# Encodage : UTF-8
# Nom : Coel v1.0
# Date de création : 2009-07-30 11:41:43
#---------------------------------------------------------------------------------------------------------------------#
# Création des tables
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_collection` (
	`cc_id_collection` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant de la collection.',
	`cc_ce_projet` INTEGER NOT NULL   COMMENT 'Identifiant du projet dans lequel les informations de la collection sont saisies.',
	`cc_ce_mere` INTEGER NOT NULL  default 0 COMMENT 'Identifiant de la collection parente. Si la collection courrante n''a pas de parente laisser la valeur 0 par défaut.',
	`cc_ce_structure` INTEGER NOT NULL  default 0 COMMENT 'Identifiant de la structure habritant physiquement la collection. Si c''est un particulier, laisser la valeur 0 par défaut et utiliser la table liant les collections aux personnes.',
	`cc_guid` VARCHAR(255)    COMMENT 'Identifiant global unique de type LSID ou URI.',
	`cc_truk_identifiant_alternatif` VARCHAR(255)    COMMENT 'Autres identifiants de la structure.',
	`cc_truk_code` VARCHAR(100)    COMMENT 'Code(s) de la collection.',
	`cc_nom` VARCHAR(255)    COMMENT 'Nom de la collection dans la langue d''origine. Afficher vis à vis du public.',
	`cc_truk_nom_alternatif` TEXT    COMMENT 'Nom alternatif de la collection.',
	`cc_description` TEXT    COMMENT 'Description principale de la collection pour un large public.',
	`cc_description_specialiste` TEXT    COMMENT 'Description de la collection pour un public de spécialistes.',
	`cc_historique` TEXT    COMMENT 'Historique de la collection (acquisition, différentes interventions de restauration, de traitement ...).',
	`cc_truk_url` VARCHAR(255)    COMMENT 'URL(s) du site web ou de la page concernant la collection.',
	`cc_truk_url_objet` VARCHAR(255)    COMMENT 'URL(s) indiquant un web service ou une page permettant d''accèder à des informations sur les objets de la collection.',
	`cc_truk_groupement_principe` VARCHAR(255)    COMMENT 'Principal but de groupement de la collection au niveau intélectuel plutôt que physique.',
	`cc_truk_groupement_but` INTEGER    COMMENT 'Principal but de réalisation de la collection.',
	`cc_ce_type` INTEGER    COMMENT 'Type de la collection vis à vis du standard NCD.',
	`cc_ce_type_depot` INTEGER    COMMENT 'Type de dépôt de la collection.',
	`cc_cote` VARCHAR(255)    COMMENT 'Côte de la collection.',
	`cc_dimenssion` VARCHAR(255)    COMMENT 'Dimenssion, taille de la collection sous forme de texte libre.',
	`cc_condition_acces` TEXT    COMMENT 'Condition d''accès à la collection. Peut être définit par défaut par la structure.',
	`cc_condition_usage` TEXT    COMMENT 'Condition d''usages de la collection. Peut être définit par défaut par la structure.',
	`cc_truk_couverture_vernaculaire` VARCHAR(255)    COMMENT 'Nature de la collection sous forme de nom(s) vernaculaire(s).',
	`cc_truk_couverture_taxonomique` VARCHAR(255)    COMMENT 'Nom de famille ou de taxons supérieurs présent dans la collection.',
	`cc_truk_couverture_regne` VARCHAR(255)    COMMENT 'Liste des règnes couverts par la collection.',
	`cc_truk_couverture_temporelle` VARCHAR(255)    COMMENT 'Période de temps couverte par la collection.',
	`cc_truk_couverture_vie` VARCHAR(255)    COMMENT 'Période de temps durant laquelle le matériel biologique était en vie. Inclu les périodes de temps paléontologiques.',
	`cc_truk_conservation_statut` VARCHAR(255)    COMMENT 'Indiquer la date d''une estimation séparée par un dièse du statut estimé utilisant l''échelle de McGinley. Plusieurs estimations seront séparés par un point virgule.',
	`cc_truk_preservation` VARCHAR(255)    COMMENT 'Liste indiquant les procédures ou techniques de conservation utilisées pour les collections non vivantes.',
	`cc_ce_developpement` VARCHAR(255)    COMMENT 'Indique le changement potentiel dans la portée de la collection.',
	`cc_truk_periode_constitution` VARCHAR(255)    COMMENT 'Liste de périodes de temps durant laquelle la collection a été assemblée.',
	`cc_truk_couverture_lieu` VARCHAR(255)    COMMENT 'Liste de lieux (continent, pays, region, département, commune, autres lieux historique ou texte libre) desquels le matériel de la collection est originaire.',
	`cc_truk_coordonnee` VARCHAR(255)    COMMENT 'Liste de coordonnées décimales des lieux d''origine du matériel de la collection.',
	`cc_ce_specimen_type` INTEGER    COMMENT 'Y-a-t''il des échantillons-types?',
	`cc_specimen_type_nbre` INTEGER    COMMENT 'Nombre de spécimen type présent dans la collection.',
	`cc_mark_speciment_type_nbre_precision` BOOL    COMMENT 'Précision sur le nombre de spécimens types indiqué (1 = exact, 0 = approximatif).',
	`cc_ce_specimen_type_classement` INTEGER    COMMENT 'Type de classement des specimens types.',
	`cc_expedition_nom` VARCHAR(255)    COMMENT 'Nom de l''expédition durant laquelle le matériel a été collecté.',
	`cc_truk_digital_medium` VARCHAR(255)    COMMENT 'Pour les collections digitales, listes des types de support d''enregistrement. Ex. : DVD-R.',
	`cc_truk_digital_format` VARCHAR(255)    COMMENT 'Pour les collections digitales, listes des types MIME.',
	`cc_mark_public` BOOL   default 0 COMMENT 'Indique si oui (=1) ou non (=0) les données de cette collection sont publiques.',
	`cc_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`cc_id_collection`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contient les informations sur les collections.\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_structure` (
	`cs_id_structure` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant de la structure.',
	`cs_ce_projet` INTEGER NOT NULL   COMMENT 'Identifiant du projet dans lequel les informations de la structure sont saisies.',
	`cs_ce_mere` INTEGER NOT NULL  default 0 COMMENT 'Identifiant de la structure mère.',
	`cs_guid` VARCHAR(255)    COMMENT 'URI (LSID ou URL) de la structure. Dans le format RDF, cela sera utilisé comme URI des données de l''institutions.',
	`cs_truk_identifiant_alternatif` VARCHAR(255)    COMMENT 'Identifiant alternatif. Par exemple, l''acronyme de l''Index Herbariorum ou du MNHN. Séparer les différentes valeurs par un point virgule ";" et le type d''identifiant de sa valeur par un dièze "#". Exemple : IH#MPU;MNHN#163',
	`cs_nom` VARCHAR(255)    COMMENT 'Nom officiel de la structure dans sa langue d''origine.',
	`cs_truk_nom_alternatif` VARCHAR(255)    COMMENT 'Autres noms de la structures. Séparer les différentes valeurs par un point virgule ";".',
	`cs_description` TEXT    COMMENT 'Description de la structure pour le public.',
	`cs_ce_type` INTEGER    COMMENT 'Identifiant du type de la structure vis à vis du standard NCD.',
	`cs_ce_truk_type_prive` VARCHAR(255)    COMMENT 'Type privé de structure.',
	`cs_ce_truk_type_public` VARCHAR(255)    COMMENT 'Type public de structure.',
	`cs_adresse_01` VARCHAR(255)    COMMENT 'Adresse principale.',
	`cs_adresse_02` VARCHAR(255)    COMMENT 'Complément d''adresse.',
	`cs_date_fondation` DATE    COMMENT 'Date de fondation de la structure.',
	`cs_code_postal` VARCHAR(16)    COMMENT 'Code postal.',
	`cs_ville` VARCHAR(255)    COMMENT 'Ville.',
	`cs_region` VARCHAR(255)    COMMENT 'Nom de la région (état, province) où est situé la structure. Utiliser les noms du standard ISO-3166-2.',
	`cs_pays` VARCHAR(255)    COMMENT 'Pays de la structure. Utiliser les codes sur deux lettres si le nom est dans le standard ISO-3166-1 sinon mettre le nom du pays.',
	`cs_latitude` FLOAT    COMMENT 'Latitude du local de la structure.',
	`cs_longitude` FLOAT    COMMENT 'Longitude du local de la structure.',
	`cs_telephone` VARCHAR(50)    COMMENT 'Téléphone principale de la structure.',
	`cs_fax` VARCHAR(50)    COMMENT 'Fax de la structure.',
	`cs_courriel` VARCHAR(255)    COMMENT 'Courriel principal de contact de l''organisation ex : accueil@organisation.org, pas de mail individuel.',
	`cs_truk_url` VARCHAR(255)    COMMENT 'URL(s) du site web principal de la structure, du logo de la structure ou d''une page web particulière.',
	`cs_nbre_personne` INTEGER    COMMENT 'Nombre de personne présentent dans la structure.',
	`cs_condition_acces` TEXT    COMMENT 'Conditions d''accès à la structure.',
	`cs_condition_usage` TEXT    COMMENT 'Conditions d''usage générales des collections de la structure.',
	`cs_mark_public` BOOL   default 0 COMMENT 'Indique si oui (=1) ou non (=0) les données de cette structure sont publiques.',
	`cs_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`cs_id_structure`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contient les informations sur les structures.\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_personne` (
	`cp_id_personne` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant d''un contact.',
	`cp_ce_projet` INTEGER NOT NULL   COMMENT 'Identifiant du projet auquel la personne appartient. Exemple : utilisateur appli coel, HUH, IPNI...',
	`cp_fmt_nom_complet` VARCHAR(100)    COMMENT 'Nom complet du contact formaté pour l''affichage (le format peut être différent en fonction du projet).',
	`cp_ce_truk_prefix` VARCHAR(20)    COMMENT 'Préfixe du nom principal. Exemple : Dr., Prof., Mr., Lord, von...',
	`cp_prenom` VARCHAR(100)    COMMENT 'Prénom principal (le plus connu, répandu) de la personne. Un point virgule peut séparer le prénom principal de prénoms secondaires à ne pas afficher dans le nom complet.',
	`cp_nom` VARCHAR(100)    COMMENT 'Indiquer les lieux de récolte (code ISO des pays) séparés par des points virgules. Après chaque code ISO indiqué les années de récolte séparées par des vigules ou des tirets pour les périodes continues). Si le pays de récolte est inconnu utilisé un point d''interogration. Exemple : FR#1905-1908,1910;PS#1912.',
	`cp_ce_truk_suffix` VARCHAR(20)    COMMENT 'Suffixe du nom principal. Exemple : Jr, III.',
	`cp_truk_nom_autre` VARCHAR(255)    COMMENT 'Nom(s) complet alternatif et surnoms. Pour les valeurs, séparez l''identifiant de l''abreviation par un symbole pipe "|". Exemple: HUH#105714|Sharp, Aaron John;APN#9544-1|Sharp, Aaron John (''Jack'')',
	`cp_abreviation` VARCHAR(50)    COMMENT 'Abreviation retenu du nom.',
	`cp_truk_abreviation_autre` VARCHAR(255)    COMMENT 'Autres abréviations du nom.',
	`cp_naissance_date` DATE   default "0000-00-00" COMMENT 'Date de naissance de la personne.',
	`cp_naissance_lieu` VARCHAR(100)    COMMENT 'Lieu de naissance de la personne.',
	`cp_deces_date` DATE    COMMENT 'Date de décés de la personne. Par défaut, si la personne n''est pas décédé le champ reste null. Si la personne est décédée mais que l''on ne connait pas la date mettre : 0000-00-00',
	`cp_deces_lieu` VARCHAR(100)    COMMENT 'Lieu de décés de la personne.',
	`cp_ce_sexe` INTEGER    COMMENT 'Indique si la personne est un homme ou une femme...',
	`cp_description` TEXT    COMMENT 'Informations diverses sur la personne.',
	`cp_biographie` TEXT    COMMENT 'Vie et renommée (locale, régionale, ...) de la personne.',
	`cp_adresse_01` VARCHAR(255)    COMMENT 'Adresse de la personne.',
	`cp_adresse_02` VARCHAR(255)    COMMENT 'Complément d''adresse personnelle.',
	`cp_region` VARCHAR(100)    COMMENT 'Nom de la région (état, province) où vit la personne. Utiliser les noms du standard ISO-3166-2.',
	`cp_bp` VARCHAR(20)    COMMENT 'Boite postale de l''adresse de la personne.',
	`cp_code_postal` VARCHAR(10)    COMMENT 'Code postal (zip) personnel.',
	`cp_ville` VARCHAR(100)    COMMENT 'Nom de la localité (ville) où vit la personne.',
	`cp_pays` VARCHAR(100)    COMMENT 'Nom du pays où vit la personne. Utiliser les noms du standard ISO-3166-1.',
	`cp_truk_telephone` VARCHAR(255)    COMMENT 'Numéro(s) de téléphone, pager... personnels complémentaires.',
	`cp_truk_fax` VARCHAR(255)    COMMENT 'Numéro(s) de fax.',
	`cp_truk_courriel` VARCHAR(255)    COMMENT 'Adresse(s) de courriel personnel. Ajouter les adresses dans leur ordre d''importance.',
	`cp_truk_url` VARCHAR(255)    COMMENT 'URL(s) de site web personnel. Ajouter les adresses dans leur ordre d''importance.',
	`cp_truk_logo` VARCHAR(255)    COMMENT 'URL(s) de logo personnel. Ajouter les adresses dans leur ordre d''importance.',
	`cp_ce_truk_specialite` VARCHAR(255)    COMMENT 'Indiquer séparer par des points virgules ";" les spécialités naturalistes de la personne.',
	`cp_truk_recolte` VARCHAR(255)    COMMENT 'Indiquer les lieux de récolte séparés par des points virgules. Indiquer le référentiel géographique utilisé puis après un # mettre le code ou identitifiant de la zone géographique. Après chaque code ISO un peut signe pipe | peut être suivi des années de récolte séparées par des vigules ou des tirets pour les périodes continues). Si le pays de récolte est inconnu utilisé un point d''interogration. Exemple : ISO-3166-1#FR|1905-1908,1910;ISO-3166-1#PS|1912;ISO-3166-2#FR-34|1917.',
	`cp_ce_truk_role` VARCHAR(255)    COMMENT 'Rôle générale de la personne vis à vis de l''ensemble des projets : superadmin, admin...',
	`cp_mark_licence` BOOL   default 0 COMMENT 'Indique quand la valeur vaut 1 que l''utilisateur a accepté la licence d''utilisation de l''application. ',
	`cp_parametre` TEXT    COMMENT 'Parametres de l''utilisateur vis à vis de l''application.',
	`cp_session_id` VARCHAR(100)    COMMENT 'Identifiant de session de la personne utilisatrice de l''application.',
	`cp_login` VARCHAR(50)    COMMENT 'Login de la personne pour accéder à l''application.',
	`cp_mot_de_passe` VARCHAR(100)    COMMENT 'Mot de passe de la personne pour accéder à l''application. Encodé par SHA1.',
	`cp_ce_annuaire_tela` INTEGER    COMMENT 'Identifiant de la personne dans l''annuaire de Tela Botanica.',
	`cp_mark_public` BOOL   default 0 COMMENT 'Indique si oui (=1) ou non (=0) les données de cette personne sont publiques.',
	`cp_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`cp_id_personne`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contient les informations sur les personnes.\nPar personne nous entendons à la fois les utilisateurs de l''application mais aussi les personnes contacts, les botanistes collecteurs, auteurs...\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_structure_a_personne` (
	`csap_id_structure` INTEGER NOT NULL   COMMENT 'Identifiant de la structure.',
	`csap_id_personne` INTEGER NOT NULL   COMMENT 'Identifiant d''une personne.',
	`csap_id_role` INTEGER NOT NULL   COMMENT 'Rôle de la personne vis à vis de la structure.',
	`csap_ce_truk_fonction` VARCHAR(255)    COMMENT 'Intitulé de la fonction de la personne dans son travail.',
	`csap_service` VARCHAR(100)    COMMENT 'Nom du service ou département dans lequel la personne travaille.',
	`csap_ce_truk_statut` VARCHAR(255)    COMMENT 'Statut(s) de la personne : salarié, bénévole...',
	`csap_mark_contact` BOOL   default 0 COMMENT 'Si la personne est un contact la valeur vaut 1 sinon c''est 0.',
	`csap_bota_travail_hebdo_tps` INTEGER    COMMENT 'Date de la dernière modification sur cet enregistrement.',
	`csap_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`csap_id_structure`, `csap_id_personne`, `csap_id_role`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Table de liaison permettant d''indiquer la composition de la structure en personnel.\nElle permet d''indiquer pour une personne vis à vis d''une structure :\n - si elle est contact\n - les informations de la personne spécifique à cette structure (ex. : téléphone du travail, fonction, service, statut...).' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_meta_donnee` (
	`cmd_id_donnee` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant de la donnée.',
	`cmd_ce_table` INTEGER NOT NULL   COMMENT 'Identifiant de la table.',
	`cmd_ce_ligne` VARCHAR(64) NOT NULL   COMMENT 'Identifiant de la ligne à laquelle le champ dans la table d''origine appartient. Pour les tables à clé primaire multi colonnes, bien respecter l''ordre des champs de la clé et inscrire chaque valeur de clé séparée par un tiret "-".',
	`cmd_ce_champ` INTEGER NOT NULL   COMMENT 'Identifiant du champ.',
	`cmd_valeur` VARCHAR(255) NOT NULL   COMMENT 'Valeur.',
PRIMARY KEY(`cmd_id_donnee`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contient les champs supplémentaires (non standard ou de spécialisation) de la base de données.' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_meta_colonne` (
	`cmc_id_champ` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant du nom du champ dans la table.',
	`cmc_ce_projet` INTEGER NOT NULL   COMMENT 'Identifiant du projet.',
	`cmc_ce_liste` INTEGER NOT NULL   COMMENT 'Identifiant de la liste de valeur possédée par cette colonne.',
	`cmc_ce_table` INTEGER NOT NULL   COMMENT 'Identifiant de la table à laquelle ce champ appartient.',
	`cmc_nom` VARCHAR(50)    COMMENT 'Intitulé du champ.',
	`cmc_abreviation` VARCHAR(20)    COMMENT 'Abréviation du champ.',
	`cmc_description` VARCHAR(510)    COMMENT 'Description du champ.',
	`cmc_ce_format_sql` INTEGER    COMMENT 'Identifiant du format SQL utilisé pour ce champ.',
	`cmc_taille` VARCHAR(20)    COMMENT 'Taille du format SQL du champ.',
	`cmc_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`cmc_id_champ`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contient l''ensemble des champs des tables de la base de données.\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_meta_liste_valeur` (
	`cmlv_id_valeur` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant d''une valeur de liste. Notez que les listes sont des valeurs de la liste des listes.',
	`cmlv_ce_parent` INTEGER NOT NULL   COMMENT 'Identifiant de la catégorie ou des informations sur la liste. Les listes ont pour parent la valeur 0 qui correspond à la liste des listes.',
	`cmlv_ce_projet` INTEGER NOT NULL   COMMENT 'Identifiant du projet de la valeur.',
	`cmlv_nom` VARCHAR(100)    COMMENT 'Nom de la valeur.',
	`cmlv_abreviation` VARCHAR(50)    COMMENT 'Abréviation, code ou identifiant de la valeur.',
	`cmlv_description` VARCHAR(255)    COMMENT 'Description de cette valeur.',
	`cmlv_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`cmlv_id_valeur`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Liste l''ensemble des valeurs des tables de type liste.\nUn champ contient des valeurs dans cette table quand il est de type "LISTE".\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_meta_historique_colonne` (
	`cmhc_id_historique_colonne` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant de cet enregistrement historisé.',
	`cmhc_ce_historique_ligne` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
	`cmhc_ce_champ` INTEGER NOT NULL   COMMENT 'Identifiant du champ.',
	`cmhc_valeur` VARCHAR(255) NOT NULL   COMMENT 'Valeur du champ pour cette ligne.',
PRIMARY KEY(`cmhc_id_historique_colonne`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contient l''historique des valeurs des champs pour les enregistrements des tables de la base de données.\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_structure_conservation` (
	`csc_id_structure` INTEGER NOT NULL   COMMENT 'Identifiant de la structure.',
	`csc_mark_formation` BOOL   default 0 COMMENT 'Le personnel s''occupant des collections botaniques a-t-il suivi des formations en conservation ?',
	`csc_formation` VARCHAR(255)    COMMENT 'Les formations en conservation suvi par le personnel.',
	`csc_mark_formation_interet` BOOL    COMMENT 'Le personnel s''occupant des collections botaniques a-t-il suivi des formations en conservation ?',
	`csc_truk_stockage_local` VARCHAR(255)    COMMENT 'Avez-vous des locaux spécifiques de stockage des collections botaniques ?',
	`csc_truk_stockage_meuble` VARCHAR(255)    COMMENT 'Avez-vous des meubles spécifiques au stockage des collections botaniques ? ',
	`csc_truk_stockage_parametre` VARCHAR(255)    COMMENT 'Quels paramètres maîtrisez-vous ?',
	`csc_mark_collection_commune` BOOL NOT NULL  default 0 COMMENT 'Les collections botaniques sont-elles conservées avec d''autres collections dans les mêmes locaux (problème de conservation en commun) ? ',
	`csc_truk_collection_autre` VARCHAR(255)    COMMENT 'Actuellement, vos collections botaniques s''accroissent-elles de nouvelles acquisitions ?',
	`csc_mark_acces_controle` BOOL    COMMENT 'L''accès à vos collections botaniques est-il contrôlé (ex. : manipulation réservée à des personnes compétentes) ?',
	`csc_mark_restauration` BOOL    COMMENT 'Effectuez-vous actuellement des opérations de restauration ou de remise en état de vos collections botaniques ?',
	`csc_truk_restauration_operation` VARCHAR(255)    COMMENT 'Les différentes opérations de restauration actuellement menées.',
	`csc_ce_materiel_conservation` INTEGER    COMMENT 'Utilisez-vous du matériel de conservation ?',
	`csc_truk_materiel_autre` VARCHAR(255)    COMMENT 'Le matériel, dit de "non conservation" utilisé.',
	`csc_mark_traitement` BOOL    COMMENT 'Réalisez-vous actuellement des traitements globaux contre les insectes ?',
	`csc_truk_traitement` VARCHAR(255)    COMMENT 'Traitements globaux contre les insectes.',
	`csc_mark_acquisition_collection` BOOL    COMMENT 'Actuellement, vos collections botaniques s''accroissent-elles de nouvelles acquisitions ?',
	`csc_mark_acquisition_echantillon` BOOL    COMMENT 'Actuellement mettez-vous en herbier de nouveaux échantillons ? ',
	`csc_mark_acquisition_traitement` BOOL    COMMENT 'Si oui, faites-vous un traitement contre les insectes avant l''intégration dans vos collections ?',
	`csc_truk_acquisition_traitement_poison` VARCHAR(255)    COMMENT 'Traitement de type empoisonnement effectué lors des des acquisitions.',
	`csc_truk_acquisition_traitement_insecte` VARCHAR(255)    COMMENT 'Traitement de type désinctisation effectué lors des des acquisitions.',
	`csc_ce_meta` INTEGER    COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`csc_id_structure`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Toutes les données spécifiques à la conservation au sein d''une structure.' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_structure_valorisation` (
	`csv_id_structure` INTEGER NOT NULL   COMMENT 'Identifiant de la structure.',
	`csv_mark_action` BOOL    COMMENT 'Avez-vous réalisé des actions de valorisation de vos collections botaniques ou avez-vous été sollicités pour la valorisation de ces collections ?',
	`csv_truk_action` VARCHAR(255)    COMMENT 'Les actions de valorisation réalisées.',
	`csv_publication` TEXT    COMMENT 'Quelques titres des ouvrages, articles scientifiques, ... ?',
	`csv_collection_autre` VARCHAR(255)    COMMENT 'L''organisme dispose-t-il d''autres collections (permettant une valorisation pluridisciplinaire) ?',
	`csv_mark_action_future` BOOL    COMMENT 'Envisagez-vous des actions de valorisation dans le cadre de votre politique culturelle ?',
	`csv_action_future` VARCHAR(255)    COMMENT 'Les actions de valorisation futures envisagées.',
	`csv_mark_recherche` BOOL    COMMENT 'Vos collections botaniques sont-elles utilisées pour des recherches scientifiques ?',
	`csv_truk_recherche_provenance` VARCHAR(255)    COMMENT 'Si oui, par des chercheurs (professionnels ou amateurs ) de  quelle provenance ?',
	`csv_truk_recherche_type` VARCHAR(255)    COMMENT 'Et pour quelles types de recherches ? ',
	`csv_mark_acces_ss_motif` BOOL    COMMENT 'Peut-on consulter vos collections botaniques sans motif de recherches scientifiques ?',
	`csv_acces_ss_motif` VARCHAR(255)    COMMENT 'Si oui, quelles démarches doit-on faire pour les consulter ?',
	`csv_mark_visite_avec_motif` BOOL    COMMENT 'Peut-on visiter vos collections botaniques en avec des objectifs de recherches scientifiques ?',
	`csv_visite_avec_motif` VARCHAR(255)    COMMENT 'Si oui, quelles démarches doit-on faire pour les visiter ?',
	`csv_ce_meta` INTEGER    COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`csv_id_structure`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Toutes les données spécifiques à la valorisation au sein d''une structure.' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_collection_a_personne` (
	`ccap_id_collection` INTEGER NOT NULL   COMMENT 'Identifiant de la collection associée à une personne.',
	`ccap_id_personne` INTEGER NOT NULL   COMMENT 'Identifiant de la personne associée à une collection.',
	`ccap_id_role` VARCHAR(255) NOT NULL   COMMENT 'Rôle(s) de la personne : auteur, collecteur... permet aussi de connaître qui a les droits de modification sur la collection.',
	`ccap_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`ccap_id_collection`, `ccap_id_personne`, `ccap_id_role`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Permet de lister les personnes en rapport avec une collection.' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_collection_botanique` (
	`ccb_id_collection` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant de la collection botanique.',
	`ccb_ce_truk_type` VARCHAR(255)    COMMENT 'Type(s) de collection botanique.',
	`ccb_truk_unite_rangement` VARCHAR(510)    COMMENT 'Type(s) unité de rangement de la collection botanique. \
Pour chaque type : indication du nombre d''unité, de la précision du nom (exact, approximatif), des formats.',
	`ccb_ce_unite_rangement_etat` INTEGER    COMMENT 'État de la majorité des unités de rangements (état des rubans, des poignées, des sangles, des cartons...).',
	`ccb_truk_unite_base` VARCHAR(510)    COMMENT 'Type(s) d''unité de base de la collection,  si différent de l''unité de rangement. \\  Ex. : si l''unité de rangement est un carton, l''unité de base peut être  une enveloppe. \\  Pour chaque type : indication du nombre d''unité, de la précision du nom (exact = 1, approximatif = 0), des formats (Lxl cm), du nombre de parts, de la précision sur le nombre de parts  (exact = 1, approximatif = 0), du nombre d''espèces, de la précision sur le nombre d''espèces (exact, approximatif).',
	`ccb_truk_conservation_papier_type` VARCHAR(255)    COMMENT 'Type(s) du papier de conservation.',
	`ccb_truk_conservation_methode` VARCHAR(255)    COMMENT 'Type(s) de méthode de conservation.',
	`ccb_specimen_fixation_pourcent` INTEGER    COMMENT 'Pourcentage de spécimens fixés.',
	`ccb_etiquette_fixation_pourcent` INTEGER    COMMENT 'Pourcentage d''étiquettes fixées.',
	`ccb_truk_specimen_fixation_methode` VARCHAR(255)    COMMENT 'Type(s) de fixation des spécimens.',
	`ccb_truk_etiquette_fixation_support` VARCHAR(255)    COMMENT 'Type(s) de fixation des étiquettes fixées au support.',
	`ccb_truk_etiquette_fixation_specimen` VARCHAR(255)    COMMENT 'Type(s) de fixation des étiquettes fixées au spécimen.',
	`ccb_truk_etiquette_ecriture` VARCHAR(255)    COMMENT 'Type(s) d''écriture sur les étiquettes.',
	`ccb_ce_traitement` INTEGER    COMMENT 'La collection botanique semble-t-elle avoir été empoisonnée ou désinsectisée lors de sa réalisation ?',
	`ccb_truk_traitement_poison` VARCHAR(255)    COMMENT 'Type(s) d''empoisonement de la collection.',
	`ccb_truk_traitement_insecte` VARCHAR(255)    COMMENT 'Type(s) de désinctisation de la collection.',
	`ccb_ce_etat_general` INTEGER    COMMENT 'État général de la collection (grosses attaques d''insectes, pourriture, papier très fragile, etc... de 1 très mauvais à 5 très bon état).',
	`ccb_truk_degradation_specimen` VARCHAR(255)    COMMENT 'Type(s) de causes des dégradations des spécimens notées de 1 très mauvais à 5 très bon état.',
	`ccb_truk_degradation_presentation` VARCHAR(255)    COMMENT 'Type(s) de causes des dégradations de la présentation notées de 1 très mauvais à 5 très bon état.',
	`ccb_ce_determination` INTEGER    COMMENT 'Les échantillons sont-ils déterminables ? (de 1 : quelques fragment de plantes à 5 plantes entières).',
	`ccb_truk_nature` VARCHAR(255)    COMMENT 'Nature de l''herbier.',
	`ccb_specialite` VARCHAR(255)    COMMENT 'Collection botanique spécialisée (ex. herbier de céréales...)',
	`ccb_recolte_date_debut` DATE    COMMENT 'Date extrême de début de récolte.',
	`ccb_ce_recolte_date_debut_type` INTEGER    COMMENT 'Type de date extrême de début de récolte.',
	`ccb_recolte_date_fin` DATE    COMMENT 'Date extrême de fin de récolte.',
	`ccb_ce_recolte_date_fin_type` INTEGER    COMMENT 'Type de date extrême de fin de récolte.',
	`ccb_annotation_classement` TEXT    COMMENT 'Indiquer le type de classement ou des informations concernant un éventuel classement.',
	`ccb_ce_classement_etat` INTEGER    COMMENT 'État du classement (de 1 très mauvais à 5 très bon).',
	`ccb_truk_etiquette_renseignement` VARCHAR(255)    COMMENT 'Pourcentage pour chaque type de renseignements portés sur l''étiquette ou sur la part.',
	`ccb_ce_precision_localite` INTEGER    COMMENT 'Les localités sont elles précises?',
	`ccb_ce_precision_date` INTEGER    COMMENT 'Les dates sont elles précises?',
	`ccb_annotation_diverse` TEXT    COMMENT 'Autres annotations (dons, annotations personnelles, recettes, utilisations médicales...).',
	`ccb_ce_collection_integre` INTEGER    COMMENT 'La collection observée intègre-t-elle des collections botaniques antérieures ?',
	`ccb_ce_collection_integre_info` INTEGER    COMMENT 'Les noms de ces collections sont-ils notés sur les étiquettes de chaque échantillon ?',
	`ccb_ce_inventaire` INTEGER    COMMENT 'Existe-t-il un inventaire de cette collection?',
	`ccb_ce_inventaire_auteur` INTEGER    COMMENT 'L''auteur de la collection a-t-il participé à cet inventaire?',
	`ccb_ce_inventaire_forme` INTEGER    COMMENT 'Forme de l''inventaire (mnauscrit, informatique...).',
	`ccb_inventaire_info` TEXT    COMMENT 'Quelles informations retrouve-t-on?',
	`ccb_ce_truk_inventaire_digital` VARCHAR(255)    COMMENT 'Si inventaire digial, quel logiciel utilisez vous?',
	`ccb_inventaire_digital_pourcent` INTEGER    COMMENT 'Pourcentage de la documentation en base de données.',
	`ccb_ce_inventaire_etat` INTEGER    COMMENT 'L''inventaire est il complet ou partiel?',
	`ccb_inventaire_donnee_type` TEXT    COMMENT 'Quels sont les éléments qui ont déjà été inventoriés (Ex. : familles, localités...) ?',
	`ccb_ce_meta` INTEGER    COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`ccb_id_collection`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Toutes les informations spécialisées sur une collection de type : botanique' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_publication` (
	`cpu_id_publication` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant de la publication.',
	`cpu_ce_projet` INTEGER NOT NULL   COMMENT 'Identifiant du projet dans lequel les données de cet enregistrement ont été saisies.',
	`cpu_fmt_nom_complet` VARCHAR(255)    COMMENT 'Intitulé de la publication complet : fmt_auteur, date_parution(année). titre. Editeur (nom), collection, fascicule, indication_nvt. pages.',
	`cpu_uri` VARCHAR(255)    COMMENT 'URI de la publication qui peut être un site web...',
	`cpu_fmt_auteur` VARCHAR(255)    COMMENT 'Contient le nom formaté de l''intitulé auteur(s). Si plusieurs personnes sont auteurs, l''intitulé est formaté ici.',
	`cpu_titre` VARCHAR(255)    COMMENT 'Titre de l''article ou de l''ouvrage.',
	`cpu_ce_truk_editeur` VARCHAR(255)    COMMENT 'Identifiant de la structure éditrice de la publication. S''il n''est pas renseignné dans la table Structure, contient AUTRE# suivit du nom complet de la structure éditrice.',
	`cpu_collection` VARCHAR(255)    COMMENT 'Intitulé de la collection, c''est à dire de la revue.',
	`cpu_date_parution` DATE    COMMENT 'Date de parution de la publication.',
	`cpu_indication_nvt` VARCHAR(255)    COMMENT 'Indication du numéro, volume ou tome de la publication. Plutôt utilisé pour les ouvrages et non les articles de revue.',
	`cpu_fascicule` VARCHAR(255)    COMMENT 'Indication du titre du fascicule. Surtout utilisé pour les revues.',
	`cpu_truk_pages` VARCHAR(25)    COMMENT 'Indication du nombre de pages (pour les ouvrages) ou des pages de début et de fin pour un artcile. Dans le cas des ouvrages un nombre doit être présent. Pour les articles deux nombres ou point d''intérogation séparés par un tiret.',
	`cpu_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`cpu_id_publication`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Publication de type articles scientifiques, ouvrages ou sites web.\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_collection_a_publication` (
	`ccapu_id_collection` INTEGER NOT NULL   COMMENT 'Identifiant de collection.',
	`ccapu_id_publication` INTEGER NOT NULL   COMMENT 'Identifiant de la publication.',
	`ccapu_mark_licence` BOOL    COMMENT 'Booléen indiquant si la publication indiqué correspond aux droits de propriétés intellectuelles de la collection.',
	`ccapu_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`ccapu_id_collection`, `ccapu_id_publication`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Permet de lister les publication liées à une collection.' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_publication_a_personne` (
	`cpuap_id_publication` INTEGER NOT NULL   COMMENT 'Identifiant d''une publication.',
	`cpuap_id_personne` INTEGER NOT NULL   COMMENT 'Identifiant d''une personne.',
	`cpuap_id_role` INTEGER NOT NULL   COMMENT 'Rôle de la personne vis à vis de la publication : contributeur, auteur...',
	`cpuap_ce_truk_type` VARCHAR(255)    COMMENT 'Contient le type de référence bibliographique : nécrologie, biographie, publication personnelle...',
	`cpuap_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`cpuap_id_publication`, `cpuap_id_personne`, `cpuap_id_role`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Permet de lister les publications d''une personne.' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_collection_a_relation` (
	`ccar_id_collection_01` INTEGER NOT NULL   COMMENT 'Identifiant de la collection n°1.',
	`ccar_id_collection_02` INTEGER NOT NULL   COMMENT 'Identifiant de la collection n°2.',
	`ccar_id_relation` INTEGER NOT NULL   COMMENT 'Indentifiant du type de la relation.',
	`ccar_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`ccar_id_collection_01`, `ccar_id_collection_02`, `ccar_id_relation`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Permet de lister les relations entre collection autre que hiérarchique.' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_projet` (
	`cpr_id_projet` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant d''un projet.',
	`cpr_nom` VARCHAR(255) NOT NULL   COMMENT 'Nom du projet.',
	`cpr_abreviation` VARCHAR(40)    COMMENT 'Abréviation du projet.',
	`cpr_resume` VARCHAR(255)    COMMENT 'Résumé du projet.',
	`cpr_description` TEXT    COMMENT 'Description détaillée du projet.',
	`cpr_url` VARCHAR(255)    COMMENT 'URL principal où trouver des compléments d''information sur le projet.',
	`cpr_mot_cles` VARCHAR(255)    COMMENT 'Mots clés correspondant au projet.',
	`cpr_citation` VARCHAR(255)    COMMENT 'Indication sur la fa\195\167on de citer le projet pour réaliser une bibliographie.',
	`cpr_licence` VARCHAR(255)    COMMENT 'Url ou texte présentant la licence des données du projet.',
	`cpr_ce_langue` INTEGER    COMMENT 'Langue principale des données du projet (selon l''ISO-639-1).',
	`cpr_indexation_heure` TIME    COMMENT 'Préférence de l''heure de départ pour les procédures d''indexation externe.',
	`cpr_ce_indexation_duree` INTEGER    COMMENT 'Durée maximum acceptable pour une procédure d''indexation externe.',
	`cpr_ce_indexation_freq` INTEGER    COMMENT 'Fréquence maximum acceptable pour une procédure d''indexation externe.',
	`cpr_mark_public` BOOL   default 0 COMMENT 'Indique si oui (=1) ou non (=0) ce projet est public. Si oui, il peut être publié dans eFlore.',
	`cpr_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`cpr_id_projet`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contient les informations sur un projet de données.\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_personne_a_relation` (
	`cpar_id_personne_01` INTEGER NOT NULL   COMMENT 'Identifiant de la personne n°1.',
	`cpar_id_personne_02` INTEGER NOT NULL   COMMENT 'Identifiant de la personne n°2.',
	`cpar_id_projet` INTEGER NOT NULL   COMMENT 'Identifiant du projet dans lequel la relation entre les deux personnes s''établie.',
	`cpar_id_role` INTEGER NOT NULL   COMMENT 'Identifiant du rôle ou de la valeur établie entre les deux personnes.',
	`cpar_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`cpar_id_personne_01`, `cpar_id_personne_02`, `cpar_id_projet`, `cpar_id_role`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Relation entre deux personnes vis à vis d''un projet.' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_projet_version` (
	`cprv_id_version` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant d''une version de projet.',
	`cprv_ce_projet` INTEGER NOT NULL   COMMENT 'Identifiant du projet de la version.',
	`cprv_nom` VARCHAR(255)    COMMENT 'Nom éventuel de la version.',
	`cprv_code` VARCHAR(25) NOT NULL   COMMENT 'Numéro ou code de la version.',
	`cprv_date_debut` DATETIME NOT NULL  default "0000-00-00 00:00:00" COMMENT 'Date de début de la version.',
	`cprv_date_fin` DATETIME    COMMENT 'Date de fin de la version.',
	`cprv_ce_meta` INTEGER NOT NULL   COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`cprv_id_version`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Table contenant les informations sur la version d''un projet.\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_meta_historique_ligne` (
	`cmhl_id_historique_ligne` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant de l''historique des lignes.',
	`cmhl_ce_table` INTEGER    COMMENT 'Identifiant de la table.',
	`cmhl_cle_ligne` VARCHAR(64) NOT NULL   COMMENT 'Identifiant de la ligne. Pour les tables à clé primaire multi colonnes, bien respecter l''ordre des champs de la clé et inscrire chaque valeur de clé séparée par un tiret "-".',
	`cmhl_enregistrement` TEXT    COMMENT 'Contient les données au format XML pour les enregistrements supprimés uniquement, sinon possède la valeur NULL. Format XML : <xml encoding="UTF-8><ligne><nom_du_champ_01>valeur_du_champ_01</nom_du_champ_01><nom_du_champ_02>valeur_du_champ_02</nom_du_champ_02>...</ligne></xml>.',
	`cmhl_date_modification` DATETIME NOT NULL   COMMENT 'Date de modification de la ligne.',
	`cmhl_notes` VARCHAR(255)    COMMENT 'Notes sur la modification effectuée sur la ligne.',
	`cmhl_ce_modifier_par` INTEGER NOT NULL   COMMENT 'Identifiant de la personne ayant effectué cette modification sur la ligne.',
	`cmhl_ce_etat` INTEGER NOT NULL   COMMENT 'Identifiant de l''état de la ligne.',
	`cmhl_ip` VARCHAR(50) NOT NULL   COMMENT 'Adresse IP (et MAC éventuellement) depuis laquelle la modification a eu lieu.',
	`cmhl_session_id` VARCHAR(40)    COMMENT 'Identifiant de session del ''utilisateur.',
PRIMARY KEY(`cmhl_id_historique_ligne`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contient les métadonnées sur l''historique des enregistrements des tables de la base de données.\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_commentaire` (
	`ccm_id_commentaire` INTEGER NOT NULL auto_increment  COMMENT 'Identifiant d''un commentaire.',
	`ccm_ce_pere` INTEGER NOT NULL  default 0 COMMENT 'Identifiant du commentaire père.',
	`ccm_ce_projet` INTEGER    COMMENT 'Identifiant du projet dans lequel le commentaire est fait.',
	`ccm_titre` VARCHAR(255)    COMMENT 'Titre du commentaire.',
	`ccm_texte` TEXT    COMMENT 'Texte du commentaire.',
	`ccm_ponderation` INTEGER    COMMENT 'Pondération du commentaire (importance). Valeur de 1 à 10.',
	`ccm_ce_meta` INTEGER    COMMENT 'Identifiant des métadonnées de cet enregistrement.',
	`ccm_mark_public` BOOL   default 0 COMMENT 'Indique si oui (=1) ou non (=0) ce commentaire est public .',
PRIMARY KEY(`ccm_id_commentaire`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Contient les commentaires.\n' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_collection_a_commentaire` (
	`ccac_id_collection` INTEGER NOT NULL   COMMENT 'Identifiant de la collection.',
	`ccac_id_commentaire` INTEGER NOT NULL   COMMENT 'Identifiant du commentaire.',
	`ccac_truk_type` VARCHAR(255)    COMMENT 'Liste des types de commentaires séparés par des points virgules.',
	`ccac_ce_meta` INTEGER    COMMENT 'Identifiant des métadonnées de cet enregistrement.',
PRIMARY KEY(`ccac_id_collection`, `ccac_id_commentaire`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='Permet de lister les commentaires / notes faits sur une collection.' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
CREATE TABLE IF NOT EXISTS `tb_coel`.`coel_projet_a_structure` (
	`cpras_id_projet` INTEGER NOT NULL   COMMENT '',
	`cpras_id_structure` INTEGER NOT NULL   COMMENT '',
	`cpras_truk_role` VARCHAR(255)    COMMENT '',
	`cpras_ce_meta` INTEGER    COMMENT '',
PRIMARY KEY(`cpras_id_projet`, `cpras_id_structure`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci COMMENT='' AUTO_INCREMENT=1;

#---------------------------------------------------------------------------------------------------------------------#
# Insertion des méta-données
# Ajout du projet de métadonnées
INSERT INTO `tb_coel`.`coel_projet` (`cpr_id_projet` ,`cpr_nom` ,`cpr_abreviation` ,`cpr_resume` ,`cpr_description` ,`cpr_url` ,`cpr_ce_meta`) VALUES 
	('1', 'Métadonnées', 'meta', 'Contient le schéma de la base de données et les listes de valeurs.', 'Ce projet est interne au système. Il permet de créer le schéma de la base de données qui sera stocké dans le module Métadonnées.', NULL , '1');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1', '115', '1', NULL , NOW( ) , 'Ajout du projet des métadonnées', '1', '1', '162.38.234.1');
# Ajout super-administrateur
INSERT INTO `tb_coel`.`coel_personne` (`cp_id_personne` ,`cp_ce_projet` ,`cp_fmt_nom_complet` ,`cp_abreviation` ,`cp_truk_courriel` ,`cp_login` ,`cp_mot_de_passe` ,`cp_ce_meta`) VALUES 
	('1', '1', 'Super Administrateur', 'SA', 'webmestre@tela-botanica.org', 'webmestre', SHA1( '000000' ) , '2');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2', '113', '1', NULL , NOW( ) , 'Ajout du super administrateur', '1', '1', '162.38.234.1');

# Liste des tables du modèle de la base de données
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('101', '1003', '1', 'coel_collection', 'cc', 'Contient les informations sur les collections.\n', '3');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3', '112', '101', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('102', '1003', '1', 'coel_collection_a_commentaire', 'ccac', 'Permet de lister les commentaires / notes faits sur une collection.', '4');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4', '112', '102', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('103', '1003', '1', 'coel_collection_a_personne', 'ccap', 'Permet de lister les personnes en rapport avec une collection.', '5');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5', '112', '103', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('104', '1003', '1', 'coel_collection_a_publication', 'ccapu', 'Permet de lister les publication liées à une collection.', '6');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6', '112', '104', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('105', '1003', '1', 'coel_collection_a_relation', 'ccar', 'Permet de lister les relations entre collection autre que hiérarchique.', '7');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7', '112', '105', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('106', '1003', '1', 'coel_collection_botanique', 'ccb', 'Toutes les informations spécialisées sur une collection de type : botanique', '8');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8', '112', '106', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('107', '1003', '1', 'coel_commentaire', 'ccm', 'Contient les commentaires.\n', '9');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9', '112', '107', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('108', '1003', '1', 'coel_meta_colonne', 'cmc', 'Contient l''ensemble des champs des tables de la base de données.\n', '10');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10', '112', '108', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('109', '1003', '1', 'coel_meta_donnee', 'cmd', 'Contient les champs supplémentaires (non standard ou de spécialisation) de la base de données.', '11');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11', '112', '109', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('110', '1003', '1', 'coel_meta_historique_colonne', 'cmhc', 'Contient l''historique des valeurs des champs pour les enregistrements des tables de la base de données.\n', '12');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12', '112', '110', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('111', '1003', '1', 'coel_meta_historique_ligne', 'cmhl', 'Contient les métadonnées sur l''historique des enregistrements des tables de la base de données.\n', '13');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13', '112', '111', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('112', '1003', '1', 'coel_meta_liste_valeur', 'cmlv', 'Liste l''ensemble des valeurs des tables de type liste.\nUn champ contient des valeurs dans cette table quand il est de type "LISTE".\n', '14');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14', '112', '112', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('113', '1003', '1', 'coel_personne', 'cp', 'Contient les informations sur les personnes.\nPar personne nous entendons à la fois les utilisateurs de l''application mais aussi les personnes contacts, les botanistes collecteurs, auteurs...\n', '15');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15', '112', '113', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('114', '1003', '1', 'coel_personne_a_relation', 'cpar', 'Relation entre deux personnes vis à vis d''un projet.', '16');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16', '112', '114', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('115', '1003', '1', 'coel_projet', 'cpr', 'Contient les informations sur un projet de données.\n', '17');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17', '112', '115', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('116', '1003', '1', 'coel_projet_a_structure', 'cpras', '', '18');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18', '112', '116', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('117', '1003', '1', 'coel_projet_version', 'cprv', 'Table contenant les informations sur la version d''un projet.\n', '19');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19', '112', '117', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('118', '1003', '1', 'coel_publication', 'cpu', 'Publication de type articles scientifiques, ouvrages ou sites web.\n', '20');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20', '112', '118', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('119', '1003', '1', 'coel_publication_a_personne', 'cpuap', 'Permet de lister les publications d''une personne.', '21');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21', '112', '119', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('120', '1003', '1', 'coel_structure', 'cs', 'Contient les informations sur les structures.\n', '22');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22', '112', '120', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('121', '1003', '1', 'coel_structure_a_personne', 'csap', 'Table de liaison permettant d''indiquer la composition de la structure en personnel.\nElle permet d''indiquer pour une personne vis à vis d''une structure :\n - si elle est contact\n - les informations de la personne spécifique à cette structure (ex. : téléphone du travail, fonction, service, statut...).', '23');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23', '112', '121', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('122', '1003', '1', 'coel_structure_conservation', 'csc', 'Toutes les données spécifiques à la conservation au sein d''une structure.', '24');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24', '112', '122', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('123', '1003', '1', 'coel_structure_valorisation', 'csv', 'Toutes les données spécifiques à la valorisation au sein d''une structure.', '25');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25', '112', '123', NULL , NOW( ) , 'Initialisation d''une valeur table pour la liste des tables.', '1', '1', '162.38.234.1');

# Valeurs et listes
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1', '1001', '1', 'Ajouté', 'A', 'NULL', '26');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26', '112', '1', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «A» pour la liste «00a».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2', '1001', '1', 'Modifié', 'M', 'NULL', '27');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27', '112', '2', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «M» pour la liste «00a».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3', '1001', '1', 'Supprimé', 'S', 'NULL', '28');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28', '112', '3', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «S» pour la liste «00a».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11', '1002', '1', 'TINYINT', '1', 'NULL', '29');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29', '112', '11', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «1» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12', '1002', '1', 'SMALLINT', '2', 'NULL', '30');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('30', '112', '12', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «2» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13', '1002', '1', 'MEDIUMINT', '3', 'NULL', '31');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('31', '112', '13', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «3» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14', '1002', '1', 'INT', '4', 'NULL', '32');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('32', '112', '14', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «4» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15', '1002', '1', 'INTEGER', '5', 'NULL', '33');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('33', '112', '15', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «5» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16', '1002', '1', 'BIGINT', '6', 'NULL', '34');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('34', '112', '16', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «6» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17', '1002', '1', 'FLOAT', '7', 'NULL', '35');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('35', '112', '17', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «7» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18', '1002', '1', 'DOUBLE', '8', 'NULL', '36');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('36', '112', '18', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «8» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19', '1002', '1', 'DOUBLE PRECISION', '9', 'NULL', '37');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('37', '112', '19', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «9» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20', '1002', '1', 'REAL', '10', 'NULL', '38');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('38', '112', '20', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «10» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21', '1002', '1', 'DECIMAL', '11', 'NULL', '39');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('39', '112', '21', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «11» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22', '1002', '1', 'NUMERIC', '12', 'NULL', '40');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('40', '112', '22', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «12» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23', '1002', '1', 'DATE', '13', 'NULL', '41');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('41', '112', '23', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «13» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24', '1002', '1', 'DATETIME', '14', 'NULL', '42');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('42', '112', '24', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «14» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25', '1002', '1', 'TIMESTAMP', '15', 'NULL', '43');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('43', '112', '25', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «15» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26', '1002', '1', 'TIME', '16', 'NULL', '44');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('44', '112', '26', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «16» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27', '1002', '1', 'YEAR', '17', 'NULL', '45');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('45', '112', '27', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «17» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28', '1002', '1', 'CHAR', '18', 'NULL', '46');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('46', '112', '28', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «18» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29', '1002', '1', 'VARCHAR', '19', 'NULL', '47');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('47', '112', '29', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «19» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30', '1002', '1', 'BIT', '20', 'NULL', '48');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('48', '112', '30', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «20» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('31', '1002', '1', 'BOOL', '21', 'NULL', '49');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('49', '112', '31', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «21» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('32', '1002', '1', 'TINYBLOB', '22', 'NULL', '50');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('50', '112', '32', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «22» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('33', '1002', '1', 'BLOB', '23', 'NULL', '51');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('51', '112', '33', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «23» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('34', '1002', '1', 'MEDIUMBLOB', '24', 'NULL', '52');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('52', '112', '34', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «24» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('35', '1002', '1', 'LONGBLOB', '25', 'NULL', '53');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('53', '112', '35', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «25» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('36', '1002', '1', 'TINYTEXT', '26', 'NULL', '54');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('54', '112', '36', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «26» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('37', '1002', '1', 'TEXT', '27', 'NULL', '55');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('55', '112', '37', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «27» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('38', '1002', '1', 'MEDIUMTEXT', '28', 'NULL', '56');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('56', '112', '38', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «28» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('39', '1002', '1', 'LONGTEXT', '29', 'NULL', '57');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('57', '112', '39', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «29» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('40', '1002', '1', 'ENUM', '30', 'NULL', '58');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('58', '112', '40', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «30» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('41', '1002', '1', 'SET', '31', 'NULL', '59');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('59', '112', '41', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «31» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('42', '1002', '1', 'GEOMETRY', '32', 'NULL', '60');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('60', '112', '42', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «32» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('43', '1002', '1', 'LINESTRING', '33', 'NULL', '61');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('61', '112', '43', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «33» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('44', '1002', '1', 'POLYGON', '34', 'NULL', '62');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('62', '112', '44', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «34» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('45', '1002', '1', 'MULTIPOINT', '35', 'NULL', '63');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('63', '112', '45', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «35» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('46', '1002', '1', 'MULTILINESTRING', '36', 'NULL', '64');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('64', '112', '46', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «36» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('47', '1002', '1', 'MULTIPOLYGON', '37', 'NULL', '65');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('65', '112', '47', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «37» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('48', '1002', '1', 'GEOMETRYCOLLECTION', '38', 'NULL', '66');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('66', '112', '48', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «38» pour la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1001', '0', '1', 'Liste des états des enregistrements de la base de données', '00a', 'NULL', '67');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('67', '112', '1001', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «00a».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1002', '0', '1', 'Liste des formats de champs SQL de la base de données', '00b', 'NULL', '68');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('68', '112', '1002', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «00b».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1003', '0', '1', 'Liste des tables de la base de données', '00c', 'NULL', '69');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('69', '112', '1003', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «00c».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1004', '0', '1', 'Liste des préfixes de noms de personne', '1', 'NULL', '70');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('70', '112', '1004', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «01».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1005', '0', '1', 'Liste des suffixes de noms de personne', '2', 'NULL', '71');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('71', '112', '1005', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «02».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1006', '0', '1', 'Liste des types de noms complémentaires d''une personne', '3', 'NULL', '72');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('72', '112', '1006', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «03».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1007', '0', '1', 'Liste des types de téléphone', '4', 'NULL', '73');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('73', '112', '1007', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «04».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1008', '0', '1', 'Liste des types de spécialités botaniques', '5', 'NULL', '74');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('74', '112', '1008', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «05».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1009', '0', '1', 'Liste des rôles d''une personne', '6', 'NULL', '75');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('75', '112', '1009', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «06».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1010', '0', '1', 'Liste des relations entre personnes', '7', 'NULL', '76');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('76', '112', '1010', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «07».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1011', '0', '1', 'Liste des relations entre une structure et une personne', '8', 'NULL', '77');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('77', '112', '1011', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «08».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1012', '0', '1', 'Liste des fonctions d''une personne au sein d''une structure', '9', 'NULL', '78');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('78', '112', '1012', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «09».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1013', '0', '1', 'Liste des statuts d''une personne au sein d''une structure', '10', 'NULL', '79');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('79', '112', '1013', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «10».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1014', '0', '1', 'Liste des types de structure dans le standard NCD', '11', 'NULL', '80');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('80', '112', '1014', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1015', '0', '1', 'Liste des types de structure privé', '12', 'NULL', '81');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('81', '112', '1015', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «12».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1016', '0', '1', 'Liste des types de structure publique', '13', 'NULL', '82');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('82', '112', '1016', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «13».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1017', '0', '1', 'Liste des identifiants alternatifs de structures à vocation botanique', '14', 'NULL', '83');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('83', '112', '1017', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «14».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1018', '0', '1', 'Liste des types de local de stockage de collections', '15', 'NULL', '84');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('84', '112', '1018', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «15».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1019', '0', '1', 'Liste des types de mobilier de stockage de collections', '16', 'NULL', '85');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('85', '112', '1019', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «16».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1020', '0', '1', 'Liste des paramètres de contrôle environnemental d''un local', '17', 'NULL', '86');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('86', '112', '1020', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «17».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1021', '0', '1', 'Liste des types de collection non botanique', '18', 'NULL', '87');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('87', '112', '1021', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «18».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1022', '0', '1', 'Liste des types d''opération de restauration pour les collections botaniques', '19', 'NULL', '88');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('88', '112', '1022', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «19».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1023', '0', '1', 'Liste oui/non/en partie', '20', 'NULL', '89');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('89', '112', '1023', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «20».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1024', '0', '1', 'Liste du matériel dit de nom conservation des parts d''herbier', '21', 'NULL', '90');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('90', '112', '1024', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «21».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1025', '0', '1', 'Liste de traitement anti-insecte pour les collections botaniques', '22', 'NULL', '91');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('91', '112', '1025', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «22».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1026', '0', '1', 'Liste des poisons utilisés pour les collections botaniques', '23', 'NULL', '92');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('92', '112', '1026', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «23».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1027', '0', '1', 'Liste des actions de valorisation des collections', '24', 'NULL', '93');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('93', '112', '1027', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «24».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1028', '0', '1', 'Liste des continents habités incluant aussi le pays France', '25', 'NULL', '94');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('94', '112', '1028', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «25».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1029', '0', '1', 'Liste des types de recherche nécessitant la consultation de collection botanique', '26', 'NULL', '95');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('95', '112', '1029', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «26».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1030', '0', '1', 'Liste des relations entre une collection et une personne', '27', 'NULL', '96');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('96', '112', '1030', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «27».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1031', '0', '1', 'Liste des relations entre collections', '28', 'NULL', '97');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('97', '112', '1031', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «28».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1032', '0', '1', 'Liste des types de collection dans le standard NCD', '29', 'NULL', '98');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('98', '112', '1032', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1033', '0', '1', 'Liste des types de dépôt de collection', '30', 'NULL', '99');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('99', '112', '1033', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «30».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1034', '0', '1', 'Liste des principes de groupement d''une collection dans le standard NCD', '31', 'NULL', '100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('100', '112', '1034', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1035', '0', '1', 'Liste des buts de réalisation d''une collection dans le standard NCD', '32', 'NULL', '101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('101', '112', '1035', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «32».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1036', '0', '1', 'Échelle Mc Ginley dans le standard NCD', '33', 'NULL', '102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('102', '112', '1036', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1037', '0', '1', 'Liste des règnes du vivant dans le standard NCD', '34', 'NULL', '103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('103', '112', '1037', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «34».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1038', '0', '1', 'Liste des méthodes de conservation dans le standard NCD', '35', 'NULL', '104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('104', '112', '1038', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1039', '0', '1', 'Liste des états de croissance d''une collection dans le standard NCD', '36', 'NULL', '105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('105', '112', '1039', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «36».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1040', '0', '1', 'Liste des siècles pour les collections naturalistes', '37', 'NULL', '106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('106', '112', '1040', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «37».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1041', '0', '1', 'Liste indéterminé/peut-être/oui/non', '38', 'NULL', '107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('107', '112', '1041', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «38».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1042', '0', '1', 'Liste des types de classement des spécimens types dans une collection', '39', 'NULL', '108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('108', '112', '1042', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «39».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1043', '0', '1', 'Liste des natures végétales', '40', 'NULL', '109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('109', '112', '1043', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «40».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1044', '0', '1', 'Liste des types d''unité de rangement pour les collections botaniques', '41', 'NULL', '110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('110', '112', '1044', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1045', '0', '1', 'Liste des états', '42', 'NULL', '111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('111', '112', '1045', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «42».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1046', '0', '1', 'Liste des types de support pour les spécimens des collections botaniques', '43', 'NULL', '112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('112', '112', '1046', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «43».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1047', '0', '1', 'Liste des types de papier de support pour les spécimens des collections botaniques', '44', 'NULL', '113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('113', '112', '1047', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «44».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1048', '0', '1', 'Liste des méthodes de rangement des supports pour les spécimens des collections botaniques', '45', 'NULL', '114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('114', '112', '1048', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «45».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1049', '0', '1', 'Liste des méthodes de fixation sur le support pour les collections botaniques', '46', 'NULL', '115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('115', '112', '1049', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «46».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1050', '0', '1', 'Liste des méthodes de fixation des étiquettes sur les spécimens pour les collections botaniques', '47', 'NULL', '116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('116', '112', '1050', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «47».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1051', '0', '1', 'Liste des types d''écriture d''étiquette', '48', 'NULL', '117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('117', '112', '1051', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «48».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1052', '0', '1', 'Liste des origines des dégradations des spécimens de collections botaniques', '49', 'NULL', '118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('118', '112', '1052', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «49».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1053', '0', '1', 'Liste des origines des dégradations des supports de collections botaniques', '50', 'NULL', '119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('119', '112', '1053', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «50».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1054', '0', '1', 'Liste des niveaux de détermination des spécimens de collections botaniques', '51', 'NULL', '120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('120', '112', '1054', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «51».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1055', '0', '1', 'Liste des types de date de début', '52', 'NULL', '121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('121', '112', '1055', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «52».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1056', '0', '1', 'Liste des types de date de fin', '53', 'NULL', '122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('122', '112', '1056', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «53».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1057', '0', '1', 'Liste des états de classement', '54', 'NULL', '123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('123', '112', '1057', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «54».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1058', '0', '1', 'Liste des informations présentes sur les étiquettes de collections botaniques', '55', 'NULL', '124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('124', '112', '1058', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «55».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1059', '0', '1', 'Liste oui/non/en grande partie', '56', 'NULL', '125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('125', '112', '1059', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «56».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1060', '0', '1', 'Liste indéterminé/parfois/oui/non', '57', 'NULL', '126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('126', '112', '1060', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «57».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1061', '0', '1', 'Liste des formes d''inventaire', '58', 'NULL', '127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('127', '112', '1061', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «58».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1062', '0', '1', 'Liste des types de logiciel pour les inventaires informatiques', '59', 'NULL', '128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('128', '112', '1062', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «59».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1063', '0', '1', 'Liste des états d''inventaire', '60', 'NULL', '129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('129', '112', '1063', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «60».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1064', '0', '1', 'Liste des relations entre une publication et une personne', '61', 'NULL', '130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('130', '112', '1064', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «61».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1065', '0', '1', 'Liste des types de publication vis à vis d''une personne', '62', 'NULL', '131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('131', '112', '1065', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «62».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1066', '0', '1', 'Liste des types d''url', '63', 'NULL', '132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('132', '112', '1066', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «63».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1067', '0', '1', 'Liste du genre d''une personne', '64', 'NULL', '133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('133', '112', '1067', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «64».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1068', '0', '1', 'Liste des types de commentaires associés à une collection', '65', 'NULL', '134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('134', '112', '1068', NULL , '2009-03-19 13:07:46' , 'Initialisation de la liste «65».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1071', '0', '1', 'Liste des langues du standard ISO-639-1', '68', 'NULL', '135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('135', '112', '1071', NULL , '2009-03-24 18:00:42' , 'Initialisation de la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1072', '0', '1', 'Liste de durées de fonctionnement d''un script en heure ', '69', 'NULL', '136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('136', '112', '1072', NULL , '2009-04-08 11:59:42' , 'Initialisation de la liste «69».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1073', '0', '1', 'Liste de fréquences de lancement d''un script', '70', 'NULL', '137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('137', '112', '1073', NULL , '2009-04-08 11:59:42' , 'Initialisation de la liste «70».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1074', '0', '1', 'Liste des pays du standard ISO-3166-1', '71', 'NULL', '138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('138', '112', '1074', NULL , '2009-04-08 11:59:43' , 'Initialisation de la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1078', '0', '1', 'Liste des noms de zones géographiques administrative de niveau 1 du projet Geonames', '75', 'NULL', '139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('139', '112', '1078', NULL , '2009-07-29 01:17:00' , 'Initialisation de la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('1079', '0', '1', 'Liste des noms de zones géographiques administrative de niveau 2 du projet Geonames', '76', 'NULL', '140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('140', '112', '1079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2001', '1004', '1', 'Mr.', '1', 'NULL', '141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('141', '112', '2001', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «1» pour la liste «01».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2002', '1004', '1', 'Dr.', '2', 'NULL', '142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('142', '112', '2002', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «2» pour la liste «01».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2003', '1004', '1', 'Abbé', '3', 'NULL', '143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('143', '112', '2003', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «3» pour la liste «01».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2004', '1004', '1', 'Colonel', '4', 'NULL', '144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('144', '112', '2004', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «4» pour la liste «01».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2005', '1004', '1', 'Prof.', '5', 'NULL', '145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('145', '112', '2005', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «5» pour la liste «01».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2006', '1004', '1', 'von', '6', 'NULL', '146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('146', '112', '2006', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «6» pour la liste «01».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2007', '1004', '1', 'Lord', '7', 'NULL', '147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('147', '112', '2007', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «7» pour la liste «01».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2008', '1005', '1', 'Jr', '1', 'NULL', '148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('148', '112', '2008', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «1» pour la liste «02».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2009', '1005', '1', 'I', '2', 'NULL', '149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('149', '112', '2009', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «2» pour la liste «02».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2010', '1005', '1', 'II', '3', 'NULL', '150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('150', '112', '2010', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «3» pour la liste «02».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2011', '1005', '1', 'III', '4', 'NULL', '151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('151', '112', '2011', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «4» pour la liste «02».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2012', '1006', '1', 'Surnom', 'SNO', 'NULL', '152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('152', '112', '2012', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «SNO» pour la liste «03».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2013', '1006', '1', 'Nom alternatif', 'ALT', 'NULL', '153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('153', '112', '2013', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «ALT» pour la liste «03».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2014', '1007', '1', 'Portable', 'GSM', 'NULL', '154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('154', '112', '2014', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «GSM» pour la liste «04».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2015', '1007', '1', 'Téléphone fixe', 'FIX', 'NULL', '155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('155', '112', '2015', NULL , '2009-03-19 13:07:46' , 'Initialisation de la valeur «FIX» pour la liste «04».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2016', '1007', '1', 'Pager', 'PAG', 'NULL', '156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('156', '112', '2016', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «PAG» pour la liste «04».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2017', '1009', '1', 'Super-Administrateur', '1', 'NULL', '157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('157', '112', '2017', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «06».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2018', '1009', '1', 'Administrateur', '2', 'NULL', '158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('158', '112', '2018', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «06».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2019', '1009', '1', 'Coordinateur', '3', 'NULL', '159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('159', '112', '2019', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «06».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2020', '1009', '1', 'Contributeur', '4', 'NULL', '160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('160', '112', '2020', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «06».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2021', '1009', '1', 'Utilisateur', '5', 'NULL', '161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('161', '112', '2021', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «06».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2022', '1010', '1', 'Administrateur', '1', 'NULL', '162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('162', '112', '2022', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «07».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2023', '1010', '1', 'Coordinateur', '2', 'NULL', '163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('163', '112', '2023', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «07».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2024', '1010', '1', 'Contributeur', '3', 'NULL', '164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('164', '112', '2024', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «07».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2025', '1010', '1', 'est coordinateur de', '4', 'NULL', '165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('165', '112', '2025', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «07».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2026', '1011', '1', 'est administrer par', 'EAP', 'Indique quelle personne peut administrer les données dans l''application courante.', '166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('166', '112', '2026', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «08».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2027', '1011', '1', 'équipe', 'EQU', 'Rôle général d''une personne au sein d''une structure.', '167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('167', '112', '2027', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «08».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2830', '1011', '1', 'Administrateur système', 'AS', 'Administrateur système (= System Administrator).', '168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('168', '112', '2830', NULL , '2009-05-07 15:26:00' , 'Initialisation de la valeur «3» pour la liste «08».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2831', '1011', '1', 'Administrateur données', 'AD', 'Administrateur des données (= Data Administrator).', '169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('169', '112', '2831', NULL , '2009-05-07 15:27:00' , 'Initialisation de la valeur «4» pour la liste «08».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2028', '1012', '1', 'Directeur', '1', 'NULL', '170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('170', '112', '2028', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «09».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2029', '1012', '1', 'Conservateur', '2', 'NULL', '171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('171', '112', '2029', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «09».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2030', '1012', '1', 'Technicien', '3', 'NULL', '172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('172', '112', '2030', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «09».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2031', '1013', '1', 'Salarié', '1', 'NULL', '173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('173', '112', '2031', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «10».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2032', '1013', '1', 'Bénévole', '2', 'NULL', '174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('174', '112', '2032', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «10».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2033', '1014', '1', 'Aquarium', '1', 'NULL', '175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('175', '112', '2033', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2034', '1014', '1', 'Archive', '2', 'NULL', '176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('176', '112', '2034', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2035', '1014', '1', 'Jardin botanique', '3', 'NULL', '177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('177', '112', '2035', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2036', '1014', '1', 'Protection de la nature', '4', 'NULL', '178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('178', '112', '2036', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2037', '1014', '1', 'Station d''étude', '5', 'NULL', '179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('179', '112', '2037', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2038', '1014', '1', 'Établissement d''État', '6', 'NULL', '180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('180', '112', '2038', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2039', '1014', '1', 'Société d''histoire', '7', 'NULL', '181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('181', '112', '2039', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2040', '1014', '1', 'Établissement horticole', '8', 'NULL', '182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('182', '112', '2040', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «8» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2041', '1014', '1', 'Industrie', '9', 'NULL', '183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('183', '112', '2041', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «9» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2042', '1014', '1', 'Laboratoire', '10', 'NULL', '184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('184', '112', '2042', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «10» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2043', '1014', '1', 'Bibliothèque', '11', 'NULL', '185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('185', '112', '2043', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «11» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2044', '1014', '1', 'Gestion de la nature', '12', 'NULL', '186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('186', '112', '2044', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «12» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2045', '1014', '1', 'Museum', '13', 'NULL', '187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('187', '112', '2045', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «13» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2046', '1014', '1', 'Centre d''éducation à la nature', '14', 'NULL', '188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('188', '112', '2046', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «14» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2047', '1014', '1', 'Établissement scolaire (Lycée)', '15', 'NULL', '189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('189', '112', '2047', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «15» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2048', '1014', '1', 'Parc', '16', 'NULL', '190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('190', '112', '2048', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «16» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2049', '1014', '1', 'Dépôt', '17', 'NULL', '191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('191', '112', '2049', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «17» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2050', '1014', '1', 'Institut de Recherche', '18', 'NULL', '192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('192', '112', '2050', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «18» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2051', '1014', '1', 'Établissement scolaire (École primaire)', '19', 'NULL', '193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('193', '112', '2051', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «19» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2052', '1014', '1', 'Centre scientifique', '20', 'NULL', '194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('194', '112', '2052', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «20» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2053', '1014', '1', 'Société', '21', 'NULL', '195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('195', '112', '2053', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «21» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2054', '1014', '1', 'Établissement scolaire (Université)', '22', 'NULL', '196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('196', '112', '2054', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «22» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2055', '1014', '1', 'Zoo', '23', 'NULL', '197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('197', '112', '2055', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «23» pour la liste «11».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2056', '1015', '1', 'Association', '1', 'NULL', '198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('198', '112', '2056', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «12».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2057', '1015', '1', 'Laboratoire', '2', 'NULL', '199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('199', '112', '2057', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «12».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2058', '1015', '1', 'Fondation', '3', 'NULL', '200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('200', '112', '2058', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «12».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2059', '1015', '1', 'Particulier', '4', 'NULL', '201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('201', '112', '2059', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «12».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2060', '1016', '1', 'Service municipal', '1', 'NULL', '202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('202', '112', '2060', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «13».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2061', '1016', '1', 'Conseil général', '2', 'NULL', '203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('203', '112', '2061', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «13».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2062', '1016', '1', 'National', '3', 'NULL', '204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('204', '112', '2062', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «13».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2063', '1016', '1', 'Université', '4', 'NULL', '205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('205', '112', '2063', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «13».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2064', '1016', '1', 'Conseil Régional', '5', 'NULL', '206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('206', '112', '2064', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «13».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2065', '1017', '1', 'Index Herbarorium', 'IH', 'Base de données mondiale où se trouvent répertoriées des informations sur plus de 3000 herbiers publics dans le monde ainsi que leurs équipes. Chaque herbier enregistré dans cet index est désigné également par un acronyme international. Exemple : Herbier de l''Université de Montpellier II = MPU.
Un herbier peut être enregistré dans cette base si ces collections totalisent plus de 5000 échantillons.
Site internet : http://sweetgum.nybg.org/ih/', '207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('207', '112', '2065', NULL , '2009-06-03 15:40:00' , 'Initialisation de la valeur «IH» pour la liste «14».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2066', '1017', '1', 'Muséum National d''Histoire Naturelle', 'MNHN', 'Pour toute demande de création d''un acronyme français contacter Marc PIGNAL <pignal@mnhn.fr>, chargé de conservation de l''herbier National de Paris (P).
Les herbiers de moins de 5000 spécimens ne seront recensés qu''au niveau du MNHN. Par la suite, lorsque le chiffre de 5000 est atteint, le MNHN en avisera l''Index Herbariorum et communiquera les données.', '208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('208', '112', '2066', NULL , '2009-06-03 15:40:00' , 'Initialisation de la valeur «MNHN» pour la liste «14».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2067', '1018', '1', 'Réserves', '1', 'Lieu de stockage des collections d''un musée, d''une bibliothèque, etc. qui sert à conserver les collections, les étudier et les gérer mais non accessible au public.', '209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('209', '112', '2067', NULL , '2009-06-03 15:13:00' , 'Initialisation de la valeur «1» pour la liste «15».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2068', '1018', '1', 'Bâtiment  (ex. : Herbier)', '2', 'NULL', '210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('210', '112', '2068', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «15».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2069', '1018', '1', 'Pièce', '3', 'NULL', '211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('211', '112', '2069', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «15».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2070', '1019', '1', 'Rayonnages mobiles type Compactus', '1', 'Rayonnages sur rails pouvant être déplacés, manuellement ou automatiquement, de façon à utiliser l''espace ordinairement occupé par les allées de desserte entre travées.', '212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('212', '112', '2070', NULL , '2009-06-02 17:05:00' , 'Initialisation de la valeur «1» pour la liste «16».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2071', '1019', '1', 'Armoires métalliques', '2', 'NULL', '213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('213', '112', '2071', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «16».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2072', '1019', '1', 'Armoires en bois', '3', 'NULL', '214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('214', '112', '2072', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «16».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2073', '1019', '1', 'Étagères métalliques', '4', 'NULL', '215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('215', '112', '2073', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «16».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2074', '1019', '1', 'Étagères en bois', '5', 'NULL', '216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('216', '112', '2074', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «16».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2075', '1020', '1', 'Température extrêmement élevée', '1', 'NULL', '217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('217', '112', '2075', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «17».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2076', '1020', '1', 'Hygrométrie', '2', 'NULL', '218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('218', '112', '2076', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «17».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2077', '1020', '1', 'Lumière', '3', 'NULL', '219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('219', '112', '2077', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «17».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2078', '1020', '1', 'Température extrêmement basse', '4', 'NULL', '220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('220', '112', '2078', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «17».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2079', '1021', '1', 'Collection d''entomologie (insectes)', '1', 'NULL', '221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('221', '112', '2079', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «18».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2080', '1021', '1', 'Animaux naturalisés', '2', 'NULL', '222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('222', '112', '2080', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «18».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2081', '1021', '1', 'Bibliothèque générale', '3', 'NULL', '223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('223', '112', '2081', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «18».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2082', '1021', '1', 'Bibliothèque botanique', '4', 'NULL', '224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('224', '112', '2082', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «18».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2083', '1021', '1', 'Collections d''ethnologie', '5', 'NULL', '225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('225', '112', '2083', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «18».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2084', '1021', '1', 'Archives papier', '6', 'NULL', '226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('226', '112', '2084', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «18».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2085', '1021', '1', 'Collection de diapos/photos', '7', 'NULL', '227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('227', '112', '2085', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «18».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2086', '1021', '1', 'Minéraux', '8', 'NULL', '228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('228', '112', '2086', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «8» pour la liste «18».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2087', '1022', '1', 'Remplacement des contenants (cartons, planches, etc)', '1', 'NULL', '229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('229', '112', '2087', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «19».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2088', '1022', '1', 'Remplacement du papier', '2', 'NULL', '230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('230', '112', '2088', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «19».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2089', '1022', '1', 'Montage des échantillons', '3', 'NULL', '231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('231', '112', '2089', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «19».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2090', '1022', '1', 'Montage des étiquettes', '4', 'NULL', '232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('232', '112', '2090', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «19».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2091', '1022', '1', 'Reclassement', '5', 'NULL', '233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('233', '112', '2091', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «19».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2092', '1023', '1', 'Non', '1', 'NULL', '234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('234', '112', '2092', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «20».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2093', '1023', '1', 'Oui', '2', 'NULL', '235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('235', '112', '2093', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «20».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2094', '1023', '1', 'En partie', '3', 'NULL', '236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('236', '112', '2094', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «20».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2096', '1024', '1', 'Papier normal', '2', 'NULL', '237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('237', '112', '2096', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «21».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2097', '1024', '1', 'Papier épais', '3', 'NULL', '238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('238', '112', '2097', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «21».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2098', '1024', '1', 'Papier cartonné', '4', 'NULL', '239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('239', '112', '2098', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «21».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2099', '1024', '1', 'Colle forte', '5', 'NULL', '240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('240', '112', '2099', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «21».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2100', '1024', '1', 'Colle en stick', '6', 'NULL', '241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('241', '112', '2100', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «21».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2101', '1024', '1', 'Colle blanche', '7', 'NULL', '242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('242', '112', '2101', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «21».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2102', '1024', '1', 'Ruban adhésif standard', '8', 'NULL', '243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('243', '112', '2102', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «8» pour la liste «21».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2103', '1025', '1', 'Fumigations', '1', 'NULL', '244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('244', '112', '2103', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «22».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2104', '1025', '1', 'Paradichlorobenzène ou anti-mites', '2', 'NULL', '245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('245', '112', '2104', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «22».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2105', '1025', '1', 'Insecticide en bombe', '3', 'NULL', '246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('246', '112', '2105', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «22».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2106', '1025', '1', 'Anoxie', '4', 'NULL', '247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('247', '112', '2106', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «22».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2107', '1025', '1', 'Surgélation', '5', 'NULL', '248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('248', '112', '2107', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «22».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2108', '1025', '1', 'Congélation', '6', 'NULL', '249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('249', '112', '2108', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «22».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2109', '1025', '1', 'Four micro-ondes', '7', 'NULL', '250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('250', '112', '2109', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «22».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2110', '1026', '1', 'Préparation à base de mercure', '1', 'NULL', '251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('251', '112', '2110', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «23».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2111', '1026', '1', 'Préparation à base d’arsenic', '2', 'NULL', '252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('252', '112', '2111', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «23».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2112', '1026', '1', 'Préparation à base de mercure et d’arsenic', '3', 'NULL', '253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('253', '112', '2112', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «23».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2113', '1027', '1', 'Ouvrages', '1', 'NULL', '254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('254', '112', '2113', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «24».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2114', '1027', '1', 'Articles de presse ou interviews radio / TV', '2', 'NULL', '255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('255', '112', '2114', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «24».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2115', '1027', '1', 'Animations', '3', 'NULL', '256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('256', '112', '2115', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «24».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2116', '1027', '1', 'Articles scientifiques', '4', 'NULL', '257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('257', '112', '2116', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «24».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2117', '1027', '1', 'Visites de groupes', '5', 'NULL', '258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('258', '112', '2117', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «24».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2118', '1027', '1', 'Conférences', '6', 'NULL', '259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('259', '112', '2118', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «24».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2119', '1027', '1', 'Expositions', '7', 'NULL', '260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('260', '112', '2119', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «24».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2120', '1028', '1', 'France', '1', 'NULL', '261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('261', '112', '2120', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «25».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2121', '1028', '1', 'Europe', '2', 'NULL', '262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('262', '112', '2121', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «25».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2122', '1028', '1', 'Asie', '3', 'NULL', '263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('263', '112', '2122', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «25».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2123', '1028', '1', 'Amérique', '4', 'NULL', '264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('264', '112', '2123', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «25».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2124', '1028', '1', 'Afrique', '5', 'NULL', '265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('265', '112', '2124', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «25».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2125', '1028', '1', 'Océanie', '6', 'NULL', '266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('266', '112', '2125', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «25».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2126', '1029', '1', 'Systématique', '1', 'NULL', '267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('267', '112', '2126', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «26».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2127', '1029', '1', 'Chorologie', '2', 'NULL', '268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('268', '112', '2127', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «26».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2128', '1029', '1', 'Biologie moléculaire', '3', 'NULL', '269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('269', '112', '2128', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «26».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2129', '1029', '1', 'Pharmacie', '4', 'NULL', '270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('270', '112', '2129', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «26».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2130', '1029', '1', 'Ethnobotanique', '5', 'NULL', '271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('271', '112', '2130', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «26».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2131', '1029', '1', 'Histoire des sciences', '6', 'NULL', '272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('272', '112', '2131', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «26».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2132', '1029', '1', 'Palynologie', '7', 'NULL', '273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('273', '112', '2132', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «26».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2133', '1029', '1', 'Paléobotanique', '8', 'NULL', '274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('274', '112', '2133', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «8» pour la liste «26».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2134', '1030', '1', 'Contributeur (celui qui a saisi la fiche le premier)', '1', 'NULL', '275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('275', '112', '2134', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «27».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2135', '1030', '1', 'Auteur', '2', 'NULL', '276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('276', '112', '2135', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «27».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2136', '1030', '1', 'Collecteur', '3', 'NULL', '277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('277', '112', '2136', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «27».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2137', '1030', '1', 'Déterminateur', '4', 'NULL', '278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('278', '112', '2137', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «27».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2138', '1030', '1', 'Hébergeur (particulier possédant une collection chez lui)', '5', 'NULL', '279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('279', '112', '2138', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «27».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2139', '1031', '1', 'inclu dans', '1', 'NULL', '280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('280', '112', '2139', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «28».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2140', '1032', '1', 'Archive', 'archival', 'NULL', '281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('281', '112', '2140', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «archival» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2141', '1032', '1', 'Art', 'art', 'NULL', '282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('282', '112', '2141', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «art» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2142', '1032', '1', 'Audio', 'audio', 'NULL', '283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('283', '112', '2142', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «audio» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2143', '1032', '1', 'Culture de cellules', 'cellcultures', 'NULL', '284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('284', '112', '2143', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «cellcultures» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2144', '1032', '1', 'Électronique', 'electronic', 'NULL', '285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('285', '112', '2144', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «electronic» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2145', '1032', '1', 'Facsimilés', 'facsimiles', 'NULL', '286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('286', '112', '2145', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «facsimiles» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2146', '1032', '1', 'Fossiles', 'fossils', 'NULL', '287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('287', '112', '2146', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «fossils» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2147', '1032', '1', 'Génétique', 'genetic', 'NULL', '288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('288', '112', '2147', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «genetic» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2148', '1032', '1', 'Vivante', 'living', 'NULL', '289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('289', '112', '2148', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «living» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2149', '1032', '1', 'Observations', 'observations', 'NULL', '290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('290', '112', '2149', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «observations» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2150', '1032', '1', 'Préservée', 'preserved', 'NULL', '291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('291', '112', '2150', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «preserved» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2151', '1032', '1', 'Produits', 'products', 'NULL', '292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('292', '112', '2151', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «products» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2152', '1032', '1', 'Spécimens', 'taxonomic', 'NULL', '293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('293', '112', '2152', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «taxonomic» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2153', '1032', '1', 'Textes (Manuscrits)', 'texts', 'NULL', '294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('294', '112', '2153', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «texts» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2154', '1032', '1', 'Tissus biologiques', 'tissue', 'NULL', '295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('295', '112', '2154', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «tissue» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2155', '1032', '1', 'Visuelle', 'visual', 'NULL', '296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('296', '112', '2155', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «visual» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2156', '1032', '1', 'Géologique', '_geologique_', 'NULL', '297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('297', '112', '2156', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «_geologique_» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2157', '1032', '1', 'Herbier', '_herbier_', 'NULL', '298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('298', '112', '2157', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «_herbier_» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2158', '1032', '1', 'Minéralogique', '_mineralogique_', 'NULL', '299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('299', '112', '2158', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «_mineralogique_» pour la liste «29».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2159', '1033', '1', 'Patrimoine de l''institution', '1', 'NULL', '300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('300', '112', '2159', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «30».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2160', '1033', '1', 'Dépôt permanent', '2', 'NULL', '301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('301', '112', '2160', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «30».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2161', '1033', '1', 'Dépôt temporaire', '3', 'NULL', '302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('302', '112', '2161', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «30».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2162', '1033', '1', 'Dépôt non consultable (privé)', '4', 'NULL', '303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('303', '112', '2162', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «30».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2163', '1033', '1', 'Prêt', '5', 'NULL', '304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('304', '112', '2163', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «30».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2164', '1034', '1', 'Culturel', 'cultural', 'NULL', '305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('305', '112', '2164', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «cultural» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2165', '1034', '1', 'Écosystème', 'ecosystems', 'NULL', '306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('306', '112', '2165', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «ecosystems» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2166', '1034', '1', 'Environmental', 'environmental', 'NULL', '307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('307', '112', '2166', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «environmental» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2167', '1034', '1', 'Évènement', 'events', 'NULL', '308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('308', '112', '2167', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «events» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2168', '1034', '1', 'Expédition', 'expeditions', 'NULL', '309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('309', '112', '2168', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «expeditions» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2169', '1034', '1', 'National', 'national', 'NULL', '310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('310', '112', '2169', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «national» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2170', '1034', '1', 'Relation biologique', 'relationships', 'NULL', '311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('311', '112', '2170', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «relationships» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2171', '1034', '1', 'Dépôt', 'repository', 'NULL', '312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('312', '112', '2171', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «repository» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2172', '1034', '1', 'Spatial', 'spatial', 'NULL', '313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('313', '112', '2172', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «spatial» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2173', '1034', '1', 'Stade de développement', 'stage', 'NULL', '314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('314', '112', '2173', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «stage» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2174', '1034', '1', 'Taxonomique', 'taxonomic', 'NULL', '315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('315', '112', '2174', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «taxonomic» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2175', '1034', '1', 'Période', 'temporal', 'NULL', '316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('316', '112', '2175', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «temporal» pour la liste «31».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2176', '1035', '1', 'Commercial', 'commercial', 'NULL', '317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('317', '112', '2176', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «commercial» pour la liste «32».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2177', '1035', '1', 'Analyses destructrices', 'destructiveAnalysis', 'NULL', '318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('318', '112', '2177', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «destructiveAnalysis» pour la liste «32».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2178', '1035', '1', 'Éducation', 'education', 'NULL', '319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('319', '112', '2178', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «education» pour la liste «32».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2179', '1035', '1', 'Présentation', 'exhibition', 'NULL', '320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('320', '112', '2179', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «exhibition» pour la liste «32».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2180', '1035', '1', 'Étude', 'monitoring', 'NULL', '321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('321', '112', '2180', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «monitoring» pour la liste «32».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2181', '1035', '1', 'Ornemental', 'ornamental', 'NULL', '322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('322', '112', '2181', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «ornamental» pour la liste «32».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2182', '1035', '1', 'personnel', 'personal', 'NULL', '323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('323', '112', '2182', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «personal» pour la liste «32».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2183', '1035', '1', 'Recherche', 'research', 'NULL', '324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('324', '112', '2183', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «research» pour la liste «32».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2184', '1035', '1', 'Voucher (à traduire)', 'voucher', 'NULL', '325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('325', '112', '2184', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «voucher» pour la liste «32».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2185', '1036', '1', 'Mac Ginley 1', 'McGinley1', 'Specimens deteriorating, potentially cullable, or unprepared. Collection unit in need of immediate attention; museum pests, rusting pins, crystallizing slide media, unringed Hoyer''s media, evaporated alcohol, fading labels, broken cover slip or slide, etc. Primary types missed in general collection.', '326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('326', '112', '2185', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «McGinley1» pour la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2186', '1036', '1', 'Mac Ginley 2', 'McGinley2', 'Material properly prepared but not sorted or only rough-sorted; not readily available to specialists.', '327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('327', '112', '2186', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «McGinley2» pour la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2187', '1036', '1', 'Mac Ginley 3', 'McGinley3', 'Specimens sorted to a level necessary to be efficiently accessible to research specialist for study. All specimens in soft-bottom trays, shell vials in jars or slide boxes, with appropriate levels denoting pertinent taxonomic information. Taxonomic category may vary among different taxa.', '328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('328', '112', '2187', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «McGinley3» pour la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2188', '1036', '1', 'Mac Ginley 4', 'McGinley4', 'Valuable material that has been identified to the species level but not yet put away effectively inaccessible.', '329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('329', '112', '2188', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «McGinley4» pour la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2189', '1036', '1', 'Mac Ginley 5', 'McGinley5', 'All specimens identified and integrated. However, this collection unit needs upgrading, e.g., names checked, header labels for unit trays prepared, transfer to soft-bottom trays, etc., box header labels checked against slides. Alcoholic collection with individual exposed vials, jar labels misleading or without detail, overall format heterogenous.', '330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('330', '112', '2189', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «McGinley5» pour la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2190', '1036', '1', 'Mac Ginley 6', 'McGinley6', 'All specimens in soft-bottom unit trays; all unit-tray header labels, drawer or box, and cabinet labels completed; space left for expansion. When a collection reaches Level 6, the name(s) or who did the curation, the date of curation and listing of catalogues or monographs on which the names are based should be entered in the Smithsonian Collection Inventory File computerized files. Vial within jar system established, labels complete and accurately typed, expansion space allocated, and alcohol levels adequate.', '331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('331', '112', '2190', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «McGinley6» pour la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2191', '1036', '1', 'Mac Ginley 7', 'McGinley7', 'Species inventory with header or box label generation completed. Alcoholic collection with taxa listed on jar labels and in database, as in Level 6 plus species-level inventory.', '332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('332', '112', '2191', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «McGinley7» pour la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2192', '1036', '1', 'Mac Ginley 8', 'McGinley8', 'Label data are recorded for systematic, biogeography or natural history studies. The data elements recorded will vary by group, however, a d standard core set includes the following: a) a country/province/place/latitude-longitude; b) date of collection; c) collector(s); d) miscellaneous (for example, elevation, host). Miscellaneous voucher specimens, including types, from various studies are also ranked at this level.', '333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('333', '112', '2192', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «McGinley8» pour la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2193', '1036', '1', 'Mac Ginley 9', 'McGinley9', 'Measurements, graphics, or other pertinent (descriptions) of specimens are captured in a database.', '334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('334', '112', '2193', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «McGinley9» pour la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2194', '1036', '1', 'Mac Ginley 10', 'McGinley10', 'Groups of specimens included in published monographic, synthetic, or revisionary works, including primary type collection if storage is at Level 7 or higher. When groups of specimens serve to voucher published scientific collection-based studies and have undergone conservation and accession requirements of at least Level 7.', '335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('335', '112', '2194', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «McGinley10» pour la liste «33».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2195', '1037', '1', 'Animal', 'Animalia', 'NULL', '336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('336', '112', '2195', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «Animalia» pour la liste «34».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2196', '1037', '1', 'Champignon', 'Fungi', 'NULL', '337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('337', '112', '2196', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «Fungi» pour la liste «34».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2197', '1037', '1', 'Végétal', 'Plantae', 'NULL', '338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('338', '112', '2197', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «Plantae» pour la liste «34».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2198', '1037', '1', 'Protiste', 'Protista', 'NULL', '339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('339', '112', '2198', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «Protista» pour la liste «34».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2199', '1037', '1', 'Archéobactérie', 'Archaebacteria', 'NULL', '340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('340', '112', '2199', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «Archaebacteria» pour la liste «34».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2200', '1037', '1', 'Eubactérie', 'Eubacteria', 'NULL', '341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('341', '112', '2200', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «Eubacteria» pour la liste «34».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2201', '1038', '1', 'Atmosphère contrôlée', 'controlledAtmosphere', 'NULL', '342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('342', '112', '2201', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «controlledAtmosphere» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2202', '1038', '1', 'Cryogénisation', 'cryopreserved', 'NULL', '343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('343', '112', '2202', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «cryopreserved» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2203', '1038', '1', 'Séchée', 'dried', 'NULL', '344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('344', '112', '2203', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «dried» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2204', '1038', '1', 'Séchée et pressée', 'driedAndPressed', 'NULL', '345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('345', '112', '2204', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «driedAndPressed» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2205', '1038', '1', 'Enchâssé (Maintenu dans une matrice solide, convenant pour la confection des lames minces)', 'embedded', 'NULL', '346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('346', '112', '2205', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «embedded» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2206', '1038', '1', 'Préservation dans un liquide', 'fluidPreserved', 'NULL', '347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('347', '112', '2206', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «fluidPreserved» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2207', '1038', '1', 'Réfrigéré et séché', 'freezeDried', 'NULL', '348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('348', '112', '2207', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «freezeDried» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2208', '1038', '1', 'Congelé', 'frozen', 'NULL', '349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('349', '112', '2208', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «frozen» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2209', '1038', '1', 'Glycérine', 'glycerin', 'NULL', '350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('350', '112', '2209', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «glycerin» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2210', '1038', '1', 'Inapplicable', 'notApplicable', 'NULL', '351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('351', '112', '2210', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «notApplicable» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2211', '1038', '1', 'Aucun traitement', 'noTreatment', 'NULL', '352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('352', '112', '2211', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «noTreatment» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2212', '1038', '1', 'Attaché (Épinglé)', 'pinned', 'NULL', '353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('353', '112', '2212', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «pinned» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2213', '1038', '1', 'Enregistrement analogique', 'recordedAnalog', 'NULL', '354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('354', '112', '2213', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «recordedAnalog» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2214', '1038', '1', 'Enregistrement numérique', 'recordedDigital', 'NULL', '355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('355', '112', '2214', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «recordedDigital» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2215', '1038', '1', 'Réfrigéré', 'refrigerated', 'NULL', '356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('356', '112', '2215', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «refrigerated» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2216', '1038', '1', 'Préparation pour microscope électronique à balayage', 'semstub', 'NULL', '357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('357', '112', '2216', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «semstub» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2217', '1038', '1', 'Squelette', 'skeletonized', 'NULL', '358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('358', '112', '2217', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «skeletonized» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2218', '1038', '1', 'Préparation microscopique', 'slideMount', 'NULL', '359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('359', '112', '2218', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «slideMount» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2219', '1038', '1', 'Stase', 'stasis', 'NULL', '360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('360', '112', '2219', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «stasis» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2220', '1038', '1', 'surfaceCoating', 'surfaceCoating', 'NULL', '361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('361', '112', '2220', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «surfaceCoating» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2221', '1038', '1', 'Tanage', 'tanned', 'NULL', '362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('362', '112', '2221', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «tanned» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2222', '1038', '1', 'Alcool', '_fluidPreservedAlcohol_', 'NULL', '363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('363', '112', '2222', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «_fluidPreservedAlcohol_» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2223', '1038', '1', 'Formol', '_fluidPreservedFormolin_', 'NULL', '364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('364', '112', '2223', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «_fluidPreservedFormolin_» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2224', '1038', '1', 'Gomme arabique', '_gumArabic_', 'NULL', '365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('365', '112', '2224', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «_gumArabic_» pour la liste «35».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2225', '1039', '1', 'Croissance active', 'activegrowth', 'NULL', '366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('366', '112', '2225', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «activegrowth» pour la liste «36».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2226', '1039', '1', 'Fermée', 'closed', 'NULL', '367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('367', '112', '2226', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «closed» pour la liste «36».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2227', '1039', '1', 'Consommable', 'consumable', 'NULL', '368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('368', '112', '2227', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «consumable» pour la liste «36».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2228', '1039', '1', 'Décroissance', 'decreasing', 'NULL', '369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('369', '112', '2228', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «decreasing» pour la liste «36».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2229', '1039', '1', 'Perdu', 'lost', 'NULL', '370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('370', '112', '2229', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «lost» pour la liste «36».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2230', '1039', '1', 'Manquante', 'missing', 'NULL', '371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('371', '112', '2230', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «missing» pour la liste «36».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2231', '1039', '1', 'Croissance passive', 'passivegrowth', 'NULL', '372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('372', '112', '2231', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «passivegrowth» pour la liste «36».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2232', '1039', '1', 'Statique', 'static', 'NULL', '373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('373', '112', '2232', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «static» pour la liste «36».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2233', '1040', '1', '16ème siècle', '1', 'NULL', '374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('374', '112', '2233', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «37».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2234', '1040', '1', '17ème siècle', '2', 'NULL', '375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('375', '112', '2234', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «37».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2235', '1040', '1', '18ème siècle', '3', 'NULL', '376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('376', '112', '2235', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «37».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2236', '1040', '1', '19ème siècle', '4', 'NULL', '377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('377', '112', '2236', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «37».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2237', '1040', '1', '20ème siècle', '5', 'NULL', '378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('378', '112', '2237', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «37».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2238', '1040', '1', '21ème siècle', '6', 'NULL', '379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('379', '112', '2238', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «37».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2239', '1041', '1', 'Indéterminé (= ne sais pas)', '1', 'NULL', '380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('380', '112', '2239', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «38».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2240', '1041', '1', 'Peut-être', '2', 'NULL', '381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('381', '112', '2240', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «38».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2241', '1041', '1', 'Oui', '3', 'NULL', '382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('382', '112', '2241', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «38».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2242', '1041', '1', 'Nom', '4', 'NULL', '383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('383', '112', '2242', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «38».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2243', '1042', '1', 'À part', '1', 'NULL', '384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('384', '112', '2243', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «39».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2244', '1042', '1', 'Inclus', '2', 'NULL', '385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('385', '112', '2244', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «39».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2245', '1042', '1', 'Partiellement extraits', '3', 'NULL', '386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('386', '112', '2245', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «39».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2246', '1043', '1', 'Phanérogames', '1', 'NULL', '387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('387', '112', '2246', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «40».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2247', '1043', '1', 'Gymnosperme (Conifère)', '2', 'NULL', '388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('388', '112', '2247', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «40».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2248', '1043', '1', 'Angiosperme (plantes à fleur)', '3', 'NULL', '389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('389', '112', '2248', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «40».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2249', '1043', '1', 'Cryptogames', '4', 'NULL', '390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('390', '112', '2249', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «40».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2250', '1043', '1', 'Algues (y compris Characées et Diatomées)', '5', 'NULL', '391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('391', '112', '2250', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «40».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2251', '1043', '1', 'Champignons', '6', 'NULL', '392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('392', '112', '2251', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «40».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2252', '1043', '1', 'Lichens', '7', 'NULL', '393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('393', '112', '2252', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «40».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2253', '1043', '1', 'Bryophytes (Mousses)', '8', 'NULL', '394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('394', '112', '2253', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «8» pour la liste «40».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2254', '1043', '1', 'Ptéridophytes (Fougères)', '9', 'NULL', '395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('395', '112', '2254', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «9» pour la liste «40».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2255', '1044', '1', 'Cartons d''herbiers', '1', 'NULL', '396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('396', '112', '2255', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2256', '1044', '1', 'Liasses', '2', 'NULL', '397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('397', '112', '2256', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2257', '1044', '1', 'Ouvrages reliés (cahiers, livres, ...)', '3', 'NULL', '398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('398', '112', '2257', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2258', '1044', '1', 'Classeurs', '4', 'NULL', '399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('399', '112', '2258', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2259', '1044', '1', 'Pochettes à élastiques', '5', 'NULL', '400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('400', '112', '2259', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2260', '1044', '1', 'Bocaux', '6', 'NULL', '401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('401', '112', '2260', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2261', '1044', '1', 'Boîtes d''herbier en bois', '7', 'NULL', '402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('402', '112', '2261', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2262', '1044', '1', 'Piluliers (en bois, plastique, verre, ...)', '8', 'NULL', '403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('403', '112', '2262', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «8» pour la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2263', '1044', '1', 'Boîtes de péparations microscopiques', '9', 'NULL', '404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('404', '112', '2263', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «9» pour la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2264', '1044', '1', 'Boîtes à chaussures', '10', 'NULL', '405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('405', '112', '2264', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «10» pour la liste «41».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2265', '1045', '1', 'Très mauvais état, à remplacer d''urgence', '1', 'NULL', '406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('406', '112', '2265', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «42».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2266', '1045', '1', 'Mauvais état, remplacement à faire assez rapidement', '2', 'NULL', '407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('407', '112', '2266', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «42».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2267', '1045', '1', 'État moyen, remplacement à envisager', '3', 'NULL', '408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('408', '112', '2267', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «42».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2268', '1045', '1', 'Bon état, peu de restauration à faire', '4', 'NULL', '409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('409', '112', '2268', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «42».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2269', '1045', '1', 'Très bon état, pas de restauration', '5', 'NULL', '410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('410', '112', '2269', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «42».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2270', '1046', '1', 'Planches d''herbiers', '1', 'NULL', '411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('411', '112', '2270', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «43».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2271', '1046', '1', 'Lames de préparations microscopiques', '2', 'NULL', '412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('412', '112', '2271', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «43».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2272', '1046', '1', 'Boîtes (à allumettes, à savons...)', '3', 'NULL', '413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('413', '112', '2272', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «43».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2273', '1046', '1', 'Enveloppes', '4', 'NULL', '414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('414', '112', '2273', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «43».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2274', '1046', '1', 'Plaques de carton', '5', 'NULL', '415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('415', '112', '2274', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «43».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2275', '1046', '1', 'Pochettes en plastiques pour classeur', '6', 'NULL', '416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('416', '112', '2275', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «43».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2276', '1047', '1', 'Journal', '1', 'NULL', '417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('417', '112', '2276', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «44».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2277', '1047', '1', 'Papier cartonné', '2', 'NULL', '418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('418', '112', '2277', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «44».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2278', '1047', '1', 'Papier normal', '3', 'NULL', '419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('419', '112', '2278', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «44».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2279', '1047', '1', 'Papier épais', '4', 'NULL', '420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('420', '112', '2279', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «44».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2280', '1047', '1', 'Buvard', '5', 'NULL', '421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('421', '112', '2280', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «44».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2281', '1047', '1', 'Papier très fin', '6', 'NULL', '422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('422', '112', '2281', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «44».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2282', '1047', '1', 'Cahier', '7', 'NULL', '423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('423', '112', '2282', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «44».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2283', '1048', '1', 'Dans des chemises', '1', 'NULL', '424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('424', '112', '2283', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «45».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2284', '1048', '1', 'Sur des feuilles', '2', 'NULL', '425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('425', '112', '2284', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «45».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2285', '1048', '1', 'Sur des feuilles incluses dans des chemises', '3', 'NULL', '426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('426', '112', '2285', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «45».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2286', '1048', '1', 'Sur des feuilles incluses dans des pochettes plastique', '4', 'NULL', '427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('427', '112', '2286', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «45».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2287', '1048', '1', 'Dans des sachets cellophane', '5', 'NULL', '428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('428', '112', '2287', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «45».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2288', '1048', '1', 'Sur des lames de verre', '6', 'NULL', '429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('429', '112', '2288', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «45».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2289', '1049', '1', 'Papier gommé', '1', 'NULL', '430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('430', '112', '2289', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «46».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2290', '1049', '1', 'Colle', '2', 'NULL', '431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('431', '112', '2290', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «46».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2291', '1049', '1', 'Cousus au support', '3', 'NULL', '432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('432', '112', '2291', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «46».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2292', '1049', '1', 'Épinglés au support', '4', 'NULL', '433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('433', '112', '2292', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «46».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2293', '1049', '1', 'Glissés dans des fentes découpées dans le support', '5', 'NULL', '434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('434', '112', '2293', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «46».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2294', '1049', '1', 'Plastifiés', '6', 'NULL', '435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('435', '112', '2294', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «46».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2295', '1049', '1', 'Papier adhésif typescotch', '7', 'NULL', '436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('436', '112', '2295', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «46».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2296', '1050', '1', 'Par épingles', '1', 'NULL', '437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('437', '112', '2296', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «47».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2297', '1050', '1', 'Par un fil', '2', 'NULL', '438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('438', '112', '2297', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «47».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2298', '1050', '1', 'Spécimens glissés dans des fentes découpées dans l''étiquette', '3', 'NULL', '439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('439', '112', '2298', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «47».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2299', '1051', '1', 'Manuscrites', '1', 'NULL', '440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('440', '112', '2299', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «48».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2300', '1051', '1', 'Dactylographiées', '2', 'NULL', '441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('441', '112', '2300', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «48».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2301', '1051', '1', 'Imprimées', '3', 'NULL', '442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('442', '112', '2301', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «48».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2302', '1051', '1', 'Ronéotypées', '4', 'NULL', '443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('443', '112', '2302', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «48».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2303', '1052', '1', 'Humidité / moisissures', '1', 'NULL', '444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('444', '112', '2303', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «49».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2304', '1052', '1', 'Attaques d''insectes', '2', 'NULL', '445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('445', '112', '2304', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «49».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2305', '1052', '1', 'Attaques de rongeurs', '3', 'NULL', '446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('446', '112', '2305', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «49».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2306', '1053', '1', 'Humidité / moisissures', '1', 'NULL', '447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('447', '112', '2306', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «50».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2307', '1053', '1', 'Attaques d''insectes', '2', 'NULL', '448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('448', '112', '2307', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «50».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2308', '1053', '1', 'Attaques de rongeurs', '3', 'NULL', '449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('449', '112', '2308', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «50».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2309', '1053', '1', 'Papiers usagés', '4', 'NULL', '450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('450', '112', '2309', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «50».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2310', '1053', '1', 'Spécimens et étiquettes mélangés ou détachés', '5', 'NULL', '451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('451', '112', '2310', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «50».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2311', '1054', '1', 'Uniquement des fragments, aucune détermination sure n''est possible', '1', 'NULL', '452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('452', '112', '2311', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «51».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2312', '1054', '1', 'Échantillons de plus grandes tailles mais majoritairement sans les  organes nécessaires à la détermi', '2', 'NULL', '453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('453', '112', '2312', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «51».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2313', '1054', '1', 'Une bonne partie des échantillons peuvent être déterminés', '3', 'NULL', '454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('454', '112', '2313', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «51».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2314', '1054', '1', 'Ma majorité des échantillons peuvent être déterminés', '4', 'NULL', '455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('455', '112', '2314', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «51».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2315', '1054', '1', 'Tous les échantillons présentent les caractères nécessaires à la détermination', '5', 'NULL', '456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('456', '112', '2315', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «51».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2316', '1055', '1', 'Date inconnue', '1', 'NULL', '457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('457', '112', '2316', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «52».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2317', '1055', '1', 'Date exacte', '2', 'NULL', '458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('458', '112', '2317', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «52».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2318', '1055', '1', 'Antérieure à', '3', 'NULL', '459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('459', '112', '2318', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «52».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2319', '1055', '1', 'Postérieure à', '4', 'NULL', '460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('460', '112', '2319', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «52».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2320', '1055', '1', 'Date estimée', '5', 'NULL', '461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('461', '112', '2320', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «52».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2321', '1056', '1', 'Date inconnue', '1', 'NULL', '462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('462', '112', '2321', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «53».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2322', '1056', '1', 'Date exacte', '2', 'NULL', '463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('463', '112', '2322', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «53».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2323', '1056', '1', 'Antérieure à', '3', 'NULL', '464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('464', '112', '2323', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «53».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2324', '1056', '1', 'Postérieure à', '4', 'NULL', '465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('465', '112', '2324', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «53».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2325', '1056', '1', 'Date estimée', '5', 'NULL', '466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('466', '112', '2325', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «53».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2326', '1056', '1', 'Encore en activité', '6', 'NULL', '467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('467', '112', '2326', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «53».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2327', '1057', '1', 'Contenants et parts sans classement, recherche d''échantillon précis très difficile, classement à met', '1', 'NULL', '468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('468', '112', '2327', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «54».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2328', '1057', '1', 'Classement existant à l''origine mais mélangé,  rangement à faire assez rapidement', '2', 'NULL', '469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('469', '112', '2328', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «54».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2329', '1057', '1', 'Classement respecté mais pas dans son intégralité, rangement à envisager', '3', 'NULL', '470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('470', '112', '2329', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «54».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2330', '1057', '1', 'Peu déclassé, peu de rangement à effectuer', '4', 'NULL', '471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('471', '112', '2330', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «54».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2331', '1057', '1', 'Entièrement classé', '5', 'NULL', '472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('472', '112', '2331', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «54».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2332', '1058', '1', 'Nom de l''auteur de la collection botanique ou du titre de la collection', '1', 'NULL', '473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('473', '112', '2332', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «55».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2333', '1058', '1', 'Nom de famille', '2', 'NULL', '474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('474', '112', '2333', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «55».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2334', '1058', '1', 'Nom de genre', '3', 'NULL', '475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('475', '112', '2334', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «55».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2335', '1058', '1', 'Nom de l''espèce', '4', 'NULL', '476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('476', '112', '2335', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «55».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2336', '1058', '1', 'Nom d''auteur', '5', 'NULL', '477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('477', '112', '2336', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «5» pour la liste «55».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2337', '1058', '1', 'Localité de récolte', '6', 'NULL', '478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('478', '112', '2337', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «6» pour la liste «55».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2338', '1058', '1', 'Date de récolte', '7', 'NULL', '479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('479', '112', '2338', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «7» pour la liste «55».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2339', '1059', '1', 'Oui', '1', 'NULL', '480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('480', '112', '2339', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «56».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2340', '1059', '1', 'Nom', '2', 'NULL', '481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('481', '112', '2340', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «56».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2341', '1059', '1', 'En grande partie', '3', 'NULL', '482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('482', '112', '2341', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «56».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2342', '1060', '1', 'Indéterminé (= ne sais pas)', '1', 'NULL', '483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('483', '112', '2342', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «57».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2343', '1060', '1', 'Parfois', '2', 'NULL', '484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('484', '112', '2343', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «57».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2344', '1060', '1', 'Oui', '3', 'NULL', '485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('485', '112', '2344', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «57».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2345', '1060', '1', 'Nom', '4', 'NULL', '486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('486', '112', '2345', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «57».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2346', '1061', '1', 'Manuscrite', '1', 'NULL', '487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('487', '112', '2346', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «58».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2347', '1061', '1', 'Imprimé', '2', 'NULL', '488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('488', '112', '2347', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «58».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2348', '1061', '1', 'Informatique', '3', 'NULL', '489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('489', '112', '2348', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «58».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2349', '1062', '1', 'Sonnerat/BryoMyco', '1', 'NULL', '490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('490', '112', '2349', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «1» pour la liste «59».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2350', '1062', '1', '4D', '2', 'NULL', '491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('491', '112', '2350', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «2» pour la liste «59».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2351', '1062', '1', 'SNBase', '3', 'NULL', '492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('492', '112', '2351', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «3» pour la liste «59».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2352', '1062', '1', 'Dbase', '4', 'NULL', '493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('493', '112', '2352', NULL , '2009-03-19 13:07:47' , 'Initialisation de la valeur «4» pour la liste «59».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2353', '1062', '1', 'Access', '5', 'NULL', '494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('494', '112', '2353', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «5» pour la liste «59».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2354', '1062', '1', 'File Maker', '6', 'NULL', '495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('495', '112', '2354', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «6» pour la liste «59».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2355', '1062', '1', 'Excel', '7', 'NULL', '496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('496', '112', '2355', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «7» pour la liste «59».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2356', '1062', '1', 'Word', '8', 'NULL', '497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('497', '112', '2356', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «8» pour la liste «59».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2357', '1063', '1', 'Indéterminé (= ne sais pas)', '1', 'NULL', '498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('498', '112', '2357', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «1» pour la liste «60».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2358', '1063', '1', 'Complet', '2', 'NULL', '499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('499', '112', '2358', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «2» pour la liste «60».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2359', '1063', '1', 'En cours', '3', 'NULL', '500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('500', '112', '2359', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «3» pour la liste «60».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2360', '1064', '1', 'Auteur', '1', 'NULL', '501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('501', '112', '2360', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «1» pour la liste «61».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2361', '1065', '1', 'Nécrologie', '1', 'NULL', '502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('502', '112', '2361', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «1» pour la liste «62».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2362', '1065', '1', 'Biographie', '2', 'NULL', '503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('503', '112', '2362', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «2» pour la liste «62».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2363', '1065', '1', 'Publication personnelle', '3', 'NULL', '504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('504', '112', '2363', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «3» pour la liste «62».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2364', '1066', '1', 'Page Web', 'WEB', 'NULL', '505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('505', '112', '2364', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «WEB» pour la liste «63».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2365', '1066', '1', 'URL d''un logo', 'LOGO', 'NULL', '506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('506', '112', '2365', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «LOGO» pour la liste «63».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2834', '1066', '1', 'URL d''une page d''information sur l''objet lié', 'INFO', 'NULL', '507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('507', '112', '2834', NULL , '2009-05-25 13:03:00' , 'Initialisation de la valeur «INFO» pour la liste «63».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2366', '1067', '1', 'Homme', 'H', 'NULL', '508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('508', '112', '2366', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «H» pour la liste «64».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2367', '1067', '1', 'Femme', 'F', 'NULL', '509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('509', '112', '2367', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «F» pour la liste «64».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2368', '1068', '1', 'Géographique', '1', 'NULL', '510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('510', '112', '2368', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «1» pour la liste «65».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2369', '1068', '1', 'Taxinomique', '2', 'NULL', '511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('511', '112', '2369', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «2» pour la liste «65».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2370', '1068', '1', 'Historique', '3', 'NULL', '512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('512', '112', '2370', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «3» pour la liste «65».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2371', '1068', '1', 'Échantillons-types', '4', 'NULL', '513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('513', '112', '2371', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «4» pour la liste «65».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2372', '1068', '1', 'Collecteurs', '5', 'NULL', '514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('514', '112', '2372', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «5» pour la liste «65».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2373', '1068', '1', 'Statut', '6', 'NULL', '515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('515', '112', '2373', NULL , '2009-03-19 13:07:48' , 'Initialisation de la valeur «6» pour la liste «65».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2381', '1071', '1', 'Afar', 'AA', 'NULL', '516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('516', '112', '2381', NULL , '2009-04-08 12:04:18' , 'Initialisation de la valeur «AA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2382', '1071', '1', 'Abkhaze', 'AB', 'NULL', '517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('517', '112', '2382', NULL , '2009-04-08 12:04:19' , 'Initialisation de la valeur «AB» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2383', '1071', '1', 'Avestique', 'AE', 'NULL', '518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('518', '112', '2383', NULL , '2009-04-08 12:04:20' , 'Initialisation de la valeur «AE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2384', '1071', '1', 'Afrikaans', 'AF', 'NULL', '519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('519', '112', '2384', NULL , '2009-04-08 12:04:21' , 'Initialisation de la valeur «AF» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2385', '1071', '1', 'Akan', 'AK', 'NULL', '520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('520', '112', '2385', NULL , '2009-04-08 12:04:22' , 'Initialisation de la valeur «AK» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2386', '1071', '1', 'Amharique', 'AM', 'NULL', '521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('521', '112', '2386', NULL , '2009-04-08 12:04:23' , 'Initialisation de la valeur «AM» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2387', '1071', '1', 'Aragonais', 'AN', 'NULL', '522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('522', '112', '2387', NULL , '2009-04-08 12:04:24' , 'Initialisation de la valeur «AN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2388', '1071', '1', 'Arabe', 'AR', 'NULL', '523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('523', '112', '2388', NULL , '2009-04-08 12:04:25' , 'Initialisation de la valeur «AR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2389', '1071', '1', 'Assamais', 'AS', 'NULL', '524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('524', '112', '2389', NULL , '2009-04-08 12:04:26' , 'Initialisation de la valeur «AS» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2390', '1071', '1', 'Avar', 'AV', 'NULL', '525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('525', '112', '2390', NULL , '2009-04-08 12:04:27' , 'Initialisation de la valeur «AV» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2391', '1071', '1', 'Aymara', 'AY', 'NULL', '526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('526', '112', '2391', NULL , '2009-04-08 12:04:28' , 'Initialisation de la valeur «AY» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2392', '1071', '1', 'Azéri', 'AZ', 'NULL', '527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('527', '112', '2392', NULL , '2009-04-08 12:04:29' , 'Initialisation de la valeur «AZ» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2393', '1071', '1', 'Bachkir', 'BA', 'NULL', '528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('528', '112', '2393', NULL , '2009-04-08 12:04:30' , 'Initialisation de la valeur «BA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2394', '1071', '1', 'Biélorusse', 'BE', 'NULL', '529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('529', '112', '2394', NULL , '2009-04-08 12:04:31' , 'Initialisation de la valeur «BE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2395', '1071', '1', 'Bulgare', 'BG', 'NULL', '530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('530', '112', '2395', NULL , '2009-04-08 12:04:32' , 'Initialisation de la valeur «BG» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2396', '1071', '1', 'Bihari', 'BH', 'NULL', '531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('531', '112', '2396', NULL , '2009-04-08 12:04:33' , 'Initialisation de la valeur «BH» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2397', '1071', '1', 'Bichelamar', 'BI', 'NULL', '532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('532', '112', '2397', NULL , '2009-04-08 12:04:34' , 'Initialisation de la valeur «BI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2398', '1071', '1', 'Bambara', 'BM', 'NULL', '533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('533', '112', '2398', NULL , '2009-04-08 12:04:35' , 'Initialisation de la valeur «BM» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2399', '1071', '1', 'Bengalî', 'BN', 'NULL', '534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('534', '112', '2399', NULL , '2009-04-08 12:04:36' , 'Initialisation de la valeur «BN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2400', '1071', '1', 'Tibétain', 'BO', 'NULL', '535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('535', '112', '2400', NULL , '2009-04-08 12:04:37' , 'Initialisation de la valeur «BO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2401', '1071', '1', 'Breton', 'BR', 'NULL', '536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('536', '112', '2401', NULL , '2009-04-08 12:04:38' , 'Initialisation de la valeur «BR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2402', '1071', '1', 'Bosnien', 'BS', 'NULL', '537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('537', '112', '2402', NULL , '2009-04-08 12:04:39' , 'Initialisation de la valeur «BS» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2403', '1071', '1', 'Catalan', 'CA', 'NULL', '538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('538', '112', '2403', NULL , '2009-04-08 12:04:40' , 'Initialisation de la valeur «CA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2404', '1071', '1', 'Tchétchène', 'CE', 'NULL', '539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('539', '112', '2404', NULL , '2009-04-08 12:04:41' , 'Initialisation de la valeur «CE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2405', '1071', '1', 'Chamorro', 'CH', 'NULL', '540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('540', '112', '2405', NULL , '2009-04-08 12:04:42' , 'Initialisation de la valeur «CH» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2406', '1071', '1', 'Corse', 'CO', 'NULL', '541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('541', '112', '2406', NULL , '2009-04-08 12:04:43' , 'Initialisation de la valeur «CO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2407', '1071', '1', 'Cri', 'CR', 'NULL', '542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('542', '112', '2407', NULL , '2009-04-08 12:04:44' , 'Initialisation de la valeur «CR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2408', '1071', '1', 'Tchèque', 'CS', 'NULL', '543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('543', '112', '2408', NULL , '2009-04-08 12:04:45' , 'Initialisation de la valeur «CS» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2409', '1071', '1', 'Vieux slave', 'CU', 'NULL', '544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('544', '112', '2409', NULL , '2009-04-08 12:04:46' , 'Initialisation de la valeur «CU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2410', '1071', '1', 'Tchouvache', 'CV', 'NULL', '545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('545', '112', '2410', NULL , '2009-04-08 12:04:47' , 'Initialisation de la valeur «CV» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2411', '1071', '1', 'Gallois', 'CY', 'NULL', '546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('546', '112', '2411', NULL , '2009-04-08 12:04:48' , 'Initialisation de la valeur «CY» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2412', '1071', '1', 'Danois', 'DA', 'NULL', '547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('547', '112', '2412', NULL , '2009-04-08 12:04:49' , 'Initialisation de la valeur «DA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2413', '1071', '1', 'Allemand', 'DE', 'NULL', '548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('548', '112', '2413', NULL , '2009-04-08 12:04:50' , 'Initialisation de la valeur «DE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2414', '1071', '1', 'Divehi', 'DV', 'NULL', '549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('549', '112', '2414', NULL , '2009-04-08 12:04:51' , 'Initialisation de la valeur «DV» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2415', '1071', '1', 'Dzongkha', 'DZ', 'NULL', '550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('550', '112', '2415', NULL , '2009-04-08 12:04:52' , 'Initialisation de la valeur «DZ» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2416', '1071', '1', 'Ewe', 'EE', 'NULL', '551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('551', '112', '2416', NULL , '2009-04-08 12:04:53' , 'Initialisation de la valeur «EE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2417', '1071', '1', 'Grec moderne', 'EL', 'NULL', '552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('552', '112', '2417', NULL , '2009-04-08 12:04:54' , 'Initialisation de la valeur «EL» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2418', '1071', '1', 'Anglais', 'EN', 'NULL', '553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('553', '112', '2418', NULL , '2009-04-08 12:04:55' , 'Initialisation de la valeur «EN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2419', '1071', '1', 'Espéranto', 'EO', 'NULL', '554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('554', '112', '2419', NULL , '2009-04-08 12:04:56' , 'Initialisation de la valeur «EO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2420', '1071', '1', 'Espagnol', 'ES', 'NULL', '555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('555', '112', '2420', NULL , '2009-04-08 12:04:57' , 'Initialisation de la valeur «ES» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2421', '1071', '1', 'Estonien', 'ET', 'NULL', '556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('556', '112', '2421', NULL , '2009-04-08 12:04:58' , 'Initialisation de la valeur «ET» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2422', '1071', '1', 'Basque', 'EU', 'NULL', '557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('557', '112', '2422', NULL , '2009-04-08 12:04:59' , 'Initialisation de la valeur «EU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2423', '1071', '1', 'Perse', 'FA', 'NULL', '558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('558', '112', '2423', NULL , '2009-04-08 12:05:00' , 'Initialisation de la valeur «FA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2424', '1071', '1', 'Peul', 'FF', 'NULL', '559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('559', '112', '2424', NULL , '2009-04-08 12:05:01' , 'Initialisation de la valeur «FF» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2425', '1071', '1', 'Finnois', 'FI', 'NULL', '560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('560', '112', '2425', NULL , '2009-04-08 12:05:02' , 'Initialisation de la valeur «FI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2426', '1071', '1', 'Fidjien', 'FJ', 'NULL', '561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('561', '112', '2426', NULL , '2009-04-08 12:05:03' , 'Initialisation de la valeur «FJ» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2427', '1071', '1', 'Féringien', 'FO', 'NULL', '562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('562', '112', '2427', NULL , '2009-04-08 12:05:04' , 'Initialisation de la valeur «FO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2428', '1071', '1', 'Français', 'FR', 'NULL', '563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('563', '112', '2428', NULL , '2009-04-08 12:05:05' , 'Initialisation de la valeur «FR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2429', '1071', '1', 'Frison', 'FY', 'NULL', '564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('564', '112', '2429', NULL , '2009-04-08 12:05:06' , 'Initialisation de la valeur «FY» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2430', '1071', '1', 'Irlandais', 'GA', 'NULL', '565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('565', '112', '2430', NULL , '2009-04-08 12:05:07' , 'Initialisation de la valeur «GA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2431', '1071', '1', 'Écossais', 'GD', 'NULL', '566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('566', '112', '2431', NULL , '2009-04-08 12:05:08' , 'Initialisation de la valeur «GD» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2432', '1071', '1', 'Galicien', 'GL', 'NULL', '567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('567', '112', '2432', NULL , '2009-04-08 12:05:09' , 'Initialisation de la valeur «GL» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2433', '1071', '1', 'Guarani', 'GN', 'NULL', '568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('568', '112', '2433', NULL , '2009-04-08 12:05:10' , 'Initialisation de la valeur «GN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2434', '1071', '1', 'Gujarâtî', 'GU', 'NULL', '569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('569', '112', '2434', NULL , '2009-04-08 12:05:11' , 'Initialisation de la valeur «GU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2435', '1071', '1', 'Mannois', 'GV', 'NULL', '570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('570', '112', '2435', NULL , '2009-04-08 12:05:12' , 'Initialisation de la valeur «GV» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2436', '1071', '1', 'Haoussa', 'HA', 'NULL', '571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('571', '112', '2436', NULL , '2009-04-08 12:05:13' , 'Initialisation de la valeur «HA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2437', '1071', '1', 'Hébreu', 'HE', 'NULL', '572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('572', '112', '2437', NULL , '2009-04-08 12:05:14' , 'Initialisation de la valeur «HE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2438', '1071', '1', 'Hindî', 'HI', 'NULL', '573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('573', '112', '2438', NULL , '2009-04-08 12:05:15' , 'Initialisation de la valeur «HI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2439', '1071', '1', 'Hiri motu', 'HO', 'NULL', '574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('574', '112', '2439', NULL , '2009-04-08 12:05:16' , 'Initialisation de la valeur «HO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2440', '1071', '1', 'Croate', 'HR', 'NULL', '575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('575', '112', '2440', NULL , '2009-04-08 12:05:17' , 'Initialisation de la valeur «HR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2441', '1071', '1', 'Créole haïtien', 'HT', 'NULL', '576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('576', '112', '2441', NULL , '2009-04-08 12:05:18' , 'Initialisation de la valeur «HT» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2442', '1071', '1', 'Hongrois', 'HU', 'NULL', '577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('577', '112', '2442', NULL , '2009-04-08 12:05:19' , 'Initialisation de la valeur «HU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2443', '1071', '1', 'Arménien', 'HY', 'NULL', '578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('578', '112', '2443', NULL , '2009-04-08 12:05:20' , 'Initialisation de la valeur «HY» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2444', '1071', '1', 'Herero', 'HZ', 'NULL', '579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('579', '112', '2444', NULL , '2009-04-08 12:05:21' , 'Initialisation de la valeur «HZ» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2445', '1071', '1', 'Interlingua', 'IA', 'NULL', '580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('580', '112', '2445', NULL , '2009-04-08 12:05:22' , 'Initialisation de la valeur «IA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2446', '1071', '1', 'Indonésien', 'ID', 'NULL', '581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('581', '112', '2446', NULL , '2009-04-08 12:05:23' , 'Initialisation de la valeur «ID» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2447', '1071', '1', 'Occidental', 'IE', 'NULL', '582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('582', '112', '2447', NULL , '2009-04-08 12:05:24' , 'Initialisation de la valeur «IE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2448', '1071', '1', 'Igbo', 'IG', 'NULL', '583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('583', '112', '2448', NULL , '2009-04-08 12:05:25' , 'Initialisation de la valeur «IG» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2449', '1071', '1', 'Yi', 'II', 'NULL', '584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('584', '112', '2449', NULL , '2009-04-08 12:05:26' , 'Initialisation de la valeur «II» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2450', '1071', '1', 'Inupiaq', 'IK', 'NULL', '585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('585', '112', '2450', NULL , '2009-04-08 12:05:27' , 'Initialisation de la valeur «IK» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2451', '1071', '1', 'Ido', 'IO', 'NULL', '586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('586', '112', '2451', NULL , '2009-04-08 12:05:28' , 'Initialisation de la valeur «IO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2452', '1071', '1', 'Islandais', 'IS', 'NULL', '587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('587', '112', '2452', NULL , '2009-04-08 12:05:29' , 'Initialisation de la valeur «IS» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2453', '1071', '1', 'Italien', 'IT', 'NULL', '588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('588', '112', '2453', NULL , '2009-04-08 12:05:30' , 'Initialisation de la valeur «IT» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2454', '1071', '1', 'Inuktitut', 'IU', 'NULL', '589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('589', '112', '2454', NULL , '2009-04-08 12:05:31' , 'Initialisation de la valeur «IU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2455', '1071', '1', 'Japonais', 'JA', 'NULL', '590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('590', '112', '2455', NULL , '2009-04-08 12:05:32' , 'Initialisation de la valeur «JA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2456', '1071', '1', 'Javanais', 'JV', 'NULL', '591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('591', '112', '2456', NULL , '2009-04-08 12:05:33' , 'Initialisation de la valeur «JV» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2457', '1071', '1', 'Géorgien', 'KA', 'NULL', '592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('592', '112', '2457', NULL , '2009-04-08 12:05:34' , 'Initialisation de la valeur «KA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2458', '1071', '1', 'Kikongo', 'KG', 'NULL', '593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('593', '112', '2458', NULL , '2009-04-08 12:05:35' , 'Initialisation de la valeur «KG» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2459', '1071', '1', 'Kikuyu', 'KI', 'NULL', '594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('594', '112', '2459', NULL , '2009-04-08 12:05:36' , 'Initialisation de la valeur «KI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2460', '1071', '1', 'Kuanyama', 'KJ', 'NULL', '595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('595', '112', '2460', NULL , '2009-04-08 12:05:37' , 'Initialisation de la valeur «KJ» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2461', '1071', '1', 'Kazakh', 'KK', 'NULL', '596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('596', '112', '2461', NULL , '2009-04-08 12:05:38' , 'Initialisation de la valeur «KK» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2462', '1071', '1', 'Kalaallisut', 'KL', 'NULL', '597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('597', '112', '2462', NULL , '2009-04-08 12:05:39' , 'Initialisation de la valeur «KL» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2463', '1071', '1', 'Khmer', 'KM', 'NULL', '598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('598', '112', '2463', NULL , '2009-04-08 12:05:40' , 'Initialisation de la valeur «KM» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2464', '1071', '1', 'Kannara', 'KN', 'NULL', '599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('599', '112', '2464', NULL , '2009-04-08 12:05:41' , 'Initialisation de la valeur «KN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2465', '1071', '1', 'Coréen', 'KO', 'NULL', '600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('600', '112', '2465', NULL , '2009-04-08 12:05:42' , 'Initialisation de la valeur «KO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2466', '1071', '1', 'Kanouri', 'KR', 'NULL', '601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('601', '112', '2466', NULL , '2009-04-08 12:05:43' , 'Initialisation de la valeur «KR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2467', '1071', '1', 'Kashmiri', 'KS', 'NULL', '602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('602', '112', '2467', NULL , '2009-04-08 12:05:44' , 'Initialisation de la valeur «KS» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2468', '1071', '1', 'Kurde', 'KU', 'NULL', '603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('603', '112', '2468', NULL , '2009-04-08 12:05:45' , 'Initialisation de la valeur «KU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2469', '1071', '1', 'Komi', 'KV', 'NULL', '604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('604', '112', '2469', NULL , '2009-04-08 12:05:46' , 'Initialisation de la valeur «KV» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2470', '1071', '1', 'Cornique', 'KW', 'NULL', '605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('605', '112', '2470', NULL , '2009-04-08 12:05:47' , 'Initialisation de la valeur «KW» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2471', '1071', '1', 'Kirghiz', 'KY', 'NULL', '606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('606', '112', '2471', NULL , '2009-04-08 12:05:48' , 'Initialisation de la valeur «KY» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2472', '1071', '1', 'Latin', 'LA', 'NULL', '607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('607', '112', '2472', NULL , '2009-04-08 12:05:49' , 'Initialisation de la valeur «LA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2473', '1071', '1', 'Luxembourgeois', 'LB', 'NULL', '608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('608', '112', '2473', NULL , '2009-04-08 12:05:50' , 'Initialisation de la valeur «LB» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2474', '1071', '1', 'Ganda', 'LG', 'NULL', '609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('609', '112', '2474', NULL , '2009-04-08 12:05:51' , 'Initialisation de la valeur «LG» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2475', '1071', '1', 'Limbourgeois', 'LI', 'NULL', '610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('610', '112', '2475', NULL , '2009-04-08 12:05:52' , 'Initialisation de la valeur «LI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2476', '1071', '1', 'Lingala', 'LN', 'NULL', '611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('611', '112', '2476', NULL , '2009-04-08 12:05:53' , 'Initialisation de la valeur «LN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2477', '1071', '1', 'Lao', 'LO', 'NULL', '612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('612', '112', '2477', NULL , '2009-04-08 12:05:54' , 'Initialisation de la valeur «LO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2478', '1071', '1', 'Lituanien', 'LT', 'NULL', '613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('613', '112', '2478', NULL , '2009-04-08 12:05:55' , 'Initialisation de la valeur «LT» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2479', '1071', '1', 'Tchiluba', 'LU', 'NULL', '614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('614', '112', '2479', NULL , '2009-04-08 12:05:56' , 'Initialisation de la valeur «LU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2480', '1071', '1', 'Letton', 'LV', 'NULL', '615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('615', '112', '2480', NULL , '2009-04-08 12:05:57' , 'Initialisation de la valeur «LV» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2481', '1071', '1', 'Malgache', 'MG', 'NULL', '616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('616', '112', '2481', NULL , '2009-04-08 12:05:58' , 'Initialisation de la valeur «MG» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2482', '1071', '1', 'Marshallais', 'MH', 'NULL', '617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('617', '112', '2482', NULL , '2009-04-08 12:05:59' , 'Initialisation de la valeur «MH» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2483', '1071', '1', 'Māori de Nouvelle-Zélande', 'MI', 'NULL', '618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('618', '112', '2483', NULL , '2009-04-08 12:06:00' , 'Initialisation de la valeur «MI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2484', '1071', '1', 'Macédonien', 'MK', 'NULL', '619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('619', '112', '2484', NULL , '2009-04-08 12:06:01' , 'Initialisation de la valeur «MK» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2485', '1071', '1', 'Malayalam', 'ML', 'NULL', '620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('620', '112', '2485', NULL , '2009-04-08 12:06:02' , 'Initialisation de la valeur «ML» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2486', '1071', '1', 'Mongol', 'MN', 'NULL', '621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('621', '112', '2486', NULL , '2009-04-08 12:06:03' , 'Initialisation de la valeur «MN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2487', '1071', '1', 'Moldave', 'MO', 'NULL', '622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('622', '112', '2487', NULL , '2009-04-08 12:06:04' , 'Initialisation de la valeur «MO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2488', '1071', '1', 'Marâthî', 'MR', 'NULL', '623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('623', '112', '2488', NULL , '2009-04-08 12:06:05' , 'Initialisation de la valeur «MR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2489', '1071', '1', 'Malais', 'MS', 'NULL', '624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('624', '112', '2489', NULL , '2009-04-08 12:06:06' , 'Initialisation de la valeur «MS» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2490', '1071', '1', 'Maltais', 'MT', 'NULL', '625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('625', '112', '2490', NULL , '2009-04-08 12:06:07' , 'Initialisation de la valeur «MT» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2491', '1071', '1', 'Birman', 'MY', 'NULL', '626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('626', '112', '2491', NULL , '2009-04-08 12:06:08' , 'Initialisation de la valeur «MY» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2492', '1071', '1', 'Nauruan', 'NA', 'NULL', '627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('627', '112', '2492', NULL , '2009-04-08 12:06:09' , 'Initialisation de la valeur «NA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2493', '1071', '1', 'Norvégien Bokmål', 'NB', 'NULL', '628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('628', '112', '2493', NULL , '2009-04-08 12:06:10' , 'Initialisation de la valeur «NB» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2494', '1071', '1', 'Ndébélé du Nord', 'ND', 'NULL', '629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('629', '112', '2494', NULL , '2009-04-08 12:06:11' , 'Initialisation de la valeur «ND» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2495', '1071', '1', 'Népalais', 'NE', 'NULL', '630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('630', '112', '2495', NULL , '2009-04-08 12:06:12' , 'Initialisation de la valeur «NE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2496', '1071', '1', 'Ndonga', 'NG', 'NULL', '631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('631', '112', '2496', NULL , '2009-04-08 12:06:13' , 'Initialisation de la valeur «NG» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2497', '1071', '1', 'Néerlandais', 'NL', 'NULL', '632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('632', '112', '2497', NULL , '2009-04-08 12:06:14' , 'Initialisation de la valeur «NL» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2498', '1071', '1', 'Norvégien Nynorsk', 'NN', 'NULL', '633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('633', '112', '2498', NULL , '2009-04-08 12:06:15' , 'Initialisation de la valeur «NN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2499', '1071', '1', 'Norvégien', 'NO', 'NULL', '634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('634', '112', '2499', NULL , '2009-04-08 12:06:16' , 'Initialisation de la valeur «NO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2500', '1071', '1', 'Ndébélé du Sud', 'NR', 'NULL', '635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('635', '112', '2500', NULL , '2009-04-08 12:06:17' , 'Initialisation de la valeur «NR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2501', '1071', '1', 'Navajo', 'NV', 'NULL', '636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('636', '112', '2501', NULL , '2009-04-08 12:06:18' , 'Initialisation de la valeur «NV» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2502', '1071', '1', 'Chichewa', 'NY', 'NULL', '637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('637', '112', '2502', NULL , '2009-04-08 12:06:19' , 'Initialisation de la valeur «NY» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2503', '1071', '1', 'Occitan', 'OC', 'NULL', '638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('638', '112', '2503', NULL , '2009-04-08 12:06:20' , 'Initialisation de la valeur «OC» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2504', '1071', '1', 'Ojibwé', 'OJ', 'NULL', '639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('639', '112', '2504', NULL , '2009-04-08 12:06:21' , 'Initialisation de la valeur «OJ» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2505', '1071', '1', 'Oromo', 'OM', 'NULL', '640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('640', '112', '2505', NULL , '2009-04-08 12:06:22' , 'Initialisation de la valeur «OM» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2506', '1071', '1', 'Oriya', 'OR', 'NULL', '641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('641', '112', '2506', NULL , '2009-04-08 12:06:23' , 'Initialisation de la valeur «OR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2507', '1071', '1', 'Ossète', 'OS', 'NULL', '642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('642', '112', '2507', NULL , '2009-04-08 12:06:24' , 'Initialisation de la valeur «OS» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2508', '1071', '1', 'Panjâbî', 'PA', 'NULL', '643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('643', '112', '2508', NULL , '2009-04-08 12:06:25' , 'Initialisation de la valeur «PA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2509', '1071', '1', 'Pâli', 'PI', 'NULL', '644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('644', '112', '2509', NULL , '2009-04-08 12:06:26' , 'Initialisation de la valeur «PI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2510', '1071', '1', 'Polonais', 'PL', 'NULL', '645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('645', '112', '2510', NULL , '2009-04-08 12:06:27' , 'Initialisation de la valeur «PL» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2511', '1071', '1', 'Pachto', 'PS', 'NULL', '646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('646', '112', '2511', NULL , '2009-04-08 12:06:28' , 'Initialisation de la valeur «PS» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2512', '1071', '1', 'Portugais', 'PT', 'NULL', '647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('647', '112', '2512', NULL , '2009-04-08 12:06:29' , 'Initialisation de la valeur «PT» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2513', '1071', '1', 'Quechua', 'QU', 'NULL', '648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('648', '112', '2513', NULL , '2009-04-08 12:06:30' , 'Initialisation de la valeur «QU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2514', '1071', '1', 'Romanche', 'RM', 'NULL', '649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('649', '112', '2514', NULL , '2009-04-08 12:06:31' , 'Initialisation de la valeur «RM» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2515', '1071', '1', 'Kirundi', 'RN', 'NULL', '650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('650', '112', '2515', NULL , '2009-04-08 12:06:32' , 'Initialisation de la valeur «RN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2516', '1071', '1', 'Roumain', 'RO', 'NULL', '651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('651', '112', '2516', NULL , '2009-04-08 12:06:33' , 'Initialisation de la valeur «RO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2517', '1071', '1', 'Russe', 'RU', 'NULL', '652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('652', '112', '2517', NULL , '2009-04-08 12:06:34' , 'Initialisation de la valeur «RU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2518', '1071', '1', 'Kinyarwanda', 'RW', 'NULL', '653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('653', '112', '2518', NULL , '2009-04-08 12:06:35' , 'Initialisation de la valeur «RW» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2519', '1071', '1', 'Sanskrit', 'SA', 'NULL', '654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('654', '112', '2519', NULL , '2009-04-08 12:06:36' , 'Initialisation de la valeur «SA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2520', '1071', '1', 'Sarde', 'SC', 'NULL', '655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('655', '112', '2520', NULL , '2009-04-08 12:06:37' , 'Initialisation de la valeur «SC» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2521', '1071', '1', 'Sindhi', 'SD', 'NULL', '656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('656', '112', '2521', NULL , '2009-04-08 12:06:38' , 'Initialisation de la valeur «SD» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2522', '1071', '1', 'Same du Nord', 'SE', 'NULL', '657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('657', '112', '2522', NULL , '2009-04-08 12:06:39' , 'Initialisation de la valeur «SE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2523', '1071', '1', 'Sango', 'SG', 'NULL', '658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('658', '112', '2523', NULL , '2009-04-08 12:06:40' , 'Initialisation de la valeur «SG» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2524', '1071', '1', 'Serbo-croate', 'SH', 'NULL', '659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('659', '112', '2524', NULL , '2009-04-08 12:06:41' , 'Initialisation de la valeur «SH» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2525', '1071', '1', 'Cingalais', 'SI', 'NULL', '660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('660', '112', '2525', NULL , '2009-04-08 12:06:42' , 'Initialisation de la valeur «SI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2526', '1071', '1', 'Slovaque', 'SK', 'NULL', '661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('661', '112', '2526', NULL , '2009-04-08 12:06:43' , 'Initialisation de la valeur «SK» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2527', '1071', '1', 'Slovène', 'SL', 'NULL', '662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('662', '112', '2527', NULL , '2009-04-08 12:06:44' , 'Initialisation de la valeur «SL» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2528', '1071', '1', 'Samoan', 'SM', 'NULL', '663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('663', '112', '2528', NULL , '2009-04-08 12:06:45' , 'Initialisation de la valeur «SM» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2529', '1071', '1', 'Shona', 'SN', 'NULL', '664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('664', '112', '2529', NULL , '2009-04-08 12:06:46' , 'Initialisation de la valeur «SN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2530', '1071', '1', 'Somali', 'SO', 'NULL', '665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('665', '112', '2530', NULL , '2009-04-08 12:06:47' , 'Initialisation de la valeur «SO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2531', '1071', '1', 'Albanais', 'SQ', 'NULL', '666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('666', '112', '2531', NULL , '2009-04-08 12:06:48' , 'Initialisation de la valeur «SQ» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2532', '1071', '1', 'Serbe', 'SR', 'NULL', '667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('667', '112', '2532', NULL , '2009-04-08 12:06:49' , 'Initialisation de la valeur «SR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2533', '1071', '1', 'Siswati', 'SS', 'NULL', '668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('668', '112', '2533', NULL , '2009-04-08 12:06:50' , 'Initialisation de la valeur «SS» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2534', '1071', '1', 'Sotho du Sud', 'ST', 'NULL', '669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('669', '112', '2534', NULL , '2009-04-08 12:06:51' , 'Initialisation de la valeur «ST» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2535', '1071', '1', 'Sundanais', 'SU', 'NULL', '670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('670', '112', '2535', NULL , '2009-04-08 12:06:52' , 'Initialisation de la valeur «SU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2536', '1071', '1', 'Suédois', 'SV', 'NULL', '671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('671', '112', '2536', NULL , '2009-04-08 12:06:53' , 'Initialisation de la valeur «SV» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2537', '1071', '1', 'Swahili', 'SW', 'NULL', '672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('672', '112', '2537', NULL , '2009-04-08 12:06:54' , 'Initialisation de la valeur «SW» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2538', '1071', '1', 'Tamoul', 'TA', 'NULL', '673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('673', '112', '2538', NULL , '2009-04-08 12:06:55' , 'Initialisation de la valeur «TA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2539', '1071', '1', 'Télougou', 'TE', 'NULL', '674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('674', '112', '2539', NULL , '2009-04-08 12:06:56' , 'Initialisation de la valeur «TE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2540', '1071', '1', 'Tadjik', 'TG', 'NULL', '675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('675', '112', '2540', NULL , '2009-04-08 12:06:57' , 'Initialisation de la valeur «TG» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2541', '1071', '1', 'Thaï', 'TH', 'NULL', '676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('676', '112', '2541', NULL , '2009-04-08 12:06:58' , 'Initialisation de la valeur «TH» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2542', '1071', '1', 'Tigrinya', 'TI', 'NULL', '677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('677', '112', '2542', NULL , '2009-04-08 12:06:59' , 'Initialisation de la valeur «TI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2543', '1071', '1', 'Turkmène', 'TK', 'NULL', '678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('678', '112', '2543', NULL , '2009-04-08 12:07:00' , 'Initialisation de la valeur «TK» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2544', '1071', '1', 'Tagalog', 'TL', 'NULL', '679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('679', '112', '2544', NULL , '2009-04-08 12:07:01' , 'Initialisation de la valeur «TL» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2545', '1071', '1', 'Tswana', 'TN', 'NULL', '680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('680', '112', '2545', NULL , '2009-04-08 12:07:02' , 'Initialisation de la valeur «TN» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2546', '1071', '1', 'Tongien', 'TO', 'NULL', '681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('681', '112', '2546', NULL , '2009-04-08 12:07:03' , 'Initialisation de la valeur «TO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2547', '1071', '1', 'Turc', 'TR', 'NULL', '682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('682', '112', '2547', NULL , '2009-04-08 12:07:04' , 'Initialisation de la valeur «TR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2548', '1071', '1', 'Tsonga', 'TS', 'NULL', '683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('683', '112', '2548', NULL , '2009-04-08 12:07:05' , 'Initialisation de la valeur «TS» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2549', '1071', '1', 'Tatar', 'TT', 'NULL', '684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('684', '112', '2549', NULL , '2009-04-08 12:07:06' , 'Initialisation de la valeur «TT» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2550', '1071', '1', 'Twi', 'TW', 'NULL', '685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('685', '112', '2550', NULL , '2009-04-08 12:07:07' , 'Initialisation de la valeur «TW» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2551', '1071', '1', 'Tahitien', 'TY', 'NULL', '686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('686', '112', '2551', NULL , '2009-04-08 12:07:08' , 'Initialisation de la valeur «TY» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2552', '1071', '1', 'Ouïghour', 'UG', 'NULL', '687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('687', '112', '2552', NULL , '2009-04-08 12:07:09' , 'Initialisation de la valeur «UG» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2553', '1071', '1', 'Ukrainien', 'UK', 'NULL', '688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('688', '112', '2553', NULL , '2009-04-08 12:07:10' , 'Initialisation de la valeur «UK» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2554', '1071', '1', 'Ourdou', 'UR', 'NULL', '689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('689', '112', '2554', NULL , '2009-04-08 12:07:11' , 'Initialisation de la valeur «UR» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2555', '1071', '1', 'Ouzbek', 'UZ', 'NULL', '690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('690', '112', '2555', NULL , '2009-04-08 12:07:12' , 'Initialisation de la valeur «UZ» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2556', '1071', '1', 'Venda', 'VE', 'NULL', '691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('691', '112', '2556', NULL , '2009-04-08 12:07:13' , 'Initialisation de la valeur «VE» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2557', '1071', '1', 'Vietnamien', 'VI', 'NULL', '692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('692', '112', '2557', NULL , '2009-04-08 12:07:14' , 'Initialisation de la valeur «VI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2558', '1071', '1', 'Volapük', 'VO', 'NULL', '693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('693', '112', '2558', NULL , '2009-04-08 12:07:15' , 'Initialisation de la valeur «VO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2559', '1071', '1', 'Wallon', 'WA', 'NULL', '694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('694', '112', '2559', NULL , '2009-04-08 12:07:16' , 'Initialisation de la valeur «WA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2560', '1071', '1', 'Wolof', 'WO', 'NULL', '695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('695', '112', '2560', NULL , '2009-04-08 12:07:17' , 'Initialisation de la valeur «WO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2561', '1071', '1', 'Xhosa', 'XH', 'NULL', '696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('696', '112', '2561', NULL , '2009-04-08 12:07:18' , 'Initialisation de la valeur «XH» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2562', '1071', '1', 'Yiddish', 'YI', 'NULL', '697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('697', '112', '2562', NULL , '2009-04-08 12:07:19' , 'Initialisation de la valeur «YI» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2563', '1071', '1', 'Yoruba', 'YO', 'NULL', '698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('698', '112', '2563', NULL , '2009-04-08 12:07:20' , 'Initialisation de la valeur «YO» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2564', '1071', '1', 'Zhuang', 'ZA', 'NULL', '699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('699', '112', '2564', NULL , '2009-04-08 12:07:21' , 'Initialisation de la valeur «ZA» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2565', '1071', '1', 'Chinois', 'ZH', 'NULL', '700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('700', '112', '2565', NULL , '2009-04-08 12:07:22' , 'Initialisation de la valeur «ZH» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2566', '1071', '1', 'Zoulou', 'ZU', 'NULL', '701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('701', '112', '2566', NULL , '2009-04-08 12:07:23' , 'Initialisation de la valeur «ZU» pour la liste «68».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2567', '1072', '1', '1 heure', '1h', 'NULL', '702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('702', '112', '2567', NULL , '2009-04-08 12:07:24' , 'Initialisation de la valeur «1h» pour la liste «69».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2568', '1072', '1', '2 heures', '2h', 'NULL', '703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('703', '112', '2568', NULL , '2009-04-08 12:07:25' , 'Initialisation de la valeur «2h» pour la liste «69».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2569', '1072', '1', '5 heures', '5h', 'NULL', '704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('704', '112', '2569', NULL , '2009-04-08 12:07:26' , 'Initialisation de la valeur «5h» pour la liste «69».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2570', '1072', '1', '10 heures', '10h', 'NULL', '705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('705', '112', '2570', NULL , '2009-04-08 12:07:27' , 'Initialisation de la valeur «10h» pour la liste «69».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2571', '1073', '1', 'Journalier', 'J', 'NULL', '706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('706', '112', '2571', NULL , '2009-04-08 12:07:28' , 'Initialisation de la valeur «J» pour la liste «70».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2572', '1073', '1', 'Hebdomadaire', 'H', 'NULL', '707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('707', '112', '2572', NULL , '2009-04-08 12:07:29' , 'Initialisation de la valeur «H» pour la liste «70».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2573', '1073', '1', 'Mensuel', 'M', 'NULL', '708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('708', '112', '2573', NULL , '2009-04-08 12:07:30' , 'Initialisation de la valeur «M» pour la liste «70».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2574', '1073', '1', 'Bi-mensuel', 'B', 'NULL', '709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('709', '112', '2574', NULL , '2009-04-08 12:07:31' , 'Initialisation de la valeur «B» pour la liste «70».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2575', '1073', '1', 'Trimestriel', 'T', 'NULL', '710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('710', '112', '2575', NULL , '2009-04-08 12:07:32' , 'Initialisation de la valeur «T» pour la liste «70».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2576', '1073', '1', 'Semestriel', 'S', 'NULL', '711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('711', '112', '2576', NULL , '2009-04-08 12:07:33' , 'Initialisation de la valeur «S» pour la liste «70».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2577', '1074', '1', 'Afghanistan', 'AF', 'NULL', '712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('712', '112', '2577', NULL , '2009-04-08 12:07:34' , 'Initialisation de la valeur «AF» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2578', '1074', '1', 'Afrique du Sud', 'ZA', 'NULL', '713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('713', '112', '2578', NULL , '2009-04-08 12:07:35' , 'Initialisation de la valeur «ZA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2579', '1074', '1', 'Åland', 'AX', 'NULL', '714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('714', '112', '2579', NULL , '2009-04-08 12:07:36' , 'Initialisation de la valeur «AX» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2580', '1074', '1', 'Albanie', 'AL', 'NULL', '715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('715', '112', '2580', NULL , '2009-04-08 12:07:37' , 'Initialisation de la valeur «AL» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2581', '1074', '1', 'Algérie', 'DZ', 'NULL', '716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('716', '112', '2581', NULL , '2009-04-08 12:07:38' , 'Initialisation de la valeur «DZ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2582', '1074', '1', 'Allemagne', 'DE', 'NULL', '717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('717', '112', '2582', NULL , '2009-04-08 12:07:39' , 'Initialisation de la valeur «DE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2583', '1074', '1', 'Andorre', 'AD', 'NULL', '718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('718', '112', '2583', NULL , '2009-04-08 12:07:40' , 'Initialisation de la valeur «AD» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2584', '1074', '1', 'Angola', 'AO', 'NULL', '719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('719', '112', '2584', NULL , '2009-04-08 12:07:41' , 'Initialisation de la valeur «AO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2585', '1074', '1', 'Anguilla', 'AI', 'NULL', '720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('720', '112', '2585', NULL , '2009-04-08 12:07:42' , 'Initialisation de la valeur «AI» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2586', '1074', '1', 'Antarctique', 'AQ', 'NULL', '721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('721', '112', '2586', NULL , '2009-04-08 12:07:43' , 'Initialisation de la valeur «AQ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2587', '1074', '1', 'Antigua-et-Barbuda', 'AG', 'NULL', '722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('722', '112', '2587', NULL , '2009-04-08 12:07:44' , 'Initialisation de la valeur «AG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2588', '1074', '1', 'Antilles néerlandaises', 'AN', 'NULL', '723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('723', '112', '2588', NULL , '2009-04-08 12:07:45' , 'Initialisation de la valeur «AN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2589', '1074', '1', 'Arabie saoudite', 'SA', 'NULL', '724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('724', '112', '2589', NULL , '2009-04-08 12:07:46' , 'Initialisation de la valeur «SA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2590', '1074', '1', 'Argentine', 'AR', 'NULL', '725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('725', '112', '2590', NULL , '2009-04-08 12:07:47' , 'Initialisation de la valeur «AR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2591', '1074', '1', 'Arménie', 'AM', 'NULL', '726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('726', '112', '2591', NULL , '2009-04-08 12:07:48' , 'Initialisation de la valeur «AM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2592', '1074', '1', 'Aruba', 'AW', 'NULL', '727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('727', '112', '2592', NULL , '2009-04-08 12:07:49' , 'Initialisation de la valeur «AW» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2593', '1074', '1', 'Australie', 'AU', 'NULL', '728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('728', '112', '2593', NULL , '2009-04-08 12:07:50' , 'Initialisation de la valeur «AU» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2594', '1074', '1', 'Autriche', 'AT', 'NULL', '729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('729', '112', '2594', NULL , '2009-04-08 12:07:51' , 'Initialisation de la valeur «AT» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2595', '1074', '1', 'Azerbaïdjan', 'AZ', 'NULL', '730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('730', '112', '2595', NULL , '2009-04-08 12:07:52' , 'Initialisation de la valeur «AZ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2596', '1074', '1', 'Bahamas', 'BS', 'NULL', '731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('731', '112', '2596', NULL , '2009-04-08 12:07:53' , 'Initialisation de la valeur «BS» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2597', '1074', '1', 'Bahreïn', 'BH', 'NULL', '732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('732', '112', '2597', NULL , '2009-04-08 12:07:54' , 'Initialisation de la valeur «BH» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2598', '1074', '1', 'Bangladesh', 'BD', 'NULL', '733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('733', '112', '2598', NULL , '2009-04-08 12:07:55' , 'Initialisation de la valeur «BD» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2599', '1074', '1', 'Barbade', 'BB', 'NULL', '734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('734', '112', '2599', NULL , '2009-04-08 12:07:56' , 'Initialisation de la valeur «BB» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2600', '1074', '1', 'Biélorussie', 'BY', 'NULL', '735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('735', '112', '2600', NULL , '2009-04-08 12:07:57' , 'Initialisation de la valeur «BY» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2601', '1074', '1', 'Belgique', 'BE', 'NULL', '736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('736', '112', '2601', NULL , '2009-04-08 12:07:58' , 'Initialisation de la valeur «BE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2602', '1074', '1', 'Belize', 'BZ', 'NULL', '737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('737', '112', '2602', NULL , '2009-04-08 12:07:59' , 'Initialisation de la valeur «BZ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2603', '1074', '1', 'Bénin', 'BJ', 'NULL', '738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('738', '112', '2603', NULL , '2009-04-08 12:08:00' , 'Initialisation de la valeur «BJ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2604', '1074', '1', 'Bermudes', 'BM', 'Territoire d''outre-mer autonome (Royaume-Uni)', '739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('739', '112', '2604', NULL , '2009-04-08 12:08:01' , 'Initialisation de la valeur «BM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2605', '1074', '1', 'Bhoutan', 'BT', 'NULL', '740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('740', '112', '2605', NULL , '2009-04-08 12:08:02' , 'Initialisation de la valeur «BT» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2606', '1074', '1', 'Bolivie', 'BO', 'NULL', '741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('741', '112', '2606', NULL , '2009-04-08 12:08:03' , 'Initialisation de la valeur «BO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2607', '1074', '1', 'Bosnie-Herzégovine', 'BA', 'NULL', '742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('742', '112', '2607', NULL , '2009-04-08 12:08:04' , 'Initialisation de la valeur «BA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2608', '1074', '1', 'Botswana', 'BW', 'NULL', '743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('743', '112', '2608', NULL , '2009-04-08 12:08:05' , 'Initialisation de la valeur «BW» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2609', '1074', '1', 'Île Bouvet', 'BV', 'NULL', '744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('744', '112', '2609', NULL , '2009-04-08 12:08:06' , 'Initialisation de la valeur «BV» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2610', '1074', '1', 'Brésil', 'BR', 'NULL', '745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('745', '112', '2610', NULL , '2009-04-08 12:08:07' , 'Initialisation de la valeur «BR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2611', '1074', '1', 'Brunei', 'BN', 'NULL', '746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('746', '112', '2611', NULL , '2009-04-08 12:08:08' , 'Initialisation de la valeur «BN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2612', '1074', '1', 'Bulgarie', 'BG', 'NULL', '747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('747', '112', '2612', NULL , '2009-04-08 12:08:09' , 'Initialisation de la valeur «BG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2613', '1074', '1', 'Burkina Faso', 'BF', 'NULL', '748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('748', '112', '2613', NULL , '2009-04-08 12:08:10' , 'Initialisation de la valeur «BF» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2614', '1074', '1', 'Burundi', 'BI', 'NULL', '749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('749', '112', '2614', NULL , '2009-04-08 12:08:11' , 'Initialisation de la valeur «BI» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2615', '1074', '1', 'Îles Caïmans', 'KY', 'NULL', '750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('750', '112', '2615', NULL , '2009-04-08 12:08:12' , 'Initialisation de la valeur «KY» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2616', '1074', '1', 'Cambodge', 'KH', 'NULL', '751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('751', '112', '2616', NULL , '2009-04-08 12:08:13' , 'Initialisation de la valeur «KH» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2617', '1074', '1', 'Cameroun', 'CM', 'NULL', '752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('752', '112', '2617', NULL , '2009-04-08 12:08:14' , 'Initialisation de la valeur «CM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2618', '1074', '1', 'Canada', 'CA', 'NULL', '753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('753', '112', '2618', NULL , '2009-04-08 12:08:15' , 'Initialisation de la valeur «CA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2619', '1074', '1', 'Cap-Vert', 'CV', 'NULL', '754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('754', '112', '2619', NULL , '2009-04-08 12:08:16' , 'Initialisation de la valeur «CV» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2620', '1074', '1', 'République centrafricaine', 'CF', 'NULL', '755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('755', '112', '2620', NULL , '2009-04-08 12:08:17' , 'Initialisation de la valeur «CF» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2621', '1074', '1', 'Chili', 'CL', 'NULL', '756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('756', '112', '2621', NULL , '2009-04-08 12:08:18' , 'Initialisation de la valeur «CL» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2622', '1074', '1', 'Chine', 'CN', 'République populaire de Chine', '757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('757', '112', '2622', NULL , '2009-04-08 12:08:19' , 'Initialisation de la valeur «CN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2623', '1074', '1', 'Île Christmas', 'CX', 'Australie', '758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('758', '112', '2623', NULL , '2009-04-08 12:08:20' , 'Initialisation de la valeur «CX» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2624', '1074', '1', 'Chypre', 'CY', 'NULL', '759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('759', '112', '2624', NULL , '2009-04-08 12:08:21' , 'Initialisation de la valeur «CY» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2625', '1074', '1', 'Îles Cocos', 'CC', 'NULL', '760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('760', '112', '2625', NULL , '2009-04-08 12:08:22' , 'Initialisation de la valeur «CC» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2626', '1074', '1', 'Colombie', 'CO', 'NULL', '761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('761', '112', '2626', NULL , '2009-04-08 12:08:23' , 'Initialisation de la valeur «CO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2627', '1074', '1', 'Comores', 'KM', 'NULL', '762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('762', '112', '2627', NULL , '2009-04-08 12:08:24' , 'Initialisation de la valeur «KM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2628', '1074', '1', 'Congo-Brazzaville / (Congo)', 'CG', 'Congo', '763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('763', '112', '2628', NULL , '2009-04-08 12:08:25' , 'Initialisation de la valeur «CG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2629', '1074', '1', 'Congo-Kinshasa / (République démocratique du Congo)', 'CD', 'République démocratique du Congo', '764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('764', '112', '2629', NULL , '2009-04-08 12:08:26' , 'Initialisation de la valeur «CD» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2630', '1074', '1', 'Îles Cook', 'CK', 'NULL', '765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('765', '112', '2630', NULL , '2009-04-08 12:08:27' , 'Initialisation de la valeur «CK» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2631', '1074', '1', 'Corée du Sud', 'KR', 'NULL', '766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('766', '112', '2631', NULL , '2009-04-08 12:08:28' , 'Initialisation de la valeur «KR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2632', '1074', '1', 'Corée du Nord', 'KP', 'NULL', '767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('767', '112', '2632', NULL , '2009-04-08 12:08:29' , 'Initialisation de la valeur «KP» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2633', '1074', '1', 'Costa Rica', 'CR', 'NULL', '768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('768', '112', '2633', NULL , '2009-04-08 12:08:30' , 'Initialisation de la valeur «CR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2634', '1074', '1', 'Côte d''Ivoire', 'CI', 'NULL', '769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('769', '112', '2634', NULL , '2009-04-08 12:08:31' , 'Initialisation de la valeur «CI» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2635', '1074', '1', 'Croatie', 'HR', 'NULL', '770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('770', '112', '2635', NULL , '2009-04-08 12:08:32' , 'Initialisation de la valeur «HR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2636', '1074', '1', 'Cuba', 'CU', 'NULL', '771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('771', '112', '2636', NULL , '2009-04-08 12:08:33' , 'Initialisation de la valeur «CU» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2637', '1074', '1', 'Danemark', 'DK', 'NULL', '772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('772', '112', '2637', NULL , '2009-04-08 12:08:34' , 'Initialisation de la valeur «DK» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2638', '1074', '1', 'Djibouti', 'DJ', 'NULL', '773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('773', '112', '2638', NULL , '2009-04-08 12:08:35' , 'Initialisation de la valeur «DJ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2639', '1074', '1', 'République dominicaine', 'DO', 'NULL', '774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('774', '112', '2639', NULL , '2009-04-08 12:08:36' , 'Initialisation de la valeur «DO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2640', '1074', '1', 'Dominique', 'DM', 'NULL', '775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('775', '112', '2640', NULL , '2009-04-08 12:08:37' , 'Initialisation de la valeur «DM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2641', '1074', '1', 'Égypte', 'EG', 'NULL', '776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('776', '112', '2641', NULL , '2009-04-08 12:08:38' , 'Initialisation de la valeur «EG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2642', '1074', '1', 'Salvador', 'SV', 'NULL', '777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('777', '112', '2642', NULL , '2009-04-08 12:08:39' , 'Initialisation de la valeur «SV» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2643', '1074', '1', 'Émirats arabes unis', 'AE', 'NULL', '778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('778', '112', '2643', NULL , '2009-04-08 12:08:40' , 'Initialisation de la valeur «AE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2644', '1074', '1', 'Équateur', 'EC', 'NULL', '779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('779', '112', '2644', NULL , '2009-04-08 12:08:41' , 'Initialisation de la valeur «EC» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2645', '1074', '1', 'Érythrée', 'ER', 'NULL', '780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('780', '112', '2645', NULL , '2009-04-08 12:08:42' , 'Initialisation de la valeur «ER» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2646', '1074', '1', 'Espagne', 'ES', 'NULL', '781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('781', '112', '2646', NULL , '2009-04-08 12:08:43' , 'Initialisation de la valeur «ES» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2647', '1074', '1', 'Estonie', 'EE', 'NULL', '782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('782', '112', '2647', NULL , '2009-04-08 12:08:44' , 'Initialisation de la valeur «EE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2648', '1074', '1', 'États-Unis', 'US', 'NULL', '783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('783', '112', '2648', NULL , '2009-04-08 12:08:45' , 'Initialisation de la valeur «US» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2649', '1074', '1', 'Éthiopie', 'ET', 'NULL', '784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('784', '112', '2649', NULL , '2009-04-08 12:08:46' , 'Initialisation de la valeur «ET» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2650', '1074', '1', 'Îles Malouines', 'FK', 'Territoire autonome (Royaume-Uni)', '785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('785', '112', '2650', NULL , '2009-04-08 12:08:47' , 'Initialisation de la valeur «FK» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2651', '1074', '1', 'Îles Féroé', 'FO', 'NULL', '786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('786', '112', '2651', NULL , '2009-04-08 12:08:48' , 'Initialisation de la valeur «FO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2652', '1074', '1', 'Fidji', 'FJ', 'NULL', '787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('787', '112', '2652', NULL , '2009-04-08 12:08:49' , 'Initialisation de la valeur «FJ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2653', '1074', '1', 'Finlande', 'FI', 'NULL', '788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('788', '112', '2653', NULL , '2009-04-08 12:08:50' , 'Initialisation de la valeur «FI» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2654', '1074', '1', 'France', 'FR', 'NULL', '789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('789', '112', '2654', NULL , '2009-04-08 12:08:51' , 'Initialisation de la valeur «FR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2655', '1074', '1', 'Gabon', 'GA', 'NULL', '790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('790', '112', '2655', NULL , '2009-04-08 12:08:52' , 'Initialisation de la valeur «GA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2656', '1074', '1', 'Gambie', 'GM', 'NULL', '791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('791', '112', '2656', NULL , '2009-04-08 12:08:53' , 'Initialisation de la valeur «GM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2657', '1074', '1', 'Géorgie', 'GE', 'NULL', '792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('792', '112', '2657', NULL , '2009-04-08 12:08:54' , 'Initialisation de la valeur «GE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2658', '1074', '1', 'Géorgie du Sud-et-les Îles Sandwich du Sud', 'GS', 'NULL', '793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('793', '112', '2658', NULL , '2009-04-08 12:08:55' , 'Initialisation de la valeur «GS» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2659', '1074', '1', 'Ghana', 'GH', 'NULL', '794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('794', '112', '2659', NULL , '2009-04-08 12:08:56' , 'Initialisation de la valeur «GH» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2660', '1074', '1', 'Gibraltar', 'GI', 'NULL', '795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('795', '112', '2660', NULL , '2009-04-08 12:08:57' , 'Initialisation de la valeur «GI» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2661', '1074', '1', 'Grèce', 'GR', 'NULL', '796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('796', '112', '2661', NULL , '2009-04-08 12:08:58' , 'Initialisation de la valeur «GR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2662', '1074', '1', 'Grenade', 'GD', 'NULL', '797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('797', '112', '2662', NULL , '2009-04-08 12:08:59' , 'Initialisation de la valeur «GD» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2663', '1074', '1', 'Groenland', 'GL', 'NULL', '798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('798', '112', '2663', NULL , '2009-04-08 12:09:00' , 'Initialisation de la valeur «GL» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2664', '1074', '1', 'Guadeloupe', 'GP', 'NULL', '799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('799', '112', '2664', NULL , '2009-04-08 12:09:01' , 'Initialisation de la valeur «GP» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2665', '1074', '1', 'Guam', 'GU', 'NULL', '800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('800', '112', '2665', NULL , '2009-04-08 12:09:02' , 'Initialisation de la valeur «GU» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2666', '1074', '1', 'Guatemala', 'GT', 'NULL', '801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('801', '112', '2666', NULL , '2009-04-08 12:09:03' , 'Initialisation de la valeur «GT» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2667', '1074', '1', 'Guernesey', 'GG', 'NULL', '802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('802', '112', '2667', NULL , '2009-04-08 12:09:04' , 'Initialisation de la valeur «GG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2668', '1074', '1', 'Guinée', 'GN', 'NULL', '803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('803', '112', '2668', NULL , '2009-04-08 12:09:05' , 'Initialisation de la valeur «GN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2669', '1074', '1', 'Guinée-Bissau', 'GW', 'NULL', '804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('804', '112', '2669', NULL , '2009-04-08 12:09:06' , 'Initialisation de la valeur «GW» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2670', '1074', '1', 'Guinée équatoriale', 'GQ', 'NULL', '805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('805', '112', '2670', NULL , '2009-04-08 12:09:07' , 'Initialisation de la valeur «GQ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2671', '1074', '1', 'Guyana', 'GY', 'NULL', '806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('806', '112', '2671', NULL , '2009-04-08 12:09:08' , 'Initialisation de la valeur «GY» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2672', '1074', '1', 'Guyane', 'GF', 'NULL', '807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('807', '112', '2672', NULL , '2009-04-08 12:09:09' , 'Initialisation de la valeur «GF» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2673', '1074', '1', 'Haïti', 'HT', 'NULL', '808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('808', '112', '2673', NULL , '2009-04-08 12:09:10' , 'Initialisation de la valeur «HT» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2674', '1074', '1', 'Île Heard et îles McDonald', 'HM', 'Australie (Territoire)', '809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('809', '112', '2674', NULL , '2009-04-08 12:09:11' , 'Initialisation de la valeur «HM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2675', '1074', '1', 'Honduras', 'HN', 'NULL', '810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('810', '112', '2675', NULL , '2009-04-08 12:09:12' , 'Initialisation de la valeur «HN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2676', '1074', '1', 'Hong Kong', 'HK', 'NULL', '811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('811', '112', '2676', NULL , '2009-04-08 12:09:13' , 'Initialisation de la valeur «HK» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2677', '1074', '1', 'Hongrie', 'HU', 'NULL', '812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('812', '112', '2677', NULL , '2009-04-08 12:09:14' , 'Initialisation de la valeur «HU» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2678', '1074', '1', 'Île de Man', 'IM', 'NULL', '813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('813', '112', '2678', NULL , '2009-04-08 12:09:15' , 'Initialisation de la valeur «IM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2679', '1074', '1', 'Îles mineures éloignées des États-Unis', 'UM', 'NULL', '814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('814', '112', '2679', NULL , '2009-04-08 12:09:16' , 'Initialisation de la valeur «UM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2680', '1074', '1', 'Îles Vierges britanniques', 'VG', 'NULL', '815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('815', '112', '2680', NULL , '2009-04-08 12:09:17' , 'Initialisation de la valeur «VG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2681', '1074', '1', 'Îles Vierges américaines', 'VI', 'NULL', '816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('816', '112', '2681', NULL , '2009-04-08 12:09:18' , 'Initialisation de la valeur «VI» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2682', '1074', '1', 'Inde', 'IN', 'NULL', '817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('817', '112', '2682', NULL , '2009-04-08 12:09:19' , 'Initialisation de la valeur «IN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2683', '1074', '1', 'Indonésie', 'ID', 'NULL', '818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('818', '112', '2683', NULL , '2009-04-08 12:09:20' , 'Initialisation de la valeur «ID» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2684', '1074', '1', 'Iran', 'IR', 'NULL', '819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('819', '112', '2684', NULL , '2009-04-08 12:09:21' , 'Initialisation de la valeur «IR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2685', '1074', '1', 'Irak', 'IQ', 'NULL', '820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('820', '112', '2685', NULL , '2009-04-08 12:09:22' , 'Initialisation de la valeur «IQ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2686', '1074', '1', 'Irlande', 'IE', 'NULL', '821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('821', '112', '2686', NULL , '2009-04-08 12:09:23' , 'Initialisation de la valeur «IE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2687', '1074', '1', 'Islande', 'IS', 'NULL', '822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('822', '112', '2687', NULL , '2009-04-08 12:09:24' , 'Initialisation de la valeur «IS» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2688', '1074', '1', 'Israël', 'IL', 'NULL', '823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('823', '112', '2688', NULL , '2009-04-08 12:09:25' , 'Initialisation de la valeur «IL» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2689', '1074', '1', 'Italie', 'IT', 'NULL', '824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('824', '112', '2689', NULL , '2009-04-08 12:09:26' , 'Initialisation de la valeur «IT» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2690', '1074', '1', 'Jamaïque', 'JM', 'NULL', '825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('825', '112', '2690', NULL , '2009-04-08 12:09:27' , 'Initialisation de la valeur «JM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2691', '1074', '1', 'Japon', 'JP', 'NULL', '826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('826', '112', '2691', NULL , '2009-04-08 12:09:28' , 'Initialisation de la valeur «JP» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2692', '1074', '1', 'Jersey', 'JE', 'NULL', '827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('827', '112', '2692', NULL , '2009-04-08 12:09:29' , 'Initialisation de la valeur «JE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2693', '1074', '1', 'Jordanie', 'JO', 'NULL', '828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('828', '112', '2693', NULL , '2009-04-08 12:09:30' , 'Initialisation de la valeur «JO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2694', '1074', '1', 'Kazakhstan', 'KZ', 'NULL', '829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('829', '112', '2694', NULL , '2009-04-08 12:09:31' , 'Initialisation de la valeur «KZ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2695', '1074', '1', 'Kenya', 'KE', 'NULL', '830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('830', '112', '2695', NULL , '2009-04-08 12:09:32' , 'Initialisation de la valeur «KE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2696', '1074', '1', 'Kirghizistan', 'KG', 'NULL', '831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('831', '112', '2696', NULL , '2009-04-08 12:09:33' , 'Initialisation de la valeur «KG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2697', '1074', '1', 'Kiribati', 'KI', 'NULL', '832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('832', '112', '2697', NULL , '2009-04-08 12:09:34' , 'Initialisation de la valeur «KI» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2698', '1074', '1', 'Koweït', 'KW', 'NULL', '833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('833', '112', '2698', NULL , '2009-04-08 12:09:35' , 'Initialisation de la valeur «KW» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2699', '1074', '1', 'Laos', 'LA', 'NULL', '834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('834', '112', '2699', NULL , '2009-04-08 12:09:36' , 'Initialisation de la valeur «LA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2700', '1074', '1', 'Lesotho', 'LS', 'NULL', '835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('835', '112', '2700', NULL , '2009-04-08 12:09:37' , 'Initialisation de la valeur «LS» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2701', '1074', '1', 'Lettonie', 'LV', 'NULL', '836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('836', '112', '2701', NULL , '2009-04-08 12:09:38' , 'Initialisation de la valeur «LV» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2702', '1074', '1', 'Liban', 'LB', 'NULL', '837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('837', '112', '2702', NULL , '2009-04-08 12:09:39' , 'Initialisation de la valeur «LB» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2703', '1074', '1', 'Libéria', 'LR', 'NULL', '838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('838', '112', '2703', NULL , '2009-04-08 12:09:40' , 'Initialisation de la valeur «LR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2704', '1074', '1', 'Libye', 'LY', 'NULL', '839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('839', '112', '2704', NULL , '2009-04-08 12:09:41' , 'Initialisation de la valeur «LY» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2705', '1074', '1', 'Liechtenstein', 'LI', 'NULL', '840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('840', '112', '2705', NULL , '2009-04-08 12:09:42' , 'Initialisation de la valeur «LI» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2706', '1074', '1', 'Lituanie', 'LT', 'NULL', '841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('841', '112', '2706', NULL , '2009-04-08 12:09:43' , 'Initialisation de la valeur «LT» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2707', '1074', '1', 'Luxembourg', 'LU', 'NULL', '842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('842', '112', '2707', NULL , '2009-04-08 12:09:44' , 'Initialisation de la valeur «LU» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2708', '1074', '1', 'Macao', 'MO', 'NULL', '843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('843', '112', '2708', NULL , '2009-04-08 12:09:45' , 'Initialisation de la valeur «MO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2709', '1074', '1', 'Macédoine', 'MK', 'NULL', '844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('844', '112', '2709', NULL , '2009-04-08 12:09:46' , 'Initialisation de la valeur «MK» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2710', '1074', '1', 'Madagascar', 'MG', 'NULL', '845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('845', '112', '2710', NULL , '2009-04-08 12:09:47' , 'Initialisation de la valeur «MG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2711', '1074', '1', 'Malaisie', 'MY', 'NULL', '846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('846', '112', '2711', NULL , '2009-04-08 12:09:48' , 'Initialisation de la valeur «MY» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2712', '1074', '1', 'Malawi', 'MW', 'NULL', '847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('847', '112', '2712', NULL , '2009-04-08 12:09:49' , 'Initialisation de la valeur «MW» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2713', '1074', '1', 'Maldives', 'MV', 'NULL', '848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('848', '112', '2713', NULL , '2009-04-08 12:09:50' , 'Initialisation de la valeur «MV» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2714', '1074', '1', 'Mali', 'ML', 'NULL', '849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('849', '112', '2714', NULL , '2009-04-08 12:09:51' , 'Initialisation de la valeur «ML» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2715', '1074', '1', 'Malte', 'MT', 'NULL', '850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('850', '112', '2715', NULL , '2009-04-08 12:09:52' , 'Initialisation de la valeur «MT» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2716', '1074', '1', 'Îles Mariannes du Nord', 'MP', 'NULL', '851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('851', '112', '2716', NULL , '2009-04-08 12:09:53' , 'Initialisation de la valeur «MP» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2717', '1074', '1', 'Maroc', 'MA', 'NULL', '852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('852', '112', '2717', NULL , '2009-04-08 12:09:54' , 'Initialisation de la valeur «MA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2718', '1074', '1', 'Îles Marshall', 'MH', 'NULL', '853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('853', '112', '2718', NULL , '2009-04-08 12:09:55' , 'Initialisation de la valeur «MH» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2719', '1074', '1', 'Martinique', 'MQ', 'NULL', '854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('854', '112', '2719', NULL , '2009-04-08 12:09:56' , 'Initialisation de la valeur «MQ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2720', '1074', '1', 'Maurice', 'MU', 'NULL', '855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('855', '112', '2720', NULL , '2009-04-08 12:09:57' , 'Initialisation de la valeur «MU» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2721', '1074', '1', 'Mauritanie', 'MR', 'NULL', '856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('856', '112', '2721', NULL , '2009-04-08 12:09:58' , 'Initialisation de la valeur «MR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2722', '1074', '1', 'Mayotte', 'YT', 'NULL', '857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('857', '112', '2722', NULL , '2009-04-08 12:09:59' , 'Initialisation de la valeur «YT» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2723', '1074', '1', 'Mexique', 'MX', 'NULL', '858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('858', '112', '2723', NULL , '2009-04-08 12:10:00' , 'Initialisation de la valeur «MX» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2724', '1074', '1', 'Micronésie', 'FM', 'NULL', '859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('859', '112', '2724', NULL , '2009-04-08 12:10:01' , 'Initialisation de la valeur «FM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2725', '1074', '1', 'Moldavie', 'MD', 'NULL', '860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('860', '112', '2725', NULL , '2009-04-08 12:10:02' , 'Initialisation de la valeur «MD» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2726', '1074', '1', 'Monaco', 'MC', 'NULL', '861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('861', '112', '2726', NULL , '2009-04-08 12:10:03' , 'Initialisation de la valeur «MC» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2727', '1074', '1', 'Mongolie', 'MN', 'NULL', '862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('862', '112', '2727', NULL , '2009-04-08 12:10:04' , 'Initialisation de la valeur «MN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2728', '1074', '1', 'Monténégro', 'ME', 'NULL', '863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('863', '112', '2728', NULL , '2009-04-08 12:10:05' , 'Initialisation de la valeur «ME» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2729', '1074', '1', 'Montserrat', 'MS', 'NULL', '864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('864', '112', '2729', NULL , '2009-04-08 12:10:06' , 'Initialisation de la valeur «MS» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2730', '1074', '1', 'Mozambique', 'MZ', 'NULL', '865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('865', '112', '2730', NULL , '2009-04-08 12:10:07' , 'Initialisation de la valeur «MZ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2731', '1074', '1', 'Birmanie', 'MM', 'NULL', '866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('866', '112', '2731', NULL , '2009-04-08 12:10:08' , 'Initialisation de la valeur «MM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2732', '1074', '1', 'Namibie', 'NA', 'NULL', '867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('867', '112', '2732', NULL , '2009-04-08 12:10:09' , 'Initialisation de la valeur «NA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2733', '1074', '1', 'Nauru', 'NR', 'NULL', '868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('868', '112', '2733', NULL , '2009-04-08 12:10:10' , 'Initialisation de la valeur «NR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2734', '1074', '1', 'Népal', 'NP', 'NULL', '869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('869', '112', '2734', NULL , '2009-04-08 12:10:11' , 'Initialisation de la valeur «NP» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2735', '1074', '1', 'Nicaragua', 'NI', 'NULL', '870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('870', '112', '2735', NULL , '2009-04-08 12:10:12' , 'Initialisation de la valeur «NI» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2736', '1074', '1', 'Niger', 'NE', 'NULL', '871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('871', '112', '2736', NULL , '2009-04-08 12:10:13' , 'Initialisation de la valeur «NE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2737', '1074', '1', 'Nigeria', 'NG', 'NULL', '872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('872', '112', '2737', NULL , '2009-04-08 12:10:14' , 'Initialisation de la valeur «NG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2738', '1074', '1', 'Niué', 'NU', 'NULL', '873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('873', '112', '2738', NULL , '2009-04-08 12:10:15' , 'Initialisation de la valeur «NU» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2739', '1074', '1', 'Norfolk', 'NF', 'NULL', '874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('874', '112', '2739', NULL , '2009-04-08 12:10:16' , 'Initialisation de la valeur «NF» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2740', '1074', '1', 'Norvège', 'NO', 'NULL', '875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('875', '112', '2740', NULL , '2009-04-08 12:10:17' , 'Initialisation de la valeur «NO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2741', '1074', '1', 'Nouvelle-Calédonie', 'NC', 'NULL', '876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('876', '112', '2741', NULL , '2009-04-08 12:10:18' , 'Initialisation de la valeur «NC» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2742', '1074', '1', 'Nouvelle-Zélande', 'NZ', 'NULL', '877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('877', '112', '2742', NULL , '2009-04-08 12:10:19' , 'Initialisation de la valeur «NZ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2743', '1074', '1', 'Territoire britannique de l''océan Indien', 'IO', 'NULL', '878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('878', '112', '2743', NULL , '2009-04-08 12:10:20' , 'Initialisation de la valeur «IO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2744', '1074', '1', 'Oman', 'OM', 'NULL', '879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('879', '112', '2744', NULL , '2009-04-08 12:10:21' , 'Initialisation de la valeur «OM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2745', '1074', '1', 'Ouganda', 'UG', 'NULL', '880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('880', '112', '2745', NULL , '2009-04-08 12:10:22' , 'Initialisation de la valeur «UG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2746', '1074', '1', 'Ouzbékistan', 'UZ', 'NULL', '881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('881', '112', '2746', NULL , '2009-04-08 12:10:23' , 'Initialisation de la valeur «UZ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2747', '1074', '1', 'Pakistan', 'PK', 'NULL', '882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('882', '112', '2747', NULL , '2009-04-08 12:10:24' , 'Initialisation de la valeur «PK» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2748', '1074', '1', 'Palaos', 'PW', 'NULL', '883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('883', '112', '2748', NULL , '2009-04-08 12:10:25' , 'Initialisation de la valeur «PW» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2749', '1074', '1', 'Palestine', 'PS', 'NULL', '884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('884', '112', '2749', NULL , '2009-04-08 12:10:26' , 'Initialisation de la valeur «PS» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2750', '1074', '1', 'Panamá', 'PA', 'NULL', '885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('885', '112', '2750', NULL , '2009-04-08 12:10:27' , 'Initialisation de la valeur «PA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2751', '1074', '1', 'Papouasie-Nouvelle-Guinée', 'PG', 'NULL', '886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('886', '112', '2751', NULL , '2009-04-08 12:10:28' , 'Initialisation de la valeur «PG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2752', '1074', '1', 'Paraguay', 'PY', 'NULL', '887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('887', '112', '2752', NULL , '2009-04-08 12:10:29' , 'Initialisation de la valeur «PY» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2753', '1074', '1', 'Pays-Bas', 'NL', 'NULL', '888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('888', '112', '2753', NULL , '2009-04-08 12:10:30' , 'Initialisation de la valeur «NL» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2754', '1074', '1', 'Pérou', 'PE', 'NULL', '889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('889', '112', '2754', NULL , '2009-04-08 12:10:31' , 'Initialisation de la valeur «PE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2755', '1074', '1', 'Philippines', 'PH', 'NULL', '890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('890', '112', '2755', NULL , '2009-04-08 12:10:32' , 'Initialisation de la valeur «PH» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2756', '1074', '1', 'Pitcairn', 'PN', 'NULL', '891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('891', '112', '2756', NULL , '2009-04-08 12:10:33' , 'Initialisation de la valeur «PN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2757', '1074', '1', 'Pologne', 'PL', 'NULL', '892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('892', '112', '2757', NULL , '2009-04-08 12:10:34' , 'Initialisation de la valeur «PL» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2758', '1074', '1', 'Polynésie française', 'PF', 'NULL', '893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('893', '112', '2758', NULL , '2009-04-08 12:10:35' , 'Initialisation de la valeur «PF» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2759', '1074', '1', 'Porto Rico', 'PR', 'NULL', '894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('894', '112', '2759', NULL , '2009-04-08 12:10:36' , 'Initialisation de la valeur «PR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2760', '1074', '1', 'Portugal', 'PT', 'NULL', '895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('895', '112', '2760', NULL , '2009-04-08 12:10:37' , 'Initialisation de la valeur «PT» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2761', '1074', '1', 'Qatar', 'QA', 'NULL', '896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('896', '112', '2761', NULL , '2009-04-08 12:10:38' , 'Initialisation de la valeur «QA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2762', '1074', '1', 'La Réunion', 'RE', 'NULL', '897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('897', '112', '2762', NULL , '2009-04-08 12:10:39' , 'Initialisation de la valeur «RE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2763', '1074', '1', 'Roumanie', 'RO', 'NULL', '898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('898', '112', '2763', NULL , '2009-04-08 12:10:40' , 'Initialisation de la valeur «RO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2764', '1074', '1', 'Royaume-Uni', 'GB', 'NULL', '899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('899', '112', '2764', NULL , '2009-04-08 12:10:41' , 'Initialisation de la valeur «GB» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2765', '1074', '1', 'Russie', 'RU', 'NULL', '900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('900', '112', '2765', NULL , '2009-04-08 12:10:42' , 'Initialisation de la valeur «RU» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2766', '1074', '1', 'Rwanda', 'RW', 'NULL', '901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('901', '112', '2766', NULL , '2009-04-08 12:10:43' , 'Initialisation de la valeur «RW» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2767', '1074', '1', 'Sahara occidental', 'EH', 'NULL', '902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('902', '112', '2767', NULL , '2009-04-08 12:10:44' , 'Initialisation de la valeur «EH» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2768', '1074', '1', 'Saint-Barthélemy', 'BL', 'NULL', '903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('903', '112', '2768', NULL , '2009-04-08 12:10:45' , 'Initialisation de la valeur «BL» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2769', '1074', '1', 'Saint-Christophe-et-Niévès', 'KN', 'NULL', '904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('904', '112', '2769', NULL , '2009-04-08 12:10:46' , 'Initialisation de la valeur «KN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2770', '1074', '1', 'Saint-Marin', 'SM', 'NULL', '905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('905', '112', '2770', NULL , '2009-04-08 12:10:47' , 'Initialisation de la valeur «SM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2771', '1074', '1', 'Saint-Martin', 'MF', 'NULL', '906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('906', '112', '2771', NULL , '2009-04-08 12:10:48' , 'Initialisation de la valeur «MF» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2772', '1074', '1', 'Saint-Pierre-et-Miquelon', 'PM', 'NULL', '907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('907', '112', '2772', NULL , '2009-04-08 12:10:49' , 'Initialisation de la valeur «PM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2773', '1074', '1', 'Vatican / (Saint-Siège)', 'VA', 'NULL', '908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('908', '112', '2773', NULL , '2009-04-08 12:10:50' , 'Initialisation de la valeur «VA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2774', '1074', '1', 'Saint-Vincent-et-les Grenadines', 'VC', 'NULL', '909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('909', '112', '2774', NULL , '2009-04-08 12:10:51' , 'Initialisation de la valeur «VC» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2775', '1074', '1', 'Sainte-Hélène (territoire)', 'SH', 'NULL', '910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('910', '112', '2775', NULL , '2009-04-08 12:10:52' , 'Initialisation de la valeur «SH» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2776', '1074', '1', 'Sainte-Lucie', 'LC', 'NULL', '911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('911', '112', '2776', NULL , '2009-04-08 12:10:53' , 'Initialisation de la valeur «LC» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2777', '1074', '1', 'Salomon', 'SB', 'NULL', '912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('912', '112', '2777', NULL , '2009-04-08 12:10:54' , 'Initialisation de la valeur «SB» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2778', '1074', '1', 'Samoa', 'WS', 'NULL', '913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('913', '112', '2778', NULL , '2009-04-08 12:10:55' , 'Initialisation de la valeur «WS» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2779', '1074', '1', 'Samoa américaines', 'AS', 'NULL', '914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('914', '112', '2779', NULL , '2009-04-08 12:10:56' , 'Initialisation de la valeur «AS» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2780', '1074', '1', 'Sao Tomé-et-Principe', 'ST', 'NULL', '915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('915', '112', '2780', NULL , '2009-04-08 12:10:57' , 'Initialisation de la valeur «ST» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2781', '1074', '1', 'Sénégal', 'SN', 'NULL', '916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('916', '112', '2781', NULL , '2009-04-08 12:10:58' , 'Initialisation de la valeur «SN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2782', '1074', '1', 'Serbie', 'RS', 'NULL', '917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('917', '112', '2782', NULL , '2009-04-08 12:10:59' , 'Initialisation de la valeur «RS» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2783', '1074', '1', 'Seychelles', 'SC', 'NULL', '918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('918', '112', '2783', NULL , '2009-04-08 12:11:00' , 'Initialisation de la valeur «SC» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2784', '1074', '1', 'Sierra Leone', 'SL', 'NULL', '919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('919', '112', '2784', NULL , '2009-04-08 12:11:01' , 'Initialisation de la valeur «SL» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2785', '1074', '1', 'Singapour', 'SG', 'NULL', '920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('920', '112', '2785', NULL , '2009-04-08 12:11:02' , 'Initialisation de la valeur «SG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2786', '1074', '1', 'Slovaquie', 'SK', 'NULL', '921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('921', '112', '2786', NULL , '2009-04-08 12:11:03' , 'Initialisation de la valeur «SK» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2787', '1074', '1', 'Slovénie', 'SI', 'NULL', '922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('922', '112', '2787', NULL , '2009-04-08 12:11:04' , 'Initialisation de la valeur «SI» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2788', '1074', '1', 'Somalie', 'SO', 'NULL', '923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('923', '112', '2788', NULL , '2009-04-08 12:11:05' , 'Initialisation de la valeur «SO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2789', '1074', '1', 'Soudan', 'SD', 'NULL', '924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('924', '112', '2789', NULL , '2009-04-08 12:11:06' , 'Initialisation de la valeur «SD» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2790', '1074', '1', 'Sri Lanka', 'LK', 'NULL', '925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('925', '112', '2790', NULL , '2009-04-08 12:11:07' , 'Initialisation de la valeur «LK» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2791', '1074', '1', 'Suède', 'SE', 'NULL', '926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('926', '112', '2791', NULL , '2009-04-08 12:11:08' , 'Initialisation de la valeur «SE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2792', '1074', '1', 'Suisse', 'CH', 'NULL', '927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('927', '112', '2792', NULL , '2009-04-08 12:11:09' , 'Initialisation de la valeur «CH» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2793', '1074', '1', 'Suriname', 'SR', 'NULL', '928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('928', '112', '2793', NULL , '2009-04-08 12:11:10' , 'Initialisation de la valeur «SR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2794', '1074', '1', 'Svalbard et île Jan Mayen', 'SJ', 'NULL', '929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('929', '112', '2794', NULL , '2009-04-08 12:11:11' , 'Initialisation de la valeur «SJ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2795', '1074', '1', 'Swaziland', 'SZ', 'NULL', '930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('930', '112', '2795', NULL , '2009-04-08 12:11:12' , 'Initialisation de la valeur «SZ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2796', '1074', '1', 'Syrie', 'SY', 'NULL', '931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('931', '112', '2796', NULL , '2009-04-08 12:11:13' , 'Initialisation de la valeur «SY» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2797', '1074', '1', 'Tadjikistan', 'TJ', 'NULL', '932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('932', '112', '2797', NULL , '2009-04-08 12:11:14' , 'Initialisation de la valeur «TJ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2798', '1074', '1', 'Taïwan / (République de Chine (Taïwan))', 'TW', 'NULL', '933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('933', '112', '2798', NULL , '2009-04-08 12:11:15' , 'Initialisation de la valeur «TW» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2799', '1074', '1', 'Tanzanie', 'TZ', 'NULL', '934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('934', '112', '2799', NULL , '2009-04-08 12:11:16' , 'Initialisation de la valeur «TZ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2800', '1074', '1', 'Tchad', 'TD', 'NULL', '935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('935', '112', '2800', NULL , '2009-04-08 12:11:17' , 'Initialisation de la valeur «TD» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2801', '1074', '1', 'République tchèque', 'CZ', 'NULL', '936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('936', '112', '2801', NULL , '2009-04-08 12:11:18' , 'Initialisation de la valeur «CZ» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2802', '1074', '1', 'Terres australes et antarctiques françaises', 'TF', 'NULL', '937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('937', '112', '2802', NULL , '2009-04-08 12:11:19' , 'Initialisation de la valeur «TF» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2803', '1074', '1', 'Thaïlande', 'TH', 'NULL', '938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('938', '112', '2803', NULL , '2009-04-08 12:11:20' , 'Initialisation de la valeur «TH» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2804', '1074', '1', 'Timor oriental', 'TL', 'NULL', '939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('939', '112', '2804', NULL , '2009-04-08 12:11:21' , 'Initialisation de la valeur «TL» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2805', '1074', '1', 'Togo', 'TG', 'NULL', '940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('940', '112', '2805', NULL , '2009-04-08 12:11:22' , 'Initialisation de la valeur «TG» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2806', '1074', '1', 'Tokelau', 'TK', 'NULL', '941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('941', '112', '2806', NULL , '2009-04-08 12:11:23' , 'Initialisation de la valeur «TK» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2807', '1074', '1', 'Tonga', 'TO', 'NULL', '942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('942', '112', '2807', NULL , '2009-04-08 12:11:24' , 'Initialisation de la valeur «TO» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2808', '1074', '1', 'Trinité-et-Tobago', 'TT', 'NULL', '943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('943', '112', '2808', NULL , '2009-04-08 12:11:25' , 'Initialisation de la valeur «TT» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2809', '1074', '1', 'Tunisie', 'TN', 'NULL', '944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('944', '112', '2809', NULL , '2009-04-08 12:11:26' , 'Initialisation de la valeur «TN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2810', '1074', '1', 'Turkménistan', 'TM', 'NULL', '945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('945', '112', '2810', NULL , '2009-04-08 12:11:27' , 'Initialisation de la valeur «TM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2811', '1074', '1', 'Îles Turques-et-Caïques', 'TC', 'NULL', '946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('946', '112', '2811', NULL , '2009-04-08 12:11:28' , 'Initialisation de la valeur «TC» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2812', '1074', '1', 'Turquie', 'TR', 'NULL', '947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('947', '112', '2812', NULL , '2009-04-08 12:11:29' , 'Initialisation de la valeur «TR» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2813', '1074', '1', 'Tuvalu', 'TV', 'NULL', '948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('948', '112', '2813', NULL , '2009-04-08 12:11:30' , 'Initialisation de la valeur «TV» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2814', '1074', '1', 'Ukraine', 'UA', 'NULL', '949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('949', '112', '2814', NULL , '2009-04-08 12:11:31' , 'Initialisation de la valeur «UA» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2815', '1074', '1', 'Uruguay', 'UY', 'NULL', '950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('950', '112', '2815', NULL , '2009-04-08 12:11:32' , 'Initialisation de la valeur «UY» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2816', '1074', '1', 'Vanuatu', 'VU', 'NULL', '951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('951', '112', '2816', NULL , '2009-04-08 12:11:33' , 'Initialisation de la valeur «VU» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2817', '1074', '1', 'Venezuela', 'VE', 'NULL', '952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('952', '112', '2817', NULL , '2009-04-08 12:11:34' , 'Initialisation de la valeur «VE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2818', '1074', '1', 'Viêt Nam', 'VN', 'NULL', '953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('953', '112', '2818', NULL , '2009-04-08 12:11:35' , 'Initialisation de la valeur «VN» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2819', '1074', '1', 'Wallis-et-Futuna', 'WF', 'NULL', '954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('954', '112', '2819', NULL , '2009-04-08 12:11:36' , 'Initialisation de la valeur «WF» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2820', '1074', '1', 'Yémen', 'YE', 'NULL', '955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('955', '112', '2820', NULL , '2009-04-08 12:11:37' , 'Initialisation de la valeur «YE» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2821', '1074', '1', 'Zambie', 'ZM', 'NULL', '956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('956', '112', '2821', NULL , '2009-04-08 12:11:38' , 'Initialisation de la valeur «ZM» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2822', '1074', '1', 'Zimbabwe', 'ZW', 'NULL', '957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('957', '112', '2822', NULL , '2009-04-08 12:11:39' , 'Initialisation de la valeur «ZW» pour la liste «71».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2835', '1078', '1', 'Andorra (general)', 'AD.00', 'NULL', '958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('958', '112', '2835', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AD.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2836', '1078', '1', 'Andorra', 'AD.01', 'NULL', '959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('959', '112', '2836', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AD.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2837', '1078', '1', 'Parròquia de Canillo', 'AD.02', 'NULL', '960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('960', '112', '2837', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AD.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2838', '1078', '1', 'Parròquia d''Encamp', 'AD.03', 'NULL', '961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('961', '112', '2838', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AD.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2839', '1078', '1', 'Parròquia de la Massana', 'AD.04', 'NULL', '962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('962', '112', '2839', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AD.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2840', '1078', '1', 'Parròquia d''Ordino', 'AD.05', 'NULL', '963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('963', '112', '2840', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AD.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2841', '1078', '1', 'Parròquia de Sant Julià de Lòria', 'AD.06', 'NULL', '964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('964', '112', '2841', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AD.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2842', '1078', '1', 'Parròquia d''Andorra la Vella', 'AD.07', 'NULL', '965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('965', '112', '2842', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AD.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2843', '1078', '1', 'Parròquia d''Escaldes-Engordany', 'AD.08', 'NULL', '966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('966', '112', '2843', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AD.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2844', '1078', '1', 'United Arab Emirates (general)', 'AE.00', 'NULL', '967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('967', '112', '2844', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2845', '1078', '1', 'Abū Z̧aby', 'AE.01', 'NULL', '968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('968', '112', '2845', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AE.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2846', '1078', '1', '‘Ajmān', 'AE.02', 'NULL', '969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('969', '112', '2846', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AE.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2847', '1078', '1', 'Dubayy', 'AE.03', 'NULL', '970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('970', '112', '2847', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AE.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2848', '1078', '1', 'Al Fujayrah', 'AE.04', 'NULL', '971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('971', '112', '2848', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AE.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2849', '1078', '1', 'Raʼs al Khaymah', 'AE.05', 'NULL', '972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('972', '112', '2849', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AE.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2850', '1078', '1', 'Ash Shāriqah', 'AE.06', 'NULL', '973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('973', '112', '2850', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AE.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2851', '1078', '1', 'Umm al Qaywayn', 'AE.07', 'NULL', '974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('974', '112', '2851', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AE.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2852', '1078', '1', 'Afghanistan (general)', 'AF.00', 'NULL', '975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('975', '112', '2852', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2853', '1078', '1', 'Badakhshan', 'AF.01', 'NULL', '976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('976', '112', '2853', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2854', '1078', '1', 'Badghis Province', 'AF.02', 'NULL', '977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('977', '112', '2854', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2855', '1078', '1', 'Baghlān', 'AF.03', 'NULL', '978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('978', '112', '2855', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2856', '1078', '1', 'Bāmīān', 'AF.05', 'NULL', '979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('979', '112', '2856', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2857', '1078', '1', 'Farah', 'AF.06', 'NULL', '980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('980', '112', '2857', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2858', '1078', '1', 'Faryab Province', 'AF.07', 'NULL', '981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('981', '112', '2858', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2859', '1078', '1', 'Ghaznī', 'AF.08', 'NULL', '982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('982', '112', '2859', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2860', '1078', '1', 'Ghowr', 'AF.09', 'NULL', '983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('983', '112', '2860', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2861', '1078', '1', 'Helmand', 'AF.10', 'NULL', '984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('984', '112', '2861', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2862', '1078', '1', 'Herat Province', 'AF.11', 'NULL', '985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('985', '112', '2862', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2863', '1078', '1', 'Kabul', 'AF.13', 'NULL', '986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('986', '112', '2863', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2864', '1078', '1', 'Kāpīsā', 'AF.14', 'NULL', '987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('987', '112', '2864', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2865', '1078', '1', 'Konarha', 'AF.15', 'NULL', '988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('988', '112', '2865', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2866', '1078', '1', 'Laghman', 'AF.16', 'NULL', '989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('989', '112', '2866', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2867', '1078', '1', 'Lowgar', 'AF.17', 'NULL', '990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('990', '112', '2867', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2868', '1078', '1', 'Nangarhār', 'AF.18', 'NULL', '991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('991', '112', '2868', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2869', '1078', '1', 'Nīmrūz', 'AF.19', 'NULL', '992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('992', '112', '2869', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2870', '1078', '1', 'Orūzgān', 'AF.20', 'NULL', '993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('993', '112', '2870', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2871', '1078', '1', 'Paktika', 'AF.21', 'NULL', '994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('994', '112', '2871', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2872', '1078', '1', 'Parvān', 'AF.22', 'NULL', '995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('995', '112', '2872', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2873', '1078', '1', 'Kandahār', 'AF.23', 'NULL', '996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('996', '112', '2873', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2874', '1078', '1', 'Kunduz Province', 'AF.24', 'NULL', '997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('997', '112', '2874', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2875', '1078', '1', 'Takhār', 'AF.26', 'NULL', '998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('998', '112', '2875', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2876', '1078', '1', 'Vardak', 'AF.27', 'NULL', '999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('999', '112', '2876', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2877', '1078', '1', 'Zabul Province', 'AF.28', 'NULL', '1000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1000', '112', '2877', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2878', '1078', '1', 'Paktīkā', 'AF.29', 'NULL', '1001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1001', '112', '2878', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2879', '1078', '1', 'Balkh', 'AF.30', 'NULL', '1002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1002', '112', '2879', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2880', '1078', '1', 'Jowzjān', 'AF.31', 'NULL', '1003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1003', '112', '2880', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2881', '1078', '1', 'Samangān', 'AF.32', 'NULL', '1004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1004', '112', '2881', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2882', '1078', '1', 'Sar-e Pol', 'AF.33', 'NULL', '1005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1005', '112', '2882', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2883', '1078', '1', 'Konar', 'AF.34', 'NULL', '1006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1006', '112', '2883', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2884', '1078', '1', 'Laghmān', 'AF.35', 'NULL', '1007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1007', '112', '2884', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2885', '1078', '1', 'Paktia Province', 'AF.36', 'NULL', '1008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1008', '112', '2885', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2886', '1078', '1', 'Khowst', 'AF.37', 'NULL', '1009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1009', '112', '2886', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2887', '1078', '1', 'Nūrestān', 'AF.38', 'NULL', '1010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1010', '112', '2887', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2888', '1078', '1', 'Orūzgān Province', 'AF.39', 'NULL', '1011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1011', '112', '2888', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2889', '1078', '1', 'Parvān', 'AF.40', 'NULL', '1012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1012', '112', '2889', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2890', '1078', '1', 'Dāykondī', 'AF.41', 'NULL', '1013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1013', '112', '2890', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2891', '1078', '1', 'Panjshīr', 'AF.42', 'NULL', '1014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1014', '112', '2891', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AF.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2892', '1078', '1', 'Antigua and Barbuda (general)', 'AG.00', 'NULL', '1015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1015', '112', '2892', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2893', '1078', '1', 'Barbuda', 'AG.01', 'NULL', '1016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1016', '112', '2893', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AG.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2894', '1078', '1', 'Saint George', 'AG.03', 'NULL', '1017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1017', '112', '2894', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AG.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2895', '1078', '1', 'Saint John', 'AG.04', 'NULL', '1018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1018', '112', '2895', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AG.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2896', '1078', '1', 'Saint Mary', 'AG.05', 'NULL', '1019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1019', '112', '2896', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AG.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2897', '1078', '1', 'Saint Paul', 'AG.06', 'NULL', '1020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1020', '112', '2897', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AG.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2898', '1078', '1', 'Saint Peter', 'AG.07', 'NULL', '1021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1021', '112', '2898', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AG.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2899', '1078', '1', 'Saint Philip', 'AG.08', 'NULL', '1022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1022', '112', '2899', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AG.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2900', '1078', '1', 'Anguilla (general)', 'AI.00', 'NULL', '1023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1023', '112', '2900', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AI.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2901', '1078', '1', 'Albania (general)', 'AL.00', 'NULL', '1024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1024', '112', '2901', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2902', '1078', '1', 'Berat', 'AL.40', 'NULL', '1025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1025', '112', '2902', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2903', '1078', '1', 'Dibër', 'AL.41', 'NULL', '1026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1026', '112', '2903', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2904', '1078', '1', 'Durrës', 'AL.42', 'NULL', '1027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1027', '112', '2904', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2905', '1078', '1', 'Elbasan', 'AL.43', 'NULL', '1028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1028', '112', '2905', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2906', '1078', '1', 'Fier', 'AL.44', 'NULL', '1029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1029', '112', '2906', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2907', '1078', '1', 'Gjirokastër', 'AL.45', 'NULL', '1030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1030', '112', '2907', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2908', '1078', '1', 'Korçë', 'AL.46', 'NULL', '1031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1031', '112', '2908', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2909', '1078', '1', 'Kukës', 'AL.47', 'NULL', '1032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1032', '112', '2909', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2910', '1078', '1', 'Lezhë', 'AL.48', 'NULL', '1033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1033', '112', '2910', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2911', '1078', '1', 'Shkodër', 'AL.49', 'NULL', '1034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1034', '112', '2911', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2912', '1078', '1', 'Tiranë', 'AL.50', 'NULL', '1035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1035', '112', '2912', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2913', '1078', '1', 'Vlorë', 'AL.51', 'NULL', '1036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1036', '112', '2913', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AL.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2914', '1078', '1', 'Armenia (general)', 'AM.00', 'NULL', '1037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1037', '112', '2914', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2915', '1078', '1', 'Aragatsotn', 'AM.01', 'NULL', '1038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1038', '112', '2915', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2916', '1078', '1', 'Ararat', 'AM.02', 'NULL', '1039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1039', '112', '2916', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2917', '1078', '1', 'Armavir', 'AM.03', 'NULL', '1040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1040', '112', '2917', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2918', '1078', '1', 'Gegharkʼunikʼ', 'AM.04', 'NULL', '1041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1041', '112', '2918', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2919', '1078', '1', 'Kotaykʼ', 'AM.05', 'NULL', '1042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1042', '112', '2919', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2920', '1078', '1', 'Lorri', 'AM.06', 'NULL', '1043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1043', '112', '2920', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2921', '1078', '1', 'Shirak', 'AM.07', 'NULL', '1044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1044', '112', '2921', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2922', '1078', '1', 'Syunikʼ', 'AM.08', 'NULL', '1045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1045', '112', '2922', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2923', '1078', '1', 'Tavush', 'AM.09', 'NULL', '1046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1046', '112', '2923', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2924', '1078', '1', 'Vayotsʼ Dzor', 'AM.10', 'NULL', '1047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1047', '112', '2924', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2925', '1078', '1', 'Yerevan', 'AM.11', 'NULL', '1048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1048', '112', '2925', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AM.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2926', '1078', '1', 'Netherlands Antilles (general)', 'AN.00', 'NULL', '1049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1049', '112', '2926', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2927', '1078', '1', 'Angola (general)', 'AO.00', 'NULL', '1050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1050', '112', '2927', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2928', '1078', '1', 'Benguela', 'AO.01', 'NULL', '1051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1051', '112', '2928', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2929', '1078', '1', 'Bié', 'AO.02', 'NULL', '1052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1052', '112', '2929', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2930', '1078', '1', 'Cabinda', 'AO.03', 'NULL', '1053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1053', '112', '2930', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2931', '1078', '1', 'Cuando Cubango', 'AO.04', 'NULL', '1054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1054', '112', '2931', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2932', '1078', '1', 'Cuanza Norte', 'AO.05', 'NULL', '1055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1055', '112', '2932', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2933', '1078', '1', 'Cuanza Sul', 'AO.06', 'NULL', '1056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1056', '112', '2933', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2934', '1078', '1', 'Cunene', 'AO.07', 'NULL', '1057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1057', '112', '2934', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2935', '1078', '1', 'Huambo', 'AO.08', 'NULL', '1058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1058', '112', '2935', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2936', '1078', '1', 'Huíla', 'AO.09', 'NULL', '1059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1059', '112', '2936', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2937', '1078', '1', 'Luanda', 'AO.10', 'NULL', '1060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1060', '112', '2937', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2938', '1078', '1', 'Malanje', 'AO.12', 'NULL', '1061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1061', '112', '2938', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2939', '1078', '1', 'Namibe', 'AO.13', 'NULL', '1062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1062', '112', '2939', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2940', '1078', '1', 'Moxico', 'AO.14', 'NULL', '1063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1063', '112', '2940', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2941', '1078', '1', 'Uíge', 'AO.15', 'NULL', '1064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1064', '112', '2941', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2942', '1078', '1', 'Zaire', 'AO.16', 'NULL', '1065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1065', '112', '2942', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2943', '1078', '1', 'Lunda Norte', 'AO.17', 'NULL', '1066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1066', '112', '2943', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2944', '1078', '1', 'Lunda Sul', 'AO.18', 'NULL', '1067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1067', '112', '2944', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2945', '1078', '1', 'Bengo', 'AO.19', 'NULL', '1068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1068', '112', '2945', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AO.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2946', '1078', '1', 'Antarctica (general)', 'AQ.00', 'NULL', '1069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1069', '112', '2946', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AQ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2947', '1078', '1', 'Argentina (general)', 'AR.00', 'NULL', '1070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1070', '112', '2947', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2948', '1078', '1', 'Buenos Aires', 'AR.01', 'NULL', '1071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1071', '112', '2948', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2949', '1078', '1', 'Catamarca', 'AR.02', 'NULL', '1072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1072', '112', '2949', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2950', '1078', '1', 'Chaco', 'AR.03', 'NULL', '1073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1073', '112', '2950', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2951', '1078', '1', 'Chubut', 'AR.04', 'NULL', '1074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1074', '112', '2951', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2952', '1078', '1', 'Córdoba', 'AR.05', 'NULL', '1075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1075', '112', '2952', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2953', '1078', '1', 'Corrientes', 'AR.06', 'NULL', '1076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1076', '112', '2953', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2954', '1078', '1', 'Distrito Federal', 'AR.07', 'NULL', '1077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1077', '112', '2954', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2955', '1078', '1', 'Entre Ríos', 'AR.08', 'NULL', '1078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1078', '112', '2955', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2956', '1078', '1', 'Formosa', 'AR.09', 'NULL', '1079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1079', '112', '2956', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2957', '1078', '1', 'Jujuy', 'AR.10', 'NULL', '1080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1080', '112', '2957', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2958', '1078', '1', 'La Pampa', 'AR.11', 'NULL', '1081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1081', '112', '2958', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2959', '1078', '1', 'La Rioja', 'AR.12', 'NULL', '1082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1082', '112', '2959', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2960', '1078', '1', 'Mendoza', 'AR.13', 'NULL', '1083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1083', '112', '2960', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2961', '1078', '1', 'Misiones', 'AR.14', 'NULL', '1084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1084', '112', '2961', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2962', '1078', '1', 'Neuquén', 'AR.15', 'NULL', '1085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1085', '112', '2962', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2963', '1078', '1', 'Río Negro', 'AR.16', 'NULL', '1086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1086', '112', '2963', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2964', '1078', '1', 'Salta', 'AR.17', 'NULL', '1087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1087', '112', '2964', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2965', '1078', '1', 'San Juan', 'AR.18', 'NULL', '1088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1088', '112', '2965', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2966', '1078', '1', 'San Luis', 'AR.19', 'NULL', '1089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1089', '112', '2966', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2967', '1078', '1', 'Santa Cruz', 'AR.20', 'NULL', '1090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1090', '112', '2967', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2968', '1078', '1', 'Santa Fe', 'AR.21', 'NULL', '1091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1091', '112', '2968', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2969', '1078', '1', 'Santiago del Estero', 'AR.22', 'NULL', '1092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1092', '112', '2969', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2970', '1078', '1', 'Tierra del Fuego, Antártida e Islas del Atlántico Sur', 'AR.23', 'NULL', '1093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1093', '112', '2970', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2971', '1078', '1', 'Tucumán', 'AR.24', 'NULL', '1094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1094', '112', '2971', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AR.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2972', '1078', '1', 'Austria (general)', 'AT.00', 'NULL', '1095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1095', '112', '2972', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AT.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2973', '1078', '1', 'Burgenland', 'AT.01', 'NULL', '1096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1096', '112', '2973', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AT.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2974', '1078', '1', 'Carinthia', 'AT.02', 'NULL', '1097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1097', '112', '2974', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AT.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2975', '1078', '1', 'Lower Austria', 'AT.03', 'NULL', '1098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1098', '112', '2975', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AT.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2976', '1078', '1', 'Upper Austria', 'AT.04', 'NULL', '1099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1099', '112', '2976', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AT.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2977', '1078', '1', 'Salzburg', 'AT.05', 'NULL', '1100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1100', '112', '2977', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AT.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2978', '1078', '1', 'Styria', 'AT.06', 'NULL', '1101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1101', '112', '2978', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AT.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2979', '1078', '1', 'Tyrol', 'AT.07', 'NULL', '1102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1102', '112', '2979', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AT.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2980', '1078', '1', 'Vorarlberg', 'AT.08', 'NULL', '1103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1103', '112', '2980', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AT.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2981', '1078', '1', 'Vienna', 'AT.09', 'NULL', '1104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1104', '112', '2981', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AT.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2982', '1078', '1', 'Heard Island and McDonald Islands (general)', 'AU.00', 'NULL', '1105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1105', '112', '2982', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AU.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2983', '1078', '1', 'Australian Capital Territory', 'AU.01', 'NULL', '1106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1106', '112', '2983', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AU.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2984', '1078', '1', 'New South Wales', 'AU.02', 'NULL', '1107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1107', '112', '2984', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AU.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2985', '1078', '1', 'Northern Territory', 'AU.03', 'NULL', '1108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1108', '112', '2985', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AU.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2986', '1078', '1', 'Queensland', 'AU.04', 'NULL', '1109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1109', '112', '2986', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AU.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2987', '1078', '1', 'South Australia', 'AU.05', 'NULL', '1110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1110', '112', '2987', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AU.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2988', '1078', '1', 'Tasmania', 'AU.06', 'NULL', '1111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1111', '112', '2988', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AU.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2989', '1078', '1', 'Victoria', 'AU.07', 'NULL', '1112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1112', '112', '2989', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AU.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2990', '1078', '1', 'Western Australia', 'AU.08', 'NULL', '1113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1113', '112', '2990', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AU.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2991', '1078', '1', 'Aruba (general)', 'AW.00', 'NULL', '1114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1114', '112', '2991', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AW.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2992', '1078', '1', 'Azerbaijan (general)', 'AZ.00', 'NULL', '1115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1115', '112', '2992', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2993', '1078', '1', 'Abşeron', 'AZ.01', 'NULL', '1116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1116', '112', '2993', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2994', '1078', '1', 'Ağcabǝdi', 'AZ.02', 'NULL', '1117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1117', '112', '2994', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2995', '1078', '1', 'Ağdam', 'AZ.03', 'NULL', '1118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1118', '112', '2995', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2996', '1078', '1', 'Ağdaş', 'AZ.04', 'NULL', '1119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1119', '112', '2996', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2997', '1078', '1', 'Ağstafa', 'AZ.05', 'NULL', '1120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1120', '112', '2997', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2998', '1078', '1', 'Ağsu', 'AZ.06', 'NULL', '1121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1121', '112', '2998', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('2999', '1078', '1', 'Əli Bayramli', 'AZ.07', 'NULL', '1122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1122', '112', '2999', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3000', '1078', '1', 'Astara', 'AZ.08', 'NULL', '1123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1123', '112', '3000', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3001', '1078', '1', 'Baki', 'AZ.09', 'NULL', '1124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1124', '112', '3001', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3002', '1078', '1', 'Balakǝn', 'AZ.10', 'NULL', '1125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1125', '112', '3002', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3003', '1078', '1', 'Bǝrdǝ', 'AZ.11', 'NULL', '1126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1126', '112', '3003', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3004', '1078', '1', 'Beylǝqan', 'AZ.12', 'NULL', '1127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1127', '112', '3004', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3005', '1078', '1', 'Bilǝsuvar', 'AZ.13', 'NULL', '1128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1128', '112', '3005', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3006', '1078', '1', 'Cǝbrayıl', 'AZ.14', 'NULL', '1129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1129', '112', '3006', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3007', '1078', '1', 'Cǝlilabad', 'AZ.15', 'NULL', '1130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1130', '112', '3007', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3008', '1078', '1', 'Daşkǝsǝn', 'AZ.16', 'NULL', '1131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1131', '112', '3008', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3009', '1078', '1', 'Dǝvǝçi', 'AZ.17', 'NULL', '1132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1132', '112', '3009', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3010', '1078', '1', 'Füzuli', 'AZ.18', 'NULL', '1133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1133', '112', '3010', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3011', '1078', '1', 'Gǝdǝbǝy', 'AZ.19', 'NULL', '1134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1134', '112', '3011', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3012', '1078', '1', 'Gǝncǝ', 'AZ.20', 'NULL', '1135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1135', '112', '3012', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3013', '1078', '1', 'Goranboy', 'AZ.21', 'NULL', '1136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1136', '112', '3013', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3014', '1078', '1', 'Göyçay', 'AZ.22', 'NULL', '1137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1137', '112', '3014', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3015', '1078', '1', 'Hacıqabul', 'AZ.23', 'NULL', '1138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1138', '112', '3015', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3016', '1078', '1', 'İmişli', 'AZ.24', 'NULL', '1139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1139', '112', '3016', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3017', '1078', '1', 'İsmayıllı', 'AZ.25', 'NULL', '1140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1140', '112', '3017', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3018', '1078', '1', 'Kǝlbǝcǝr', 'AZ.26', 'NULL', '1141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1141', '112', '3018', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3019', '1078', '1', 'Kürdǝmir', 'AZ.27', 'NULL', '1142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1142', '112', '3019', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3020', '1078', '1', 'Laçın', 'AZ.28', 'NULL', '1143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1143', '112', '3020', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3021', '1078', '1', 'Lǝnkǝran', 'AZ.29', 'NULL', '1144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1144', '112', '3021', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3022', '1078', '1', 'Lǝnkǝran Şǝhǝri', 'AZ.30', 'NULL', '1145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1145', '112', '3022', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3023', '1078', '1', 'Lerik', 'AZ.31', 'NULL', '1146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1146', '112', '3023', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3024', '1078', '1', 'Masallı', 'AZ.32', 'NULL', '1147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1147', '112', '3024', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3025', '1078', '1', 'Mingǝcevir', 'AZ.33', 'NULL', '1148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1148', '112', '3025', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3026', '1078', '1', 'Naftalan', 'AZ.34', 'NULL', '1149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1149', '112', '3026', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3027', '1078', '1', 'Nakhichevan', 'AZ.35', 'NULL', '1150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1150', '112', '3027', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3028', '1078', '1', 'Neftçala', 'AZ.36', 'NULL', '1151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1151', '112', '3028', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3029', '1078', '1', 'Oğuz', 'AZ.37', 'NULL', '1152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1152', '112', '3029', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3030', '1078', '1', 'Qǝbǝlǝ', 'AZ.38', 'NULL', '1153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1153', '112', '3030', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3031', '1078', '1', 'Qǝx', 'AZ.39', 'NULL', '1154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1154', '112', '3031', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3032', '1078', '1', 'Qazax', 'AZ.40', 'NULL', '1155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1155', '112', '3032', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3033', '1078', '1', 'Qobustan', 'AZ.41', 'NULL', '1156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1156', '112', '3033', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3034', '1078', '1', 'Quba', 'AZ.42', 'NULL', '1157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1157', '112', '3034', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3035', '1078', '1', 'Qubadlı', 'AZ.43', 'NULL', '1158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1158', '112', '3035', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3036', '1078', '1', 'Qusar', 'AZ.44', 'NULL', '1159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1159', '112', '3036', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3037', '1078', '1', 'Saatlı', 'AZ.45', 'NULL', '1160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1160', '112', '3037', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3038', '1078', '1', 'Sabirabad', 'AZ.46', 'NULL', '1161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1161', '112', '3038', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3039', '1078', '1', 'Şǝki', 'AZ.47', 'NULL', '1162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1162', '112', '3039', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3040', '1078', '1', 'Şǝki', 'AZ.48', 'NULL', '1163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1163', '112', '3040', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3041', '1078', '1', 'Salyan', 'AZ.49', 'NULL', '1164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1164', '112', '3041', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3042', '1078', '1', 'Şamaxı', 'AZ.50', 'NULL', '1165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1165', '112', '3042', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3043', '1078', '1', 'Şǝmkir', 'AZ.51', 'NULL', '1166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1166', '112', '3043', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3044', '1078', '1', 'Samux', 'AZ.52', 'NULL', '1167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1167', '112', '3044', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3045', '1078', '1', 'Siyǝzǝn', 'AZ.53', 'NULL', '1168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1168', '112', '3045', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3046', '1078', '1', 'Sumqayit', 'AZ.54', 'NULL', '1169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1169', '112', '3046', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3047', '1078', '1', 'Şuşa', 'AZ.55', 'NULL', '1170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1170', '112', '3047', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3048', '1078', '1', 'Şuşa Şəhəri', 'AZ.56', 'NULL', '1171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1171', '112', '3048', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3049', '1078', '1', 'Tǝrtǝr', 'AZ.57', 'NULL', '1172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1172', '112', '3049', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3050', '1078', '1', 'Tovuz', 'AZ.58', 'NULL', '1173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1173', '112', '3050', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3051', '1078', '1', 'Ucar', 'AZ.59', 'NULL', '1174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1174', '112', '3051', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3052', '1078', '1', 'Xaçmaz', 'AZ.60', 'NULL', '1175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1175', '112', '3052', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3053', '1078', '1', 'Xankǝndi', 'AZ.61', 'NULL', '1176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1176', '112', '3053', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3054', '1078', '1', 'Xanlar', 'AZ.62', 'NULL', '1177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1177', '112', '3054', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3055', '1078', '1', 'Xızı', 'AZ.63', 'NULL', '1178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1178', '112', '3055', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3056', '1078', '1', 'Xocalı', 'AZ.64', 'NULL', '1179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1179', '112', '3056', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3057', '1078', '1', 'Xocavǝnd', 'AZ.65', 'NULL', '1180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1180', '112', '3057', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3058', '1078', '1', 'Yardımlı', 'AZ.66', 'NULL', '1181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1181', '112', '3058', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3059', '1078', '1', 'Yevlax', 'AZ.67', 'NULL', '1182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1182', '112', '3059', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3060', '1078', '1', 'Yevlax', 'AZ.68', 'NULL', '1183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1183', '112', '3060', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3061', '1078', '1', 'Zǝngilan', 'AZ.69', 'NULL', '1184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1184', '112', '3061', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3062', '1078', '1', 'Zaqatala', 'AZ.70', 'NULL', '1185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1185', '112', '3062', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3063', '1078', '1', 'Zǝrdab', 'AZ.71', 'NULL', '1186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1186', '112', '3063', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «AZ.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3064', '1078', '1', 'Bosnia and Herzegovina (general)', 'BA.00', 'NULL', '1187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1187', '112', '3064', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3065', '1078', '1', 'Federation of Bosnia and Herzegovina', 'BA.01', 'NULL', '1188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1188', '112', '3065', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BA.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3066', '1078', '1', 'Republika Srpska', 'BA.02', 'NULL', '1189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1189', '112', '3066', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3067', '1078', '1', 'Brčko Distrikt', 'BA.BD', 'NULL', '1190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1190', '112', '3067', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BA.BD» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3068', '1078', '1', 'Barbados (general)', 'BB.00', 'NULL', '1191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1191', '112', '3068', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3069', '1078', '1', 'Christ Church', 'BB.01', 'NULL', '1192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1192', '112', '3069', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3070', '1078', '1', 'Saint Andrew', 'BB.02', 'NULL', '1193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1193', '112', '3070', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3071', '1078', '1', 'Saint George', 'BB.03', 'NULL', '1194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1194', '112', '3071', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3072', '1078', '1', 'Saint James', 'BB.04', 'NULL', '1195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1195', '112', '3072', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3073', '1078', '1', 'Saint John', 'BB.05', 'NULL', '1196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1196', '112', '3073', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3074', '1078', '1', 'Saint Joseph', 'BB.06', 'NULL', '1197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1197', '112', '3074', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3075', '1078', '1', 'Saint Lucy', 'BB.07', 'NULL', '1198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1198', '112', '3075', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3076', '1078', '1', 'Saint Michael', 'BB.08', 'NULL', '1199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1199', '112', '3076', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3077', '1078', '1', 'Saint Peter', 'BB.09', 'NULL', '1200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1200', '112', '3077', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3078', '1078', '1', 'Saint Philip', 'BB.10', 'NULL', '1201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1201', '112', '3078', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3079', '1078', '1', 'Saint Thomas', 'BB.11', 'NULL', '1202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1202', '112', '3079', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BB.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3080', '1078', '1', 'Bangladesh (general)', 'BD.00', 'NULL', '1203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1203', '112', '3080', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BD.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3081', '1078', '1', 'BG80', 'BD.80', 'NULL', '1204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1204', '112', '3081', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BD.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3082', '1078', '1', 'Dhaka', 'BD.81', 'NULL', '1205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1205', '112', '3082', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BD.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3083', '1078', '1', 'Khulna', 'BD.82', 'NULL', '1206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1206', '112', '3083', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BD.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3084', '1078', '1', 'Rājshāhi', 'BD.83', 'NULL', '1207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1207', '112', '3084', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BD.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3085', '1078', '1', 'Chittagong', 'BD.84', 'NULL', '1208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1208', '112', '3085', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BD.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3086', '1078', '1', 'Barisāl', 'BD.85', 'NULL', '1209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1209', '112', '3086', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BD.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3087', '1078', '1', 'Sylhet', 'BD.86', 'NULL', '1210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1210', '112', '3087', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BD.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3088', '1078', '1', 'Belgium (general)', 'BE.00', 'NULL', '1211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1211', '112', '3088', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3089', '1078', '1', 'Région de Bruxelles-Capitale', 'BE.BRU', 'NULL', '1212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1212', '112', '3089', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BE.BRU» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3090', '1078', '1', 'Flanders', 'BE.VLG', 'NULL', '1213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1213', '112', '3090', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BE.VLG» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3091', '1078', '1', 'Wallonia', 'BE.WAL', 'NULL', '1214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1214', '112', '3091', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BE.WAL» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3092', '1078', '1', 'Burkina Faso (general)', 'BF.00', 'NULL', '1215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1215', '112', '3092', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3093', '1078', '1', 'Boucle du Mouhoun', 'BF.01', 'NULL', '1216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1216', '112', '3093', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3094', '1078', '1', 'Cascades', 'BF.02', 'NULL', '1217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1217', '112', '3094', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3095', '1078', '1', 'Centre', 'BF.03', 'NULL', '1218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1218', '112', '3095', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3096', '1078', '1', 'Centre-Est', 'BF.04', 'NULL', '1219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1219', '112', '3096', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3097', '1078', '1', 'Centre-Nord', 'BF.05', 'NULL', '1220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1220', '112', '3097', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3098', '1078', '1', 'Centre-Ouest', 'BF.06', 'NULL', '1221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1221', '112', '3098', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3099', '1078', '1', 'Centre-Sud', 'BF.07', 'NULL', '1222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1222', '112', '3099', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3100', '1078', '1', 'Est', 'BF.08', 'NULL', '1223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1223', '112', '3100', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3101', '1078', '1', 'Hauts-Bassins', 'BF.09', 'NULL', '1224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1224', '112', '3101', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3102', '1078', '1', 'Nord', 'BF.10', 'NULL', '1225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1225', '112', '3102', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3103', '1078', '1', 'Plateau-Central', 'BF.11', 'NULL', '1226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1226', '112', '3103', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3104', '1078', '1', 'Sahel', 'BF.12', 'NULL', '1227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1227', '112', '3104', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3105', '1078', '1', 'Sud-Ouest', 'BF.13', 'NULL', '1228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1228', '112', '3105', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3106', '1078', '1', 'Bam', 'BF.15', 'NULL', '1229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1229', '112', '3106', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3107', '1078', '1', 'Boulkiemdé', 'BF.19', 'NULL', '1230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1230', '112', '3107', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3108', '1078', '1', 'Ganzourgou', 'BF.20', 'NULL', '1231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1231', '112', '3108', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3109', '1078', '1', 'Gnagna', 'BF.21', 'NULL', '1232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1232', '112', '3109', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3110', '1078', '1', 'Kouritenga', 'BF.28', 'NULL', '1233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1233', '112', '3110', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3111', '1078', '1', 'Oudalan', 'BF.33', 'NULL', '1234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1234', '112', '3111', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3112', '1078', '1', 'Passore', 'BF.34', 'NULL', '1235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1235', '112', '3112', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3113', '1078', '1', 'Sanguié', 'BF.36', 'NULL', '1236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1236', '112', '3113', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3114', '1078', '1', '(UV37)', 'BF.37', 'NULL', '1237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1237', '112', '3114', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3115', '1078', '1', '(UV38)', 'BF.38', 'NULL', '1238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1238', '112', '3115', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3116', '1078', '1', '(UV39)', 'BF.39', 'NULL', '1239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1239', '112', '3116', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3117', '1078', '1', 'Soum', 'BF.40', 'NULL', '1240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1240', '112', '3117', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3118', '1078', '1', '(UV41)', 'BF.41', 'NULL', '1241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1241', '112', '3118', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3119', '1078', '1', 'Tapoa', 'BF.42', 'NULL', '1242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1242', '112', '3119', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3120', '1078', '1', '(UV43)', 'BF.43', 'NULL', '1243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1243', '112', '3120', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3121', '1078', '1', 'Zoundwéogo', 'BF.44', 'NULL', '1244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1244', '112', '3121', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3122', '1078', '1', 'Banwa', 'BF.46', 'NULL', '1245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1245', '112', '3122', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3123', '1078', '1', 'Bazèga', 'BF.47', 'NULL', '1246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1246', '112', '3123', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3124', '1078', '1', 'Bougouriba', 'BF.48', 'NULL', '1247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1247', '112', '3124', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3125', '1078', '1', 'Boulgou', 'BF.49', 'NULL', '1248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1248', '112', '3125', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3126', '1078', '1', 'Gourma', 'BF.50', 'NULL', '1249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1249', '112', '3126', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3127', '1078', '1', 'Houet', 'BF.51', 'NULL', '1250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1250', '112', '3127', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3128', '1078', '1', 'Ioba', 'BF.52', 'NULL', '1251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1251', '112', '3128', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3129', '1078', '1', 'Kadiogo', 'BF.53', 'NULL', '1252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1252', '112', '3129', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3130', '1078', '1', 'Kènèdougou', 'BF.54', 'NULL', '1253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1253', '112', '3130', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3131', '1078', '1', 'Comoé', 'BF.55', 'NULL', '1254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1254', '112', '3131', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3132', '1078', '1', 'Komondjari', 'BF.56', 'NULL', '1255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1255', '112', '3132', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3133', '1078', '1', 'Kompienga', 'BF.57', 'NULL', '1256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1256', '112', '3133', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3134', '1078', '1', 'Kossi', 'BF.58', 'NULL', '1257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1257', '112', '3134', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3135', '1078', '1', 'Koulpélogo', 'BF.59', 'NULL', '1258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1258', '112', '3135', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3136', '1078', '1', 'Kourwéogo', 'BF.60', 'NULL', '1259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1259', '112', '3136', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3137', '1078', '1', 'Léraba', 'BF.61', 'NULL', '1260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1260', '112', '3137', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3138', '1078', '1', 'Loroum', 'BF.62', 'NULL', '1261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1261', '112', '3138', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3139', '1078', '1', 'Mouhoun', 'BF.63', 'NULL', '1262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1262', '112', '3139', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3140', '1078', '1', 'Namentenga', 'BF.64', 'NULL', '1263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1263', '112', '3140', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3141', '1078', '1', 'Nahouri', 'BF.65', 'NULL', '1264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1264', '112', '3141', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3142', '1078', '1', 'Nayala', 'BF.66', 'NULL', '1265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1265', '112', '3142', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3143', '1078', '1', 'Noumbiel', 'BF.67', 'NULL', '1266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1266', '112', '3143', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3144', '1078', '1', 'Oubritenga', 'BF.68', 'NULL', '1267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1267', '112', '3144', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3145', '1078', '1', 'Poni', 'BF.69', 'NULL', '1268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1268', '112', '3145', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3146', '1078', '1', 'Sanmatenga', 'BF.70', 'NULL', '1269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1269', '112', '3146', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3147', '1078', '1', 'Séno', 'BF.71', 'NULL', '1270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1270', '112', '3147', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3148', '1078', '1', 'Sissili', 'BF.72', 'NULL', '1271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1271', '112', '3148', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3149', '1078', '1', 'Sourou', 'BF.73', 'NULL', '1272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1272', '112', '3149', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3150', '1078', '1', 'Tuy', 'BF.74', 'NULL', '1273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1273', '112', '3150', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3151', '1078', '1', 'Yagha', 'BF.75', 'NULL', '1274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1274', '112', '3151', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.75» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3152', '1078', '1', 'Yatenga', 'BF.76', 'NULL', '1275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1275', '112', '3152', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3153', '1078', '1', 'Ziro', 'BF.77', 'NULL', '1276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1276', '112', '3153', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3154', '1078', '1', 'Zondoma', 'BF.78', 'NULL', '1277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1277', '112', '3154', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BF.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3155', '1078', '1', 'Bulgaria (general)', 'BG.00', 'NULL', '1278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1278', '112', '3155', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3156', '1078', '1', 'Burgas', 'BG.29', 'NULL', '1279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1279', '112', '3156', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3157', '1078', '1', 'Grad', 'BG.30', 'NULL', '1280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1280', '112', '3157', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3158', '1078', '1', 'Khaskovo', 'BG.31', 'NULL', '1281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1281', '112', '3158', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3159', '1078', '1', 'Lovech', 'BG.32', 'NULL', '1282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1282', '112', '3159', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3160', '1078', '1', 'Mikhaylovgrad', 'BG.33', 'NULL', '1283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1283', '112', '3160', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3161', '1078', '1', 'Plovdiv', 'BG.34', 'NULL', '1284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1284', '112', '3161', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3162', '1078', '1', 'Razgrad', 'BG.35', 'NULL', '1285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1285', '112', '3162', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3163', '1078', '1', 'Sofiya', 'BG.36', 'NULL', '1286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1286', '112', '3163', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3164', '1078', '1', 'Varna', 'BG.37', 'NULL', '1287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1287', '112', '3164', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3165', '1078', '1', 'Blagoevgrad', 'BG.38', 'NULL', '1288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1288', '112', '3165', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3166', '1078', '1', 'Burgas', 'BG.39', 'NULL', '1289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1289', '112', '3166', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3167', '1078', '1', 'Dobrich', 'BG.40', 'NULL', '1290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1290', '112', '3167', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3168', '1078', '1', 'Gabrovo', 'BG.41', 'NULL', '1291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1291', '112', '3168', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3169', '1078', '1', 'Oblast Sofiya-Grad', 'BG.42', 'NULL', '1292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1292', '112', '3169', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3170', '1078', '1', 'Khaskovo', 'BG.43', 'NULL', '1293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1293', '112', '3170', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3171', '1078', '1', 'Kŭrdzhali', 'BG.44', 'NULL', '1294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1294', '112', '3171', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3172', '1078', '1', 'Kyustendil', 'BG.45', 'NULL', '1295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1295', '112', '3172', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3173', '1078', '1', 'Lovech', 'BG.46', 'NULL', '1296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1296', '112', '3173', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3174', '1078', '1', 'Montana', 'BG.47', 'NULL', '1297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1297', '112', '3174', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3175', '1078', '1', 'Pazardzhit', 'BG.48', 'NULL', '1298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1298', '112', '3175', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3176', '1078', '1', 'Pernik', 'BG.49', 'NULL', '1299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1299', '112', '3176', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3177', '1078', '1', 'Pleven', 'BG.50', 'NULL', '1300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1300', '112', '3177', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3178', '1078', '1', 'Plovdiv', 'BG.51', 'NULL', '1301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1301', '112', '3178', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3179', '1078', '1', 'Razgrad', 'BG.52', 'NULL', '1302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1302', '112', '3179', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3180', '1078', '1', 'Ruse', 'BG.53', 'NULL', '1303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1303', '112', '3180', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3181', '1078', '1', 'Shumen', 'BG.54', 'NULL', '1304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1304', '112', '3181', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3182', '1078', '1', 'Silistra', 'BG.55', 'NULL', '1305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1305', '112', '3182', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3183', '1078', '1', 'Sliven', 'BG.56', 'NULL', '1306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1306', '112', '3183', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3184', '1078', '1', 'Smolyan', 'BG.57', 'NULL', '1307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1307', '112', '3184', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3185', '1078', '1', 'Sofiya', 'BG.58', 'NULL', '1308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1308', '112', '3185', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3186', '1078', '1', 'Stara Zagora', 'BG.59', 'NULL', '1309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1309', '112', '3186', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3187', '1078', '1', 'Tŭrgovishte', 'BG.60', 'NULL', '1310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1310', '112', '3187', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3188', '1078', '1', 'Varna', 'BG.61', 'NULL', '1311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1311', '112', '3188', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3189', '1078', '1', 'Veliko Tŭrnovo', 'BG.62', 'NULL', '1312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1312', '112', '3189', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3190', '1078', '1', 'Vidin', 'BG.63', 'NULL', '1313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1313', '112', '3190', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3191', '1078', '1', 'Vratsa', 'BG.64', 'NULL', '1314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1314', '112', '3191', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3192', '1078', '1', 'Yambol', 'BG.65', 'NULL', '1315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1315', '112', '3192', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BG.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3193', '1078', '1', 'Bahrain (general)', 'BH.00', 'NULL', '1316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1316', '112', '3193', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3194', '1078', '1', 'Hedd', 'BH.01', 'NULL', '1317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1317', '112', '3194', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3195', '1078', '1', 'Manama', 'BH.02', 'NULL', '1318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1318', '112', '3195', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3196', '1078', '1', 'Muharraq', 'BH.03', 'NULL', '1319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1319', '112', '3196', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3197', '1078', '1', 'Jidd Haffs', 'BH.05', 'NULL', '1320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1320', '112', '3197', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3198', '1078', '1', 'Sitra', 'BH.06', 'NULL', '1321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1321', '112', '3198', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3199', '1078', '1', '(BA07)', 'BH.07', 'NULL', '1322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1322', '112', '3199', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3200', '1078', '1', 'Western Region', 'BH.08', 'NULL', '1323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1323', '112', '3200', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3201', '1078', '1', 'Hawar Islands', 'BH.09', 'NULL', '1324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1324', '112', '3201', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3202', '1078', '1', 'Northern Region', 'BH.10', 'NULL', '1325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1325', '112', '3202', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3203', '1078', '1', 'Central Region', 'BH.11', 'NULL', '1326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1326', '112', '3203', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3204', '1078', '1', 'Isa Town', 'BH.12', 'NULL', '1327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1327', '112', '3204', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3205', '1078', '1', 'Ar Rifa’ and Southern Region', 'BH.13', 'NULL', '1328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1328', '112', '3205', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3206', '1078', '1', 'Hamad town', 'BH.14', 'NULL', '1329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1329', '112', '3206', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BH.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3207', '1078', '1', 'Burundi (general)', 'BI.00', 'NULL', '1330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1330', '112', '3207', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3208', '1078', '1', 'Bujumbura', 'BI.02', 'NULL', '1331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1331', '112', '3208', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3209', '1078', '1', '(BY05)', 'BI.05', 'NULL', '1332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1332', '112', '3209', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3210', '1078', '1', 'Bubanza', 'BI.09', 'NULL', '1333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1333', '112', '3210', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3211', '1078', '1', 'Bururi', 'BI.10', 'NULL', '1334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1334', '112', '3211', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3212', '1078', '1', 'Cankuzo', 'BI.11', 'NULL', '1335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1335', '112', '3212', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3213', '1078', '1', 'Cibitoke', 'BI.12', 'NULL', '1336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1336', '112', '3213', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3214', '1078', '1', 'Gitega', 'BI.13', 'NULL', '1337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1337', '112', '3214', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3215', '1078', '1', 'Karuzi', 'BI.14', 'NULL', '1338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1338', '112', '3215', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3216', '1078', '1', 'Kayanza', 'BI.15', 'NULL', '1339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1339', '112', '3216', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3217', '1078', '1', 'Kirundo', 'BI.16', 'NULL', '1340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1340', '112', '3217', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3218', '1078', '1', 'Makamba', 'BI.17', 'NULL', '1341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1341', '112', '3218', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3219', '1078', '1', 'Muyinga', 'BI.18', 'NULL', '1342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1342', '112', '3219', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3220', '1078', '1', 'Ngozi', 'BI.19', 'NULL', '1343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1343', '112', '3220', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3221', '1078', '1', 'Rutana', 'BI.20', 'NULL', '1344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1344', '112', '3221', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3222', '1078', '1', 'Ruyigi', 'BI.21', 'NULL', '1345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1345', '112', '3222', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3223', '1078', '1', 'Muramvya', 'BI.22', 'NULL', '1346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1346', '112', '3223', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3224', '1078', '1', 'Mwaro', 'BI.23', 'NULL', '1347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1347', '112', '3224', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BI.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3225', '1078', '1', 'Benin (general)', 'BJ.00', 'NULL', '1348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1348', '112', '3225', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3226', '1078', '1', 'Atakora', 'BJ.01', 'NULL', '1349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1349', '112', '3226', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3227', '1078', '1', 'Atlantique', 'BJ.02', 'NULL', '1350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1350', '112', '3227', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3228', '1078', '1', 'Borgou', 'BJ.03', 'NULL', '1351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1351', '112', '3228', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3229', '1078', '1', 'Mono', 'BJ.04', 'NULL', '1352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1352', '112', '3229', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3230', '1078', '1', 'Oueme', 'BJ.05', 'NULL', '1353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1353', '112', '3230', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3231', '1078', '1', 'Zou', 'BJ.06', 'NULL', '1354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1354', '112', '3231', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3232', '1078', '1', 'Alibori', 'BJ.07', 'NULL', '1355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1355', '112', '3232', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3233', '1078', '1', 'Atakora', 'BJ.08', 'NULL', '1356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1356', '112', '3233', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3234', '1078', '1', 'Atlantique', 'BJ.09', 'NULL', '1357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1357', '112', '3234', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3235', '1078', '1', 'Borgou', 'BJ.10', 'NULL', '1358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1358', '112', '3235', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3236', '1078', '1', 'Collines', 'BJ.11', 'NULL', '1359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1359', '112', '3236', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3237', '1078', '1', 'Kouffo', 'BJ.12', 'NULL', '1360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1360', '112', '3237', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3238', '1078', '1', 'Donga', 'BJ.13', 'NULL', '1361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1361', '112', '3238', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3239', '1078', '1', 'Littoral', 'BJ.14', 'NULL', '1362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1362', '112', '3239', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3240', '1078', '1', 'Mono', 'BJ.15', 'NULL', '1363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1363', '112', '3240', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3241', '1078', '1', 'Quémé', 'BJ.16', 'NULL', '1364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1364', '112', '3241', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3242', '1078', '1', 'Plateau', 'BJ.17', 'NULL', '1365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1365', '112', '3242', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3243', '1078', '1', 'Zou', 'BJ.18', 'NULL', '1366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1366', '112', '3243', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BJ.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3244', '1078', '1', 'Bermuda (general)', 'BM.00', 'NULL', '1367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1367', '112', '3244', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3245', '1078', '1', 'Devonshire', 'BM.01', 'NULL', '1368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1368', '112', '3245', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3246', '1078', '1', 'Hamilton Parish', 'BM.02', 'NULL', '1369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1369', '112', '3246', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3247', '1078', '1', 'Hamilton city', 'BM.03', 'NULL', '1370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1370', '112', '3247', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3248', '1078', '1', 'Paget', 'BM.04', 'NULL', '1371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1371', '112', '3248', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3249', '1078', '1', 'Pembroke', 'BM.05', 'NULL', '1372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1372', '112', '3249', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3250', '1078', '1', 'Saint George', 'BM.06', 'NULL', '1373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1373', '112', '3250', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3251', '1078', '1', 'Saint Georgeʼs', 'BM.07', 'NULL', '1374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1374', '112', '3251', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3252', '1078', '1', 'Sandys', 'BM.08', 'NULL', '1375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1375', '112', '3252', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3253', '1078', '1', 'Smithʼs', 'BM.09', 'NULL', '1376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1376', '112', '3253', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3254', '1078', '1', 'Southampton', 'BM.10', 'NULL', '1377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1377', '112', '3254', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3255', '1078', '1', 'Warwick', 'BM.11', 'NULL', '1378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1378', '112', '3255', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BM.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3256', '1078', '1', 'Brunei (general)', 'BN.00', 'NULL', '1379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1379', '112', '3256', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3257', '1078', '1', 'Belait', 'BN.01', 'NULL', '1380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1380', '112', '3257', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BN.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3258', '1078', '1', 'Brunei and Muara', 'BN.02', 'NULL', '1381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1381', '112', '3258', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BN.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3259', '1078', '1', 'Temburong', 'BN.03', 'NULL', '1382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1382', '112', '3259', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BN.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3260', '1078', '1', 'Tutong', 'BN.04', 'NULL', '1383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1383', '112', '3260', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BN.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3261', '1078', '1', 'Bolivia (general)', 'BO.00', 'NULL', '1384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1384', '112', '3261', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BO.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3262', '1078', '1', 'Chuquisaca', 'BO.01', 'NULL', '1385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1385', '112', '3262', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BO.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3263', '1078', '1', 'Cochabamba', 'BO.02', 'NULL', '1386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1386', '112', '3263', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BO.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3264', '1078', '1', 'El Beni', 'BO.03', 'NULL', '1387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1387', '112', '3264', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BO.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3265', '1078', '1', 'La Paz', 'BO.04', 'NULL', '1388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1388', '112', '3265', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BO.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3266', '1078', '1', 'Oruro', 'BO.05', 'NULL', '1389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1389', '112', '3266', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BO.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3267', '1078', '1', 'Pando', 'BO.06', 'NULL', '1390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1390', '112', '3267', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BO.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3268', '1078', '1', 'Potosí', 'BO.07', 'NULL', '1391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1391', '112', '3268', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BO.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3269', '1078', '1', 'Santa Cruz', 'BO.08', 'NULL', '1392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1392', '112', '3269', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BO.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3270', '1078', '1', 'Tarija', 'BO.09', 'NULL', '1393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1393', '112', '3270', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BO.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3271', '1078', '1', 'Brazil (general)', 'BR.00', 'NULL', '1394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1394', '112', '3271', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3272', '1078', '1', 'Acre', 'BR.01', 'NULL', '1395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1395', '112', '3272', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3273', '1078', '1', 'Alagoas', 'BR.02', 'NULL', '1396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1396', '112', '3273', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3274', '1078', '1', 'Amapá', 'BR.03', 'NULL', '1397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1397', '112', '3274', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3275', '1078', '1', 'Estado do Amazonas', 'BR.04', 'NULL', '1398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1398', '112', '3275', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3276', '1078', '1', 'Bahia', 'BR.05', 'NULL', '1399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1399', '112', '3276', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3277', '1078', '1', 'Ceará', 'BR.06', 'NULL', '1400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1400', '112', '3277', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3278', '1078', '1', 'Distrito Federal', 'BR.07', 'NULL', '1401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1401', '112', '3278', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3279', '1078', '1', 'Espírito Santo', 'BR.08', 'NULL', '1402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1402', '112', '3279', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3280', '1078', '1', 'Fernando de Noronha', 'BR.09', 'NULL', '1403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1403', '112', '3280', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3281', '1078', '1', 'Goias', 'BR.10', 'NULL', '1404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1404', '112', '3281', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3282', '1078', '1', 'Mato Grosso do Sul', 'BR.11', 'NULL', '1405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1405', '112', '3282', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3283', '1078', '1', 'Maranhão', 'BR.13', 'NULL', '1406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1406', '112', '3283', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3284', '1078', '1', 'Mato Grosso', 'BR.14', 'NULL', '1407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1407', '112', '3284', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3285', '1078', '1', 'Minas Gerais', 'BR.15', 'NULL', '1408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1408', '112', '3285', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3286', '1078', '1', 'Pará', 'BR.16', 'NULL', '1409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1409', '112', '3286', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3287', '1078', '1', 'Paraíba', 'BR.17', 'NULL', '1410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1410', '112', '3287', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3288', '1078', '1', 'Paraná', 'BR.18', 'NULL', '1411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1411', '112', '3288', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3289', '1078', '1', 'Pernambuco', 'BR.19', 'NULL', '1412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1412', '112', '3289', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3290', '1078', '1', 'Piauí', 'BR.20', 'NULL', '1413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1413', '112', '3290', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3291', '1078', '1', 'Rio de Janeiro', 'BR.21', 'NULL', '1414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1414', '112', '3291', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3292', '1078', '1', 'Rio Grande do Norte', 'BR.22', 'NULL', '1415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1415', '112', '3292', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3293', '1078', '1', 'Rio Grande do Sul', 'BR.23', 'NULL', '1416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1416', '112', '3293', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3294', '1078', '1', 'Rondônia', 'BR.24', 'NULL', '1417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1417', '112', '3294', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3295', '1078', '1', 'Roraima', 'BR.25', 'NULL', '1418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1418', '112', '3295', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3296', '1078', '1', 'Santa Catarina', 'BR.26', 'NULL', '1419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1419', '112', '3296', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3297', '1078', '1', 'São Paulo', 'BR.27', 'NULL', '1420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1420', '112', '3297', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3298', '1078', '1', 'Sergipe', 'BR.28', 'NULL', '1421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1421', '112', '3298', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3299', '1078', '1', 'Estado de Goiás', 'BR.29', 'NULL', '1422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1422', '112', '3299', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3300', '1078', '1', 'Pernambuco', 'BR.30', 'NULL', '1423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1423', '112', '3300', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3301', '1078', '1', 'Tocantins', 'BR.31', 'NULL', '1424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1424', '112', '3301', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BR.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3302', '1078', '1', 'Bahamas, The (general)', 'BS.00', 'NULL', '1425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1425', '112', '3302', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3303', '1078', '1', 'Bimini', 'BS.05', 'NULL', '1426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1426', '112', '3303', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3304', '1078', '1', 'Cat Island', 'BS.06', 'NULL', '1427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1427', '112', '3304', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3305', '1078', '1', 'Exuma', 'BS.10', 'NULL', '1428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1428', '112', '3305', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3306', '1078', '1', 'Inagua', 'BS.13', 'NULL', '1429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1429', '112', '3306', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3307', '1078', '1', 'Long Island', 'BS.15', 'NULL', '1430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1430', '112', '3307', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3308', '1078', '1', 'Mayaguana', 'BS.16', 'NULL', '1431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1431', '112', '3308', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3309', '1078', '1', 'Ragged Island', 'BS.18', 'NULL', '1432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1432', '112', '3309', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3310', '1078', '1', 'Harbour Island', 'BS.22', 'NULL', '1433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1433', '112', '3310', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3311', '1078', '1', 'New Providence', 'BS.23', 'NULL', '1434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1434', '112', '3311', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3312', '1078', '1', 'Acklins and Crooked Islands', 'BS.24', 'NULL', '1435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1435', '112', '3312', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3313', '1078', '1', 'Freeport', 'BS.25', 'NULL', '1436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1436', '112', '3313', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3314', '1078', '1', 'Fresh Creek', 'BS.26', 'NULL', '1437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1437', '112', '3314', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3315', '1078', '1', 'Governorʼs Harbour', 'BS.27', 'NULL', '1438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1438', '112', '3315', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3316', '1078', '1', 'Green Turtle Cay', 'BS.28', 'NULL', '1439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1439', '112', '3316', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3317', '1078', '1', 'High Rock', 'BS.29', 'NULL', '1440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1440', '112', '3317', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3318', '1078', '1', 'Kemps Bay', 'BS.30', 'NULL', '1441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1441', '112', '3318', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3319', '1078', '1', 'Marsh Harbour', 'BS.31', 'NULL', '1442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1442', '112', '3319', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3320', '1078', '1', 'Nichollstown and Berry Islands', 'BS.32', 'NULL', '1443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1443', '112', '3320', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3321', '1078', '1', 'Rock Sound', 'BS.33', 'NULL', '1444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1444', '112', '3321', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3322', '1078', '1', 'Sandy Point', 'BS.34', 'NULL', '1445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1445', '112', '3322', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3323', '1078', '1', 'San Salvador and Rum Cay', 'BS.35', 'NULL', '1446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1446', '112', '3323', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BS.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3324', '1078', '1', 'Bhutan (general)', 'BT.00', 'NULL', '1447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1447', '112', '3324', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3325', '1078', '1', 'Bumthang', 'BT.05', 'NULL', '1448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1448', '112', '3325', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3326', '1078', '1', 'Chhukha', 'BT.06', 'NULL', '1449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1449', '112', '3326', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3327', '1078', '1', 'Chirang', 'BT.07', 'NULL', '1450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1450', '112', '3327', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3328', '1078', '1', 'Daga', 'BT.08', 'NULL', '1451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1451', '112', '3328', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3329', '1078', '1', 'Geylegphug', 'BT.09', 'NULL', '1452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1452', '112', '3329', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3330', '1078', '1', 'Ha', 'BT.10', 'NULL', '1453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1453', '112', '3330', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3331', '1078', '1', 'Lhuntshi', 'BT.11', 'NULL', '1454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1454', '112', '3331', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3332', '1078', '1', 'Mongar', 'BT.12', 'NULL', '1455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1455', '112', '3332', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3333', '1078', '1', 'Paro District', 'BT.13', 'NULL', '1456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1456', '112', '3333', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3334', '1078', '1', 'Pemagatsel', 'BT.14', 'NULL', '1457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1457', '112', '3334', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3335', '1078', '1', 'Samchi', 'BT.16', 'NULL', '1458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1458', '112', '3335', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3336', '1078', '1', 'Samdrup Jongkhar District', 'BT.17', 'NULL', '1459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1459', '112', '3336', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3337', '1078', '1', 'Shemgang', 'BT.18', 'NULL', '1460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1460', '112', '3337', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3338', '1078', '1', 'Tashigang', 'BT.19', 'NULL', '1461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1461', '112', '3338', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3339', '1078', '1', 'Thimphu', 'BT.20', 'NULL', '1462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1462', '112', '3339', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3340', '1078', '1', 'Tongsa', 'BT.21', 'NULL', '1463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1463', '112', '3340', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3341', '1078', '1', 'Wangdi Phodrang', 'BT.22', 'NULL', '1464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1464', '112', '3341', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BT.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3342', '1078', '1', 'Botswana (general)', 'BW.00', 'NULL', '1465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1465', '112', '3342', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3343', '1078', '1', 'Central', 'BW.01', 'NULL', '1466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1466', '112', '3343', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3344', '1078', '1', 'Chobe', 'BW.02', 'NULL', '1467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1467', '112', '3344', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3345', '1078', '1', 'Ghanzi', 'BW.03', 'NULL', '1468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1468', '112', '3345', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3346', '1078', '1', 'Kgalagadi', 'BW.04', 'NULL', '1469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1469', '112', '3346', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3347', '1078', '1', 'Kgatleng', 'BW.05', 'NULL', '1470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1470', '112', '3347', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3348', '1078', '1', 'Kweneng', 'BW.06', 'NULL', '1471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1471', '112', '3348', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3349', '1078', '1', 'Ngamiland', 'BW.07', 'NULL', '1472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1472', '112', '3349', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3350', '1078', '1', 'North East', 'BW.08', 'NULL', '1473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1473', '112', '3350', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3351', '1078', '1', 'South East', 'BW.09', 'NULL', '1474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1474', '112', '3351', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3352', '1078', '1', 'Southern', 'BW.10', 'NULL', '1475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1475', '112', '3352', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3353', '1078', '1', 'North West', 'BW.11', 'NULL', '1476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1476', '112', '3353', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BW.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3354', '1078', '1', 'Belarus (general)', 'BY.00', 'NULL', '1477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1477', '112', '3354', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BY.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3355', '1078', '1', 'Brestskaya Voblastsʼ', 'BY.01', 'NULL', '1478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1478', '112', '3355', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BY.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3356', '1078', '1', 'Homyelʼskaya Voblastsʼ', 'BY.02', 'NULL', '1479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1479', '112', '3356', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BY.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3357', '1078', '1', 'Hrodzyenskaya Voblastsʼ', 'BY.03', 'NULL', '1480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1480', '112', '3357', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BY.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3358', '1078', '1', 'Mahilyowskaya Voblastsʼ', 'BY.04', 'NULL', '1481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1481', '112', '3358', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BY.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3359', '1078', '1', 'Horad Minsk', 'BY.05', 'NULL', '1482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1482', '112', '3359', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BY.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3360', '1078', '1', 'Minskaya Voblastsʼ', 'BY.06', 'NULL', '1483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1483', '112', '3360', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BY.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3361', '1078', '1', 'Vitsyebskaya Voblastsʼ', 'BY.07', 'NULL', '1484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1484', '112', '3361', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BY.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3362', '1078', '1', 'Belize (general)', 'BZ.00', 'NULL', '1485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1485', '112', '3362', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BZ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3363', '1078', '1', 'Belize', 'BZ.01', 'NULL', '1486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1486', '112', '3363', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BZ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3364', '1078', '1', 'Cayo', 'BZ.02', 'NULL', '1487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1487', '112', '3364', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BZ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3365', '1078', '1', 'Corozal', 'BZ.03', 'NULL', '1488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1488', '112', '3365', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BZ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3366', '1078', '1', 'Orange Walk', 'BZ.04', 'NULL', '1489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1489', '112', '3366', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BZ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3367', '1078', '1', 'Stann Creek', 'BZ.05', 'NULL', '1490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1490', '112', '3367', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BZ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3368', '1078', '1', 'Toledo', 'BZ.06', 'NULL', '1491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1491', '112', '3368', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «BZ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3369', '1078', '1', 'Canada (general)', 'CA.00', 'NULL', '1492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1492', '112', '3369', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3370', '1078', '1', 'Alberta', 'CA.01', 'NULL', '1493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1493', '112', '3370', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3371', '1078', '1', 'British Columbia', 'CA.02', 'NULL', '1494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1494', '112', '3371', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3372', '1078', '1', 'Manitoba', 'CA.03', 'NULL', '1495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1495', '112', '3372', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3373', '1078', '1', 'New Brunswick', 'CA.04', 'NULL', '1496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1496', '112', '3373', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3374', '1078', '1', 'Newfoundland and Labrador', 'CA.05', 'NULL', '1497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1497', '112', '3374', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3375', '1078', '1', 'Nova Scotia', 'CA.07', 'NULL', '1498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1498', '112', '3375', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3376', '1078', '1', 'Ontario', 'CA.08', 'NULL', '1499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1499', '112', '3376', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3377', '1078', '1', 'Prince Edward Island', 'CA.09', 'NULL', '1500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1500', '112', '3377', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3378', '1078', '1', 'Quebec', 'CA.10', 'NULL', '1501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1501', '112', '3378', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3379', '1078', '1', 'Saskatchewan', 'CA.11', 'NULL', '1502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1502', '112', '3379', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3380', '1078', '1', 'Yukon', 'CA.12', 'NULL', '1503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1503', '112', '3380', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3381', '1078', '1', 'Northwest Territories', 'CA.13', 'NULL', '1504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1504', '112', '3381', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3382', '1078', '1', 'Nunavut', 'CA.14', 'NULL', '1505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1505', '112', '3382', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CA.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3383', '1078', '1', 'Cocos (Keeling) Islands (general)', 'CC.00', 'NULL', '1506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1506', '112', '3383', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CC.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3384', '1078', '1', 'Congo, Democratic Republic of The (general)', 'CD.00', 'NULL', '1507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1507', '112', '3384', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3385', '1078', '1', 'Bandundu', 'CD.01', 'NULL', '1508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1508', '112', '3385', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3386', '1078', '1', 'Équateur', 'CD.02', 'NULL', '1509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1509', '112', '3386', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3387', '1078', '1', 'Kasaï-Occidental', 'CD.03', 'NULL', '1510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1510', '112', '3387', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3388', '1078', '1', 'Kasaï-Oriental', 'CD.04', 'NULL', '1511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1511', '112', '3388', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3389', '1078', '1', 'Katanga', 'CD.05', 'NULL', '1512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1512', '112', '3389', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3390', '1078', '1', 'Kinshasa', 'CD.06', 'NULL', '1513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1513', '112', '3390', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3391', '1078', '1', 'Kivu Région du', 'CD.07', 'NULL', '1514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1514', '112', '3391', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3392', '1078', '1', 'Bas-Congo', 'CD.08', 'NULL', '1515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1515', '112', '3392', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3393', '1078', '1', 'Orientale', 'CD.09', 'NULL', '1516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1516', '112', '3393', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3394', '1078', '1', 'Maniema', 'CD.10', 'NULL', '1517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1517', '112', '3394', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3395', '1078', '1', 'Nord-Kivu', 'CD.11', 'NULL', '1518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1518', '112', '3395', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3396', '1078', '1', 'Sud-Kivu', 'CD.12', 'NULL', '1519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1519', '112', '3396', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CD.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3397', '1078', '1', 'Central African Republic (general)', 'CF.00', 'NULL', '1520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1520', '112', '3397', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3398', '1078', '1', 'Bamingui-Bangoran', 'CF.01', 'NULL', '1521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1521', '112', '3398', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3399', '1078', '1', 'Basse-Kotto', 'CF.02', 'NULL', '1522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1522', '112', '3399', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3400', '1078', '1', 'Haute-Kotto', 'CF.03', 'NULL', '1523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1523', '112', '3400', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3401', '1078', '1', 'Mambéré-Kadéï', 'CF.04', 'NULL', '1524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1524', '112', '3401', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3402', '1078', '1', 'Haut-Mbomou', 'CF.05', 'NULL', '1525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1525', '112', '3402', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3403', '1078', '1', 'Kémo', 'CF.06', 'NULL', '1526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1526', '112', '3403', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3404', '1078', '1', 'Lobaye', 'CF.07', 'NULL', '1527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1527', '112', '3404', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3405', '1078', '1', 'Mbomou', 'CF.08', 'NULL', '1528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1528', '112', '3405', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3406', '1078', '1', 'Nana-Mambéré', 'CF.09', 'NULL', '1529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1529', '112', '3406', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3407', '1078', '1', 'Ouaka', 'CF.11', 'NULL', '1530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1530', '112', '3407', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3408', '1078', '1', 'Ouham', 'CF.12', 'NULL', '1531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1531', '112', '3408', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3409', '1078', '1', 'Ouham-Pendé', 'CF.13', 'NULL', '1532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1532', '112', '3409', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3410', '1078', '1', 'Vakaga', 'CF.14', 'NULL', '1533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1533', '112', '3410', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3411', '1078', '1', 'Nana-Grébizi', 'CF.15', 'NULL', '1534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1534', '112', '3411', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3412', '1078', '1', 'Sangha-Mbaéré', 'CF.16', 'NULL', '1535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1535', '112', '3412', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3413', '1078', '1', 'Ombella-Mpoko', 'CF.17', 'NULL', '1536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1536', '112', '3413', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3414', '1078', '1', 'Bangui', 'CF.18', 'NULL', '1537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1537', '112', '3414', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CF.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3415', '1078', '1', 'Congo (general)', 'CG.00', 'NULL', '1538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1538', '112', '3415', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3416', '1078', '1', 'Bouenza', 'CG.01', 'NULL', '1539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1539', '112', '3416', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3417', '1078', '1', 'CF03', 'CG.03', 'NULL', '1540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1540', '112', '3417', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3418', '1078', '1', 'Kouilou', 'CG.04', 'NULL', '1541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1541', '112', '3418', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3419', '1078', '1', 'Lékoumou', 'CG.05', 'NULL', '1542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1542', '112', '3419', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3420', '1078', '1', 'Likouala', 'CG.06', 'NULL', '1543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1543', '112', '3420', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3421', '1078', '1', 'Niari', 'CG.07', 'NULL', '1544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1544', '112', '3421', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3422', '1078', '1', 'Plateaux', 'CG.08', 'NULL', '1545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1545', '112', '3422', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3423', '1078', '1', 'Sangha', 'CG.10', 'NULL', '1546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1546', '112', '3423', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3424', '1078', '1', 'Pool', 'CG.11', 'NULL', '1547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1547', '112', '3424', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3425', '1078', '1', 'Brazzaville', 'CG.12', 'NULL', '1548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1548', '112', '3425', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3426', '1078', '1', 'Cuvette', 'CG.13', 'NULL', '1549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1549', '112', '3426', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3427', '1078', '1', 'Cuvette-Ouest', 'CG.14', 'NULL', '1550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1550', '112', '3427', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CG.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3428', '1078', '1', 'Switzerland (general)', 'CH.00', 'NULL', '1551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1551', '112', '3428', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3429', '1078', '1', 'Aargau', 'CH.AG', 'NULL', '1552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1552', '112', '3429', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.AG» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3430', '1078', '1', 'Appenzell Innerrhoden', 'CH.AI', 'NULL', '1553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1553', '112', '3430', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.AI» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3431', '1078', '1', 'Appenzell Ausserrhoden', 'CH.AR', 'NULL', '1554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1554', '112', '3431', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.AR» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3432', '1078', '1', 'Bern', 'CH.BE', 'NULL', '1555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1555', '112', '3432', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.BE» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3433', '1078', '1', 'Basel-Landschaft', 'CH.BL', 'NULL', '1556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1556', '112', '3433', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.BL» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3434', '1078', '1', 'Basel-Stadt', 'CH.BS', 'NULL', '1557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1557', '112', '3434', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.BS» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3435', '1078', '1', 'Fribourg', 'CH.FR', 'NULL', '1558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1558', '112', '3435', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.FR» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3436', '1078', '1', 'Genève', 'CH.GE', 'NULL', '1559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1559', '112', '3436', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.GE» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3437', '1078', '1', 'Glarus', 'CH.GL', 'NULL', '1560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1560', '112', '3437', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.GL» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3438', '1078', '1', 'Graubünden', 'CH.GR', 'NULL', '1561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1561', '112', '3438', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.GR» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3439', '1078', '1', 'Jura', 'CH.JU', 'NULL', '1562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1562', '112', '3439', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.JU» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3440', '1078', '1', 'Luzern', 'CH.LU', 'NULL', '1563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1563', '112', '3440', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.LU» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3441', '1078', '1', 'Neuchâtel', 'CH.NE', 'NULL', '1564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1564', '112', '3441', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.NE» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3442', '1078', '1', 'Nidwalden', 'CH.NW', 'NULL', '1565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1565', '112', '3442', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.NW» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3443', '1078', '1', 'Obwalden', 'CH.OW', 'NULL', '1566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1566', '112', '3443', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.OW» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3444', '1078', '1', 'Kanton St. Gallen', 'CH.SG', 'NULL', '1567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1567', '112', '3444', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.SG» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3445', '1078', '1', 'Schaffhausen', 'CH.SH', 'NULL', '1568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1568', '112', '3445', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.SH» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3446', '1078', '1', 'Solothurn', 'CH.SO', 'NULL', '1569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1569', '112', '3446', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.SO» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3447', '1078', '1', 'Schwyz', 'CH.SZ', 'NULL', '1570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1570', '112', '3447', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.SZ» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3448', '1078', '1', 'Thurgau', 'CH.TG', 'NULL', '1571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1571', '112', '3448', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.TG» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3449', '1078', '1', 'Ticino', 'CH.TI', 'NULL', '1572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1572', '112', '3449', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.TI» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3450', '1078', '1', 'Uri', 'CH.UR', 'NULL', '1573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1573', '112', '3450', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.UR» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3451', '1078', '1', 'Vaud', 'CH.VD', 'NULL', '1574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1574', '112', '3451', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.VD» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3452', '1078', '1', 'Valais', 'CH.VS', 'NULL', '1575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1575', '112', '3452', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.VS» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3453', '1078', '1', 'Zug', 'CH.ZG', 'NULL', '1576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1576', '112', '3453', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.ZG» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3454', '1078', '1', 'Zürich', 'CH.ZH', 'NULL', '1577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1577', '112', '3454', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CH.ZH» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3455', '1078', '1', 'Côte dʼIvoire (general)', 'CI.00', 'NULL', '1578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1578', '112', '3455', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3456', '1078', '1', 'Valparaíso Region', 'CI.01', 'NULL', '1579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1579', '112', '3456', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3457', '1078', '1', 'Antofagasta Region', 'CI.03', 'NULL', '1580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1580', '112', '3457', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3458', '1078', '1', 'Araucanía Region', 'CI.04', 'NULL', '1581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1581', '112', '3458', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3459', '1078', '1', 'Atacama Region', 'CI.05', 'NULL', '1582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1582', '112', '3459', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3460', '1078', '1', 'Biobío Region', 'CI.06', 'NULL', '1583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1583', '112', '3460', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3461', '1078', '1', 'Coquimbo Region', 'CI.07', 'NULL', '1584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1584', '112', '3461', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3462', '1078', '1', 'Maule Region', 'CI.11', 'NULL', '1585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1585', '112', '3462', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3463', '1078', '1', 'Santiago Metropolitan Region', 'CI.12', 'NULL', '1586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1586', '112', '3463', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3464', '1078', '1', 'Danane', 'CI.14', 'NULL', '1587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1587', '112', '3464', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3465', '1078', '1', 'Divo', 'CI.16', 'NULL', '1588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1588', '112', '3465', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3466', '1078', '1', 'Ferkessedougou', 'CI.17', 'NULL', '1589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1589', '112', '3466', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3467', '1078', '1', 'Gagnoa', 'CI.18', 'NULL', '1590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1590', '112', '3467', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3468', '1078', '1', 'Katiola', 'CI.20', 'NULL', '1591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1591', '112', '3468', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3469', '1078', '1', 'Korhogo', 'CI.21', 'NULL', '1592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1592', '112', '3469', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3470', '1078', '1', 'Odienne', 'CI.23', 'NULL', '1593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1593', '112', '3470', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3471', '1078', '1', 'Seguela', 'CI.25', 'NULL', '1594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1594', '112', '3471', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3472', '1078', '1', 'Touba', 'CI.26', 'NULL', '1595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1595', '112', '3472', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3473', '1078', '1', 'Bongouanou', 'CI.27', 'NULL', '1596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1596', '112', '3473', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3474', '1078', '1', 'Issia', 'CI.28', 'NULL', '1597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1597', '112', '3474', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3475', '1078', '1', 'Lakota', 'CI.29', 'NULL', '1598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1598', '112', '3475', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3476', '1078', '1', 'Mankono', 'CI.30', 'NULL', '1599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1599', '112', '3476', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3477', '1078', '1', 'Oume', 'CI.31', 'NULL', '1600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1600', '112', '3477', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3478', '1078', '1', 'Soubre', 'CI.32', 'NULL', '1601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1601', '112', '3478', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3479', '1078', '1', 'Tingrela', 'CI.33', 'NULL', '1602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1602', '112', '3479', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3480', '1078', '1', 'Zuenoula', 'CI.34', 'NULL', '1603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1603', '112', '3480', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3481', '1078', '1', '(IV35)', 'CI.35', 'NULL', '1604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1604', '112', '3481', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3482', '1078', '1', 'Bangolo', 'CI.36', 'NULL', '1605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1605', '112', '3482', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3483', '1078', '1', 'Beoumi', 'CI.37', 'NULL', '1606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1606', '112', '3483', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3484', '1078', '1', 'Bondoukou', 'CI.38', 'NULL', '1607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1607', '112', '3484', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3485', '1078', '1', 'Bouafle', 'CI.39', 'NULL', '1608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1608', '112', '3485', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3486', '1078', '1', 'Bouake', 'CI.40', 'NULL', '1609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1609', '112', '3486', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3487', '1078', '1', 'Daloa', 'CI.41', 'NULL', '1610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1610', '112', '3487', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3488', '1078', '1', 'Daoukro', 'CI.42', 'NULL', '1611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1611', '112', '3488', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3489', '1078', '1', '(IV43)', 'CI.43', 'NULL', '1612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1612', '112', '3489', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3490', '1078', '1', 'Duekoue', 'CI.44', 'NULL', '1613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1613', '112', '3490', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3491', '1078', '1', 'Grand-Lahou', 'CI.45', 'NULL', '1614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1614', '112', '3491', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3492', '1078', '1', '(IV46)', 'CI.46', 'NULL', '1615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1615', '112', '3492', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3493', '1078', '1', 'Man', 'CI.47', 'NULL', '1616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1616', '112', '3493', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3494', '1078', '1', 'Mbahiakro', 'CI.48', 'NULL', '1617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1617', '112', '3494', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3495', '1078', '1', 'Sakassou', 'CI.49', 'NULL', '1618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1618', '112', '3495', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3496', '1078', '1', 'San Pedro', 'CI.50', 'NULL', '1619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1619', '112', '3496', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3497', '1078', '1', 'Sassandra', 'CI.51', 'NULL', '1620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1620', '112', '3497', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3498', '1078', '1', 'Sinfra', 'CI.52', 'NULL', '1621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1621', '112', '3498', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3499', '1078', '1', 'Tabou', 'CI.53', 'NULL', '1622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1622', '112', '3499', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3500', '1078', '1', 'Tanda', 'CI.54', 'NULL', '1623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1623', '112', '3500', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3501', '1078', '1', 'Tiassale', 'CI.55', 'NULL', '1624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1624', '112', '3501', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3502', '1078', '1', 'Toumodi', 'CI.56', 'NULL', '1625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1625', '112', '3502', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3503', '1078', '1', 'Vavoua', 'CI.57', 'NULL', '1626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1626', '112', '3503', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3504', '1078', '1', '(IV58)', 'CI.58', 'NULL', '1627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1627', '112', '3504', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3505', '1078', '1', '(IV59)', 'CI.59', 'NULL', '1628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1628', '112', '3505', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3506', '1078', '1', '(IV60)', 'CI.60', 'NULL', '1629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1629', '112', '3506', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3507', '1078', '1', 'Abidjan', 'CI.61', 'NULL', '1630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1630', '112', '3507', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3508', '1078', '1', 'Aboisso', 'CI.62', 'NULL', '1631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1631', '112', '3508', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3509', '1078', '1', 'Adiake', 'CI.63', 'NULL', '1632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1632', '112', '3509', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3510', '1078', '1', 'Alepe', 'CI.64', 'NULL', '1633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1633', '112', '3510', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3511', '1078', '1', 'Bocanda', 'CI.65', 'NULL', '1634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1634', '112', '3511', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3512', '1078', '1', 'Dabou', 'CI.66', 'NULL', '1635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1635', '112', '3512', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3513', '1078', '1', 'Dimbokro', 'CI.67', 'NULL', '1636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1636', '112', '3513', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3514', '1078', '1', 'Grand-Bassam', 'CI.68', 'NULL', '1637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1637', '112', '3514', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3515', '1078', '1', 'Guiglo', 'CI.69', 'NULL', '1638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1638', '112', '3515', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3516', '1078', '1', 'Jacqueville', 'CI.70', 'NULL', '1639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1639', '112', '3516', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3517', '1078', '1', 'Tiebissou', 'CI.71', 'NULL', '1640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1640', '112', '3517', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3518', '1078', '1', 'Toulepleu', 'CI.72', 'NULL', '1641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1641', '112', '3518', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3519', '1078', '1', 'Yamoussoukro', 'CI.73', 'NULL', '1642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1642', '112', '3519', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3520', '1078', '1', 'Agnéby', 'CI.74', 'NULL', '1643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1643', '112', '3520', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3521', '1078', '1', 'Bafing', 'CI.75', 'NULL', '1644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1644', '112', '3521', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.75» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3522', '1078', '1', 'Bas-Sassandra', 'CI.76', 'NULL', '1645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1645', '112', '3522', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3523', '1078', '1', 'Denguélé', 'CI.77', 'NULL', '1646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1646', '112', '3523', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3524', '1078', '1', 'Dix-Huit Montagnes', 'CI.78', 'NULL', '1647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1647', '112', '3524', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3525', '1078', '1', 'Fromager', 'CI.79', 'NULL', '1648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1648', '112', '3525', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3526', '1078', '1', 'Haut-Sassandra', 'CI.80', 'NULL', '1649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1649', '112', '3526', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3527', '1078', '1', 'Lacs', 'CI.81', 'NULL', '1650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1650', '112', '3527', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3528', '1078', '1', 'Lagunes', 'CI.82', 'NULL', '1651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1651', '112', '3528', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3529', '1078', '1', 'Marahoué', 'CI.83', 'NULL', '1652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1652', '112', '3529', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3530', '1078', '1', 'Moyen-Cavally', 'CI.84', 'NULL', '1653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1653', '112', '3530', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3531', '1078', '1', 'Moyen-Comoé', 'CI.85', 'NULL', '1654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1654', '112', '3531', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3532', '1078', '1', 'Nʼzi-Comoé', 'CI.86', 'NULL', '1655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1655', '112', '3532', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3533', '1078', '1', 'Savanes', 'CI.87', 'NULL', '1656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1656', '112', '3533', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.87» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3534', '1078', '1', 'Sud-Bandama', 'CI.88', 'NULL', '1657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1657', '112', '3534', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.88» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3535', '1078', '1', 'Sud-Comoé', 'CI.89', 'NULL', '1658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1658', '112', '3535', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.89» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3536', '1078', '1', 'Vallée du Bandama', 'CI.90', 'NULL', '1659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1659', '112', '3536', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.90» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3537', '1078', '1', 'Worodougou', 'CI.91', 'NULL', '1660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1660', '112', '3537', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.91» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3538', '1078', '1', 'Zanzan', 'CI.92', 'NULL', '1661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1661', '112', '3538', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CI.92» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3539', '1078', '1', 'Cook Islands (general)', 'CK.00', 'NULL', '1662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1662', '112', '3539', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CK.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3540', '1078', '1', 'Chile (general)', 'CL.00', 'NULL', '1663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1663', '112', '3540', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3541', '1078', '1', 'Valparaíso', 'CL.01', 'NULL', '1664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1664', '112', '3541', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3542', '1078', '1', 'Aisén del General Carlos Ibáñez del Campo', 'CL.02', 'NULL', '1665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1665', '112', '3542', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3543', '1078', '1', 'Antofagasta', 'CL.03', 'NULL', '1666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1666', '112', '3543', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3544', '1078', '1', 'Araucanía', 'CL.04', 'NULL', '1667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1667', '112', '3544', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3545', '1078', '1', 'Atacama', 'CL.05', 'NULL', '1668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1668', '112', '3545', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3546', '1078', '1', 'Bío-Bío', 'CL.06', 'NULL', '1669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1669', '112', '3546', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3547', '1078', '1', 'Coquimbo', 'CL.07', 'NULL', '1670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1670', '112', '3547', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3548', '1078', '1', 'Libertador General Bernardo OʼHiggins', 'CL.08', 'NULL', '1671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1671', '112', '3548', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3549', '1078', '1', 'Magallanes y Antártica Chilena', 'CL.10', 'NULL', '1672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1672', '112', '3549', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3550', '1078', '1', 'Maule', 'CL.11', 'NULL', '1673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1673', '112', '3550', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3551', '1078', '1', 'Región Metropolitana', 'CL.12', 'NULL', '1674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1674', '112', '3551', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CL.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3552', '1078', '1', 'Cameroon (general)', 'CM.00', 'NULL', '1675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1675', '112', '3552', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3553', '1078', '1', 'Est', 'CM.04', 'NULL', '1676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1676', '112', '3553', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3554', '1078', '1', 'Littoral', 'CM.05', 'NULL', '1677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1677', '112', '3554', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3555', '1078', '1', 'North-West Province', 'CM.07', 'NULL', '1678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1678', '112', '3555', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3556', '1078', '1', 'Ouest', 'CM.08', 'NULL', '1679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1679', '112', '3556', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3557', '1078', '1', 'South-West Province', 'CM.09', 'NULL', '1680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1680', '112', '3557', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3558', '1078', '1', 'Adamaoua', 'CM.10', 'NULL', '1681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1681', '112', '3558', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3559', '1078', '1', 'Centre', 'CM.11', 'NULL', '1682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1682', '112', '3559', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3560', '1078', '1', 'Extreme-Nord', 'CM.12', 'NULL', '1683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1683', '112', '3560', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3561', '1078', '1', 'North Province', 'CM.13', 'NULL', '1684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1684', '112', '3561', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3562', '1078', '1', 'South Province', 'CM.14', 'NULL', '1685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1685', '112', '3562', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CM.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3563', '1078', '1', 'Paracel Islands (general)', 'CN.00', 'NULL', '1686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1686', '112', '3563', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3564', '1078', '1', 'Anhui', 'CN.01', 'NULL', '1687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1687', '112', '3564', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3565', '1078', '1', 'Zhejiang', 'CN.02', 'NULL', '1688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1688', '112', '3565', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3566', '1078', '1', 'Jiangxi', 'CN.03', 'NULL', '1689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1689', '112', '3566', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3567', '1078', '1', 'Jiangsu', 'CN.04', 'NULL', '1690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1690', '112', '3567', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3568', '1078', '1', 'Jilin', 'CN.05', 'NULL', '1691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1691', '112', '3568', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3569', '1078', '1', 'Qinghai', 'CN.06', 'NULL', '1692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1692', '112', '3569', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3570', '1078', '1', 'Fujian', 'CN.07', 'NULL', '1693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1693', '112', '3570', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3571', '1078', '1', 'Heilongjiang', 'CN.08', 'NULL', '1694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1694', '112', '3571', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3572', '1078', '1', 'Henan', 'CN.09', 'NULL', '1695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1695', '112', '3572', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3573', '1078', '1', 'disputed', 'CN.0Z', 'NULL', '1696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1696', '112', '3573', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.0Z» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3574', '1078', '1', 'Hebei', 'CN.10', 'NULL', '1697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1697', '112', '3574', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3575', '1078', '1', 'Hunan Province', 'CN.11', 'NULL', '1698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1698', '112', '3575', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3576', '1078', '1', 'Hubei', 'CN.12', 'NULL', '1699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1699', '112', '3576', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3577', '1078', '1', 'Xinjiang', 'CN.13', 'NULL', '1700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1700', '112', '3577', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3578', '1078', '1', 'Xizang', 'CN.14', 'NULL', '1701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1701', '112', '3578', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3579', '1078', '1', 'Gansu', 'CN.15', 'NULL', '1702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1702', '112', '3579', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3580', '1078', '1', 'Guangxi', 'CN.16', 'NULL', '1703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1703', '112', '3580', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3581', '1078', '1', 'Guizhou', 'CN.18', 'NULL', '1704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1704', '112', '3581', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3582', '1078', '1', 'Liaoning Province', 'CN.19', 'NULL', '1705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1705', '112', '3582', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3583', '1078', '1', 'Nei Mongol', 'CN.20', 'NULL', '1706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1706', '112', '3583', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3584', '1078', '1', 'Ningxia', 'CN.21', 'NULL', '1707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1707', '112', '3584', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3585', '1078', '1', 'Beijing', 'CN.22', 'NULL', '1708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1708', '112', '3585', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3586', '1078', '1', 'Shanghai', 'CN.23', 'NULL', '1709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1709', '112', '3586', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3587', '1078', '1', 'Shanxi', 'CN.24', 'NULL', '1710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1710', '112', '3587', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3588', '1078', '1', 'Shandong', 'CN.25', 'NULL', '1711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1711', '112', '3588', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3589', '1078', '1', 'Shaanxi', 'CN.26', 'NULL', '1712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1712', '112', '3589', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3590', '1078', '1', 'Tianjin', 'CN.28', 'NULL', '1713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1713', '112', '3590', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3591', '1078', '1', 'Yunnan Province', 'CN.29', 'NULL', '1714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1714', '112', '3591', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3592', '1078', '1', 'Guangdong', 'CN.30', 'NULL', '1715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1715', '112', '3592', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3593', '1078', '1', 'Hainan Province', 'CN.31', 'NULL', '1716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1716', '112', '3593', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3594', '1078', '1', 'Sichuan', 'CN.32', 'NULL', '1717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1717', '112', '3594', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3595', '1078', '1', 'Chongqing', 'CN.33', 'NULL', '1718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1718', '112', '3595', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3596', '1078', '1', 'PF99', 'CN.99', 'NULL', '1719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1719', '112', '3596', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CN.99» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3597', '1078', '1', 'Colombia (general)', 'CO.00', 'NULL', '1720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1720', '112', '3597', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3598', '1078', '1', 'Amazonas', 'CO.01', 'NULL', '1721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1721', '112', '3598', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3599', '1078', '1', 'Antioquia', 'CO.02', 'NULL', '1722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1722', '112', '3599', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3600', '1078', '1', 'Arauca', 'CO.03', 'NULL', '1723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1723', '112', '3600', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3601', '1078', '1', 'Atlántico', 'CO.04', 'NULL', '1724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1724', '112', '3601', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3602', '1078', '1', 'Bolívar', 'CO.05', 'NULL', '1725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1725', '112', '3602', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3603', '1078', '1', 'Boyacá', 'CO.06', 'NULL', '1726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1726', '112', '3603', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3604', '1078', '1', 'Caldas', 'CO.07', 'NULL', '1727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1727', '112', '3604', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3605', '1078', '1', 'Caquetá', 'CO.08', 'NULL', '1728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1728', '112', '3605', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3606', '1078', '1', 'Cauca', 'CO.09', 'NULL', '1729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1729', '112', '3606', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3607', '1078', '1', 'Cesar', 'CO.10', 'NULL', '1730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1730', '112', '3607', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3608', '1078', '1', 'Chocó', 'CO.11', 'NULL', '1731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1731', '112', '3608', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3609', '1078', '1', 'Córdoba', 'CO.12', 'NULL', '1732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1732', '112', '3609', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3610', '1078', '1', 'Guaviare', 'CO.14', 'NULL', '1733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1733', '112', '3610', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3611', '1078', '1', 'Guainía', 'CO.15', 'NULL', '1734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1734', '112', '3611', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3612', '1078', '1', 'Huila', 'CO.16', 'NULL', '1735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1735', '112', '3612', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3613', '1078', '1', 'La Guajira', 'CO.17', 'NULL', '1736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1736', '112', '3613', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3614', '1078', '1', 'Magdalena', 'CO.18', 'NULL', '1737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1737', '112', '3614', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3615', '1078', '1', 'Meta', 'CO.19', 'NULL', '1738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1738', '112', '3615', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3616', '1078', '1', 'Nariño', 'CO.20', 'NULL', '1739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1739', '112', '3616', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3617', '1078', '1', 'Norte de Santander', 'CO.21', 'NULL', '1740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1740', '112', '3617', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3618', '1078', '1', 'Putumayo', 'CO.22', 'NULL', '1741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1741', '112', '3618', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3619', '1078', '1', 'Quindío', 'CO.23', 'NULL', '1742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1742', '112', '3619', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3620', '1078', '1', 'Risaralda', 'CO.24', 'NULL', '1743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1743', '112', '3620', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3621', '1078', '1', 'Archipiélago de San Andrés, Providencia y Santa Catalina', 'CO.25', 'NULL', '1744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1744', '112', '3621', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3622', '1078', '1', 'Santander', 'CO.26', 'NULL', '1745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1745', '112', '3622', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3623', '1078', '1', 'Sucre', 'CO.27', 'NULL', '1746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1746', '112', '3623', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3624', '1078', '1', 'Tolima', 'CO.28', 'NULL', '1747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1747', '112', '3624', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3625', '1078', '1', 'Valle del Cauca', 'CO.29', 'NULL', '1748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1748', '112', '3625', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3626', '1078', '1', 'Vaupés', 'CO.30', 'NULL', '1749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1749', '112', '3626', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3627', '1078', '1', 'Vichada', 'CO.31', 'NULL', '1750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1750', '112', '3627', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3628', '1078', '1', 'Casanare', 'CO.32', 'NULL', '1751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1751', '112', '3628', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3629', '1078', '1', 'Cundinamarca', 'CO.33', 'NULL', '1752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1752', '112', '3629', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3630', '1078', '1', 'Bogota D.C.', 'CO.34', 'NULL', '1753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1753', '112', '3630', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3631', '1078', '1', 'Bolívar', 'CO.35', 'NULL', '1754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1754', '112', '3631', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3632', '1078', '1', 'Boyacá', 'CO.36', 'NULL', '1755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1755', '112', '3632', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3633', '1078', '1', 'Caldas', 'CO.37', 'NULL', '1756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1756', '112', '3633', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3634', '1078', '1', 'Magdalena', 'CO.38', 'NULL', '1757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1757', '112', '3634', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CO.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3635', '1078', '1', 'Costa Rica (general)', 'CR.00', 'NULL', '1758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1758', '112', '3635', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3636', '1078', '1', 'Alajuela', 'CR.01', 'NULL', '1759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1759', '112', '3636', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CR.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3637', '1078', '1', 'Cartago', 'CR.02', 'NULL', '1760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1760', '112', '3637', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CR.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3638', '1078', '1', 'Guanacaste', 'CR.03', 'NULL', '1761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1761', '112', '3638', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CR.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3639', '1078', '1', 'Heredia', 'CR.04', 'NULL', '1762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1762', '112', '3639', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CR.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3640', '1078', '1', 'Limón', 'CR.06', 'NULL', '1763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1763', '112', '3640', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CR.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3641', '1078', '1', 'Puntarenas', 'CR.07', 'NULL', '1764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1764', '112', '3641', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CR.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3642', '1078', '1', 'San José', 'CR.08', 'NULL', '1765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1765', '112', '3642', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CR.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3643', '1078', '1', 'Serbia and Montenegro (general)', 'CS.00', 'NULL', '1766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1766', '112', '3643', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CS.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3644', '1078', '1', 'Crna Gora (Montenegro)', 'CS.01', 'NULL', '1767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1767', '112', '3644', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CS.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3645', '1078', '1', 'Srbija (Serbia)', 'CS.02', 'NULL', '1768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1768', '112', '3645', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CS.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3646', '1078', '1', 'Cuba (general)', 'CU.00', 'NULL', '1769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1769', '112', '3646', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3647', '1078', '1', 'Pinar del Río', 'CU.01', 'NULL', '1770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1770', '112', '3647', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3648', '1078', '1', 'Ciudad de La Habana', 'CU.02', 'NULL', '1771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1771', '112', '3648', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3649', '1078', '1', 'Matanzas', 'CU.03', 'NULL', '1772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1772', '112', '3649', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3650', '1078', '1', 'Isla de la Juventud', 'CU.04', 'NULL', '1773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1773', '112', '3650', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3651', '1078', '1', 'Camagüey', 'CU.05', 'NULL', '1774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1774', '112', '3651', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3652', '1078', '1', 'Ciego de Ávila', 'CU.07', 'NULL', '1775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1775', '112', '3652', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3653', '1078', '1', 'Cienfuegos', 'CU.08', 'NULL', '1776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1776', '112', '3653', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3654', '1078', '1', 'Granma', 'CU.09', 'NULL', '1777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1777', '112', '3654', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3655', '1078', '1', 'Guantánamo', 'CU.10', 'NULL', '1778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1778', '112', '3655', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3656', '1078', '1', 'La Habana', 'CU.11', 'NULL', '1779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1779', '112', '3656', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3657', '1078', '1', 'Holguín', 'CU.12', 'NULL', '1780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1780', '112', '3657', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3658', '1078', '1', 'Las Tunas', 'CU.13', 'NULL', '1781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1781', '112', '3658', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3659', '1078', '1', 'Sancti Spíritus', 'CU.14', 'NULL', '1782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1782', '112', '3659', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3660', '1078', '1', 'Santiago de Cuba', 'CU.15', 'NULL', '1783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1783', '112', '3660', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3661', '1078', '1', 'Villa Clara', 'CU.16', 'NULL', '1784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1784', '112', '3661', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CU.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3662', '1078', '1', 'Cape Verde (general)', 'CV.00', 'NULL', '1785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1785', '112', '3662', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3663', '1078', '1', 'Boa Vista', 'CV.01', 'NULL', '1786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1786', '112', '3663', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3664', '1078', '1', 'Brava', 'CV.02', 'NULL', '1787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1787', '112', '3664', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3665', '1078', '1', 'Maio', 'CV.04', 'NULL', '1788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1788', '112', '3665', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3666', '1078', '1', 'Paul', 'CV.05', 'NULL', '1789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1789', '112', '3666', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3667', '1078', '1', 'Praia', 'CV.06', 'NULL', '1790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1790', '112', '3667', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3668', '1078', '1', 'Ribeira Grande', 'CV.07', 'NULL', '1791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1791', '112', '3668', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3669', '1078', '1', 'Sal', 'CV.08', 'NULL', '1792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1792', '112', '3669', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3670', '1078', '1', 'Santa Catarina   ', 'CV.09', 'NULL', '1793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1793', '112', '3670', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3671', '1078', '1', 'São Nicolau', 'CV.10', 'NULL', '1794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1794', '112', '3671', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3672', '1078', '1', 'São Vicente', 'CV.11', 'NULL', '1795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1795', '112', '3672', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3673', '1078', '1', 'Tarrafal ', 'CV.12', 'NULL', '1796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1796', '112', '3673', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3674', '1078', '1', 'Mosteiros', 'CV.13', 'NULL', '1797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1797', '112', '3674', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3675', '1078', '1', 'Praia', 'CV.14', 'NULL', '1798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1798', '112', '3675', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3676', '1078', '1', 'Santa Catarina', 'CV.15', 'NULL', '1799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1799', '112', '3676', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3677', '1078', '1', 'Santa Cruz', 'CV.16', 'NULL', '1800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1800', '112', '3677', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3678', '1078', '1', 'São Domingos', 'CV.17', 'NULL', '1801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1801', '112', '3678', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3679', '1078', '1', 'São Filipe', 'CV.18', 'NULL', '1802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1802', '112', '3679', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3680', '1078', '1', 'São Miguel', 'CV.19', 'NULL', '1803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1803', '112', '3680', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3681', '1078', '1', 'Tarrafal', 'CV.20', 'NULL', '1804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1804', '112', '3681', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CV.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3682', '1078', '1', 'Christmas Island (general)', 'CX.00', 'NULL', '1805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1805', '112', '3682', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CX.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3683', '1078', '1', 'Cyprus (general)', 'CY.00', 'NULL', '1806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1806', '112', '3683', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CY.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3684', '1078', '1', 'Famagusta', 'CY.01', 'NULL', '1807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1807', '112', '3684', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CY.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3685', '1078', '1', 'Kyrenia', 'CY.02', 'NULL', '1808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1808', '112', '3685', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CY.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3686', '1078', '1', 'Larnaca', 'CY.03', 'NULL', '1809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1809', '112', '3686', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CY.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3687', '1078', '1', 'Nicosia', 'CY.04', 'NULL', '1810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1810', '112', '3687', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CY.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3688', '1078', '1', 'Limassol', 'CY.05', 'NULL', '1811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1811', '112', '3688', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CY.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3689', '1078', '1', 'Paphos', 'CY.06', 'NULL', '1812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1812', '112', '3689', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CY.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3690', '1078', '1', 'Czech Republic (general)', 'CZ.00', 'NULL', '1813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1813', '112', '3690', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3691', '1078', '1', 'Hradec Kralove', 'CZ.20', 'NULL', '1814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1814', '112', '3691', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3692', '1078', '1', 'Jablonec nad Nisou', 'CZ.21', 'NULL', '1815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1815', '112', '3692', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3693', '1078', '1', 'Jiein', 'CZ.23', 'NULL', '1816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1816', '112', '3693', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3694', '1078', '1', 'Jihlava', 'CZ.24', 'NULL', '1817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1817', '112', '3694', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3695', '1078', '1', 'Kolin', 'CZ.30', 'NULL', '1818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1818', '112', '3695', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3696', '1078', '1', 'Liberec', 'CZ.33', 'NULL', '1819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1819', '112', '3696', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3697', '1078', '1', 'Melnik', 'CZ.36', 'NULL', '1820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1820', '112', '3697', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3698', '1078', '1', 'Mlada Boleslav', 'CZ.37', 'NULL', '1821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1821', '112', '3698', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3699', '1078', '1', 'Nachod', 'CZ.39', 'NULL', '1822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1822', '112', '3699', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3700', '1078', '1', 'Nymburk', 'CZ.41', 'NULL', '1823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1823', '112', '3700', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3701', '1078', '1', 'Pardubice', 'CZ.45', 'NULL', '1824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1824', '112', '3701', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3702', '1078', '1', 'Hlavní Mesto Praha', 'CZ.52', 'NULL', '1825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1825', '112', '3702', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3703', '1078', '1', 'Semily', 'CZ.61', 'NULL', '1826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1826', '112', '3703', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3704', '1078', '1', 'Trutnov', 'CZ.70', 'NULL', '1827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1827', '112', '3704', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3705', '1078', '1', '(EZ73)', 'CZ.73', 'NULL', '1828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1828', '112', '3705', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3706', '1078', '1', 'South Moravian Region', 'CZ.78', 'NULL', '1829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1829', '112', '3706', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3707', '1078', '1', 'Jihočeský Kraj', 'CZ.79', 'NULL', '1830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1830', '112', '3707', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3708', '1078', '1', 'Vysočina', 'CZ.80', 'NULL', '1831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1831', '112', '3708', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3709', '1078', '1', 'Karlovarský Kraj', 'CZ.81', 'NULL', '1832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1832', '112', '3709', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3710', '1078', '1', 'Královéhradecký Kraj', 'CZ.82', 'NULL', '1833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1833', '112', '3710', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3711', '1078', '1', 'Liberecký Kraj', 'CZ.83', 'NULL', '1834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1834', '112', '3711', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3712', '1078', '1', 'Olomoucký Kraj', 'CZ.84', 'NULL', '1835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1835', '112', '3712', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3713', '1078', '1', 'Moravskoslezský Kraj', 'CZ.85', 'NULL', '1836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1836', '112', '3713', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3714', '1078', '1', 'Pardubický Kraj', 'CZ.86', 'NULL', '1837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1837', '112', '3714', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3715', '1078', '1', 'Plzeňský Kraj', 'CZ.87', 'NULL', '1838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1838', '112', '3715', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.87» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3716', '1078', '1', 'Středočeský Kraj', 'CZ.88', 'NULL', '1839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1839', '112', '3716', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.88» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3717', '1078', '1', 'Ústecký Kraj', 'CZ.89', 'NULL', '1840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1840', '112', '3717', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.89» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3718', '1078', '1', 'Zlínský Kraj', 'CZ.90', 'NULL', '1841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1841', '112', '3718', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «CZ.90» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3719', '1078', '1', 'Germany (general)', 'DE.00', 'NULL', '1842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1842', '112', '3719', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3720', '1078', '1', 'Baden-Württemberg', 'DE.01', 'NULL', '1843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1843', '112', '3720', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3721', '1078', '1', 'Bavaria', 'DE.02', 'NULL', '1844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1844', '112', '3721', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3722', '1078', '1', 'Bremen', 'DE.03', 'NULL', '1845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1845', '112', '3722', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3723', '1078', '1', 'Hamburg', 'DE.04', 'NULL', '1846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1846', '112', '3723', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3724', '1078', '1', 'Hesse', 'DE.05', 'NULL', '1847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1847', '112', '3724', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3725', '1078', '1', 'Lower Saxony', 'DE.06', 'NULL', '1848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1848', '112', '3725', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3726', '1078', '1', 'North Rhine-Westphalia', 'DE.07', 'NULL', '1849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1849', '112', '3726', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3727', '1078', '1', 'Rhineland-Palatinate', 'DE.08', 'NULL', '1850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1850', '112', '3727', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3728', '1078', '1', 'Saarland', 'DE.09', 'NULL', '1851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1851', '112', '3728', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3729', '1078', '1', 'Schleswig-Holstein', 'DE.10', 'NULL', '1852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1852', '112', '3729', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3730', '1078', '1', 'Brandenburg', 'DE.11', 'NULL', '1853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1853', '112', '3730', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3731', '1078', '1', 'Mecklenburg-Vorpommern', 'DE.12', 'NULL', '1854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1854', '112', '3731', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3732', '1078', '1', 'Saxony', 'DE.13', 'NULL', '1855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1855', '112', '3732', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3733', '1078', '1', 'Saxony-Anhalt', 'DE.14', 'NULL', '1856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1856', '112', '3733', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3734', '1078', '1', 'Thuringia', 'DE.15', 'NULL', '1857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1857', '112', '3734', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3735', '1078', '1', 'Berlin', 'DE.16', 'NULL', '1858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1858', '112', '3735', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DE.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3736', '1078', '1', 'Djibouti (general)', 'DJ.00', 'NULL', '1859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1859', '112', '3736', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DJ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3737', '1078', '1', 'Ali Sabieh', 'DJ.01', 'NULL', '1860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1860', '112', '3737', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DJ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3738', '1078', '1', 'Dikhil   ', 'DJ.02', 'NULL', '1861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1861', '112', '3738', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DJ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3739', '1078', '1', 'Djibouti  ', 'DJ.03', 'NULL', '1862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1862', '112', '3739', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DJ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3740', '1078', '1', 'Obock', 'DJ.04', 'NULL', '1863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1863', '112', '3740', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DJ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3741', '1078', '1', 'Tadjourah', 'DJ.05', 'NULL', '1864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1864', '112', '3741', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DJ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3742', '1078', '1', 'Dikhil', 'DJ.06', 'NULL', '1865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1865', '112', '3742', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DJ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3743', '1078', '1', 'Djibouti', 'DJ.07', 'NULL', '1866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1866', '112', '3743', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DJ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3744', '1078', '1', 'Arta', 'DJ.08', 'NULL', '1867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1867', '112', '3744', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DJ.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3745', '1078', '1', 'Århus', 'DK.01', 'NULL', '1868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1868', '112', '3745', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3746', '1078', '1', 'Bornholm', 'DK.02', 'NULL', '1869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1869', '112', '3746', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3747', '1078', '1', 'Frederiksborg', 'DK.03', 'NULL', '1870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1870', '112', '3747', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3748', '1078', '1', 'Fyn', 'DK.04', 'NULL', '1871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1871', '112', '3748', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3749', '1078', '1', 'Copenhagen city', 'DK.05', 'NULL', '1872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1872', '112', '3749', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3750', '1078', '1', 'København', 'DK.06', 'NULL', '1873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1873', '112', '3750', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3751', '1078', '1', 'Nordjylland', 'DK.07', 'NULL', '1874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1874', '112', '3751', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3752', '1078', '1', 'Ribe', 'DK.08', 'NULL', '1875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1875', '112', '3752', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3753', '1078', '1', 'Ringkøbing', 'DK.09', 'NULL', '1876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1876', '112', '3753', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3754', '1078', '1', 'Roskilde', 'DK.10', 'NULL', '1877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1877', '112', '3754', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3755', '1078', '1', 'Sønderjylland', 'DK.11', 'NULL', '1878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1878', '112', '3755', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3756', '1078', '1', 'Storstrøm', 'DK.12', 'NULL', '1879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1879', '112', '3756', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3757', '1078', '1', 'Vejle', 'DK.13', 'NULL', '1880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1880', '112', '3757', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3758', '1078', '1', 'Vestsjælland', 'DK.14', 'NULL', '1881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1881', '112', '3758', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3759', '1078', '1', 'Viborg', 'DK.15', 'NULL', '1882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1882', '112', '3759', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3760', '1078', '1', 'Fredriksberg', 'DK.16', 'NULL', '1883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1883', '112', '3760', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3761', '1078', '1', 'Capital Region', 'DK.17', 'NULL', '1884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1884', '112', '3761', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3762', '1078', '1', 'Central Jutland', 'DK.18', 'NULL', '1885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1885', '112', '3762', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3763', '1078', '1', 'North Jutland', 'DK.19', 'NULL', '1886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1886', '112', '3763', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3764', '1078', '1', 'Region Zealand', 'DK.20', 'NULL', '1887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1887', '112', '3764', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3765', '1078', '1', 'Region South Denmark', 'DK.21', 'NULL', '1888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1888', '112', '3765', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DK.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3766', '1078', '1', 'Dominica (general)', 'DM.00', 'NULL', '1889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1889', '112', '3766', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3767', '1078', '1', 'Saint Andrew', 'DM.02', 'NULL', '1890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1890', '112', '3767', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3768', '1078', '1', 'Saint David', 'DM.03', 'NULL', '1891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1891', '112', '3768', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3769', '1078', '1', 'Saint George', 'DM.04', 'NULL', '1892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1892', '112', '3769', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3770', '1078', '1', 'Saint John', 'DM.05', 'NULL', '1893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1893', '112', '3770', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3771', '1078', '1', 'Saint Joseph', 'DM.06', 'NULL', '1894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1894', '112', '3771', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3772', '1078', '1', 'Saint Luke', 'DM.07', 'NULL', '1895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1895', '112', '3772', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3773', '1078', '1', 'Saint Mark', 'DM.08', 'NULL', '1896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1896', '112', '3773', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3774', '1078', '1', 'Saint Patrick', 'DM.09', 'NULL', '1897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1897', '112', '3774', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3775', '1078', '1', 'Saint Paul', 'DM.10', 'NULL', '1898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1898', '112', '3775', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3776', '1078', '1', 'Saint Peter', 'DM.11', 'NULL', '1899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1899', '112', '3776', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DM.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3777', '1078', '1', 'Dominican Republic (general)', 'DO.00', 'NULL', '1900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1900', '112', '3777', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3778', '1078', '1', 'Azua', 'DO.01', 'NULL', '1901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1901', '112', '3778', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3779', '1078', '1', 'Baoruco', 'DO.02', 'NULL', '1902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1902', '112', '3779', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3780', '1078', '1', 'Barahona', 'DO.03', 'NULL', '1903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1903', '112', '3780', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3781', '1078', '1', 'Dajabón', 'DO.04', 'NULL', '1904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1904', '112', '3781', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3782', '1078', '1', 'Duarte', 'DO.06', 'NULL', '1905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1905', '112', '3782', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3783', '1078', '1', 'Espaillat', 'DO.08', 'NULL', '1906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1906', '112', '3783', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3784', '1078', '1', 'Independencia', 'DO.09', 'NULL', '1907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1907', '112', '3784', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3785', '1078', '1', 'La Altagracia', 'DO.10', 'NULL', '1908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1908', '112', '3785', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3786', '1078', '1', 'Elías Piña', 'DO.11', 'NULL', '1909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1909', '112', '3786', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3787', '1078', '1', 'La Romana', 'DO.12', 'NULL', '1910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1910', '112', '3787', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3788', '1078', '1', 'María Trinidad Sánchez', 'DO.14', 'NULL', '1911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1911', '112', '3788', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3789', '1078', '1', 'Monte Cristi', 'DO.15', 'NULL', '1912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1912', '112', '3789', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3790', '1078', '1', 'Pedernales', 'DO.16', 'NULL', '1913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1913', '112', '3790', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3791', '1078', '1', 'Puerto Plata', 'DO.18', 'NULL', '1914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1914', '112', '3791', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3792', '1078', '1', 'Salcedo', 'DO.19', 'NULL', '1915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1915', '112', '3792', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3793', '1078', '1', 'Samaná', 'DO.20', 'NULL', '1916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1916', '112', '3793', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3794', '1078', '1', 'Sánchez Ramírez', 'DO.21', 'NULL', '1917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1917', '112', '3794', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3795', '1078', '1', 'San Juan', 'DO.23', 'NULL', '1918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1918', '112', '3795', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3796', '1078', '1', 'San Pedro de Macorís', 'DO.24', 'NULL', '1919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1919', '112', '3796', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3797', '1078', '1', 'Santiago', 'DO.25', 'NULL', '1920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1920', '112', '3797', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3798', '1078', '1', 'Santiago Rodríguez', 'DO.26', 'NULL', '1921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1921', '112', '3798', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3799', '1078', '1', 'Valverde', 'DO.27', 'NULL', '1922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1922', '112', '3799', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3800', '1078', '1', 'El Seíbo', 'DO.28', 'NULL', '1923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1923', '112', '3800', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3801', '1078', '1', 'Hato Mayor', 'DO.29', 'NULL', '1924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1924', '112', '3801', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3802', '1078', '1', 'La Vega', 'DO.30', 'NULL', '1925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1925', '112', '3802', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3803', '1078', '1', 'Monseñor Nouel', 'DO.31', 'NULL', '1926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1926', '112', '3803', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3804', '1078', '1', 'Monte Plata', 'DO.32', 'NULL', '1927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1927', '112', '3804', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3805', '1078', '1', 'San Cristóbal', 'DO.33', 'NULL', '1928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1928', '112', '3805', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3806', '1078', '1', 'Distrito Nacional', 'DO.34', 'NULL', '1929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1929', '112', '3806', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3807', '1078', '1', 'Peravia', 'DO.35', 'NULL', '1930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1930', '112', '3807', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3808', '1078', '1', 'Provincia de San José de Ocoa', 'DO.36', 'NULL', '1931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1931', '112', '3808', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3809', '1078', '1', 'Provincia de Santo Domingo', 'DO.37', 'NULL', '1932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1932', '112', '3809', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DO.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3810', '1078', '1', 'Algeria (general)', 'DZ.00', 'NULL', '1933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1933', '112', '3810', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3811', '1078', '1', 'Alger', 'DZ.01', 'NULL', '1934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1934', '112', '3811', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3812', '1078', '1', 'Batna', 'DZ.03', 'NULL', '1935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1935', '112', '3812', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3813', '1078', '1', 'Constantine', 'DZ.04', 'NULL', '1936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1936', '112', '3813', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3814', '1078', '1', 'Médéa', 'DZ.06', 'NULL', '1937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1937', '112', '3814', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3815', '1078', '1', 'Mostaganem', 'DZ.07', 'NULL', '1938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1938', '112', '3815', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3816', '1078', '1', 'Oran', 'DZ.09', 'NULL', '1939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1939', '112', '3816', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3817', '1078', '1', 'Saïda', 'DZ.10', 'NULL', '1940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1940', '112', '3817', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3818', '1078', '1', 'Sétif', 'DZ.12', 'NULL', '1941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1941', '112', '3818', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3819', '1078', '1', 'Tiaret', 'DZ.13', 'NULL', '1942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1942', '112', '3819', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3820', '1078', '1', 'Tizi Ouzou', 'DZ.14', 'NULL', '1943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1943', '112', '3820', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3821', '1078', '1', 'Tlemcen', 'DZ.15', 'NULL', '1944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1944', '112', '3821', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3822', '1078', '1', 'Bejaïa', 'DZ.18', 'NULL', '1945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1945', '112', '3822', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3823', '1078', '1', 'Biskra', 'DZ.19', 'NULL', '1946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1946', '112', '3823', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3824', '1078', '1', 'Blida', 'DZ.20', 'NULL', '1947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1947', '112', '3824', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3825', '1078', '1', 'Bouira', 'DZ.21', 'NULL', '1948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1948', '112', '3825', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3826', '1078', '1', 'Djelfa', 'DZ.22', 'NULL', '1949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1949', '112', '3826', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3827', '1078', '1', 'Guelma', 'DZ.23', 'NULL', '1950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1950', '112', '3827', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3828', '1078', '1', 'Jijel', 'DZ.24', 'NULL', '1951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1951', '112', '3828', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3829', '1078', '1', 'Laghouat', 'DZ.25', 'NULL', '1952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1952', '112', '3829', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3830', '1078', '1', 'Mascara', 'DZ.26', 'NULL', '1953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1953', '112', '3830', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3831', '1078', '1', 'Mʼsila', 'DZ.27', 'NULL', '1954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1954', '112', '3831', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3832', '1078', '1', 'Oum el Bouaghi', 'DZ.29', 'NULL', '1955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1955', '112', '3832', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3833', '1078', '1', 'Sidi Bel Abbès', 'DZ.30', 'NULL', '1956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1956', '112', '3833', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3834', '1078', '1', 'Skikda', 'DZ.31', 'NULL', '1957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1957', '112', '3834', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3835', '1078', '1', 'Tébessa', 'DZ.33', 'NULL', '1958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1958', '112', '3835', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3836', '1078', '1', 'Adrar', 'DZ.34', 'NULL', '1959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1959', '112', '3836', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3837', '1078', '1', 'Aïn Defla', 'DZ.35', 'NULL', '1960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1960', '112', '3837', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3838', '1078', '1', 'Aïn Temouchent', 'DZ.36', 'NULL', '1961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1961', '112', '3838', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3839', '1078', '1', 'Annaba', 'DZ.37', 'NULL', '1962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1962', '112', '3839', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3840', '1078', '1', 'Béchar', 'DZ.38', 'NULL', '1963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1963', '112', '3840', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3841', '1078', '1', 'Bordj Bou Arréridj', 'DZ.39', 'NULL', '1964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1964', '112', '3841', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3842', '1078', '1', 'Boumerdes', 'DZ.40', 'NULL', '1965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1965', '112', '3842', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3843', '1078', '1', 'Chlef', 'DZ.41', 'NULL', '1966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1966', '112', '3843', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3844', '1078', '1', 'El Bayadh', 'DZ.42', 'NULL', '1967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1967', '112', '3844', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3845', '1078', '1', 'El Oued', 'DZ.43', 'NULL', '1968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1968', '112', '3845', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3846', '1078', '1', 'El Tarf', 'DZ.44', 'NULL', '1969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1969', '112', '3846', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3847', '1078', '1', 'Ghardaïa', 'DZ.45', 'NULL', '1970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1970', '112', '3847', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3848', '1078', '1', 'Illizi', 'DZ.46', 'NULL', '1971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1971', '112', '3848', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3849', '1078', '1', 'Khenchela', 'DZ.47', 'NULL', '1972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1972', '112', '3849', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3850', '1078', '1', 'Mila', 'DZ.48', 'NULL', '1973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1973', '112', '3850', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3851', '1078', '1', 'Naama النعامة', 'DZ.49', 'NULL', '1974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1974', '112', '3851', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3852', '1078', '1', 'Ouargla', 'DZ.50', 'NULL', '1975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1975', '112', '3852', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3853', '1078', '1', 'Relizane', 'DZ.51', 'NULL', '1976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1976', '112', '3853', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3854', '1078', '1', 'Souk Ahras', 'DZ.52', 'NULL', '1977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1977', '112', '3854', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3855', '1078', '1', 'Tamanghasset', 'DZ.53', 'NULL', '1978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1978', '112', '3855', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3856', '1078', '1', 'Tindouf', 'DZ.54', 'NULL', '1979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1979', '112', '3856', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3857', '1078', '1', 'Tipaza', 'DZ.55', 'NULL', '1980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1980', '112', '3857', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3858', '1078', '1', 'Tissemsilt', 'DZ.56', 'NULL', '1981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1981', '112', '3858', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «DZ.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3859', '1078', '1', 'Ecuador (general)', 'EC.00', 'NULL', '1982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1982', '112', '3859', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3860', '1078', '1', 'Galápagos', 'EC.01', 'NULL', '1983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1983', '112', '3860', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3861', '1078', '1', 'Azuay', 'EC.02', 'NULL', '1984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1984', '112', '3861', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3862', '1078', '1', 'Bolívar', 'EC.03', 'NULL', '1985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1985', '112', '3862', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3863', '1078', '1', 'Cañar', 'EC.04', 'NULL', '1986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1986', '112', '3863', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3864', '1078', '1', 'Carchi', 'EC.05', 'NULL', '1987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1987', '112', '3864', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3865', '1078', '1', 'Chimborazo', 'EC.06', 'NULL', '1988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1988', '112', '3865', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3866', '1078', '1', 'Cotopaxi', 'EC.07', 'NULL', '1989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1989', '112', '3866', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3867', '1078', '1', 'El Oro', 'EC.08', 'NULL', '1990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1990', '112', '3867', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3868', '1078', '1', 'Esmeraldas', 'EC.09', 'NULL', '1991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1991', '112', '3868', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3869', '1078', '1', 'Guayas', 'EC.10', 'NULL', '1992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1992', '112', '3869', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3870', '1078', '1', 'Imbabura', 'EC.11', 'NULL', '1993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1993', '112', '3870', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3871', '1078', '1', 'Loja', 'EC.12', 'NULL', '1994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1994', '112', '3871', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3872', '1078', '1', 'Los Ríos', 'EC.13', 'NULL', '1995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1995', '112', '3872', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3873', '1078', '1', 'Manabí', 'EC.14', 'NULL', '1996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1996', '112', '3873', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3874', '1078', '1', 'Morona-Santiago', 'EC.15', 'NULL', '1997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1997', '112', '3874', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3875', '1078', '1', 'Napo', 'EC.16', 'NULL', '1998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1998', '112', '3875', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3876', '1078', '1', 'Pastaza', 'EC.17', 'NULL', '1999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('1999', '112', '3876', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3877', '1078', '1', 'Pichincha', 'EC.18', 'NULL', '2000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2000', '112', '3877', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3878', '1078', '1', 'Tungurahua', 'EC.19', 'NULL', '2001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2001', '112', '3878', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3879', '1078', '1', 'Zamora-Chinchipe', 'EC.20', 'NULL', '2002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2002', '112', '3879', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3880', '1078', '1', 'Sucumbios', 'EC.22', 'NULL', '2003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2003', '112', '3880', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3881', '1078', '1', 'Napo', 'EC.23', 'NULL', '2004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2004', '112', '3881', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3882', '1078', '1', 'Orellana', 'EC.24', 'NULL', '2005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2005', '112', '3882', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EC.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3883', '1078', '1', 'Estonia (general)', 'EE.00', 'NULL', '2006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2006', '112', '3883', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3884', '1078', '1', 'Harjumaa', 'EE.01', 'NULL', '2007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2007', '112', '3884', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3885', '1078', '1', 'Hiiumaa', 'EE.02', 'NULL', '2008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2008', '112', '3885', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3886', '1078', '1', 'Ida-Virumaa', 'EE.03', 'NULL', '2009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2009', '112', '3886', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3887', '1078', '1', 'Järvamaa', 'EE.04', 'NULL', '2010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2010', '112', '3887', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3888', '1078', '1', 'Jõgevamaa', 'EE.05', 'NULL', '2011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2011', '112', '3888', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3889', '1078', '1', 'Läänemaa', 'EE.07', 'NULL', '2012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2012', '112', '3889', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3890', '1078', '1', 'Lääne-Virumaa', 'EE.08', 'NULL', '2013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2013', '112', '3890', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3891', '1078', '1', 'Pärnumaa', 'EE.11', 'NULL', '2014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2014', '112', '3891', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3892', '1078', '1', 'Põlvamaa', 'EE.12', 'NULL', '2015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2015', '112', '3892', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3893', '1078', '1', 'Raplamaa', 'EE.13', 'NULL', '2016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2016', '112', '3893', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3894', '1078', '1', 'Saaremaa', 'EE.14', 'NULL', '2017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2017', '112', '3894', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3895', '1078', '1', 'Tartumaa', 'EE.18', 'NULL', '2018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2018', '112', '3895', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3896', '1078', '1', 'Valgamaa', 'EE.19', 'NULL', '2019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2019', '112', '3896', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3897', '1078', '1', 'Viljandimaa', 'EE.20', 'NULL', '2020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2020', '112', '3897', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3898', '1078', '1', 'Võrumaa', 'EE.21', 'NULL', '2021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2021', '112', '3898', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EE.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3899', '1078', '1', 'Egypt (general)', 'EG.00', 'NULL', '2022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2022', '112', '3899', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3900', '1078', '1', 'Ad Daqahlīyah', 'EG.01', 'NULL', '2023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2023', '112', '3900', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3901', '1078', '1', 'Al Baḩr al Aḩmar', 'EG.02', 'NULL', '2024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2024', '112', '3901', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3902', '1078', '1', 'Al Buḩayrah', 'EG.03', 'NULL', '2025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2025', '112', '3902', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3903', '1078', '1', 'Al Fayyūm', 'EG.04', 'NULL', '2026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2026', '112', '3903', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3904', '1078', '1', 'Al Gharbīyah', 'EG.05', 'NULL', '2027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2027', '112', '3904', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3905', '1078', '1', 'Alexandria', 'EG.06', 'NULL', '2028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2028', '112', '3905', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3906', '1078', '1', 'Al Ismā‘īlīyah', 'EG.07', 'NULL', '2029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2029', '112', '3906', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3907', '1078', '1', 'Al Jīzah', 'EG.08', 'NULL', '2030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2030', '112', '3907', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3908', '1078', '1', 'Al Minūfīyah', 'EG.09', 'NULL', '2031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2031', '112', '3908', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3909', '1078', '1', 'Al Minyā', 'EG.10', 'NULL', '2032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2032', '112', '3909', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3910', '1078', '1', 'Al Qāhirah', 'EG.11', 'NULL', '2033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2033', '112', '3910', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3911', '1078', '1', 'Al Qalyūbīyah', 'EG.12', 'NULL', '2034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2034', '112', '3911', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3912', '1078', '1', 'Al Wādī al Jadīd', 'EG.13', 'NULL', '2035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2035', '112', '3912', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3913', '1078', '1', 'Eastern Province', 'EG.14', 'NULL', '2036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2036', '112', '3913', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3914', '1078', '1', 'As Suways', 'EG.15', 'NULL', '2037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2037', '112', '3914', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3915', '1078', '1', 'Aswān', 'EG.16', 'NULL', '2038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2038', '112', '3915', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3916', '1078', '1', 'Asyūţ', 'EG.17', 'NULL', '2039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2039', '112', '3916', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3917', '1078', '1', 'Banī Suwayf', 'EG.18', 'NULL', '2040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2040', '112', '3917', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3918', '1078', '1', 'Būr Sa‘īd', 'EG.19', 'NULL', '2041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2041', '112', '3918', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3919', '1078', '1', 'Dumyāţ', 'EG.20', 'NULL', '2042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2042', '112', '3919', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3920', '1078', '1', 'Kafr ash Shaykh', 'EG.21', 'NULL', '2043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2043', '112', '3920', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3921', '1078', '1', 'Maţrūḩ', 'EG.22', 'NULL', '2044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2044', '112', '3921', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3922', '1078', '1', 'Qinā', 'EG.23', 'NULL', '2045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2045', '112', '3922', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3923', '1078', '1', 'Sūhāj', 'EG.24', 'NULL', '2046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2046', '112', '3923', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3924', '1078', '1', 'Janūb Sīnāʼ', 'EG.26', 'NULL', '2047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2047', '112', '3924', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3925', '1078', '1', 'Shamāl Sīnāʼ', 'EG.27', 'NULL', '2048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2048', '112', '3925', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EG.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3926', '1078', '1', 'Western Sahara (general)', 'EH.00', 'NULL', '2049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2049', '112', '3926', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «EH.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3927', '1078', '1', 'Eritrea (general)', 'ER.00', 'NULL', '2050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2050', '112', '3927', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ER.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3928', '1078', '1', 'Ānseba', 'ER.01', 'NULL', '2051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2051', '112', '3928', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ER.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3929', '1078', '1', 'Debub', 'ER.02', 'NULL', '2052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2052', '112', '3929', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ER.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3930', '1078', '1', 'Debubawī Kʼeyih Bahrī', 'ER.03', 'NULL', '2053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2053', '112', '3930', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ER.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3931', '1078', '1', 'Gash Barka', 'ER.04', 'NULL', '2054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2054', '112', '3931', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ER.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3932', '1078', '1', 'Maʼākel', 'ER.05', 'NULL', '2055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2055', '112', '3932', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ER.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3933', '1078', '1', 'Semēnawī Kʼeyih Bahrī', 'ER.06', 'NULL', '2056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2056', '112', '3933', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ER.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3934', '1078', '1', 'Ceuta', 'ES.00', 'NULL', '2057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2057', '112', '3934', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3935', '1078', '1', 'Balearic Islands', 'ES.07', 'NULL', '2058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2058', '112', '3935', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3936', '1078', '1', 'La Rioja', 'ES.27', 'NULL', '2059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2059', '112', '3936', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3937', '1078', '1', '(SP28)', 'ES.28', 'NULL', '2060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2060', '112', '3937', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3938', '1078', '1', 'Autonomous Region of Madrid', 'ES.29', 'NULL', '2061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2061', '112', '3938', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3939', '1078', '1', 'Murcia', 'ES.31', 'NULL', '2062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2062', '112', '3939', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3940', '1078', '1', 'Navarre', 'ES.32', 'NULL', '2063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2063', '112', '3940', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3941', '1078', '1', 'Asturias', 'ES.34', 'NULL', '2064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2064', '112', '3941', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3942', '1078', '1', 'Cantabria', 'ES.39', 'NULL', '2065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2065', '112', '3942', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3943', '1078', '1', 'Andalusia', 'ES.51', 'NULL', '2066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2066', '112', '3943', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3944', '1078', '1', 'Aragon', 'ES.52', 'NULL', '2067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2067', '112', '3944', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3945', '1078', '1', 'Canary Islands', 'ES.53', 'NULL', '2068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2068', '112', '3945', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3946', '1078', '1', 'Castille-La Mancha', 'ES.54', 'NULL', '2069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2069', '112', '3946', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3947', '1078', '1', 'Castille and León', 'ES.55', 'NULL', '2070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2070', '112', '3947', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3948', '1078', '1', 'Catalonia', 'ES.56', 'NULL', '2071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2071', '112', '3948', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3949', '1078', '1', 'Estremadura', 'ES.57', 'NULL', '2072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2072', '112', '3949', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3950', '1078', '1', 'Galicia', 'ES.58', 'NULL', '2073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2073', '112', '3950', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3951', '1078', '1', 'Basque Country', 'ES.59', 'NULL', '2074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2074', '112', '3951', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3952', '1078', '1', 'Valencia', 'ES.60', 'NULL', '2075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2075', '112', '3952', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ES.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3953', '1078', '1', 'Ethiopia (general)', 'ET.00', 'NULL', '2076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2076', '112', '3953', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3954', '1078', '1', 'Arsi', 'ET.01', 'NULL', '2077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2077', '112', '3954', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3955', '1078', '1', 'Gonder', 'ET.02', 'NULL', '2078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2078', '112', '3955', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3956', '1078', '1', 'Bale', 'ET.03', 'NULL', '2079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2079', '112', '3956', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3957', '1078', '1', 'Eritrea', 'ET.04', 'NULL', '2080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2080', '112', '3957', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3958', '1078', '1', 'Gamo Gofa', 'ET.05', 'NULL', '2081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2081', '112', '3958', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3959', '1078', '1', 'Gojam', 'ET.06', 'NULL', '2082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2082', '112', '3959', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3960', '1078', '1', 'Harerge', 'ET.07', 'NULL', '2083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2083', '112', '3960', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3961', '1078', '1', 'Ilubabor', 'ET.08', 'NULL', '2084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2084', '112', '3961', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3962', '1078', '1', 'Kefa', 'ET.09', 'NULL', '2085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2085', '112', '3962', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3963', '1078', '1', 'Addis Abeba', 'ET.10', 'NULL', '2086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2086', '112', '3963', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3964', '1078', '1', 'Sidamo', 'ET.11', 'NULL', '2087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2087', '112', '3964', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3965', '1078', '1', 'Tigray', 'ET.12', 'NULL', '2088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2088', '112', '3965', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3966', '1078', '1', 'Welega Kifle Hāger', 'ET.13', 'NULL', '2089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2089', '112', '3966', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3967', '1078', '1', 'Welo', 'ET.14', 'NULL', '2090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2090', '112', '3967', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3968', '1078', '1', 'Adis Abeba', 'ET.15', 'NULL', '2091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2091', '112', '3968', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3969', '1078', '1', 'Asosa', 'ET.17', 'NULL', '2092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2092', '112', '3969', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3970', '1078', '1', 'Borena ', 'ET.18', 'NULL', '2093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2093', '112', '3970', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3971', '1078', '1', 'Debub Gonder', 'ET.19', 'NULL', '2094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2094', '112', '3971', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3972', '1078', '1', 'Debub Shewa', 'ET.20', 'NULL', '2095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2095', '112', '3972', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3973', '1078', '1', 'Debub Welo', 'ET.21', 'NULL', '2096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2096', '112', '3973', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3974', '1078', '1', 'Dire Dawa', 'ET.22', 'NULL', '2097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2097', '112', '3974', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3975', '1078', '1', 'Gambela', 'ET.23', 'NULL', '2098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2098', '112', '3975', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3976', '1078', '1', 'Metekel', 'ET.24', 'NULL', '2099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2099', '112', '3976', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3977', '1078', '1', 'Mirab Gojam', 'ET.25', 'NULL', '2100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2100', '112', '3977', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3978', '1078', '1', 'Mirab Harerge', 'ET.26', 'NULL', '2101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2101', '112', '3978', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3979', '1078', '1', 'Mirab Shewa', 'ET.27', 'NULL', '2102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2102', '112', '3979', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3980', '1078', '1', 'Misrak Gojam', 'ET.28', 'NULL', '2103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2103', '112', '3980', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3981', '1078', '1', 'Misrak Harerge', 'ET.29', 'NULL', '2104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2104', '112', '3981', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3982', '1078', '1', 'Nazret', 'ET.30', 'NULL', '2105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2105', '112', '3982', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3983', '1078', '1', 'Ogaden', 'ET.31', 'NULL', '2106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2106', '112', '3983', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3984', '1078', '1', 'Omo', 'ET.32', 'NULL', '2107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2107', '112', '3984', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3985', '1078', '1', 'Semen Gonder', 'ET.33', 'NULL', '2108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2108', '112', '3985', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3986', '1078', '1', 'Semen Shewa', 'ET.34', 'NULL', '2109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2109', '112', '3986', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3987', '1078', '1', 'Semen Welo', 'ET.35', 'NULL', '2110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2110', '112', '3987', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3988', '1078', '1', 'Tigray', 'ET.37', 'NULL', '2111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2111', '112', '3988', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3989', '1078', '1', 'Bale', 'ET.38', 'NULL', '2112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2112', '112', '3989', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3990', '1078', '1', 'Gamo Gofa', 'ET.39', 'NULL', '2113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2113', '112', '3990', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3991', '1078', '1', 'Ilubabor', 'ET.40', 'NULL', '2114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2114', '112', '3991', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3992', '1078', '1', 'Kefa', 'ET.41', 'NULL', '2115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2115', '112', '3992', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3993', '1078', '1', 'Sidamo', 'ET.42', 'NULL', '2116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2116', '112', '3993', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3994', '1078', '1', 'Welega', 'ET.43', 'NULL', '2117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2117', '112', '3994', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3995', '1078', '1', 'Ādīs Ābeba', 'ET.44', 'NULL', '2118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2118', '112', '3995', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3996', '1078', '1', 'Āfar', 'ET.45', 'NULL', '2119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2119', '112', '3996', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3997', '1078', '1', 'Āmara', 'ET.46', 'NULL', '2120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2120', '112', '3997', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3998', '1078', '1', 'Bīnshangul Gumuz', 'ET.47', 'NULL', '2121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2121', '112', '3998', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('3999', '1078', '1', 'Dirē Dawa', 'ET.48', 'NULL', '2122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2122', '112', '3999', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4000', '1078', '1', 'Gambēla Hizboch', 'ET.49', 'NULL', '2123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2123', '112', '4000', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4001', '1078', '1', 'Hārerī Hizb', 'ET.50', 'NULL', '2124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2124', '112', '4001', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4002', '1078', '1', 'Oromīya', 'ET.51', 'NULL', '2125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2125', '112', '4002', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4003', '1078', '1', 'Sumalē', 'ET.52', 'NULL', '2126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2126', '112', '4003', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4004', '1078', '1', 'Tigray', 'ET.53', 'NULL', '2127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2127', '112', '4004', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4005', '1078', '1', 'YeDebub Bihēroch Bihēreseboch na Hizboch', 'ET.54', 'NULL', '2128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2128', '112', '4005', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ET.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4006', '1078', '1', 'Finland (general)', 'FI.00', 'NULL', '2129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2129', '112', '4006', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4007', '1078', '1', 'Åland', 'FI.01', 'NULL', '2130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2130', '112', '4007', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4008', '1078', '1', 'Hame', 'FI.02', 'NULL', '2131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2131', '112', '4008', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4009', '1078', '1', 'Keski-Suomi', 'FI.03', 'NULL', '2132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2132', '112', '4009', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4010', '1078', '1', 'Kuopio', 'FI.04', 'NULL', '2133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2133', '112', '4010', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4011', '1078', '1', 'Kymi', 'FI.05', 'NULL', '2134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2134', '112', '4011', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4012', '1078', '1', 'Lapponia', 'FI.06', 'NULL', '2135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2135', '112', '4012', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4013', '1078', '1', 'Mikkeli', 'FI.07', 'NULL', '2136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2136', '112', '4013', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4014', '1078', '1', 'Oulu', 'FI.08', 'NULL', '2137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2137', '112', '4014', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4015', '1078', '1', 'Pohjois-Karjala', 'FI.09', 'NULL', '2138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2138', '112', '4015', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4016', '1078', '1', 'Turku ja Pori', 'FI.10', 'NULL', '2139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2139', '112', '4016', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4017', '1078', '1', 'Uusimaa', 'FI.11', 'NULL', '2140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2140', '112', '4017', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4018', '1078', '1', 'Vaasa', 'FI.12', 'NULL', '2141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2141', '112', '4018', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4019', '1078', '1', 'Southern Finland', 'FI.13', 'NULL', '2142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2142', '112', '4019', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4020', '1078', '1', 'Eastern Finland', 'FI.14', 'NULL', '2143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2143', '112', '4020', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4021', '1078', '1', 'Western Finland', 'FI.15', 'NULL', '2144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2144', '112', '4021', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FI.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4022', '1078', '1', 'Fiji (general)', 'FJ.00', 'NULL', '2145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2145', '112', '4022', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FJ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4023', '1078', '1', 'Central', 'FJ.01', 'NULL', '2146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2146', '112', '4023', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FJ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4024', '1078', '1', 'Eastern', 'FJ.02', 'NULL', '2147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2147', '112', '4024', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FJ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4025', '1078', '1', 'Northern', 'FJ.03', 'NULL', '2148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2148', '112', '4025', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FJ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4026', '1078', '1', 'Rotuma', 'FJ.04', 'NULL', '2149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2149', '112', '4026', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FJ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4027', '1078', '1', 'Western', 'FJ.05', 'NULL', '2150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2150', '112', '4027', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FJ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4028', '1078', '1', 'Falkland Islands (Islas Malvinas) (general)', 'FK.00', 'NULL', '2151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2151', '112', '4028', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FK.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4029', '1078', '1', 'Micronesia, Federated States of (general)', 'FM.00', 'NULL', '2152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2152', '112', '4029', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4030', '1078', '1', 'Kosrae', 'FM.01', 'NULL', '2153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2153', '112', '4030', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4031', '1078', '1', 'Pohnpei', 'FM.02', 'NULL', '2154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2154', '112', '4031', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4032', '1078', '1', 'Chuuk', 'FM.03', 'NULL', '2155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2155', '112', '4032', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4033', '1078', '1', 'Yap', 'FM.04', 'NULL', '2156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2156', '112', '4033', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4034', '1078', '1', '', 'FM.FM', 'NULL', '2157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2157', '112', '4034', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FM.FM» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4035', '1078', '1', 'Norðoya Sýsla', 'FO.NO', 'NULL', '2158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2158', '112', '4035', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FO.NO» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4036', '1078', '1', 'Eysturoyar Sýsla', 'FO.OS', 'NULL', '2159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2159', '112', '4036', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FO.OS» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4037', '1078', '1', 'Sandoyar Sýsla', 'FO.SA', 'NULL', '2160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2160', '112', '4037', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FO.SA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4038', '1078', '1', 'Streymoyar Sýsla', 'FO.ST', 'NULL', '2161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2161', '112', '4038', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FO.ST» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4039', '1078', '1', 'Suðuroyar Sunnara Sýsla', 'FO.SU', 'NULL', '2162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2162', '112', '4039', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FO.SU» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4040', '1078', '1', 'Vága Sýsla', 'FO.VG', 'NULL', '2163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2163', '112', '4040', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FO.VG» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4041', '1078', '1', 'France (general)', 'FR.00', 'NULL', '2164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2164', '112', '4041', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4042', '1078', '1', 'Aquitaine', 'FR.97', 'NULL', '2165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2165', '112', '4042', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.97» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4043', '1078', '1', 'Auvergne', 'FR.98', 'NULL', '2166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2166', '112', '4043', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.98» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4044', '1078', '1', 'Basse-Normandie', 'FR.99', 'NULL', '2167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2167', '112', '4044', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.99» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4045', '1078', '1', 'Bourgogne', 'FR.A1', 'NULL', '2168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2168', '112', '4045', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.A1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4046', '1078', '1', 'Brittany', 'FR.A2', 'NULL', '2169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2169', '112', '4046', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.A2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4047', '1078', '1', 'Centre', 'FR.A3', 'NULL', '2170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2170', '112', '4047', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.A3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4048', '1078', '1', 'Champagne-Ardenne', 'FR.A4', 'NULL', '2171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2171', '112', '4048', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.A4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4049', '1078', '1', 'Corsica', 'FR.A5', 'NULL', '2172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2172', '112', '4049', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.A5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4050', '1078', '1', 'Franche-Comté', 'FR.A6', 'NULL', '2173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2173', '112', '4050', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.A6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4051', '1078', '1', 'Haute-Normandie', 'FR.A7', 'NULL', '2174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2174', '112', '4051', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.A7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4052', '1078', '1', 'Île-de-France', 'FR.A8', 'NULL', '2175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2175', '112', '4052', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.A8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4053', '1078', '1', 'Languedoc-Roussillon', 'FR.A9', 'NULL', '2176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2176', '112', '4053', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.A9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4054', '1078', '1', 'Limousin', 'FR.B1', 'NULL', '2177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2177', '112', '4054', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.B1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4055', '1078', '1', 'Lorraine', 'FR.B2', 'NULL', '2178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2178', '112', '4055', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.B2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4056', '1078', '1', 'Midi-Pyrénées', 'FR.B3', 'NULL', '2179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2179', '112', '4056', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.B3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4057', '1078', '1', 'Nord-Pas-de-Calais', 'FR.B4', 'NULL', '2180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2180', '112', '4057', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.B4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4058', '1078', '1', 'Pays de la Loire', 'FR.B5', 'NULL', '2181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2181', '112', '4058', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.B5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4059', '1078', '1', 'Picardie', 'FR.B6', 'NULL', '2182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2182', '112', '4059', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.B6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4060', '1078', '1', 'Poitou-Charentes', 'FR.B7', 'NULL', '2183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2183', '112', '4060', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.B7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4061', '1078', '1', 'Provence-Alpes-Côte d''Azur', 'FR.B8', 'NULL', '2184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2184', '112', '4061', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.B8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4062', '1078', '1', 'Rhône-Alpes', 'FR.B9', 'NULL', '2185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2185', '112', '4062', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.B9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4063', '1078', '1', 'Alsace', 'FR.C1', 'NULL', '2186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2186', '112', '4063', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «FR.C1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4064', '1078', '1', 'Gabon (general)', 'GA.00', 'NULL', '2187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2187', '112', '4064', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4065', '1078', '1', 'Estuaire', 'GA.01', 'NULL', '2188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2188', '112', '4065', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GA.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4066', '1078', '1', 'Haut-Ogooué', 'GA.02', 'NULL', '2189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2189', '112', '4066', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4067', '1078', '1', 'Moyen-Ogooué', 'GA.03', 'NULL', '2190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2190', '112', '4067', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GA.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4068', '1078', '1', 'Ngounié', 'GA.04', 'NULL', '2191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2191', '112', '4068', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GA.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4069', '1078', '1', 'Nyanga', 'GA.05', 'NULL', '2192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2192', '112', '4069', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GA.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4070', '1078', '1', 'Ogooué-Ivindo', 'GA.06', 'NULL', '2193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2193', '112', '4070', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GA.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4071', '1078', '1', 'Ogooué-Lolo', 'GA.07', 'NULL', '2194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2194', '112', '4071', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GA.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4072', '1078', '1', 'Ogooué-Maritime', 'GA.08', 'NULL', '2195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2195', '112', '4072', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GA.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4073', '1078', '1', 'Woleu-Ntem', 'GA.09', 'NULL', '2196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2196', '112', '4073', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GA.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4074', '1078', '1', '(UK11)', 'GB.11', 'NULL', '2197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2197', '112', '4074', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4075', '1078', '1', '(UK12)', 'GB.12', 'NULL', '2198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2198', '112', '4075', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4076', '1078', '1', '(UK13)', 'GB.13', 'NULL', '2199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2199', '112', '4076', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4077', '1078', '1', 'Greater London', 'GB.17', 'NULL', '2200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2200', '112', '4077', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4078', '1078', '1', '(UK19)', 'GB.19', 'NULL', '2201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2201', '112', '4078', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4079', '1078', '1', '(UK29)', 'GB.29', 'NULL', '2202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2202', '112', '4079', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4080', '1078', '1', '(UK32)', 'GB.32', 'NULL', '2203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2203', '112', '4080', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4081', '1078', '1', '(UK36)', 'GB.36', 'NULL', '2204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2204', '112', '4081', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4082', '1078', '1', '(UK52)', 'GB.52', 'NULL', '2205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2205', '112', '4082', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4083', '1078', '1', '(UK64)', 'GB.64', 'NULL', '2206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2206', '112', '4083', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4084', '1078', '1', '(UK80)', 'GB.80', 'NULL', '2207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2207', '112', '4084', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4085', '1078', '1', '(UK81)', 'GB.81', 'NULL', '2208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2208', '112', '4085', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4086', '1078', '1', 'Grampian', 'GB.82', 'NULL', '2209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2209', '112', '4086', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4087', '1078', '1', '(UK83)', 'GB.83', 'NULL', '2210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2210', '112', '4087', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4088', '1078', '1', 'Lothian', 'GB.84', 'NULL', '2211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2211', '112', '4088', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4089', '1078', '1', '(UK85)', 'GB.85', 'NULL', '2212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2212', '112', '4089', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4090', '1078', '1', '(UK86)', 'GB.86', 'NULL', '2213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2213', '112', '4090', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4091', '1078', '1', 'Strathclyde', 'GB.87', 'NULL', '2214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2214', '112', '4091', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.87» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4092', '1078', '1', 'Tayside', 'GB.88', 'NULL', '2215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2215', '112', '4092', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.88» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4093', '1078', '1', '(UK89)', 'GB.89', 'NULL', '2216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2216', '112', '4093', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.89» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4094', '1078', '1', 'Clwyd', 'GB.90', 'NULL', '2217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2217', '112', '4094', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.90» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4095', '1078', '1', 'Dyfed', 'GB.91', 'NULL', '2218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2218', '112', '4095', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.91» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4096', '1078', '1', 'Gwent', 'GB.92', 'NULL', '2219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2219', '112', '4096', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.92» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4097', '1078', '1', '(UK93)', 'GB.93', 'NULL', '2220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2220', '112', '4097', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.93» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4098', '1078', '1', 'South Glamorgan', 'GB.96', 'NULL', '2221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2221', '112', '4098', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.96» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4099', '1078', '1', 'Bath and North East Somerset', 'GB.A4', 'NULL', '2222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2222', '112', '4099', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.A4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4100', '1078', '1', 'England', 'GB.ENG', 'NULL', '2223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2223', '112', '4100', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.ENG» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4101', '1078', '1', 'North East Lincolnshire', 'GB.J2', 'NULL', '2224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2224', '112', '4101', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.J2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4102', '1078', '1', 'North Lincolnshire', 'GB.J3', 'NULL', '2225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2225', '112', '4102', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.J3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4103', '1078', '1', 'North Somerset', 'GB.J4', 'NULL', '2226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2226', '112', '4103', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.J4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4104', '1078', '1', 'South Gloucestershire', 'GB.M6', 'NULL', '2227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2227', '112', '4104', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.M6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4105', '1078', '1', 'Northern Ireland', 'GB.NIR', 'NULL', '2228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2228', '112', '4105', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.NIR» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4106', '1078', '1', 'Scotland', 'GB.SCT', 'NULL', '2229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2229', '112', '4106', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.SCT» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4107', '1078', '1', 'Argyll and Bute', 'GB.T8', 'NULL', '2230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2230', '112', '4107', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.T8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4108', '1078', '1', 'Wales', 'GB.WLS', 'NULL', '2231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2231', '112', '4108', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GB.WLS» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4109', '1078', '1', 'Grenada (general)', 'GD.00', 'NULL', '2232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2232', '112', '4109', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GD.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4110', '1078', '1', 'Saint Andrew', 'GD.01', 'NULL', '2233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2233', '112', '4110', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GD.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4111', '1078', '1', 'Saint David', 'GD.02', 'NULL', '2234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2234', '112', '4111', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GD.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4112', '1078', '1', 'Saint George', 'GD.03', 'NULL', '2235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2235', '112', '4112', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GD.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4113', '1078', '1', 'Saint John', 'GD.04', 'NULL', '2236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2236', '112', '4113', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GD.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4114', '1078', '1', 'Saint Mark', 'GD.05', 'NULL', '2237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2237', '112', '4114', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GD.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4115', '1078', '1', 'Saint Patrick', 'GD.06', 'NULL', '2238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2238', '112', '4115', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GD.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4116', '1078', '1', 'Abkhazia', 'GE.00', 'NULL', '2239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2239', '112', '4116', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4117', '1078', '1', 'Ajaria', 'GE.04', 'NULL', '2240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2240', '112', '4117', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GE.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4118', '1078', '1', 'Chʼkhorotsqus Raioni', 'GE.15', 'NULL', '2241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2241', '112', '4118', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GE.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4119', '1078', '1', 'Martvilis Raioni', 'GE.36', 'NULL', '2242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2242', '112', '4119', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GE.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4120', '1078', '1', 'T''bilisi', 'GE.51', 'NULL', '2243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2243', '112', '4120', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GE.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4121', '1078', '1', 'Zugdidis Raioni', 'GE.64', 'NULL', '2244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2244', '112', '4121', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GE.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4122', '1078', '1', 'Guyane', 'GF.GF', 'NULL', '2245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2245', '112', '4122', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GF.GF» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4123', '1078', '1', 'Guernsey (general)', 'GG.00', 'NULL', '2246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2246', '112', '4123', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4124', '1078', '1', 'Ghana (general)', 'GH.00', 'NULL', '2247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2247', '112', '4124', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4125', '1078', '1', 'Greater Accra', 'GH.01', 'NULL', '2248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2248', '112', '4125', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4126', '1078', '1', 'Ashanti', 'GH.02', 'NULL', '2249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2249', '112', '4126', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4127', '1078', '1', 'Brong-Ahafo Region', 'GH.03', 'NULL', '2250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2250', '112', '4127', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4128', '1078', '1', 'Central', 'GH.04', 'NULL', '2251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2251', '112', '4128', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4129', '1078', '1', 'Eastern', 'GH.05', 'NULL', '2252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2252', '112', '4129', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4130', '1078', '1', 'Northern', 'GH.06', 'NULL', '2253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2253', '112', '4130', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4131', '1078', '1', 'Volta', 'GH.08', 'NULL', '2254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2254', '112', '4131', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4132', '1078', '1', 'Western', 'GH.09', 'NULL', '2255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2255', '112', '4132', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4133', '1078', '1', 'Upper East', 'GH.10', 'NULL', '2256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2256', '112', '4133', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4134', '1078', '1', 'Upper West', 'GH.11', 'NULL', '2257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2257', '112', '4134', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GH.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4135', '1078', '1', 'Gibraltar (general)', 'GI.00', 'NULL', '2258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2258', '112', '4135', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GI.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4136', '1078', '1', 'Greenland (general)', 'GL.00', 'NULL', '2259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2259', '112', '4136', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GL.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4137', '1078', '1', 'Nordgrønland', 'GL.01', 'NULL', '2260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2260', '112', '4137', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GL.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4138', '1078', '1', 'Østgrønland', 'GL.02', 'NULL', '2261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2261', '112', '4138', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GL.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4139', '1078', '1', 'Vestgrønland', 'GL.03', 'NULL', '2262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2262', '112', '4139', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GL.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4140', '1078', '1', 'Gambia, The (general)', 'GM.00', 'NULL', '2263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2263', '112', '4140', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4141', '1078', '1', 'Banjul', 'GM.01', 'NULL', '2264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2264', '112', '4141', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4142', '1078', '1', 'Lower River', 'GM.02', 'NULL', '2265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2265', '112', '4142', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4143', '1078', '1', 'Central River', 'GM.03', 'NULL', '2266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2266', '112', '4143', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4144', '1078', '1', 'Upper River', 'GM.04', 'NULL', '2267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2267', '112', '4144', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4145', '1078', '1', 'Western', 'GM.05', 'NULL', '2268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2268', '112', '4145', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GM.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4146', '1078', '1', 'North Bank', 'GM.07', 'NULL', '2269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2269', '112', '4146', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GM.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4147', '1078', '1', 'Guinea (general)', 'GN.00', 'NULL', '2270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2270', '112', '4147', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4148', '1078', '1', 'Beyla', 'GN.01', 'NULL', '2271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2271', '112', '4148', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4149', '1078', '1', 'Boffa', 'GN.02', 'NULL', '2272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2272', '112', '4149', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4150', '1078', '1', 'Boké', 'GN.03', 'NULL', '2273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2273', '112', '4150', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4151', '1078', '1', 'Conakry', 'GN.04', 'NULL', '2274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2274', '112', '4151', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4152', '1078', '1', 'Dabola', 'GN.05', 'NULL', '2275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2275', '112', '4152', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4153', '1078', '1', 'Dalaba', 'GN.06', 'NULL', '2276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2276', '112', '4153', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4154', '1078', '1', 'Dinguiraye', 'GN.07', 'NULL', '2277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2277', '112', '4154', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4155', '1078', '1', '(GV08)', 'GN.08', 'NULL', '2278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2278', '112', '4155', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4156', '1078', '1', 'Faranah', 'GN.09', 'NULL', '2279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2279', '112', '4156', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4157', '1078', '1', 'Forécariah', 'GN.10', 'NULL', '2280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2280', '112', '4157', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4158', '1078', '1', 'Fria', 'GN.11', 'NULL', '2281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2281', '112', '4158', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4159', '1078', '1', 'Gaoual', 'GN.12', 'NULL', '2282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2282', '112', '4159', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4160', '1078', '1', 'Guéckédou', 'GN.13', 'NULL', '2283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2283', '112', '4160', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4161', '1078', '1', '(GV14)', 'GN.14', 'NULL', '2284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2284', '112', '4161', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4162', '1078', '1', 'Kérouané', 'GN.15', 'NULL', '2285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2285', '112', '4162', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4163', '1078', '1', 'Kindia', 'GN.16', 'NULL', '2286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2286', '112', '4163', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4164', '1078', '1', 'Kissidougou', 'GN.17', 'NULL', '2287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2287', '112', '4164', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4165', '1078', '1', 'Koundara', 'GN.18', 'NULL', '2288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2288', '112', '4165', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4166', '1078', '1', 'Kouroussa', 'GN.19', 'NULL', '2289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2289', '112', '4166', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4167', '1078', '1', '(GV20)', 'GN.20', 'NULL', '2290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2290', '112', '4167', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4168', '1078', '1', 'Macenta', 'GN.21', 'NULL', '2291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2291', '112', '4168', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4169', '1078', '1', 'Mali', 'GN.22', 'NULL', '2292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2292', '112', '4169', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4170', '1078', '1', 'Mamou', 'GN.23', 'NULL', '2293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2293', '112', '4170', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4171', '1078', '1', '(GV24)', 'GN.24', 'NULL', '2294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2294', '112', '4171', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4172', '1078', '1', 'Pita', 'GN.25', 'NULL', '2295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2295', '112', '4172', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4173', '1078', '1', '(GV26)', 'GN.26', 'NULL', '2296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2296', '112', '4173', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4174', '1078', '1', 'Télimélé', 'GN.27', 'NULL', '2297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2297', '112', '4174', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4175', '1078', '1', 'Tougué', 'GN.28', 'NULL', '2298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2298', '112', '4175', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4176', '1078', '1', 'Yomou', 'GN.29', 'NULL', '2299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2299', '112', '4176', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4177', '1078', '1', 'Coyah', 'GN.30', 'NULL', '2300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2300', '112', '4177', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4178', '1078', '1', 'Dubréka', 'GN.31', 'NULL', '2301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2301', '112', '4178', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4179', '1078', '1', 'Kankan', 'GN.32', 'NULL', '2302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2302', '112', '4179', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4180', '1078', '1', 'Koubia', 'GN.33', 'NULL', '2303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2303', '112', '4180', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4181', '1078', '1', 'Labé', 'GN.34', 'NULL', '2304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2304', '112', '4181', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4182', '1078', '1', 'Lélouma', 'GN.35', 'NULL', '2305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2305', '112', '4182', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4183', '1078', '1', 'Lola', 'GN.36', 'NULL', '2306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2306', '112', '4183', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4184', '1078', '1', 'Mandiana', 'GN.37', 'NULL', '2307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2307', '112', '4184', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4185', '1078', '1', 'Nzérékoré', 'GN.38', 'NULL', '2308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2308', '112', '4185', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4186', '1078', '1', 'Siguiri', 'GN.39', 'NULL', '2309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2309', '112', '4186', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GN.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4187', '1078', '1', 'Région Guadeloupe', 'GP.GP', 'NULL', '2310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2310', '112', '4187', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GP.GP» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4188', '1078', '1', 'Equatorial Guinea (general)', 'GQ.00', 'NULL', '2311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2311', '112', '4188', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GQ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4189', '1078', '1', 'Annobón', 'GQ.03', 'NULL', '2312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2312', '112', '4189', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GQ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4190', '1078', '1', 'Bioko Norte', 'GQ.04', 'NULL', '2313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2313', '112', '4190', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GQ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4191', '1078', '1', 'Bioko Sur', 'GQ.05', 'NULL', '2314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2314', '112', '4191', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GQ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4192', '1078', '1', 'Centro Sur', 'GQ.06', 'NULL', '2315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2315', '112', '4192', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GQ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4193', '1078', '1', 'Kié-Ntem', 'GQ.07', 'NULL', '2316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2316', '112', '4193', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GQ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4194', '1078', '1', 'Litoral', 'GQ.08', 'NULL', '2317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2317', '112', '4194', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GQ.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4195', '1078', '1', 'Wele-Nzas', 'GQ.09', 'NULL', '2318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2318', '112', '4195', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GQ.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4196', '1078', '1', 'East Macedonia and Thrace', 'GR.ESYE11', 'NULL', '2319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2319', '112', '4196', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4197', '1078', '1', 'Central Macedonia', 'GR.ESYE12', 'NULL', '2320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2320', '112', '4197', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4198', '1078', '1', 'West Macedonia', 'GR.ESYE13', 'NULL', '2321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2321', '112', '4198', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4199', '1078', '1', 'Thessaly', 'GR.ESYE14', 'NULL', '2322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2322', '112', '4199', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4200', '1078', '1', 'Epirus', 'GR.ESYE21', 'NULL', '2323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2323', '112', '4200', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4201', '1078', '1', 'Ionian Islands', 'GR.ESYE22', 'NULL', '2324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2324', '112', '4201', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4202', '1078', '1', 'West Greece', 'GR.ESYE23', 'NULL', '2325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2325', '112', '4202', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4203', '1078', '1', 'Central Greece', 'GR.ESYE24', 'NULL', '2326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2326', '112', '4203', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4204', '1078', '1', 'Peloponnese', 'GR.ESYE25', 'NULL', '2327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2327', '112', '4204', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4205', '1078', '1', 'Attica', 'GR.ESYE31', 'NULL', '2328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2328', '112', '4205', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4206', '1078', '1', 'North Aegean', 'GR.ESYE41', 'NULL', '2329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2329', '112', '4206', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4207', '1078', '1', 'South Aegean', 'GR.ESYE42', 'NULL', '2330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2330', '112', '4207', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4208', '1078', '1', 'Crete', 'GR.ESYE43', 'NULL', '2331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2331', '112', '4208', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GR.ESYE43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4209', '1078', '1', 'South Georgia and The South Sandwich Islands (general)', 'GS.00', 'NULL', '2332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2332', '112', '4209', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GS.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4210', '1078', '1', 'Guatemala (general)', 'GT.00', 'NULL', '2333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2333', '112', '4210', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4211', '1078', '1', 'Alta Verapaz', 'GT.01', 'NULL', '2334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2334', '112', '4211', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4212', '1078', '1', 'Baja Verapaz', 'GT.02', 'NULL', '2335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2335', '112', '4212', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4213', '1078', '1', 'Chimaltenango', 'GT.03', 'NULL', '2336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2336', '112', '4213', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4214', '1078', '1', 'Chiquimula', 'GT.04', 'NULL', '2337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2337', '112', '4214', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4215', '1078', '1', 'El Progreso', 'GT.05', 'NULL', '2338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2338', '112', '4215', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4216', '1078', '1', 'Escuintla', 'GT.06', 'NULL', '2339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2339', '112', '4216', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4217', '1078', '1', 'Guatemala', 'GT.07', 'NULL', '2340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2340', '112', '4217', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4218', '1078', '1', 'Huehuetenango', 'GT.08', 'NULL', '2341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2341', '112', '4218', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4219', '1078', '1', 'Izabal', 'GT.09', 'NULL', '2342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2342', '112', '4219', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4220', '1078', '1', 'Jalapa', 'GT.10', 'NULL', '2343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2343', '112', '4220', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4221', '1078', '1', 'Jutiapa', 'GT.11', 'NULL', '2344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2344', '112', '4221', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4222', '1078', '1', 'Petén', 'GT.12', 'NULL', '2345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2345', '112', '4222', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4223', '1078', '1', 'Quetzaltenango', 'GT.13', 'NULL', '2346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2346', '112', '4223', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4224', '1078', '1', 'Quiché', 'GT.14', 'NULL', '2347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2347', '112', '4224', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4225', '1078', '1', 'Retalhuleu', 'GT.15', 'NULL', '2348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2348', '112', '4225', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4226', '1078', '1', 'Sacatepéquez', 'GT.16', 'NULL', '2349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2349', '112', '4226', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4227', '1078', '1', 'San Marcos', 'GT.17', 'NULL', '2350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2350', '112', '4227', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4228', '1078', '1', 'Santa Rosa', 'GT.18', 'NULL', '2351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2351', '112', '4228', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4229', '1078', '1', 'Sololá', 'GT.19', 'NULL', '2352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2352', '112', '4229', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4230', '1078', '1', 'Suchitepéquez', 'GT.20', 'NULL', '2353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2353', '112', '4230', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4231', '1078', '1', 'Totonicapán', 'GT.21', 'NULL', '2354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2354', '112', '4231', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4232', '1078', '1', 'Zacapa', 'GT.22', 'NULL', '2355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2355', '112', '4232', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GT.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4233', '1078', '1', 'Guinea-Bissau (general)', 'GW.00', 'NULL', '2356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2356', '112', '4233', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GW.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4234', '1078', '1', 'Bafatá', 'GW.01', 'NULL', '2357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2357', '112', '4234', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GW.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4235', '1078', '1', 'Quinara', 'GW.02', 'NULL', '2358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2358', '112', '4235', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GW.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4236', '1078', '1', 'Oio', 'GW.04', 'NULL', '2359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2359', '112', '4236', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GW.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4237', '1078', '1', 'Bolama', 'GW.05', 'NULL', '2360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2360', '112', '4237', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GW.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4238', '1078', '1', 'Cacheu', 'GW.06', 'NULL', '2361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2361', '112', '4238', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GW.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4239', '1078', '1', 'Tombali', 'GW.07', 'NULL', '2362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2362', '112', '4239', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GW.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4240', '1078', '1', 'Gabú', 'GW.10', 'NULL', '2363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2363', '112', '4240', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GW.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4241', '1078', '1', 'Bissau', 'GW.11', 'NULL', '2364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2364', '112', '4241', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GW.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4242', '1078', '1', 'Biombo', 'GW.12', 'NULL', '2365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2365', '112', '4242', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GW.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4243', '1078', '1', 'Guyana (general)', 'GY.00', 'NULL', '2366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2366', '112', '4243', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4244', '1078', '1', 'Barima-Waini', 'GY.10', 'NULL', '2367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2367', '112', '4244', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4245', '1078', '1', 'Cuyuni-Mazaruni', 'GY.11', 'NULL', '2368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2368', '112', '4245', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4246', '1078', '1', 'Demerara-Mahaica', 'GY.12', 'NULL', '2369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2369', '112', '4246', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4247', '1078', '1', 'East Berbice-Corentyne', 'GY.13', 'NULL', '2370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2370', '112', '4247', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4248', '1078', '1', 'Essequibo Islands-West Demerara', 'GY.14', 'NULL', '2371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2371', '112', '4248', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4249', '1078', '1', 'Mahaica-Berbice', 'GY.15', 'NULL', '2372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2372', '112', '4249', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4250', '1078', '1', 'Pomeroon-Supenaam', 'GY.16', 'NULL', '2373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2373', '112', '4250', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4251', '1078', '1', 'Potaro-Siparuni', 'GY.17', 'NULL', '2374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2374', '112', '4251', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4252', '1078', '1', 'Upper Demerara-Berbice', 'GY.18', 'NULL', '2375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2375', '112', '4252', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4253', '1078', '1', 'Upper Takutu-Upper Essequibo', 'GY.19', 'NULL', '2376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2376', '112', '4253', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «GY.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4254', '1078', '1', 'Hong Kong (general)', 'HK.00', 'NULL', '2377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2377', '112', '4254', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HK.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4255', '1078', '1', 'Honduras (general)', 'HN.00', 'NULL', '2378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2378', '112', '4255', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4256', '1078', '1', 'Atlántida', 'HN.01', 'NULL', '2379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2379', '112', '4256', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4257', '1078', '1', 'Choluteca', 'HN.02', 'NULL', '2380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2380', '112', '4257', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4258', '1078', '1', 'Colón', 'HN.03', 'NULL', '2381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2381', '112', '4258', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4259', '1078', '1', 'Comayagua', 'HN.04', 'NULL', '2382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2382', '112', '4259', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4260', '1078', '1', 'Copán', 'HN.05', 'NULL', '2383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2383', '112', '4260', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4261', '1078', '1', 'Cortés', 'HN.06', 'NULL', '2384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2384', '112', '4261', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4262', '1078', '1', 'El Paraíso', 'HN.07', 'NULL', '2385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2385', '112', '4262', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4263', '1078', '1', 'Francisco Morazán', 'HN.08', 'NULL', '2386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2386', '112', '4263', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4264', '1078', '1', 'Gracias a Dios', 'HN.09', 'NULL', '2387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2387', '112', '4264', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4265', '1078', '1', 'Intibucá', 'HN.10', 'NULL', '2388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2388', '112', '4265', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4266', '1078', '1', 'Islas de la Bahía', 'HN.11', 'NULL', '2389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2389', '112', '4266', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4267', '1078', '1', 'La Paz', 'HN.12', 'NULL', '2390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2390', '112', '4267', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4268', '1078', '1', 'Lempira', 'HN.13', 'NULL', '2391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2391', '112', '4268', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4269', '1078', '1', 'Ocotepeque', 'HN.14', 'NULL', '2392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2392', '112', '4269', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4270', '1078', '1', 'Olancho', 'HN.15', 'NULL', '2393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2393', '112', '4270', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4271', '1078', '1', 'Santa Bárbara', 'HN.16', 'NULL', '2394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2394', '112', '4271', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4272', '1078', '1', 'Valle', 'HN.17', 'NULL', '2395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2395', '112', '4272', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4273', '1078', '1', 'Yoro', 'HN.18', 'NULL', '2396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2396', '112', '4273', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HN.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4274', '1078', '1', 'Croatia (general)', 'HR.00', 'NULL', '2397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2397', '112', '4274', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4275', '1078', '1', 'Bjelovarsko-Bilogorska', 'HR.01', 'NULL', '2398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2398', '112', '4275', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4276', '1078', '1', 'Brodsko-Posavska', 'HR.02', 'NULL', '2399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2399', '112', '4276', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4277', '1078', '1', 'Dubrovačko-Neretvanska', 'HR.03', 'NULL', '2400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2400', '112', '4277', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4278', '1078', '1', 'Istarska', 'HR.04', 'NULL', '2401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2401', '112', '4278', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4279', '1078', '1', 'Karlovačka', 'HR.05', 'NULL', '2402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2402', '112', '4279', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4280', '1078', '1', 'Koprivničko-Križevačka', 'HR.06', 'NULL', '2403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2403', '112', '4280', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4281', '1078', '1', 'Krapinsko-Zagorska', 'HR.07', 'NULL', '2404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2404', '112', '4281', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4282', '1078', '1', 'Ličko-Senjska', 'HR.08', 'NULL', '2405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2405', '112', '4282', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4283', '1078', '1', 'Međimurska', 'HR.09', 'NULL', '2406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2406', '112', '4283', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4284', '1078', '1', 'Osječko-Baranjska', 'HR.10', 'NULL', '2407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2407', '112', '4284', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4285', '1078', '1', 'Požeško-Slavonska', 'HR.11', 'NULL', '2408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2408', '112', '4285', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4286', '1078', '1', 'Primorsko-Goranska', 'HR.12', 'NULL', '2409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2409', '112', '4286', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4287', '1078', '1', 'Šibensko-Kniniska', 'HR.13', 'NULL', '2410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2410', '112', '4287', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4288', '1078', '1', 'Sisačko-Moslavačka', 'HR.14', 'NULL', '2411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2411', '112', '4288', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4289', '1078', '1', 'Splitsko-Dalmatinska', 'HR.15', 'NULL', '2412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2412', '112', '4289', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4290', '1078', '1', 'Varaždinska', 'HR.16', 'NULL', '2413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2413', '112', '4290', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4291', '1078', '1', 'Virovitičk-Podravska', 'HR.17', 'NULL', '2414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2414', '112', '4291', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4292', '1078', '1', 'Vukovarsko-Srijemska', 'HR.18', 'NULL', '2415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2415', '112', '4292', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4293', '1078', '1', 'Zadarska', 'HR.19', 'NULL', '2416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2416', '112', '4293', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4294', '1078', '1', 'Zagrebačka', 'HR.20', 'NULL', '2417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2417', '112', '4294', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4295', '1078', '1', 'Grad Zagreb', 'HR.21', 'NULL', '2418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2418', '112', '4295', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HR.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4296', '1078', '1', 'Haiti (general)', 'HT.00', 'NULL', '2419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2419', '112', '4296', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HT.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4297', '1078', '1', 'Nord-Ouest', 'HT.03', 'NULL', '2420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2420', '112', '4297', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HT.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4298', '1078', '1', 'Artibonite', 'HT.06', 'NULL', '2421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2421', '112', '4298', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HT.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4299', '1078', '1', 'Centre', 'HT.07', 'NULL', '2422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2422', '112', '4299', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HT.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4300', '1078', '1', 'Nord', 'HT.09', 'NULL', '2423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2423', '112', '4300', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HT.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4301', '1078', '1', 'Nord-Est', 'HT.10', 'NULL', '2424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2424', '112', '4301', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HT.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4302', '1078', '1', 'Ouest', 'HT.11', 'NULL', '2425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2425', '112', '4302', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HT.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4303', '1078', '1', 'Sud', 'HT.12', 'NULL', '2426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2426', '112', '4303', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HT.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4304', '1078', '1', 'Sud-Est', 'HT.13', 'NULL', '2427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2427', '112', '4304', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HT.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4305', '1078', '1', 'GrandʼAnse', 'HT.14', 'NULL', '2428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2428', '112', '4305', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HT.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4306', '1078', '1', 'Hungary (general)', 'HU.00', 'NULL', '2429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2429', '112', '4306', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4307', '1078', '1', 'Bács-Kiskun', 'HU.01', 'NULL', '2430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2430', '112', '4307', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4308', '1078', '1', 'Baranya', 'HU.02', 'NULL', '2431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2431', '112', '4308', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4309', '1078', '1', 'Békés', 'HU.03', 'NULL', '2432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2432', '112', '4309', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4310', '1078', '1', 'Borsod-Abaúj-Zemplén', 'HU.04', 'NULL', '2433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2433', '112', '4310', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4311', '1078', '1', 'Budapest', 'HU.05', 'NULL', '2434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2434', '112', '4311', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4312', '1078', '1', 'Csongrád', 'HU.06', 'NULL', '2435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2435', '112', '4312', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4313', '1078', '1', 'Fejér', 'HU.08', 'NULL', '2436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2436', '112', '4313', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4314', '1078', '1', 'Győr-Moson-Sopron', 'HU.09', 'NULL', '2437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2437', '112', '4314', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4315', '1078', '1', 'Hajdú-Bihar', 'HU.10', 'NULL', '2438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2438', '112', '4315', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4316', '1078', '1', 'Heves', 'HU.11', 'NULL', '2439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2439', '112', '4316', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4317', '1078', '1', 'Komárom-Esztergom', 'HU.12', 'NULL', '2440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2440', '112', '4317', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4318', '1078', '1', 'Nógrád', 'HU.14', 'NULL', '2441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2441', '112', '4318', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4319', '1078', '1', 'Pest', 'HU.16', 'NULL', '2442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2442', '112', '4319', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4320', '1078', '1', 'Somogy', 'HU.17', 'NULL', '2443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2443', '112', '4320', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4321', '1078', '1', 'Szabolcs-Szatmár-Bereg', 'HU.18', 'NULL', '2444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2444', '112', '4321', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4322', '1078', '1', 'Jász-Nagykun-Szolnok', 'HU.20', 'NULL', '2445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2445', '112', '4322', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4323', '1078', '1', 'Tolna', 'HU.21', 'NULL', '2446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2446', '112', '4323', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4324', '1078', '1', 'Vas', 'HU.22', 'NULL', '2447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2447', '112', '4324', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4325', '1078', '1', 'Veszprém', 'HU.23', 'NULL', '2448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2448', '112', '4325', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4326', '1078', '1', 'Zala', 'HU.24', 'NULL', '2449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2449', '112', '4326', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «HU.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4327', '1078', '1', 'Indonesia (general) ', 'ID.00', 'NULL', '2450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2450', '112', '4327', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4328', '1078', '1', 'Aceh', 'ID.01', 'NULL', '2451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2451', '112', '4328', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4329', '1078', '1', 'Bali', 'ID.02', 'NULL', '2452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2452', '112', '4329', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4330', '1078', '1', 'Bengkulu', 'ID.03', 'NULL', '2453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2453', '112', '4330', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4331', '1078', '1', 'Jakarta Raya', 'ID.04', 'NULL', '2454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2454', '112', '4331', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4332', '1078', '1', 'Jambi', 'ID.05', 'NULL', '2455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2455', '112', '4332', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4333', '1078', '1', 'Jawa Barat', 'ID.06', 'NULL', '2456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2456', '112', '4333', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4334', '1078', '1', 'East Java', 'ID.08', 'NULL', '2457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2457', '112', '4334', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4335', '1078', '1', '(ID09) ', 'ID.09', 'NULL', '2458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2458', '112', '4335', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4336', '1078', '1', 'Yogyakarta ', 'ID.10', 'NULL', '2459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2459', '112', '4336', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4337', '1078', '1', 'West Kalimantan', 'ID.11', 'NULL', '2460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2460', '112', '4337', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4338', '1078', '1', 'South Kalimantan', 'ID.12', 'NULL', '2461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2461', '112', '4338', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4339', '1078', '1', 'Kalimantan Tengah', 'ID.13', 'NULL', '2462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2462', '112', '4339', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4340', '1078', '1', 'East Kalimantan', 'ID.14', 'NULL', '2463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2463', '112', '4340', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4341', '1078', '1', 'Lampung', 'ID.15', 'NULL', '2464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2464', '112', '4341', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4342', '1078', '1', 'Nusa Tenggara Barat', 'ID.17', 'NULL', '2465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2465', '112', '4342', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4343', '1078', '1', 'East Nusa Tenggara', 'ID.18', 'NULL', '2466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2466', '112', '4343', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4344', '1078', '1', '(ID19) ', 'ID.19', 'NULL', '2467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2467', '112', '4344', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4345', '1078', '1', '(ID20) ', 'ID.20', 'NULL', '2468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2468', '112', '4345', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4346', '1078', '1', 'Central Sulawesi', 'ID.21', 'NULL', '2469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2469', '112', '4346', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4347', '1078', '1', 'Sulawesi Tenggara', 'ID.22', 'NULL', '2470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2470', '112', '4347', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4348', '1078', '1', 'Sulawesi Utara', 'ID.23', 'NULL', '2471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2471', '112', '4348', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4349', '1078', '1', 'West Sumatra', 'ID.24', 'NULL', '2472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2472', '112', '4349', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4350', '1078', '1', 'Sumatera Selatan', 'ID.25', 'NULL', '2473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2473', '112', '4350', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4351', '1078', '1', 'North Sumatra', 'ID.26', 'NULL', '2474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2474', '112', '4351', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4352', '1078', '1', 'Timor Timur', 'ID.27', 'NULL', '2475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2475', '112', '4352', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4353', '1078', '1', 'Maluku ', 'ID.28', 'NULL', '2476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2476', '112', '4353', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4354', '1078', '1', 'Maluku Utara', 'ID.29', 'NULL', '2477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2477', '112', '4354', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4355', '1078', '1', 'West Java', 'ID.30', 'NULL', '2478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2478', '112', '4355', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4356', '1078', '1', 'North Sulawesi', 'ID.31', 'NULL', '2479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2479', '112', '4356', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4357', '1078', '1', 'South Sumatra', 'ID.32', 'NULL', '2480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2480', '112', '4357', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4358', '1078', '1', 'Banten', 'ID.33', 'NULL', '2481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2481', '112', '4358', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4359', '1078', '1', 'Gorontalo', 'ID.34', 'NULL', '2482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2482', '112', '4359', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4360', '1078', '1', 'Bangka-Belitung', 'ID.35', 'NULL', '2483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2483', '112', '4360', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4361', '1078', '1', 'Papua', 'ID.36', 'NULL', '2484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2484', '112', '4361', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4362', '1078', '1', 'Riau', 'ID.37', 'NULL', '2485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2485', '112', '4362', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4363', '1078', '1', 'South Sulawesi', 'ID.38', 'NULL', '2486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2486', '112', '4363', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4364', '1078', '1', 'Irian Jaya Barat', 'ID.39', 'NULL', '2487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2487', '112', '4364', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4365', '1078', '1', 'Riau Islands', 'ID.40', 'NULL', '2488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2488', '112', '4365', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4366', '1078', '1', 'Sulawesi Barat', 'ID.41', 'NULL', '2489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2489', '112', '4366', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ID.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4367', '1078', '1', 'Ireland (general)', 'IE.00', 'NULL', '2490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2490', '112', '4367', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4368', '1078', '1', 'Carlow', 'IE.01', 'NULL', '2491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2491', '112', '4368', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4369', '1078', '1', 'County Cavan', 'IE.02', 'NULL', '2492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2492', '112', '4369', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4370', '1078', '1', 'County Clare', 'IE.03', 'NULL', '2493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2493', '112', '4370', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4371', '1078', '1', 'Cork', 'IE.04', 'NULL', '2494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2494', '112', '4371', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4372', '1078', '1', 'Donegal', 'IE.06', 'NULL', '2495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2495', '112', '4372', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4373', '1078', '1', 'Dublin', 'IE.07', 'NULL', '2496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2496', '112', '4373', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4374', '1078', '1', 'Galway', 'IE.10', 'NULL', '2497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2497', '112', '4374', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4375', '1078', '1', 'County Kerry', 'IE.11', 'NULL', '2498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2498', '112', '4375', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4376', '1078', '1', 'County Kildare', 'IE.12', 'NULL', '2499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2499', '112', '4376', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4377', '1078', '1', 'County Kilkenny', 'IE.13', 'NULL', '2500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2500', '112', '4377', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4378', '1078', '1', 'Leitrim', 'IE.14', 'NULL', '2501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2501', '112', '4378', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4379', '1078', '1', 'Leix', 'IE.15', 'NULL', '2502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2502', '112', '4379', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4380', '1078', '1', 'Limerick', 'IE.16', 'NULL', '2503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2503', '112', '4380', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4381', '1078', '1', 'County Longford', 'IE.18', 'NULL', '2504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2504', '112', '4381', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4382', '1078', '1', 'County Louth', 'IE.19', 'NULL', '2505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2505', '112', '4382', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4383', '1078', '1', 'County Mayo', 'IE.20', 'NULL', '2506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2506', '112', '4383', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4384', '1078', '1', 'County Meath', 'IE.21', 'NULL', '2507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2507', '112', '4384', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4385', '1078', '1', 'Monaghan', 'IE.22', 'NULL', '2508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2508', '112', '4385', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4386', '1078', '1', 'County Offaly', 'IE.23', 'NULL', '2509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2509', '112', '4386', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4387', '1078', '1', 'County Roscommon', 'IE.24', 'NULL', '2510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2510', '112', '4387', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4388', '1078', '1', 'County Sligo', 'IE.25', 'NULL', '2511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2511', '112', '4388', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4389', '1078', '1', 'Tipperary', 'IE.26', 'NULL', '2512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2512', '112', '4389', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4390', '1078', '1', 'County Waterford', 'IE.27', 'NULL', '2513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2513', '112', '4390', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4391', '1078', '1', 'County Westmeath', 'IE.29', 'NULL', '2514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2514', '112', '4391', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4392', '1078', '1', 'County Wexford', 'IE.30', 'NULL', '2515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2515', '112', '4392', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4393', '1078', '1', 'County Wicklow', 'IE.31', 'NULL', '2516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2516', '112', '4393', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IE.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4394', '1078', '1', 'Israel (general)', 'IL.00', 'NULL', '2517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2517', '112', '4394', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IL.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4395', '1078', '1', 'HaDarom', 'IL.01', 'NULL', '2518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2518', '112', '4395', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IL.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4396', '1078', '1', 'HaMerkaz', 'IL.02', 'NULL', '2519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2519', '112', '4396', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IL.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4397', '1078', '1', 'Northern District', 'IL.03', 'NULL', '2520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2520', '112', '4397', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IL.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4398', '1078', '1', 'H̱efa', 'IL.04', 'NULL', '2521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2521', '112', '4398', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IL.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4399', '1078', '1', 'Tel Aviv', 'IL.05', 'NULL', '2522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2522', '112', '4399', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IL.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4400', '1078', '1', 'Yerushalayim', 'IL.06', 'NULL', '2523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2523', '112', '4400', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IL.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4401', '1078', '1', 'Isle of Man (general)', 'IM.00', 'NULL', '2524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2524', '112', '4401', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4402', '1078', '1', 'India (general)', 'IN.00', 'NULL', '2525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2525', '112', '4402', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4403', '1078', '1', 'Andaman and Nicobar Islands', 'IN.01', 'NULL', '2526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2526', '112', '4403', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4404', '1078', '1', 'Andhra Pradesh', 'IN.02', 'NULL', '2527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2527', '112', '4404', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4405', '1078', '1', 'Assam', 'IN.03', 'NULL', '2528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2528', '112', '4405', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4406', '1078', '1', 'Bihar', 'IN.04', 'NULL', '2529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2529', '112', '4406', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4407', '1078', '1', 'Chandīgarh', 'IN.05', 'NULL', '2530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2530', '112', '4407', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4408', '1078', '1', 'Dādra and Nagar Haveli', 'IN.06', 'NULL', '2531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2531', '112', '4408', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4409', '1078', '1', 'Delhi', 'IN.07', 'NULL', '2532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2532', '112', '4409', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4410', '1078', '1', 'Gujarāt', 'IN.09', 'NULL', '2533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2533', '112', '4410', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4411', '1078', '1', 'Haryāna', 'IN.10', 'NULL', '2534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2534', '112', '4411', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4412', '1078', '1', 'Himāchal Pradesh', 'IN.11', 'NULL', '2535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2535', '112', '4412', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4413', '1078', '1', 'Kashmir', 'IN.12', 'NULL', '2536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2536', '112', '4413', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4414', '1078', '1', 'Kerala', 'IN.13', 'NULL', '2537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2537', '112', '4414', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4415', '1078', '1', 'Laccadives', 'IN.14', 'NULL', '2538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2538', '112', '4415', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4416', '1078', '1', 'Madhya Pradesh ', 'IN.15', 'NULL', '2539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2539', '112', '4416', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4417', '1078', '1', 'Mahārāshtra', 'IN.16', 'NULL', '2540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2540', '112', '4417', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4418', '1078', '1', 'Manipur', 'IN.17', 'NULL', '2541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2541', '112', '4418', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4419', '1078', '1', 'Meghālaya', 'IN.18', 'NULL', '2542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2542', '112', '4419', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4420', '1078', '1', 'Karnātaka', 'IN.19', 'NULL', '2543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2543', '112', '4420', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4421', '1078', '1', 'Nāgāland', 'IN.20', 'NULL', '2544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2544', '112', '4421', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4422', '1078', '1', 'Orissa', 'IN.21', 'NULL', '2545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2545', '112', '4422', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4423', '1078', '1', 'Pondicherry', 'IN.22', 'NULL', '2546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2546', '112', '4423', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4424', '1078', '1', 'Punjab', 'IN.23', 'NULL', '2547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2547', '112', '4424', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4425', '1078', '1', 'Rājasthān', 'IN.24', 'NULL', '2548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2548', '112', '4425', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4426', '1078', '1', 'Tamil Nādu', 'IN.25', 'NULL', '2549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2549', '112', '4426', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4427', '1078', '1', 'Tripura', 'IN.26', 'NULL', '2550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2550', '112', '4427', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4428', '1078', '1', 'Uttar Pradesh', 'IN.27', 'NULL', '2551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2551', '112', '4428', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4429', '1078', '1', 'Bengal', 'IN.28', 'NULL', '2552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2552', '112', '4429', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4430', '1078', '1', 'Sikkim', 'IN.29', 'NULL', '2553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2553', '112', '4430', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4431', '1078', '1', 'Arunāchal Pradesh', 'IN.30', 'NULL', '2554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2554', '112', '4431', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4432', '1078', '1', 'Mizoram', 'IN.31', 'NULL', '2555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2555', '112', '4432', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4433', '1078', '1', 'Daman and Diu', 'IN.32', 'NULL', '2556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2556', '112', '4433', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4434', '1078', '1', 'Goa', 'IN.33', 'NULL', '2557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2557', '112', '4434', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4435', '1078', '1', 'Bihār', 'IN.34', 'NULL', '2558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2558', '112', '4435', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4436', '1078', '1', 'Madhya Pradesh', 'IN.35', 'NULL', '2559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2559', '112', '4436', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4437', '1078', '1', 'Uttar Pradesh', 'IN.36', 'NULL', '2560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2560', '112', '4437', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4438', '1078', '1', 'Chhattisgarh', 'IN.37', 'NULL', '2561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2561', '112', '4438', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4439', '1078', '1', 'Jharkhand', 'IN.38', 'NULL', '2562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2562', '112', '4439', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4440', '1078', '1', 'Uttarakhand', 'IN.39', 'NULL', '2563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2563', '112', '4440', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IN.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4441', '1078', '1', 'British Indian Ocean Territory (general)', 'IO.00', 'NULL', '2564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2564', '112', '4441', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IO.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4442', '1078', '1', 'Iraq (general)', 'IQ.00', 'NULL', '2565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2565', '112', '4442', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4443', '1078', '1', 'Al Anbār', 'IQ.01', 'NULL', '2566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2566', '112', '4443', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4444', '1078', '1', 'Al Başrah', 'IQ.02', 'NULL', '2567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2567', '112', '4444', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4445', '1078', '1', 'Al Muthanná', 'IQ.03', 'NULL', '2568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2568', '112', '4445', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4446', '1078', '1', 'Al Qādisīyah', 'IQ.04', 'NULL', '2569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2569', '112', '4446', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4447', '1078', '1', 'As Sulaymānīyah', 'IQ.05', 'NULL', '2570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2570', '112', '4447', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4448', '1078', '1', 'Bābil', 'IQ.06', 'NULL', '2571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2571', '112', '4448', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4449', '1078', '1', 'Baghdād', 'IQ.07', 'NULL', '2572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2572', '112', '4449', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4450', '1078', '1', 'Dahūk', 'IQ.08', 'NULL', '2573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2573', '112', '4450', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4451', '1078', '1', 'Dhi Qar', 'IQ.09', 'NULL', '2574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2574', '112', '4451', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4452', '1078', '1', 'Diyala', 'IQ.10', 'NULL', '2575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2575', '112', '4452', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4453', '1078', '1', 'Arbīl', 'IQ.11', 'NULL', '2576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2576', '112', '4453', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4454', '1078', '1', 'Karbalāʼ', 'IQ.12', 'NULL', '2577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2577', '112', '4454', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4455', '1078', '1', 'At Taʼmīm', 'IQ.13', 'NULL', '2578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2578', '112', '4455', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4456', '1078', '1', 'Maysan', 'IQ.14', 'NULL', '2579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2579', '112', '4456', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4457', '1078', '1', 'Nīnawá', 'IQ.15', 'NULL', '2580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2580', '112', '4457', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4458', '1078', '1', 'Wāsiţ', 'IQ.16', 'NULL', '2581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2581', '112', '4458', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4459', '1078', '1', 'An Najaf', 'IQ.17', 'NULL', '2582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2582', '112', '4459', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4460', '1078', '1', 'Şalāḩ ad Dīn', 'IQ.18', 'NULL', '2583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2583', '112', '4460', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IQ.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4461', '1078', '1', 'Iran (general)', 'IR.00', 'NULL', '2584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2584', '112', '4461', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4462', '1078', '1', 'Āz̄ārbāyjān-e Gharbī', 'IR.01', 'NULL', '2585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2585', '112', '4462', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4463', '1078', '1', 'Ostān-e Āz̄arbāyjān-e Sharqī', 'IR.02', 'NULL', '2586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2586', '112', '4463', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4464', '1078', '1', 'Chahār Maḩāll va Bakhtīārī', 'IR.03', 'NULL', '2587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2587', '112', '4464', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4465', '1078', '1', 'Sīstān va Balūchestān', 'IR.04', 'NULL', '2588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2588', '112', '4465', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4466', '1078', '1', 'Kohgīlūyeh va Būyer Aḩmad', 'IR.05', 'NULL', '2589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2589', '112', '4466', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4467', '1078', '1', 'Fārs Province', 'IR.07', 'NULL', '2590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2590', '112', '4467', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4468', '1078', '1', 'Gīlān', 'IR.08', 'NULL', '2591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2591', '112', '4468', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4469', '1078', '1', 'Hamadān', 'IR.09', 'NULL', '2592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2592', '112', '4469', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4470', '1078', '1', 'Īlām', 'IR.10', 'NULL', '2593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2593', '112', '4470', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4471', '1078', '1', 'Hormozgān Province', 'IR.11', 'NULL', '2594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2594', '112', '4471', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4472', '1078', '1', 'Kerman', 'IR.12', 'NULL', '2595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2595', '112', '4472', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4473', '1078', '1', 'Kermānshāh', 'IR.13', 'NULL', '2596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2596', '112', '4473', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4474', '1078', '1', 'Khūzestān', 'IR.15', 'NULL', '2597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2597', '112', '4474', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4475', '1078', '1', 'Kordestān', 'IR.16', 'NULL', '2598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2598', '112', '4475', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4476', '1078', '1', 'Mazandaran', 'IR.17', 'NULL', '2599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2599', '112', '4476', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4477', '1078', '1', 'Markazi', 'IR.19', 'NULL', '2600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2600', '112', '4477', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4478', '1078', '1', 'Zanjan', 'IR.21', 'NULL', '2601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2601', '112', '4478', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4479', '1078', '1', 'Bushehr Province', 'IR.22', 'NULL', '2602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2602', '112', '4479', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4480', '1078', '1', 'Lorestān', 'IR.23', 'NULL', '2603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2603', '112', '4480', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4481', '1078', '1', 'Markazi', 'IR.24', 'NULL', '2604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2604', '112', '4481', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4482', '1078', '1', 'Semnān Province', 'IR.25', 'NULL', '2605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2605', '112', '4482', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4483', '1078', '1', 'Tehrān', 'IR.26', 'NULL', '2606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2606', '112', '4483', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4484', '1078', '1', 'Zanjan', 'IR.27', 'NULL', '2607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2607', '112', '4484', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4485', '1078', '1', 'Eşfahān', 'IR.28', 'NULL', '2608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2608', '112', '4485', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4486', '1078', '1', 'Kermān', 'IR.29', 'NULL', '2609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2609', '112', '4486', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4487', '1078', '1', 'Ostan-e Khorasan-e Razavi', 'IR.30', 'NULL', '2610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2610', '112', '4487', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4488', '1078', '1', 'Yazd', 'IR.31', 'NULL', '2611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2611', '112', '4488', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4489', '1078', '1', 'Ardabīl', 'IR.32', 'NULL', '2612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2612', '112', '4489', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4490', '1078', '1', 'Āz̄ārbāyjān-e Sharqī', 'IR.33', 'NULL', '2613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2613', '112', '4490', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4491', '1078', '1', 'Markazi Province', 'IR.34', 'NULL', '2614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2614', '112', '4491', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4492', '1078', '1', 'Māzandarān Province', 'IR.35', 'NULL', '2615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2615', '112', '4492', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4493', '1078', '1', 'Zanjan Province', 'IR.36', 'NULL', '2616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2616', '112', '4493', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4494', '1078', '1', 'Golestān', 'IR.37', 'NULL', '2617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2617', '112', '4494', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4495', '1078', '1', 'Qazvīn', 'IR.38', 'NULL', '2618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2618', '112', '4495', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4496', '1078', '1', 'Qom', 'IR.39', 'NULL', '2619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2619', '112', '4496', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4497', '1078', '1', 'Yazd', 'IR.40', 'NULL', '2620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2620', '112', '4497', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4498', '1078', '1', 'Khorāsān-e Jonūbī', 'IR.41', 'NULL', '2621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2621', '112', '4498', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4499', '1078', '1', 'Razavi Khorasan Province', 'IR.42', 'NULL', '2622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2622', '112', '4499', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4500', '1078', '1', 'Khorāsān-e Shomālī', 'IR.43', 'NULL', '2623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2623', '112', '4500', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IR.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4501', '1078', '1', 'Iceland (general)', 'IS.00', 'NULL', '2624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2624', '112', '4501', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4502', '1078', '1', 'Borgarfjardarsysla', 'IS.07', 'NULL', '2625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2625', '112', '4502', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4503', '1078', '1', 'Dalasysla', 'IS.08', 'NULL', '2626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2626', '112', '4503', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4504', '1078', '1', 'Eyjafjardarsysla', 'IS.09', 'NULL', '2627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2627', '112', '4504', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4505', '1078', '1', 'Gullbringusysla', 'IS.10', 'NULL', '2628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2628', '112', '4505', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4506', '1078', '1', 'Hafnarfjördur', 'IS.11', 'NULL', '2629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2629', '112', '4506', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4507', '1078', '1', 'Husavik', 'IS.12', 'NULL', '2630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2630', '112', '4507', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4508', '1078', '1', 'Isafjördur', 'IS.13', 'NULL', '2631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2631', '112', '4508', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4509', '1078', '1', 'Keflavik', 'IS.14', 'NULL', '2632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2632', '112', '4509', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4510', '1078', '1', 'Kjosarsysla', 'IS.15', 'NULL', '2633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2633', '112', '4510', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4511', '1078', '1', 'Kopavogur', 'IS.16', 'NULL', '2634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2634', '112', '4511', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4512', '1078', '1', 'Myrasysla', 'IS.17', 'NULL', '2635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2635', '112', '4512', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4513', '1078', '1', 'Neskaupstadur', 'IS.18', 'NULL', '2636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2636', '112', '4513', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4514', '1078', '1', 'Nordur-Isafjardarsysla', 'IS.19', 'NULL', '2637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2637', '112', '4514', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4515', '1078', '1', 'Nordur-Mulasysla', 'IS.20', 'NULL', '2638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2638', '112', '4515', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4516', '1078', '1', 'Nordur-Tingeyjarsysla', 'IS.21', 'NULL', '2639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2639', '112', '4516', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4517', '1078', '1', 'Olafsfjördur', 'IS.22', 'NULL', '2640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2640', '112', '4517', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4518', '1078', '1', 'Rangarvallasysla', 'IS.23', 'NULL', '2641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2641', '112', '4518', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4519', '1078', '1', 'Reykjavík', 'IS.24', 'NULL', '2642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2642', '112', '4519', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4520', '1078', '1', 'Saudarkrokur', 'IS.25', 'NULL', '2643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2643', '112', '4520', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4521', '1078', '1', 'Seydisfjordur', 'IS.26', 'NULL', '2644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2644', '112', '4521', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4522', '1078', '1', 'Siglufjordur', 'IS.27', 'NULL', '2645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2645', '112', '4522', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4523', '1078', '1', 'Skagafjardarsysla', 'IS.28', 'NULL', '2646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2646', '112', '4523', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4524', '1078', '1', 'Snafellsnes- og Hnappadalssysla', 'IS.29', 'NULL', '2647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2647', '112', '4524', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4525', '1078', '1', 'Strandasysla', 'IS.30', 'NULL', '2648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2648', '112', '4525', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4526', '1078', '1', 'Sudur-Mulasysla', 'IS.31', 'NULL', '2649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2649', '112', '4526', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4527', '1078', '1', 'Sudur-Tingeyjarsysla', 'IS.32', 'NULL', '2650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2650', '112', '4527', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4528', '1078', '1', 'Vestmannaeyjar', 'IS.33', 'NULL', '2651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2651', '112', '4528', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4529', '1078', '1', 'Vestur-Bardastrandarsysla', 'IS.34', 'NULL', '2652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2652', '112', '4529', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4530', '1078', '1', 'Vestur-Hunavatnssysla', 'IS.35', 'NULL', '2653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2653', '112', '4530', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4531', '1078', '1', 'Vestur-Isafjardarsysla', 'IS.36', 'NULL', '2654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2654', '112', '4531', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4532', '1078', '1', 'Vestur-Skaftafellssysla', 'IS.37', 'NULL', '2655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2655', '112', '4532', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4533', '1078', '1', 'East', 'IS.38', 'NULL', '2656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2656', '112', '4533', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4534', '1078', '1', 'Capital Region', 'IS.39', 'NULL', '2657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2657', '112', '4534', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4535', '1078', '1', 'Northeast', 'IS.40', 'NULL', '2658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2658', '112', '4535', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4536', '1078', '1', 'Northwest', 'IS.41', 'NULL', '2659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2659', '112', '4536', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4537', '1078', '1', 'South', 'IS.42', 'NULL', '2660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2660', '112', '4537', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4538', '1078', '1', 'Southern Peninsula', 'IS.43', 'NULL', '2661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2661', '112', '4538', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4539', '1078', '1', 'Westfjords', 'IS.44', 'NULL', '2662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2662', '112', '4539', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4540', '1078', '1', 'West', 'IS.45', 'NULL', '2663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2663', '112', '4540', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IS.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4541', '1078', '1', 'Italy (general)', 'IT.00', 'NULL', '2664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2664', '112', '4541', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4542', '1078', '1', 'Abruzzo', 'IT.01', 'NULL', '2665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2665', '112', '4542', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4543', '1078', '1', 'Basilicate', 'IT.02', 'NULL', '2666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2666', '112', '4543', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4544', '1078', '1', 'Calabria', 'IT.03', 'NULL', '2667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2667', '112', '4544', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4545', '1078', '1', 'Campania', 'IT.04', 'NULL', '2668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2668', '112', '4545', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4546', '1078', '1', 'Emilia-Romagna', 'IT.05', 'NULL', '2669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2669', '112', '4546', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4547', '1078', '1', 'Friuli', 'IT.06', 'NULL', '2670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2670', '112', '4547', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4548', '1078', '1', 'Latium', 'IT.07', 'NULL', '2671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2671', '112', '4548', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4549', '1078', '1', 'Liguria', 'IT.08', 'NULL', '2672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2672', '112', '4549', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4550', '1078', '1', 'Lombardy', 'IT.09', 'NULL', '2673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2673', '112', '4550', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4551', '1078', '1', 'The Marches', 'IT.10', 'NULL', '2674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2674', '112', '4551', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4552', '1078', '1', 'Molise', 'IT.11', 'NULL', '2675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2675', '112', '4552', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4553', '1078', '1', 'Piedmont', 'IT.12', 'NULL', '2676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2676', '112', '4553', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4554', '1078', '1', 'Apulia', 'IT.13', 'NULL', '2677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2677', '112', '4554', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4555', '1078', '1', 'Sardinia', 'IT.14', 'NULL', '2678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2678', '112', '4555', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4556', '1078', '1', 'Sicily', 'IT.15', 'NULL', '2679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2679', '112', '4556', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4557', '1078', '1', 'Tuscany', 'IT.16', 'NULL', '2680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2680', '112', '4557', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4558', '1078', '1', 'Trentino-Alto Adige', 'IT.17', 'NULL', '2681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2681', '112', '4558', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4559', '1078', '1', 'Umbria', 'IT.18', 'NULL', '2682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2682', '112', '4559', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4560', '1078', '1', 'Aosta Valley', 'IT.19', 'NULL', '2683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2683', '112', '4560', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4561', '1078', '1', 'Veneto', 'IT.20', 'NULL', '2684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2684', '112', '4561', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «IT.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4562', '1078', '1', 'Jamaica (general)', 'JM.00', 'NULL', '2685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2685', '112', '4562', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4563', '1078', '1', 'Clarendon', 'JM.01', 'NULL', '2686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2686', '112', '4563', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4564', '1078', '1', 'Hanover Parish', 'JM.02', 'NULL', '2687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2687', '112', '4564', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4565', '1078', '1', 'Manchester', 'JM.04', 'NULL', '2688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2688', '112', '4565', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4566', '1078', '1', 'Portland', 'JM.07', 'NULL', '2689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2689', '112', '4566', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4567', '1078', '1', 'Saint Andrew', 'JM.08', 'NULL', '2690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2690', '112', '4567', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4568', '1078', '1', 'Saint Ann', 'JM.09', 'NULL', '2691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2691', '112', '4568', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4569', '1078', '1', 'Saint Catherine', 'JM.10', 'NULL', '2692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2692', '112', '4569', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4570', '1078', '1', 'Saint Elizabeth', 'JM.11', 'NULL', '2693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2693', '112', '4570', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4571', '1078', '1', 'Saint James', 'JM.12', 'NULL', '2694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2694', '112', '4571', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4572', '1078', '1', 'Saint Mary', 'JM.13', 'NULL', '2695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2695', '112', '4572', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4573', '1078', '1', 'Saint Thomas', 'JM.14', 'NULL', '2696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2696', '112', '4573', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4574', '1078', '1', 'Trelawny', 'JM.15', 'NULL', '2697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2697', '112', '4574', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4575', '1078', '1', 'Westmoreland', 'JM.16', 'NULL', '2698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2698', '112', '4575', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4576', '1078', '1', 'Kingston', 'JM.17', 'NULL', '2699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2699', '112', '4576', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JM.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4577', '1078', '1', 'Jordan (general)', 'JO.00', 'NULL', '2700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2700', '112', '4577', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4578', '1078', '1', 'Balqa', 'JO.02', 'NULL', '2701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2701', '112', '4578', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4579', '1078', '1', 'Ma’an', 'JO.07', 'NULL', '2702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2702', '112', '4579', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4580', '1078', '1', 'Karak', 'JO.09', 'NULL', '2703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2703', '112', '4580', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4581', '1078', '1', 'Al Mafraq', 'JO.10', 'NULL', '2704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2704', '112', '4581', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4582', '1078', '1', 'Amman', 'JO.11', 'NULL', '2705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2705', '112', '4582', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4583', '1078', '1', 'Tafielah', 'JO.12', 'NULL', '2706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2706', '112', '4583', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4584', '1078', '1', 'Az Zarqa', 'JO.13', 'NULL', '2707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2707', '112', '4584', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4585', '1078', '1', 'Irbid', 'JO.14', 'NULL', '2708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2708', '112', '4585', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4586', '1078', '1', 'Mafraq', 'JO.15', 'NULL', '2709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2709', '112', '4586', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4587', '1078', '1', '‘Ammān', 'JO.16', 'NULL', '2710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2710', '112', '4587', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4588', '1078', '1', 'Zarqa', 'JO.17', 'NULL', '2711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2711', '112', '4588', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4589', '1078', '1', 'Irbid', 'JO.18', 'NULL', '2712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2712', '112', '4589', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4590', '1078', '1', 'Ma''an', 'JO.19', 'NULL', '2713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2713', '112', '4590', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4591', '1078', '1', 'Ajlun', 'JO.20', 'NULL', '2714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2714', '112', '4591', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4592', '1078', '1', 'Aqaba', 'JO.21', 'NULL', '2715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2715', '112', '4592', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4593', '1078', '1', 'Jerash', 'JO.22', 'NULL', '2716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2716', '112', '4593', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4594', '1078', '1', 'Madaba', 'JO.23', 'NULL', '2717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2717', '112', '4594', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JO.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4595', '1078', '1', 'Japan (general)', 'JP.00', 'NULL', '2718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2718', '112', '4595', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4596', '1078', '1', 'Aichi', 'JP.01', 'NULL', '2719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2719', '112', '4596', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4597', '1078', '1', 'Akita', 'JP.02', 'NULL', '2720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2720', '112', '4597', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4598', '1078', '1', 'Aomori', 'JP.03', 'NULL', '2721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2721', '112', '4598', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4599', '1078', '1', 'Chiba', 'JP.04', 'NULL', '2722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2722', '112', '4599', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4600', '1078', '1', 'Ehime', 'JP.05', 'NULL', '2723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2723', '112', '4600', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4601', '1078', '1', 'Fukui', 'JP.06', 'NULL', '2724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2724', '112', '4601', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4602', '1078', '1', 'Fukuoka', 'JP.07', 'NULL', '2725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2725', '112', '4602', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4603', '1078', '1', 'Fukushima', 'JP.08', 'NULL', '2726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2726', '112', '4603', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4604', '1078', '1', 'Gifu', 'JP.09', 'NULL', '2727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2727', '112', '4604', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4605', '1078', '1', 'Gumma', 'JP.10', 'NULL', '2728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2728', '112', '4605', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4606', '1078', '1', 'Hiroshima', 'JP.11', 'NULL', '2729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2729', '112', '4606', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4607', '1078', '1', 'Hokkaidō', 'JP.12', 'NULL', '2730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2730', '112', '4607', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4608', '1078', '1', 'Hyōgo', 'JP.13', 'NULL', '2731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2731', '112', '4608', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4609', '1078', '1', 'Ibaraki', 'JP.14', 'NULL', '2732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2732', '112', '4609', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4610', '1078', '1', 'Ishikawa', 'JP.15', 'NULL', '2733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2733', '112', '4610', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4611', '1078', '1', 'Iwate', 'JP.16', 'NULL', '2734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2734', '112', '4611', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4612', '1078', '1', 'Kagawa', 'JP.17', 'NULL', '2735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2735', '112', '4612', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4613', '1078', '1', 'Kagoshima', 'JP.18', 'NULL', '2736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2736', '112', '4613', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4614', '1078', '1', 'Kanagawa', 'JP.19', 'NULL', '2737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2737', '112', '4614', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4615', '1078', '1', 'Kōchi', 'JP.20', 'NULL', '2738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2738', '112', '4615', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4616', '1078', '1', 'Kumamoto', 'JP.21', 'NULL', '2739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2739', '112', '4616', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4617', '1078', '1', 'Kyōto', 'JP.22', 'NULL', '2740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2740', '112', '4617', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4618', '1078', '1', 'Mie', 'JP.23', 'NULL', '2741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2741', '112', '4618', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4619', '1078', '1', 'Miyagi', 'JP.24', 'NULL', '2742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2742', '112', '4619', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4620', '1078', '1', 'Miyazaki', 'JP.25', 'NULL', '2743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2743', '112', '4620', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4621', '1078', '1', 'Nagano', 'JP.26', 'NULL', '2744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2744', '112', '4621', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4622', '1078', '1', 'Nagasaki', 'JP.27', 'NULL', '2745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2745', '112', '4622', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4623', '1078', '1', 'Nara', 'JP.28', 'NULL', '2746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2746', '112', '4623', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4624', '1078', '1', 'Niigata', 'JP.29', 'NULL', '2747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2747', '112', '4624', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4625', '1078', '1', 'Ōita', 'JP.30', 'NULL', '2748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2748', '112', '4625', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4626', '1078', '1', 'Okayama', 'JP.31', 'NULL', '2749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2749', '112', '4626', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4627', '1078', '1', 'Ōsaka', 'JP.32', 'NULL', '2750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2750', '112', '4627', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4628', '1078', '1', 'Saga', 'JP.33', 'NULL', '2751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2751', '112', '4628', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4629', '1078', '1', 'Saitama', 'JP.34', 'NULL', '2752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2752', '112', '4629', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4630', '1078', '1', 'Shiga', 'JP.35', 'NULL', '2753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2753', '112', '4630', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4631', '1078', '1', 'Shimane', 'JP.36', 'NULL', '2754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2754', '112', '4631', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4632', '1078', '1', 'Shizuoka', 'JP.37', 'NULL', '2755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2755', '112', '4632', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4633', '1078', '1', 'Tochigi', 'JP.38', 'NULL', '2756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2756', '112', '4633', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4634', '1078', '1', 'Tokushima', 'JP.39', 'NULL', '2757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2757', '112', '4634', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4635', '1078', '1', 'Tōkyō', 'JP.40', 'NULL', '2758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2758', '112', '4635', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4636', '1078', '1', 'Tottori', 'JP.41', 'NULL', '2759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2759', '112', '4636', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4637', '1078', '1', 'Toyama', 'JP.42', 'NULL', '2760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2760', '112', '4637', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4638', '1078', '1', 'Wakayama', 'JP.43', 'NULL', '2761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2761', '112', '4638', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4639', '1078', '1', 'Yamagata', 'JP.44', 'NULL', '2762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2762', '112', '4639', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4640', '1078', '1', 'Yamaguchi', 'JP.45', 'NULL', '2763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2763', '112', '4640', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4641', '1078', '1', 'Yamanashi', 'JP.46', 'NULL', '2764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2764', '112', '4641', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4642', '1078', '1', 'Okinawa', 'JP.47', 'NULL', '2765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2765', '112', '4642', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «JP.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4643', '1078', '1', 'Kenya (general)', 'KE.00', 'NULL', '2766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2766', '112', '4643', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4644', '1078', '1', 'Central', 'KE.01', 'NULL', '2767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2767', '112', '4644', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KE.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4645', '1078', '1', 'Coast', 'KE.02', 'NULL', '2768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2768', '112', '4645', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KE.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4646', '1078', '1', 'Eastern', 'KE.03', 'NULL', '2769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2769', '112', '4646', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KE.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4647', '1078', '1', 'Nairobi Area', 'KE.05', 'NULL', '2770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2770', '112', '4647', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KE.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4648', '1078', '1', 'North-Eastern', 'KE.06', 'NULL', '2771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2771', '112', '4648', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KE.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4649', '1078', '1', 'Nyanza', 'KE.07', 'NULL', '2772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2772', '112', '4649', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KE.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4650', '1078', '1', 'Rift Valley', 'KE.08', 'NULL', '2773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2773', '112', '4650', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KE.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4651', '1078', '1', 'Western', 'KE.09', 'NULL', '2774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2774', '112', '4651', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KE.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4652', '1078', '1', 'Kyrgyzstan (general)', 'KG.00', 'NULL', '2775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2775', '112', '4652', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4653', '1078', '1', 'Bishkek', 'KG.01', 'NULL', '2776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2776', '112', '4653', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KG.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4654', '1078', '1', 'Chüy', 'KG.02', 'NULL', '2777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2777', '112', '4654', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KG.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4655', '1078', '1', 'Jalal-Abad', 'KG.03', 'NULL', '2778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2778', '112', '4655', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KG.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4656', '1078', '1', 'Naryn', 'KG.04', 'NULL', '2779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2779', '112', '4656', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KG.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4657', '1078', '1', '(KG05)', 'KG.05', 'NULL', '2780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2780', '112', '4657', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KG.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4658', '1078', '1', 'Talas', 'KG.06', 'NULL', '2781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2781', '112', '4658', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KG.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4659', '1078', '1', 'Ysyk-Köl', 'KG.07', 'NULL', '2782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2782', '112', '4659', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KG.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4660', '1078', '1', 'Osh', 'KG.08', 'NULL', '2783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2783', '112', '4660', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KG.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4661', '1078', '1', 'Batken', 'KG.09', 'NULL', '2784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2784', '112', '4661', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KG.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4662', '1078', '1', 'Khétt Bântéay Méan Cheăy', 'KH.00', 'NULL', '2785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2785', '112', '4662', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4663', '1078', '1', 'Khétt Bătdâmbâng', 'KH.01', 'NULL', '2786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2786', '112', '4663', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4664', '1078', '1', 'Kâmpóng Cham', 'KH.02', 'NULL', '2787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2787', '112', '4664', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4665', '1078', '1', 'Kâmpóng Chhnăng', 'KH.03', 'NULL', '2788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2788', '112', '4665', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4666', '1078', '1', 'Khétt Kâmpóng Spœ', 'KH.04', 'NULL', '2789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2789', '112', '4666', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4667', '1078', '1', 'Kâmpóng Thum', 'KH.05', 'NULL', '2790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2790', '112', '4667', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4668', '1078', '1', 'Khétt Kâmpôt', 'KH.06', 'NULL', '2791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2791', '112', '4668', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4669', '1078', '1', 'Kândal', 'KH.07', 'NULL', '2792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2792', '112', '4669', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4670', '1078', '1', 'Kaôh Kŏng', 'KH.08', 'NULL', '2793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2793', '112', '4670', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4671', '1078', '1', 'Krâchéh', 'KH.09', 'NULL', '2794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2794', '112', '4671', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4672', '1078', '1', 'Môndól Kiri', 'KH.10', 'NULL', '2795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2795', '112', '4672', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4673', '1078', '1', 'Phnum Penh', 'KH.11', 'NULL', '2796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2796', '112', '4673', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4674', '1078', '1', 'Poŭthĭsăt', 'KH.12', 'NULL', '2797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2797', '112', '4674', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4675', '1078', '1', 'Preăh Vihéar', 'KH.13', 'NULL', '2798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2798', '112', '4675', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4676', '1078', '1', 'Prey Vêng', 'KH.14', 'NULL', '2799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2799', '112', '4676', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4677', '1078', '1', 'Khétt Rôtânăh Kiri', 'KH.15', 'NULL', '2800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2800', '112', '4677', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4678', '1078', '1', 'Stœ̆ng Trêng', 'KH.17', 'NULL', '2801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2801', '112', '4678', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4679', '1078', '1', 'Svay Riĕng', 'KH.18', 'NULL', '2802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2802', '112', '4679', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4680', '1078', '1', 'Takêv', 'KH.19', 'NULL', '2803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2803', '112', '4680', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4681', '1078', '1', '(CB20)', 'KH.20', 'NULL', '2804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2804', '112', '4681', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4682', '1078', '1', 'Kâmpôt', 'KH.21', 'NULL', '2805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2805', '112', '4682', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4683', '1078', '1', 'Phnum Pénh', 'KH.22', 'NULL', '2806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2806', '112', '4683', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4684', '1078', '1', 'Rôtânăh Kiri', 'KH.23', 'NULL', '2807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2807', '112', '4684', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4685', '1078', '1', 'Siĕm Réab', 'KH.24', 'NULL', '2808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2808', '112', '4685', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4686', '1078', '1', 'Bantéay Méan Cheăy', 'KH.25', 'NULL', '2809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2809', '112', '4686', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4687', '1078', '1', 'Kêb', 'KH.26', 'NULL', '2810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2810', '112', '4687', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4688', '1078', '1', 'Ŏtdâr Méan Cheăy', 'KH.27', 'NULL', '2811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2811', '112', '4688', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4689', '1078', '1', 'Preăh Seihânŭ', 'KH.28', 'NULL', '2812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2812', '112', '4689', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4690', '1078', '1', 'Bătdâmbâng', 'KH.29', 'NULL', '2813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2813', '112', '4690', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4691', '1078', '1', 'Palĭn', 'KH.30', 'NULL', '2814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2814', '112', '4691', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KH.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4692', '1078', '1', 'Line Islands', 'KI.00', 'NULL', '2815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2815', '112', '4692', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KI.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4693', '1078', '1', 'Gilbert Islands', 'KI.01', 'NULL', '2816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2816', '112', '4693', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KI.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4694', '1078', '1', 'Line Islands', 'KI.02', 'NULL', '2817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2817', '112', '4694', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KI.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4695', '1078', '1', 'Phoenix Islands', 'KI.03', 'NULL', '2818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2818', '112', '4695', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KI.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4696', '1078', '1', 'Comoros (general)', 'KM.00', 'NULL', '2819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2819', '112', '4696', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4697', '1078', '1', 'Anjouan', 'KM.01', 'NULL', '2820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2820', '112', '4697', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4698', '1078', '1', 'Grande Comore', 'KM.02', 'NULL', '2821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2821', '112', '4698', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4699', '1078', '1', 'Mohéli', 'KM.03', 'NULL', '2822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2822', '112', '4699', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4700', '1078', '1', 'Saint Kitts and Nevis (general)', 'KN.00', 'NULL', '2823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2823', '112', '4700', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4701', '1078', '1', 'Christ Church Nichola Town', 'KN.01', 'NULL', '2824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2824', '112', '4701', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4702', '1078', '1', 'Saint Anne Sandy Point', 'KN.02', 'NULL', '2825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2825', '112', '4702', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4703', '1078', '1', 'Saint George Basseterre', 'KN.03', 'NULL', '2826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2826', '112', '4703', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4704', '1078', '1', 'Saint George Gingerland', 'KN.04', 'NULL', '2827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2827', '112', '4704', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4705', '1078', '1', 'Saint James Windwa', 'KN.05', 'NULL', '2828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2828', '112', '4705', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4706', '1078', '1', 'Saint John Capesterre', 'KN.06', 'NULL', '2829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2829', '112', '4706', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4707', '1078', '1', 'Saint John Figtree', 'KN.07', 'NULL', '2830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2830', '112', '4707', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4708', '1078', '1', 'Saint Mary Cayon', 'KN.08', 'NULL', '2831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2831', '112', '4708', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4709', '1078', '1', 'Saint Paul Capesterre', 'KN.09', 'NULL', '2832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2832', '112', '4709', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4710', '1078', '1', 'Saint Paul Charlestown', 'KN.10', 'NULL', '2833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2833', '112', '4710', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4711', '1078', '1', 'Saint Peter Basseterre', 'KN.11', 'NULL', '2834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2834', '112', '4711', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4712', '1078', '1', 'Saint Thomas Lowland', 'KN.12', 'NULL', '2835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2835', '112', '4712', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4713', '1078', '1', 'Saint Thomas Middle Island', 'KN.13', 'NULL', '2836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2836', '112', '4713', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4714', '1078', '1', 'Trinity Palmetto Point', 'KN.15', 'NULL', '2837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2837', '112', '4714', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KN.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4715', '1078', '1', 'North Korea (general)', 'KP.00', 'NULL', '2838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2838', '112', '4715', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4716', '1078', '1', 'Chagang-do', 'KP.01', 'NULL', '2839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2839', '112', '4716', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4717', '1078', '1', 'Hamgyŏng-namdo', 'KP.03', 'NULL', '2840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2840', '112', '4717', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4718', '1078', '1', 'Hwanghae-namdo', 'KP.06', 'NULL', '2841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2841', '112', '4718', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4719', '1078', '1', 'Hwanghae-bukto', 'KP.07', 'NULL', '2842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2842', '112', '4719', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4720', '1078', '1', 'Kaesŏng-si', 'KP.08', 'NULL', '2843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2843', '112', '4720', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4721', '1078', '1', 'Gangwon', 'KP.09', 'NULL', '2844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2844', '112', '4721', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4722', '1078', '1', 'P''yŏngan-bukto', 'KP.11', 'NULL', '2845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2845', '112', '4722', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4723', '1078', '1', 'P''yŏngyang-si', 'KP.12', 'NULL', '2846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2846', '112', '4723', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4724', '1078', '1', 'Yanggang-do', 'KP.13', 'NULL', '2847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2847', '112', '4724', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4725', '1078', '1', 'Namp''o-si', 'KP.14', 'NULL', '2848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2848', '112', '4725', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4726', '1078', '1', 'P''yŏngan-namdo', 'KP.15', 'NULL', '2849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2849', '112', '4726', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4727', '1078', '1', '(KN16)', 'KP.16', 'NULL', '2850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2850', '112', '4727', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4728', '1078', '1', 'Hamgyŏng-bukto', 'KP.17', 'NULL', '2851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2851', '112', '4728', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4729', '1078', '1', 'Najin Sŏnbong-si', 'KP.18', 'NULL', '2852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2852', '112', '4729', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KP.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4730', '1078', '1', 'South Korea (general)', 'KR.00', 'NULL', '2853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2853', '112', '4730', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4731', '1078', '1', 'Jeju', 'KR.01', 'NULL', '2854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2854', '112', '4731', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4732', '1078', '1', 'North Jeolla', 'KR.03', 'NULL', '2855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2855', '112', '4732', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4733', '1078', '1', 'North Chungcheong', 'KR.05', 'NULL', '2856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2856', '112', '4733', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4734', '1078', '1', 'Gangwon', 'KR.06', 'NULL', '2857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2857', '112', '4734', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4735', '1078', '1', 'Busan', 'KR.10', 'NULL', '2858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2858', '112', '4735', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4736', '1078', '1', 'Seoul', 'KR.11', 'NULL', '2859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2859', '112', '4736', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4737', '1078', '1', 'Incheon', 'KR.12', 'NULL', '2860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2860', '112', '4737', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4738', '1078', '1', 'Gyeonggi', 'KR.13', 'NULL', '2861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2861', '112', '4738', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4739', '1078', '1', 'North Gyeongsang', 'KR.14', 'NULL', '2862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2862', '112', '4739', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4740', '1078', '1', 'Daegu', 'KR.15', 'NULL', '2863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2863', '112', '4740', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4741', '1078', '1', 'South Jeolla', 'KR.16', 'NULL', '2864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2864', '112', '4741', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4742', '1078', '1', 'South Chungcheong', 'KR.17', 'NULL', '2865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2865', '112', '4742', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4743', '1078', '1', 'Gwangju', 'KR.18', 'NULL', '2866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2866', '112', '4743', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4744', '1078', '1', 'Daejeon', 'KR.19', 'NULL', '2867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2867', '112', '4744', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4745', '1078', '1', 'South Gyeongsang', 'KR.20', 'NULL', '2868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2868', '112', '4745', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4746', '1078', '1', 'Ulsan', 'KR.21', 'NULL', '2869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2869', '112', '4746', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KR.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4747', '1078', '1', 'Muḩāfaz̧atalWafrah', 'KW.00', 'NULL', '2870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2870', '112', '4747', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KW.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4748', '1078', '1', 'Al ‘Āşimah', 'KW.02', 'NULL', '2871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2871', '112', '4748', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KW.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4749', '1078', '1', 'Ḩawallī', 'KW.03', 'NULL', '2872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2872', '112', '4749', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KW.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4750', '1078', '1', 'Al Aḩmadī', 'KW.04', 'NULL', '2873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2873', '112', '4750', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KW.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4751', '1078', '1', 'Al Jahrāʼ', 'KW.05', 'NULL', '2874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2874', '112', '4751', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KW.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4752', '1078', '1', 'Al Farwaniyah', 'KW.06', 'NULL', '2875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2875', '112', '4752', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KW.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4753', '1078', '1', 'Cayman Islands (general)', 'KY.00', 'NULL', '2876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2876', '112', '4753', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KY.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4754', '1078', '1', 'Creek', 'KY.01', 'NULL', '2877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2877', '112', '4754', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KY.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4755', '1078', '1', 'Eastern', 'KY.02', 'NULL', '2878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2878', '112', '4755', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KY.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4756', '1078', '1', 'Midland', 'KY.03', 'NULL', '2879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2879', '112', '4756', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KY.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4757', '1078', '1', 'South Town', 'KY.04', 'NULL', '2880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2880', '112', '4757', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KY.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4758', '1078', '1', 'Spot Bay', 'KY.05', 'NULL', '2881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2881', '112', '4758', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KY.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4759', '1078', '1', 'Stake Bay', 'KY.06', 'NULL', '2882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2882', '112', '4759', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KY.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4760', '1078', '1', 'West End', 'KY.07', 'NULL', '2883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2883', '112', '4760', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KY.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4761', '1078', '1', 'Western', 'KY.08', 'NULL', '2884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2884', '112', '4761', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KY.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4762', '1078', '1', 'Zhezqazghan Oblysy', 'KZ.00', 'NULL', '2885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2885', '112', '4762', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4763', '1078', '1', 'Almaty', 'KZ.01', 'NULL', '2886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2886', '112', '4763', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4764', '1078', '1', 'Almaty Qalasy', 'KZ.02', 'NULL', '2887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2887', '112', '4764', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4765', '1078', '1', 'Aqmola', 'KZ.03', 'NULL', '2888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2888', '112', '4765', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4766', '1078', '1', 'Aqtöbe', 'KZ.04', 'NULL', '2889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2889', '112', '4766', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4767', '1078', '1', 'Astana Qalasy', 'KZ.05', 'NULL', '2890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2890', '112', '4767', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4768', '1078', '1', 'Atyraū', 'KZ.06', 'NULL', '2891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2891', '112', '4768', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4769', '1078', '1', 'Batys Qazaqstan', 'KZ.07', 'NULL', '2892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2892', '112', '4769', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4770', '1078', '1', 'Mangghystaū', 'KZ.09', 'NULL', '2893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2893', '112', '4770', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4771', '1078', '1', 'Ongtüstik Qazaqstan', 'KZ.10', 'NULL', '2894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2894', '112', '4771', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4772', '1078', '1', 'Pavlodar', 'KZ.11', 'NULL', '2895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2895', '112', '4772', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4773', '1078', '1', 'Qaraghandy', 'KZ.12', 'NULL', '2896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2896', '112', '4773', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4774', '1078', '1', 'Qostanay', 'KZ.13', 'NULL', '2897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2897', '112', '4774', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4775', '1078', '1', 'Qyzylorda', 'KZ.14', 'NULL', '2898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2898', '112', '4775', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4776', '1078', '1', 'East Kazakhstan', 'KZ.15', 'NULL', '2899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2899', '112', '4776', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4777', '1078', '1', 'Soltüstik Qazaqstan', 'KZ.16', 'NULL', '2900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2900', '112', '4777', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4778', '1078', '1', 'Zhambyl', 'KZ.17', 'NULL', '2901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2901', '112', '4778', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «KZ.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4779', '1078', '1', 'Laos (general)', 'LA.00', 'NULL', '2902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2902', '112', '4779', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4780', '1078', '1', 'Attapu', 'LA.01', 'NULL', '2903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2903', '112', '4780', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4781', '1078', '1', 'Champasak', 'LA.02', 'NULL', '2904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2904', '112', '4781', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4782', '1078', '1', 'Houaphan', 'LA.03', 'NULL', '2905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2905', '112', '4782', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4783', '1078', '1', 'Khammouan', 'LA.04', 'NULL', '2906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2906', '112', '4783', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4784', '1078', '1', 'Louang Namtha', 'LA.05', 'NULL', '2907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2907', '112', '4784', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4785', '1078', '1', 'Louangphrabang', 'LA.06', 'NULL', '2908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2908', '112', '4785', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4786', '1078', '1', 'Oudômxai', 'LA.07', 'NULL', '2909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2909', '112', '4786', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4787', '1078', '1', 'Phongsali', 'LA.08', 'NULL', '2910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2910', '112', '4787', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4788', '1078', '1', 'Saravan', 'LA.09', 'NULL', '2911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2911', '112', '4788', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4789', '1078', '1', 'Savannakhet', 'LA.10', 'NULL', '2912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2912', '112', '4789', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4790', '1078', '1', 'Vientiane', 'LA.11', 'NULL', '2913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2913', '112', '4790', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4791', '1078', '1', 'Xiagnabouli', 'LA.13', 'NULL', '2914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2914', '112', '4791', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4792', '1078', '1', 'Xiangkhoang', 'LA.14', 'NULL', '2915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2915', '112', '4792', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4793', '1078', '1', 'Khammouan', 'LA.15', 'NULL', '2916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2916', '112', '4793', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4794', '1078', '1', 'Loungnamtha', 'LA.16', 'NULL', '2917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2917', '112', '4794', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4795', '1078', '1', 'Louangphabang', 'LA.17', 'NULL', '2918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2918', '112', '4795', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4796', '1078', '1', 'Phôngsali', 'LA.18', 'NULL', '2919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2919', '112', '4796', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4797', '1078', '1', 'Salavan', 'LA.19', 'NULL', '2920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2920', '112', '4797', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4798', '1078', '1', 'Savannahkhét', 'LA.20', 'NULL', '2921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2921', '112', '4798', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4799', '1078', '1', 'Bokèo', 'LA.22', 'NULL', '2922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2922', '112', '4799', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4800', '1078', '1', 'Bolikhamxai', 'LA.23', 'NULL', '2923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2923', '112', '4800', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4801', '1078', '1', 'Viangchan', 'LA.24', 'NULL', '2924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2924', '112', '4801', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4802', '1078', '1', 'Xaisômboun', 'LA.25', 'NULL', '2925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2925', '112', '4802', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4803', '1078', '1', 'Xékong', 'LA.26', 'NULL', '2926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2926', '112', '4803', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4804', '1078', '1', 'Viangchan', 'LA.27', 'NULL', '2927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2927', '112', '4804', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LA.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4805', '1078', '1', 'Lebanon (general)', 'LB.00', 'NULL', '2928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2928', '112', '4805', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4806', '1078', '1', 'Béqaa', 'LB.01', 'NULL', '2929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2929', '112', '4806', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4807', '1078', '1', '(LE02)', 'LB.02', 'NULL', '2930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2930', '112', '4807', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4808', '1078', '1', 'Liban-Nord', 'LB.03', 'NULL', '2931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2931', '112', '4808', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4809', '1078', '1', 'Beyrouth', 'LB.04', 'NULL', '2932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2932', '112', '4809', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4810', '1078', '1', 'Mont-Liban', 'LB.05', 'NULL', '2933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2933', '112', '4810', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4811', '1078', '1', 'Liban-Sud', 'LB.06', 'NULL', '2934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2934', '112', '4811', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4812', '1078', '1', 'Nabatîyé', 'LB.07', 'NULL', '2935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2935', '112', '4812', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4813', '1078', '1', 'Béqaa', 'LB.08', 'NULL', '2936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2936', '112', '4813', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4814', '1078', '1', 'Liban-Nord', 'LB.09', 'NULL', '2937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2937', '112', '4814', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4815', '1078', '1', 'Aakkâr', 'LB.10', 'NULL', '2938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2938', '112', '4815', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4816', '1078', '1', 'Baalbek-Hermel', 'LB.11', 'NULL', '2939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2939', '112', '4816', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LB.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4817', '1078', '1', 'Saint Lucia (general)', 'LC.00', 'NULL', '2940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2940', '112', '4817', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4818', '1078', '1', 'Anse-la-Raye', 'LC.01', 'NULL', '2941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2941', '112', '4818', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4819', '1078', '1', 'Dauphin', 'LC.02', 'NULL', '2942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2942', '112', '4819', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4820', '1078', '1', 'Castries', 'LC.03', 'NULL', '2943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2943', '112', '4820', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4821', '1078', '1', 'Choiseul', 'LC.04', 'NULL', '2944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2944', '112', '4821', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4822', '1078', '1', 'Dennery', 'LC.05', 'NULL', '2945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2945', '112', '4822', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4823', '1078', '1', 'Gros-Islet', 'LC.06', 'NULL', '2946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2946', '112', '4823', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4824', '1078', '1', 'Laborie', 'LC.07', 'NULL', '2947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2947', '112', '4824', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4825', '1078', '1', 'Micoud', 'LC.08', 'NULL', '2948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2948', '112', '4825', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4826', '1078', '1', 'Soufrière', 'LC.09', 'NULL', '2949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2949', '112', '4826', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4827', '1078', '1', 'Vieux-Fort', 'LC.10', 'NULL', '2950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2950', '112', '4827', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4828', '1078', '1', 'Praslin', 'LC.11', 'NULL', '2951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2951', '112', '4828', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LC.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4829', '1078', '1', 'Liechtenstein (general)', 'LI.00', 'NULL', '2952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2952', '112', '4829', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4830', '1078', '1', 'Balzers', 'LI.01', 'NULL', '2953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2953', '112', '4830', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4831', '1078', '1', 'Eschen', 'LI.02', 'NULL', '2954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2954', '112', '4831', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4832', '1078', '1', 'Gamprin', 'LI.03', 'NULL', '2955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2955', '112', '4832', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4833', '1078', '1', 'Mauren', 'LI.04', 'NULL', '2956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2956', '112', '4833', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4834', '1078', '1', 'Planken', 'LI.05', 'NULL', '2957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2957', '112', '4834', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4835', '1078', '1', 'Ruggell', 'LI.06', 'NULL', '2958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2958', '112', '4835', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4836', '1078', '1', 'Schaan', 'LI.07', 'NULL', '2959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2959', '112', '4836', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4837', '1078', '1', 'Schellenberg', 'LI.08', 'NULL', '2960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2960', '112', '4837', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4838', '1078', '1', 'Triesen', 'LI.09', 'NULL', '2961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2961', '112', '4838', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4839', '1078', '1', 'Triesenberg', 'LI.10', 'NULL', '2962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2962', '112', '4839', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4840', '1078', '1', 'Vaduz', 'LI.11', 'NULL', '2963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2963', '112', '4840', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LI.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4841', '1078', '1', 'Sri Lanka (general)', 'LK.00', 'NULL', '2964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2964', '112', '4841', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LK.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4842', '1078', '1', 'Central', 'LK.29', 'NULL', '2965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2965', '112', '4842', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LK.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4843', '1078', '1', 'North Central', 'LK.30', 'NULL', '2966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2966', '112', '4843', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LK.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4844', '1078', '1', 'North Eastern', 'LK.31', 'NULL', '2967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2967', '112', '4844', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LK.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4845', '1078', '1', 'North Western', 'LK.32', 'NULL', '2968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2968', '112', '4845', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LK.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4846', '1078', '1', 'Sabaragamuwa', 'LK.33', 'NULL', '2969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2969', '112', '4846', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LK.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4847', '1078', '1', 'Southern', 'LK.34', 'NULL', '2970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2970', '112', '4847', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LK.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4848', '1078', '1', 'Uva', 'LK.35', 'NULL', '2971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2971', '112', '4848', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LK.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4849', '1078', '1', 'Western', 'LK.36', 'NULL', '2972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2972', '112', '4849', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LK.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4850', '1078', '1', 'Liberia (general)', 'LR.00', 'NULL', '2973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2973', '112', '4850', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4851', '1078', '1', 'Bong', 'LR.01', 'NULL', '2974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2974', '112', '4851', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4852', '1078', '1', 'Grand Jide', 'LR.02', 'NULL', '2975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2975', '112', '4852', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4853', '1078', '1', 'Grand Cape Mount', 'LR.04', 'NULL', '2976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2976', '112', '4853', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4854', '1078', '1', 'Lofa', 'LR.05', 'NULL', '2977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2977', '112', '4854', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4855', '1078', '1', '(LI08)', 'LR.08', 'NULL', '2978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2978', '112', '4855', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4856', '1078', '1', 'Nimba', 'LR.09', 'NULL', '2979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2979', '112', '4856', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4857', '1078', '1', 'Sinoe', 'LR.10', 'NULL', '2980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2980', '112', '4857', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4858', '1078', '1', 'Grand Bassa County', 'LR.11', 'NULL', '2981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2981', '112', '4858', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4859', '1078', '1', 'Grand Cape Mount', 'LR.12', 'NULL', '2982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2982', '112', '4859', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4860', '1078', '1', 'Maryland', 'LR.13', 'NULL', '2983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2983', '112', '4860', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4861', '1078', '1', 'Montserrado', 'LR.14', 'NULL', '2984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2984', '112', '4861', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4862', '1078', '1', 'Bomi', 'LR.15', 'NULL', '2985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2985', '112', '4862', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4863', '1078', '1', 'Grand Kru', 'LR.16', 'NULL', '2986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2986', '112', '4863', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4864', '1078', '1', 'Margibi', 'LR.17', 'NULL', '2987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2987', '112', '4864', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4865', '1078', '1', 'River Cess', 'LR.18', 'NULL', '2988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2988', '112', '4865', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4866', '1078', '1', 'Grand Gedeh', 'LR.19', 'NULL', '2989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2989', '112', '4866', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4867', '1078', '1', 'Lofa', 'LR.20', 'NULL', '2990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2990', '112', '4867', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4868', '1078', '1', 'Gbarpolu', 'LR.21', 'NULL', '2991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2991', '112', '4868', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4869', '1078', '1', 'River Gee', 'LR.22', 'NULL', '2992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2992', '112', '4869', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LR.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4870', '1078', '1', 'Lesotho (general)', 'LS.00', 'NULL', '2993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2993', '112', '4870', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4871', '1078', '1', 'Balzers Commune', 'LS.01', 'NULL', '2994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2994', '112', '4871', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4872', '1078', '1', 'Eschen Commune', 'LS.02', 'NULL', '2995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2995', '112', '4872', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4873', '1078', '1', 'Gamprin Commune', 'LS.03', 'NULL', '2996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2996', '112', '4873', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4874', '1078', '1', 'Mauren Commune', 'LS.04', 'NULL', '2997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2997', '112', '4874', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4875', '1078', '1', 'Planken Commune', 'LS.05', 'NULL', '2998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2998', '112', '4875', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4876', '1078', '1', 'Ruggell Commune', 'LS.06', 'NULL', '2999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('2999', '112', '4876', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4877', '1078', '1', 'Berea District', 'LS.10', 'NULL', '3000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3000', '112', '4877', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4878', '1078', '1', 'Butha-Buthe District', 'LS.11', 'NULL', '3001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3001', '112', '4878', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4879', '1078', '1', 'Leribe District', 'LS.12', 'NULL', '3002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3002', '112', '4879', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4880', '1078', '1', 'Mafeteng', 'LS.13', 'NULL', '3003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3003', '112', '4880', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4881', '1078', '1', 'Maseru', 'LS.14', 'NULL', '3004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3004', '112', '4881', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4882', '1078', '1', 'Mohaleʼs Hoek', 'LS.15', 'NULL', '3005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3005', '112', '4882', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4883', '1078', '1', 'Mokhotlong', 'LS.16', 'NULL', '3006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3006', '112', '4883', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4884', '1078', '1', 'Qachaʼs Nek', 'LS.17', 'NULL', '3007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3007', '112', '4884', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4885', '1078', '1', 'Quthing District', 'LS.18', 'NULL', '3008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3008', '112', '4885', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4886', '1078', '1', 'Thaba-Tseka District', 'LS.19', 'NULL', '3009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3009', '112', '4886', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LS.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4887', '1078', '1', 'Lithuania (general)', 'LT.00', 'NULL', '3010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3010', '112', '4887', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4888', '1078', '1', '(LH40)', 'LT.40', 'NULL', '3011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3011', '112', '4888', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4889', '1078', '1', 'Alytaus Apskritis', 'LT.56', 'NULL', '3012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3012', '112', '4889', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4890', '1078', '1', 'Kauno Apskritis', 'LT.57', 'NULL', '3013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3013', '112', '4890', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4891', '1078', '1', 'Klaipėdos Apskritis', 'LT.58', 'NULL', '3014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3014', '112', '4891', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4892', '1078', '1', 'Marijampolės Apskritis', 'LT.59', 'NULL', '3015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3015', '112', '4892', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4893', '1078', '1', 'Panevėžio Apskritis', 'LT.60', 'NULL', '3016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3016', '112', '4893', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4894', '1078', '1', 'Šiaulių Apskritis', 'LT.61', 'NULL', '3017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3017', '112', '4894', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4895', '1078', '1', 'Tauragės Apskritis', 'LT.62', 'NULL', '3018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3018', '112', '4895', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4896', '1078', '1', 'Telšių Apskritis', 'LT.63', 'NULL', '3019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3019', '112', '4896', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4897', '1078', '1', 'Utenos Apskritis', 'LT.64', 'NULL', '3020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3020', '112', '4897', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4898', '1078', '1', 'Vilniaus Apskritis', 'LT.65', 'NULL', '3021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3021', '112', '4898', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LT.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4899', '1078', '1', 'Luxembourg (general)', 'LU.00', 'NULL', '3022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3022', '112', '4899', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LU.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4900', '1078', '1', 'Diekirch', 'LU.01', 'NULL', '3023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3023', '112', '4900', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LU.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4901', '1078', '1', 'Grevenmacher', 'LU.02', 'NULL', '3024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3024', '112', '4901', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LU.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4902', '1078', '1', 'Luxembourg', 'LU.03', 'NULL', '3025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3025', '112', '4902', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LU.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4903', '1078', '1', 'Dobeles Rajons', 'LV.00', 'NULL', '3026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3026', '112', '4903', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4904', '1078', '1', 'Aizkraukles Rajons', 'LV.01', 'NULL', '3027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3027', '112', '4904', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4905', '1078', '1', 'Alūksnes Rajons', 'LV.02', 'NULL', '3028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3028', '112', '4905', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4906', '1078', '1', 'Balvu Rajons', 'LV.03', 'NULL', '3029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3029', '112', '4906', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4907', '1078', '1', 'Bauskas Rajons', 'LV.04', 'NULL', '3030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3030', '112', '4907', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4908', '1078', '1', 'Cēsu Rajons', 'LV.05', 'NULL', '3031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3031', '112', '4908', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4909', '1078', '1', 'Daugavpils', 'LV.06', 'NULL', '3032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3032', '112', '4909', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4910', '1078', '1', 'Daugavpils Rajons', 'LV.07', 'NULL', '3033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3033', '112', '4910', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4911', '1078', '1', 'Dobeles Rajons', 'LV.08', 'NULL', '3034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3034', '112', '4911', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4912', '1078', '1', 'Gulbenes Rajons', 'LV.09', 'NULL', '3035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3035', '112', '4912', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4913', '1078', '1', 'Jēkabpils Rajons', 'LV.10', 'NULL', '3036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3036', '112', '4913', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4914', '1078', '1', 'Jelgava', 'LV.11', 'NULL', '3037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3037', '112', '4914', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4915', '1078', '1', 'Jelgavas Rajons', 'LV.12', 'NULL', '3038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3038', '112', '4915', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4916', '1078', '1', 'Jūrmala', 'LV.13', 'NULL', '3039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3039', '112', '4916', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4917', '1078', '1', 'Krāslavas Rajons', 'LV.14', 'NULL', '3040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3040', '112', '4917', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4918', '1078', '1', 'Kuldīgas Rajons', 'LV.15', 'NULL', '3041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3041', '112', '4918', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4919', '1078', '1', 'Liepāja', 'LV.16', 'NULL', '3042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3042', '112', '4919', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4920', '1078', '1', 'Liepājas Rajons', 'LV.17', 'NULL', '3043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3043', '112', '4920', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4921', '1078', '1', 'Limbažu Rajons', 'LV.18', 'NULL', '3044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3044', '112', '4921', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4922', '1078', '1', 'Ludzas Rajons', 'LV.19', 'NULL', '3045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3045', '112', '4922', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4923', '1078', '1', 'Madonas Rajons', 'LV.20', 'NULL', '3046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3046', '112', '4923', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4924', '1078', '1', 'Ogres Rajons', 'LV.21', 'NULL', '3047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3047', '112', '4924', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4925', '1078', '1', 'Preiļu Rajons', 'LV.22', 'NULL', '3048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3048', '112', '4925', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4926', '1078', '1', 'Rēzekne', 'LV.23', 'NULL', '3049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3049', '112', '4926', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4927', '1078', '1', 'Rēzeknes Rajons', 'LV.24', 'NULL', '3050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3050', '112', '4927', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4928', '1078', '1', 'Rīga', 'LV.25', 'NULL', '3051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3051', '112', '4928', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4929', '1078', '1', 'Rīgas Rajons', 'LV.26', 'NULL', '3052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3052', '112', '4929', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4930', '1078', '1', 'Saldus Rajons', 'LV.27', 'NULL', '3053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3053', '112', '4930', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4931', '1078', '1', 'Talsu Rajons', 'LV.28', 'NULL', '3054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3054', '112', '4931', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4932', '1078', '1', 'Tukuma Rajons', 'LV.29', 'NULL', '3055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3055', '112', '4932', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4933', '1078', '1', 'Valkas Rajons', 'LV.30', 'NULL', '3056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3056', '112', '4933', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4934', '1078', '1', 'Valmieras Rajons', 'LV.31', 'NULL', '3057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3057', '112', '4934', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4935', '1078', '1', 'Ventspils', 'LV.32', 'NULL', '3058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3058', '112', '4935', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4936', '1078', '1', 'Ventspils Rajons', 'LV.33', 'NULL', '3059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3059', '112', '4936', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LV.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4937', '1078', '1', 'Libya (general)', 'LY.00', 'NULL', '3060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3060', '112', '4937', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4938', '1078', '1', 'Baladīyat al Abyār', 'LY.02', 'NULL', '3061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3061', '112', '4938', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4939', '1078', '1', 'Al ‘Azīzīyah', 'LY.03', 'NULL', '3062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3062', '112', '4939', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4940', '1078', '1', 'Baladīyat al Bayḑā''', 'LY.04', 'NULL', '3063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3063', '112', '4940', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4941', '1078', '1', 'Al Jufrah', 'LY.05', 'NULL', '3064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3064', '112', '4941', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4942', '1078', '1', 'Baladīyat al Jumayl', 'LY.06', 'NULL', '3065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3065', '112', '4942', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4943', '1078', '1', 'Al Kufrah', 'LY.08', 'NULL', '3066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3066', '112', '4943', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4944', '1078', '1', 'Baladīyat al Marj', 'LY.09', 'NULL', '3067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3067', '112', '4944', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4945', '1078', '1', 'Baladīyat al Qarābūll', 'LY.10', 'NULL', '3068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3068', '112', '4945', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4946', '1078', '1', 'Baladīyat al Qubbah', 'LY.11', 'NULL', '3069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3069', '112', '4946', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4947', '1078', '1', 'Baladīyat al `Ujaylāt', 'LY.12', 'NULL', '3070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3070', '112', '4947', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4948', '1078', '1', 'Ash Shāţiʼ', 'LY.13', 'NULL', '3071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3071', '112', '4948', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4949', '1078', '1', 'Baladīyat az Zahrā''', 'LY.15', 'NULL', '3072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3072', '112', '4949', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4950', '1078', '1', 'Baladīyat Banī Walīd', 'LY.18', 'NULL', '3073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3073', '112', '4950', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4951', '1078', '1', 'Baladīyat Bin Jawwād', 'LY.19', 'NULL', '3074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3074', '112', '4951', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4952', '1078', '1', 'Baladīyat Ghāt', 'LY.23', 'NULL', '3075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3075', '112', '4952', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4953', '1078', '1', 'Baladīyat Jādū', 'LY.24', 'NULL', '3076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3076', '112', '4953', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4954', '1078', '1', 'Baladīyat Jālū', 'LY.25', 'NULL', '3077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3077', '112', '4954', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4955', '1078', '1', 'Baladīyat Janzūr', 'LY.26', 'NULL', '3078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3078', '112', '4955', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4956', '1078', '1', 'Masallatah', 'LY.27', 'NULL', '3079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3079', '112', '4956', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4957', '1078', '1', 'Baladīyat Mizdah', 'LY.29', 'NULL', '3080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3080', '112', '4957', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4958', '1078', '1', 'Murzuq', 'LY.30', 'NULL', '3081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3081', '112', '4958', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4959', '1078', '1', 'Baladīyat Nālūt', 'LY.31', 'NULL', '3082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3082', '112', '4959', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4960', '1078', '1', 'Baladīyat Qamīnis', 'LY.32', 'NULL', '3083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3083', '112', '4960', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4961', '1078', '1', 'Baladīyat Qaşr Bin Ghashīr', 'LY.33', 'NULL', '3084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3084', '112', '4961', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4962', '1078', '1', 'Sabhā', 'LY.34', 'NULL', '3085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3085', '112', '4962', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4963', '1078', '1', 'Baladīyat Şabrātah', 'LY.35', 'NULL', '3086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3086', '112', '4963', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4964', '1078', '1', 'Baladīyat Shaḩḩāt', 'LY.36', 'NULL', '3087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3087', '112', '4964', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4965', '1078', '1', 'Baladīyat Şurmān', 'LY.37', 'NULL', '3088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3088', '112', '4965', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4966', '1078', '1', 'Tajura’ ', 'LY.39', 'NULL', '3089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3089', '112', '4966', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4967', '1078', '1', 'Tarhūnah', 'LY.41', 'NULL', '3090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3090', '112', '4967', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4968', '1078', '1', 'Ţubruq', 'LY.42', 'NULL', '3091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3091', '112', '4968', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4969', '1078', '1', 'Baladīyat Tūkrah', 'LY.43', 'NULL', '3092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3092', '112', '4969', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4970', '1078', '1', 'Zlīţan', 'LY.45', 'NULL', '3093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3093', '112', '4970', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4971', '1078', '1', 'Baladīyat Zuwārah', 'LY.46', 'NULL', '3094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3094', '112', '4971', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4972', '1078', '1', 'Ajdābiyā', 'LY.47', 'NULL', '3095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3095', '112', '4972', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4973', '1078', '1', 'Al Fātiḩ', 'LY.48', 'NULL', '3096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3096', '112', '4973', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4974', '1078', '1', 'Al Jabal al Akhḑar', 'LY.49', 'NULL', '3097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3097', '112', '4974', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4975', '1078', '1', 'Al Khums', 'LY.50', 'NULL', '3098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3098', '112', '4975', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4976', '1078', '1', 'An Nuqāţ al Khams', 'LY.51', 'NULL', '3099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3099', '112', '4976', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4977', '1078', '1', 'Awbārī', 'LY.52', 'NULL', '3100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3100', '112', '4977', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4978', '1078', '1', 'Az Zāwiyah', 'LY.53', 'NULL', '3101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3101', '112', '4978', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4979', '1078', '1', 'Banghāzī', 'LY.54', 'NULL', '3102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3102', '112', '4979', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4980', '1078', '1', 'Darnah', 'LY.55', 'NULL', '3103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3103', '112', '4980', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4981', '1078', '1', 'Ghadāmis', 'LY.56', 'NULL', '3104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3104', '112', '4981', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4982', '1078', '1', 'Gharyān', 'LY.57', 'NULL', '3105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3105', '112', '4982', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4983', '1078', '1', 'Mişrātah', 'LY.58', 'NULL', '3106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3106', '112', '4983', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4984', '1078', '1', 'Sawfajjīn', 'LY.59', 'NULL', '3107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3107', '112', '4984', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4985', '1078', '1', 'Surt', 'LY.60', 'NULL', '3108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3108', '112', '4985', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4986', '1078', '1', 'Ţarābulus', 'LY.61', 'NULL', '3109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3109', '112', '4986', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4987', '1078', '1', 'Yafran', 'LY.62', 'NULL', '3110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3110', '112', '4987', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «LY.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4988', '1078', '1', 'Agadir', 'MA.01', 'NULL', '3111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3111', '112', '4988', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4989', '1078', '1', 'Al Hoceïma', 'MA.02', 'NULL', '3112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3112', '112', '4989', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4990', '1078', '1', 'Azizal', 'MA.03', 'NULL', '3113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3113', '112', '4990', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4991', '1078', '1', 'Ben Slimane', 'MA.04', 'NULL', '3114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3114', '112', '4991', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4992', '1078', '1', 'Beni Mellal', 'MA.05', 'NULL', '3115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3115', '112', '4992', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4993', '1078', '1', 'Boulemane', 'MA.06', 'NULL', '3116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3116', '112', '4993', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4994', '1078', '1', 'Casablanca', 'MA.07', 'NULL', '3117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3117', '112', '4994', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4995', '1078', '1', 'Chaouen', 'MA.08', 'NULL', '3118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3118', '112', '4995', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4996', '1078', '1', 'El Jadida', 'MA.09', 'NULL', '3119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3119', '112', '4996', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4997', '1078', '1', 'El Kelaa des Srarhna', 'MA.10', 'NULL', '3120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3120', '112', '4997', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4998', '1078', '1', 'Er Rachidia', 'MA.11', 'NULL', '3121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3121', '112', '4998', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('4999', '1078', '1', 'Essaouira', 'MA.12', 'NULL', '3122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3122', '112', '4999', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5000', '1078', '1', 'Fes', 'MA.13', 'NULL', '3123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3123', '112', '5000', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5001', '1078', '1', 'Figuig', 'MA.14', 'NULL', '3124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3124', '112', '5001', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5002', '1078', '1', 'Kenitra', 'MA.15', 'NULL', '3125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3125', '112', '5002', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5003', '1078', '1', 'Khemisset', 'MA.16', 'NULL', '3126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3126', '112', '5003', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5004', '1078', '1', 'Khenifra', 'MA.17', 'NULL', '3127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3127', '112', '5004', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5005', '1078', '1', 'Khouribga', 'MA.18', 'NULL', '3128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3128', '112', '5005', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5006', '1078', '1', 'Marrakech', 'MA.19', 'NULL', '3129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3129', '112', '5006', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5007', '1078', '1', 'Meknes', 'MA.20', 'NULL', '3130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3130', '112', '5007', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5008', '1078', '1', 'Nador', 'MA.21', 'NULL', '3131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3131', '112', '5008', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5009', '1078', '1', 'Ouarzazate', 'MA.22', 'NULL', '3132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3132', '112', '5009', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5010', '1078', '1', 'Oujda', 'MA.23', 'NULL', '3133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3133', '112', '5010', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5011', '1078', '1', 'Rabat-Sale', 'MA.24', 'NULL', '3134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3134', '112', '5011', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5012', '1078', '1', 'Safi', 'MA.25', 'NULL', '3135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3135', '112', '5012', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5013', '1078', '1', 'Settat', 'MA.26', 'NULL', '3136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3136', '112', '5013', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5014', '1078', '1', 'Tanger', 'MA.27', 'NULL', '3137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3137', '112', '5014', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5015', '1078', '1', 'Tata', 'MA.29', 'NULL', '3138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3138', '112', '5015', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5016', '1078', '1', 'Taza', 'MA.30', 'NULL', '3139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3139', '112', '5016', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5017', '1078', '1', 'Tiznit', 'MA.32', 'NULL', '3140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3140', '112', '5017', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5018', '1078', '1', 'Guelmim', 'MA.33', 'NULL', '3141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3141', '112', '5018', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5019', '1078', '1', 'Ifrane', 'MA.34', 'NULL', '3142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3142', '112', '5019', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5020', '1078', '1', 'Laayoune', 'MA.35', 'NULL', '3143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3143', '112', '5020', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5021', '1078', '1', 'Tan-Tan', 'MA.36', 'NULL', '3144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3144', '112', '5021', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5022', '1078', '1', 'Taounate', 'MA.37', 'NULL', '3145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3145', '112', '5022', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5023', '1078', '1', 'Sidi Kacem', 'MA.38', 'NULL', '3146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3146', '112', '5023', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5024', '1078', '1', 'Taroudannt', 'MA.39', 'NULL', '3147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3147', '112', '5024', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5025', '1078', '1', 'Tetouan', 'MA.40', 'NULL', '3148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3148', '112', '5025', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5026', '1078', '1', 'Larache', 'MA.41', 'NULL', '3149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3149', '112', '5026', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5027', '1078', '1', '(MO42)', 'MA.42', 'NULL', '3150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3150', '112', '5027', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5028', '1078', '1', '(MO43)', 'MA.43', 'NULL', '3151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3151', '112', '5028', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5029', '1078', '1', '(MO44)', 'MA.44', 'NULL', '3152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3152', '112', '5029', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5030', '1078', '1', 'Grand Casablanca', 'MA.45', 'NULL', '3153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3153', '112', '5030', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5031', '1078', '1', 'Fès-Boulemane', 'MA.46', 'NULL', '3154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3154', '112', '5031', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5032', '1078', '1', 'Marrakech-Tensift-Al Haouz', 'MA.47', 'NULL', '3155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3155', '112', '5032', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5033', '1078', '1', 'Meknès-Tafilalet', 'MA.48', 'NULL', '3156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3156', '112', '5033', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5034', '1078', '1', 'Rabat-Salé-Zemmour-Zaër', 'MA.49', 'NULL', '3157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3157', '112', '5034', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5035', '1078', '1', 'Chaouia-Ouardigha', 'MA.50', 'NULL', '3158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3158', '112', '5035', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5036', '1078', '1', 'Doukkala-Abda', 'MA.51', 'NULL', '3159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3159', '112', '5036', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5037', '1078', '1', 'Gharb-Chrarda-Beni Hssen', 'MA.52', 'NULL', '3160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3160', '112', '5037', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5038', '1078', '1', 'Guelmim-Es Smara', 'MA.53', 'NULL', '3161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3161', '112', '5038', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5039', '1078', '1', 'Oriental', 'MA.54', 'NULL', '3162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3162', '112', '5039', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5040', '1078', '1', 'Souss-Massa-Drâa', 'MA.55', 'NULL', '3163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3163', '112', '5040', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5041', '1078', '1', 'Tadla-Azilal', 'MA.56', 'NULL', '3164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3164', '112', '5041', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5042', '1078', '1', 'Tanger-Tétouan', 'MA.57', 'NULL', '3165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3165', '112', '5042', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5043', '1078', '1', 'Taza-Al Hoceima-Taounate', 'MA.58', 'NULL', '3166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3166', '112', '5043', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5044', '1078', '1', 'Laâyoune-Boujdour-Sakia El Hamra', 'MA.59', 'NULL', '3167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3167', '112', '5044', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MA.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5045', '1078', '1', 'Monaco (general)', 'MC.00', 'NULL', '3168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3168', '112', '5045', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MC.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5046', '1078', '1', 'Ungheni Judetul', 'MD.00', 'NULL', '3169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3169', '112', '5046', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5047', '1078', '1', '(MD13)', 'MD.13', 'NULL', '3170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3170', '112', '5047', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5048', '1078', '1', 'Balti', 'MD.46', 'NULL', '3171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3171', '112', '5048', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5049', '1078', '1', 'Cahul', 'MD.47', 'NULL', '3172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3172', '112', '5049', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5050', '1078', '1', 'Stinga Nistrului', 'MD.49', 'NULL', '3173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3173', '112', '5050', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5051', '1078', '1', 'Edinet', 'MD.50', 'NULL', '3174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3174', '112', '5051', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5052', '1078', '1', 'Găgăuzia', 'MD.51', 'NULL', '3175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3175', '112', '5052', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5053', '1078', '1', 'Lapusna', 'MD.52', 'NULL', '3176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3176', '112', '5053', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5054', '1078', '1', 'Orhei', 'MD.53', 'NULL', '3177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3177', '112', '5054', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5055', '1078', '1', 'Soroca', 'MD.54', 'NULL', '3178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3178', '112', '5055', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5056', '1078', '1', 'Tighina', 'MD.55', 'NULL', '3179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3179', '112', '5056', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5057', '1078', '1', 'Ungheni', 'MD.56', 'NULL', '3180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3180', '112', '5057', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5058', '1078', '1', 'Chişinău', 'MD.57', 'NULL', '3181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3181', '112', '5058', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5059', '1078', '1', 'Stînga Nistrului', 'MD.58', 'NULL', '3182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3182', '112', '5059', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5060', '1078', '1', 'Raionul Anenii Noi', 'MD.59', 'NULL', '3183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3183', '112', '5060', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5061', '1078', '1', 'Bălţi', 'MD.60', 'NULL', '3184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3184', '112', '5061', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5062', '1078', '1', 'Raionul Basarabeasca', 'MD.61', 'NULL', '3185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3185', '112', '5062', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5063', '1078', '1', 'Bender', 'MD.62', 'NULL', '3186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3186', '112', '5063', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5064', '1078', '1', 'Raionul Briceni', 'MD.63', 'NULL', '3187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3187', '112', '5064', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5065', '1078', '1', 'Raionul Cahul', 'MD.64', 'NULL', '3188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3188', '112', '5065', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5066', '1078', '1', 'Raionul Cantemir', 'MD.65', 'NULL', '3189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3189', '112', '5066', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5067', '1078', '1', 'Călăraşi', 'MD.66', 'NULL', '3190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3190', '112', '5067', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5068', '1078', '1', 'Căuşeni', 'MD.67', 'NULL', '3191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3191', '112', '5068', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5069', '1078', '1', 'Raionul Cimişlia', 'MD.68', 'NULL', '3192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3192', '112', '5069', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5070', '1078', '1', 'Raionul Criuleni', 'MD.69', 'NULL', '3193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3193', '112', '5070', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5071', '1078', '1', 'Raionul Donduşeni', 'MD.70', 'NULL', '3194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3194', '112', '5071', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5072', '1078', '1', 'Raionul Drochia', 'MD.71', 'NULL', '3195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3195', '112', '5072', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5073', '1078', '1', 'Dubăsari', 'MD.72', 'NULL', '3196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3196', '112', '5073', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5074', '1078', '1', 'Raionul Edineţ', 'MD.73', 'NULL', '3197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3197', '112', '5074', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5075', '1078', '1', 'Raionul Făleşti', 'MD.74', 'NULL', '3198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3198', '112', '5075', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5076', '1078', '1', 'Raionul Floreşti', 'MD.75', 'NULL', '3199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3199', '112', '5076', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.75» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5077', '1078', '1', 'Raionul Glodeni', 'MD.76', 'NULL', '3200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3200', '112', '5077', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5078', '1078', '1', 'Raionul Hînceşti', 'MD.77', 'NULL', '3201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3201', '112', '5078', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5079', '1078', '1', 'Raionul Ialoveni', 'MD.78', 'NULL', '3202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3202', '112', '5079', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5080', '1078', '1', 'Raionul Leova', 'MD.79', 'NULL', '3203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3203', '112', '5080', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5081', '1078', '1', 'Raionul Nisporeni', 'MD.80', 'NULL', '3204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3204', '112', '5081', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5082', '1078', '1', 'Raionul Ocniţa', 'MD.81', 'NULL', '3205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3205', '112', '5082', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5083', '1078', '1', 'Raionul Orhei', 'MD.82', 'NULL', '3206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3206', '112', '5083', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5084', '1078', '1', 'Raionul Rezina', 'MD.83', 'NULL', '3207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3207', '112', '5084', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5085', '1078', '1', 'Raionul Rîşcani', 'MD.84', 'NULL', '3208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3208', '112', '5085', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5086', '1078', '1', 'Raionul Sîngerei', 'MD.85', 'NULL', '3209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3209', '112', '5086', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5087', '1078', '1', 'Raionul Şoldăneşti', 'MD.86', 'NULL', '3210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3210', '112', '5087', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5088', '1078', '1', 'Raionul Soroca', 'MD.87', 'NULL', '3211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3211', '112', '5088', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.87» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5089', '1078', '1', 'Ştefan-Vodă', 'MD.88', 'NULL', '3212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3212', '112', '5089', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.88» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5090', '1078', '1', 'Raionul Străşeni', 'MD.89', 'NULL', '3213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3213', '112', '5090', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.89» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5091', '1078', '1', 'Raionul Taraclia', 'MD.90', 'NULL', '3214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3214', '112', '5091', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.90» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5092', '1078', '1', 'Raionul Teleneşti', 'MD.91', 'NULL', '3215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3215', '112', '5092', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.91» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5093', '1078', '1', 'Raionul Ungheni', 'MD.92', 'NULL', '3216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3216', '112', '5093', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MD.92» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5094', '1078', '1', 'Montenegro (general)', 'ME.00', 'NULL', '3217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3217', '112', '5094', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ME.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5095', '1078', '1', 'Madagascar (general)', 'MG.00', 'NULL', '3218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3218', '112', '5095', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5096', '1078', '1', 'Antsiranana', 'MG.01', 'NULL', '3219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3219', '112', '5096', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MG.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5097', '1078', '1', 'Fianarantsoa', 'MG.02', 'NULL', '3220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3220', '112', '5097', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MG.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5098', '1078', '1', 'Mahajanga', 'MG.03', 'NULL', '3221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3221', '112', '5098', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MG.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5099', '1078', '1', 'Toamasina', 'MG.04', 'NULL', '3222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3222', '112', '5099', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MG.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5100', '1078', '1', 'Antananarivo', 'MG.05', 'NULL', '3223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3223', '112', '5100', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MG.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5101', '1078', '1', 'Toliara', 'MG.06', 'NULL', '3224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3224', '112', '5101', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MG.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5102', '1078', '1', 'Marshall Islands (general)', 'MH.00', 'NULL', '3225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3225', '112', '5102', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MH.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5103', '1078', '1', 'Macedonia, The Former Yugoslav Republic of (general)', 'MK.00', 'NULL', '3226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3226', '112', '5103', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5104', '1078', '1', 'Aračinovo', 'MK.01', 'NULL', '3227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3227', '112', '5104', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5105', '1078', '1', 'Bač', 'MK.02', 'NULL', '3228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3228', '112', '5105', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5106', '1078', '1', 'Belčišta', 'MK.03', 'NULL', '3229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3229', '112', '5106', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5107', '1078', '1', 'Berovo', 'MK.04', 'NULL', '3230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3230', '112', '5107', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5108', '1078', '1', 'Bistrica', 'MK.05', 'NULL', '3231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3231', '112', '5108', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5109', '1078', '1', 'Bitola', 'MK.06', 'NULL', '3232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3232', '112', '5109', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5110', '1078', '1', 'Blatec', 'MK.07', 'NULL', '3233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3233', '112', '5110', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5111', '1078', '1', 'Bogdanci', 'MK.08', 'NULL', '3234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3234', '112', '5111', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5112', '1078', '1', 'Opstina Bogomila', 'MK.09', 'NULL', '3235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3235', '112', '5112', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5113', '1078', '1', 'Bogovinje', 'MK.10', 'NULL', '3236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3236', '112', '5113', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5114', '1078', '1', 'Bosilovo', 'MK.11', 'NULL', '3237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3237', '112', '5114', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5115', '1078', '1', 'Brvenica', 'MK.12', 'NULL', '3238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3238', '112', '5115', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5116', '1078', '1', 'Čair', 'MK.13', 'NULL', '3239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3239', '112', '5116', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5117', '1078', '1', 'Capari', 'MK.14', 'NULL', '3240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3240', '112', '5117', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5118', '1078', '1', 'Čaška', 'MK.15', 'NULL', '3241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3241', '112', '5118', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5119', '1078', '1', 'Čegrana', 'MK.16', 'NULL', '3242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3242', '112', '5119', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5120', '1078', '1', 'Centar', 'MK.17', 'NULL', '3243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3243', '112', '5120', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5121', '1078', '1', 'Centar Župa', 'MK.18', 'NULL', '3244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3244', '112', '5121', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5122', '1078', '1', 'Češinovo', 'MK.19', 'NULL', '3245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3245', '112', '5122', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5123', '1078', '1', 'Čučer-Sandevo', 'MK.20', 'NULL', '3246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3246', '112', '5123', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5124', '1078', '1', 'Debar', 'MK.21', 'NULL', '3247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3247', '112', '5124', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5125', '1078', '1', 'Delčevo', 'MK.22', 'NULL', '3248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3248', '112', '5125', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5126', '1078', '1', 'Delogoždi', 'MK.23', 'NULL', '3249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3249', '112', '5126', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5127', '1078', '1', 'Demir Hisar', 'MK.24', 'NULL', '3250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3250', '112', '5127', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5128', '1078', '1', 'Demir Kapija', 'MK.25', 'NULL', '3251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3251', '112', '5128', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5129', '1078', '1', 'Dobruševo', 'MK.26', 'NULL', '3252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3252', '112', '5129', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5130', '1078', '1', 'Dolna Banjica', 'MK.27', 'NULL', '3253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3253', '112', '5130', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5131', '1078', '1', 'Dolneni', 'MK.28', 'NULL', '3254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3254', '112', '5131', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5132', '1078', '1', 'Opstina Gjorce Petrov', 'MK.29', 'NULL', '3255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3255', '112', '5132', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5133', '1078', '1', 'Drugovo', 'MK.30', 'NULL', '3256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3256', '112', '5133', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5134', '1078', '1', 'Džepčište', 'MK.31', 'NULL', '3257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3257', '112', '5134', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5135', '1078', '1', 'Gazi Baba', 'MK.32', 'NULL', '3258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3258', '112', '5135', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5136', '1078', '1', 'Gevgelija', 'MK.33', 'NULL', '3259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3259', '112', '5136', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5137', '1078', '1', 'Gostivar', 'MK.34', 'NULL', '3260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3260', '112', '5137', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5138', '1078', '1', 'Gradsko', 'MK.35', 'NULL', '3261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3261', '112', '5138', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5139', '1078', '1', 'Ilinden', 'MK.36', 'NULL', '3262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3262', '112', '5139', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5140', '1078', '1', 'Izvor', 'MK.37', 'NULL', '3263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3263', '112', '5140', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5141', '1078', '1', 'Jegunovce', 'MK.38', 'NULL', '3264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3264', '112', '5141', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5142', '1078', '1', 'Kamenjane', 'MK.39', 'NULL', '3265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3265', '112', '5142', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5143', '1078', '1', 'Karbinci', 'MK.40', 'NULL', '3266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3266', '112', '5143', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5144', '1078', '1', 'Karpoš', 'MK.41', 'NULL', '3267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3267', '112', '5144', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5145', '1078', '1', 'Kavadarci', 'MK.42', 'NULL', '3268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3268', '112', '5145', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5146', '1078', '1', 'Kičevo', 'MK.43', 'NULL', '3269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3269', '112', '5146', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5147', '1078', '1', 'Kisela Voda', 'MK.44', 'NULL', '3270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3270', '112', '5147', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5148', '1078', '1', 'Klečevce', 'MK.45', 'NULL', '3271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3271', '112', '5148', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5149', '1078', '1', 'Kočani', 'MK.46', 'NULL', '3272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3272', '112', '5149', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5150', '1078', '1', 'Konče', 'MK.47', 'NULL', '3273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3273', '112', '5150', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5151', '1078', '1', 'Kondovo', 'MK.48', 'NULL', '3274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3274', '112', '5151', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5152', '1078', '1', 'Konopište', 'MK.49', 'NULL', '3275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3275', '112', '5152', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5153', '1078', '1', 'Kosel', 'MK.50', 'NULL', '3276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3276', '112', '5153', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5154', '1078', '1', 'Kratovo', 'MK.51', 'NULL', '3277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3277', '112', '5154', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5155', '1078', '1', 'Kriva Palanka', 'MK.52', 'NULL', '3278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3278', '112', '5155', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5156', '1078', '1', 'Krivogaštani', 'MK.53', 'NULL', '3279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3279', '112', '5156', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5157', '1078', '1', 'Kruševo', 'MK.54', 'NULL', '3280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3280', '112', '5157', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5158', '1078', '1', 'Kukliš', 'MK.55', 'NULL', '3281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3281', '112', '5158', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5159', '1078', '1', 'Kukurečani', 'MK.56', 'NULL', '3282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3282', '112', '5159', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5160', '1078', '1', 'Kumanovo', 'MK.57', 'NULL', '3283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3283', '112', '5160', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5161', '1078', '1', 'Labuništa', 'MK.58', 'NULL', '3284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3284', '112', '5161', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5162', '1078', '1', 'Opstina Lipkovo', 'MK.59', 'NULL', '3285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3285', '112', '5162', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5163', '1078', '1', 'Lozovo', 'MK.60', 'NULL', '3286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3286', '112', '5163', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5164', '1078', '1', 'Lukovo', 'MK.61', 'NULL', '3287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3287', '112', '5164', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5165', '1078', '1', 'Makedonska Kamenica', 'MK.62', 'NULL', '3288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3288', '112', '5165', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5166', '1078', '1', 'Makedonski Brod', 'MK.63', 'NULL', '3289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3289', '112', '5166', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5167', '1078', '1', 'Mavrovi Anovi', 'MK.64', 'NULL', '3290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3290', '112', '5167', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5168', '1078', '1', 'Mešeišta', 'MK.65', 'NULL', '3291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3291', '112', '5168', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5169', '1078', '1', 'Miravci', 'MK.66', 'NULL', '3292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3292', '112', '5169', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5170', '1078', '1', 'Mogila', 'MK.67', 'NULL', '3293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3293', '112', '5170', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5171', '1078', '1', 'Murtino', 'MK.68', 'NULL', '3294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3294', '112', '5171', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5172', '1078', '1', 'Negotino', 'MK.69', 'NULL', '3295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3295', '112', '5172', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5173', '1078', '1', 'Negotino-Pološko', 'MK.70', 'NULL', '3296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3296', '112', '5173', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5174', '1078', '1', 'Novaci', 'MK.71', 'NULL', '3297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3297', '112', '5174', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5175', '1078', '1', 'Novo Selo', 'MK.72', 'NULL', '3298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3298', '112', '5175', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5176', '1078', '1', 'Obleševo', 'MK.73', 'NULL', '3299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3299', '112', '5176', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5177', '1078', '1', 'Ohrid', 'MK.74', 'NULL', '3300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3300', '112', '5177', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5178', '1078', '1', 'Orašac', 'MK.75', 'NULL', '3301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3301', '112', '5178', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.75» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5179', '1078', '1', 'Orizari', 'MK.76', 'NULL', '3302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3302', '112', '5179', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5180', '1078', '1', 'Oslomej', 'MK.77', 'NULL', '3303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3303', '112', '5180', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5181', '1078', '1', 'Pehčevo', 'MK.78', 'NULL', '3304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3304', '112', '5181', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5182', '1078', '1', 'Petrovec', 'MK.79', 'NULL', '3305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3305', '112', '5182', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5183', '1078', '1', 'Plasnica', 'MK.80', 'NULL', '3306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3306', '112', '5183', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5184', '1078', '1', 'Podareš', 'MK.81', 'NULL', '3307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3307', '112', '5184', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5185', '1078', '1', 'Prilep', 'MK.82', 'NULL', '3308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3308', '112', '5185', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5186', '1078', '1', 'Probištip', 'MK.83', 'NULL', '3309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3309', '112', '5186', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5187', '1078', '1', 'Radoviš', 'MK.84', 'NULL', '3310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3310', '112', '5187', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5188', '1078', '1', 'Opstina Rankovce', 'MK.85', 'NULL', '3311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3311', '112', '5188', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5189', '1078', '1', 'Resen', 'MK.86', 'NULL', '3312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3312', '112', '5189', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5190', '1078', '1', 'Rosoman', 'MK.87', 'NULL', '3313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3313', '112', '5190', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.87» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5191', '1078', '1', 'Rostuša', 'MK.88', 'NULL', '3314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3314', '112', '5191', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.88» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5192', '1078', '1', 'Samokov', 'MK.89', 'NULL', '3315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3315', '112', '5192', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.89» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5193', '1078', '1', 'Saraj', 'MK.90', 'NULL', '3316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3316', '112', '5193', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.90» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5194', '1078', '1', 'Šipkovica', 'MK.91', 'NULL', '3317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3317', '112', '5194', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.91» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5195', '1078', '1', 'Sopište', 'MK.92', 'NULL', '3318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3318', '112', '5195', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.92» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5196', '1078', '1', 'Sopotnica', 'MK.93', 'NULL', '3319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3319', '112', '5196', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.93» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5197', '1078', '1', 'Srbinovo', 'MK.94', 'NULL', '3320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3320', '112', '5197', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.94» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5198', '1078', '1', 'Staravina', 'MK.95', 'NULL', '3321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3321', '112', '5198', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.95» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5199', '1078', '1', 'Star Dojran', 'MK.96', 'NULL', '3322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3322', '112', '5199', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.96» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5200', '1078', '1', 'Staro Nagoričane', 'MK.97', 'NULL', '3323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3323', '112', '5200', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.97» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5201', '1078', '1', 'Štip', 'MK.98', 'NULL', '3324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3324', '112', '5201', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.98» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5202', '1078', '1', 'Struga', 'MK.99', 'NULL', '3325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3325', '112', '5202', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.99» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5203', '1078', '1', 'Strumica', 'MK.A1', 'NULL', '3326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3326', '112', '5203', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.A1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5204', '1078', '1', 'Studeničani', 'MK.A2', 'NULL', '3327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3327', '112', '5204', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.A2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5205', '1078', '1', 'Šuto Orizari', 'MK.A3', 'NULL', '3328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3328', '112', '5205', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.A3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5206', '1078', '1', 'Sveti Nikole', 'MK.A4', 'NULL', '3329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3329', '112', '5206', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.A4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5207', '1078', '1', 'Tearce', 'MK.A5', 'NULL', '3330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3330', '112', '5207', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.A5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5208', '1078', '1', 'Tetovo', 'MK.A6', 'NULL', '3331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3331', '112', '5208', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.A6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5209', '1078', '1', 'Topolčani', 'MK.A7', 'NULL', '3332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3332', '112', '5209', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.A7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5210', '1078', '1', 'Valandovo', 'MK.A8', 'NULL', '3333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3333', '112', '5210', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.A8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5211', '1078', '1', 'Vasilevo', 'MK.A9', 'NULL', '3334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3334', '112', '5211', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.A9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5212', '1078', '1', 'Veles', 'MK.B1', 'NULL', '3335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3335', '112', '5212', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.B1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5213', '1078', '1', 'Velešta', 'MK.B2', 'NULL', '3336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3336', '112', '5213', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.B2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5214', '1078', '1', 'Vevčani', 'MK.B3', 'NULL', '3337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3337', '112', '5214', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.B3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5215', '1078', '1', 'Vinica', 'MK.B4', 'NULL', '3338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3338', '112', '5215', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.B4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5216', '1078', '1', 'Vitolište', 'MK.B5', 'NULL', '3339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3339', '112', '5216', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.B5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5217', '1078', '1', 'Vraneštica', 'MK.B6', 'NULL', '3340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3340', '112', '5217', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.B6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5218', '1078', '1', 'Vrapčište', 'MK.B7', 'NULL', '3341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3341', '112', '5218', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.B7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5219', '1078', '1', 'Vratnica', 'MK.B8', 'NULL', '3342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3342', '112', '5219', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.B8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5220', '1078', '1', 'Vrutok', 'MK.B9', 'NULL', '3343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3343', '112', '5220', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.B9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5221', '1078', '1', 'Zajas', 'MK.C1', 'NULL', '3344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3344', '112', '5221', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.C1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5222', '1078', '1', 'Zelenikovo', 'MK.C2', 'NULL', '3345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3345', '112', '5222', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.C2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5223', '1078', '1', 'Želino', 'MK.C3', 'NULL', '3346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3346', '112', '5223', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.C3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5224', '1078', '1', 'Žitoše', 'MK.C4', 'NULL', '3347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3347', '112', '5224', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.C4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5225', '1078', '1', 'Zletovo', 'MK.C5', 'NULL', '3348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3348', '112', '5225', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.C5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5226', '1078', '1', 'Zrnovci', 'MK.C6', 'NULL', '3349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3349', '112', '5226', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MK.C6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5227', '1078', '1', 'Mali (general)', 'ML.00', 'NULL', '3350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3350', '112', '5227', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5228', '1078', '1', 'Bamako', 'ML.01', 'NULL', '3351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3351', '112', '5228', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5229', '1078', '1', 'Gao', 'ML.02', 'NULL', '3352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3352', '112', '5229', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5230', '1078', '1', 'Kayes', 'ML.03', 'NULL', '3353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3353', '112', '5230', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5231', '1078', '1', 'Mopti', 'ML.04', 'NULL', '3354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3354', '112', '5231', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5232', '1078', '1', 'Ségou', 'ML.05', 'NULL', '3355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3355', '112', '5232', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5233', '1078', '1', 'Sikasso', 'ML.06', 'NULL', '3356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3356', '112', '5233', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5234', '1078', '1', 'Koulikoro', 'ML.07', 'NULL', '3357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3357', '112', '5234', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5235', '1078', '1', 'Tombouctou', 'ML.08', 'NULL', '3358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3358', '112', '5235', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5236', '1078', '1', 'Gao', 'ML.09', 'NULL', '3359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3359', '112', '5236', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5237', '1078', '1', 'Kidal', 'ML.10', 'NULL', '3360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3360', '112', '5237', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ML.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5238', '1078', '1', 'Burma (general)', 'MM.00', 'NULL', '3361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3361', '112', '5238', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5239', '1078', '1', 'Rakhine State', 'MM.01', 'NULL', '3362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3362', '112', '5239', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5240', '1078', '1', 'Chin State', 'MM.02', 'NULL', '3363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3363', '112', '5240', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5241', '1078', '1', 'Ayeyarwady', 'MM.03', 'NULL', '3364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3364', '112', '5241', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5242', '1078', '1', 'Kachin State', 'MM.04', 'NULL', '3365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3365', '112', '5242', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5243', '1078', '1', 'Kayin State', 'MM.05', 'NULL', '3366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3366', '112', '5243', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5244', '1078', '1', 'Kayah State', 'MM.06', 'NULL', '3367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3367', '112', '5244', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5245', '1078', '1', 'Magwe', 'MM.07', 'NULL', '3368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3368', '112', '5245', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5246', '1078', '1', 'Mandalay', 'MM.08', 'NULL', '3369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3369', '112', '5246', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5247', '1078', '1', 'Pegu', 'MM.09', 'NULL', '3370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3370', '112', '5247', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5248', '1078', '1', 'Sagain', 'MM.10', 'NULL', '3371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3371', '112', '5248', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5249', '1078', '1', 'Shan State', 'MM.11', 'NULL', '3372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3372', '112', '5249', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5250', '1078', '1', 'Tanintharyi', 'MM.12', 'NULL', '3373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3373', '112', '5250', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5251', '1078', '1', 'Mon State', 'MM.13', 'NULL', '3374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3374', '112', '5251', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5252', '1078', '1', 'Rangoon', 'MM.14', 'NULL', '3375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3375', '112', '5252', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5253', '1078', '1', 'Magway', 'MM.15', 'NULL', '3376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3376', '112', '5253', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5254', '1078', '1', 'Bago', 'MM.16', 'NULL', '3377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3377', '112', '5254', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5255', '1078', '1', 'Yangon', 'MM.17', 'NULL', '3378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3378', '112', '5255', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5256', '1078', '1', '(BM22)', 'MM.22', 'NULL', '3379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3379', '112', '5256', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MM.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5257', '1078', '1', 'Erdenet Hot (historical)', 'MN.00', 'NULL', '3380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3380', '112', '5257', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5258', '1078', '1', 'Arhangay', 'MN.01', 'NULL', '3381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3381', '112', '5258', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5259', '1078', '1', 'Bayanhongor', 'MN.02', 'NULL', '3382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3382', '112', '5259', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5260', '1078', '1', 'Bayan-Ölgiy', 'MN.03', 'NULL', '3383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3383', '112', '5260', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5261', '1078', '1', 'East Aimak', 'MN.06', 'NULL', '3384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3384', '112', '5261', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5262', '1078', '1', 'East Gobi Aymag', 'MN.07', 'NULL', '3385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3385', '112', '5262', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5263', '1078', '1', 'Middle Govĭ', 'MN.08', 'NULL', '3386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3386', '112', '5263', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5264', '1078', '1', 'Dzavhan', 'MN.09', 'NULL', '3387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3387', '112', '5264', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5265', '1078', '1', 'Govĭ-Altay', 'MN.10', 'NULL', '3388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3388', '112', '5265', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5266', '1078', '1', 'Hentiy', 'MN.11', 'NULL', '3389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3389', '112', '5266', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5267', '1078', '1', 'Hovd', 'MN.12', 'NULL', '3390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3390', '112', '5267', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5268', '1078', '1', 'Hövsgöl', 'MN.13', 'NULL', '3391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3391', '112', '5268', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5269', '1078', '1', 'South Gobi Aimak', 'MN.14', 'NULL', '3392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3392', '112', '5269', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5270', '1078', '1', 'South Hangay', 'MN.15', 'NULL', '3393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3393', '112', '5270', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5271', '1078', '1', 'Selenge', 'MN.16', 'NULL', '3394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3394', '112', '5271', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5272', '1078', '1', 'Sühbaatar', 'MN.17', 'NULL', '3395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3395', '112', '5272', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5273', '1078', '1', 'Central Aimak', 'MN.18', 'NULL', '3396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3396', '112', '5273', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5274', '1078', '1', 'Uvs', 'MN.19', 'NULL', '3397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3397', '112', '5274', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5275', '1078', '1', 'Ulaanbaatar', 'MN.20', 'NULL', '3398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3398', '112', '5275', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5276', '1078', '1', 'Bulgan', 'MN.21', 'NULL', '3399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3399', '112', '5276', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5277', '1078', '1', 'Darhan Uul', 'MN.23', 'NULL', '3400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3400', '112', '5277', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5278', '1078', '1', 'Govĭ-Sumber', 'MN.24', 'NULL', '3401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3401', '112', '5278', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5279', '1078', '1', 'Orhon', 'MN.25', 'NULL', '3402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3402', '112', '5279', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MN.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5280', '1078', '1', 'Macau (general)', 'MO.00', 'NULL', '3403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3403', '112', '5280', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MO.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5281', '1078', '1', 'Ilhas', 'MO.01', 'NULL', '3404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3404', '112', '5281', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MO.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5282', '1078', '1', 'Macau', 'MO.02', 'NULL', '3405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3405', '112', '5282', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MO.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5283', '1078', '1', 'Région Martinique', 'MQ.MQ', 'NULL', '3406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3406', '112', '5283', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MQ.MQ» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5284', '1078', '1', 'Nouakchott District de', 'MR.00', 'NULL', '3407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3407', '112', '5284', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5285', '1078', '1', 'Hodh Ech Chargui', 'MR.01', 'NULL', '3408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3408', '112', '5285', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5286', '1078', '1', 'Hodh El Gharbi', 'MR.02', 'NULL', '3409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3409', '112', '5286', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5287', '1078', '1', 'Assaba', 'MR.03', 'NULL', '3410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3410', '112', '5287', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5288', '1078', '1', 'Gorgol', 'MR.04', 'NULL', '3411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3411', '112', '5288', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5289', '1078', '1', 'Brakna', 'MR.05', 'NULL', '3412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3412', '112', '5289', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5290', '1078', '1', 'Trarza', 'MR.06', 'NULL', '3413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3413', '112', '5290', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5291', '1078', '1', 'Adrar', 'MR.07', 'NULL', '3414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3414', '112', '5291', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5292', '1078', '1', 'Dakhlet Nouadhibou', 'MR.08', 'NULL', '3415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3415', '112', '5292', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5293', '1078', '1', 'Tagant', 'MR.09', 'NULL', '3416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3416', '112', '5293', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5294', '1078', '1', 'Guidimaka', 'MR.10', 'NULL', '3417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3417', '112', '5294', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5295', '1078', '1', 'Tiris Zemmour', 'MR.11', 'NULL', '3418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3418', '112', '5295', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5296', '1078', '1', 'Inchiri', 'MR.12', 'NULL', '3419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3419', '112', '5296', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MR.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5297', '1078', '1', 'Montserrat (general)', 'MS.00', 'NULL', '3420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3420', '112', '5297', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MS.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5298', '1078', '1', 'Saint Anthony', 'MS.01', 'NULL', '3421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3421', '112', '5298', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MS.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5299', '1078', '1', 'Saint Georges', 'MS.02', 'NULL', '3422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3422', '112', '5299', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MS.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5300', '1078', '1', 'Saint Peter', 'MS.03', 'NULL', '3423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3423', '112', '5300', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MS.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5301', '1078', '1', 'Malta (general)', 'MT.00', 'NULL', '3424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3424', '112', '5301', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MT.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5302', '1078', '1', 'Mauritius (general)', 'MU.00', 'NULL', '3425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3425', '112', '5302', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5303', '1078', '1', 'Black River', 'MU.12', 'NULL', '3426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3426', '112', '5303', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5304', '1078', '1', 'Flacq', 'MU.13', 'NULL', '3427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3427', '112', '5304', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5305', '1078', '1', 'Grand Port', 'MU.14', 'NULL', '3428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3428', '112', '5305', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5306', '1078', '1', 'Moka', 'MU.15', 'NULL', '3429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3429', '112', '5306', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5307', '1078', '1', 'Pamplemousses', 'MU.16', 'NULL', '3430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3430', '112', '5307', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5308', '1078', '1', 'Plaines Wilhems', 'MU.17', 'NULL', '3431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3431', '112', '5308', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5309', '1078', '1', 'Port Louis', 'MU.18', 'NULL', '3432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3432', '112', '5309', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5310', '1078', '1', 'Rivière du Rempart', 'MU.19', 'NULL', '3433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3433', '112', '5310', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5311', '1078', '1', 'Savanne', 'MU.20', 'NULL', '3434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3434', '112', '5311', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5312', '1078', '1', 'Agalega Islands', 'MU.21', 'NULL', '3435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3435', '112', '5312', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5313', '1078', '1', 'Cargados Carajos', 'MU.22', 'NULL', '3436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3436', '112', '5313', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5314', '1078', '1', 'Rodrigues', 'MU.23', 'NULL', '3437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3437', '112', '5314', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MU.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5315', '1078', '1', 'Maale', 'MV.00', 'NULL', '3438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3438', '112', '5315', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5316', '1078', '1', 'Seenu', 'MV.01', 'NULL', '3439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3439', '112', '5316', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5317', '1078', '1', 'Alifu Atholhu', 'MV.02', 'NULL', '3440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3440', '112', '5317', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5318', '1078', '1', 'Lhaviyani Atholhu', 'MV.03', 'NULL', '3441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3441', '112', '5318', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5319', '1078', '1', 'Vaavu Atholhu', 'MV.04', 'NULL', '3442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3442', '112', '5319', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5320', '1078', '1', 'Laamu', 'MV.05', 'NULL', '3443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3443', '112', '5320', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5321', '1078', '1', 'Haa Alifu Atholhu', 'MV.07', 'NULL', '3444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3444', '112', '5321', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5322', '1078', '1', 'Thaa Atholhu', 'MV.08', 'NULL', '3445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3445', '112', '5322', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5323', '1078', '1', 'Meemu Atholhu', 'MV.12', 'NULL', '3446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3446', '112', '5323', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5324', '1078', '1', 'Raa Atholhu', 'MV.13', 'NULL', '3447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3447', '112', '5324', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5325', '1078', '1', 'Faafu Atholhu', 'MV.14', 'NULL', '3448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3448', '112', '5325', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5326', '1078', '1', 'Dhaalu Atholhu', 'MV.17', 'NULL', '3449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3449', '112', '5326', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5327', '1078', '1', 'Baa Atholhu', 'MV.20', 'NULL', '3450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3450', '112', '5327', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5328', '1078', '1', 'Haa Dhaalu Atholhu', 'MV.23', 'NULL', '3451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3451', '112', '5328', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5329', '1078', '1', 'Shaviyani Atholhu', 'MV.24', 'NULL', '3452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3452', '112', '5329', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5330', '1078', '1', 'Noonu Atholhu', 'MV.25', 'NULL', '3453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3453', '112', '5330', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5331', '1078', '1', 'Gaafu Alifu Atholhu', 'MV.27', 'NULL', '3454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3454', '112', '5331', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5332', '1078', '1', 'Gaafu Dhaalu Atholhu', 'MV.28', 'NULL', '3455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3455', '112', '5332', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5333', '1078', '1', 'Gnyaviyani Atoll', 'MV.29', 'NULL', '3456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3456', '112', '5333', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5334', '1078', '1', 'Alifu', 'MV.30', 'NULL', '3457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3457', '112', '5334', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5335', '1078', '1', 'Baa', 'MV.31', 'NULL', '3458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3458', '112', '5335', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5336', '1078', '1', 'Dhaalu', 'MV.32', 'NULL', '3459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3459', '112', '5336', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5337', '1078', '1', 'Faafu', 'MV.33', 'NULL', '3460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3460', '112', '5337', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5338', '1078', '1', 'Gaafu Alifu', 'MV.34', 'NULL', '3461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3461', '112', '5338', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5339', '1078', '1', 'Gaafu Dhaalu', 'MV.35', 'NULL', '3462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3462', '112', '5339', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5340', '1078', '1', 'Haa Alifu', 'MV.36', 'NULL', '3463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3463', '112', '5340', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5341', '1078', '1', 'Haa Dhaalu', 'MV.37', 'NULL', '3464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3464', '112', '5341', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5342', '1078', '1', 'Kaafu', 'MV.38', 'NULL', '3465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3465', '112', '5342', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5343', '1078', '1', 'Lhaviyani', 'MV.39', 'NULL', '3466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3466', '112', '5343', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5344', '1078', '1', 'Maale', 'MV.40', 'NULL', '3467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3467', '112', '5344', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5345', '1078', '1', 'Meemu', 'MV.41', 'NULL', '3468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3468', '112', '5345', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5346', '1078', '1', 'Gnaviyani', 'MV.42', 'NULL', '3469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3469', '112', '5346', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5347', '1078', '1', 'Noonu', 'MV.43', 'NULL', '3470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3470', '112', '5347', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5348', '1078', '1', 'Raa', 'MV.44', 'NULL', '3471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3471', '112', '5348', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5349', '1078', '1', 'Shaviyani', 'MV.45', 'NULL', '3472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3472', '112', '5349', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5350', '1078', '1', 'Thaa', 'MV.46', 'NULL', '3473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3473', '112', '5350', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5351', '1078', '1', 'Vaavu', 'MV.47', 'NULL', '3474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3474', '112', '5351', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MV.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5352', '1078', '1', 'Malawi (general)', 'MW.00', 'NULL', '3475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3475', '112', '5352', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5353', '1078', '1', 'Chikwawa', 'MW.02', 'NULL', '3476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3476', '112', '5353', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5354', '1078', '1', 'Chiradzulu', 'MW.03', 'NULL', '3477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3477', '112', '5354', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5355', '1078', '1', 'Chitipa', 'MW.04', 'NULL', '3478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3478', '112', '5355', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5356', '1078', '1', 'Thyolo', 'MW.05', 'NULL', '3479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3479', '112', '5356', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5357', '1078', '1', 'Dedza', 'MW.06', 'NULL', '3480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3480', '112', '5357', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5358', '1078', '1', 'Dowa', 'MW.07', 'NULL', '3481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3481', '112', '5358', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5359', '1078', '1', 'Karonga', 'MW.08', 'NULL', '3482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3482', '112', '5359', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5360', '1078', '1', 'Kasungu', 'MW.09', 'NULL', '3483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3483', '112', '5360', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5361', '1078', '1', '(MI10)', 'MW.10', 'NULL', '3484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3484', '112', '5361', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5362', '1078', '1', 'Lilongwe', 'MW.11', 'NULL', '3485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3485', '112', '5362', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5363', '1078', '1', 'Mangochi', 'MW.12', 'NULL', '3486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3486', '112', '5363', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5364', '1078', '1', 'Mchinji', 'MW.13', 'NULL', '3487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3487', '112', '5364', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5365', '1078', '1', '(MI14)', 'MW.14', 'NULL', '3488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3488', '112', '5365', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5366', '1078', '1', 'Mzimba', 'MW.15', 'NULL', '3489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3489', '112', '5366', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5367', '1078', '1', 'Ntcheu', 'MW.16', 'NULL', '3490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3490', '112', '5367', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5368', '1078', '1', 'Nkhata Bay', 'MW.17', 'NULL', '3491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3491', '112', '5368', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5369', '1078', '1', 'Nkhotakota', 'MW.18', 'NULL', '3492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3492', '112', '5369', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5370', '1078', '1', 'Nsanje', 'MW.19', 'NULL', '3493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3493', '112', '5370', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5371', '1078', '1', 'Ntchisi', 'MW.20', 'NULL', '3494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3494', '112', '5371', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5372', '1078', '1', 'Rumphi', 'MW.21', 'NULL', '3495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3495', '112', '5372', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5373', '1078', '1', 'Salima', 'MW.22', 'NULL', '3496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3496', '112', '5373', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5374', '1078', '1', 'Zomba', 'MW.23', 'NULL', '3497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3497', '112', '5374', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5375', '1078', '1', 'Blantyre', 'MW.24', 'NULL', '3498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3498', '112', '5375', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5376', '1078', '1', 'Mwanza', 'MW.25', 'NULL', '3499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3499', '112', '5376', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5377', '1078', '1', 'Balaka', 'MW.26', 'NULL', '3500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3500', '112', '5377', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5378', '1078', '1', 'Likoma', 'MW.27', 'NULL', '3501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3501', '112', '5378', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5379', '1078', '1', 'Machinga', 'MW.28', 'NULL', '3502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3502', '112', '5379', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5380', '1078', '1', 'Mulanje', 'MW.29', 'NULL', '3503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3503', '112', '5380', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5381', '1078', '1', 'Phalombe', 'MW.30', 'NULL', '3504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3504', '112', '5381', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MW.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5382', '1078', '1', 'Mexico (general)', 'MX.00', 'NULL', '3505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3505', '112', '5382', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5383', '1078', '1', 'Aguascalientes', 'MX.01', 'NULL', '3506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3506', '112', '5383', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5384', '1078', '1', 'Baja California', 'MX.02', 'NULL', '3507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3507', '112', '5384', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5385', '1078', '1', 'Baja California Sur', 'MX.03', 'NULL', '3508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3508', '112', '5385', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5386', '1078', '1', 'Campeche', 'MX.04', 'NULL', '3509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3509', '112', '5386', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5387', '1078', '1', 'Chiapas', 'MX.05', 'NULL', '3510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3510', '112', '5387', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5388', '1078', '1', 'Chihuahua', 'MX.06', 'NULL', '3511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3511', '112', '5388', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5389', '1078', '1', 'Coahuila', 'MX.07', 'NULL', '3512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3512', '112', '5389', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5390', '1078', '1', 'Colima', 'MX.08', 'NULL', '3513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3513', '112', '5390', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5391', '1078', '1', 'The Federal District', 'MX.09', 'NULL', '3514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3514', '112', '5391', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5392', '1078', '1', 'Durango', 'MX.10', 'NULL', '3515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3515', '112', '5392', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5393', '1078', '1', 'Guanajuato', 'MX.11', 'NULL', '3516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3516', '112', '5393', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5394', '1078', '1', 'Guerrero', 'MX.12', 'NULL', '3517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3517', '112', '5394', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5395', '1078', '1', 'Hidalgo', 'MX.13', 'NULL', '3518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3518', '112', '5395', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5396', '1078', '1', 'Jalisco', 'MX.14', 'NULL', '3519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3519', '112', '5396', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5397', '1078', '1', 'México', 'MX.15', 'NULL', '3520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3520', '112', '5397', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5398', '1078', '1', 'Michoacán', 'MX.16', 'NULL', '3521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3521', '112', '5398', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5399', '1078', '1', 'Morelos', 'MX.17', 'NULL', '3522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3522', '112', '5399', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5400', '1078', '1', 'Nayarit', 'MX.18', 'NULL', '3523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3523', '112', '5400', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5401', '1078', '1', 'Nuevo León', 'MX.19', 'NULL', '3524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3524', '112', '5401', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5402', '1078', '1', 'Oaxaca', 'MX.20', 'NULL', '3525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3525', '112', '5402', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5403', '1078', '1', 'Puebla', 'MX.21', 'NULL', '3526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3526', '112', '5403', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5404', '1078', '1', 'Querétaro', 'MX.22', 'NULL', '3527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3527', '112', '5404', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5405', '1078', '1', 'Quintana Roo', 'MX.23', 'NULL', '3528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3528', '112', '5405', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5406', '1078', '1', 'San Luis Potosí', 'MX.24', 'NULL', '3529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3529', '112', '5406', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5407', '1078', '1', 'Sinaloa', 'MX.25', 'NULL', '3530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3530', '112', '5407', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5408', '1078', '1', 'Sonora', 'MX.26', 'NULL', '3531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3531', '112', '5408', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5409', '1078', '1', 'Tabasco', 'MX.27', 'NULL', '3532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3532', '112', '5409', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5410', '1078', '1', 'Tamaulipas', 'MX.28', 'NULL', '3533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3533', '112', '5410', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5411', '1078', '1', 'Tlaxcala', 'MX.29', 'NULL', '3534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3534', '112', '5411', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5412', '1078', '1', 'Veracruz-Llave', 'MX.30', 'NULL', '3535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3535', '112', '5412', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5413', '1078', '1', 'Yucatán', 'MX.31', 'NULL', '3536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3536', '112', '5413', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5414', '1078', '1', 'Zacatecas', 'MX.32', 'NULL', '3537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3537', '112', '5414', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MX.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5415', '1078', '1', 'Malaysia (general)', 'MY.00', 'NULL', '3538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3538', '112', '5415', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5416', '1078', '1', 'Johor', 'MY.01', 'NULL', '3539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3539', '112', '5416', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5417', '1078', '1', 'Kedah', 'MY.02', 'NULL', '3540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3540', '112', '5417', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5418', '1078', '1', 'Kelantan', 'MY.03', 'NULL', '3541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3541', '112', '5418', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5419', '1078', '1', 'Melaka', 'MY.04', 'NULL', '3542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3542', '112', '5419', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5420', '1078', '1', 'Negeri Sembilan', 'MY.05', 'NULL', '3543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3543', '112', '5420', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5421', '1078', '1', 'Pahang', 'MY.06', 'NULL', '3544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3544', '112', '5421', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5422', '1078', '1', 'Perak', 'MY.07', 'NULL', '3545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3545', '112', '5422', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5423', '1078', '1', 'Perlis', 'MY.08', 'NULL', '3546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3546', '112', '5423', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5424', '1078', '1', 'Pulau Pinang', 'MY.09', 'NULL', '3547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3547', '112', '5424', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5425', '1078', '1', 'Sarawak', 'MY.11', 'NULL', '3548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3548', '112', '5425', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5426', '1078', '1', 'Selangor', 'MY.12', 'NULL', '3549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3549', '112', '5426', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5427', '1078', '1', 'Terengganu', 'MY.13', 'NULL', '3550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3550', '112', '5427', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5428', '1078', '1', 'Kuala Lumpur', 'MY.14', 'NULL', '3551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3551', '112', '5428', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5429', '1078', '1', 'Federal Territory of Labuan', 'MY.15', 'NULL', '3552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3552', '112', '5429', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5430', '1078', '1', 'Sabah', 'MY.16', 'NULL', '3553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3553', '112', '5430', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5431', '1078', '1', 'Putrajaya', 'MY.17', 'NULL', '3554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3554', '112', '5431', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MY.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5432', '1078', '1', 'Mozambique (general)', 'MZ.00', 'NULL', '3555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3555', '112', '5432', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5433', '1078', '1', 'Cabo Delgado', 'MZ.01', 'NULL', '3556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3556', '112', '5433', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5434', '1078', '1', 'Gaza', 'MZ.02', 'NULL', '3557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3557', '112', '5434', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5435', '1078', '1', 'Inhambane', 'MZ.03', 'NULL', '3558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3558', '112', '5435', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5436', '1078', '1', 'Maputo Province', 'MZ.04', 'NULL', '3559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3559', '112', '5436', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5437', '1078', '1', 'Sofala', 'MZ.05', 'NULL', '3560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3560', '112', '5437', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5438', '1078', '1', 'Nampula', 'MZ.06', 'NULL', '3561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3561', '112', '5438', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5439', '1078', '1', 'Niassa', 'MZ.07', 'NULL', '3562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3562', '112', '5439', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5440', '1078', '1', 'Tete', 'MZ.08', 'NULL', '3563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3563', '112', '5440', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5441', '1078', '1', 'Zambézia', 'MZ.09', 'NULL', '3564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3564', '112', '5441', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5442', '1078', '1', 'Manica', 'MZ.10', 'NULL', '3565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3565', '112', '5442', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5443', '1078', '1', 'Maputo', 'MZ.11', 'NULL', '3566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3566', '112', '5443', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «MZ.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5444', '1078', '1', 'Namibia (general)', 'NA.00', 'NULL', '3567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3567', '112', '5444', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5445', '1078', '1', 'Bethanien', 'NA.01', 'NULL', '3568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3568', '112', '5445', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5446', '1078', '1', 'Caprivi Oos', 'NA.02', 'NULL', '3569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3569', '112', '5446', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5447', '1078', '1', 'Kaokoland', 'NA.06', 'NULL', '3570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3570', '112', '5447', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5448', '1078', '1', 'Otjiwarongo', 'NA.13', 'NULL', '3571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3571', '112', '5448', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5449', '1078', '1', 'Outjo', 'NA.14', 'NULL', '3572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3572', '112', '5449', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5450', '1078', '1', 'Owambo', 'NA.15', 'NULL', '3573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3573', '112', '5450', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5451', '1078', '1', 'Khomas', 'NA.21', 'NULL', '3574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3574', '112', '5451', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5452', '1078', '1', 'Kavango', 'NA.25', 'NULL', '3575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3575', '112', '5452', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5453', '1078', '1', 'Caprivi', 'NA.28', 'NULL', '3576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3576', '112', '5453', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5454', '1078', '1', 'Erongo', 'NA.29', 'NULL', '3577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3577', '112', '5454', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5455', '1078', '1', 'Hardap', 'NA.30', 'NULL', '3578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3578', '112', '5455', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5456', '1078', '1', 'Karas', 'NA.31', 'NULL', '3579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3579', '112', '5456', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5457', '1078', '1', 'Kunene', 'NA.32', 'NULL', '3580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3580', '112', '5457', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5458', '1078', '1', 'Ohangwena', 'NA.33', 'NULL', '3581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3581', '112', '5458', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5459', '1078', '1', 'Okavango', 'NA.34', 'NULL', '3582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3582', '112', '5459', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5460', '1078', '1', 'Omaheke', 'NA.35', 'NULL', '3583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3583', '112', '5460', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5461', '1078', '1', 'Omusati', 'NA.36', 'NULL', '3584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3584', '112', '5461', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5462', '1078', '1', 'Oshana', 'NA.37', 'NULL', '3585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3585', '112', '5462', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5463', '1078', '1', 'Oshikoto', 'NA.38', 'NULL', '3586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3586', '112', '5463', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5464', '1078', '1', 'Otjozondjupa', 'NA.39', 'NULL', '3587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3587', '112', '5464', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NA.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5465', '1078', '1', 'Niger (general)', 'NE.00', 'NULL', '3588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3588', '112', '5465', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5466', '1078', '1', 'Agadez', 'NE.01', 'NULL', '3589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3589', '112', '5466', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NE.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5467', '1078', '1', 'Diffa', 'NE.02', 'NULL', '3590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3590', '112', '5467', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NE.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5468', '1078', '1', 'Dosso', 'NE.03', 'NULL', '3591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3591', '112', '5468', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NE.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5469', '1078', '1', 'Maradi', 'NE.04', 'NULL', '3592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3592', '112', '5469', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NE.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5470', '1078', '1', 'Tahoua', 'NE.06', 'NULL', '3593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3593', '112', '5470', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NE.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5471', '1078', '1', 'Zinder', 'NE.07', 'NULL', '3594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3594', '112', '5471', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NE.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5472', '1078', '1', 'Tillabéri', 'NE.09', 'NULL', '3595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3595', '112', '5472', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NE.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5473', '1078', '1', 'Norfolk Island (general)', 'NF.00', 'NULL', '3596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3596', '112', '5473', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NF.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5474', '1078', '1', 'Bendel State', 'NG.00', 'NULL', '3597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3597', '112', '5474', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5475', '1078', '1', 'Lagos', 'NG.05', 'NULL', '3598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3598', '112', '5475', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5476', '1078', '1', '(NI10)', 'NG.10', 'NULL', '3599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3599', '112', '5476', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5477', '1078', '1', 'Abuja Federal Capital Territory', 'NG.11', 'NULL', '3600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3600', '112', '5477', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5478', '1078', '1', '(NI12)', 'NG.12', 'NULL', '3601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3601', '112', '5478', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5479', '1078', '1', 'Ogun', 'NG.16', 'NULL', '3602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3602', '112', '5479', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5480', '1078', '1', '(NI17)', 'NG.17', 'NULL', '3603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3603', '112', '5480', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5481', '1078', '1', '(NI18)', 'NG.18', 'NULL', '3604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3604', '112', '5481', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5482', '1078', '1', '(NI20)', 'NG.20', 'NULL', '3605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3605', '112', '5482', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5483', '1078', '1', 'Akwa Ibom', 'NG.21', 'NULL', '3606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3606', '112', '5483', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5484', '1078', '1', 'Cross River', 'NG.22', 'NULL', '3607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3607', '112', '5484', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5485', '1078', '1', 'Kaduna', 'NG.23', 'NULL', '3608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3608', '112', '5485', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5486', '1078', '1', 'Katsina', 'NG.24', 'NULL', '3609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3609', '112', '5486', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5487', '1078', '1', 'Anambra', 'NG.25', 'NULL', '3610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3610', '112', '5487', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5488', '1078', '1', 'Benue', 'NG.26', 'NULL', '3611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3611', '112', '5488', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5489', '1078', '1', 'Borno', 'NG.27', 'NULL', '3612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3612', '112', '5489', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5490', '1078', '1', 'Imo', 'NG.28', 'NULL', '3613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3613', '112', '5490', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5491', '1078', '1', 'Kano', 'NG.29', 'NULL', '3614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3614', '112', '5491', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5492', '1078', '1', 'Kwara', 'NG.30', 'NULL', '3615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3615', '112', '5492', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5493', '1078', '1', 'Niger', 'NG.31', 'NULL', '3616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3616', '112', '5493', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5494', '1078', '1', 'Oyo', 'NG.32', 'NULL', '3617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3617', '112', '5494', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5495', '1078', '1', '(NI34)', 'NG.34', 'NULL', '3618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3618', '112', '5495', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5496', '1078', '1', 'Adamawa', 'NG.35', 'NULL', '3619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3619', '112', '5496', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5497', '1078', '1', 'Delta', 'NG.36', 'NULL', '3620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3620', '112', '5497', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5498', '1078', '1', 'Edo', 'NG.37', 'NULL', '3621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3621', '112', '5498', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5499', '1078', '1', 'Jigawa', 'NG.39', 'NULL', '3622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3622', '112', '5499', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5500', '1078', '1', 'Kebbi', 'NG.40', 'NULL', '3623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3623', '112', '5500', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5501', '1078', '1', 'Kogi', 'NG.41', 'NULL', '3624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3624', '112', '5501', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5502', '1078', '1', 'Osun', 'NG.42', 'NULL', '3625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3625', '112', '5502', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5503', '1078', '1', 'Taraba', 'NG.43', 'NULL', '3626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3626', '112', '5503', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5504', '1078', '1', 'Yobe', 'NG.44', 'NULL', '3627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3627', '112', '5504', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5505', '1078', '1', 'Abia', 'NG.45', 'NULL', '3628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3628', '112', '5505', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5506', '1078', '1', 'Bauchi', 'NG.46', 'NULL', '3629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3629', '112', '5506', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5507', '1078', '1', 'Enugu', 'NG.47', 'NULL', '3630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3630', '112', '5507', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5508', '1078', '1', 'Ondo', 'NG.48', 'NULL', '3631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3631', '112', '5508', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5509', '1078', '1', 'Plateau', 'NG.49', 'NULL', '3632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3632', '112', '5509', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5510', '1078', '1', 'Rivers', 'NG.50', 'NULL', '3633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3633', '112', '5510', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5511', '1078', '1', 'Sokoto', 'NG.51', 'NULL', '3634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3634', '112', '5511', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5512', '1078', '1', 'Bayelsa', 'NG.52', 'NULL', '3635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3635', '112', '5512', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5513', '1078', '1', 'Ebonyi', 'NG.53', 'NULL', '3636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3636', '112', '5513', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5514', '1078', '1', 'Ekiti', 'NG.54', 'NULL', '3637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3637', '112', '5514', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5515', '1078', '1', 'Gombe', 'NG.55', 'NULL', '3638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3638', '112', '5515', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5516', '1078', '1', 'Nassarawa', 'NG.56', 'NULL', '3639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3639', '112', '5516', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5517', '1078', '1', 'Zamfara', 'NG.57', 'NULL', '3640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3640', '112', '5517', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NG.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5518', '1078', '1', 'Nicaragua (general)', 'NI.00', 'NULL', '3641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3641', '112', '5518', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5519', '1078', '1', 'Boaco', 'NI.01', 'NULL', '3642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3642', '112', '5519', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5520', '1078', '1', 'Carazo', 'NI.02', 'NULL', '3643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3643', '112', '5520', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5521', '1078', '1', 'Chinandega', 'NI.03', 'NULL', '3644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3644', '112', '5521', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5522', '1078', '1', 'Chontales', 'NI.04', 'NULL', '3645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3645', '112', '5522', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5523', '1078', '1', 'Estelí', 'NI.05', 'NULL', '3646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3646', '112', '5523', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5524', '1078', '1', 'Granada', 'NI.06', 'NULL', '3647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3647', '112', '5524', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5525', '1078', '1', 'Jinotega', 'NI.07', 'NULL', '3648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3648', '112', '5525', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5526', '1078', '1', 'León', 'NI.08', 'NULL', '3649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3649', '112', '5526', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5527', '1078', '1', 'Madriz', 'NI.09', 'NULL', '3650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3650', '112', '5527', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5528', '1078', '1', 'Managua', 'NI.10', 'NULL', '3651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3651', '112', '5528', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5529', '1078', '1', 'Masaya', 'NI.11', 'NULL', '3652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3652', '112', '5529', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5530', '1078', '1', 'Matagalpa', 'NI.12', 'NULL', '3653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3653', '112', '5530', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5531', '1078', '1', 'Nueva Segovia', 'NI.13', 'NULL', '3654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3654', '112', '5531', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5532', '1078', '1', 'Río San Juan', 'NI.14', 'NULL', '3655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3655', '112', '5532', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5533', '1078', '1', 'Rivas', 'NI.15', 'NULL', '3656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3656', '112', '5533', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5534', '1078', '1', 'Ogun State', 'NI.16', 'NULL', '3657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3657', '112', '5534', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5535', '1078', '1', 'Atlántico Norte', 'NI.17', 'NULL', '3658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3658', '112', '5535', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5536', '1078', '1', 'Región Autónoma Atlántico Sur', 'NI.18', 'NULL', '3659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3659', '112', '5536', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NI.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5537', '1078', '1', 'Netherlands (general)', 'NL.00', 'NULL', '3660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3660', '112', '5537', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5538', '1078', '1', 'Provincie Drenthe', 'NL.01', 'NULL', '3661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3661', '112', '5538', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5539', '1078', '1', 'Provincie Friesland', 'NL.02', 'NULL', '3662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3662', '112', '5539', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5540', '1078', '1', 'Gelderland', 'NL.03', 'NULL', '3663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3663', '112', '5540', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5541', '1078', '1', 'Groningen', 'NL.04', 'NULL', '3664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3664', '112', '5541', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5542', '1078', '1', 'Limburg', 'NL.05', 'NULL', '3665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3665', '112', '5542', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5543', '1078', '1', 'North Brabant', 'NL.06', 'NULL', '3666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3666', '112', '5543', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5544', '1078', '1', 'North Holland', 'NL.07', 'NULL', '3667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3667', '112', '5544', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5545', '1078', '1', 'Utrecht', 'NL.09', 'NULL', '3668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3668', '112', '5545', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5546', '1078', '1', 'Zeeland', 'NL.10', 'NULL', '3669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3669', '112', '5546', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5547', '1078', '1', 'South Holland', 'NL.11', 'NULL', '3670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3670', '112', '5547', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5548', '1078', '1', 'Overijssel', 'NL.15', 'NULL', '3671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3671', '112', '5548', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5549', '1078', '1', 'Flevoland', 'NL.16', 'NULL', '3672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3672', '112', '5549', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NL.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5550', '1078', '1', 'Jan Mayen', 'NO.00', 'NULL', '3673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3673', '112', '5550', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5551', '1078', '1', 'Akershus', 'NO.01', 'NULL', '3674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3674', '112', '5551', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5552', '1078', '1', 'Aust-Agder', 'NO.02', 'NULL', '3675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3675', '112', '5552', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5553', '1078', '1', 'Buskerud', 'NO.04', 'NULL', '3676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3676', '112', '5553', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5554', '1078', '1', 'Finnmark', 'NO.05', 'NULL', '3677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3677', '112', '5554', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5555', '1078', '1', 'Hedmark', 'NO.06', 'NULL', '3678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3678', '112', '5555', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5556', '1078', '1', 'Hordaland', 'NO.07', 'NULL', '3679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3679', '112', '5556', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5557', '1078', '1', 'Møre og Romsdal', 'NO.08', 'NULL', '3680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3680', '112', '5557', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5558', '1078', '1', 'Nordland', 'NO.09', 'NULL', '3681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3681', '112', '5558', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5559', '1078', '1', 'Nord-Trøndelag', 'NO.10', 'NULL', '3682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3682', '112', '5559', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5560', '1078', '1', 'Oppland', 'NO.11', 'NULL', '3683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3683', '112', '5560', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5561', '1078', '1', 'Oslo', 'NO.12', 'NULL', '3684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3684', '112', '5561', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5562', '1078', '1', 'Østfold', 'NO.13', 'NULL', '3685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3685', '112', '5562', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5563', '1078', '1', 'Rogaland', 'NO.14', 'NULL', '3686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3686', '112', '5563', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5564', '1078', '1', 'Sogn og Fjordane', 'NO.15', 'NULL', '3687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3687', '112', '5564', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5565', '1078', '1', 'Sør-Trøndelag', 'NO.16', 'NULL', '3688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3688', '112', '5565', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5566', '1078', '1', 'Telemark', 'NO.17', 'NULL', '3689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3689', '112', '5566', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5567', '1078', '1', 'Troms', 'NO.18', 'NULL', '3690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3690', '112', '5567', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5568', '1078', '1', 'Vest-Agder', 'NO.19', 'NULL', '3691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3691', '112', '5568', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5569', '1078', '1', 'Vestfold', 'NO.20', 'NULL', '3692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3692', '112', '5569', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NO.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5570', '1078', '1', 'Bāgmatī Zone', 'NP.00', 'NULL', '3693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3693', '112', '5570', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5571', '1078', '1', 'Bāgmatī', 'NP.01', 'NULL', '3694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3694', '112', '5571', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5572', '1078', '1', 'Bherī', 'NP.02', 'NULL', '3695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3695', '112', '5572', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5573', '1078', '1', 'Dhawalāgiri', 'NP.03', 'NULL', '3696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3696', '112', '5573', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5574', '1078', '1', 'Gandakī', 'NP.04', 'NULL', '3697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3697', '112', '5574', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5575', '1078', '1', 'Janakpur', 'NP.05', 'NULL', '3698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3698', '112', '5575', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5576', '1078', '1', 'Karnālī', 'NP.06', 'NULL', '3699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3699', '112', '5576', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5577', '1078', '1', 'Kosī', 'NP.07', 'NULL', '3700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3700', '112', '5577', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5578', '1078', '1', 'Lumbinī', 'NP.08', 'NULL', '3701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3701', '112', '5578', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5579', '1078', '1', 'Mahākālī', 'NP.09', 'NULL', '3702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3702', '112', '5579', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5580', '1078', '1', 'Mechī', 'NP.10', 'NULL', '3703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3703', '112', '5580', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5581', '1078', '1', 'Nārāyanī', 'NP.11', 'NULL', '3704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3704', '112', '5581', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5582', '1078', '1', 'Rāptī', 'NP.12', 'NULL', '3705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3705', '112', '5582', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5583', '1078', '1', 'Sagarmāthā', 'NP.13', 'NULL', '3706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3706', '112', '5583', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5584', '1078', '1', 'Setī', 'NP.14', 'NULL', '3707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3707', '112', '5584', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NP.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5585', '1078', '1', 'Nauru (general)', 'NR.00', 'NULL', '3708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3708', '112', '5585', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5586', '1078', '1', 'Aiwo', 'NR.01', 'NULL', '3709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3709', '112', '5586', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5587', '1078', '1', 'Anabar', 'NR.02', 'NULL', '3710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3710', '112', '5587', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5588', '1078', '1', 'Anetan', 'NR.03', 'NULL', '3711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3711', '112', '5588', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5589', '1078', '1', 'Anibare', 'NR.04', 'NULL', '3712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3712', '112', '5589', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5590', '1078', '1', 'Baiti', 'NR.05', 'NULL', '3713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3713', '112', '5590', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5591', '1078', '1', 'Boe', 'NR.06', 'NULL', '3714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3714', '112', '5591', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5592', '1078', '1', 'Buada', 'NR.07', 'NULL', '3715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3715', '112', '5592', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5593', '1078', '1', 'Denigomodu', 'NR.08', 'NULL', '3716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3716', '112', '5593', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5594', '1078', '1', 'Ewa', 'NR.09', 'NULL', '3717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3717', '112', '5594', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5595', '1078', '1', 'Ijuw', 'NR.10', 'NULL', '3718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3718', '112', '5595', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5596', '1078', '1', 'Meneng', 'NR.11', 'NULL', '3719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3719', '112', '5596', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5597', '1078', '1', 'Nibok', 'NR.12', 'NULL', '3720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3720', '112', '5597', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5598', '1078', '1', 'Uaboe', 'NR.13', 'NULL', '3721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3721', '112', '5598', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5599', '1078', '1', 'Yaren', 'NR.14', 'NULL', '3722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3722', '112', '5599', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NR.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5600', '1078', '1', 'Niue (general)', 'NU.00', 'NULL', '3723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3723', '112', '5600', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NU.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5601', '1078', '1', 'Akaroa', 'NZ.01', 'NULL', '3724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3724', '112', '5601', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5602', '1078', '1', 'Amuri', 'NZ.03', 'NULL', '3725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3725', '112', '5602', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5603', '1078', '1', 'Ashburton', 'NZ.04', 'NULL', '3726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3726', '112', '5603', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5604', '1078', '1', 'Bay of Islands', 'NZ.07', 'NULL', '3727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3727', '112', '5604', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5605', '1078', '1', 'Bruce', 'NZ.08', 'NULL', '3728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3728', '112', '5605', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5606', '1078', '1', 'Buller', 'NZ.09', 'NULL', '3729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3729', '112', '5606', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5607', '1078', '1', 'Chatham Islands', 'NZ.10', 'NULL', '3730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3730', '112', '5607', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5608', '1078', '1', 'Cheviot', 'NZ.11', 'NULL', '3731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3731', '112', '5608', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5609', '1078', '1', 'Clifton', 'NZ.12', 'NULL', '3732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3732', '112', '5609', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5610', '1078', '1', 'Clutha', 'NZ.13', 'NULL', '3733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3733', '112', '5610', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5611', '1078', '1', 'Cook', 'NZ.14', 'NULL', '3734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3734', '112', '5611', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5612', '1078', '1', 'Dannevirke', 'NZ.16', 'NULL', '3735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3735', '112', '5612', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5613', '1078', '1', 'Egmont', 'NZ.17', 'NULL', '3736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3736', '112', '5613', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5614', '1078', '1', 'Eketahuna', 'NZ.18', 'NULL', '3737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3737', '112', '5614', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5615', '1078', '1', 'Ellesmere', 'NZ.19', 'NULL', '3738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3738', '112', '5615', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5616', '1078', '1', 'Eltham', 'NZ.20', 'NULL', '3739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3739', '112', '5616', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5617', '1078', '1', 'Eyre', 'NZ.21', 'NULL', '3740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3740', '112', '5617', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5618', '1078', '1', 'Tasman', 'NZ.2181818', 'NULL', '3741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3741', '112', '5618', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.2181818» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5619', '1078', '1', 'Featherston', 'NZ.22', 'NULL', '3742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3742', '112', '5619', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5620', '1078', '1', 'Franklin', 'NZ.24', 'NULL', '3743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3743', '112', '5620', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5621', '1078', '1', 'Golden Bay', 'NZ.26', 'NULL', '3744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3744', '112', '5621', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5622', '1078', '1', 'Great Barrier Island', 'NZ.27', 'NULL', '3745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3745', '112', '5622', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5623', '1078', '1', 'Grey', 'NZ.28', 'NULL', '3746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3746', '112', '5623', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5624', '1078', '1', 'Hauraki Plains', 'NZ.29', 'NULL', '3747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3747', '112', '5624', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5625', '1078', '1', 'Hawera', 'NZ.30', 'NULL', '3748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3748', '112', '5625', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5626', '1078', '1', 'Hawkeʼs Bay', 'NZ.31', 'NULL', '3749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3749', '112', '5626', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5627', '1078', '1', 'Heathcote', 'NZ.32', 'NULL', '3750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3750', '112', '5627', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5628', '1078', '1', 'Hobson', 'NZ.33', 'NULL', '3751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3751', '112', '5628', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5629', '1078', '1', 'Hokianga', 'NZ.34', 'NULL', '3752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3752', '112', '5629', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5630', '1078', '1', 'Horowhenua', 'NZ.35', 'NULL', '3753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3753', '112', '5630', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5631', '1078', '1', 'Hutt', 'NZ.36', 'NULL', '3754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3754', '112', '5631', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5632', '1078', '1', 'Inangahua', 'NZ.37', 'NULL', '3755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3755', '112', '5632', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5633', '1078', '1', 'Inglewood', 'NZ.38', 'NULL', '3756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3756', '112', '5633', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5634', '1078', '1', 'Kaikoura', 'NZ.39', 'NULL', '3757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3757', '112', '5634', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5635', '1078', '1', 'Kairanga', 'NZ.40', 'NULL', '3758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3758', '112', '5635', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5636', '1078', '1', 'Kiwitea', 'NZ.41', 'NULL', '3759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3759', '112', '5636', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5637', '1078', '1', 'Lake', 'NZ.43', 'NULL', '3760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3760', '112', '5637', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5638', '1078', '1', 'Mackenzie', 'NZ.45', 'NULL', '3761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3761', '112', '5638', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5639', '1078', '1', 'Malvern', 'NZ.46', 'NULL', '3762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3762', '112', '5639', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5640', '1078', '1', 'Manawatu', 'NZ.47', 'NULL', '3763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3763', '112', '5640', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5641', '1078', '1', 'Mangonui', 'NZ.48', 'NULL', '3764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3764', '112', '5641', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5642', '1078', '1', 'Maniototo', 'NZ.49', 'NULL', '3765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3765', '112', '5642', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5643', '1078', '1', 'Marlborough', 'NZ.50', 'NULL', '3766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3766', '112', '5643', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5644', '1078', '1', 'Masterton', 'NZ.51', 'NULL', '3767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3767', '112', '5644', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5645', '1078', '1', 'Matamata', 'NZ.52', 'NULL', '3768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3768', '112', '5645', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5646', '1078', '1', 'Mount Herbert', 'NZ.53', 'NULL', '3769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3769', '112', '5646', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5647', '1078', '1', 'Ohinemuri', 'NZ.54', 'NULL', '3770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3770', '112', '5647', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5648', '1078', '1', 'Opotiki', 'NZ.55', 'NULL', '3771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3771', '112', '5648', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5649', '1078', '1', 'Oroua', 'NZ.56', 'NULL', '3772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3772', '112', '5649', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5650', '1078', '1', 'Otamatea', 'NZ.57', 'NULL', '3773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3773', '112', '5650', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5651', '1078', '1', 'Otorohanga', 'NZ.58', 'NULL', '3774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3774', '112', '5651', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5652', '1078', '1', 'Oxford', 'NZ.59', 'NULL', '3775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3775', '112', '5652', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5653', '1078', '1', 'Pahiatua', 'NZ.60', 'NULL', '3776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3776', '112', '5653', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5654', '1078', '1', 'Paparua', 'NZ.61', 'NULL', '3777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3777', '112', '5654', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5655', '1078', '1', 'Patea', 'NZ.63', 'NULL', '3778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3778', '112', '5655', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5656', '1078', '1', 'Piako', 'NZ.65', 'NULL', '3779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3779', '112', '5656', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5657', '1078', '1', 'Pohangina', 'NZ.66', 'NULL', '3780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3780', '112', '5657', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5658', '1078', '1', 'Raglan', 'NZ.67', 'NULL', '3781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3781', '112', '5658', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5659', '1078', '1', 'Rangiora', 'NZ.68', 'NULL', '3782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3782', '112', '5659', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5660', '1078', '1', 'Rangitikei', 'NZ.69', 'NULL', '3783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3783', '112', '5660', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5661', '1078', '1', 'Rodney', 'NZ.70', 'NULL', '3784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3784', '112', '5661', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5662', '1078', '1', 'Rotorua', 'NZ.71', 'NULL', '3785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3785', '112', '5662', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5663', '1078', '1', 'Southland', 'NZ.72', 'NULL', '3786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3786', '112', '5663', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5664', '1078', '1', 'Stewart Island', 'NZ.73', 'NULL', '3787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3787', '112', '5664', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5665', '1078', '1', 'Stratford', 'NZ.74', 'NULL', '3788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3788', '112', '5665', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5666', '1078', '1', 'Taranaki', 'NZ.76', 'NULL', '3789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3789', '112', '5666', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5667', '1078', '1', 'Taumarunui', 'NZ.77', 'NULL', '3790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3790', '112', '5667', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5668', '1078', '1', 'Taupo', 'NZ.78', 'NULL', '3791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3791', '112', '5668', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5669', '1078', '1', 'Tauranga', 'NZ.79', 'NULL', '3792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3792', '112', '5669', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5670', '1078', '1', 'Tuapeka', 'NZ.81', 'NULL', '3793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3793', '112', '5670', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5671', '1078', '1', 'Vincent', 'NZ.82', 'NULL', '3794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3794', '112', '5671', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5672', '1078', '1', 'Waiapu', 'NZ.83', 'NULL', '3795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3795', '112', '5672', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5673', '1078', '1', 'Waihemo', 'NZ.84', 'NULL', '3796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3796', '112', '5673', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5674', '1078', '1', 'Waikato', 'NZ.85', 'NULL', '3797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3797', '112', '5674', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5675', '1078', '1', 'Waikohu', 'NZ.86', 'NULL', '3798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3798', '112', '5675', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5676', '1078', '1', 'Waimairi', 'NZ.88', 'NULL', '3799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3799', '112', '5676', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.88» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5677', '1078', '1', 'Waimarino', 'NZ.89', 'NULL', '3800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3800', '112', '5677', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.89» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5678', '1078', '1', 'Waimate', 'NZ.90', 'NULL', '3801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3801', '112', '5678', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.90» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5679', '1078', '1', 'Waimate West', 'NZ.91', 'NULL', '3802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3802', '112', '5679', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.91» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5680', '1078', '1', 'Waimea', 'NZ.92', 'NULL', '3803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3803', '112', '5680', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.92» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5681', '1078', '1', 'Waipa', 'NZ.93', 'NULL', '3804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3804', '112', '5681', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.93» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5682', '1078', '1', 'Waipawa', 'NZ.95', 'NULL', '3805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3805', '112', '5682', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.95» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5683', '1078', '1', 'Waipukurau', 'NZ.96', 'NULL', '3806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3806', '112', '5683', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.96» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5684', '1078', '1', 'Wairarapa South', 'NZ.97', 'NULL', '3807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3807', '112', '5684', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.97» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5685', '1078', '1', 'Wairewa', 'NZ.98', 'NULL', '3808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3808', '112', '5685', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.98» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5686', '1078', '1', 'Wairoa', 'NZ.99', 'NULL', '3809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3809', '112', '5686', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.99» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5687', '1078', '1', 'Whangarei', 'NZ.A1', 'NULL', '3810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3810', '112', '5687', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.A1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5688', '1078', '1', 'Whangaroa', 'NZ.A2', 'NULL', '3811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3811', '112', '5688', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.A2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5689', '1078', '1', 'Woodville', 'NZ.A3', 'NULL', '3812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3812', '112', '5689', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.A3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5690', '1078', '1', 'Waitaki', 'NZ.A4', 'NULL', '3813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3813', '112', '5690', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.A4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5691', '1078', '1', 'Waitomo', 'NZ.A6', 'NULL', '3814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3814', '112', '5691', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.A6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5692', '1078', '1', 'Waitotara', 'NZ.A8', 'NULL', '3815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3815', '112', '5692', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.A8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5693', '1078', '1', 'North Auckland', 'NZ.AK', 'NULL', '3816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3816', '112', '5693', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.AK» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5694', '1078', '1', 'Wanganui', 'NZ.B2', 'NULL', '3817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3817', '112', '5694', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.B2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5695', '1078', '1', 'Westland', 'NZ.B3', 'NULL', '3818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3818', '112', '5695', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.B3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5696', '1078', '1', 'Whakatane', 'NZ.B4', 'NULL', '3819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3819', '112', '5696', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.B4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5697', '1078', '1', 'Marlborough', 'NZ.BM', 'NULL', '3820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3820', '112', '5697', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.BM» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5698', '1078', '1', 'Canterbury', 'NZ.CH', 'NULL', '3821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3821', '112', '5698', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.CH» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5699', '1078', '1', 'Hurunui', 'NZ.D4', 'NULL', '3822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3822', '112', '5699', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.D4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5700', '1078', '1', 'Silverpeaks', 'NZ.D5', 'NULL', '3823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3823', '112', '5700', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.D5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5701', '1078', '1', 'Strathallan', 'NZ.D6', 'NULL', '3824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3824', '112', '5701', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.D6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5702', '1078', '1', 'Waiheke', 'NZ.D8', 'NULL', '3825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3825', '112', '5702', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.D8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5703', '1078', '1', 'Hikurangi', 'NZ.D9', 'NULL', '3826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3826', '112', '5703', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.D9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5704', '1078', '1', 'Otago', 'NZ.DN', 'NULL', '3827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3827', '112', '5704', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.DN» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5705', '1078', '1', 'Manaia', 'NZ.E1', 'NULL', '3828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3828', '112', '5705', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.E1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5706', '1078', '1', 'Runanga', 'NZ.E2', 'NULL', '3829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3829', '112', '5706', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.E2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5707', '1078', '1', 'Saint Kilda', 'NZ.E3', 'NULL', '3830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3830', '112', '5707', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.E3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5708', '1078', '1', 'Thames-Coromandel', 'NZ.E4', 'NULL', '3831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3831', '112', '5708', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.E4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5709', '1078', '1', 'Waverley', 'NZ.E5', 'NULL', '3832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3832', '112', '5709', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.E5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5710', '1078', '1', 'Wallace', 'NZ.E6', 'NULL', '3833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3833', '112', '5710', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.E6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5711', '1078', '1', 'Auckland', 'NZ.E7', 'NULL', '3834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3834', '112', '5711', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.E7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5712', '1078', '1', 'Bay of Plenty', 'NZ.E8', 'NULL', '3835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3835', '112', '5712', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.E8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5713', '1078', '1', 'Canterbury', 'NZ.E9', 'NULL', '3836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3836', '112', '5713', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.E9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5714', '1078', '1', 'Gisborne', 'NZ.F1', 'NULL', '3837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3837', '112', '5714', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.F1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5715', '1078', '1', 'Hawke''s Bay', 'NZ.F2', 'NULL', '3838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3838', '112', '5715', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.F2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5716', '1078', '1', 'Manawatu-Wanganui', 'NZ.F3', 'NULL', '3839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3839', '112', '5716', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.F3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5717', '1078', '1', 'Marlborough', 'NZ.F4', 'NULL', '3840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3840', '112', '5717', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.F4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5718', '1078', '1', 'Nelson', 'NZ.F5', 'NULL', '3841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3841', '112', '5718', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.F5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5719', '1078', '1', 'Northland', 'NZ.F6', 'NULL', '3842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3842', '112', '5719', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.F6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5720', '1078', '1', 'Otago', 'NZ.F7', 'NULL', '3843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3843', '112', '5720', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.F7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5721', '1078', '1', 'Southland', 'NZ.F8', 'NULL', '3844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3844', '112', '5721', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.F8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5722', '1078', '1', 'Taranaki', 'NZ.F9', 'NULL', '3845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3845', '112', '5722', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.F9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5723', '1078', '1', 'Waikato', 'NZ.G1', 'NULL', '3846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3846', '112', '5723', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.G1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5724', '1078', '1', 'Wellington', 'NZ.G2', 'NULL', '3847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3847', '112', '5724', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.G2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5725', '1078', '1', 'West Coast', 'NZ.G3', 'NULL', '3848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3848', '112', '5725', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.G3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5726', '1078', '1', 'Gisborne', 'NZ.GS', 'NULL', '3849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3849', '112', '5726', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.GS» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5727', '1078', '1', 'Westland', 'NZ.HK', 'NULL', '3850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3850', '112', '5727', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.HK» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5728', '1078', '1', 'South Auckland', 'NZ.HN', 'NULL', '3851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3851', '112', '5728', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.HN» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5729', '1078', '1', 'Southland', 'NZ.IN', 'NULL', '3852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3852', '112', '5729', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.IN» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5730', '1078', '1', 'Hawke''s Bay', 'NZ.NA', 'NULL', '3853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3853', '112', '5730', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.NA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5731', '1078', '1', 'Nelson', 'NZ.NN', 'NULL', '3854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3854', '112', '5731', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.NN» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5732', '1078', '1', 'Taranaki', 'NZ.NP', 'NULL', '3855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3855', '112', '5732', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.NP» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5733', '1078', '1', 'Wellington', 'NZ.WN', 'NULL', '3856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3856', '112', '5733', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «NZ.WN» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5734', '1078', '1', 'Oman (general)', 'OM.00', 'NULL', '3857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3857', '112', '5734', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «OM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5735', '1078', '1', 'Ad Dākhilīyah', 'OM.01', 'NULL', '3858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3858', '112', '5735', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «OM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5736', '1078', '1', 'Al Bāţinah', 'OM.02', 'NULL', '3859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3859', '112', '5736', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «OM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5737', '1078', '1', 'Al Wusţá', 'OM.03', 'NULL', '3860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3860', '112', '5737', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «OM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5738', '1078', '1', 'Ash Sharqīyah', 'OM.04', 'NULL', '3861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3861', '112', '5738', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «OM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5739', '1078', '1', 'Az̧ Z̧āhirah', 'OM.05', 'NULL', '3862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3862', '112', '5739', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «OM.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5740', '1078', '1', 'Masqaţ', 'OM.06', 'NULL', '3863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3863', '112', '5740', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «OM.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5741', '1078', '1', 'Musandam', 'OM.07', 'NULL', '3864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3864', '112', '5741', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «OM.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5742', '1078', '1', 'Z̧ufār', 'OM.08', 'NULL', '3865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3865', '112', '5742', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «OM.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5743', '1078', '1', 'Panama (general)', 'PA.00', 'NULL', '3866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3866', '112', '5743', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5744', '1078', '1', 'Bocas del Toro', 'PA.01', 'NULL', '3867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3867', '112', '5744', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5745', '1078', '1', 'Chiriquí', 'PA.02', 'NULL', '3868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3868', '112', '5745', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5746', '1078', '1', 'Coclé', 'PA.03', 'NULL', '3869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3869', '112', '5746', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5747', '1078', '1', 'Colón', 'PA.04', 'NULL', '3870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3870', '112', '5747', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5748', '1078', '1', 'Darién', 'PA.05', 'NULL', '3871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3871', '112', '5748', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5749', '1078', '1', 'Herrera', 'PA.06', 'NULL', '3872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3872', '112', '5749', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5750', '1078', '1', 'Los Santos', 'PA.07', 'NULL', '3873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3873', '112', '5750', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5751', '1078', '1', 'Panamá', 'PA.08', 'NULL', '3874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3874', '112', '5751', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5752', '1078', '1', 'San Blas', 'PA.09', 'NULL', '3875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3875', '112', '5752', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5753', '1078', '1', 'Veraguas', 'PA.10', 'NULL', '3876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3876', '112', '5753', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PA.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5754', '1078', '1', 'Peru (general)', 'PE.00', 'NULL', '3877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3877', '112', '5754', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5755', '1078', '1', 'Amazonas', 'PE.01', 'NULL', '3878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3878', '112', '5755', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5756', '1078', '1', 'Ancash', 'PE.02', 'NULL', '3879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3879', '112', '5756', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5757', '1078', '1', 'Apurímac', 'PE.03', 'NULL', '3880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3880', '112', '5757', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5758', '1078', '1', 'Arequipa', 'PE.04', 'NULL', '3881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3881', '112', '5758', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5759', '1078', '1', 'Ayacucho', 'PE.05', 'NULL', '3882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3882', '112', '5759', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5760', '1078', '1', 'Cajamarca', 'PE.06', 'NULL', '3883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3883', '112', '5760', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5761', '1078', '1', 'Callao', 'PE.07', 'NULL', '3884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3884', '112', '5761', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5762', '1078', '1', 'Cusco', 'PE.08', 'NULL', '3885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3885', '112', '5762', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5763', '1078', '1', 'Huancavelica', 'PE.09', 'NULL', '3886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3886', '112', '5763', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5764', '1078', '1', 'Huanuco', 'PE.10', 'NULL', '3887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3887', '112', '5764', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5765', '1078', '1', 'Ica', 'PE.11', 'NULL', '3888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3888', '112', '5765', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5766', '1078', '1', 'Junín', 'PE.12', 'NULL', '3889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3889', '112', '5766', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5767', '1078', '1', 'La Libertad', 'PE.13', 'NULL', '3890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3890', '112', '5767', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5768', '1078', '1', 'Lambayeque', 'PE.14', 'NULL', '3891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3891', '112', '5768', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5769', '1078', '1', 'Lima', 'PE.15', 'NULL', '3892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3892', '112', '5769', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5770', '1078', '1', 'Loreto', 'PE.16', 'NULL', '3893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3893', '112', '5770', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5771', '1078', '1', 'Madre de Dios', 'PE.17', 'NULL', '3894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3894', '112', '5771', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5772', '1078', '1', 'Moquegua', 'PE.18', 'NULL', '3895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3895', '112', '5772', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5773', '1078', '1', 'Pasco', 'PE.19', 'NULL', '3896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3896', '112', '5773', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5774', '1078', '1', 'Piura', 'PE.20', 'NULL', '3897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3897', '112', '5774', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5775', '1078', '1', 'Puno', 'PE.21', 'NULL', '3898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3898', '112', '5775', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5776', '1078', '1', 'San Martín', 'PE.22', 'NULL', '3899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3899', '112', '5776', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5777', '1078', '1', 'Tacna', 'PE.23', 'NULL', '3900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3900', '112', '5777', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5778', '1078', '1', 'Tumbes', 'PE.24', 'NULL', '3901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3901', '112', '5778', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5779', '1078', '1', 'Ucayali', 'PE.25', 'NULL', '3902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3902', '112', '5779', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PE.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5780', '1078', '1', 'Papua New Guinea (general)', 'PG.00', 'NULL', '3903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3903', '112', '5780', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5781', '1078', '1', 'Central', 'PG.01', 'NULL', '3904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3904', '112', '5781', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5782', '1078', '1', 'Gulf', 'PG.02', 'NULL', '3905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3905', '112', '5782', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5783', '1078', '1', 'Milne Bay', 'PG.03', 'NULL', '3906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3906', '112', '5783', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5784', '1078', '1', 'Northern', 'PG.04', 'NULL', '3907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3907', '112', '5784', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5785', '1078', '1', 'Southern Highlands', 'PG.05', 'NULL', '3908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3908', '112', '5785', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5786', '1078', '1', 'Western', 'PG.06', 'NULL', '3909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3909', '112', '5786', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5787', '1078', '1', 'Bougainville', 'PG.07', 'NULL', '3910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3910', '112', '5787', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5788', '1078', '1', 'Chimbu', 'PG.08', 'NULL', '3911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3911', '112', '5788', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5789', '1078', '1', 'Eastern Highlands', 'PG.09', 'NULL', '3912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3912', '112', '5789', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5790', '1078', '1', 'East New Britain', 'PG.10', 'NULL', '3913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3913', '112', '5790', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5791', '1078', '1', 'East Sepik', 'PG.11', 'NULL', '3914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3914', '112', '5791', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5792', '1078', '1', 'Madang', 'PG.12', 'NULL', '3915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3915', '112', '5792', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5793', '1078', '1', 'Manus', 'PG.13', 'NULL', '3916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3916', '112', '5793', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5794', '1078', '1', 'Morobe', 'PG.14', 'NULL', '3917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3917', '112', '5794', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5795', '1078', '1', 'New Ireland', 'PG.15', 'NULL', '3918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3918', '112', '5795', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5796', '1078', '1', 'Western Highlands', 'PG.16', 'NULL', '3919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3919', '112', '5796', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5797', '1078', '1', 'West New Britain', 'PG.17', 'NULL', '3920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3920', '112', '5797', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5798', '1078', '1', 'Sandaun', 'PG.18', 'NULL', '3921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3921', '112', '5798', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5799', '1078', '1', 'Enga', 'PG.19', 'NULL', '3922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3922', '112', '5799', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5800', '1078', '1', 'National Capital', 'PG.20', 'NULL', '3923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3923', '112', '5800', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PG.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5801', '1078', '1', 'Philippines (general)', 'PH.00', 'NULL', '3924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3924', '112', '5801', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5802', '1078', '1', 'Abra', 'PH.01', 'NULL', '3925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3925', '112', '5802', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5803', '1078', '1', 'Agusan del Norte', 'PH.02', 'NULL', '3926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3926', '112', '5803', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5804', '1078', '1', 'Agusan del Sur', 'PH.03', 'NULL', '3927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3927', '112', '5804', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5805', '1078', '1', 'Aklan', 'PH.04', 'NULL', '3928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3928', '112', '5805', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5806', '1078', '1', 'Albay', 'PH.05', 'NULL', '3929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3929', '112', '5806', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5807', '1078', '1', 'Antique', 'PH.06', 'NULL', '3930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3930', '112', '5807', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5808', '1078', '1', 'Bataan', 'PH.07', 'NULL', '3931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3931', '112', '5808', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5809', '1078', '1', 'Batanes', 'PH.08', 'NULL', '3932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3932', '112', '5809', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5810', '1078', '1', 'Batangas', 'PH.09', 'NULL', '3933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3933', '112', '5810', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5811', '1078', '1', 'Benguet', 'PH.10', 'NULL', '3934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3934', '112', '5811', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5812', '1078', '1', 'Bohol', 'PH.11', 'NULL', '3935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3935', '112', '5812', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5813', '1078', '1', 'Bukidnon', 'PH.12', 'NULL', '3936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3936', '112', '5813', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5814', '1078', '1', 'Bulacan', 'PH.13', 'NULL', '3937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3937', '112', '5814', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5815', '1078', '1', 'Cagayan', 'PH.14', 'NULL', '3938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3938', '112', '5815', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5816', '1078', '1', 'Camarines Norte', 'PH.15', 'NULL', '3939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3939', '112', '5816', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5817', '1078', '1', 'Camarines Sur', 'PH.16', 'NULL', '3940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3940', '112', '5817', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5818', '1078', '1', 'Camiguin', 'PH.17', 'NULL', '3941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3941', '112', '5818', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5819', '1078', '1', 'Capiz', 'PH.18', 'NULL', '3942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3942', '112', '5819', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5820', '1078', '1', 'Catanduanes', 'PH.19', 'NULL', '3943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3943', '112', '5820', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5821', '1078', '1', 'Cavite', 'PH.20', 'NULL', '3944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3944', '112', '5821', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5822', '1078', '1', 'Cebu', 'PH.21', 'NULL', '3945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3945', '112', '5822', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5823', '1078', '1', 'Basilan', 'PH.22', 'NULL', '3946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3946', '112', '5823', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5824', '1078', '1', 'Eastern Samar', 'PH.23', 'NULL', '3947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3947', '112', '5824', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5825', '1078', '1', 'Davao', 'PH.24', 'NULL', '3948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3948', '112', '5825', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5826', '1078', '1', 'Davao del Sur', 'PH.25', 'NULL', '3949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3949', '112', '5826', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5827', '1078', '1', 'Davao Oriental', 'PH.26', 'NULL', '3950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3950', '112', '5827', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5828', '1078', '1', 'Ifugao', 'PH.27', 'NULL', '3951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3951', '112', '5828', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5829', '1078', '1', 'Ilocos Norte', 'PH.28', 'NULL', '3952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3952', '112', '5829', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5830', '1078', '1', 'Ilocos Sur', 'PH.29', 'NULL', '3953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3953', '112', '5830', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5831', '1078', '1', 'Iloilo', 'PH.30', 'NULL', '3954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3954', '112', '5831', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5832', '1078', '1', 'Isabela', 'PH.31', 'NULL', '3955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3955', '112', '5832', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5833', '1078', '1', 'Kalinga-Apayao', 'PH.32', 'NULL', '3956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3956', '112', '5833', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5834', '1078', '1', 'Laguna', 'PH.33', 'NULL', '3957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3957', '112', '5834', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5835', '1078', '1', 'Lanao del Norte', 'PH.34', 'NULL', '3958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3958', '112', '5835', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5836', '1078', '1', 'Lanao del Sur', 'PH.35', 'NULL', '3959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3959', '112', '5836', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5837', '1078', '1', 'La Union', 'PH.36', 'NULL', '3960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3960', '112', '5837', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5838', '1078', '1', 'Leyte', 'PH.37', 'NULL', '3961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3961', '112', '5838', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5839', '1078', '1', 'Marinduque', 'PH.38', 'NULL', '3962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3962', '112', '5839', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5840', '1078', '1', 'Masbate', 'PH.39', 'NULL', '3963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3963', '112', '5840', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5841', '1078', '1', 'Mindoro Occidental', 'PH.40', 'NULL', '3964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3964', '112', '5841', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5842', '1078', '1', 'Mindoro Oriental', 'PH.41', 'NULL', '3965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3965', '112', '5842', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5843', '1078', '1', 'Misamis Occidental', 'PH.42', 'NULL', '3966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3966', '112', '5843', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5844', '1078', '1', 'Misamis Oriental', 'PH.43', 'NULL', '3967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3967', '112', '5844', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5845', '1078', '1', 'Mountain Province', 'PH.44', 'NULL', '3968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3968', '112', '5845', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5846', '1078', '1', '(RP45)', 'PH.45', 'NULL', '3969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3969', '112', '5846', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5847', '1078', '1', 'Negros Oriental', 'PH.46', 'NULL', '3970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3970', '112', '5847', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5848', '1078', '1', 'Nueva Ecija', 'PH.47', 'NULL', '3971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3971', '112', '5848', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5849', '1078', '1', 'Nueva Vizcaya', 'PH.48', 'NULL', '3972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3972', '112', '5849', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5850', '1078', '1', 'Palawan', 'PH.49', 'NULL', '3973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3973', '112', '5850', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5851', '1078', '1', 'Pampanga', 'PH.50', 'NULL', '3974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3974', '112', '5851', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5852', '1078', '1', 'Pangasinan', 'PH.51', 'NULL', '3975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3975', '112', '5852', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5853', '1078', '1', 'Rizal', 'PH.53', 'NULL', '3976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3976', '112', '5853', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5854', '1078', '1', 'Romblon', 'PH.54', 'NULL', '3977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3977', '112', '5854', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5855', '1078', '1', 'Samar', 'PH.55', 'NULL', '3978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3978', '112', '5855', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5856', '1078', '1', 'Maguindanao', 'PH.56', 'NULL', '3979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3979', '112', '5856', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5857', '1078', '1', 'North Cotabato', 'PH.57', 'NULL', '3980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3980', '112', '5857', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5858', '1078', '1', 'Sorsogon', 'PH.58', 'NULL', '3981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3981', '112', '5858', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5859', '1078', '1', 'Southern Leyte', 'PH.59', 'NULL', '3982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3982', '112', '5859', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5860', '1078', '1', 'Sulu', 'PH.60', 'NULL', '3983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3983', '112', '5860', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5861', '1078', '1', 'Surigao del Norte', 'PH.61', 'NULL', '3984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3984', '112', '5861', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5862', '1078', '1', 'Surigao del Sur', 'PH.62', 'NULL', '3985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3985', '112', '5862', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5863', '1078', '1', 'Tarlac', 'PH.63', 'NULL', '3986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3986', '112', '5863', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5864', '1078', '1', 'Zambales', 'PH.64', 'NULL', '3987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3987', '112', '5864', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5865', '1078', '1', 'Zamboanga del Norte', 'PH.65', 'NULL', '3988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3988', '112', '5865', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5866', '1078', '1', 'Zamboanga del Sur', 'PH.66', 'NULL', '3989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3989', '112', '5866', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5867', '1078', '1', 'Northern Samar', 'PH.67', 'NULL', '3990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3990', '112', '5867', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5868', '1078', '1', 'Quirino', 'PH.68', 'NULL', '3991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3991', '112', '5868', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5869', '1078', '1', 'Siquijor', 'PH.69', 'NULL', '3992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3992', '112', '5869', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5870', '1078', '1', 'South Cotabato', 'PH.70', 'NULL', '3993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3993', '112', '5870', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5871', '1078', '1', 'Sultan Kudarat', 'PH.71', 'NULL', '3994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3994', '112', '5871', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5872', '1078', '1', 'Tawi-Tawi', 'PH.72', 'NULL', '3995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3995', '112', '5872', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5873', '1078', '1', 'Angeles', 'PH.A1', 'NULL', '3996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3996', '112', '5873', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.A1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5874', '1078', '1', 'Bacolod City', 'PH.A2', 'NULL', '3997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3997', '112', '5874', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.A2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5875', '1078', '1', 'Bago', 'PH.A3', 'NULL', '3998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3998', '112', '5875', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.A3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5876', '1078', '1', 'Baguio', 'PH.A4', 'NULL', '3999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('3999', '112', '5876', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.A4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5877', '1078', '1', 'Bais', 'PH.A5', 'NULL', '4000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4000', '112', '5877', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.A5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5878', '1078', '1', 'Basilan', 'PH.A6', 'NULL', '4001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4001', '112', '5878', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.A6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5879', '1078', '1', 'Batangas', 'PH.A7', 'NULL', '4002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4002', '112', '5879', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.A7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5880', '1078', '1', 'Butuan', 'PH.A8', 'NULL', '4003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4003', '112', '5880', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.A8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5881', '1078', '1', 'Cabanatuan', 'PH.A9', 'NULL', '4004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4004', '112', '5881', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.A9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5882', '1078', '1', 'Cadiz', 'PH.B1', 'NULL', '4005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4005', '112', '5882', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.B1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5883', '1078', '1', 'Calbayog', 'PH.B3', 'NULL', '4006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4006', '112', '5883', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.B3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5884', '1078', '1', 'Caloocan', 'PH.B4', 'NULL', '4007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4007', '112', '5884', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.B4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5885', '1078', '1', 'Canlaon', 'PH.B5', 'NULL', '4008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4008', '112', '5885', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.B5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5886', '1078', '1', 'Cavite', 'PH.B6', 'NULL', '4009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4009', '112', '5886', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.B6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5887', '1078', '1', 'Cebu City', 'PH.B7', 'NULL', '4010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4010', '112', '5887', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.B7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5888', '1078', '1', 'Cotabato', 'PH.B8', 'NULL', '4011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4011', '112', '5888', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.B8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5889', '1078', '1', 'Dagupan', 'PH.B9', 'NULL', '4012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4012', '112', '5889', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.B9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5890', '1078', '1', 'Danao', 'PH.C1', 'NULL', '4013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4013', '112', '5890', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.C1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5891', '1078', '1', 'Dapitan', 'PH.C2', 'NULL', '4014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4014', '112', '5891', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.C2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5892', '1078', '1', 'Davao', 'PH.C3', 'NULL', '4015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4015', '112', '5892', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.C3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5893', '1078', '1', 'Dipolog', 'PH.C4', 'NULL', '4016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4016', '112', '5893', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.C4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5894', '1078', '1', 'Dumaguete', 'PH.C5', 'NULL', '4017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4017', '112', '5894', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.C5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5895', '1078', '1', 'General Santos', 'PH.C6', 'NULL', '4018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4018', '112', '5895', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.C6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5896', '1078', '1', 'Gingoog', 'PH.C7', 'NULL', '4019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4019', '112', '5896', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.C7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5897', '1078', '1', 'Iloilo', 'PH.C9', 'NULL', '4020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4020', '112', '5897', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.C9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5898', '1078', '1', 'Iriga', 'PH.D1', 'NULL', '4021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4021', '112', '5898', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.D1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5899', '1078', '1', 'La Carlota', 'PH.D2', 'NULL', '4022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4022', '112', '5899', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.D2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5900', '1078', '1', 'Laoag', 'PH.D3', 'NULL', '4023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4023', '112', '5900', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.D3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5901', '1078', '1', 'Lapu-Lapu', 'PH.D4', 'NULL', '4024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4024', '112', '5901', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.D4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5902', '1078', '1', 'Legaspi', 'PH.D5', 'NULL', '4025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4025', '112', '5902', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.D5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5903', '1078', '1', 'Lipa', 'PH.D6', 'NULL', '4026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4026', '112', '5903', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.D6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5904', '1078', '1', 'Lucena', 'PH.D7', 'NULL', '4027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4027', '112', '5904', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.D7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5905', '1078', '1', 'Mandaue', 'PH.D8', 'NULL', '4028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4028', '112', '5905', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.D8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5906', '1078', '1', 'Manila', 'PH.D9', 'NULL', '4029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4029', '112', '5906', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.D9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5907', '1078', '1', 'Naga', 'PH.E2', 'NULL', '4030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4030', '112', '5907', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.E2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5908', '1078', '1', 'Olongapo', 'PH.E3', 'NULL', '4031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4031', '112', '5908', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.E3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5909', '1078', '1', 'Ormoc', 'PH.E4', 'NULL', '4032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4032', '112', '5909', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.E4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5910', '1078', '1', 'Oroquieta', 'PH.E5', 'NULL', '4033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4033', '112', '5910', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.E5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5911', '1078', '1', 'Ozamis', 'PH.E6', 'NULL', '4034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4034', '112', '5911', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.E6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5912', '1078', '1', 'Pagadian', 'PH.E7', 'NULL', '4035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4035', '112', '5912', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.E7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5913', '1078', '1', 'Palayan', 'PH.E8', 'NULL', '4036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4036', '112', '5913', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.E8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5914', '1078', '1', 'Pasay', 'PH.E9', 'NULL', '4037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4037', '112', '5914', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.E9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5915', '1078', '1', 'Puerto Princesa', 'PH.F1', 'NULL', '4038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4038', '112', '5915', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.F1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5916', '1078', '1', 'Quezon', 'PH.F2', 'NULL', '4039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4039', '112', '5916', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.F2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5917', '1078', '1', 'Roxas', 'PH.F3', 'NULL', '4040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4040', '112', '5917', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.F3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5918', '1078', '1', 'San Carlos, Negros Occidental', 'PH.F4', 'NULL', '4041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4041', '112', '5918', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.F4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5919', '1078', '1', 'San Carlos, Pangasinan', 'PH.F5', 'NULL', '4042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4042', '112', '5919', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.F5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5920', '1078', '1', 'San Jose', 'PH.F6', 'NULL', '4043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4043', '112', '5920', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.F6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5921', '1078', '1', 'San Pablo', 'PH.F7', 'NULL', '4044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4044', '112', '5921', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.F7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5922', '1078', '1', 'Silay', 'PH.F8', 'NULL', '4045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4045', '112', '5922', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.F8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5923', '1078', '1', 'Surigao', 'PH.F9', 'NULL', '4046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4046', '112', '5923', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.F9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5924', '1078', '1', 'Tacloban', 'PH.G1', 'NULL', '4047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4047', '112', '5924', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.G1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5925', '1078', '1', 'Tagaytay', 'PH.G2', 'NULL', '4048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4048', '112', '5925', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.G2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5926', '1078', '1', 'Tagbilaran', 'PH.G3', 'NULL', '4049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4049', '112', '5926', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.G3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5927', '1078', '1', 'Tangub', 'PH.G4', 'NULL', '4050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4050', '112', '5927', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.G4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5928', '1078', '1', 'Toledo', 'PH.G5', 'NULL', '4051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4051', '112', '5928', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.G5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5929', '1078', '1', 'Trece Martires', 'PH.G6', 'NULL', '4052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4052', '112', '5929', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.G6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5930', '1078', '1', 'Zamboanga City', 'PH.G7', 'NULL', '4053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4053', '112', '5930', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.G7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5931', '1078', '1', 'Aurora', 'PH.G8', 'NULL', '4054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4054', '112', '5931', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.G8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5932', '1078', '1', 'Quezon', 'PH.H2', 'NULL', '4055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4055', '112', '5932', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.H2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5933', '1078', '1', 'Negros Occidental', 'PH.H3', 'NULL', '4056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4056', '112', '5933', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PH.H3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5934', '1078', '1', 'Pakistan (general)', 'PK.00', 'NULL', '4057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4057', '112', '5934', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PK.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5935', '1078', '1', 'Federally Administered Tribal Areas', 'PK.01', 'NULL', '4058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4058', '112', '5935', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PK.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5936', '1078', '1', 'Balochistān', 'PK.02', 'NULL', '4059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4059', '112', '5936', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PK.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5937', '1078', '1', 'North-West Frontier', 'PK.03', 'NULL', '4060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4060', '112', '5937', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PK.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5938', '1078', '1', 'Punjab', 'PK.04', 'NULL', '4061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4061', '112', '5938', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PK.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5939', '1078', '1', 'Sindh', 'PK.05', 'NULL', '4062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4062', '112', '5939', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PK.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5940', '1078', '1', 'Azad Kashmir', 'PK.06', 'NULL', '4063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4063', '112', '5940', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PK.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5941', '1078', '1', 'Northern Areas', 'PK.07', 'NULL', '4064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4064', '112', '5941', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PK.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5942', '1078', '1', 'Islāmābād', 'PK.08', 'NULL', '4065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4065', '112', '5942', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PK.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5943', '1078', '1', 'Biala Podlaska', 'PL.23', 'NULL', '4066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4066', '112', '5943', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5944', '1078', '1', 'Bialystok', 'PL.24', 'NULL', '4067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4067', '112', '5944', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5945', '1078', '1', 'Bielsko', 'PL.25', 'NULL', '4068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4068', '112', '5945', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5946', '1078', '1', 'Bydgoszcz', 'PL.26', 'NULL', '4069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4069', '112', '5946', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5947', '1078', '1', 'Chelm', 'PL.27', 'NULL', '4070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4070', '112', '5947', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5948', '1078', '1', 'Ciechanow', 'PL.28', 'NULL', '4071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4071', '112', '5948', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5949', '1078', '1', 'Czestochowa', 'PL.29', 'NULL', '4072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4072', '112', '5949', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5950', '1078', '1', 'Elblag', 'PL.30', 'NULL', '4073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4073', '112', '5950', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5951', '1078', '1', 'Gdansk', 'PL.31', 'NULL', '4074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4074', '112', '5951', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5952', '1078', '1', 'Gorzow', 'PL.32', 'NULL', '4075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4075', '112', '5952', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5953', '1078', '1', 'Jelenia Gora', 'PL.33', 'NULL', '4076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4076', '112', '5953', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5954', '1078', '1', 'Kalisz', 'PL.34', 'NULL', '4077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4077', '112', '5954', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5955', '1078', '1', 'Katowice', 'PL.35', 'NULL', '4078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4078', '112', '5955', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5956', '1078', '1', 'Kielce', 'PL.36', 'NULL', '4079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4079', '112', '5956', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5957', '1078', '1', 'Konin', 'PL.37', 'NULL', '4080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4080', '112', '5957', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5958', '1078', '1', 'Koszalin', 'PL.38', 'NULL', '4081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4081', '112', '5958', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5959', '1078', '1', 'Krakow', 'PL.39', 'NULL', '4082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4082', '112', '5959', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5960', '1078', '1', 'Krosno', 'PL.40', 'NULL', '4083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4083', '112', '5960', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5961', '1078', '1', 'Legnica', 'PL.41', 'NULL', '4084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4084', '112', '5961', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5962', '1078', '1', 'Leszno', 'PL.42', 'NULL', '4085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4085', '112', '5962', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5963', '1078', '1', 'Lodz', 'PL.43', 'NULL', '4086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4086', '112', '5963', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5964', '1078', '1', 'Lomza', 'PL.44', 'NULL', '4087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4087', '112', '5964', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5965', '1078', '1', 'Lublin', 'PL.45', 'NULL', '4088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4088', '112', '5965', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5966', '1078', '1', 'Nowy Sacz', 'PL.46', 'NULL', '4089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4089', '112', '5966', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5967', '1078', '1', 'Olsztyn', 'PL.47', 'NULL', '4090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4090', '112', '5967', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5968', '1078', '1', 'Opole', 'PL.48', 'NULL', '4091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4091', '112', '5968', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5969', '1078', '1', 'Ostroleka', 'PL.49', 'NULL', '4092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4092', '112', '5969', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5970', '1078', '1', 'Pita', 'PL.50', 'NULL', '4093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4093', '112', '5970', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5971', '1078', '1', 'Piotrkow', 'PL.51', 'NULL', '4094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4094', '112', '5971', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5972', '1078', '1', 'Plock', 'PL.52', 'NULL', '4095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4095', '112', '5972', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5973', '1078', '1', 'Poznan', 'PL.53', 'NULL', '4096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4096', '112', '5973', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5974', '1078', '1', 'Przemysl', 'PL.54', 'NULL', '4097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4097', '112', '5974', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5975', '1078', '1', 'Radom', 'PL.55', 'NULL', '4098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4098', '112', '5975', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5976', '1078', '1', 'Rzeszow', 'PL.56', 'NULL', '4099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4099', '112', '5976', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5977', '1078', '1', 'Siedlce', 'PL.57', 'NULL', '4100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4100', '112', '5977', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5978', '1078', '1', 'Sieradz', 'PL.58', 'NULL', '4101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4101', '112', '5978', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5979', '1078', '1', 'Skierniewice', 'PL.59', 'NULL', '4102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4102', '112', '5979', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5980', '1078', '1', 'Slupsk', 'PL.60', 'NULL', '4103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4103', '112', '5980', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5981', '1078', '1', 'Suwalki', 'PL.61', 'NULL', '4104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4104', '112', '5981', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5982', '1078', '1', 'Szczecin', 'PL.62', 'NULL', '4105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4105', '112', '5982', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5983', '1078', '1', 'Tarnobrzeg', 'PL.63', 'NULL', '4106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4106', '112', '5983', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5984', '1078', '1', 'Tarnow', 'PL.64', 'NULL', '4107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4107', '112', '5984', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5985', '1078', '1', 'Torufi', 'PL.65', 'NULL', '4108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4108', '112', '5985', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5986', '1078', '1', 'Walbrzych', 'PL.66', 'NULL', '4109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4109', '112', '5986', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5987', '1078', '1', 'Warszawa', 'PL.67', 'NULL', '4110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4110', '112', '5987', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5988', '1078', '1', 'Wloclawek', 'PL.68', 'NULL', '4111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4111', '112', '5988', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5989', '1078', '1', 'Wroclaw', 'PL.69', 'NULL', '4112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4112', '112', '5989', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5990', '1078', '1', 'Zamosc', 'PL.70', 'NULL', '4113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4113', '112', '5990', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5991', '1078', '1', 'Zielona Gora', 'PL.71', 'NULL', '4114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4114', '112', '5991', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5992', '1078', '1', 'Lower Silesian Voivodeship', 'PL.72', 'NULL', '4115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4115', '112', '5992', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5993', '1078', '1', 'Kujawsko-Pomorskie Voivodship', 'PL.73', 'NULL', '4116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4116', '112', '5993', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5994', '1078', '1', 'Łódź Voivodeship', 'PL.74', 'NULL', '4117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4117', '112', '5994', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5995', '1078', '1', 'Lublin Voivodeship', 'PL.75', 'NULL', '4118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4118', '112', '5995', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.75» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5996', '1078', '1', 'Lubusz Voivodship', 'PL.76', 'NULL', '4119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4119', '112', '5996', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5997', '1078', '1', 'Lesser Poland Voivodeship', 'PL.77', 'NULL', '4120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4120', '112', '5997', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5998', '1078', '1', 'Masovian Voivodeship', 'PL.78', 'NULL', '4121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4121', '112', '5998', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('5999', '1078', '1', 'Opole Voivodeship', 'PL.79', 'NULL', '4122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4122', '112', '5999', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6000', '1078', '1', 'Subcarpathian Voivodeship', 'PL.80', 'NULL', '4123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4123', '112', '6000', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6001', '1078', '1', 'Podlasie Voivodship', 'PL.81', 'NULL', '4124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4124', '112', '6001', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6002', '1078', '1', 'Pomeranian Voivodeship', 'PL.82', 'NULL', '4125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4125', '112', '6002', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6003', '1078', '1', 'Silesian Voivodeship', 'PL.83', 'NULL', '4126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4126', '112', '6003', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6004', '1078', '1', 'Świętokrzyskie Voivodship', 'PL.84', 'NULL', '4127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4127', '112', '6004', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6005', '1078', '1', 'Warmian-Masurian Voivodeship', 'PL.85', 'NULL', '4128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4128', '112', '6005', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6006', '1078', '1', 'Greater Poland Voivodeship', 'PL.86', 'NULL', '4129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4129', '112', '6006', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6007', '1078', '1', 'West Pomeranian Voivodeship', 'PL.87', 'NULL', '4130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4130', '112', '6007', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PL.87» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6008', '1078', '1', 'Collectivité territoriale de Saint-Pierre-et-Miquelon', 'PM.975', 'NULL', '4131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4131', '112', '6008', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PM.975» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6009', '1078', '1', 'Pitcairn Islands (general)', 'PN.00', 'NULL', '4132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4132', '112', '6009', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6010', '1078', '1', 'San Juan', 'PR.00', 'NULL', '4133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4133', '112', '6010', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6011', '1078', '1', 'Palestine (general)', 'PS.00', 'NULL', '4134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4134', '112', '6011', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PS.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6012', '1078', '1', 'Gaza Strip', 'PS.GZ', 'NULL', '4135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4135', '112', '6012', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PS.GZ» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6013', '1078', '1', 'West Bank', 'PS.WE', 'NULL', '4136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4136', '112', '6013', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PS.WE» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6014', '1078', '1', 'Portugal (general)', 'PT.00', 'NULL', '4137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4137', '112', '6014', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6015', '1078', '1', 'Aveiro', 'PT.02', 'NULL', '4138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4138', '112', '6015', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6016', '1078', '1', 'Beja', 'PT.03', 'NULL', '4139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4139', '112', '6016', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6017', '1078', '1', 'Braga', 'PT.04', 'NULL', '4140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4140', '112', '6017', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6018', '1078', '1', 'Bragança', 'PT.05', 'NULL', '4141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4141', '112', '6018', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6019', '1078', '1', 'Castelo Branco', 'PT.06', 'NULL', '4142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4142', '112', '6019', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6020', '1078', '1', 'Coimbra', 'PT.07', 'NULL', '4143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4143', '112', '6020', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6021', '1078', '1', 'Évora', 'PT.08', 'NULL', '4144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4144', '112', '6021', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6022', '1078', '1', 'Faro', 'PT.09', 'NULL', '4145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4145', '112', '6022', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6023', '1078', '1', 'Madeira', 'PT.10', 'NULL', '4146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4146', '112', '6023', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6024', '1078', '1', 'Guarda', 'PT.11', 'NULL', '4147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4147', '112', '6024', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6025', '1078', '1', 'Leiria', 'PT.13', 'NULL', '4148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4148', '112', '6025', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6026', '1078', '1', 'Lisbon', 'PT.14', 'NULL', '4149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4149', '112', '6026', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6027', '1078', '1', 'Portalegre', 'PT.16', 'NULL', '4150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4150', '112', '6027', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6028', '1078', '1', 'Porto', 'PT.17', 'NULL', '4151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4151', '112', '6028', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6029', '1078', '1', 'Santarém', 'PT.18', 'NULL', '4152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4152', '112', '6029', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6030', '1078', '1', 'Setúbal', 'PT.19', 'NULL', '4153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4153', '112', '6030', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6031', '1078', '1', 'Viana do Castelo', 'PT.20', 'NULL', '4154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4154', '112', '6031', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6032', '1078', '1', 'Vila Real', 'PT.21', 'NULL', '4155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4155', '112', '6032', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6033', '1078', '1', 'Viseu', 'PT.22', 'NULL', '4156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4156', '112', '6033', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6034', '1078', '1', 'Azores', 'PT.23', 'NULL', '4157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4157', '112', '6034', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PT.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6035', '1078', '1', 'State of Ngeremlengui', 'PW.00', 'NULL', '4158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4158', '112', '6035', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PW.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6036', '1078', '1', 'Paraguay (general)', 'PY.00', 'NULL', '4159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4159', '112', '6036', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6037', '1078', '1', 'Alto Paraná', 'PY.01', 'NULL', '4160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4160', '112', '6037', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6038', '1078', '1', 'Amambay', 'PY.02', 'NULL', '4161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4161', '112', '6038', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6039', '1078', '1', 'Departamento de Alto Paraguay', 'PY.03', 'NULL', '4162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4162', '112', '6039', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6040', '1078', '1', 'Caaguazú', 'PY.04', 'NULL', '4163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4163', '112', '6040', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6041', '1078', '1', 'Caazapá', 'PY.05', 'NULL', '4164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4164', '112', '6041', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6042', '1078', '1', 'Central', 'PY.06', 'NULL', '4165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4165', '112', '6042', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6043', '1078', '1', 'Concepción', 'PY.07', 'NULL', '4166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4166', '112', '6043', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6044', '1078', '1', 'Cordillera', 'PY.08', 'NULL', '4167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4167', '112', '6044', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6045', '1078', '1', 'Guairá', 'PY.10', 'NULL', '4168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4168', '112', '6045', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6046', '1078', '1', 'Itapúa', 'PY.11', 'NULL', '4169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4169', '112', '6046', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6047', '1078', '1', 'Misiones', 'PY.12', 'NULL', '4170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4170', '112', '6047', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6048', '1078', '1', 'Ñeembucú', 'PY.13', 'NULL', '4171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4171', '112', '6048', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6049', '1078', '1', 'Paraguarí', 'PY.15', 'NULL', '4172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4172', '112', '6049', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6050', '1078', '1', 'Presidente Hayes', 'PY.16', 'NULL', '4173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4173', '112', '6050', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6051', '1078', '1', 'San Pedro', 'PY.17', 'NULL', '4174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4174', '112', '6051', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6052', '1078', '1', 'Canindeyú', 'PY.19', 'NULL', '4175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4175', '112', '6052', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6053', '1078', '1', 'Asunción', 'PY.22', 'NULL', '4176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4176', '112', '6053', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6054', '1078', '1', 'Asunción', 'PY.23', 'NULL', '4177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4177', '112', '6054', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6055', '1078', '1', 'Boquerón', 'PY.24', 'NULL', '4178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4178', '112', '6055', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «PY.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6056', '1078', '1', 'Qatar (general)', 'QA.00', 'NULL', '4179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4179', '112', '6056', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6057', '1078', '1', 'Ad Dawḩah', 'QA.01', 'NULL', '4180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4180', '112', '6057', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6058', '1078', '1', 'Al Ghuwayrīyah', 'QA.02', 'NULL', '4181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4181', '112', '6058', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6059', '1078', '1', 'Al Jumaylīyah', 'QA.03', 'NULL', '4182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4182', '112', '6059', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6060', '1078', '1', 'Al Khawr', 'QA.04', 'NULL', '4183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4183', '112', '6060', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6061', '1078', '1', 'Al Wakrah Municipality', 'QA.05', 'NULL', '4184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4184', '112', '6061', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6062', '1078', '1', 'Ar Rayyān', 'QA.06', 'NULL', '4185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4185', '112', '6062', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6063', '1078', '1', 'Jarayan al Batinah', 'QA.07', 'NULL', '4186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4186', '112', '6063', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6064', '1078', '1', 'Madīnat ash Shamāl', 'QA.08', 'NULL', '4187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4187', '112', '6064', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6065', '1078', '1', 'Umm Şalāl', 'QA.09', 'NULL', '4188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4188', '112', '6065', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6066', '1078', '1', 'Al Wakrah', 'QA.10', 'NULL', '4189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4189', '112', '6066', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6067', '1078', '1', 'Jarayān al Bāţinah', 'QA.11', 'NULL', '4190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4190', '112', '6067', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6068', '1078', '1', 'Umm Sa‘īd', 'QA.12', 'NULL', '4191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4191', '112', '6068', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «QA.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6069', '1078', '1', 'Région Réunion', 'RE.RE', 'NULL', '4192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4192', '112', '6069', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RE.RE» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6070', '1078', '1', 'Alba', 'RO.01', 'NULL', '4193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4193', '112', '6070', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6071', '1078', '1', 'Arad', 'RO.02', 'NULL', '4194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4194', '112', '6071', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6072', '1078', '1', 'Argeş', 'RO.03', 'NULL', '4195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4195', '112', '6072', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6073', '1078', '1', 'Bacău', 'RO.04', 'NULL', '4196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4196', '112', '6073', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6074', '1078', '1', 'Bihor', 'RO.05', 'NULL', '4197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4197', '112', '6074', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6075', '1078', '1', 'Bistriţa-Năsăud', 'RO.06', 'NULL', '4198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4198', '112', '6075', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6076', '1078', '1', 'Botoşani', 'RO.07', 'NULL', '4199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4199', '112', '6076', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6077', '1078', '1', 'Brăila', 'RO.08', 'NULL', '4200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4200', '112', '6077', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6078', '1078', '1', 'Braşov', 'RO.09', 'NULL', '4201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4201', '112', '6078', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6079', '1078', '1', 'Bucureşti', 'RO.10', 'NULL', '4202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4202', '112', '6079', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6080', '1078', '1', 'Buzău', 'RO.11', 'NULL', '4203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4203', '112', '6080', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6081', '1078', '1', 'Caraş-Severin', 'RO.12', 'NULL', '4204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4204', '112', '6081', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6082', '1078', '1', 'Cluj', 'RO.13', 'NULL', '4205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4205', '112', '6082', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6083', '1078', '1', 'Constanţa', 'RO.14', 'NULL', '4206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4206', '112', '6083', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6084', '1078', '1', 'Covasna', 'RO.15', 'NULL', '4207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4207', '112', '6084', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6085', '1078', '1', 'Dâmboviţa', 'RO.16', 'NULL', '4208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4208', '112', '6085', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6086', '1078', '1', 'Dolj', 'RO.17', 'NULL', '4209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4209', '112', '6086', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6087', '1078', '1', 'Galaţi', 'RO.18', 'NULL', '4210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4210', '112', '6087', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6088', '1078', '1', 'Gorj', 'RO.19', 'NULL', '4211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4211', '112', '6088', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6089', '1078', '1', 'Harghita', 'RO.20', 'NULL', '4212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4212', '112', '6089', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6090', '1078', '1', 'Hunedoara', 'RO.21', 'NULL', '4213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4213', '112', '6090', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6091', '1078', '1', 'Ialomiţa', 'RO.22', 'NULL', '4214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4214', '112', '6091', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6092', '1078', '1', 'Iaşi', 'RO.23', 'NULL', '4215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4215', '112', '6092', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6093', '1078', '1', 'Maramureş', 'RO.25', 'NULL', '4216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4216', '112', '6093', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6094', '1078', '1', 'Mehedinţi', 'RO.26', 'NULL', '4217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4217', '112', '6094', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6095', '1078', '1', 'Mureş', 'RO.27', 'NULL', '4218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4218', '112', '6095', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6096', '1078', '1', 'Neamţ', 'RO.28', 'NULL', '4219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4219', '112', '6096', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6097', '1078', '1', 'Olt', 'RO.29', 'NULL', '4220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4220', '112', '6097', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6098', '1078', '1', 'Prahova', 'RO.30', 'NULL', '4221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4221', '112', '6098', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6099', '1078', '1', 'Sălaj', 'RO.31', 'NULL', '4222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4222', '112', '6099', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6100', '1078', '1', 'Satu Mare', 'RO.32', 'NULL', '4223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4223', '112', '6100', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6101', '1078', '1', 'Sibiu', 'RO.33', 'NULL', '4224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4224', '112', '6101', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6102', '1078', '1', 'Suceava', 'RO.34', 'NULL', '4225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4225', '112', '6102', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6103', '1078', '1', 'Teleorman', 'RO.35', 'NULL', '4226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4226', '112', '6103', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6104', '1078', '1', 'Timiş', 'RO.36', 'NULL', '4227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4227', '112', '6104', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6105', '1078', '1', 'Tulcea', 'RO.37', 'NULL', '4228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4228', '112', '6105', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6106', '1078', '1', 'Vaslui', 'RO.38', 'NULL', '4229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4229', '112', '6106', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6107', '1078', '1', 'Vâlcea', 'RO.39', 'NULL', '4230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4230', '112', '6107', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6108', '1078', '1', 'Judeţul Vrancea', 'RO.40', 'NULL', '4231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4231', '112', '6108', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6109', '1078', '1', 'Călăraşi', 'RO.41', 'NULL', '4232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4232', '112', '6109', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6110', '1078', '1', 'Giurgiu', 'RO.42', 'NULL', '4233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4233', '112', '6110', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6111', '1078', '1', 'Ilfov', 'RO.43', 'NULL', '4234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4234', '112', '6111', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RO.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6112', '1078', '1', 'Serbia (general)', 'RS.00', 'NULL', '4235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4235', '112', '6112', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RS.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6113', '1078', '1', 'Kosovo', 'RS.01', 'NULL', '4236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4236', '112', '6113', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RS.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6114', '1078', '1', 'Autonomna Pokrajina Vojvodina', 'RS.02', 'NULL', '4237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4237', '112', '6114', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RS.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6115', '1078', '1', 'Russia (general)', 'RU.00', 'NULL', '4238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4238', '112', '6115', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6116', '1078', '1', 'Adygeya', 'RU.01', 'NULL', '4239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4239', '112', '6116', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6117', '1078', '1', 'Aginskiy Buryatskiy Avtonomnyy Okrug', 'RU.02', 'NULL', '4240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4240', '112', '6117', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6118', '1078', '1', 'Altay', 'RU.03', 'NULL', '4241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4241', '112', '6118', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6119', '1078', '1', 'Altayskiy Kray', 'RU.04', 'NULL', '4242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4242', '112', '6119', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6120', '1078', '1', 'Amur', 'RU.05', 'NULL', '4243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4243', '112', '6120', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6121', '1078', '1', 'Arkhangelskaya oblast', 'RU.06', 'NULL', '4244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4244', '112', '6121', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6122', '1078', '1', 'Astrakhan', 'RU.07', 'NULL', '4245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4245', '112', '6122', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6123', '1078', '1', 'Bashkortostan', 'RU.08', 'NULL', '4246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4246', '112', '6123', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6124', '1078', '1', 'Belgorod', 'RU.09', 'NULL', '4247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4247', '112', '6124', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6125', '1078', '1', 'Brjansk', 'RU.10', 'NULL', '4248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4248', '112', '6125', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6126', '1078', '1', 'Buryatiya', 'RU.11', 'NULL', '4249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4249', '112', '6126', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6127', '1078', '1', 'Chechnya', 'RU.12', 'NULL', '4250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4250', '112', '6127', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6128', '1078', '1', 'Tsjeljabinsk', 'RU.13', 'NULL', '4251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4251', '112', '6128', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6129', '1078', '1', 'Tsjita', 'RU.14', 'NULL', '4252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4252', '112', '6129', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6130', '1078', '1', 'Chukotskiy Avtonomnyy Okrug', 'RU.15', 'NULL', '4253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4253', '112', '6130', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6131', '1078', '1', 'Chuvashia', 'RU.16', 'NULL', '4254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4254', '112', '6131', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6132', '1078', '1', 'Dagestan', 'RU.17', 'NULL', '4255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4255', '112', '6132', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6133', '1078', '1', 'Evenkiyskiy Avtonomnyy Okrug', 'RU.18', 'NULL', '4256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4256', '112', '6133', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6134', '1078', '1', 'Ingushetiya', 'RU.19', 'NULL', '4257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4257', '112', '6134', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6135', '1078', '1', 'Irkutsk', 'RU.20', 'NULL', '4258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4258', '112', '6135', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6136', '1078', '1', 'Ivanovo', 'RU.21', 'NULL', '4259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4259', '112', '6136', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6137', '1078', '1', 'Kabardino-Balkariya', 'RU.22', 'NULL', '4260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4260', '112', '6137', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6138', '1078', '1', 'Kaliningrad', 'RU.23', 'NULL', '4261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4261', '112', '6138', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6139', '1078', '1', 'Kalmykiya', 'RU.24', 'NULL', '4262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4262', '112', '6139', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6140', '1078', '1', 'Kaluga', 'RU.25', 'NULL', '4263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4263', '112', '6140', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6141', '1078', '1', 'Kamtsjatka', 'RU.26', 'NULL', '4264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4264', '112', '6141', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6142', '1078', '1', 'Karachayevo-Cherkesiya', 'RU.27', 'NULL', '4265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4265', '112', '6142', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6143', '1078', '1', 'Kareliya', 'RU.28', 'NULL', '4266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4266', '112', '6143', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6144', '1078', '1', 'Kemerovo', 'RU.29', 'NULL', '4267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4267', '112', '6144', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6145', '1078', '1', 'Khabarovsk Krai', 'RU.30', 'NULL', '4268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4268', '112', '6145', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6146', '1078', '1', 'Khakasiya', 'RU.31', 'NULL', '4269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4269', '112', '6146', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6147', '1078', '1', 'Khanty-Mansiyskiy Avtonomnyy Okrug', 'RU.32', 'NULL', '4270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4270', '112', '6147', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6148', '1078', '1', 'Kirov', 'RU.33', 'NULL', '4271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4271', '112', '6148', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6149', '1078', '1', 'Komi', 'RU.34', 'NULL', '4272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4272', '112', '6149', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6150', '1078', '1', 'Koryakskiy Avtonomnyy Okrug', 'RU.36', 'NULL', '4273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4273', '112', '6150', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6151', '1078', '1', 'Kostroma', 'RU.37', 'NULL', '4274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4274', '112', '6151', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6152', '1078', '1', 'Krasnodarskiy Kray', 'RU.38', 'NULL', '4275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4275', '112', '6152', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6153', '1078', '1', 'Krasnoyarskiy Kray', 'RU.39', 'NULL', '4276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4276', '112', '6153', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6154', '1078', '1', 'Kurgan', 'RU.40', 'NULL', '4277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4277', '112', '6154', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6155', '1078', '1', 'Kursk', 'RU.41', 'NULL', '4278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4278', '112', '6155', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6156', '1078', '1', 'Leningradskaya Oblast''', 'RU.42', 'NULL', '4279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4279', '112', '6156', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6157', '1078', '1', 'Lipetsk', 'RU.43', 'NULL', '4280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4280', '112', '6157', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6158', '1078', '1', 'Magadan', 'RU.44', 'NULL', '4281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4281', '112', '6158', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6159', '1078', '1', 'Mariy-El', 'RU.45', 'NULL', '4282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4282', '112', '6159', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6160', '1078', '1', 'Mordoviya', 'RU.46', 'NULL', '4283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4283', '112', '6160', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6161', '1078', '1', 'Moskovskaya Oblast''', 'RU.47', 'NULL', '4284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4284', '112', '6161', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6162', '1078', '1', 'Moscow', 'RU.48', 'NULL', '4285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4285', '112', '6162', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6163', '1078', '1', 'Murmansk Oblast', 'RU.49', 'NULL', '4286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4286', '112', '6163', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6164', '1078', '1', 'Nenetskiy Avtonomnyy Okrug', 'RU.50', 'NULL', '4287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4287', '112', '6164', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6165', '1078', '1', 'Nizjnij Novgorod', 'RU.51', 'NULL', '4288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4288', '112', '6165', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6166', '1078', '1', 'Novgorod', 'RU.52', 'NULL', '4289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4289', '112', '6166', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6167', '1078', '1', 'Novosibirsk', 'RU.53', 'NULL', '4290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4290', '112', '6167', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6168', '1078', '1', 'Omsk', 'RU.54', 'NULL', '4291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4291', '112', '6168', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6169', '1078', '1', 'Orenburg', 'RU.55', 'NULL', '4292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4292', '112', '6169', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6170', '1078', '1', 'Orjol', 'RU.56', 'NULL', '4293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4293', '112', '6170', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6171', '1078', '1', 'Penza', 'RU.57', 'NULL', '4294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4294', '112', '6171', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6172', '1078', '1', 'Primorskiy Kray', 'RU.59', 'NULL', '4295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4295', '112', '6172', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6173', '1078', '1', 'Pskov', 'RU.60', 'NULL', '4296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4296', '112', '6173', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6174', '1078', '1', 'Rostov', 'RU.61', 'NULL', '4297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4297', '112', '6174', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6175', '1078', '1', 'Rjazan', 'RU.62', 'NULL', '4298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4298', '112', '6175', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6176', '1078', '1', 'Sakha', 'RU.63', 'NULL', '4299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4299', '112', '6176', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6177', '1078', '1', 'Sakhalin', 'RU.64', 'NULL', '4300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4300', '112', '6177', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6178', '1078', '1', 'Samara', 'RU.65', 'NULL', '4301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4301', '112', '6178', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6179', '1078', '1', 'Sankt-Peterburg', 'RU.66', 'NULL', '4302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4302', '112', '6179', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6180', '1078', '1', 'Saratov', 'RU.67', 'NULL', '4303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4303', '112', '6180', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6181', '1078', '1', 'Severnaya Osetiya-Alaniya', 'RU.68', 'NULL', '4304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4304', '112', '6181', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6182', '1078', '1', 'Smolensk', 'RU.69', 'NULL', '4305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4305', '112', '6182', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6183', '1078', '1', 'Stavropol''skiy Kray', 'RU.70', 'NULL', '4306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4306', '112', '6183', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6184', '1078', '1', 'Sverdlovsk', 'RU.71', 'NULL', '4307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4307', '112', '6184', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6185', '1078', '1', 'Tambov', 'RU.72', 'NULL', '4308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4308', '112', '6185', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6186', '1078', '1', 'Tatarstan', 'RU.73', 'NULL', '4309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4309', '112', '6186', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6187', '1078', '1', 'Taymyrskiy (Dolgano-Nenetskiy) Avtonomnyy Okrug', 'RU.74', 'NULL', '4310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4310', '112', '6187', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6188', '1078', '1', 'Tomsk', 'RU.75', 'NULL', '4311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4311', '112', '6188', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.75» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6189', '1078', '1', 'Tula', 'RU.76', 'NULL', '4312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4312', '112', '6189', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6190', '1078', '1', 'Tverskaya Oblast’', 'RU.77', 'NULL', '4313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4313', '112', '6190', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6191', '1078', '1', 'Tjumen', 'RU.78', 'NULL', '4314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4314', '112', '6191', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6192', '1078', '1', 'Tyva', 'RU.79', 'NULL', '4315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4315', '112', '6192', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6193', '1078', '1', 'Udmurtiya', 'RU.80', 'NULL', '4316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4316', '112', '6193', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6194', '1078', '1', 'Uljanovsk', 'RU.81', 'NULL', '4317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4317', '112', '6194', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6195', '1078', '1', 'Ust''-Ordynskiy Buryatskiy Avtonomnyy Okrug', 'RU.82', 'NULL', '4318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4318', '112', '6195', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6196', '1078', '1', 'Vladimir', 'RU.83', 'NULL', '4319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4319', '112', '6196', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6197', '1078', '1', 'Volgograd', 'RU.84', 'NULL', '4320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4320', '112', '6197', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6198', '1078', '1', 'Vologda', 'RU.85', 'NULL', '4321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4321', '112', '6198', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6199', '1078', '1', 'Voronezj', 'RU.86', 'NULL', '4322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4322', '112', '6199', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6200', '1078', '1', 'Yamalo-Nenetskiy Avtonomnyy Okrug', 'RU.87', 'NULL', '4323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4323', '112', '6200', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.87» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6201', '1078', '1', 'Jaroslavl', 'RU.88', 'NULL', '4324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4324', '112', '6201', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.88» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6202', '1078', '1', 'Jewish Autonomous Oblast', 'RU.89', 'NULL', '4325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4325', '112', '6202', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.89» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6203', '1078', '1', 'Perm', 'RU.90', 'NULL', '4326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4326', '112', '6203', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.90» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6204', '1078', '1', 'RSJA', 'RU.JA', 'NULL', '4327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4327', '112', '6204', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RU.JA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6205', '1078', '1', 'Rwanda (general)', 'RW.00', 'NULL', '4328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4328', '112', '6205', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6206', '1078', '1', 'Butare', 'RW.01', 'NULL', '4329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4329', '112', '6206', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6207', '1078', '1', 'Byumba', 'RW.02', 'NULL', '4330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4330', '112', '6207', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6208', '1078', '1', 'Cyangugu', 'RW.03', 'NULL', '4331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4331', '112', '6208', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6209', '1078', '1', 'Gikongoro', 'RW.04', 'NULL', '4332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4332', '112', '6209', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6210', '1078', '1', 'Gisenyi', 'RW.05', 'NULL', '4333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4333', '112', '6210', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6211', '1078', '1', 'Gitarama', 'RW.06', 'NULL', '4334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4334', '112', '6211', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6212', '1078', '1', 'Kibungo', 'RW.07', 'NULL', '4335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4335', '112', '6212', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6213', '1078', '1', 'Kibuye', 'RW.08', 'NULL', '4336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4336', '112', '6213', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6214', '1078', '1', 'Kigali', 'RW.09', 'NULL', '4337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4337', '112', '6214', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6215', '1078', '1', 'Ruhengeri', 'RW.10', 'NULL', '4338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4338', '112', '6215', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6216', '1078', '1', 'Eastern Province', 'RW.11', 'NULL', '4339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4339', '112', '6216', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6217', '1078', '1', 'Kigali City', 'RW.12', 'NULL', '4340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4340', '112', '6217', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6218', '1078', '1', 'Northern Province', 'RW.13', 'NULL', '4341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4341', '112', '6218', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6219', '1078', '1', 'Western Province', 'RW.14', 'NULL', '4342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4342', '112', '6219', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6220', '1078', '1', 'Southern Province', 'RW.15', 'NULL', '4343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4343', '112', '6220', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «RW.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6221', '1078', '1', 'Saudi Arabia (general)', 'SA.00', 'NULL', '4344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4344', '112', '6221', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6222', '1078', '1', 'Al Bāḩah', 'SA.02', 'NULL', '4345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4345', '112', '6222', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6223', '1078', '1', 'Al Madīnah', 'SA.05', 'NULL', '4346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4346', '112', '6223', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6224', '1078', '1', 'Ash Sharqīyah', 'SA.06', 'NULL', '4347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4347', '112', '6224', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6225', '1078', '1', 'Al Qaşīm', 'SA.08', 'NULL', '4348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4348', '112', '6225', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6226', '1078', '1', 'Ar Riyāḑ', 'SA.10', 'NULL', '4349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4349', '112', '6226', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6227', '1078', '1', '‘Asīr', 'SA.11', 'NULL', '4350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4350', '112', '6227', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6228', '1078', '1', 'Ḩāʼil', 'SA.13', 'NULL', '4351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4351', '112', '6228', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6229', '1078', '1', 'Makkah', 'SA.14', 'NULL', '4352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4352', '112', '6229', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6230', '1078', '1', 'Northern Borders Region', 'SA.15', 'NULL', '4353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4353', '112', '6230', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6231', '1078', '1', 'Najrān', 'SA.16', 'NULL', '4354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4354', '112', '6231', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6232', '1078', '1', 'Jīzān', 'SA.17', 'NULL', '4355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4355', '112', '6232', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6233', '1078', '1', 'Tabūk', 'SA.19', 'NULL', '4356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4356', '112', '6233', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6234', '1078', '1', 'Al Jawf', 'SA.20', 'NULL', '4357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4357', '112', '6234', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SA.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6235', '1078', '1', 'Makira Province', 'SB.00', 'NULL', '4358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4358', '112', '6235', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SB.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6236', '1078', '1', 'Malaita', 'SB.03', 'NULL', '4359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4359', '112', '6236', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SB.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6237', '1078', '1', 'Western', 'SB.04', 'NULL', '4360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4360', '112', '6237', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SB.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6238', '1078', '1', 'Central', 'SB.05', 'NULL', '4361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4361', '112', '6238', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SB.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6239', '1078', '1', 'Guadalcanal', 'SB.06', 'NULL', '4362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4362', '112', '6239', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SB.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6240', '1078', '1', 'Isabel', 'SB.07', 'NULL', '4363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4363', '112', '6240', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SB.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6241', '1078', '1', 'Makira', 'SB.08', 'NULL', '4364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4364', '112', '6241', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SB.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6242', '1078', '1', 'Temotu', 'SB.09', 'NULL', '4365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4365', '112', '6242', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SB.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6243', '1078', '1', 'Choiseul', 'SB.11', 'NULL', '4366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4366', '112', '6243', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SB.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6244', '1078', '1', 'Rennell and Bellona', 'SB.12', 'NULL', '4367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4367', '112', '6244', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SB.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6245', '1078', '1', 'Seychelles (general)', 'SC.00', 'NULL', '4368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4368', '112', '6245', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6246', '1078', '1', 'Anse aux Pins', 'SC.01', 'NULL', '4369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4369', '112', '6246', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6247', '1078', '1', 'Anse Boileau', 'SC.02', 'NULL', '4370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4370', '112', '6247', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6248', '1078', '1', 'Anse Etoile', 'SC.03', 'NULL', '4371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4371', '112', '6248', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6249', '1078', '1', 'Anse Louis', 'SC.04', 'NULL', '4372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4372', '112', '6249', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6250', '1078', '1', 'Anse Royale', 'SC.05', 'NULL', '4373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4373', '112', '6250', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6251', '1078', '1', 'Baie Lazare', 'SC.06', 'NULL', '4374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4374', '112', '6251', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6252', '1078', '1', 'Baie Sainte Anne', 'SC.07', 'NULL', '4375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4375', '112', '6252', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6253', '1078', '1', 'Beau Vallon', 'SC.08', 'NULL', '4376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4376', '112', '6253', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6254', '1078', '1', 'Bel Air', 'SC.09', 'NULL', '4377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4377', '112', '6254', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6255', '1078', '1', 'Bel Ombre', 'SC.10', 'NULL', '4378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4378', '112', '6255', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6256', '1078', '1', 'Cascade', 'SC.11', 'NULL', '4379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4379', '112', '6256', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6257', '1078', '1', 'Glacis', 'SC.12', 'NULL', '4380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4380', '112', '6257', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6258', '1078', '1', 'Saint Thomas Middle Island Parish', 'SC.13', 'NULL', '4381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4381', '112', '6258', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6259', '1078', '1', 'Grand Anse Praslin', 'SC.14', 'NULL', '4382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4382', '112', '6259', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6260', '1078', '1', 'Trinity Palmetto Point Parish', 'SC.15', 'NULL', '4383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4383', '112', '6260', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6261', '1078', '1', 'La Riviere Anglaise', 'SC.16', 'NULL', '4384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4384', '112', '6261', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6262', '1078', '1', 'Mont Buxton', 'SC.17', 'NULL', '4385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4385', '112', '6262', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6263', '1078', '1', 'Mont Fleuri', 'SC.18', 'NULL', '4386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4386', '112', '6263', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6264', '1078', '1', 'Plaisance', 'SC.19', 'NULL', '4387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4387', '112', '6264', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6265', '1078', '1', 'Pointe Larue', 'SC.20', 'NULL', '4388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4388', '112', '6265', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6266', '1078', '1', 'Port Glaud', 'SC.21', 'NULL', '4389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4389', '112', '6266', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6267', '1078', '1', 'Saint Louis', 'SC.22', 'NULL', '4390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4390', '112', '6267', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6268', '1078', '1', 'Takamaka', 'SC.23', 'NULL', '4391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4391', '112', '6268', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6269', '1078', '1', 'Anse aux Pins', 'SC.24', 'NULL', '4392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4392', '112', '6269', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6270', '1078', '1', 'Inner Islands', 'SC.25', 'NULL', '4393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4393', '112', '6270', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6271', '1078', '1', 'English River', 'SC.26', 'NULL', '4394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4394', '112', '6271', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6272', '1078', '1', 'Port Glaud', 'SC.27', 'NULL', '4395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4395', '112', '6272', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6273', '1078', '1', 'Baie Lazare', 'SC.28', 'NULL', '4396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4396', '112', '6273', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6274', '1078', '1', 'Beau Vallon', 'SC.29', 'NULL', '4397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4397', '112', '6274', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6275', '1078', '1', 'Bel Ombre', 'SC.30', 'NULL', '4398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4398', '112', '6275', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6276', '1078', '1', 'Glacis', 'SC.31', 'NULL', '4399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4399', '112', '6276', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6277', '1078', '1', 'Grand Anse Mahe', 'SC.32', 'NULL', '4400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4400', '112', '6277', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6278', '1078', '1', 'Grand Anse Praslin', 'SC.33', 'NULL', '4401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4401', '112', '6278', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6279', '1078', '1', 'Inner Islands', 'SC.34', 'NULL', '4402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4402', '112', '6279', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6280', '1078', '1', 'English River', 'SC.35', 'NULL', '4403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4403', '112', '6280', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6281', '1078', '1', 'Mont Fleuri', 'SC.36', 'NULL', '4404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4404', '112', '6281', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6282', '1078', '1', 'Plaisance', 'SC.37', 'NULL', '4405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4405', '112', '6282', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6283', '1078', '1', 'Pointe Larue', 'SC.38', 'NULL', '4406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4406', '112', '6283', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6284', '1078', '1', 'Port Glaud', 'SC.39', 'NULL', '4407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4407', '112', '6284', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6285', '1078', '1', 'Takamaka', 'SC.40', 'NULL', '4408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4408', '112', '6285', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6286', '1078', '1', 'Au Cap', 'SC.41', 'NULL', '4409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4409', '112', '6286', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6287', '1078', '1', 'Les Mamelles', 'SC.42', 'NULL', '4410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4410', '112', '6287', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6288', '1078', '1', 'Roche Caiman', 'SC.43', 'NULL', '4411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4411', '112', '6288', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SC.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6289', '1078', '1', 'Sudan (general)', 'SD.00', 'NULL', '4412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4412', '112', '6289', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6290', '1078', '1', '(SU26)', 'SD.26', 'NULL', '4413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4413', '112', '6290', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6291', '1078', '1', 'Al Wilāyah al Wusţá', 'SD.27', 'NULL', '4414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4414', '112', '6291', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6292', '1078', '1', 'Al Wilāyah al Istiwā''īyah', 'SD.28', 'NULL', '4415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4415', '112', '6292', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6293', '1078', '1', 'Khartoum', 'SD.29', 'NULL', '4416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4416', '112', '6293', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6294', '1078', '1', 'Ash Shamaliyah', 'SD.30', 'NULL', '4417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4417', '112', '6294', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6295', '1078', '1', 'Al Wilāyah ash Sharqīyah', 'SD.31', 'NULL', '4418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4418', '112', '6295', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6296', '1078', '1', 'Ba?r al Ghazal Wilayat', 'SD.32', 'NULL', '4419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4419', '112', '6296', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6297', '1078', '1', 'Darfur Wilayat', 'SD.33', 'NULL', '4420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4420', '112', '6297', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6298', '1078', '1', 'Kurdufan Wilayat', 'SD.34', 'NULL', '4421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4421', '112', '6298', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6299', '1078', '1', 'Upper Nile', 'SD.35', 'NULL', '4422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4422', '112', '6299', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6300', '1078', '1', 'Red Sea', 'SD.36', 'NULL', '4423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4423', '112', '6300', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6301', '1078', '1', 'Lakes', 'SD.37', 'NULL', '4424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4424', '112', '6301', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6302', '1078', '1', 'Al Jazirah', 'SD.38', 'NULL', '4425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4425', '112', '6302', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6303', '1078', '1', 'Al Qadarif', 'SD.39', 'NULL', '4426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4426', '112', '6303', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6304', '1078', '1', 'Unity', 'SD.40', 'NULL', '4427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4427', '112', '6304', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6305', '1078', '1', 'White Nile', 'SD.41', 'NULL', '4428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4428', '112', '6305', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6306', '1078', '1', 'Blue Nile', 'SD.42', 'NULL', '4429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4429', '112', '6306', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6307', '1078', '1', 'Northern', 'SD.43', 'NULL', '4430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4430', '112', '6307', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6308', '1078', '1', 'Central Equatoria', 'SD.44', 'NULL', '4431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4431', '112', '6308', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6309', '1078', '1', 'Gharb al Istiwāʼīyah', 'SD.45', 'NULL', '4432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4432', '112', '6309', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6310', '1078', '1', 'Western Bahr al Ghazal', 'SD.46', 'NULL', '4433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4433', '112', '6310', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6311', '1078', '1', 'Gharb Dārfūr', 'SD.47', 'NULL', '4434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4434', '112', '6311', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6312', '1078', '1', 'Gharb Kurdufān', 'SD.48', 'NULL', '4435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4435', '112', '6312', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6313', '1078', '1', 'Janūb Dārfūr', 'SD.49', 'NULL', '4436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4436', '112', '6313', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6314', '1078', '1', 'Janūb Kurdufān', 'SD.50', 'NULL', '4437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4437', '112', '6314', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6315', '1078', '1', 'Junqalī', 'SD.51', 'NULL', '4438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4438', '112', '6315', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6316', '1078', '1', 'Kassalā', 'SD.52', 'NULL', '4439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4439', '112', '6316', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6317', '1078', '1', 'Nahr an Nīl', 'SD.53', 'NULL', '4440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4440', '112', '6317', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6318', '1078', '1', 'Shamāl Baḩr al Ghazāl', 'SD.54', 'NULL', '4441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4441', '112', '6318', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6319', '1078', '1', 'Shamāl Dārfūr', 'SD.55', 'NULL', '4442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4442', '112', '6319', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6320', '1078', '1', 'Shamāl Kurdufān', 'SD.56', 'NULL', '4443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4443', '112', '6320', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6321', '1078', '1', 'Eastern Equatoria', 'SD.57', 'NULL', '4444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4444', '112', '6321', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6322', '1078', '1', 'Sinnār', 'SD.58', 'NULL', '4445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4445', '112', '6322', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6323', '1078', '1', 'Warab', 'SD.59', 'NULL', '4446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4446', '112', '6323', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SD.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6324', '1078', '1', 'Sweden (general)', 'SE.00', 'NULL', '4447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4447', '112', '6324', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6325', '1078', '1', 'Alvsborg ', 'SE.01', 'NULL', '4448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4448', '112', '6325', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6326', '1078', '1', 'Blekinge County', 'SE.02', 'NULL', '4449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4449', '112', '6326', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6327', '1078', '1', 'Gävleborg County', 'SE.03', 'NULL', '4450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4450', '112', '6327', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6328', '1078', '1', 'Goteborgs Och Bohus', 'SE.04', 'NULL', '4451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4451', '112', '6328', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6329', '1078', '1', 'Gotland County', 'SE.05', 'NULL', '4452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4452', '112', '6329', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6330', '1078', '1', 'Halland County', 'SE.06', 'NULL', '4453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4453', '112', '6330', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6331', '1078', '1', 'Jämtland County', 'SE.07', 'NULL', '4454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4454', '112', '6331', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6332', '1078', '1', 'Jönköping County', 'SE.08', 'NULL', '4455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4455', '112', '6332', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6333', '1078', '1', 'Kalmar County', 'SE.09', 'NULL', '4456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4456', '112', '6333', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6334', '1078', '1', 'Dalarna County', 'SE.10', 'NULL', '4457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4457', '112', '6334', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6335', '1078', '1', 'Kristianstad', 'SE.11', 'NULL', '4458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4458', '112', '6335', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6336', '1078', '1', 'Kronoberg County', 'SE.12', 'NULL', '4459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4459', '112', '6336', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6337', '1078', '1', 'Malmohus', 'SE.13', 'NULL', '4460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4460', '112', '6337', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6338', '1078', '1', 'Norrbotten County', 'SE.14', 'NULL', '4461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4461', '112', '6338', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6339', '1078', '1', 'Örebro County', 'SE.15', 'NULL', '4462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4462', '112', '6339', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6340', '1078', '1', 'Östergötland County', 'SE.16', 'NULL', '4463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4463', '112', '6340', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6341', '1078', '1', 'Skaraborg', 'SE.17', 'NULL', '4464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4464', '112', '6341', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6342', '1078', '1', 'Södermanland County', 'SE.18', 'NULL', '4465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4465', '112', '6342', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6343', '1078', '1', 'Uppsala County', 'SE.21', 'NULL', '4466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4466', '112', '6343', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6344', '1078', '1', 'Värmland County', 'SE.22', 'NULL', '4467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4467', '112', '6344', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6345', '1078', '1', 'Västerbotten County', 'SE.23', 'NULL', '4468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4468', '112', '6345', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6346', '1078', '1', 'Västernorrland County', 'SE.24', 'NULL', '4469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4469', '112', '6346', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6347', '1078', '1', 'Västmanland County', 'SE.25', 'NULL', '4470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4470', '112', '6347', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6348', '1078', '1', 'Stockholm County', 'SE.26', 'NULL', '4471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4471', '112', '6348', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6349', '1078', '1', 'Skåne County', 'SE.27', 'NULL', '4472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4472', '112', '6349', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6350', '1078', '1', 'Västra Götaland County', 'SE.28', 'NULL', '4473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4473', '112', '6350', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SE.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6351', '1078', '1', 'Singapore (general)', 'SG.00', 'NULL', '4474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4474', '112', '6351', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6352', '1078', '1', 'Saint Helena (general)', 'SH.00', 'NULL', '4475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4475', '112', '6352', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SH.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6353', '1078', '1', 'Ascension', 'SH.01', 'NULL', '4476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4476', '112', '6353', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SH.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6354', '1078', '1', 'Saint Helena', 'SH.02', 'NULL', '4477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4477', '112', '6354', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SH.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6355', '1078', '1', 'Tristan da Cunha', 'SH.03', 'NULL', '4478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4478', '112', '6355', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SH.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6356', '1078', '1', 'Bled', 'SI.03', 'NULL', '4479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4479', '112', '6356', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6357', '1078', '1', 'Bohinj', 'SI.04', 'NULL', '4480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4480', '112', '6357', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6358', '1078', '1', 'Borovnica', 'SI.05', 'NULL', '4481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4481', '112', '6358', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6359', '1078', '1', 'Bovec', 'SI.06', 'NULL', '4482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4482', '112', '6359', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6360', '1078', '1', 'Brda', 'SI.07', 'NULL', '4483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4483', '112', '6360', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6361', '1078', '1', 'Brežice', 'SI.08', 'NULL', '4484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4484', '112', '6361', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6362', '1078', '1', 'Brezovica', 'SI.09', 'NULL', '4485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4485', '112', '6362', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6363', '1078', '1', 'Celje', 'SI.11', 'NULL', '4486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4486', '112', '6363', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6364', '1078', '1', 'Občina Cerklje na Gorenjskem', 'SI.12', 'NULL', '4487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4487', '112', '6364', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6365', '1078', '1', 'Cerknica', 'SI.13', 'NULL', '4488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4488', '112', '6365', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6366', '1078', '1', 'Cerkno', 'SI.14', 'NULL', '4489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4489', '112', '6366', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6367', '1078', '1', 'Črenšovci', 'SI.15', 'NULL', '4490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4490', '112', '6367', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6368', '1078', '1', 'Črna na Koroškem', 'SI.16', 'NULL', '4491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4491', '112', '6368', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6369', '1078', '1', 'Črnomelj', 'SI.17', 'NULL', '4492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4492', '112', '6369', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6370', '1078', '1', 'Divača', 'SI.19', 'NULL', '4493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4493', '112', '6370', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6371', '1078', '1', 'Dobrepolje', 'SI.20', 'NULL', '4494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4494', '112', '6371', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6372', '1078', '1', 'Občina Dol pri Ljubljani', 'SI.22', 'NULL', '4495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4495', '112', '6372', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6373', '1078', '1', 'Dornava', 'SI.24', 'NULL', '4496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4496', '112', '6373', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6374', '1078', '1', 'Dravograd', 'SI.25', 'NULL', '4497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4497', '112', '6374', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6375', '1078', '1', 'Duplek', 'SI.26', 'NULL', '4498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4498', '112', '6375', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6376', '1078', '1', 'Gorenja Vas-Poljane', 'SI.27', 'NULL', '4499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4499', '112', '6376', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6377', '1078', '1', 'Gorišnica', 'SI.28', 'NULL', '4500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4500', '112', '6377', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6378', '1078', '1', 'Gornja Radgona', 'SI.29', 'NULL', '4501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4501', '112', '6378', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6379', '1078', '1', 'Gornji Grad', 'SI.30', 'NULL', '4502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4502', '112', '6379', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6380', '1078', '1', 'Gornji Petrovci', 'SI.31', 'NULL', '4503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4503', '112', '6380', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6381', '1078', '1', 'Grosuplje', 'SI.32', 'NULL', '4504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4504', '112', '6381', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6382', '1078', '1', 'Hrastnik', 'SI.34', 'NULL', '4505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4505', '112', '6382', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6383', '1078', '1', 'Hrpelje-Kozina', 'SI.35', 'NULL', '4506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4506', '112', '6383', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6384', '1078', '1', 'Idrija', 'SI.36', 'NULL', '4507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4507', '112', '6384', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6385', '1078', '1', 'Ig', 'SI.37', 'NULL', '4508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4508', '112', '6385', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6386', '1078', '1', 'Ilirska Bistrica', 'SI.38', 'NULL', '4509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4509', '112', '6386', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6387', '1078', '1', 'Ivančna Gorica', 'SI.39', 'NULL', '4510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4510', '112', '6387', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6388', '1078', '1', 'Izola-Isola', 'SI.40', 'NULL', '4511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4511', '112', '6388', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6389', '1078', '1', 'Juršinci', 'SI.42', 'NULL', '4512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4512', '112', '6389', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6390', '1078', '1', 'Kanal', 'SI.44', 'NULL', '4513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4513', '112', '6390', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6391', '1078', '1', 'Kidričevo', 'SI.45', 'NULL', '4514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4514', '112', '6391', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6392', '1078', '1', 'Kobarid', 'SI.46', 'NULL', '4515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4515', '112', '6392', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6393', '1078', '1', 'Kobilje', 'SI.47', 'NULL', '4516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4516', '112', '6393', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6394', '1078', '1', 'Komen', 'SI.49', 'NULL', '4517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4517', '112', '6394', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6395', '1078', '1', 'Koper-Capodistria', 'SI.50', 'NULL', '4518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4518', '112', '6395', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6396', '1078', '1', 'Kozje', 'SI.51', 'NULL', '4519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4519', '112', '6396', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6397', '1078', '1', 'Kranj', 'SI.52', 'NULL', '4520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4520', '112', '6397', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6398', '1078', '1', 'Kranjska Gora', 'SI.53', 'NULL', '4521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4521', '112', '6398', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6399', '1078', '1', 'Krško', 'SI.54', 'NULL', '4522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4522', '112', '6399', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6400', '1078', '1', 'Kungota', 'SI.55', 'NULL', '4523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4523', '112', '6400', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6401', '1078', '1', 'Laško', 'SI.57', 'NULL', '4524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4524', '112', '6401', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6402', '1078', '1', 'Ljubljana', 'SI.61', 'NULL', '4525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4525', '112', '6402', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6403', '1078', '1', 'Ljubno', 'SI.62', 'NULL', '4526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4526', '112', '6403', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6404', '1078', '1', 'Logatec', 'SI.64', 'NULL', '4527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4527', '112', '6404', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6405', '1078', '1', 'Loški Potok', 'SI.66', 'NULL', '4528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4528', '112', '6405', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6406', '1078', '1', 'Lukovica', 'SI.68', 'NULL', '4529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4529', '112', '6406', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6407', '1078', '1', 'Medvode', 'SI.71', 'NULL', '4530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4530', '112', '6407', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6408', '1078', '1', 'Mengeš', 'SI.72', 'NULL', '4531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4531', '112', '6408', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6409', '1078', '1', 'Metlika', 'SI.73', 'NULL', '4532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4532', '112', '6409', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6410', '1078', '1', 'Mežica', 'SI.74', 'NULL', '4533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4533', '112', '6410', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6411', '1078', '1', 'Mislinja', 'SI.76', 'NULL', '4534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4534', '112', '6411', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6412', '1078', '1', 'Moravče', 'SI.77', 'NULL', '4535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4535', '112', '6412', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6413', '1078', '1', 'Moravske Toplice', 'SI.78', 'NULL', '4536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4536', '112', '6413', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6414', '1078', '1', 'Mozirje', 'SI.79', 'NULL', '4537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4537', '112', '6414', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6415', '1078', '1', 'Murska Sobota', 'SI.80', 'NULL', '4538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4538', '112', '6415', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6416', '1078', '1', 'Muta', 'SI.81', 'NULL', '4539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4539', '112', '6416', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6417', '1078', '1', 'Naklo', 'SI.82', 'NULL', '4540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4540', '112', '6417', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6418', '1078', '1', 'Nazarje', 'SI.83', 'NULL', '4541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4541', '112', '6418', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6419', '1078', '1', 'Nova Gorica', 'SI.84', 'NULL', '4542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4542', '112', '6419', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6420', '1078', '1', 'Odranci', 'SI.86', 'NULL', '4543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4543', '112', '6420', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6421', '1078', '1', 'Ormož', 'SI.87', 'NULL', '4544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4544', '112', '6421', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.87» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6422', '1078', '1', 'Osilnica', 'SI.88', 'NULL', '4545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4545', '112', '6422', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.88» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6423', '1078', '1', 'Pesnica', 'SI.89', 'NULL', '4546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4546', '112', '6423', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.89» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6424', '1078', '1', 'Pivka', 'SI.91', 'NULL', '4547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4547', '112', '6424', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.91» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6425', '1078', '1', 'Podčetrtek', 'SI.92', 'NULL', '4548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4548', '112', '6425', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.92» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6426', '1078', '1', 'Postojna', 'SI.94', 'NULL', '4549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4549', '112', '6426', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.94» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6427', '1078', '1', 'Puconci', 'SI.97', 'NULL', '4550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4550', '112', '6427', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.97» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6428', '1078', '1', 'Rače-Fram', 'SI.98', 'NULL', '4551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4551', '112', '6428', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.98» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6429', '1078', '1', 'Radeče', 'SI.99', 'NULL', '4552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4552', '112', '6429', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.99» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6430', '1078', '1', 'Radenci', 'SI.A1', 'NULL', '4553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4553', '112', '6430', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.A1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6431', '1078', '1', 'Radlje ob Dravi', 'SI.A2', 'NULL', '4554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4554', '112', '6431', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.A2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6432', '1078', '1', 'Radovljica', 'SI.A3', 'NULL', '4555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4555', '112', '6432', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.A3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6433', '1078', '1', 'Rogašovci', 'SI.A6', 'NULL', '4556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4556', '112', '6433', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.A6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6434', '1078', '1', 'Rogaška Slatina', 'SI.A7', 'NULL', '4557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4557', '112', '6434', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.A7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6435', '1078', '1', 'Rogatec', 'SI.A8', 'NULL', '4558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4558', '112', '6435', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.A8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6436', '1078', '1', 'Semič', 'SI.B1', 'NULL', '4559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4559', '112', '6436', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.B1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6437', '1078', '1', 'Šenčur', 'SI.B2', 'NULL', '4560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4560', '112', '6437', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.B2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6438', '1078', '1', 'Šentilj', 'SI.B3', 'NULL', '4561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4561', '112', '6438', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.B3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6439', '1078', '1', 'Šentjernej', 'SI.B4', 'NULL', '4562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4562', '112', '6439', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.B4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6440', '1078', '1', 'Sevnica', 'SI.B6', 'NULL', '4563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4563', '112', '6440', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.B6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6441', '1078', '1', 'Sežana', 'SI.B7', 'NULL', '4564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4564', '112', '6441', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.B7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6442', '1078', '1', 'Škocjan', 'SI.B8', 'NULL', '4565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4565', '112', '6442', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.B8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6443', '1078', '1', 'Škofja Loka', 'SI.B9', 'NULL', '4566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4566', '112', '6443', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.B9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6444', '1078', '1', 'Škofljica', 'SI.C1', 'NULL', '4567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4567', '112', '6444', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.C1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6445', '1078', '1', 'Slovenj Gradec', 'SI.C2', 'NULL', '4568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4568', '112', '6445', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.C2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6446', '1078', '1', 'Slovenska Konjice', 'SI.C4', 'NULL', '4569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4569', '112', '6446', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.C4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6447', '1078', '1', 'Šmarje pri Jelšah', 'SI.C5', 'NULL', '4570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4570', '112', '6447', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.C5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6448', '1078', '1', 'Šmartno ob Paki', 'SI.C6', 'NULL', '4571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4571', '112', '6448', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.C6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6449', '1078', '1', 'Šoštanj', 'SI.C7', 'NULL', '4572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4572', '112', '6449', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.C7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6450', '1078', '1', 'Starše', 'SI.C8', 'NULL', '4573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4573', '112', '6450', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.C8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6451', '1078', '1', 'Štore', 'SI.C9', 'NULL', '4574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4574', '112', '6451', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.C9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6452', '1078', '1', 'Sveti Jurij', 'SI.D1', 'NULL', '4575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4575', '112', '6452', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.D1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6453', '1078', '1', 'Tolmin', 'SI.D2', 'NULL', '4576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4576', '112', '6453', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.D2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6454', '1078', '1', 'Trbovlje', 'SI.D3', 'NULL', '4577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4577', '112', '6454', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.D3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6455', '1078', '1', 'Trebnje', 'SI.D4', 'NULL', '4578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4578', '112', '6455', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.D4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6456', '1078', '1', 'Tržič', 'SI.D5', 'NULL', '4579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4579', '112', '6456', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.D5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6457', '1078', '1', 'Turnišče', 'SI.D6', 'NULL', '4580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4580', '112', '6457', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.D6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6458', '1078', '1', 'Velenje', 'SI.D7', 'NULL', '4581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4581', '112', '6458', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.D7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6459', '1078', '1', 'Velike Lašče', 'SI.D8', 'NULL', '4582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4582', '112', '6459', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.D8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6460', '1078', '1', 'Vipava', 'SI.E1', 'NULL', '4583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4583', '112', '6460', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.E1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6461', '1078', '1', 'Vitanje', 'SI.E2', 'NULL', '4584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4584', '112', '6461', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.E2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6462', '1078', '1', 'Vodice', 'SI.E3', 'NULL', '4585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4585', '112', '6462', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.E3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6463', '1078', '1', 'Vrhnika', 'SI.E5', 'NULL', '4586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4586', '112', '6463', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.E5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6464', '1078', '1', 'Vuzenica', 'SI.E6', 'NULL', '4587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4587', '112', '6464', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.E6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6465', '1078', '1', 'Zagorje ob Savi', 'SI.E7', 'NULL', '4588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4588', '112', '6465', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.E7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6466', '1078', '1', 'Zavrč', 'SI.E9', 'NULL', '4589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4589', '112', '6466', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.E9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6467', '1078', '1', 'Železniki', 'SI.F1', 'NULL', '4590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4590', '112', '6467', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.F1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6468', '1078', '1', 'Žiri', 'SI.F2', 'NULL', '4591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4591', '112', '6468', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.F2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6469', '1078', '1', 'Zreče', 'SI.F3', 'NULL', '4592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4592', '112', '6469', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.F3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6470', '1078', '1', 'Benedikt', 'SI.F4', 'NULL', '4593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4593', '112', '6470', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.F4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6471', '1078', '1', 'Bistrica ob Sotli', 'SI.F5', 'NULL', '4594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4594', '112', '6471', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.F5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6472', '1078', '1', 'Bloke', 'SI.F6', 'NULL', '4595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4595', '112', '6472', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.F6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6473', '1078', '1', 'Braslovče', 'SI.F7', 'NULL', '4596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4596', '112', '6473', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.F7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6474', '1078', '1', 'Cankova', 'SI.F8', 'NULL', '4597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4597', '112', '6474', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.F8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6475', '1078', '1', 'Cerkvenjak', 'SI.F9', 'NULL', '4598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4598', '112', '6475', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.F9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6476', '1078', '1', 'Destrnik', 'SI.G1', 'NULL', '4599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4599', '112', '6476', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.G1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6477', '1078', '1', 'Dobje', 'SI.G2', 'NULL', '4600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4600', '112', '6477', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.G2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6478', '1078', '1', 'Dobrna', 'SI.G3', 'NULL', '4601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4601', '112', '6478', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.G3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6479', '1078', '1', 'Dobrova-Horjul-Polhov Gradec', 'SI.G4', 'NULL', '4602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4602', '112', '6479', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.G4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6480', '1078', '1', 'Dobrovnik-Dobronak', 'SI.G5', 'NULL', '4603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4603', '112', '6480', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.G5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6481', '1078', '1', 'Dolenjske Toplice', 'SI.G6', 'NULL', '4604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4604', '112', '6481', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.G6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6482', '1078', '1', 'Domžale', 'SI.G7', 'NULL', '4605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4605', '112', '6482', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.G7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6483', '1078', '1', 'Grad', 'SI.G8', 'NULL', '4606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4606', '112', '6483', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.G8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6484', '1078', '1', 'Hajdina', 'SI.G9', 'NULL', '4607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4607', '112', '6484', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.G9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6485', '1078', '1', 'Hoče-Slivnica', 'SI.H1', 'NULL', '4608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4608', '112', '6485', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.H1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6486', '1078', '1', 'Hodoš-Hodos', 'SI.H2', 'NULL', '4609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4609', '112', '6486', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.H2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6487', '1078', '1', 'Horjul', 'SI.H3', 'NULL', '4610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4610', '112', '6487', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.H3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6488', '1078', '1', 'Jesenice', 'SI.H4', 'NULL', '4611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4611', '112', '6488', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.H4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6489', '1078', '1', 'Jezersko', 'SI.H5', 'NULL', '4612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4612', '112', '6489', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.H5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6490', '1078', '1', 'Kamnik', 'SI.H6', 'NULL', '4613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4613', '112', '6490', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.H6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6491', '1078', '1', 'Kočevje', 'SI.H7', 'NULL', '4614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4614', '112', '6491', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.H7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6492', '1078', '1', 'Komenda', 'SI.H8', 'NULL', '4615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4615', '112', '6492', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.H8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6493', '1078', '1', 'Kostel', 'SI.H9', 'NULL', '4616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4616', '112', '6493', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.H9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6494', '1078', '1', 'Križevci', 'SI.I1', 'NULL', '4617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4617', '112', '6494', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.I1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6495', '1078', '1', 'Kuzma', 'SI.I2', 'NULL', '4618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4618', '112', '6495', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.I2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6496', '1078', '1', 'Lenart', 'SI.I3', 'NULL', '4619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4619', '112', '6496', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.I3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6497', '1078', '1', 'Litija', 'SI.I5', 'NULL', '4620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4620', '112', '6497', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.I5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6498', '1078', '1', 'Ljutomer', 'SI.I6', 'NULL', '4621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4621', '112', '6498', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.I6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6499', '1078', '1', 'Loška Dolina', 'SI.I7', 'NULL', '4622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4622', '112', '6499', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.I7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6500', '1078', '1', 'Lovrenc na Pohorju', 'SI.I8', 'NULL', '4623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4623', '112', '6500', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.I8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6501', '1078', '1', 'Luče', 'SI.I9', 'NULL', '4624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4624', '112', '6501', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.I9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6502', '1078', '1', 'Majšperk', 'SI.J1', 'NULL', '4625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4625', '112', '6502', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.J1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6503', '1078', '1', 'Maribor', 'SI.J2', 'NULL', '4626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4626', '112', '6503', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.J2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6504', '1078', '1', 'Markovci', 'SI.J3', 'NULL', '4627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4627', '112', '6504', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.J3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6505', '1078', '1', 'Miklavž na Dravskem Polju', 'SI.J4', 'NULL', '4628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4628', '112', '6505', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.J4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6506', '1078', '1', 'Miren-Kostanjevica', 'SI.J5', 'NULL', '4629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4629', '112', '6506', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.J5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6507', '1078', '1', 'Mirna Peč', 'SI.J6', 'NULL', '4630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4630', '112', '6507', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.J6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6508', '1078', '1', 'Novo Mesto', 'SI.J7', 'NULL', '4631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4631', '112', '6508', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.J7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6509', '1078', '1', 'Oplotnica', 'SI.J8', 'NULL', '4632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4632', '112', '6509', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.J8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6510', '1078', '1', 'Piran-Pirano', 'SI.J9', 'NULL', '4633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4633', '112', '6510', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.J9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6511', '1078', '1', 'Podlehnik', 'SI.K1', 'NULL', '4634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4634', '112', '6511', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.K1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6512', '1078', '1', 'Polzela', 'SI.K3', 'NULL', '4635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4635', '112', '6512', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.K3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6513', '1078', '1', 'Prebold', 'SI.K4', 'NULL', '4636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4636', '112', '6513', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.K4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6514', '1078', '1', 'Preddvor', 'SI.K5', 'NULL', '4637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4637', '112', '6514', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.K5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6515', '1078', '1', 'Prevalje', 'SI.K6', 'NULL', '4638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4638', '112', '6515', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.K6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6516', '1078', '1', 'Ptuj', 'SI.K7', 'NULL', '4639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4639', '112', '6516', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.K7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6517', '1078', '1', 'Ravne na Koroškem', 'SI.K8', 'NULL', '4640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4640', '112', '6517', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.K8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6518', '1078', '1', 'Razkrižje', 'SI.K9', 'NULL', '4641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4641', '112', '6518', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.K9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6519', '1078', '1', 'Ribnica', 'SI.L1', 'NULL', '4642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4642', '112', '6519', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.L1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6520', '1078', '1', 'Ribnica na Pohorju', 'SI.L2', 'NULL', '4643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4643', '112', '6520', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.L2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6521', '1078', '1', 'Ruše', 'SI.L3', 'NULL', '4644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4644', '112', '6521', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.L3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6522', '1078', '1', 'Selnica ob Dravi', 'SI.L5', 'NULL', '4645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4645', '112', '6522', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.L5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6523', '1078', '1', 'Šempeter-Vrtojba', 'SI.L6', 'NULL', '4646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4646', '112', '6523', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.L6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6524', '1078', '1', 'Šentjur pri Celju', 'SI.L7', 'NULL', '4647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4647', '112', '6524', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.L7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6525', '1078', '1', 'Slovenska Bistrica', 'SI.L8', 'NULL', '4648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4648', '112', '6525', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.L8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6526', '1078', '1', 'Šmartno pri Litiji', 'SI.L9', 'NULL', '4649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4649', '112', '6526', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.L9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6527', '1078', '1', 'Sodražica', 'SI.M1', 'NULL', '4650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4650', '112', '6527', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.M1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6528', '1078', '1', 'Solčava', 'SI.M2', 'NULL', '4651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4651', '112', '6528', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.M2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6529', '1078', '1', 'Sveta Ana', 'SI.M3', 'NULL', '4652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4652', '112', '6529', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.M3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6530', '1078', '1', 'Sveti Andraž v Slovenskih Goricah', 'SI.M4', 'NULL', '4653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4653', '112', '6530', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.M4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6531', '1078', '1', 'Tabor', 'SI.M5', 'NULL', '4654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4654', '112', '6531', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.M5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6532', '1078', '1', 'Trzin', 'SI.M8', 'NULL', '4655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4655', '112', '6532', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.M8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6533', '1078', '1', 'Velika Polana', 'SI.M9', 'NULL', '4656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4656', '112', '6533', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.M9» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6534', '1078', '1', 'Veržej', 'SI.N1', 'NULL', '4657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4657', '112', '6534', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.N1» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6535', '1078', '1', 'Videm', 'SI.N2', 'NULL', '4658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4658', '112', '6535', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.N2» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6536', '1078', '1', 'Vojnik', 'SI.N3', 'NULL', '4659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4659', '112', '6536', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.N3» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6537', '1078', '1', 'Vransko', 'SI.N4', 'NULL', '4660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4660', '112', '6537', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.N4» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6538', '1078', '1', 'Žalec', 'SI.N5', 'NULL', '4661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4661', '112', '6538', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.N5» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6539', '1078', '1', 'Žetale', 'SI.N6', 'NULL', '4662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4662', '112', '6539', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.N6» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6540', '1078', '1', 'Žirovnica', 'SI.N7', 'NULL', '4663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4663', '112', '6540', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.N7» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6541', '1078', '1', 'Žužemberk', 'SI.N8', 'NULL', '4664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4664', '112', '6541', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SI.N8» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6542', '1078', '1', 'Slovakia (general)', 'SK.00', 'NULL', '4665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4665', '112', '6542', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SK.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6543', '1078', '1', 'Banskobystrický', 'SK.01', 'NULL', '4666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4666', '112', '6543', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SK.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6544', '1078', '1', 'Bratislavský', 'SK.02', 'NULL', '4667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4667', '112', '6544', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SK.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6545', '1078', '1', 'Košický', 'SK.03', 'NULL', '4668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4668', '112', '6545', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SK.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6546', '1078', '1', 'Nitriansky', 'SK.04', 'NULL', '4669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4669', '112', '6546', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SK.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6547', '1078', '1', 'Prešovský', 'SK.05', 'NULL', '4670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4670', '112', '6547', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SK.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6548', '1078', '1', 'Trenčiansky', 'SK.06', 'NULL', '4671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4671', '112', '6548', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SK.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6549', '1078', '1', 'Trnavský', 'SK.07', 'NULL', '4672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4672', '112', '6549', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SK.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6550', '1078', '1', 'Žilinský', 'SK.08', 'NULL', '4673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4673', '112', '6550', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SK.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6551', '1078', '1', 'Sierra Leone (general)', 'SL.00', 'NULL', '4674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4674', '112', '6551', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SL.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6552', '1078', '1', 'Eastern Province', 'SL.01', 'NULL', '4675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4675', '112', '6552', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SL.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6553', '1078', '1', 'Northern Province', 'SL.02', 'NULL', '4676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4676', '112', '6553', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SL.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6554', '1078', '1', 'Southern Province', 'SL.03', 'NULL', '4677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4677', '112', '6554', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SL.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6555', '1078', '1', 'Western Area', 'SL.04', 'NULL', '4678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4678', '112', '6555', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SL.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6556', '1078', '1', 'San Marino (general)', 'SM.00', 'NULL', '4679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4679', '112', '6556', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6557', '1078', '1', 'Acquaviva', 'SM.01', 'NULL', '4680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4680', '112', '6557', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6558', '1078', '1', 'Chiesanuova', 'SM.02', 'NULL', '4681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4681', '112', '6558', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6559', '1078', '1', 'Domagnano', 'SM.03', 'NULL', '4682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4682', '112', '6559', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6560', '1078', '1', 'Faetano', 'SM.04', 'NULL', '4683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4683', '112', '6560', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6561', '1078', '1', 'Fiorentino', 'SM.05', 'NULL', '4684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4684', '112', '6561', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SM.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6562', '1078', '1', 'Borgo Maggiore', 'SM.06', 'NULL', '4685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4685', '112', '6562', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SM.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6563', '1078', '1', 'San Marino', 'SM.07', 'NULL', '4686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4686', '112', '6563', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SM.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6564', '1078', '1', 'Montegiardino', 'SM.08', 'NULL', '4687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4687', '112', '6564', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SM.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6565', '1078', '1', 'Serravalle', 'SM.09', 'NULL', '4688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4688', '112', '6565', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SM.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6566', '1078', '1', 'Senegal (general)', 'SN.00', 'NULL', '4689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4689', '112', '6566', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6567', '1078', '1', 'Dakar', 'SN.01', 'NULL', '4690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4690', '112', '6567', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6568', '1078', '1', 'Diourbel', 'SN.03', 'NULL', '4691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4691', '112', '6568', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6569', '1078', '1', 'Saint-Louis', 'SN.04', 'NULL', '4692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4692', '112', '6569', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6570', '1078', '1', 'Tambacounda', 'SN.05', 'NULL', '4693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4693', '112', '6570', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6571', '1078', '1', 'Thiès', 'SN.07', 'NULL', '4694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4694', '112', '6571', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6572', '1078', '1', 'Louga', 'SN.08', 'NULL', '4695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4695', '112', '6572', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6573', '1078', '1', 'Fatick', 'SN.09', 'NULL', '4696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4696', '112', '6573', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6574', '1078', '1', 'Kaolack', 'SN.10', 'NULL', '4697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4697', '112', '6574', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6575', '1078', '1', 'Kolda Region', 'SN.11', 'NULL', '4698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4698', '112', '6575', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6576', '1078', '1', 'Ziguinchor', 'SN.12', 'NULL', '4699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4699', '112', '6576', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6577', '1078', '1', 'Louga', 'SN.13', 'NULL', '4700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4700', '112', '6577', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6578', '1078', '1', 'Saint-Louis', 'SN.14', 'NULL', '4701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4701', '112', '6578', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6579', '1078', '1', 'Matam', 'SN.15', 'NULL', '4702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4702', '112', '6579', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SN.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6580', '1078', '1', 'Somalia (general)', 'SO.00', 'NULL', '4703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4703', '112', '6580', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6581', '1078', '1', 'Bakool', 'SO.01', 'NULL', '4704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4704', '112', '6581', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6582', '1078', '1', 'Banaadir', 'SO.02', 'NULL', '4705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4705', '112', '6582', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6583', '1078', '1', 'Bari', 'SO.03', 'NULL', '4706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4706', '112', '6583', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6584', '1078', '1', 'Bay', 'SO.04', 'NULL', '4707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4707', '112', '6584', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6585', '1078', '1', 'Galguduud', 'SO.05', 'NULL', '4708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4708', '112', '6585', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6586', '1078', '1', 'Gedo', 'SO.06', 'NULL', '4709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4709', '112', '6586', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6587', '1078', '1', 'Hiiraan', 'SO.07', 'NULL', '4710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4710', '112', '6587', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6588', '1078', '1', 'Middle Juba', 'SO.08', 'NULL', '4711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4711', '112', '6588', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6589', '1078', '1', 'Lower Juba', 'SO.09', 'NULL', '4712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4712', '112', '6589', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6590', '1078', '1', 'Mudug', 'SO.10', 'NULL', '4713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4713', '112', '6590', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6591', '1078', '1', 'Sanaag', 'SO.12', 'NULL', '4714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4714', '112', '6591', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6592', '1078', '1', 'Middle Shabele', 'SO.13', 'NULL', '4715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4715', '112', '6592', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6593', '1078', '1', 'Shabeellaha Hoose', 'SO.14', 'NULL', '4716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4716', '112', '6593', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6594', '1078', '1', '(SO17)', 'SO.17', 'NULL', '4717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4717', '112', '6594', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6595', '1078', '1', 'Nugaal', 'SO.18', 'NULL', '4718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4718', '112', '6595', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6596', '1078', '1', 'Togdheer', 'SO.19', 'NULL', '4719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4719', '112', '6596', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6597', '1078', '1', 'Woqooyi Galbeed', 'SO.20', 'NULL', '4720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4720', '112', '6597', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6598', '1078', '1', 'Awdal', 'SO.21', 'NULL', '4721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4721', '112', '6598', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6599', '1078', '1', 'Sool', 'SO.22', 'NULL', '4722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4722', '112', '6599', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SO.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6600', '1078', '1', 'Suriname (general)', 'SR.00', 'NULL', '4723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4723', '112', '6600', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6601', '1078', '1', 'Brokopondo', 'SR.10', 'NULL', '4724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4724', '112', '6601', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6602', '1078', '1', 'Commewijne', 'SR.11', 'NULL', '4725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4725', '112', '6602', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6603', '1078', '1', 'Coronie', 'SR.12', 'NULL', '4726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4726', '112', '6603', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6604', '1078', '1', 'Marowijne', 'SR.13', 'NULL', '4727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4727', '112', '6604', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6605', '1078', '1', 'Nickerie', 'SR.14', 'NULL', '4728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4728', '112', '6605', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6606', '1078', '1', 'Para', 'SR.15', 'NULL', '4729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4729', '112', '6606', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6607', '1078', '1', 'Paramaribo', 'SR.16', 'NULL', '4730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4730', '112', '6607', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6608', '1078', '1', 'Saramacca', 'SR.17', 'NULL', '4731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4731', '112', '6608', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6609', '1078', '1', 'Sipaliwini', 'SR.18', 'NULL', '4732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4732', '112', '6609', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6610', '1078', '1', 'Wanica', 'SR.19', 'NULL', '4733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4733', '112', '6610', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SR.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6611', '1078', '1', 'Príncipe', 'ST.00', 'NULL', '4734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4734', '112', '6611', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ST.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6612', '1078', '1', 'Príncipe', 'ST.01', 'NULL', '4735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4735', '112', '6612', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ST.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6613', '1078', '1', 'São Tomé', 'ST.02', 'NULL', '4736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4736', '112', '6613', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ST.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6614', '1078', '1', 'El Salvador (general)', 'SV.00', 'NULL', '4737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4737', '112', '6614', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6615', '1078', '1', 'Ahuachapán', 'SV.01', 'NULL', '4738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4738', '112', '6615', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6616', '1078', '1', 'Cabañas', 'SV.02', 'NULL', '4739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4739', '112', '6616', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6617', '1078', '1', 'Chalatenango', 'SV.03', 'NULL', '4740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4740', '112', '6617', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6618', '1078', '1', 'Cuscatlán', 'SV.04', 'NULL', '4741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4741', '112', '6618', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6619', '1078', '1', 'La Libertad', 'SV.05', 'NULL', '4742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4742', '112', '6619', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6620', '1078', '1', 'La Paz', 'SV.06', 'NULL', '4743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4743', '112', '6620', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6621', '1078', '1', 'La Unión', 'SV.07', 'NULL', '4744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4744', '112', '6621', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6622', '1078', '1', 'Morazán', 'SV.08', 'NULL', '4745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4745', '112', '6622', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6623', '1078', '1', 'San Miguel', 'SV.09', 'NULL', '4746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4746', '112', '6623', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6624', '1078', '1', 'San Salvador', 'SV.10', 'NULL', '4747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4747', '112', '6624', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6625', '1078', '1', 'Santa Ana', 'SV.11', 'NULL', '4748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4748', '112', '6625', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6626', '1078', '1', 'San Vicente', 'SV.12', 'NULL', '4749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4749', '112', '6626', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6627', '1078', '1', 'Sonsonate', 'SV.13', 'NULL', '4750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4750', '112', '6627', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6628', '1078', '1', 'Usulután', 'SV.14', 'NULL', '4751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4751', '112', '6628', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SV.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6629', '1078', '1', 'Syria (general)', 'SY.00', 'NULL', '4752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4752', '112', '6629', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6630', '1078', '1', 'Al-Hasakah', 'SY.01', 'NULL', '4753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4753', '112', '6630', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6631', '1078', '1', 'Latakia', 'SY.02', 'NULL', '4754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4754', '112', '6631', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6632', '1078', '1', 'Quneitra', 'SY.03', 'NULL', '4755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4755', '112', '6632', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6633', '1078', '1', 'Ar-Raqqah', 'SY.04', 'NULL', '4756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4756', '112', '6633', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6634', '1078', '1', 'As-Suwayda', 'SY.05', 'NULL', '4757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4757', '112', '6634', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6635', '1078', '1', 'Daraa', 'SY.06', 'NULL', '4758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4758', '112', '6635', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6636', '1078', '1', 'Deir ez-Zor', 'SY.07', 'NULL', '4759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4759', '112', '6636', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6637', '1078', '1', 'Rif-dimashq', 'SY.08', 'NULL', '4760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4760', '112', '6637', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6638', '1078', '1', 'Aleppo', 'SY.09', 'NULL', '4761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4761', '112', '6638', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6639', '1078', '1', 'Hama Governorate', 'SY.10', 'NULL', '4762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4762', '112', '6639', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6640', '1078', '1', 'Homs', 'SY.11', 'NULL', '4763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4763', '112', '6640', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6641', '1078', '1', 'Idlib', 'SY.12', 'NULL', '4764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4764', '112', '6641', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6642', '1078', '1', 'Damascus City', 'SY.13', 'NULL', '4765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4765', '112', '6642', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6643', '1078', '1', 'Tartus', 'SY.14', 'NULL', '4766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4766', '112', '6643', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SY.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6644', '1078', '1', 'Swaziland (general)', 'SZ.00', 'NULL', '4767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4767', '112', '6644', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SZ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6645', '1078', '1', 'Hhohho', 'SZ.01', 'NULL', '4768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4768', '112', '6645', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SZ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6646', '1078', '1', 'Lubombo', 'SZ.02', 'NULL', '4769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4769', '112', '6646', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SZ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6647', '1078', '1', 'Manzini', 'SZ.03', 'NULL', '4770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4770', '112', '6647', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SZ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6648', '1078', '1', 'Shiselweni', 'SZ.04', 'NULL', '4771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4771', '112', '6648', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «SZ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6649', '1078', '1', 'Turks and Caicos Islands (general)', 'TC.00', 'NULL', '4772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4772', '112', '6649', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TC.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6650', '1078', '1', 'Chad (general)', 'TD.00', 'NULL', '4773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4773', '112', '6650', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6651', '1078', '1', 'Batha', 'TD.01', 'NULL', '4774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4774', '112', '6651', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6652', '1078', '1', 'Biltine', 'TD.02', 'NULL', '4775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4775', '112', '6652', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6653', '1078', '1', 'Borkou-Ennedi-Tibesti', 'TD.03', 'NULL', '4776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4776', '112', '6653', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6654', '1078', '1', 'Chari-Baguirmi', 'TD.04', 'NULL', '4777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4777', '112', '6654', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6655', '1078', '1', 'Guéra', 'TD.05', 'NULL', '4778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4778', '112', '6655', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6656', '1078', '1', 'Kanem', 'TD.06', 'NULL', '4779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4779', '112', '6656', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6657', '1078', '1', 'Lac', 'TD.07', 'NULL', '4780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4780', '112', '6657', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6658', '1078', '1', 'Logone Occidental', 'TD.08', 'NULL', '4781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4781', '112', '6658', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6659', '1078', '1', 'Logone Oriental', 'TD.09', 'NULL', '4782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4782', '112', '6659', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6660', '1078', '1', 'Mayo-Kébbi', 'TD.10', 'NULL', '4783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4783', '112', '6660', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6661', '1078', '1', 'Moyen-Chari', 'TD.11', 'NULL', '4784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4784', '112', '6661', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6662', '1078', '1', 'Ouaddaï', 'TD.12', 'NULL', '4785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4785', '112', '6662', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6663', '1078', '1', 'Salamat', 'TD.13', 'NULL', '4786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4786', '112', '6663', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6664', '1078', '1', 'Tandjilé', 'TD.14', 'NULL', '4787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4787', '112', '6664', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TD.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6665', '1078', '1', 'District de Saint-Paul-et-Amsterdam', 'TF.01', 'NULL', '4788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4788', '112', '6665', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TF.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6666', '1078', '1', 'District de Crozet', 'TF.02', 'NULL', '4789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4789', '112', '6666', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TF.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6667', '1078', '1', 'District de Kerguelen', 'TF.03', 'NULL', '4790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4790', '112', '6667', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TF.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6668', '1078', '1', 'District de Terre Adélie', 'TF.04', 'NULL', '4791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4791', '112', '6668', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TF.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6669', '1078', '1', 'District des Îles Éparses', 'TF.05', 'NULL', '4792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4792', '112', '6669', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TF.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6670', '1078', '1', 'Togo (general)', 'TG.00', 'NULL', '4793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4793', '112', '6670', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6671', '1078', '1', 'Amlame', 'TG.01', 'NULL', '4794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4794', '112', '6671', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6672', '1078', '1', 'Aneho', 'TG.02', 'NULL', '4795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4795', '112', '6672', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6673', '1078', '1', 'Atakpame', 'TG.03', 'NULL', '4796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4796', '112', '6673', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6674', '1078', '1', 'Bafilo', 'TG.04', 'NULL', '4797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4797', '112', '6674', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6675', '1078', '1', 'Bassar', 'TG.05', 'NULL', '4798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4798', '112', '6675', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6676', '1078', '1', 'Dapaong', 'TG.06', 'NULL', '4799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4799', '112', '6676', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6677', '1078', '1', 'Kante', 'TG.07', 'NULL', '4800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4800', '112', '6677', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6678', '1078', '1', 'Klouto', 'TG.08', 'NULL', '4801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4801', '112', '6678', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6679', '1078', '1', 'Lama-Kara', 'TG.09', 'NULL', '4802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4802', '112', '6679', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6680', '1078', '1', 'Lome', 'TG.10', 'NULL', '4803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4803', '112', '6680', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6681', '1078', '1', 'Mango', 'TG.11', 'NULL', '4804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4804', '112', '6681', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6682', '1078', '1', 'Niamtougou', 'TG.12', 'NULL', '4805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4805', '112', '6682', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6683', '1078', '1', 'Notse', 'TG.13', 'NULL', '4806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4806', '112', '6683', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6684', '1078', '1', 'Kpagouda', 'TG.14', 'NULL', '4807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4807', '112', '6684', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6685', '1078', '1', 'Badou', 'TG.15', 'NULL', '4808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4808', '112', '6685', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6686', '1078', '1', 'Sotouboua', 'TG.16', 'NULL', '4809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4809', '112', '6686', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6687', '1078', '1', 'Tabligbo', 'TG.17', 'NULL', '4810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4810', '112', '6687', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6688', '1078', '1', 'Tsevie', 'TG.18', 'NULL', '4811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4811', '112', '6688', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6689', '1078', '1', 'Tchamba', 'TG.19', 'NULL', '4812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4812', '112', '6689', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6690', '1078', '1', 'Tchaoudjo', 'TG.20', 'NULL', '4813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4813', '112', '6690', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6691', '1078', '1', 'Vogan', 'TG.21', 'NULL', '4814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4814', '112', '6691', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6692', '1078', '1', 'Centrale', 'TG.22', 'NULL', '4815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4815', '112', '6692', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6693', '1078', '1', 'Kara', 'TG.23', 'NULL', '4816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4816', '112', '6693', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6694', '1078', '1', 'Maritime', 'TG.24', 'NULL', '4817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4817', '112', '6694', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6695', '1078', '1', 'Plateaux', 'TG.25', 'NULL', '4818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4818', '112', '6695', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6696', '1078', '1', 'Savanes', 'TG.26', 'NULL', '4819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4819', '112', '6696', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TG.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6697', '1078', '1', 'Thailand (general)', 'TH.00', 'NULL', '4820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4820', '112', '6697', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6698', '1078', '1', 'Mae Hong Son', 'TH.01', 'NULL', '4821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4821', '112', '6698', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6699', '1078', '1', 'Chiang Mai', 'TH.02', 'NULL', '4822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4822', '112', '6699', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6700', '1078', '1', 'Chiang Rai', 'TH.03', 'NULL', '4823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4823', '112', '6700', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6701', '1078', '1', 'Nan', 'TH.04', 'NULL', '4824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4824', '112', '6701', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6702', '1078', '1', 'Lamphun', 'TH.05', 'NULL', '4825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4825', '112', '6702', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6703', '1078', '1', 'Lampang', 'TH.06', 'NULL', '4826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4826', '112', '6703', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6704', '1078', '1', 'Phrae', 'TH.07', 'NULL', '4827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4827', '112', '6704', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6705', '1078', '1', 'Tak', 'TH.08', 'NULL', '4828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4828', '112', '6705', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6706', '1078', '1', 'Sukhothai', 'TH.09', 'NULL', '4829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4829', '112', '6706', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6707', '1078', '1', 'Uttaradit', 'TH.10', 'NULL', '4830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4830', '112', '6707', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6708', '1078', '1', 'Kamphaeng Phet', 'TH.11', 'NULL', '4831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4831', '112', '6708', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6709', '1078', '1', 'Phitsanulok', 'TH.12', 'NULL', '4832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4832', '112', '6709', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6710', '1078', '1', 'Phichit', 'TH.13', 'NULL', '4833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4833', '112', '6710', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6711', '1078', '1', 'Phetchabun', 'TH.14', 'NULL', '4834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4834', '112', '6711', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6712', '1078', '1', 'Uthai Thani', 'TH.15', 'NULL', '4835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4835', '112', '6712', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6713', '1078', '1', 'Nakhon Sawan', 'TH.16', 'NULL', '4836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4836', '112', '6713', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6714', '1078', '1', 'Nong Khai', 'TH.17', 'NULL', '4837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4837', '112', '6714', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6715', '1078', '1', 'Loei', 'TH.18', 'NULL', '4838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4838', '112', '6715', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6716', '1078', '1', 'Sakon Nakhon', 'TH.20', 'NULL', '4839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4839', '112', '6716', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6717', '1078', '1', 'Nakhon Phanom', 'TH.21', 'NULL', '4840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4840', '112', '6717', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6718', '1078', '1', 'Khon Kaen', 'TH.22', 'NULL', '4841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4841', '112', '6718', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6719', '1078', '1', 'Kalasin', 'TH.23', 'NULL', '4842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4842', '112', '6719', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6720', '1078', '1', 'Maha Sarakham', 'TH.24', 'NULL', '4843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4843', '112', '6720', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6721', '1078', '1', 'Roi Et', 'TH.25', 'NULL', '4844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4844', '112', '6721', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6722', '1078', '1', 'Chaiyaphum', 'TH.26', 'NULL', '4845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4845', '112', '6722', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6723', '1078', '1', 'Nakhon Ratchasima', 'TH.27', 'NULL', '4846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4846', '112', '6723', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6724', '1078', '1', 'Buriram', 'TH.28', 'NULL', '4847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4847', '112', '6724', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6725', '1078', '1', 'Surin', 'TH.29', 'NULL', '4848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4848', '112', '6725', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6726', '1078', '1', 'Sisaket', 'TH.30', 'NULL', '4849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4849', '112', '6726', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6727', '1078', '1', 'Narathiwat', 'TH.31', 'NULL', '4850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4850', '112', '6727', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6728', '1078', '1', 'Chai Nat', 'TH.32', 'NULL', '4851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4851', '112', '6728', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6729', '1078', '1', 'Sing Buri', 'TH.33', 'NULL', '4852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4852', '112', '6729', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6730', '1078', '1', 'Lop Buri', 'TH.34', 'NULL', '4853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4853', '112', '6730', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6731', '1078', '1', 'Ang Thong', 'TH.35', 'NULL', '4854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4854', '112', '6731', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6732', '1078', '1', 'Phra Nakhon Si Ayutthaya', 'TH.36', 'NULL', '4855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4855', '112', '6732', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6733', '1078', '1', 'Sara Buri', 'TH.37', 'NULL', '4856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4856', '112', '6733', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6734', '1078', '1', 'Nonthaburi', 'TH.38', 'NULL', '4857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4857', '112', '6734', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6735', '1078', '1', 'Pathum Thani', 'TH.39', 'NULL', '4858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4858', '112', '6735', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6736', '1078', '1', 'Phayao', 'TH.41', 'NULL', '4859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4859', '112', '6736', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6737', '1078', '1', 'Samut Prakan', 'TH.42', 'NULL', '4860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4860', '112', '6737', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6738', '1078', '1', 'Nakhon Nayok', 'TH.43', 'NULL', '4861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4861', '112', '6738', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6739', '1078', '1', 'Chachoengsao', 'TH.44', 'NULL', '4862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4862', '112', '6739', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6740', '1078', '1', 'Chon Buri', 'TH.46', 'NULL', '4863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4863', '112', '6740', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6741', '1078', '1', 'Rayong', 'TH.47', 'NULL', '4864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4864', '112', '6741', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6742', '1078', '1', 'Chanthaburi', 'TH.48', 'NULL', '4865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4865', '112', '6742', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6743', '1078', '1', 'Trat', 'TH.49', 'NULL', '4866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4866', '112', '6743', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6744', '1078', '1', 'Kanchanaburi', 'TH.50', 'NULL', '4867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4867', '112', '6744', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6745', '1078', '1', 'Suphan Buri', 'TH.51', 'NULL', '4868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4868', '112', '6745', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6746', '1078', '1', 'Ratchaburi', 'TH.52', 'NULL', '4869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4869', '112', '6746', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6747', '1078', '1', 'Nakhon Pathom', 'TH.53', 'NULL', '4870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4870', '112', '6747', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6748', '1078', '1', 'Samut Songkhram', 'TH.54', 'NULL', '4871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4871', '112', '6748', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6749', '1078', '1', 'Samut Sakhon', 'TH.55', 'NULL', '4872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4872', '112', '6749', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6750', '1078', '1', 'Phetchaburi', 'TH.56', 'NULL', '4873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4873', '112', '6750', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6751', '1078', '1', 'Prachuap Khiri Khan', 'TH.57', 'NULL', '4874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4874', '112', '6751', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6752', '1078', '1', 'Chumphon', 'TH.58', 'NULL', '4875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4875', '112', '6752', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6753', '1078', '1', 'Ranong', 'TH.59', 'NULL', '4876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4876', '112', '6753', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6754', '1078', '1', 'Surat Thani', 'TH.60', 'NULL', '4877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4877', '112', '6754', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6755', '1078', '1', 'Phangnga', 'TH.61', 'NULL', '4878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4878', '112', '6755', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6756', '1078', '1', 'Phuket', 'TH.62', 'NULL', '4879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4879', '112', '6756', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6757', '1078', '1', 'Krabi', 'TH.63', 'NULL', '4880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4880', '112', '6757', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6758', '1078', '1', 'Nakhon Si Thammarat', 'TH.64', 'NULL', '4881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4881', '112', '6758', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6759', '1078', '1', 'Trang', 'TH.65', 'NULL', '4882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4882', '112', '6759', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6760', '1078', '1', 'Phatthalung', 'TH.66', 'NULL', '4883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4883', '112', '6760', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6761', '1078', '1', 'Satun', 'TH.67', 'NULL', '4884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4884', '112', '6761', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6762', '1078', '1', 'Songkhla', 'TH.68', 'NULL', '4885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4885', '112', '6762', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6763', '1078', '1', 'Pattani', 'TH.69', 'NULL', '4886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4886', '112', '6763', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6764', '1078', '1', 'Yala', 'TH.70', 'NULL', '4887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4887', '112', '6764', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6765', '1078', '1', 'Yasothon', 'TH.72', 'NULL', '4888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4888', '112', '6765', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6766', '1078', '1', 'Nakhon Phanom', 'TH.73', 'NULL', '4889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4889', '112', '6766', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6767', '1078', '1', 'Prachin Buri', 'TH.74', 'NULL', '4890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4890', '112', '6767', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6768', '1078', '1', 'Ubon Ratchathani', 'TH.75', 'NULL', '4891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4891', '112', '6768', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.75» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6769', '1078', '1', 'Udon Thani', 'TH.76', 'NULL', '4892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4892', '112', '6769', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6770', '1078', '1', 'Amnat Charoen', 'TH.77', 'NULL', '4893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4893', '112', '6770', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6771', '1078', '1', 'Mukdahan', 'TH.78', 'NULL', '4894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4894', '112', '6771', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6772', '1078', '1', 'Nong Bua Lamphu', 'TH.79', 'NULL', '4895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4895', '112', '6772', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6773', '1078', '1', 'Sa Kaeo', 'TH.80', 'NULL', '4896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4896', '112', '6773', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TH.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6774', '1078', '1', 'Kulyabskaya Oblast''', 'TJ.00', 'NULL', '4897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4897', '112', '6774', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TJ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6775', '1078', '1', 'Gorno-Badakhshan', 'TJ.01', 'NULL', '4898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4898', '112', '6775', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TJ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6776', '1078', '1', 'Khatlon', 'TJ.02', 'NULL', '4899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4899', '112', '6776', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TJ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6777', '1078', '1', 'Leninobod', 'TJ.03', 'NULL', '4900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4900', '112', '6777', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TJ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6778', '1078', '1', 'Region of Republican Subordination', 'TJ.RR', 'NULL', '4901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4901', '112', '6778', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TJ.RR» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6779', '1078', '1', 'Tokelau (general)', 'TK.00', 'NULL', '4902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4902', '112', '6779', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TK.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6780', '1078', '1', 'Bobonaro', 'TL.00', 'NULL', '4903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4903', '112', '6780', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TL.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6781', '1078', '1', 'Turkmenistan (general)', 'TM.00', 'NULL', '4904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4904', '112', '6781', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6782', '1078', '1', 'Ahal', 'TM.01', 'NULL', '4905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4905', '112', '6782', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6783', '1078', '1', 'Balkan', 'TM.02', 'NULL', '4906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4906', '112', '6783', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6784', '1078', '1', 'Daşoguz', 'TM.03', 'NULL', '4907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4907', '112', '6784', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6785', '1078', '1', 'Lebap', 'TM.04', 'NULL', '4908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4908', '112', '6785', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6786', '1078', '1', 'Mary', 'TM.05', 'NULL', '4909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4909', '112', '6786', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TM.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6787', '1078', '1', 'Tunis al Janubiyah Wilayat', 'TN.00', 'NULL', '4910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4910', '112', '6787', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6788', '1078', '1', 'Al Qaşrayn', 'TN.02', 'NULL', '4911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4911', '112', '6788', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6789', '1078', '1', 'Al Qayrawān', 'TN.03', 'NULL', '4912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4912', '112', '6789', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6790', '1078', '1', 'Jundūbah', 'TN.06', 'NULL', '4913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4913', '112', '6790', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6791', '1078', '1', 'Kef', 'TN.14', 'NULL', '4914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4914', '112', '6791', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6792', '1078', '1', 'Al Mahdīyah', 'TN.15', 'NULL', '4915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4915', '112', '6792', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6793', '1078', '1', 'Al Munastīr', 'TN.16', 'NULL', '4916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4916', '112', '6793', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6794', '1078', '1', 'Bājah', 'TN.17', 'NULL', '4917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4917', '112', '6794', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6795', '1078', '1', 'Banzart', 'TN.18', 'NULL', '4918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4918', '112', '6795', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6796', '1078', '1', 'Nābul', 'TN.19', 'NULL', '4919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4919', '112', '6796', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6797', '1078', '1', 'Silyānah', 'TN.22', 'NULL', '4920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4920', '112', '6797', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6798', '1078', '1', 'Sūsah', 'TN.23', 'NULL', '4921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4921', '112', '6798', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6799', '1078', '1', '(TS26)', 'TN.26', 'NULL', '4922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4922', '112', '6799', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6800', '1078', '1', 'Bin ‘Arūs', 'TN.27', 'NULL', '4923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4923', '112', '6800', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6801', '1078', '1', 'Madanīn', 'TN.28', 'NULL', '4924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4924', '112', '6801', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6802', '1078', '1', 'Qābis', 'TN.29', 'NULL', '4925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4925', '112', '6802', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6803', '1078', '1', 'Qafşah', 'TN.30', 'NULL', '4926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4926', '112', '6803', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6804', '1078', '1', 'Qibilī', 'TN.31', 'NULL', '4927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4927', '112', '6804', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6805', '1078', '1', 'Şafāqis', 'TN.32', 'NULL', '4928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4928', '112', '6805', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6806', '1078', '1', 'Sīdī Bū Zayd', 'TN.33', 'NULL', '4929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4929', '112', '6806', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6807', '1078', '1', 'Taţāwīn', 'TN.34', 'NULL', '4930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4930', '112', '6807', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6808', '1078', '1', 'Tawzar', 'TN.35', 'NULL', '4931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4931', '112', '6808', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6809', '1078', '1', 'Tūnis', 'TN.36', 'NULL', '4932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4932', '112', '6809', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6810', '1078', '1', 'Zaghwān', 'TN.37', 'NULL', '4933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4933', '112', '6810', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6811', '1078', '1', 'Ariana', 'TN.38', 'NULL', '4934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4934', '112', '6811', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6812', '1078', '1', 'Manouba', 'TN.39', 'NULL', '4935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4935', '112', '6812', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TN.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6813', '1078', '1', 'Tonga (general)', 'TO.00', 'NULL', '4936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4936', '112', '6813', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TO.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6814', '1078', '1', 'Ha‘apai', 'TO.01', 'NULL', '4937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4937', '112', '6814', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TO.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6815', '1078', '1', 'Tongatapu', 'TO.02', 'NULL', '4938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4938', '112', '6815', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TO.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6816', '1078', '1', 'Vava‘u', 'TO.03', 'NULL', '4939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4939', '112', '6816', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TO.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6817', '1078', '1', 'Turkey (general)', 'TR.00', 'NULL', '4940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4940', '112', '6817', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6818', '1078', '1', 'Adana Province', 'TR.01', 'NULL', '4941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4941', '112', '6818', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6819', '1078', '1', 'Adıyaman', 'TR.02', 'NULL', '4942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4942', '112', '6819', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6820', '1078', '1', 'Afyonkarahisar', 'TR.03', 'NULL', '4943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4943', '112', '6820', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6821', '1078', '1', 'Ağrı Province', 'TR.04', 'NULL', '4944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4944', '112', '6821', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6822', '1078', '1', 'Amasya Province', 'TR.05', 'NULL', '4945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4945', '112', '6822', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6823', '1078', '1', 'Antalya Province', 'TR.07', 'NULL', '4946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4946', '112', '6823', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6824', '1078', '1', 'Artvin Province', 'TR.08', 'NULL', '4947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4947', '112', '6824', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6825', '1078', '1', 'Aydın Province', 'TR.09', 'NULL', '4948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4948', '112', '6825', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6826', '1078', '1', 'Balıkesir Province', 'TR.10', 'NULL', '4949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4949', '112', '6826', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6827', '1078', '1', 'Bilecik Province', 'TR.11', 'NULL', '4950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4950', '112', '6827', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6828', '1078', '1', 'Bingöl Province', 'TR.12', 'NULL', '4951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4951', '112', '6828', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6829', '1078', '1', 'Bitlis Province', 'TR.13', 'NULL', '4952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4952', '112', '6829', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6830', '1078', '1', 'Bolu Province', 'TR.14', 'NULL', '4953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4953', '112', '6830', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6831', '1078', '1', 'Burdur Province', 'TR.15', 'NULL', '4954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4954', '112', '6831', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6832', '1078', '1', 'Bursa', 'TR.16', 'NULL', '4955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4955', '112', '6832', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6833', '1078', '1', 'Çanakkale Province', 'TR.17', 'NULL', '4956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4956', '112', '6833', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6834', '1078', '1', 'Çorum Province', 'TR.19', 'NULL', '4957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4957', '112', '6834', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6835', '1078', '1', 'Denizli Province', 'TR.20', 'NULL', '4958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4958', '112', '6835', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6836', '1078', '1', 'Diyarbakır', 'TR.21', 'NULL', '4959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4959', '112', '6836', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6837', '1078', '1', 'Edirne Province', 'TR.22', 'NULL', '4960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4960', '112', '6837', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6838', '1078', '1', 'Elazığ', 'TR.23', 'NULL', '4961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4961', '112', '6838', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6839', '1078', '1', 'Erzincan Province', 'TR.24', 'NULL', '4962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4962', '112', '6839', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6840', '1078', '1', 'Erzurum Province', 'TR.25', 'NULL', '4963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4963', '112', '6840', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6841', '1078', '1', 'Giresun Province', 'TR.28', 'NULL', '4964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4964', '112', '6841', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6842', '1078', '1', 'Hatay Province', 'TR.31', 'NULL', '4965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4965', '112', '6842', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6843', '1078', '1', 'Mersin Province', 'TR.32', 'NULL', '4966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4966', '112', '6843', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6844', '1078', '1', 'Isparta Province', 'TR.33', 'NULL', '4967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4967', '112', '6844', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6845', '1078', '1', 'Istanbul', 'TR.34', 'NULL', '4968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4968', '112', '6845', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6846', '1078', '1', 'İzmir', 'TR.35', 'NULL', '4969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4969', '112', '6846', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6847', '1078', '1', 'Kastamonu Province', 'TR.37', 'NULL', '4970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4970', '112', '6847', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6848', '1078', '1', 'Kayseri Province', 'TR.38', 'NULL', '4971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4971', '112', '6848', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6849', '1078', '1', 'Kırklareli Province', 'TR.39', 'NULL', '4972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4972', '112', '6849', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6850', '1078', '1', 'Kırşehir Province', 'TR.40', 'NULL', '4973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4973', '112', '6850', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6851', '1078', '1', 'Kocaeli Province', 'TR.41', 'NULL', '4974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4974', '112', '6851', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6852', '1078', '1', 'Kütahya Province', 'TR.43', 'NULL', '4975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4975', '112', '6852', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6853', '1078', '1', 'Malatya Province', 'TR.44', 'NULL', '4976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4976', '112', '6853', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6854', '1078', '1', 'Manisa Province', 'TR.45', 'NULL', '4977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4977', '112', '6854', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6855', '1078', '1', 'Kahramanmaraş Province', 'TR.46', 'NULL', '4978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4978', '112', '6855', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6856', '1078', '1', 'Muğla Province', 'TR.48', 'NULL', '4979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4979', '112', '6856', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6857', '1078', '1', 'Muş Province', 'TR.49', 'NULL', '4980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4980', '112', '6857', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6858', '1078', '1', 'Nevşehir', 'TR.50', 'NULL', '4981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4981', '112', '6858', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6859', '1078', '1', 'Ordu', 'TR.52', 'NULL', '4982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4982', '112', '6859', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6860', '1078', '1', 'Rize', 'TR.53', 'NULL', '4983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4983', '112', '6860', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6861', '1078', '1', 'Sakarya Province', 'TR.54', 'NULL', '4984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4984', '112', '6861', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6862', '1078', '1', 'Samsun Province', 'TR.55', 'NULL', '4985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4985', '112', '6862', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6863', '1078', '1', 'Sinop Province', 'TR.57', 'NULL', '4986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4986', '112', '6863', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6864', '1078', '1', 'Sivas Province', 'TR.58', 'NULL', '4987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4987', '112', '6864', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6865', '1078', '1', 'Tekirdağ Province', 'TR.59', 'NULL', '4988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4988', '112', '6865', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6866', '1078', '1', 'Tokat', 'TR.60', 'NULL', '4989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4989', '112', '6866', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6867', '1078', '1', 'Trabzon Province', 'TR.61', 'NULL', '4990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4990', '112', '6867', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6868', '1078', '1', 'Tunceli Province', 'TR.62', 'NULL', '4991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4991', '112', '6868', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6869', '1078', '1', 'Şanlıurfa Province', 'TR.63', 'NULL', '4992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4992', '112', '6869', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6870', '1078', '1', 'Uşak Province', 'TR.64', 'NULL', '4993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4993', '112', '6870', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6871', '1078', '1', 'Van Province', 'TR.65', 'NULL', '4994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4994', '112', '6871', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6872', '1078', '1', 'Yozgat Province', 'TR.66', 'NULL', '4995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4995', '112', '6872', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6873', '1078', '1', 'Ankara Province', 'TR.68', 'NULL', '4996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4996', '112', '6873', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6874', '1078', '1', 'Gümüşhane', 'TR.69', 'NULL', '4997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4997', '112', '6874', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6875', '1078', '1', 'Hakkâri Province', 'TR.70', 'NULL', '4998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4998', '112', '6875', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6876', '1078', '1', 'Konya Province', 'TR.71', 'NULL', '4999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('4999', '112', '6876', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6877', '1078', '1', 'Mardin Province', 'TR.72', 'NULL', '5000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5000', '112', '6877', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6878', '1078', '1', 'Niğde', 'TR.73', 'NULL', '5001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5001', '112', '6878', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6879', '1078', '1', 'Siirt Province', 'TR.74', 'NULL', '5002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5002', '112', '6879', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6880', '1078', '1', 'Aksaray Province', 'TR.75', 'NULL', '5003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5003', '112', '6880', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.75» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6881', '1078', '1', 'Batman Province', 'TR.76', 'NULL', '5004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5004', '112', '6881', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6882', '1078', '1', 'Bayburt', 'TR.77', 'NULL', '5005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5005', '112', '6882', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6883', '1078', '1', 'Karaman Province', 'TR.78', 'NULL', '5006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5006', '112', '6883', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6884', '1078', '1', 'Kırıkkale Province', 'TR.79', 'NULL', '5007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5007', '112', '6884', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6885', '1078', '1', 'Şırnak Province', 'TR.80', 'NULL', '5008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5008', '112', '6885', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6886', '1078', '1', 'Çankırı Province', 'TR.82', 'NULL', '5009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5009', '112', '6886', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6887', '1078', '1', 'Gaziantep Province', 'TR.83', 'NULL', '5010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5010', '112', '6887', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6888', '1078', '1', 'Kars', 'TR.84', 'NULL', '5011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5011', '112', '6888', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6889', '1078', '1', 'Zonguldak', 'TR.85', 'NULL', '5012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5012', '112', '6889', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6890', '1078', '1', 'Ardahan Province', 'TR.86', 'NULL', '5013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5013', '112', '6890', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6891', '1078', '1', 'Bartın Province', 'TR.87', 'NULL', '5014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5014', '112', '6891', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.87» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6892', '1078', '1', 'Iğdır Province', 'TR.88', 'NULL', '5015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5015', '112', '6892', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.88» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6893', '1078', '1', 'Karabük', 'TR.89', 'NULL', '5016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5016', '112', '6893', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.89» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6894', '1078', '1', 'Kilis Province', 'TR.90', 'NULL', '5017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5017', '112', '6894', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.90» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6895', '1078', '1', 'Osmaniye Province', 'TR.91', 'NULL', '5018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5018', '112', '6895', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.91» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6896', '1078', '1', 'Yalova Province', 'TR.92', 'NULL', '5019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5019', '112', '6896', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.92» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6897', '1078', '1', 'Düzce', 'TR.93', 'NULL', '5020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5020', '112', '6897', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TR.93» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6898', '1078', '1', 'Trinidad and Tobago (general)', 'TT.00', 'NULL', '5021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5021', '112', '6898', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6899', '1078', '1', 'Arima', 'TT.01', 'NULL', '5022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5022', '112', '6899', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6900', '1078', '1', 'Caroni', 'TT.02', 'NULL', '5023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5023', '112', '6900', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6901', '1078', '1', 'Mayaro', 'TT.03', 'NULL', '5024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5024', '112', '6901', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6902', '1078', '1', 'Nariva', 'TT.04', 'NULL', '5025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5025', '112', '6902', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6903', '1078', '1', 'Port-of-Spain', 'TT.05', 'NULL', '5026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5026', '112', '6903', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6904', '1078', '1', 'Saint Andrew', 'TT.06', 'NULL', '5027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5027', '112', '6904', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6905', '1078', '1', 'Saint David', 'TT.07', 'NULL', '5028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5028', '112', '6905', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6906', '1078', '1', 'Saint George', 'TT.08', 'NULL', '5029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5029', '112', '6906', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6907', '1078', '1', 'Saint Patrick', 'TT.09', 'NULL', '5030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5030', '112', '6907', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6908', '1078', '1', 'San Fernando', 'TT.10', 'NULL', '5031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5031', '112', '6908', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6909', '1078', '1', 'Tobago', 'TT.11', 'NULL', '5032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5032', '112', '6909', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6910', '1078', '1', 'Victoria', 'TT.12', 'NULL', '5033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5033', '112', '6910', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TT.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6911', '1078', '1', 'Tuvalu (general)', 'TV.00', 'NULL', '5034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5034', '112', '6911', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TV.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6912', '1078', '1', 'Taiwan (general)', 'TW.00', 'NULL', '5035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5035', '112', '6912', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TW.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6913', '1078', '1', 'Fu-chien', 'TW.01', 'NULL', '5036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5036', '112', '6913', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TW.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6914', '1078', '1', 'T''ai-pei', 'TW.03', 'NULL', '5037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5037', '112', '6914', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TW.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6915', '1078', '1', 'Tanzania (general)', 'TZ.00', 'NULL', '5038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5038', '112', '6915', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6916', '1078', '1', 'Arusha', 'TZ.01', 'NULL', '5039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5039', '112', '6916', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6917', '1078', '1', 'Pwani', 'TZ.02', 'NULL', '5040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5040', '112', '6917', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6918', '1078', '1', 'Dodoma', 'TZ.03', 'NULL', '5041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5041', '112', '6918', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6919', '1078', '1', 'Iringa', 'TZ.04', 'NULL', '5042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5042', '112', '6919', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6920', '1078', '1', 'Kigoma', 'TZ.05', 'NULL', '5043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5043', '112', '6920', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6921', '1078', '1', 'Kilimanjaro', 'TZ.06', 'NULL', '5044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5044', '112', '6921', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6922', '1078', '1', 'Lindi', 'TZ.07', 'NULL', '5045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5045', '112', '6922', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6923', '1078', '1', 'Mara', 'TZ.08', 'NULL', '5046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5046', '112', '6923', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6924', '1078', '1', 'Mbeya', 'TZ.09', 'NULL', '5047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5047', '112', '6924', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6925', '1078', '1', 'Morogoro', 'TZ.10', 'NULL', '5048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5048', '112', '6925', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6926', '1078', '1', 'Mtwara', 'TZ.11', 'NULL', '5049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5049', '112', '6926', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6927', '1078', '1', 'Mwanza', 'TZ.12', 'NULL', '5050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5050', '112', '6927', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6928', '1078', '1', 'Pemba North', 'TZ.13', 'NULL', '5051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5051', '112', '6928', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6929', '1078', '1', 'Ruvuma', 'TZ.14', 'NULL', '5052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5052', '112', '6929', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6930', '1078', '1', 'Shinyanga', 'TZ.15', 'NULL', '5053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5053', '112', '6930', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6931', '1078', '1', 'Singida', 'TZ.16', 'NULL', '5054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5054', '112', '6931', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6932', '1078', '1', 'Tabora', 'TZ.17', 'NULL', '5055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5055', '112', '6932', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6933', '1078', '1', 'Tanga', 'TZ.18', 'NULL', '5056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5056', '112', '6933', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6934', '1078', '1', 'Kagera', 'TZ.19', 'NULL', '5057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5057', '112', '6934', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6935', '1078', '1', 'Pemba South', 'TZ.20', 'NULL', '5058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5058', '112', '6935', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6936', '1078', '1', 'Zanzibar Central/South', 'TZ.21', 'NULL', '5059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5059', '112', '6936', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6937', '1078', '1', 'Zanzibar North', 'TZ.22', 'NULL', '5060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5060', '112', '6937', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6938', '1078', '1', 'Dar es Salaam', 'TZ.23', 'NULL', '5061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5061', '112', '6938', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6939', '1078', '1', 'Rukwa', 'TZ.24', 'NULL', '5062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5062', '112', '6939', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6940', '1078', '1', 'Zanzibar Urban/West', 'TZ.25', 'NULL', '5063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5063', '112', '6940', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6941', '1078', '1', 'Arusha', 'TZ.26', 'NULL', '5064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5064', '112', '6941', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6942', '1078', '1', 'Manyara', 'TZ.27', 'NULL', '5065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5065', '112', '6942', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «TZ.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6943', '1078', '1', 'Ukraine (general)', 'UA.00', 'NULL', '5066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5066', '112', '6943', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6944', '1078', '1', 'Cherkas''ka Oblast''', 'UA.01', 'NULL', '5067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5067', '112', '6944', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6945', '1078', '1', 'Chernihivs''ka Oblast''', 'UA.02', 'NULL', '5068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5068', '112', '6945', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6946', '1078', '1', 'Chernivets''ka Oblast''', 'UA.03', 'NULL', '5069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5069', '112', '6946', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6947', '1078', '1', 'Dnipropetrovs''ka Oblast''', 'UA.04', 'NULL', '5070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5070', '112', '6947', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6948', '1078', '1', 'Donets''ka Oblast''', 'UA.05', 'NULL', '5071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5071', '112', '6948', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6949', '1078', '1', 'Ivano-Frankivs''ka Oblast''', 'UA.06', 'NULL', '5072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5072', '112', '6949', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6950', '1078', '1', 'Kharkivs''ka Oblast''', 'UA.07', 'NULL', '5073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5073', '112', '6950', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6951', '1078', '1', 'Kherson Oblast', 'UA.08', 'NULL', '5074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5074', '112', '6951', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6952', '1078', '1', 'Khmel''nyts''ka Oblast''', 'UA.09', 'NULL', '5075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5075', '112', '6952', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6953', '1078', '1', 'Kirovohrads''ka Oblast''', 'UA.10', 'NULL', '5076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5076', '112', '6953', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6954', '1078', '1', 'Avtonomna Respublika Krym', 'UA.11', 'NULL', '5077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5077', '112', '6954', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6955', '1078', '1', 'Misto Kyyiv', 'UA.12', 'NULL', '5078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5078', '112', '6955', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6956', '1078', '1', 'Kiev Oblast', 'UA.13', 'NULL', '5079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5079', '112', '6956', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6957', '1078', '1', 'Luhans''ka Oblast''', 'UA.14', 'NULL', '5080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5080', '112', '6957', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6958', '1078', '1', 'L''vivs''ka Oblast''', 'UA.15', 'NULL', '5081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5081', '112', '6958', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6959', '1078', '1', 'Mykolayivs''ka Oblast''', 'UA.16', 'NULL', '5082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5082', '112', '6959', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6960', '1078', '1', 'Odessa Oblast', 'UA.17', 'NULL', '5083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5083', '112', '6960', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6961', '1078', '1', 'Poltava Oblast', 'UA.18', 'NULL', '5084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5084', '112', '6961', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6962', '1078', '1', 'Rivnens''ka Oblast''', 'UA.19', 'NULL', '5085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5085', '112', '6962', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6963', '1078', '1', 'Misto Sevastopol', 'UA.20', 'NULL', '5086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5086', '112', '6963', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6964', '1078', '1', 'Sumy Oblast', 'UA.21', 'NULL', '5087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5087', '112', '6964', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6965', '1078', '1', 'Ternopil''s''ka Oblast''', 'UA.22', 'NULL', '5088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5088', '112', '6965', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6966', '1078', '1', 'Vinnyts''ka Oblast''', 'UA.23', 'NULL', '5089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5089', '112', '6966', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6967', '1078', '1', 'Volyns''ka Oblast''', 'UA.24', 'NULL', '5090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5090', '112', '6967', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6968', '1078', '1', 'Zakarpats''ka Oblast''', 'UA.25', 'NULL', '5091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5091', '112', '6968', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6969', '1078', '1', 'Zaporiz''ka Oblast''', 'UA.26', 'NULL', '5092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5092', '112', '6969', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6970', '1078', '1', 'Zhytomyrs''ka Oblast''', 'UA.27', 'NULL', '5093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5093', '112', '6970', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UA.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6971', '1078', '1', 'Busoga Province', 'UG.00', 'NULL', '5094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5094', '112', '6971', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6972', '1078', '1', 'Kampala District', 'UG.18', 'NULL', '5095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5095', '112', '6972', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6973', '1078', '1', 'Apac', 'UG.26', 'NULL', '5096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5096', '112', '6973', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6974', '1078', '1', 'Arua', 'UG.27', 'NULL', '5097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5097', '112', '6974', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6975', '1078', '1', 'Bundibugyo', 'UG.28', 'NULL', '5098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5098', '112', '6975', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6976', '1078', '1', 'Bushenyi', 'UG.29', 'NULL', '5099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5099', '112', '6976', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6977', '1078', '1', 'Gulu', 'UG.30', 'NULL', '5100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5100', '112', '6977', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6978', '1078', '1', 'Hoima', 'UG.31', 'NULL', '5101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5101', '112', '6978', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6979', '1078', '1', 'Iganga', 'UG.32', 'NULL', '5102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5102', '112', '6979', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6980', '1078', '1', 'Jinja', 'UG.33', 'NULL', '5103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5103', '112', '6980', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6981', '1078', '1', 'Kabale', 'UG.34', 'NULL', '5104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5104', '112', '6981', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6982', '1078', '1', 'Kabarole', 'UG.35', 'NULL', '5105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5105', '112', '6982', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6983', '1078', '1', 'Kalangala', 'UG.36', 'NULL', '5106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5106', '112', '6983', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6984', '1078', '1', 'Kampala', 'UG.37', 'NULL', '5107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5107', '112', '6984', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6985', '1078', '1', 'Kamuli', 'UG.38', 'NULL', '5108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5108', '112', '6985', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6986', '1078', '1', 'Kapchorwa', 'UG.39', 'NULL', '5109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5109', '112', '6986', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6987', '1078', '1', 'Kasese', 'UG.40', 'NULL', '5110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5110', '112', '6987', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6988', '1078', '1', 'Kibale', 'UG.41', 'NULL', '5111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5111', '112', '6988', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6989', '1078', '1', 'Kiboga', 'UG.42', 'NULL', '5112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5112', '112', '6989', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.42» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6990', '1078', '1', 'Kisoro', 'UG.43', 'NULL', '5113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5113', '112', '6990', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6991', '1078', '1', 'Kitgum', 'UG.44', 'NULL', '5114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5114', '112', '6991', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6992', '1078', '1', 'Kotido', 'UG.45', 'NULL', '5115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5115', '112', '6992', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6993', '1078', '1', 'Kumi', 'UG.46', 'NULL', '5116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5116', '112', '6993', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6994', '1078', '1', 'Lira', 'UG.47', 'NULL', '5117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5117', '112', '6994', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6995', '1078', '1', 'Luwero', 'UG.48', 'NULL', '5118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5118', '112', '6995', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6996', '1078', '1', 'Masaka', 'UG.49', 'NULL', '5119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5119', '112', '6996', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6997', '1078', '1', 'Masindi', 'UG.50', 'NULL', '5120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5120', '112', '6997', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6998', '1078', '1', 'Mbale', 'UG.51', 'NULL', '5121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5121', '112', '6998', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('6999', '1078', '1', 'Mbarara', 'UG.52', 'NULL', '5122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5122', '112', '6999', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7000', '1078', '1', 'Moroto', 'UG.53', 'NULL', '5123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5123', '112', '7000', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7001', '1078', '1', 'Moyo', 'UG.54', 'NULL', '5124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5124', '112', '7001', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7002', '1078', '1', 'Mpigi', 'UG.55', 'NULL', '5125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5125', '112', '7002', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7003', '1078', '1', 'Mubende', 'UG.56', 'NULL', '5126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5126', '112', '7003', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7004', '1078', '1', 'Mukuno', 'UG.57', 'NULL', '5127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5127', '112', '7004', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7005', '1078', '1', 'Nebbi', 'UG.58', 'NULL', '5128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5128', '112', '7005', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7006', '1078', '1', 'Ntungamo', 'UG.59', 'NULL', '5129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5129', '112', '7006', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7007', '1078', '1', 'Pallisa', 'UG.60', 'NULL', '5130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5130', '112', '7007', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7008', '1078', '1', 'Rakai', 'UG.61', 'NULL', '5131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5131', '112', '7008', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7009', '1078', '1', 'Rukungiri', 'UG.62', 'NULL', '5132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5132', '112', '7009', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7010', '1078', '1', 'Soroti', 'UG.63', 'NULL', '5133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5133', '112', '7010', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7011', '1078', '1', 'Tororo', 'UG.64', 'NULL', '5134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5134', '112', '7011', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7012', '1078', '1', 'Adjumani', 'UG.65', 'NULL', '5135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5135', '112', '7012', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7013', '1078', '1', 'Bugiri', 'UG.66', 'NULL', '5136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5136', '112', '7013', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7014', '1078', '1', 'Busia', 'UG.67', 'NULL', '5137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5137', '112', '7014', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7015', '1078', '1', 'Iganga', 'UG.68', 'NULL', '5138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5138', '112', '7015', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7016', '1078', '1', 'Katakwi', 'UG.69', 'NULL', '5139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5139', '112', '7016', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7017', '1078', '1', 'Luwero', 'UG.70', 'NULL', '5140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5140', '112', '7017', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7018', '1078', '1', 'Masaka', 'UG.71', 'NULL', '5141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5141', '112', '7018', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7019', '1078', '1', 'Moyo', 'UG.72', 'NULL', '5142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5142', '112', '7019', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7020', '1078', '1', 'Nakasongola', 'UG.73', 'NULL', '5143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5143', '112', '7020', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7021', '1078', '1', 'Sembabule', 'UG.74', 'NULL', '5144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5144', '112', '7021', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7022', '1078', '1', 'Soroti', 'UG.75', 'NULL', '5145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5145', '112', '7022', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.75» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7023', '1078', '1', 'Tororo', 'UG.76', 'NULL', '5146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5146', '112', '7023', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7024', '1078', '1', 'Arua', 'UG.77', 'NULL', '5147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5147', '112', '7024', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7025', '1078', '1', 'Iganga', 'UG.78', 'NULL', '5148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5148', '112', '7025', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7026', '1078', '1', 'Kabarole', 'UG.79', 'NULL', '5149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5149', '112', '7026', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7027', '1078', '1', 'Kaberamaido', 'UG.80', 'NULL', '5150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5150', '112', '7027', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7028', '1078', '1', 'Kamwenge', 'UG.81', 'NULL', '5151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5151', '112', '7028', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7029', '1078', '1', 'Kanungu', 'UG.82', 'NULL', '5152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5152', '112', '7029', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7030', '1078', '1', 'Kayunga', 'UG.83', 'NULL', '5153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5153', '112', '7030', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7031', '1078', '1', 'Kitgum', 'UG.84', 'NULL', '5154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5154', '112', '7031', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7032', '1078', '1', 'Kyenjojo', 'UG.85', 'NULL', '5155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5155', '112', '7032', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7033', '1078', '1', 'Mayuge', 'UG.86', 'NULL', '5156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5156', '112', '7033', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7034', '1078', '1', 'Mbale', 'UG.87', 'NULL', '5157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5157', '112', '7034', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.87» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7035', '1078', '1', 'Moroto', 'UG.88', 'NULL', '5158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5158', '112', '7035', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.88» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7036', '1078', '1', 'Mpigi', 'UG.89', 'NULL', '5159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5159', '112', '7036', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.89» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7037', '1078', '1', 'Mukono', 'UG.90', 'NULL', '5160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5160', '112', '7037', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.90» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7038', '1078', '1', 'Nakapiripirit', 'UG.91', 'NULL', '5161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5161', '112', '7038', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.91» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7039', '1078', '1', 'Pader', 'UG.92', 'NULL', '5162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5162', '112', '7039', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.92» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7040', '1078', '1', 'Rukungiri', 'UG.93', 'NULL', '5163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5163', '112', '7040', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.93» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7041', '1078', '1', 'Sironko', 'UG.94', 'NULL', '5164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5164', '112', '7041', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.94» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7042', '1078', '1', 'Soroti', 'UG.95', 'NULL', '5165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5165', '112', '7042', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.95» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7043', '1078', '1', 'Wakiso', 'UG.96', 'NULL', '5166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5166', '112', '7043', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.96» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7044', '1078', '1', 'Yumbe', 'UG.97', 'NULL', '5167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5167', '112', '7044', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UG.97» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7045', '1078', '1', 'United States (general)', 'US.00', 'NULL', '5168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5168', '112', '7045', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7046', '1078', '1', 'Alaska', 'US.AK', 'NULL', '5169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5169', '112', '7046', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.AK» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7047', '1078', '1', 'Alabama', 'US.AL', 'NULL', '5170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5170', '112', '7047', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.AL» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7048', '1078', '1', 'Arkansas', 'US.AR', 'NULL', '5171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5171', '112', '7048', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.AR» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7049', '1078', '1', 'Arizona', 'US.AZ', 'NULL', '5172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5172', '112', '7049', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.AZ» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7050', '1078', '1', 'California', 'US.CA', 'NULL', '5173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5173', '112', '7050', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.CA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7051', '1078', '1', 'Colorado', 'US.CO', 'NULL', '5174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5174', '112', '7051', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.CO» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7052', '1078', '1', 'Connecticut', 'US.CT', 'NULL', '5175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5175', '112', '7052', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.CT» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7053', '1078', '1', 'Washington, D.C.', 'US.DC', 'NULL', '5176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5176', '112', '7053', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.DC» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7054', '1078', '1', 'Delaware', 'US.DE', 'NULL', '5177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5177', '112', '7054', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.DE» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7055', '1078', '1', 'Florida', 'US.FL', 'NULL', '5178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5178', '112', '7055', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.FL» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7056', '1078', '1', 'Georgia', 'US.GA', 'NULL', '5179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5179', '112', '7056', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.GA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7057', '1078', '1', 'Hawaii', 'US.HI', 'NULL', '5180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5180', '112', '7057', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.HI» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7058', '1078', '1', 'Iowa', 'US.IA', 'NULL', '5181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5181', '112', '7058', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.IA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7059', '1078', '1', 'Idaho', 'US.ID', 'NULL', '5182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5182', '112', '7059', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.ID» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7060', '1078', '1', 'Illinois', 'US.IL', 'NULL', '5183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5183', '112', '7060', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.IL» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7061', '1078', '1', 'Indiana', 'US.IN', 'NULL', '5184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5184', '112', '7061', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.IN» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7062', '1078', '1', 'Kansas', 'US.KS', 'NULL', '5185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5185', '112', '7062', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.KS» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7063', '1078', '1', 'Kentucky', 'US.KY', 'NULL', '5186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5186', '112', '7063', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.KY» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7064', '1078', '1', 'Louisiana', 'US.LA', 'NULL', '5187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5187', '112', '7064', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.LA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7065', '1078', '1', 'Massachusetts', 'US.MA', 'NULL', '5188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5188', '112', '7065', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.MA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7066', '1078', '1', 'Maryland', 'US.MD', 'NULL', '5189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5189', '112', '7066', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.MD» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7067', '1078', '1', 'Maine', 'US.ME', 'NULL', '5190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5190', '112', '7067', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.ME» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7068', '1078', '1', 'Michigan', 'US.MI', 'NULL', '5191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5191', '112', '7068', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.MI» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7069', '1078', '1', 'Minnesota', 'US.MN', 'NULL', '5192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5192', '112', '7069', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.MN» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7070', '1078', '1', 'Missouri', 'US.MO', 'NULL', '5193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5193', '112', '7070', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.MO» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7071', '1078', '1', 'Mississippi', 'US.MS', 'NULL', '5194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5194', '112', '7071', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.MS» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7072', '1078', '1', 'Montana', 'US.MT', 'NULL', '5195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5195', '112', '7072', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.MT» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7073', '1078', '1', 'North Carolina', 'US.NC', 'NULL', '5196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5196', '112', '7073', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.NC» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7074', '1078', '1', 'North Dakota', 'US.ND', 'NULL', '5197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5197', '112', '7074', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.ND» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7075', '1078', '1', 'Nebraska', 'US.NE', 'NULL', '5198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5198', '112', '7075', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.NE» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7076', '1078', '1', 'New Hampshire', 'US.NH', 'NULL', '5199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5199', '112', '7076', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.NH» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7077', '1078', '1', 'New Jersey', 'US.NJ', 'NULL', '5200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5200', '112', '7077', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.NJ» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7078', '1078', '1', 'New Mexico', 'US.NM', 'NULL', '5201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5201', '112', '7078', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.NM» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7079', '1078', '1', 'Nevada', 'US.NV', 'NULL', '5202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5202', '112', '7079', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.NV» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7080', '1078', '1', 'New York', 'US.NY', 'NULL', '5203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5203', '112', '7080', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.NY» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7081', '1078', '1', 'Ohio', 'US.OH', 'NULL', '5204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5204', '112', '7081', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.OH» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7082', '1078', '1', 'Oklahoma', 'US.OK', 'NULL', '5205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5205', '112', '7082', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.OK» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7083', '1078', '1', 'Oregon', 'US.OR', 'NULL', '5206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5206', '112', '7083', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.OR» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7084', '1078', '1', 'Pennsylvania', 'US.PA', 'NULL', '5207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5207', '112', '7084', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.PA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7085', '1078', '1', 'Rhode Island', 'US.RI', 'NULL', '5208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5208', '112', '7085', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.RI» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7086', '1078', '1', 'South Carolina', 'US.SC', 'NULL', '5209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5209', '112', '7086', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.SC» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7087', '1078', '1', 'South Dakota', 'US.SD', 'NULL', '5210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5210', '112', '7087', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.SD» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7088', '1078', '1', 'Tennessee', 'US.TN', 'NULL', '5211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5211', '112', '7088', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.TN» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7089', '1078', '1', 'Texas', 'US.TX', 'NULL', '5212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5212', '112', '7089', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.TX» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7090', '1078', '1', 'Utah', 'US.UT', 'NULL', '5213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5213', '112', '7090', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.UT» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7091', '1078', '1', 'Virginia', 'US.VA', 'NULL', '5214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5214', '112', '7091', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.VA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7092', '1078', '1', 'Vermont', 'US.VT', 'NULL', '5215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5215', '112', '7092', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.VT» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7093', '1078', '1', 'Washington', 'US.WA', 'NULL', '5216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5216', '112', '7093', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.WA» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7094', '1078', '1', 'Wisconsin', 'US.WI', 'NULL', '5217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5217', '112', '7094', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.WI» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7095', '1078', '1', 'West Virginia', 'US.WV', 'NULL', '5218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5218', '112', '7095', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.WV» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7096', '1078', '1', 'Wyoming', 'US.WY', 'NULL', '5219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5219', '112', '7096', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «US.WY» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7097', '1078', '1', 'Uruguay (general)', 'UY.00', 'NULL', '5220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5220', '112', '7097', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7098', '1078', '1', 'Artigas Department', 'UY.01', 'NULL', '5221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5221', '112', '7098', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7099', '1078', '1', 'Canelones Department', 'UY.02', 'NULL', '5222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5222', '112', '7099', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7100', '1078', '1', 'Cerro Largo Department', 'UY.03', 'NULL', '5223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5223', '112', '7100', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7101', '1078', '1', 'Colonia Department', 'UY.04', 'NULL', '5224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5224', '112', '7101', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7102', '1078', '1', 'Durazno', 'UY.05', 'NULL', '5225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5225', '112', '7102', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7103', '1078', '1', 'Flores', 'UY.06', 'NULL', '5226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5226', '112', '7103', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7104', '1078', '1', 'Florida Department', 'UY.07', 'NULL', '5227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5227', '112', '7104', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7105', '1078', '1', 'Lavalleja Department', 'UY.08', 'NULL', '5228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5228', '112', '7105', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7106', '1078', '1', 'Maldonado Department', 'UY.09', 'NULL', '5229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5229', '112', '7106', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7107', '1078', '1', 'Montevideo', 'UY.10', 'NULL', '5230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5230', '112', '7107', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7108', '1078', '1', 'Paysandú', 'UY.11', 'NULL', '5231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5231', '112', '7108', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7109', '1078', '1', 'Río Negro', 'UY.12', 'NULL', '5232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5232', '112', '7109', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7110', '1078', '1', 'Rivera', 'UY.13', 'NULL', '5233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5233', '112', '7110', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7111', '1078', '1', 'Rocha', 'UY.14', 'NULL', '5234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5234', '112', '7111', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7112', '1078', '1', 'Salto', 'UY.15', 'NULL', '5235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5235', '112', '7112', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7113', '1078', '1', 'San José', 'UY.16', 'NULL', '5236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5236', '112', '7113', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7114', '1078', '1', 'Soriano Department', 'UY.17', 'NULL', '5237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5237', '112', '7114', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7115', '1078', '1', 'Tacuarembó', 'UY.18', 'NULL', '5238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5238', '112', '7115', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7116', '1078', '1', 'Treinta y Tres', 'UY.19', 'NULL', '5239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5239', '112', '7116', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UY.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7117', '1078', '1', 'Uzbekistan (general)', 'UZ.00', 'NULL', '5240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5240', '112', '7117', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7118', '1078', '1', 'Andijon', 'UZ.01', 'NULL', '5241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5241', '112', '7118', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7119', '1078', '1', 'Buxoro', 'UZ.02', 'NULL', '5242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5242', '112', '7119', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7120', '1078', '1', 'Farg ona', 'UZ.03', 'NULL', '5243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5243', '112', '7120', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7121', '1078', '1', 'Xorazm', 'UZ.05', 'NULL', '5244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5244', '112', '7121', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7122', '1078', '1', 'Namangan', 'UZ.06', 'NULL', '5245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5245', '112', '7122', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7123', '1078', '1', 'Navoiy', 'UZ.07', 'NULL', '5246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5246', '112', '7123', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7124', '1078', '1', 'Qashqadaryo', 'UZ.08', 'NULL', '5247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5247', '112', '7124', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7125', '1078', '1', 'Karakalpakstan', 'UZ.09', 'NULL', '5248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5248', '112', '7125', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7126', '1078', '1', 'Samarqand', 'UZ.10', 'NULL', '5249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5249', '112', '7126', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7127', '1078', '1', 'Surxondaryo', 'UZ.12', 'NULL', '5250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5250', '112', '7127', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7128', '1078', '1', 'Toshkent Shahri', 'UZ.13', 'NULL', '5251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5251', '112', '7128', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7129', '1078', '1', 'Toshkent', 'UZ.14', 'NULL', '5252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5252', '112', '7129', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7130', '1078', '1', 'Jizzax', 'UZ.15', 'NULL', '5253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5253', '112', '7130', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7131', '1078', '1', 'Sirdaryo', 'UZ.16', 'NULL', '5254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5254', '112', '7131', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «UZ.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7132', '1078', '1', 'Vatican City (general)', 'VA.00', 'NULL', '5255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5255', '112', '7132', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7133', '1078', '1', 'Saint Vincent and The Grenadines (general)', 'VC.00', 'NULL', '5256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5256', '112', '7133', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VC.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7134', '1078', '1', 'Charlotte', 'VC.01', 'NULL', '5257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5257', '112', '7134', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VC.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7135', '1078', '1', 'Saint Andrew', 'VC.02', 'NULL', '5258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5258', '112', '7135', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VC.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7136', '1078', '1', 'Saint David', 'VC.03', 'NULL', '5259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5259', '112', '7136', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VC.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7137', '1078', '1', 'Saint George', 'VC.04', 'NULL', '5260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5260', '112', '7137', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VC.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7138', '1078', '1', 'Saint Patrick', 'VC.05', 'NULL', '5261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5261', '112', '7138', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VC.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7139', '1078', '1', 'Grenadines', 'VC.06', 'NULL', '5262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5262', '112', '7139', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VC.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7140', '1078', '1', 'Venezuela (general)', 'VE.00', 'NULL', '5263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5263', '112', '7140', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7141', '1078', '1', 'Amazonas', 'VE.01', 'NULL', '5264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5264', '112', '7141', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7142', '1078', '1', 'Anzoátegui', 'VE.02', 'NULL', '5265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5265', '112', '7142', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7143', '1078', '1', 'Apure', 'VE.03', 'NULL', '5266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5266', '112', '7143', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7144', '1078', '1', 'Aragua', 'VE.04', 'NULL', '5267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5267', '112', '7144', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7145', '1078', '1', 'Barinas', 'VE.05', 'NULL', '5268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5268', '112', '7145', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7146', '1078', '1', 'Bolívar', 'VE.06', 'NULL', '5269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5269', '112', '7146', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7147', '1078', '1', 'Carabobo', 'VE.07', 'NULL', '5270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5270', '112', '7147', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7148', '1078', '1', 'Cojedes', 'VE.08', 'NULL', '5271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5271', '112', '7148', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7149', '1078', '1', 'Delta Amacuro', 'VE.09', 'NULL', '5272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5272', '112', '7149', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7150', '1078', '1', 'Distrito Federal', 'VE.10', 'NULL', '5273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5273', '112', '7150', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7151', '1078', '1', 'Falcón', 'VE.11', 'NULL', '5274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5274', '112', '7151', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7152', '1078', '1', 'Guárico', 'VE.12', 'NULL', '5275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5275', '112', '7152', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7153', '1078', '1', 'Lara', 'VE.13', 'NULL', '5276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5276', '112', '7153', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7154', '1078', '1', 'Mérida', 'VE.14', 'NULL', '5277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5277', '112', '7154', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7155', '1078', '1', 'Miranda', 'VE.15', 'NULL', '5278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5278', '112', '7155', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7156', '1078', '1', 'Monagas', 'VE.16', 'NULL', '5279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5279', '112', '7156', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7157', '1078', '1', 'Isla Margarita', 'VE.17', 'NULL', '5280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5280', '112', '7157', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7158', '1078', '1', 'Portuguesa', 'VE.18', 'NULL', '5281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5281', '112', '7158', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7159', '1078', '1', 'Sucre', 'VE.19', 'NULL', '5282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5282', '112', '7159', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7160', '1078', '1', 'Táchira', 'VE.20', 'NULL', '5283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5283', '112', '7160', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7161', '1078', '1', 'Trujillo', 'VE.21', 'NULL', '5284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5284', '112', '7161', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7162', '1078', '1', 'Yaracuy', 'VE.22', 'NULL', '5285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5285', '112', '7162', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7163', '1078', '1', 'Zulia', 'VE.23', 'NULL', '5286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5286', '112', '7163', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7164', '1078', '1', 'Dependencias Federales', 'VE.24', 'NULL', '5287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5287', '112', '7164', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7165', '1078', '1', 'Distrito Federal', 'VE.25', 'NULL', '5288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5288', '112', '7165', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7166', '1078', '1', 'Vargas', 'VE.26', 'NULL', '5289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5289', '112', '7166', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7167', '1078', '1', '(VE99)', 'VE.99', 'NULL', '5290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5290', '112', '7167', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VE.99» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7168', '1078', '1', 'British Virgin Islands (general)', 'VG.00', 'NULL', '5291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5291', '112', '7168', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VG.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7169', '1078', '1', 'Virgin Islands (general)', 'VI.00', 'NULL', '5292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5292', '112', '7169', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VI.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7170', '1078', '1', 'Vietnam (general)', 'VN.00', 'NULL', '5293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5293', '112', '7170', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7171', '1078', '1', 'An Giang', 'VN.01', 'NULL', '5294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5294', '112', '7171', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7172', '1078', '1', 'B?c Thái T?nh', 'VN.02', 'NULL', '5295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5295', '112', '7172', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7173', '1078', '1', 'Bến Tre', 'VN.03', 'NULL', '5296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5296', '112', '7173', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7174', '1078', '1', 'Cao Bang', 'VN.04', 'NULL', '5297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5297', '112', '7174', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7175', '1078', '1', 'Cao Bằng', 'VN.05', 'NULL', '5298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5298', '112', '7175', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7176', '1078', '1', 'Ten Bai', 'VN.06', 'NULL', '5299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5299', '112', '7176', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7177', '1078', '1', 'Ðắc Lắk', 'VN.07', 'NULL', '5300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5300', '112', '7177', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7178', '1078', '1', 'Ðồng Tháp', 'VN.09', 'NULL', '5301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5301', '112', '7178', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7179', '1078', '1', '(VM10)', 'VN.10', 'NULL', '5302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5302', '112', '7179', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7180', '1078', '1', 'Hà B?c T?nh', 'VN.11', 'NULL', '5303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5303', '112', '7180', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7181', '1078', '1', 'H?i Hung T?nh', 'VN.12', 'NULL', '5304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5304', '112', '7181', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7182', '1078', '1', 'Hải Phòng', 'VN.13', 'NULL', '5305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5305', '112', '7182', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7183', '1078', '1', 'Hoa Binh', 'VN.14', 'NULL', '5306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5306', '112', '7183', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7184', '1078', '1', 'Ha Tay', 'VN.15', 'NULL', '5307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5307', '112', '7184', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7185', '1078', '1', '(VM16)', 'VN.16', 'NULL', '5308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5308', '112', '7185', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7186', '1078', '1', '(VM17)', 'VN.17', 'NULL', '5309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5309', '112', '7186', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7187', '1078', '1', '(VM19)', 'VN.19', 'NULL', '5310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5310', '112', '7187', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7188', '1078', '1', 'Hồ Chí Minh', 'VN.20', 'NULL', '5311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5311', '112', '7188', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7189', '1078', '1', 'Kiến Giang', 'VN.21', 'NULL', '5312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5312', '112', '7189', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7190', '1078', '1', 'Lai Châu', 'VN.22', 'NULL', '5313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5313', '112', '7190', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7191', '1078', '1', 'Lâm Ðồng', 'VN.23', 'NULL', '5314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5314', '112', '7191', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7192', '1078', '1', 'Long An', 'VN.24', 'NULL', '5315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5315', '112', '7192', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7193', '1078', '1', 'Minh H?i T?nh', 'VN.25', 'NULL', '5316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5316', '112', '7193', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7194', '1078', '1', 'Thua Thien-Hue', 'VN.26', 'NULL', '5317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5317', '112', '7194', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7195', '1078', '1', 'Quang Nam', 'VN.27', 'NULL', '5318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5318', '112', '7195', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7196', '1078', '1', 'Kon Tum', 'VN.28', 'NULL', '5319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5319', '112', '7196', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.28» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7197', '1078', '1', 'Qu?ng Nam-Ðà N?ng T?nh', 'VN.29', 'NULL', '5320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5320', '112', '7197', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.29» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7198', '1078', '1', 'Quảng Ninh', 'VN.30', 'NULL', '5321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5321', '112', '7198', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.30» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7199', '1078', '1', 'Sông Bé T?nh', 'VN.31', 'NULL', '5322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5322', '112', '7199', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.31» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7200', '1078', '1', 'Sơn La', 'VN.32', 'NULL', '5323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5323', '112', '7200', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.32» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7201', '1078', '1', 'Tây Ninh', 'VN.33', 'NULL', '5324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5324', '112', '7201', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.33» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7202', '1078', '1', 'Thanh Hóa', 'VN.34', 'NULL', '5325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5325', '112', '7202', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.34» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7203', '1078', '1', 'Thái Bình', 'VN.35', 'NULL', '5326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5326', '112', '7203', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.35» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7204', '1078', '1', 'Nin Thuan', 'VN.36', 'NULL', '5327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5327', '112', '7204', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.36» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7205', '1078', '1', 'Tiền Giang', 'VN.37', 'NULL', '5328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5328', '112', '7205', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.37» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7206', '1078', '1', 'Vinh Phú T?nh', 'VN.38', 'NULL', '5329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5329', '112', '7206', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.38» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7207', '1078', '1', 'Lạng Sơn', 'VN.39', 'NULL', '5330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5330', '112', '7207', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.39» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7208', '1078', '1', 'Binh Thuan', 'VN.40', 'NULL', '5331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5331', '112', '7208', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.40» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7209', '1078', '1', 'Long An', 'VN.41', 'NULL', '5332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5332', '112', '7209', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.41» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7210', '1078', '1', 'Ðồng Nai', 'VN.43', 'NULL', '5333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5333', '112', '7210', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.43» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7211', '1078', '1', 'Ha Nội', 'VN.44', 'NULL', '5334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5334', '112', '7211', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.44» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7212', '1078', '1', 'Bà Rịa-Vũng Tàu', 'VN.45', 'NULL', '5335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5335', '112', '7212', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.45» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7213', '1078', '1', 'Bình Ðịnh', 'VN.46', 'NULL', '5336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5336', '112', '7213', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.46» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7214', '1078', '1', 'Bình Thuận', 'VN.47', 'NULL', '5337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5337', '112', '7214', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.47» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7215', '1078', '1', 'Cần Thơ', 'VN.48', 'NULL', '5338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5338', '112', '7215', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.48» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7216', '1078', '1', 'Gia Lai', 'VN.49', 'NULL', '5339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5339', '112', '7216', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.49» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7217', '1078', '1', 'Hà Giang', 'VN.50', 'NULL', '5340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5340', '112', '7217', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.50» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7218', '1078', '1', 'Hà Tây', 'VN.51', 'NULL', '5341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5341', '112', '7218', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.51» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7219', '1078', '1', 'Hà Tĩnh', 'VN.52', 'NULL', '5342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5342', '112', '7219', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.52» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7220', '1078', '1', 'Hòa Bình', 'VN.53', 'NULL', '5343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5343', '112', '7220', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.53» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7221', '1078', '1', 'Khánh Hòa', 'VN.54', 'NULL', '5344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5344', '112', '7221', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.54» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7222', '1078', '1', 'Kon Tum', 'VN.55', 'NULL', '5345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5345', '112', '7222', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.55» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7223', '1078', '1', 'Lào Cai', 'VN.56', 'NULL', '5346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5346', '112', '7223', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.56» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7224', '1078', '1', 'Nam Hà T?nh', 'VN.57', 'NULL', '5347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5347', '112', '7224', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.57» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7225', '1078', '1', 'Nghệ An', 'VN.58', 'NULL', '5348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5348', '112', '7225', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.58» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7226', '1078', '1', 'Ninh Bình', 'VN.59', 'NULL', '5349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5349', '112', '7226', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.59» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7227', '1078', '1', 'Ninh Thuận', 'VN.60', 'NULL', '5350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5350', '112', '7227', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.60» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7228', '1078', '1', 'Phú Yên', 'VN.61', 'NULL', '5351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5351', '112', '7228', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.61» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7229', '1078', '1', 'Quảng Bình', 'VN.62', 'NULL', '5352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5352', '112', '7229', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.62» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7230', '1078', '1', 'Quảng Ngãi', 'VN.63', 'NULL', '5353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5353', '112', '7230', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.63» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7231', '1078', '1', 'Quảng Trị', 'VN.64', 'NULL', '5354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5354', '112', '7231', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.64» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7232', '1078', '1', 'Sóc Trăng', 'VN.65', 'NULL', '5355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5355', '112', '7232', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.65» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7233', '1078', '1', 'Thừa Thiên-Huế', 'VN.66', 'NULL', '5356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5356', '112', '7233', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.66» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7234', '1078', '1', 'Trà Vinh', 'VN.67', 'NULL', '5357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5357', '112', '7234', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.67» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7235', '1078', '1', 'Tuyên Quang', 'VN.68', 'NULL', '5358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5358', '112', '7235', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.68» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7236', '1078', '1', 'Vĩnh Long', 'VN.69', 'NULL', '5359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5359', '112', '7236', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.69» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7237', '1078', '1', 'Yên Bái', 'VN.70', 'NULL', '5360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5360', '112', '7237', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.70» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7238', '1078', '1', 'Bắc Giang', 'VN.71', 'NULL', '5361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5361', '112', '7238', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.71» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7239', '1078', '1', 'Bắc Kạn', 'VN.72', 'NULL', '5362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5362', '112', '7239', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.72» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7240', '1078', '1', 'Bạc Liêu', 'VN.73', 'NULL', '5363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5363', '112', '7240', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.73» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7241', '1078', '1', 'Bắc Ninh', 'VN.74', 'NULL', '5364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5364', '112', '7241', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.74» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7242', '1078', '1', 'Bình Dương', 'VN.75', 'NULL', '5365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5365', '112', '7242', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.75» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7243', '1078', '1', 'Bình Phước', 'VN.76', 'NULL', '5366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5366', '112', '7243', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.76» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7244', '1078', '1', 'Cà Mau', 'VN.77', 'NULL', '5367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5367', '112', '7244', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.77» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7245', '1078', '1', 'Ðà Nẵng', 'VN.78', 'NULL', '5368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5368', '112', '7245', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.78» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7246', '1078', '1', 'Hải Dương', 'VN.79', 'NULL', '5369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5369', '112', '7246', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.79» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7247', '1078', '1', 'Hà Nam', 'VN.80', 'NULL', '5370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5370', '112', '7247', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.80» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7248', '1078', '1', 'Hưng Yên', 'VN.81', 'NULL', '5371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5371', '112', '7248', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.81» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7249', '1078', '1', 'Nam Ðịnh', 'VN.82', 'NULL', '5372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5372', '112', '7249', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.82» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7250', '1078', '1', 'Phú Thọ', 'VN.83', 'NULL', '5373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5373', '112', '7250', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.83» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7251', '1078', '1', 'Quảng Nam', 'VN.84', 'NULL', '5374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5374', '112', '7251', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.84» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7252', '1078', '1', 'Thái Nguyên', 'VN.85', 'NULL', '5375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5375', '112', '7252', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.85» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7253', '1078', '1', 'Vĩnh Phúc', 'VN.86', 'NULL', '5376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5376', '112', '7253', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VN.86» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7254', '1078', '1', 'Vanuatu (general)', 'VU.00', 'NULL', '5377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5377', '112', '7254', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7255', '1078', '1', 'Ambrym', 'VU.05', 'NULL', '5378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5378', '112', '7255', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7256', '1078', '1', 'Aoba/Maéwo', 'VU.06', 'NULL', '5379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5379', '112', '7256', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7257', '1078', '1', 'Torba', 'VU.07', 'NULL', '5380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5380', '112', '7257', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7258', '1078', '1', 'Éfaté', 'VU.08', 'NULL', '5381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5381', '112', '7258', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7259', '1078', '1', 'Épi', 'VU.09', 'NULL', '5382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5382', '112', '7259', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7260', '1078', '1', 'Malakula', 'VU.10', 'NULL', '5383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5383', '112', '7260', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7261', '1078', '1', 'Paama', 'VU.11', 'NULL', '5384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5384', '112', '7261', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7262', '1078', '1', 'Pentecôte', 'VU.12', 'NULL', '5385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5385', '112', '7262', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7263', '1078', '1', 'Sanma', 'VU.13', 'NULL', '5386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5386', '112', '7263', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7264', '1078', '1', 'Shepherd', 'VU.14', 'NULL', '5387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5387', '112', '7264', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7265', '1078', '1', 'Tafea', 'VU.15', 'NULL', '5388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5388', '112', '7265', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7266', '1078', '1', 'Malampa', 'VU.16', 'NULL', '5389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5389', '112', '7266', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7267', '1078', '1', 'Penama', 'VU.17', 'NULL', '5390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5390', '112', '7267', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7268', '1078', '1', 'Shefa', 'VU.18', 'NULL', '5391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5391', '112', '7268', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «VU.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7269', '1078', '1', 'Samoa (general)', 'WS.00', 'NULL', '5392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5392', '112', '7269', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7270', '1078', '1', 'A‘ana', 'WS.01', 'NULL', '5393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5393', '112', '7270', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7271', '1078', '1', 'Aiga-i-le-Tai', 'WS.02', 'NULL', '5394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5394', '112', '7271', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7272', '1078', '1', 'Atua', 'WS.03', 'NULL', '5395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5395', '112', '7272', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7273', '1078', '1', 'Fa‘asaleleaga', 'WS.04', 'NULL', '5396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5396', '112', '7273', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7274', '1078', '1', 'Gaga‘emauga', 'WS.05', 'NULL', '5397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5397', '112', '7274', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7275', '1078', '1', 'Va‘a-o-Fonoti', 'WS.06', 'NULL', '5398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5398', '112', '7275', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7276', '1078', '1', 'Gagaifomauga', 'WS.07', 'NULL', '5399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5399', '112', '7276', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7277', '1078', '1', 'Palauli', 'WS.08', 'NULL', '5400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5400', '112', '7277', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7278', '1078', '1', 'Satupa‘itea', 'WS.09', 'NULL', '5401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5401', '112', '7278', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7279', '1078', '1', 'Tuamasaga', 'WS.10', 'NULL', '5402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5402', '112', '7279', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7280', '1078', '1', 'Vaisigano', 'WS.11', 'NULL', '5403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5403', '112', '7280', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «WS.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7281', '1078', '1', 'Abyan', 'YE.01', 'NULL', '5404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5404', '112', '7281', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7282', '1078', '1', '‘Adan', 'YE.02', 'NULL', '5405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5405', '112', '7282', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7283', '1078', '1', 'Al Mahrah', 'YE.03', 'NULL', '5406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5406', '112', '7283', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7284', '1078', '1', 'Ḩaḑramawt', 'YE.04', 'NULL', '5407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5407', '112', '7284', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7285', '1078', '1', 'Shabwah', 'YE.05', 'NULL', '5408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5408', '112', '7285', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7286', '1078', '1', 'San’a’', 'YE.06', 'NULL', '5409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5409', '112', '7286', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7287', '1078', '1', 'Ta’izz', 'YE.07', 'NULL', '5410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5410', '112', '7287', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7288', '1078', '1', 'Al Ḩudaydah', 'YE.08', 'NULL', '5411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5411', '112', '7288', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7289', '1078', '1', 'Dhamar', 'YE.09', 'NULL', '5412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5412', '112', '7289', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7290', '1078', '1', 'Al Maḩwīt', 'YE.10', 'NULL', '5413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5413', '112', '7290', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7291', '1078', '1', 'Dhamār', 'YE.11', 'NULL', '5414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5414', '112', '7291', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7292', '1078', '1', '(YM12)', 'YE.12', 'NULL', '5415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5415', '112', '7292', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.12» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7293', '1078', '1', '(YM13)', 'YE.13', 'NULL', '5416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5416', '112', '7293', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.13» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7294', '1078', '1', 'Maʼrib', 'YE.14', 'NULL', '5417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5417', '112', '7294', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.14» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7295', '1078', '1', 'Şa‘dah', 'YE.15', 'NULL', '5418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5418', '112', '7295', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.15» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7296', '1078', '1', 'Şan‘āʼ', 'YE.16', 'NULL', '5419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5419', '112', '7296', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.16» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7297', '1078', '1', '(YM17)', 'YE.17', 'NULL', '5420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5420', '112', '7297', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.17» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7298', '1078', '1', 'Aḑ Ḑāli‘', 'YE.18', 'NULL', '5421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5421', '112', '7298', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.18» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7299', '1078', '1', 'Omran', 'YE.19', 'NULL', '5422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5422', '112', '7299', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.19» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7300', '1078', '1', 'Al Bayḑāʼ', 'YE.20', 'NULL', '5423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5423', '112', '7300', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.20» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7301', '1078', '1', 'Al Jawf', 'YE.21', 'NULL', '5424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5424', '112', '7301', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.21» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7302', '1078', '1', 'Ḩajjah', 'YE.22', 'NULL', '5425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5425', '112', '7302', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.22» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7303', '1078', '1', 'Ibb', 'YE.23', 'NULL', '5426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5426', '112', '7303', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.23» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7304', '1078', '1', 'Laḩij', 'YE.24', 'NULL', '5427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5427', '112', '7304', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.24» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7305', '1078', '1', 'Ta‘izz', 'YE.25', 'NULL', '5428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5428', '112', '7305', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.25» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7306', '1078', '1', 'Amanat Al Asimah', 'YE.26', 'NULL', '5429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5429', '112', '7306', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.26» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7307', '1078', '1', 'Muḩāfaz̧at Raymah', 'YE.27', 'NULL', '5430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5430', '112', '7307', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YE.27» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7308', '1078', '1', 'Mayotte (general)', 'YT.00', 'NULL', '5431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5431', '112', '7308', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «YT.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7309', '1078', '1', 'South Africa (general)', 'ZA.00', 'NULL', '5432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5432', '112', '7309', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7310', '1078', '1', 'North-Western Province', 'ZA.01', 'NULL', '5433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5433', '112', '7310', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7311', '1078', '1', 'KwaZulu-Natal', 'ZA.02', 'NULL', '5434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5434', '112', '7311', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7312', '1078', '1', 'Free State', 'ZA.03', 'NULL', '5435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5435', '112', '7312', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7313', '1078', '1', 'Southern Province', 'ZA.04', 'NULL', '5436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5436', '112', '7313', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7314', '1078', '1', 'Eastern Cape', 'ZA.05', 'NULL', '5437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5437', '112', '7314', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7315', '1078', '1', 'Gauteng', 'ZA.06', 'NULL', '5438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5438', '112', '7315', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7316', '1078', '1', 'Mpumalanga', 'ZA.07', 'NULL', '5439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5439', '112', '7316', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7317', '1078', '1', 'Northern Cape', 'ZA.08', 'NULL', '5440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5440', '112', '7317', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7318', '1078', '1', 'Limpopo', 'ZA.09', 'NULL', '5441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5441', '112', '7318', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7319', '1078', '1', 'North-West', 'ZA.10', 'NULL', '5442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5442', '112', '7319', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7320', '1078', '1', 'Western Cape', 'ZA.11', 'NULL', '5443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5443', '112', '7320', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZA.11» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7321', '1078', '1', 'Zambia (general)', 'ZM.00', 'NULL', '5444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5444', '112', '7321', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZM.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7322', '1078', '1', 'North-Western', 'ZM.01', 'NULL', '5445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5445', '112', '7322', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZM.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7323', '1078', '1', 'Copperbelt Province', 'ZM.02', 'NULL', '5446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5446', '112', '7323', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZM.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7324', '1078', '1', 'Western', 'ZM.03', 'NULL', '5447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5447', '112', '7324', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZM.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7325', '1078', '1', 'Southern', 'ZM.04', 'NULL', '5448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5448', '112', '7325', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZM.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7326', '1078', '1', 'Central', 'ZM.05', 'NULL', '5449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5449', '112', '7326', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZM.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7327', '1078', '1', 'Eastern', 'ZM.06', 'NULL', '5450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5450', '112', '7327', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZM.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7328', '1078', '1', 'Northern', 'ZM.07', 'NULL', '5451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5451', '112', '7328', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZM.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7329', '1078', '1', 'Luapula', 'ZM.08', 'NULL', '5452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5452', '112', '7329', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZM.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7330', '1078', '1', 'Lusaka', 'ZM.09', 'NULL', '5453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5453', '112', '7330', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZM.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7331', '1078', '1', 'Zimbabwe (general)', 'ZW.00', 'NULL', '5454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5454', '112', '7331', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.00» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7332', '1078', '1', 'Manicaland', 'ZW.01', 'NULL', '5455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5455', '112', '7332', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.01» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7333', '1078', '1', 'Midlands', 'ZW.02', 'NULL', '5456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5456', '112', '7333', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.02» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7334', '1078', '1', 'Mashonaland Central', 'ZW.03', 'NULL', '5457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5457', '112', '7334', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.03» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7335', '1078', '1', 'Mashonaland East', 'ZW.04', 'NULL', '5458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5458', '112', '7335', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.04» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7336', '1078', '1', 'Mashonaland West', 'ZW.05', 'NULL', '5459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5459', '112', '7336', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.05» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7337', '1078', '1', 'Matabeleland North', 'ZW.06', 'NULL', '5460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5460', '112', '7337', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.06» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7338', '1078', '1', 'Matabeleland South', 'ZW.07', 'NULL', '5461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5461', '112', '7338', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.07» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7339', '1078', '1', 'Masvingo', 'ZW.08', 'NULL', '5462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5462', '112', '7339', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.08» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7340', '1078', '1', 'Bulawayo', 'ZW.09', 'NULL', '5463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5463', '112', '7340', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.09» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7341', '1078', '1', 'Harare', 'ZW.10', 'NULL', '5464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5464', '112', '7341', NULL , '2009-07-29 00:00:00' , 'Initialisation de la valeur «ZW.10» pour la liste «75».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7342', '1079', '1', '`Alāqehdārī-ye Gīlān', 'AF.08.1140918', 'ASCII:`Alaqehdari-ye Gilan;ID:1140918', '5465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5465', '112', '7342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AF.08.1140918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7343', '1079', '1', 'Rrethi i Sarandës', 'AL.51.363245', 'ASCII:Rrethi i Sarandes;ID:363245', '5466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5466', '112', '7343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.51.363245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7344', '1079', '1', 'Rrethi i Delvinës', 'AL.51.414383', 'ASCII:Rrethi i Delvines;ID:414383', '5467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5467', '112', '7344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.51.414383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7345', '1079', '1', 'Rrethi i Tropojës', 'AL.47.781360', 'ASCII:Rrethi i Tropojes;ID:781360', '5468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5468', '112', '7345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.47.781360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7346', '1079', '1', 'Rrethi i Skraparit', 'AL.40.781574', 'ASCII:Rrethi i Skraparit;ID:781574', '5469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5469', '112', '7346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.40.781574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7347', '1079', '1', 'Rrethi i Pukës', 'AL.49.781913', 'ASCII:Rrethi i Pukes;ID:781913', '5470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5470', '112', '7347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.49.781913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7348', '1079', '1', 'Rrethi i Pogradecit', 'AL.46.781990', 'ASCII:Rrethi i Pogradecit;ID:781990', '5471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5471', '112', '7348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.46.781990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7349', '1079', '1', 'Rrethi i Përmetit', 'AL.45.782072', 'ASCII:Rrethi i Permetit;ID:782072', '5472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5472', '112', '7349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.45.782072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7350', '1079', '1', 'Rrethi i Mirditës', 'AL.48.782268', 'ASCII:Rrethi i Mirdites;ID:782268', '5473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5473', '112', '7350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.48.782268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7351', '1079', '1', 'Rrethi i Matit', 'AL.41.782345', 'ASCII:Rrethi i Matit;ID:782345', '5474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5474', '112', '7351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.41.782345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7352', '1079', '1', 'Rrethi i Librazhdit', 'AL.43.782521', 'ASCII:Rrethi i Librazhdit;ID:782521', '5475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5475', '112', '7352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.43.782521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7353', '1079', '1', 'Rrethi i Kukësit', 'AL.47.782662', 'ASCII:Rrethi i Kukesit;ID:782662', '5476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5476', '112', '7353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.47.782662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7354', '1079', '1', 'Rrethi i Korçës', 'AL.46.782758', 'ASCII:Rrethi i Korces;ID:782758', '5477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5477', '112', '7354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.46.782758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7355', '1079', '1', 'Rrethi i Kolonjës', 'AL.46.782775', 'ASCII:Rrethi i Kolonjes;ID:782775', '5478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5478', '112', '7355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.46.782775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7356', '1079', '1', 'Rrethi i Gramshit', 'AL.43.783060', 'ASCII:Rrethi i Gramshit;ID:783060', '5479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5479', '112', '7356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.43.783060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7357', '1079', '1', 'Rrethi i Gjirokastrës', 'AL.45.783151', 'ASCII:Rrethi i Gjirokastres;ID:783151', '5480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5480', '112', '7357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.45.783151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7358', '1079', '1', 'Rrethi i Elbasanit', 'AL.43.783265', 'ASCII:Rrethi i Elbasanit;ID:783265', '5481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5481', '112', '7358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.43.783265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7359', '1079', '1', 'Rrethi i Dibrës', 'AL.41.783346', 'ASCII:Rrethi i Dibres;ID:783346', '5482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5482', '112', '7359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.41.783346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7360', '1079', '1', 'Rrethi i Beratit', 'AL.40.783626', 'ASCII:Rrethi i Beratit;ID:783626', '5483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5483', '112', '7360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.40.783626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7361', '1079', '1', 'Rrethi i Hasit', 'AL.47.831098', 'ASCII:Rrethi i Hasit;ID:831098', '5484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5484', '112', '7361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.47.831098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7362', '1079', '1', 'Rrethi i Bulqizës', 'AL.41.831275', 'ASCII:Rrethi i Bulqizes;ID:831275', '5485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5485', '112', '7362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.41.831275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7363', '1079', '1', 'Rrethi i Devollit', 'AL.46.831276', 'ASCII:Rrethi i Devollit;ID:831276', '5486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5486', '112', '7363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.46.831276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7364', '1079', '1', 'Rrethi i Vlorës', 'AL.51.3183721', 'ASCII:Rrethi i Vlores;ID:3183721', '5487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5487', '112', '7364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.51.3183721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7365', '1079', '1', 'Bashkia e Tiranës', 'AL.50.3183878', 'ASCII:Bashkia e Tiranes;ID:3183878', '5488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5488', '112', '7365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.50.3183878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7366', '1079', '1', 'Rrethi i Tiranës', 'AL.50.3183879', 'ASCII:Rrethi i Tiranes;ID:3183879', '5489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5489', '112', '7366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.50.3183879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7367', '1079', '1', 'Rrethi i Tepelenës', 'AL.45.3183911', 'ASCII:Rrethi i Tepelenes;ID:3183911', '5490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5490', '112', '7367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.45.3183911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7368', '1079', '1', 'Rrethi i Shkodrës', 'AL.49.3184083', 'ASCII:Rrethi i Shkodres;ID:3184083', '5491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5491', '112', '7368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.49.3184083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7369', '1079', '1', 'Rrethi i Lushnjës', 'AL.44.3184864', 'ASCII:Rrethi i Lushnjes;ID:3184864', '5492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5492', '112', '7369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.44.3184864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7370', '1079', '1', 'Rrethi i Lezhës', 'AL.48.3184937', 'ASCII:Rrethi i Lezhes;ID:3184937', '5493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5493', '112', '7370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.48.3184937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7371', '1079', '1', 'Rrethi i Krujës', 'AL.42.3185084', 'ASCII:Rrethi i Krujes;ID:3185084', '5494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5494', '112', '7371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.42.3185084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7372', '1079', '1', 'Rrethi i Fierit', 'AL.44.3185674', 'ASCII:Rrethi i Fierit;ID:3185674', '5495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5495', '112', '7372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.44.3185674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7373', '1079', '1', 'Rrethi i Durrësit', 'AL.42.3185730', 'ASCII:Rrethi i Durresit;ID:3185730', '5496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5496', '112', '7373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.42.3185730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7374', '1079', '1', 'Rrethi i Kavajës', 'AL.50.3315068', 'ASCII:Rrethi i Kavajes;ID:3315068', '5497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5497', '112', '7374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.50.3315068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7375', '1079', '1', 'Rrethi i Kuçovës', 'AL.40.3315069', 'ASCII:Rrethi i Kucoves;ID:3315069', '5498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5498', '112', '7375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.40.3315069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7376', '1079', '1', 'Rrethi i Kurbinit', 'AL.48.3315070', 'ASCII:Rrethi i Kurbinit;ID:3315070', '5499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5499', '112', '7376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.48.3315070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7377', '1079', '1', 'Rrethi i Mallakastrës', 'AL.44.3316444', 'ASCII:Rrethi i Mallakastres;ID:3316444', '5500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5500', '112', '7377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.44.3316444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7378', '1079', '1', 'Rrethi i Malësia e Madhe', 'AL.49.3338383', 'ASCII:Rrethi i Malesia e Madhe;ID:3338383', '5501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5501', '112', '7378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.49.3338383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7379', '1079', '1', 'Rrethi i Peqinit', 'AL.43.3342179', 'ASCII:Rrethi i Peqinit;ID:3342179', '5502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5502', '112', '7379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AL.43.3342179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7380', '1079', '1', 'Spandaryanskiy Rayon', 'AM.11.616200', 'ASCII:Spandaryanskiy Rayon;ID:616200', '5503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5503', '112', '7380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AM.11.616200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7381', '1079', '1', 'Sovetskiy Rayon', 'AM.11.616205', 'ASCII:Sovetskiy Rayon;ID:616205', '5504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5504', '112', '7381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AM.11.616205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7382', '1079', '1', 'Shaumyanskiy Rayon', 'AM.11.616233', 'ASCII:Shaumyanskiy Rayon;ID:616233', '5505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5505', '112', '7382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AM.11.616233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7383', '1079', '1', 'Ordzhonikidzevskiy Rayon', 'AM.11.616323', 'ASCII:Ordzhonikidzevskiy Rayon;ID:616323', '5506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5506', '112', '7383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AM.11.616323» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7384', '1079', '1', 'Leninskiy Rayon', 'AM.11.616485', 'ASCII:Leninskiy Rayon;ID:616485', '5507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5507', '112', '7384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AM.11.616485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7385', '1079', '1', 'Imeni Dvadtsati Shesti Komissarov Rayon', 'AM.11.616624', 'ASCII:Imeni Dvadtsati Shesti Komissarov Rayon;ID:616624', '5508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5508', '112', '7385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AM.11.616624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7386', '1079', '1', 'Município Saurimo', 'AO.18.145530', 'ASCII:Municipio Saurimo;ID:145530', '5509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5509', '112', '7386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.18.145530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7387', '1079', '1', 'Município Lucapa', 'AO.17.145723', 'ASCII:Municipio Lucapa;ID:145723', '5510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5510', '112', '7387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.17.145723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7388', '1079', '1', 'Município Chitato', 'AO.17.145775', 'ASCII:Municipio Chitato;ID:145775', '5511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5511', '112', '7388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.17.145775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7389', '1079', '1', 'Município Cambulo', 'AO.17.145897', 'ASCII:Municipio Cambulo;ID:145897', '5512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5512', '112', '7389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.17.145897» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7390', '1079', '1', 'Município Rivungo', 'AO.14.875819', 'ASCII:Municipio Rivungo;ID:875819', '5513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5513', '112', '7390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.14.875819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7391', '1079', '1', 'Município Muconda', 'AO.18.875968', 'ASCII:Municipio Muconda;ID:875968', '5514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5514', '112', '7391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.18.875968» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7392', '1079', '1', 'Município Moxico', 'AO.14.875997', 'ASCII:Municipio Moxico;ID:875997', '5515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5515', '112', '7392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.14.875997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7393', '1079', '1', 'Município Mavinga', 'AO.04.876017', 'ASCII:Municipio Mavinga;ID:876017', '5516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5516', '112', '7393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.04.876017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7394', '1079', '1', 'Município Lumege', 'AO.14.876125', 'ASCII:Municipio Lumege;ID:876125', '5517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5517', '112', '7394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.14.876125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7395', '1079', '1', 'Município Lumbala N''guimbo', 'AO.14.876129', 'ASCII:Municipio Lumbala N''guimbo;ID:876129', '5518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5518', '112', '7395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.14.876129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7396', '1079', '1', 'Município Luau', 'AO.14.876176', 'ASCII:Municipio Luau;ID:876176', '5519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5519', '112', '7396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.14.876176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7397', '1079', '1', 'Município Luacano', 'AO.14.876198', 'ASCII:Municipio Luacano;ID:876198', '5520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5520', '112', '7397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.14.876198» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7398', '1079', '1', 'Município Léua', 'AO.14.876232', 'ASCII:Municipio Leua;ID:876232', '5521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5521', '112', '7398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.14.876232» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7399', '1079', '1', 'Município Dirico', 'AO.04.876291', 'ASCII:Municipio Dirico;ID:876291', '5522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5522', '112', '7399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.04.876291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7400', '1079', '1', 'Município Dala', 'AO.18.876307', 'ASCII:Municipio Dala;ID:876307', '5523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5523', '112', '7400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.18.876307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7401', '1079', '1', 'Município Camanongue', 'AO.14.876631', 'ASCII:Municipio Camanongue;ID:876631', '5524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5524', '112', '7401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.14.876631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7402', '1079', '1', 'Município Alto Zambeze', 'AO.14.876723', 'ASCII:Municipio Alto Zambeze;ID:876723', '5525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5525', '112', '7402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.14.876723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7403', '1079', '1', 'Município Xá-Muteba', 'AO.17.2236396', 'ASCII:Municipio Xa-Muteba;ID:2236396', '5526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5526', '112', '7403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.17.2236396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7404', '1079', '1', 'Município Viana', 'AO.10.2236499', 'ASCII:Viana;ID:2236499', '5527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5527', '112', '7404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.10.2236499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7405', '1079', '1', 'Município Uíge', 'AO.15.2236567', 'ASCII:Municipio Uige;ID:2236567', '5528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5528', '112', '7405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2236567» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7406', '1079', '1', 'Município Tomboco', 'AO.16.2236714', 'ASCII:Municipio Tomboco;ID:2236714', '5529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5529', '112', '7406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.16.2236714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7407', '1079', '1', 'Município Soyo', 'AO.16.2236966', 'ASCII:Municipio Soyo;ID:2236966', '5530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5530', '112', '7407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.16.2236966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7408', '1079', '1', 'Município Songo', 'AO.15.2236985', 'ASCII:Municipio Songo;ID:2236985', '5531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5531', '112', '7408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2236985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7409', '1079', '1', 'Município Sanza Pombo', 'AO.15.2237127', 'ASCII:Municipio Sanza Pombo;ID:2237127', '5532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5532', '112', '7409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2237127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7410', '1079', '1', 'Município Santa Cruz', 'AO.15.2237144', 'ASCII:Municipio Santa Cruz;ID:2237144', '5533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5533', '112', '7410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2237144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7411', '1079', '1', 'Município Quitexe', 'AO.15.2237499', 'ASCII:Municipio Quitexe;ID:2237499', '5534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5534', '112', '7411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2237499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7412', '1079', '1', 'Município Quimbele', 'AO.15.2238174', 'ASCII:Municipio Quimbele;ID:2238174', '5535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5535', '112', '7412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2238174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7413', '1079', '1', 'Município Quiculungo', 'AO.05.2238485', 'ASCII:Municipio Quiculungo;ID:2238485', '5536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5536', '112', '7413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2238485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7414', '1079', '1', 'Município Quicama', 'AO.19.2238564', 'ASCII:Municipio Quicama;ID:2238564', '5537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5537', '112', '7414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.19.2238564» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7415', '1079', '1', 'Município Quela', 'AO.12.2238814', 'ASCII:Municipio Quela;ID:2238814', '5538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5538', '112', '7415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.2238814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7416', '1079', '1', 'Município Puri', 'AO.15.2238826', 'ASCII:Municipio Puri;ID:2238826', '5539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5539', '112', '7416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2238826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7417', '1079', '1', 'Município Pango Aluquém', 'AO.05.2238950', 'ASCII:Municipio Pango Aluquem;ID:2238950', '5540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5540', '112', '7417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2238950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7418', '1079', '1', 'Município N''zeto', 'AO.16.2239000', 'ASCII:Municipio N''zeto;ID:2239000', '5541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5541', '112', '7418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.16.2239000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7419', '1079', '1', 'Município Nóqui', 'AO.16.2239019', 'ASCII:Municipio Noqui;ID:2239019', '5542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5542', '112', '7419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.16.2239019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7420', '1079', '1', 'Município Negage', 'AO.15.2239067', 'ASCII:Municipio Negage;ID:2239067', '5543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5543', '112', '7420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2239067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7421', '1079', '1', 'Município Nambuangongo', 'AO.19.2239093', 'ASCII:Municipio Nambuangongo;ID:2239093', '5544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5544', '112', '7421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.19.2239093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7422', '1079', '1', 'Município Mucari', 'AO.12.2239335', 'ASCII:Municipio Mucari;ID:2239335', '5545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5545', '112', '7422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.2239335» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7423', '1079', '1', 'Município Mucaba', 'AO.15.2239352', 'ASCII:Municipio Mucaba;ID:2239352', '5546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5546', '112', '7423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2239352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7424', '1079', '1', 'Município M''banza Congo', 'AO.16.2239519', 'ASCII:Municipio M''banza Congo;ID:2239519', '5547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5547', '112', '7424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.16.2239519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7425', '1079', '1', 'Município Massango', 'AO.12.2239696', 'ASCII:Municipio Massango;ID:2239696', '5548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5548', '112', '7425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.2239696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7426', '1079', '1', 'Município Marimba', 'AO.12.2239711', 'ASCII:Municipio Marimba;ID:2239711', '5549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5549', '112', '7426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.2239711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7427', '1079', '1', 'Muniípio Maquela do Zombo', 'AO.15.2239731', 'ASCII:Muniipio Maquela do Zombo;ID:2239731', '5550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5550', '112', '7427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2239731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7428', '1079', '1', 'Município Malanje', 'AO.12.2239859', 'ASCII:Municipio Malanje;ID:2239859', '5551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5551', '112', '7428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.2239859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7429', '1079', '1', 'Município Lucala', 'AO.05.2240384', 'ASCII:Municipio Lucala;ID:2240384', '5552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5552', '112', '7429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2240384» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7430', '1079', '1', 'Município Lubalo', 'AO.17.2240415', 'ASCII:Municipio Lubalo;ID:2240415', '5553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5553', '112', '7430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.17.2240415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7431', '1079', '1', 'Município Luanda', 'AO.10.2240445', 'ASCII:Municipio Luanda;ID:2240445', '5554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5554', '112', '7431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.10.2240445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7432', '1079', '1', 'Município Lândana', 'AO.03.2240660', 'ASCII:Municipio Landana;ID:2240660', '5555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5555', '112', '7432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.03.2240660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7433', '1079', '1', 'Município Kunda-dia-Baze', 'AO.12.2240685', 'ASCII:Municipio Kunda-dia-Baze;ID:2240685', '5556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5556', '112', '7433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.2240685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7434', '1079', '1', 'Município Kiwaba N''zogi', 'AO.12.2240688', 'ASCII:Municipio Kiwaba N''zogi;ID:2240688', '5557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5557', '112', '7434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.2240688» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7435', '1079', '1', 'Município Icoloe Bengo', 'AO.19.2240756', 'ASCII:Municipio Icoloe Bengo;ID:2240756', '5558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5558', '112', '7435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.19.2240756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7436', '1079', '1', 'Município Gonguembo', 'AO.05.2240905', 'ASCII:Municipio Gonguembo;ID:2240905', '5559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5559', '112', '7436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2240905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7437', '1079', '1', 'Município Golungo Alto', 'AO.05.2240974', 'ASCII:Municipio Golungo Alto;ID:2240974', '5560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5560', '112', '7437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2240974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7438', '1079', '1', 'Município Dembos', 'AO.05.2241454', 'ASCII:Municipio Dembos;ID:2241454', '5561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5561', '112', '7438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2241454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7439', '1079', '1', 'Município Dande', 'AO.19.2241484', 'ASCII:Municipio Dande;ID:2241484', '5562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5562', '112', '7439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.19.2241484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7440', '1079', '1', 'Município Damba', 'AO.15.2241498', 'ASCII:Municipio Damba;ID:2241498', '5563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5563', '112', '7440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2241498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7441', '1079', '1', 'Município Cuimba', 'AO.16.2241620', 'ASCII:Municipio Cuimba;ID:2241620', '5564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5564', '112', '7441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.16.2241620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7442', '1079', '1', 'Município Cuilo', 'AO.17.2241628', 'ASCII:Municipio Cuilo;ID:2241628', '5565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5565', '112', '7442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.17.2241628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7443', '1079', '1', 'Município Cuango', 'AO.17.2241665', 'ASCII:Municipio Cuango;ID:2241665', '5566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5566', '112', '7443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.17.2241665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7444', '1079', '1', 'Município Cazengo', 'AO.05.2241967', 'ASCII:Municipio Cazengo;ID:2241967', '5567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5567', '112', '7444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2241967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7445', '1079', '1', 'Município Caungula', 'AO.17.2242051', 'ASCII:Municipio Caungula;ID:2242051', '5568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5568', '112', '7445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.17.2242051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7446', '1079', '1', 'Município Capenda-Camulemba', 'AO.17.2242427', 'ASCII:Municipio Capenda-Camulemba;ID:2242427', '5569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5569', '112', '7446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.17.2242427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7447', '1079', '1', 'Município Caombo', 'AO.12.2242475', 'ASCII:Municipio Caombo;ID:2242475', '5570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5570', '112', '7447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.2242475» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7448', '1079', '1', 'Município Cambambe', 'AO.05.2242801', 'ASCII:Municipio Cambambe;ID:2242801', '5571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5571', '112', '7448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2242801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7449', '1079', '1', 'Município Calandula', 'AO.12.2242997', 'ASCII:Municipio Calandula;ID:2242997', '5572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5572', '112', '7449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.2242997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7450', '1079', '1', 'Município Cacuso', 'AO.12.2243120', 'ASCII:Municipio Cacuso;ID:2243120', '5573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5573', '112', '7450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.2243120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7451', '1079', '1', 'Município Cacuaco', 'AO.10.2243171', 'ASCII:Municipio Cacuaco;ID:2243171', '5574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5574', '112', '7451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.10.2243171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7452', '1079', '1', 'Município Cabinda', 'AO.03.2243267', 'ASCII:Municipio Cabinda;ID:2243267', '5575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5575', '112', '7452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.03.2243267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7453', '1079', '1', 'Município Bungo', 'AO.15.2243355', 'ASCII:Municipio Bungo;ID:2243355', '5576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5576', '112', '7453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2243355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7454', '1079', '1', 'Município Bula Atumba', 'AO.05.2243420', 'ASCII:Municipio Bula Atumba;ID:2243420', '5577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5577', '112', '7454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2243420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7455', '1079', '1', 'Município Buengas', 'AO.15.2243441', 'ASCII:Municipio Buengas;ID:2243441', '5578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5578', '112', '7455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2243441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7456', '1079', '1', 'Município Buco Zau', 'AO.03.2243457', 'ASCII:Municipio Buco Zau;ID:2243457', '5579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5579', '112', '7456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.03.2243457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7457', '1079', '1', 'Município Bolongongo', 'AO.05.2243535', 'ASCII:Municipio Bolongongo;ID:2243535', '5580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5580', '112', '7457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2243535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7458', '1079', '1', 'Município Bembe', 'AO.15.2243631', 'ASCII:Municipio Bembe;ID:2243631', '5581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5581', '112', '7458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2243631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7459', '1079', '1', 'Concelho doBembe, Município Bembe', 'AO.15.2243632', 'ASCII:Concelho doBembe, Municipio Bembe;ID:2243632', '5582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5582', '112', '7459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2243632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7460', '1079', '1', 'Município Belize', 'AO.03.2243645', 'ASCII:Municipio Belize;ID:2243645', '5583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5583', '112', '7460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.03.2243645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7461', '1079', '1', 'Município Banga', 'AO.05.2243811', 'ASCII:Municipio Banga;ID:2243811', '5584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5584', '112', '7461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2243811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7462', '1079', '1', 'Município Ambuila', 'AO.15.2243908', 'ASCII:Municipio Ambuila;ID:2243908', '5585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5585', '112', '7462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2243908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7463', '1079', '1', 'Município Ambriz', 'AO.19.2243911', 'ASCII:Municipio Ambriz;ID:2243911', '5586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5586', '112', '7463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.19.2243911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7464', '1079', '1', 'Município Ambaca', 'AO.05.2243916', 'ASCII:Municipio Ambaca;ID:2243916', '5587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5587', '112', '7464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.05.2243916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7465', '1079', '1', 'Município Alto Cauale', 'AO.15.2243921', 'ASCII:Municipio Alto Cauale;ID:2243921', '5588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5588', '112', '7465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.15.2243921» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7466', '1079', '1', 'Município Waku Kungo', 'AO.06.3345496', 'ASCII:Municipio Waku Kungo;ID:3345496', '5589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5589', '112', '7466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3345496» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7467', '1079', '1', 'Município Virei', 'AO.13.3345516', 'ASCII:Municipio Virei;ID:3345516', '5590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5590', '112', '7467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.13.3345516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7468', '1079', '1', 'Município Ukuma', 'AO.08.3345667', 'ASCII:Municipio Ukuma;ID:3345667', '5591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5591', '112', '7468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3345667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7469', '1079', '1', 'Município Tombua', 'AO.13.3345788', 'ASCII:Municipio Tombua;ID:3345788', '5592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5592', '112', '7469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.13.3345788» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7470', '1079', '1', 'Município Tchindjenje', 'AO.08.3345909', 'ASCII:Municipio Tchindjenje;ID:3345909', '5593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5593', '112', '7470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3345909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7471', '1079', '1', 'Município Tchikala-Tcholohanga', 'AO.08.3345923', 'ASCII:Municipio Tchikala-Tcholohanga;ID:3345923', '5594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5594', '112', '7471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3345923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7472', '1079', '1', 'Município Sumbe', 'AO.06.3346014', 'ASCII:Municipio Sumbe;ID:3346014', '5595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5595', '112', '7472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3346014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7473', '1079', '1', 'Município Seles', 'AO.06.3346113', 'ASCII:Municipio Seles;ID:3346113', '5596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5596', '112', '7473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3346113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7474', '1079', '1', 'Município Quirima', 'AO.12.3346489', 'ASCII:Municipio Quirima;ID:3346489', '5597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5597', '112', '7474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.3346489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7475', '1079', '1', 'Município Quipungo', 'AO.09.3346496', 'ASCII:Municipio Quipungo;ID:3346496', '5598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5598', '112', '7475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3346496» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7476', '1079', '1', 'Município Quilengues', 'AO.09.3346556', 'ASCII:Municipio Quilengues;ID:3346556', '5599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5599', '112', '7476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3346556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7477', '1079', '1', 'Município Quilenda', 'AO.06.3346558', 'ASCII:Municipio Quilenda;ID:3346558', '5600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5600', '112', '7477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3346558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7478', '1079', '1', 'Município Quibala', 'AO.06.3346597', 'ASCII:Municipio Quibala;ID:3346597', '5601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5601', '112', '7478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3346597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7479', '1079', '1', 'Município Porto Amboim', 'AO.06.3346659', 'ASCII:Municipio Porto Amboim;ID:3346659', '5602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5602', '112', '7479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3346659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7480', '1079', '1', 'Município Ombadja', 'AO.07.3346850', 'ASCII:Municipio Ombadja;ID:3346850', '5603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5603', '112', '7480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.07.3346850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7481', '1079', '1', 'Município N''harea', 'AO.02.3346941', 'ASCII:Municipio N''harea;ID:3346941', '5604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5604', '112', '7481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.02.3346941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7482', '1079', '1', 'Município Nankova', 'AO.04.3347005', 'ASCII:Municipio Nankova;ID:3347005', '5605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5605', '112', '7482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.04.3347005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7483', '1079', '1', 'Município Namibe', 'AO.13.3347017', 'ASCII:Municipio Namibe;ID:3347017', '5606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5606', '112', '7483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.13.3347017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7484', '1079', '1', 'Município Namacunde', 'AO.07.3347028', 'ASCII:Municipio Namacunde;ID:3347028', '5607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5607', '112', '7484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.07.3347028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7485', '1079', '1', 'Município Mussende', 'AO.06.3347070', 'ASCII:Municipio Mussende;ID:3347070', '5608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5608', '112', '7485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3347070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7486', '1079', '1', 'Município Mungo', 'AO.08.3347110', 'ASCII:Municipio Mungo;ID:3347110', '5609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5609', '112', '7486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3347110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7487', '1079', '1', 'Município Menongue', 'AO.04.3347352', 'ASCII:Municipio Menongue;ID:3347352', '5610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5610', '112', '7487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.04.3347352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7488', '1079', '1', 'Município Matala', 'AO.09.3347423', 'ASCII:Municipio Matala;ID:3347423', '5611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5611', '112', '7488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3347423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7489', '1079', '1', 'Município Luquembo', 'AO.12.3347614', 'ASCII:Municipio Luquembo;ID:3347614', '5612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5612', '112', '7489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.3347614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7490', '1079', '1', 'Município Luchazes', 'AO.14.3347741', 'ASCII:Municipio Luchazes;ID:3347741', '5613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5613', '112', '7490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.14.3347741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7491', '1079', '1', 'Município Lubango', 'AO.09.3347760', 'ASCII:Municipio Lubango;ID:3347760', '5614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5614', '112', '7491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3347760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7492', '1079', '1', 'Município Longonjo', 'AO.08.3347852', 'ASCII:Municipio Longonjo;ID:3347852', '5615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5615', '112', '7492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3347852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7493', '1079', '1', 'Município Londuimbali', 'AO.08.3347879', 'ASCII:Municipio Londuimbali;ID:3347879', '5616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5616', '112', '7493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3347879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7494', '1079', '1', 'Município Lobito', 'AO.01.3347937', 'ASCII:Municipio Lobito;ID:3347937', '5617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5617', '112', '7494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.01.3347937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7495', '1079', '1', 'Município Libolo', 'AO.06.3347989', 'ASCII:Municipio Libolo;ID:3347989', '5618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5618', '112', '7495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3347989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7496', '1079', '1', 'Município Kuvango', 'AO.09.3348075', 'ASCII:Municipio Kuvango;ID:3348075', '5619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5619', '112', '7496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3348075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7497', '1079', '1', 'Município Kuito', 'AO.02.3348077', 'ASCII:Municipio Kuito;ID:3348077', '5620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5620', '112', '7497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.02.3348077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7498', '1079', '1', 'Município Katchiungo', 'AO.08.3348093', 'ASCII:Municipio Katchiungo;ID:3348093', '5621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5621', '112', '7498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3348093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7499', '1079', '1', 'Município Jamba', 'AO.09.3348165', 'ASCII:Municipio Jamba;ID:3348165', '5622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5622', '112', '7499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3348165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7500', '1079', '1', 'Município Humpata', 'AO.09.3348286', 'ASCII:Municipio Humpata;ID:3348286', '5623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5623', '112', '7500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3348286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7501', '1079', '1', 'Município Huambo', 'AO.08.3348311', 'ASCII:Municipio Huambo;ID:3348311', '5624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5624', '112', '7501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3348311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7502', '1079', '1', 'Município Ganda', 'AO.01.3348578', 'ASCII:Municipio Ganda;ID:3348578', '5625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5625', '112', '7502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.01.3348578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7503', '1079', '1', 'Município Ekunha', 'AO.08.3348773', 'ASCII:Municipio Ekunha;ID:3348773', '5626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5626', '112', '7503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3348773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7504', '1079', '1', 'Município Ebo', 'AO.06.3348792', 'ASCII:Municipio Ebo;ID:3348792', '5627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5627', '112', '7504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3348792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7505', '1079', '1', 'Município Cuvelai', 'AO.07.3348986', 'ASCII:Municipio Cuvelai;ID:3348986', '5628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5628', '112', '7505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.07.3348986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7506', '1079', '1', 'Município Curoca', 'AO.07.3349045', 'ASCII:Municipio Curoca;ID:3349045', '5629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5629', '112', '7506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.07.3349045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7507', '1079', '1', 'Município Cunhinga', 'AO.02.3349078', 'ASCII:Municipio Cunhinga;ID:3349078', '5630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5630', '112', '7507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.02.3349078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7508', '1079', '1', 'Município Cuito Cuanavale', 'AO.04.3349148', 'ASCII:Municipio Cuito Cuanavale;ID:3349148', '5631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5631', '112', '7508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.04.3349148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7509', '1079', '1', 'Município Cuemba', 'AO.02.3349179', 'ASCII:Municipio Cuemba;ID:3349179', '5632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5632', '112', '7509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.02.3349179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7510', '1079', '1', 'Município Cuchi', 'AO.04.3349195', 'ASCII:Municipio Cuchi;ID:3349195', '5633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5633', '112', '7510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.04.3349195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7511', '1079', '1', 'Município Cubal', 'AO.01.3349225', 'ASCII:Municipio Cubal;ID:3349225', '5634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5634', '112', '7511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.01.3349225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7512', '1079', '1', 'Município Cuanhama', 'AO.07.3349237', 'ASCII:Municipio Cuanhama;ID:3349237', '5635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5635', '112', '7512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.07.3349237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7513', '1079', '1', 'Município Cuangar', 'AO.04.3349243', 'ASCII:Municipio Cuangar;ID:3349243', '5636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5636', '112', '7513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.04.3349243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7514', '1079', '1', 'Município Conda', 'AO.06.3349321', 'ASCII:Municipio Conda;ID:3349321', '5637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5637', '112', '7514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3349321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7515', '1079', '1', 'Município Chongoroi', 'AO.01.3349404', 'ASCII:Municipio Chongoroi;ID:3349404', '5638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5638', '112', '7515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.01.3349404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7516', '1079', '1', 'Município Chitembo', 'AO.02.3349514', 'ASCII:Municipio Chitembo;ID:3349514', '5639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5639', '112', '7516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.02.3349514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7517', '1079', '1', 'Município Chipindo', 'AO.09.3349647', 'ASCII:Municipio Chipindo;ID:3349647', '5640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5640', '112', '7517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3349647» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7518', '1079', '1', 'Município Chinguar', 'AO.02.3349722', 'ASCII:Municipio Chinguar;ID:3349722', '5641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5641', '112', '7518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.02.3349722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7519', '1079', '1', 'Município Chicomba', 'AO.09.3349949', 'ASCII:Municipio Chicomba;ID:3349949', '5642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5642', '112', '7519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3349949» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7520', '1079', '1', 'Município Chibia', 'AO.09.3349996', 'ASCII:Municipio Chibia;ID:3349996', '5643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5643', '112', '7520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3349996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7521', '1079', '1', 'Município Chiange', 'AO.09.3350009', 'ASCII:Municipio Chiange;ID:3350009', '5644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5644', '112', '7521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3350009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7522', '1079', '1', 'Município Catabola', 'AO.02.3350370', 'ASCII:Municipio Catabola;ID:3350370', '5645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5645', '112', '7522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.02.3350370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7523', '1079', '1', 'Município Cassongue', 'AO.06.3350385', 'ASCII:Municipio Cassongue;ID:3350385', '5646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5646', '112', '7523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3350385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7524', '1079', '1', 'Município Cangandala', 'AO.12.3350771', 'ASCII:Municipio Cangandala;ID:3350771', '5647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5647', '112', '7524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.3350771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7525', '1079', '1', 'Município Cambundi-Catembo', 'AO.12.3350916', 'ASCII:Municipio Cambundi-Catembo;ID:3350916', '5648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5648', '112', '7525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.12.3350916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7526', '1079', '1', 'Município Camacupa', 'AO.02.3351012', 'ASCII:Municipio Camacupa;ID:3351012', '5649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5649', '112', '7526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.02.3351012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7527', '1079', '1', 'Concelho deCamacupa, Município Camacupa', 'AO.02.3351013', 'ASCII:Concelho deCamacupa, Municipio Camacupa;ID:3351013', '5650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5650', '112', '7527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.02.3351013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7528', '1079', '1', 'Município Camacuio', 'AO.13.3351015', 'ASCII:Municipio Camacuio;ID:3351015', '5651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5651', '112', '7528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.13.3351015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7529', '1079', '1', 'Município Caluquembe', 'AO.09.3351021', 'ASCII:Municipio Caluquembe;ID:3351021', '5652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5652', '112', '7529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3351021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7530', '1079', '1', 'Mnuicípio Calai', 'AO.04.3351214', 'ASCII:Mnuicipio Calai;ID:3351214', '5653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5653', '112', '7530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.04.3351214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7531', '1079', '1', 'Município Caimbambo', 'AO.01.3351267', 'ASCII:Municipio Caimbambo;ID:3351267', '5654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5654', '112', '7531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.01.3351267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7532', '1079', '1', 'Município Cahama', 'AO.07.3351306', 'ASCII:Municipio Cahama;ID:3351306', '5655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5655', '112', '7532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.07.3351306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7533', '1079', '1', 'Município Caconda', 'AO.09.3351379', 'ASCII:Municipio Caconda;ID:3351379', '5656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5656', '112', '7533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.09.3351379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7534', '1079', '1', 'Município Cacolo', 'AO.18.3351386', 'ASCII:Municipio Cacolo;ID:3351386', '5657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5657', '112', '7534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.18.3351386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7535', '1079', '1', 'Município Caála', 'AO.08.3351497', 'ASCII:Municipio Caala;ID:3351497', '5658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5658', '112', '7535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3351497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7536', '1079', '1', 'Município Bocoio', 'AO.01.3351597', 'ASCII:Municipio Bocoio;ID:3351597', '5659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5659', '112', '7536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.01.3351597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7537', '1079', '1', 'Município Bibala', 'AO.13.3351646', 'ASCII:Municipio Bibala;ID:3351646', '5660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5660', '112', '7537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.13.3351646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7538', '1079', '1', 'Município Benguela', 'AO.01.3351661', 'ASCII:Municipio Benguela;ID:3351661', '5661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5661', '112', '7538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.01.3351661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7539', '1079', '1', 'Município Balombo', 'AO.01.3351758', 'ASCII:Municipio Balombo;ID:3351758', '5662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5662', '112', '7539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.01.3351758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7540', '1079', '1', 'Circunscrição doBalombo, Município Balombo', 'AO.01.3351760', 'ASCII:Circunscricao doBalombo, Municipio Balombo;ID:3351760', '5663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5663', '112', '7540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.01.3351760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7541', '1079', '1', 'Município Bailundo', 'AO.08.3351782', 'ASCII:Municipio Bailundo;ID:3351782', '5664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5664', '112', '7541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.08.3351782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7542', '1079', '1', 'Município Baía Farta', 'AO.01.3351785', 'ASCII:Municipio Baia Farta;ID:3351785', '5665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5665', '112', '7542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.01.3351785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7543', '1079', '1', 'Município Andulo', 'AO.02.3351882', 'ASCII:Municipio Andulo;ID:3351882', '5666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5666', '112', '7543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.02.3351882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7544', '1079', '1', 'Município Amboim', 'AO.06.3351905', 'ASCII:Municipio Amboim;ID:3351905', '5667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5667', '112', '7544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AO.06.3351905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7545', '1079', '1', 'Partido de Zárate', 'AR.01.3427212', 'ASCII:Partido de Zarate;ID:3427212', '5668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5668', '112', '7545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3427212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7546', '1079', '1', 'Departamento de Villaguay', 'AR.08.3427426', 'ASCII:Departamento de Villaguay;ID:3427426', '5669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5669', '112', '7546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3427426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7547', '1079', '1', 'Partido de Vicente López', 'AR.01.3427504', 'ASCII:Partido de Vicente Lopez;ID:3427504', '5670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5670', '112', '7547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3427504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7548', '1079', '1', 'Partido de Veinticinco de Mayo', 'AR.03.3427532', 'ASCII:Partido de Veinticinco de Mayo;ID:3427532', '5671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5671', '112', '7548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3427532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7549', '1079', '1', 'Departamento de Veinticinco de Mayo', 'AR.14.3427535', 'ASCII:Departamento de Veinticinco de Mayo;ID:3427535', '5672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5672', '112', '7549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3427535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7550', '1079', '1', 'Departamento de Uruguay', 'AR.08.3427576', 'ASCII:Departamento de Uruguay;ID:3427576', '5673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5673', '112', '7550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3427576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7551', '1079', '1', 'Partido de Tres de Febrero', 'AR.01.3427655', 'ASCII:Partido de Tres de Febrero;ID:3427655', '5674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5674', '112', '7551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3427655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7552', '1079', '1', 'Partido de Tordillo', 'AR.01.3427709', 'ASCII:Partido de Tordillo;ID:3427709', '5675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5675', '112', '7552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3427709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7553', '1079', '1', 'Partido de Tigre', 'AR.01.3427753', 'ASCII:Partido de Tigre;ID:3427753', '5676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5676', '112', '7553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3427753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7554', '1079', '1', 'Partido de Tapenagá', 'AR.03.3427822', 'ASCII:Partido de Tapenaga;ID:3427822', '5677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5677', '112', '7554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3427822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7555', '1079', '1', 'Partido de Tandil', 'AR.01.3427832', 'ASCII:Partido de Tandil;ID:3427832', '5678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5678', '112', '7555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3427832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7556', '1079', '1', 'Departamento de Tala', 'AR.08.3427856', 'ASCII:Departamento de Tala;ID:3427856', '5679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5679', '112', '7556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3427856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7557', '1079', '1', 'Partido de Suipacha', 'AR.01.3427896', 'ASCII:Partido de Suipacha;ID:3427896', '5680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5680', '112', '7557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3427896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7558', '1079', '1', 'Departamento de Sauce', 'AR.06.3428003', 'ASCII:Departamento de Sauce;ID:3428003', '5681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5681', '112', '7558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3428003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7559', '1079', '1', 'Partido de Sargento Cabral', 'AR.03.3428032', 'ASCII:Partido de Sargento Cabral;ID:3428032', '5682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5682', '112', '7559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3428032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7560', '1079', '1', 'Partido de San Vicente', 'AR.01.3428056', 'ASCII:Partido de San Vicente;ID:3428056', '5683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5683', '112', '7560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3428056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7561', '1079', '1', 'Departamento de Santo Tomé', 'AR.06.3428070', 'ASCII:Departamento de Santo Tome;ID:3428070', '5684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5684', '112', '7561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3428070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7562', '1079', '1', 'Departamento de San Roque', 'AR.06.3428491', 'ASCII:Departamento de San Roque;ID:3428491', '5685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5685', '112', '7562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3428491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7563', '1079', '1', 'Partido de San Pedro', 'AR.01.3428533', 'ASCII:Partido de San Pedro;ID:3428533', '5686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5686', '112', '7563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3428533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7564', '1079', '1', 'Departamento de San Pedro', 'AR.14.3428569', 'ASCII:Departamento de San Pedro;ID:3428569', '5687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5687', '112', '7564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3428569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7565', '1079', '1', 'Departamento de San Miguel', 'AR.06.3428638', 'ASCII:Departamento de San Miguel;ID:3428638', '5688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5688', '112', '7565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3428638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7566', '1079', '1', 'Departamento de San Martín', 'AR.06.3428679', 'ASCII:Departamento de San Martin;ID:3428679', '5689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5689', '112', '7566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3428679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7567', '1079', '1', 'Departamento de San Luis del Palmar', 'AR.06.3428707', 'ASCII:Departamento de San Luis del Palmar;ID:3428707', '5690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5690', '112', '7567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3428707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7568', '1079', '1', 'Departamento de San Javier', 'AR.21.3428973', 'ASCII:Departamento de San Javier;ID:3428973', '5691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5691', '112', '7568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3428973» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7569', '1079', '1', 'Departamento de San Javier', 'AR.14.3428974', 'ASCII:Departamento de San Javier;ID:3428974', '5692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5692', '112', '7569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3428974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7570', '1079', '1', 'Partido de San Isidro', 'AR.01.3428983', 'ASCII:Partido de San Isidro;ID:3428983', '5693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5693', '112', '7570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3428983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7571', '1079', '1', 'Departamento de San Ignacio', 'AR.14.3429014', 'ASCII:Departamento de San Ignacio;ID:3429014', '5694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5694', '112', '7571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3429014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7572', '1079', '1', 'Partido de San Fernando', 'AR.01.3429088', 'ASCII:Partido de San Fernando;ID:3429088', '5695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5695', '112', '7572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3429088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7573', '1079', '1', 'Partido de San Fernando', 'AR.03.3429089', 'ASCII:Partido de San Fernando;ID:3429089', '5696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5696', '112', '7573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3429089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7574', '1079', '1', 'Departamento de San Cosme', 'AR.06.3429156', 'ASCII:Departamento de San Cosme;ID:3429156', '5697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5697', '112', '7574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3429156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7575', '1079', '1', 'Partido de San Cayetano', 'AR.01.3429168', 'ASCII:Partido de San Cayetano;ID:3429168', '5698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5698', '112', '7575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3429168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7576', '1079', '1', 'Partido de San Antonio de Areco', 'AR.01.3429247', 'ASCII:Partido de San Antonio de Areco;ID:3429247', '5699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5699', '112', '7576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3429247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7577', '1079', '1', 'Partido de San Andrés de Giles', 'AR.01.3429308', 'ASCII:Partido de San Andres de Giles;ID:3429308', '5700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5700', '112', '7577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3429308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7578', '1079', '1', 'Partido de Saladillo', 'AR.01.3429389', 'ASCII:Partido de Saladillo;ID:3429389', '5701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5701', '112', '7578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3429389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7579', '1079', '1', 'Departamento de Saladas', 'AR.06.3429402', 'ASCII:Departamento de Saladas;ID:3429402', '5702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5702', '112', '7579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3429402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7580', '1079', '1', 'Partido de Roque Pérez', 'AR.01.3429449', 'ASCII:Partido de Roque Perez;ID:3429449', '5703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5703', '112', '7580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3429449» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7581', '1079', '1', 'Partido de Rauch', 'AR.01.3429601', 'ASCII:Partido de Rauch;ID:3429601', '5704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5704', '112', '7581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3429601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7582', '1079', '1', 'Partido de Quilmes', 'AR.01.3429651', 'ASCII:Partido de Quilmes;ID:3429651', '5705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5705', '112', '7582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3429651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7583', '1079', '1', 'Partido Primero de Mayo', 'AR.03.3429850', 'ASCII:Partido Primero de Mayo;ID:3429850', '5706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5706', '112', '7583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3429850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7584', '1079', '1', 'Partido de Presidencia de la Plaza', 'AR.03.3429865', 'ASCII:Partido de Presidencia de la Plaza;ID:3429865', '5707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5707', '112', '7584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3429865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7585', '1079', '1', 'Departamento de Pirané', 'AR.09.3429948', 'ASCII:Departamento de Pirane;ID:3429948', '5708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5708', '112', '7585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.09.3429948» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7586', '1079', '1', 'Departamento de Pilcomayo', 'AR.09.3429978', 'ASCII:Departamento de Pilcomayo;ID:3429978', '5709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5709', '112', '7586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.09.3429978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7587', '1079', '1', 'Partido de Pilar', 'AR.01.3429979', 'ASCII:Partido de Pilar;ID:3429979', '5710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5710', '112', '7587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3429979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7588', '1079', '1', 'Departamento de Pilagás', 'AR.09.3429982', 'ASCII:Departamento de Pilagas;ID:3429982', '5711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5711', '112', '7588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.09.3429982» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7589', '1079', '1', 'Partido de Pila', 'AR.01.3429987', 'ASCII:Partido de Pila;ID:3429987', '5712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5712', '112', '7589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3429987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7590', '1079', '1', 'Departamento de Patiño', 'AR.09.3430084', 'ASCII:Departamento de Patino;ID:3430084', '5713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5713', '112', '7590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.09.3430084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7591', '1079', '1', 'Departamento de Paso de los Libres', 'AR.06.3430103', 'ASCII:Departamento de Paso de los Libres;ID:3430103', '5714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5714', '112', '7591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3430103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7592', '1079', '1', 'Departamento de Paraná', 'AR.08.3430146', 'ASCII:Departamento de Parana;ID:3430146', '5715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5715', '112', '7592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3430146» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7593', '1079', '1', 'Departamento de Oberá', 'AR.14.3430339', 'ASCII:Departamento de Obera;ID:3430339', '5716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5716', '112', '7593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3430339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7594', '1079', '1', 'Departamento de Nogoyá', 'AR.08.3430412', 'ASCII:Departamento de Nogoya;ID:3430412', '5717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5717', '112', '7594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3430412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7595', '1079', '1', 'Partido de Necochea', 'AR.01.3430442', 'ASCII:Partido de Necochea;ID:3430442', '5718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5718', '112', '7595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7596', '1079', '1', 'Partido de Navarro', 'AR.01.3430454', 'ASCII:Partido de Navarro;ID:3430454', '5719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5719', '112', '7596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7597', '1079', '1', 'Partido de Morón', 'AR.01.3430544', 'ASCII:Partido de Moron;ID:3430544', '5720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5720', '112', '7597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7598', '1079', '1', 'Partido de Moreno', 'AR.01.3430550', 'ASCII:Partido de Moreno;ID:3430550', '5721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5721', '112', '7598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7599', '1079', '1', 'Departamento de Monte Caseros', 'AR.06.3430597', 'ASCII:Departamento de Monte Caseros;ID:3430597', '5722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5722', '112', '7599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3430597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7600', '1079', '1', 'Departamento de Montecarlo', 'AR.14.3430599', 'ASCII:Departamento de Montecarlo;ID:3430599', '5723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5723', '112', '7600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3430599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7601', '1079', '1', 'Partido de Monte', 'AR.01.3430604', 'ASCII:Partido de Monte;ID:3430604', '5724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5724', '112', '7601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7602', '1079', '1', 'Partido de Merlo', 'AR.01.3430696', 'ASCII:Partido de Merlo;ID:3430696', '5725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5725', '112', '7602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7603', '1079', '1', 'Partido de Mercedes', 'AR.01.3430705', 'ASCII:Partido de Mercedes;ID:3430705', '5726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5726', '112', '7603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7604', '1079', '1', 'Departamento de Mercedes', 'AR.06.3430706', 'ASCII:Departamento de Mercedes;ID:3430706', '5727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5727', '112', '7604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3430706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7605', '1079', '1', 'Departamento de Mburucuyá', 'AR.06.3430759', 'ASCII:Departamento de Mburucuya;ID:3430759', '5728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5728', '112', '7605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3430759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7606', '1079', '1', 'Partido de Matanza', 'AR.01.3430786', 'ASCII:Partido de Matanza;ID:3430786', '5729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5729', '112', '7606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7607', '1079', '1', 'Partido de Marcos Paz', 'AR.01.3430867', 'ASCII:Partido de Marcos Paz;ID:3430867', '5730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5730', '112', '7607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7608', '1079', '1', 'Partido de Mar Chiquita', 'AR.01.3430869', 'ASCII:Partido de Mar Chiquita;ID:3430869', '5731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5731', '112', '7608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7609', '1079', '1', 'Partido de Maipú', 'AR.01.3430945', 'ASCII:Partido de Maipu;ID:3430945', '5732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5732', '112', '7609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7610', '1079', '1', 'Partido de Magdalena', 'AR.01.3430951', 'ASCII:Partido de Magdalena;ID:3430951', '5733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5733', '112', '7610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7611', '1079', '1', 'Partido de Luján', 'AR.01.3430982', 'ASCII:Partido de Lujan;ID:3430982', '5734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5734', '112', '7611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3430982» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7612', '1079', '1', 'Partido de Lomas de Zamora', 'AR.01.3431270', 'ASCII:Partido de Lomas de Zamora;ID:3431270', '5735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5735', '112', '7612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3431270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7613', '1079', '1', 'Partido de Lobos', 'AR.01.3431309', 'ASCII:Partido de Lobos;ID:3431309', '5736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5736', '112', '7613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3431309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7614', '1079', '1', 'Partido de Lobería', 'AR.01.3431318', 'ASCII:Partido de Loberia;ID:3431318', '5737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5737', '112', '7614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3431318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7615', '1079', '1', 'Partido de Libertador General San Martín', 'AR.03.3431356', 'ASCII:Partido de Libertador General San Martin;ID:3431356', '5738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5738', '112', '7615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3431356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7616', '1079', '1', 'Departamento de Libertador General San Martín', 'AR.14.3431357', 'ASCII:Departamento de Libertador General San Martin;ID:3431357', '5739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5739', '112', '7616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3431357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7617', '1079', '1', 'Partido de Libertad', 'AR.03.3431359', 'ASCII:Partido de Libertad;ID:3431359', '5740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5740', '112', '7617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3431359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7618', '1079', '1', 'Departamento de Leandro N. Alem', 'AR.14.3431390', 'ASCII:Departamento de Leandro N. Alem;ID:3431390', '5741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5741', '112', '7618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3431390» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7619', '1079', '1', 'Departamento de Lavalle', 'AR.06.3431468', 'ASCII:Departamento de Lavalle;ID:3431468', '5742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5742', '112', '7619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3431468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7620', '1079', '1', 'Partido de Las Flores', 'AR.01.3431782', 'ASCII:Partido de Las Flores;ID:3431782', '5743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5743', '112', '7620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3431782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7621', '1079', '1', 'Partido de La Plata', 'AR.01.3432039', 'ASCII:Partido de La Plata;ID:3432039', '5744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5744', '112', '7621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3432039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7622', '1079', '1', 'Departamento de La Paz', 'AR.08.3432077', 'ASCII:Departamento de La Paz;ID:3432077', '5745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5745', '112', '7622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3432077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7623', '1079', '1', 'Partido de Lanús', 'AR.01.3432134', 'ASCII:Partido de Lanus;ID:3432134', '5746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5746', '112', '7623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3432134» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7624', '1079', '1', 'Departamento de Laishí', 'AR.09.3432407', 'ASCII:Departamento de Laishi;ID:3432407', '5747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5747', '112', '7624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.09.3432407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7625', '1079', '1', 'Partido de Juárez', 'AR.01.3433284', 'ASCII:Partido de Juarez;ID:3433284', '5748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5748', '112', '7625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7626', '1079', '1', 'Departamento de Ituzaingó', 'AR.06.3433357', 'ASCII:Departamento de Ituzaingo;ID:3433357', '5749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5749', '112', '7626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3433357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7627', '1079', '1', 'Departamento de Itatí', 'AR.06.3433362', 'ASCII:Departamento de Itati;ID:3433362', '5750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5750', '112', '7627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3433362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7628', '1079', '1', 'Partido de Isla Martín García', 'AR.01.3433417', 'ASCII:Partido de Isla Martin Garcia;ID:3433417', '5751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5751', '112', '7628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7629', '1079', '1', 'Departamento de Iguazú', 'AR.14.3433487', 'ASCII:Departamento de Iguazu;ID:3433487', '5752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5752', '112', '7629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3433487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7630', '1079', '1', 'Departamento de Guaraní', 'AR.14.3433646', 'ASCII:Departamento de Guarani;ID:3433646', '5753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5753', '112', '7630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3433646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7631', '1079', '1', 'Departamento de Gualeguaychú', 'AR.08.3433657', 'ASCII:Departamento de Gualeguaychu;ID:3433657', '5754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5754', '112', '7631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3433657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7632', '1079', '1', 'Departamento de Gualeguay', 'AR.08.3433661', 'ASCII:Departamento de Gualeguay;ID:3433661', '5755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5755', '112', '7632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3433661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7633', '1079', '1', 'Departamento de Goya', 'AR.06.3433714', 'ASCII:Departamento de Goya;ID:3433714', '5756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5756', '112', '7633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3433714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7634', '1079', '1', 'Partido de General Sarmiento', 'AR.01.3433777', 'ASCII:Partido de General Sarmiento;ID:3433777', '5757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5757', '112', '7634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7635', '1079', '1', 'Partido de General San Martín', 'AR.01.3433778', 'ASCII:Partido de General San Martin;ID:3433778', '5758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5758', '112', '7635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7636', '1079', '1', 'Partido de General Rodríguez', 'AR.01.3433780', 'ASCII:Partido de General Rodriguez;ID:3433780', '5759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5759', '112', '7636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7637', '1079', '1', 'Partido de General Pueyrredón', 'AR.01.3433782', 'ASCII:Partido de General Pueyrredon;ID:3433782', '5760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5760', '112', '7637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7638', '1079', '1', 'Partido de General Paz', 'AR.01.3433785', 'ASCII:Partido de General Paz;ID:3433785', '5761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5761', '112', '7638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7639', '1079', '1', 'Departamento de General Paz', 'AR.06.3433786', 'ASCII:Departamento de General Paz;ID:3433786', '5762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5762', '112', '7639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3433786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7640', '1079', '1', 'Departamento de General Obligado', 'AR.21.3433788', 'ASCII:Departamento de General Obligado;ID:3433788', '5763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5763', '112', '7640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3433788» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7641', '1079', '1', 'Departamento de General Manuel Belgrano', 'AR.14.3433790', 'ASCII:Departamento de General Manuel Belgrano;ID:3433790', '5764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5764', '112', '7641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3433790» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7642', '1079', '1', 'Partido de General Lavalle', 'AR.01.3433794', 'ASCII:Partido de General Lavalle;ID:3433794', '5765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5765', '112', '7642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7643', '1079', '1', 'Partido de General Las Heras', 'AR.01.3433798', 'ASCII:Partido de General Las Heras;ID:3433798', '5766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5766', '112', '7643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7644', '1079', '1', 'Partido de General Juan Madariaga', 'AR.01.3433800', 'ASCII:Partido de General Juan Madariaga;ID:3433800', '5767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5767', '112', '7644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7645', '1079', '1', 'Partido de General Guido', 'AR.01.3433805', 'ASCII:Partido de General Guido;ID:3433805', '5768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5768', '112', '7645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7646', '1079', '1', 'Partido de General Donovan', 'AR.03.3433811', 'ASCII:Partido de General Donovan;ID:3433811', '5769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5769', '112', '7646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3433811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7647', '1079', '1', 'Partido de General Belgrano', 'AR.01.3433816', 'ASCII:Partido de General Belgrano;ID:3433816', '5770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5770', '112', '7647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7648', '1079', '1', 'Departamento de General Alvear', 'AR.06.3433819', 'ASCII:Departamento de General Alvear;ID:3433819', '5771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5771', '112', '7648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3433819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7649', '1079', '1', 'Partido de General Alvarado', 'AR.01.3433821', 'ASCII:Partido de General Alvarado;ID:3433821', '5772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5772', '112', '7649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7650', '1079', '1', 'Departamento de Formosa', 'AR.09.3433898', 'ASCII:Departamento de Formosa;ID:3433898', '5773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5773', '112', '7650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.09.3433898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7651', '1079', '1', 'Partido de Florencio Varela', 'AR.01.3433922', 'ASCII:Partido de Florencio Varela;ID:3433922', '5774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5774', '112', '7651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7652', '1079', '1', 'Departamento de Feliciano', 'AR.08.3433947', 'ASCII:Departamento de Feliciano;ID:3433947', '5775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5775', '112', '7652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3433947» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7653', '1079', '1', 'Departamento de Federación', 'AR.08.3433958', 'ASCII:Departamento de Federacion;ID:3433958', '5776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5776', '112', '7653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3433958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7654', '1079', '1', 'Partido de Exaltación de la Cruz', 'AR.01.3433977', 'ASCII:Partido de Exaltacion de la Cruz;ID:3433977', '5777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5777', '112', '7654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3433977» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7655', '1079', '1', 'Partido de Esteban Echeverría', 'AR.01.3434003', 'ASCII:Partido de Esteban Echeverria;ID:3434003', '5778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5778', '112', '7655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3434003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7656', '1079', '1', 'Departamento de Esquina', 'AR.06.3434094', 'ASCII:Departamento de Esquina;ID:3434094', '5779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5779', '112', '7656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3434094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7657', '1079', '1', 'Partido de Escobar', 'AR.01.3434130', 'ASCII:Partido de Escobar;ID:3434130', '5780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5780', '112', '7657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3434130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7658', '1079', '1', 'Partido de Ensenada', 'AR.01.3434140', 'ASCII:Partido de Ensenada;ID:3434140', '5781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5781', '112', '7658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3434140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7659', '1079', '1', 'Departamento de Empedrado', 'AR.06.3434152', 'ASCII:Departamento de Empedrado;ID:3434152', '5782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5782', '112', '7659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3434152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7660', '1079', '1', 'Departamento de Eldorado', 'AR.14.3434672', 'ASCII:Departamento de Eldorado;ID:3434672', '5783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5783', '112', '7660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3434672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7661', '1079', '1', 'Partido de Dolores', 'AR.01.3435032', 'ASCII:Partido de Dolores;ID:3435032', '5784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5784', '112', '7661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3435032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7662', '1079', '1', 'Departamento de Curuzú Cuatiá', 'AR.06.3435101', 'ASCII:Departamento de Curuzu Cuatia;ID:3435101', '5785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5785', '112', '7662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3435101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7663', '1079', '1', 'Departamento de Concordia', 'AR.08.3435260', 'ASCII:Departamento de Concordia;ID:3435260', '5786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5786', '112', '7663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3435260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7664', '1079', '1', 'Departamento de Concepción', 'AR.06.3435269', 'ASCII:Departamento de Concepcion;ID:3435269', '5787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5787', '112', '7664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3435269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7665', '1079', '1', 'Departamento de Concepción', 'AR.14.3435270', 'ASCII:Departamento de Concepcion;ID:3435270', '5788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5788', '112', '7665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3435270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7666', '1079', '1', 'Departamento de Colón', 'AR.08.3435351', 'ASCII:Departamento de Colon;ID:3435351', '5789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5789', '112', '7666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3435351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7667', '1079', '1', 'Partido de Chivilcoy', 'AR.01.3435406', 'ASCII:Partido de Chivilcoy;ID:3435406', '5790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5790', '112', '7667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3435406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7668', '1079', '1', 'Partido de Chascomús', 'AR.01.3435446', 'ASCII:Partido de Chascomus;ID:3435446', '5791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5791', '112', '7668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3435446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7669', '1079', '1', 'Partido de Castelli', 'AR.01.3435603', 'ASCII:Partido de Castelli;ID:3435603', '5792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5792', '112', '7669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3435603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7670', '1079', '1', 'Partido de Carmen de Areco', 'AR.01.3435643', 'ASCII:Partido de Carmen de Areco;ID:3435643', '5793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5793', '112', '7670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3435643» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7671', '1079', '1', 'Partido de Capitán Sarmiento', 'AR.01.3435689', 'ASCII:Partido de Capitan Sarmiento;ID:3435689', '5794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5794', '112', '7671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3435689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7672', '1079', '1', 'Departamento de Capital', 'AR.06.3435698', 'ASCII:Departamento de Capital;ID:3435698', '5795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5795', '112', '7672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3435698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7673', '1079', '1', 'Departamento de Capital', 'AR.14.3435699', 'ASCII:Departamento de Capital;ID:3435699', '5796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5796', '112', '7673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3435699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7674', '1079', '1', 'Partido de Canuelas', 'AR.01.3435710', 'ASCII:Partido de Canuelas;ID:3435710', '5797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5797', '112', '7674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3435710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7675', '1079', '1', 'Departamento de Candelaria', 'AR.14.3435732', 'ASCII:Departamento de Candelaria;ID:3435732', '5798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5798', '112', '7675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3435732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7676', '1079', '1', 'Partido de Campana', 'AR.01.3435809', 'ASCII:Partido de Campana;ID:3435809', '5799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5799', '112', '7676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3435809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7677', '1079', '1', 'Departamento de Cainguás', 'AR.14.3435844', 'ASCII:Departamento de Cainguas;ID:3435844', '5800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5800', '112', '7677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3435844» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7678', '1079', '1', 'Partido de Brandsen', 'AR.01.3435962', 'ASCII:Partido de Brandsen;ID:3435962', '5801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5801', '112', '7678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3435962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7679', '1079', '1', 'Departamento de Berón de Astrada', 'AR.06.3436028', 'ASCII:Departamento de Beron de Astrada;ID:3436028', '5802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5802', '112', '7679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3436028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7680', '1079', '1', 'Partido de Bermejo', 'AR.03.3436037', 'ASCII:Partido de Bermejo;ID:3436037', '5803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5803', '112', '7680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3436037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7681', '1079', '1', 'Partido de Berisso', 'AR.01.3436038', 'ASCII:Partido de Berisso;ID:3436038', '5804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5804', '112', '7681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3436038» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7682', '1079', '1', 'Partido de Berazategui', 'AR.01.3436042', 'ASCII:Partido de Berazategui;ID:3436042', '5805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5805', '112', '7682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3436042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7683', '1079', '1', 'Departamento de Bella Vista', 'AR.06.3436058', 'ASCII:Departamento de Bella Vista;ID:3436058', '5806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5806', '112', '7683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.06.3436058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7684', '1079', '1', 'Partido de Bartolomé Mitre', 'AR.01.3436101', 'ASCII:Partido de Bartolome Mitre;ID:3436101', '5807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5807', '112', '7684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3436101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7685', '1079', '1', 'Partido de Baradero', 'AR.01.3436149', 'ASCII:Partido de Baradero;ID:3436149', '5808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5808', '112', '7685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3436149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7686', '1079', '1', 'Partido de Balcarce', 'AR.01.3436176', 'ASCII:Partido de Balcarce;ID:3436176', '5809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5809', '112', '7686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3436176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7687', '1079', '1', 'Partido de Azul', 'AR.01.3436197', 'ASCII:Partido de Azul;ID:3436197', '5810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5810', '112', '7687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3436197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7688', '1079', '1', 'Partido de Ayacucho', 'AR.01.3436219', 'ASCII:Partido de Ayacucho;ID:3436219', '5811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5811', '112', '7688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3436219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7689', '1079', '1', 'Partido de Avellaneda', 'AR.01.3436227', 'ASCII:Partido de Avellaneda;ID:3436227', '5812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5812', '112', '7689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3436227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7690', '1079', '1', 'Departamento de Apóstoles', 'AR.14.3436309', 'ASCII:Departamento de Apostoles;ID:3436309', '5813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5813', '112', '7690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.14.3436309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7691', '1079', '1', 'Partido de Almirante Brown', 'AR.01.3436394', 'ASCII:Partido de Almirante Brown;ID:3436394', '5814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5814', '112', '7691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3436394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7692', '1079', '1', 'Departamento de Zonda', 'AR.18.3832079', 'ASCII:Departamento de Zonda;ID:3832079', '5815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5815', '112', '7692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3832079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7693', '1079', '1', 'Departamento de Zapala', 'AR.15.3832131', 'ASCII:Departamento de Zapala;ID:3832131', '5816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5816', '112', '7693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3832131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7694', '1079', '1', 'Departamento de Yaví', 'AR.10.3832287', 'ASCII:Departamento de Yavi;ID:3832287', '5817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5817', '112', '7694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3832287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7695', '1079', '1', 'Partido de Villarino', 'AR.01.3832640', 'ASCII:Partido de Villarino;ID:3832640', '5818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5818', '112', '7695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3832640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7696', '1079', '1', 'Departamento de Victoria', 'AR.08.3832932', 'ASCII:Departamento de Victoria;ID:3832932', '5819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5819', '112', '7696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3832932» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7697', '1079', '1', 'Departamento de Vera', 'AR.21.3833025', 'ASCII:Departamento de Vera;ID:3833025', '5820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5820', '112', '7697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3833025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7698', '1079', '1', 'Departamento de Vélez Sársfield', 'AR.12.3833075', 'ASCII:Departamento de Velez Sarsfield;ID:3833075', '5821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5821', '112', '7698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3833075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7699', '1079', '1', 'Partido de Veinticinco de Mayo', 'AR.01.3833100', 'ASCII:Partido de Veinticinco de Mayo;ID:3833100', '5822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5822', '112', '7699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3833100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7700', '1079', '1', 'Departamento de Veinticinco de Mayo', 'AR.16.3833106', 'ASCII:Departamento de Veinticinco de Mayo;ID:3833106', '5823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5823', '112', '7700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3833106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7701', '1079', '1', 'Departamento de Veinticinco de Mayo', 'AR.18.3833107', 'ASCII:Departamento de Veinticinco de Mayo;ID:3833107', '5824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5824', '112', '7701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3833107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7702', '1079', '1', 'Departamento de Valle Viejo', 'AR.02.3833198', 'ASCII:Departamento de Valle Viejo;ID:3833198', '5825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5825', '112', '7702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3833198» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7703', '1079', '1', 'Departamento de Valle Grande', 'AR.10.3833218', 'ASCII:Departamento de Valle Grande;ID:3833218', '5826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5826', '112', '7703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3833218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7704', '1079', '1', 'Departamento de Valle Fértil', 'AR.18.3833221', 'ASCII:Departamento de Valle Fertil;ID:3833221', '5827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5827', '112', '7704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3833221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7705', '1079', '1', 'Departamento de Valcheta', 'AR.16.3833280', 'ASCII:Departamento de Valcheta;ID:3833280', '5828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5828', '112', '7705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3833280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7706', '1079', '1', 'Departamento de Utracán', 'AR.11.3833347', 'ASCII:Departamento de Utracan;ID:3833347', '5829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5829', '112', '7706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3833347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7707', '1079', '1', 'Departamento de Ushuaia', 'AR.23.3833365', 'ASCII:Departamento de Ushuaia;ID:3833365', '5830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5830', '112', '7707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.23.3833365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7708', '1079', '1', 'Departamento de Unión', 'AR.05.3833419', 'ASCII:Departamento de Union;ID:3833419', '5831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5831', '112', '7708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3833419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7709', '1079', '1', 'Departamento de Ullún', 'AR.18.3833446', 'ASCII:Departamento de Ullun;ID:3833446', '5832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5832', '112', '7709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3833446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7710', '1079', '1', 'Departamento de Tupungato', 'AR.13.3833511', 'ASCII:Departamento de Tupungato;ID:3833511', '5833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5833', '112', '7710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3833511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7711', '1079', '1', 'Departamento de Tunuyán', 'AR.13.3833519', 'ASCII:Departamento de Tunuyan;ID:3833519', '5834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5834', '112', '7711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3833519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7712', '1079', '1', 'Departamento de Tumbaya', 'AR.10.3833548', 'ASCII:Departamento de Tumbaya;ID:3833548', '5835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5835', '112', '7712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3833548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7713', '1079', '1', 'Departamento de Tulumba', 'AR.05.3833554', 'ASCII:Departamento de Tulumba;ID:3833554', '5836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5836', '112', '7713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3833554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7714', '1079', '1', 'Partido de Tres Arroyos', 'AR.01.3833857', 'ASCII:Partido de Tres Arroyos;ID:3833857', '5837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5837', '112', '7714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3833857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7715', '1079', '1', 'Partido de Trenque Lauquen', 'AR.01.3833874', 'ASCII:Partido de Trenque Lauquen;ID:3833874', '5838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5838', '112', '7715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3833874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7716', '1079', '1', 'Departamento de Trenel', 'AR.11.3833878', 'ASCII:Departamento de Trenel;ID:3833878', '5839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5839', '112', '7716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3833878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7717', '1079', '1', 'Departamento de Trancas', 'AR.24.3833945', 'ASCII:Departamento de Trancas;ID:3833945', '5840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5840', '112', '7717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3833945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7718', '1079', '1', 'Departamento de Totoral', 'AR.05.3834008', 'ASCII:Departamento de Totoral;ID:3834008', '5841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5841', '112', '7718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3834008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7719', '1079', '1', 'Partido de Tornquist', 'AR.01.3834182', 'ASCII:Partido de Tornquist;ID:3834182', '5842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5842', '112', '7719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3834182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7720', '1079', '1', 'Departamento de Toay', 'AR.11.3834309', 'ASCII:Departamento de Toay;ID:3834309', '5843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5843', '112', '7720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3834309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7721', '1079', '1', 'Departamento de Tinogasta', 'AR.02.3834360', 'ASCII:Departamento de Tinogasta;ID:3834360', '5844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5844', '112', '7721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3834360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7722', '1079', '1', 'Departamento de Tilcara', 'AR.10.3834402', 'ASCII:Departamento de Tilcara;ID:3834402', '5845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5845', '112', '7722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3834402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7723', '1079', '1', 'Departamento de Tercero Arriba', 'AR.05.3834506', 'ASCII:Departamento de Tercero Arriba;ID:3834506', '5846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5846', '112', '7723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3834506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7724', '1079', '1', 'Departamento de Telsen', 'AR.04.3834535', 'ASCII:Departamento de Telsen;ID:3834535', '5847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5847', '112', '7724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3834535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7725', '1079', '1', 'Departamento de Tehuelches', 'AR.04.3834560', 'ASCII:Departamento de Tehuelches;ID:3834560', '5848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5848', '112', '7725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3834560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7726', '1079', '1', 'Partido de Tapalquén', 'AR.01.3834646', 'ASCII:Partido de Tapalquen;ID:3834646', '5849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5849', '112', '7726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3834646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7727', '1079', '1', 'Departamento de Tafí', 'AR.24.3834816', 'ASCII:Departamento de Tafi;ID:3834816', '5850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5850', '112', '7727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3834816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7728', '1079', '1', 'Departamento de Susques', 'AR.10.3834892', 'ASCII:Departamento de Susques;ID:3834892', '5851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5851', '112', '7728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3834892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7729', '1079', '1', 'Departamento de Sobremonte', 'AR.05.3835180', 'ASCII:Departamento de Sobremonte;ID:3835180', '5852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5852', '112', '7729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3835180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7730', '1079', '1', 'Departamento de Silípica', 'AR.22.3835272', 'ASCII:Departamento de Silipica;ID:3835272', '5853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5853', '112', '7730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3835272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7731', '1079', '1', 'Departamento de Sarmiento', 'AR.04.3835705', 'ASCII:Departamento de Sarmiento;ID:3835705', '5854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5854', '112', '7731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3835705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7732', '1079', '1', 'Departamento de Sarmiento', 'AR.18.3835706', 'ASCII:Departamento de Sarmiento;ID:3835706', '5855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5855', '112', '7732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3835706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7733', '1079', '1', 'Departamento de Sarmiento', 'AR.22.3835707', 'ASCII:Departamento de Sarmiento;ID:3835707', '5856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5856', '112', '7733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3835707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7734', '1079', '1', 'Departamento de Santa Victoria', 'AR.17.3835877', 'ASCII:Departamento de Santa Victoria;ID:3835877', '5857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5857', '112', '7734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3835877» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7735', '1079', '1', 'Departamento de Santa Rosa', 'AR.13.3835984', 'ASCII:Departamento de Santa Rosa;ID:3835984', '5858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5858', '112', '7735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3835984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7736', '1079', '1', 'Departamento de Santa Rosa', 'AR.02.3835985', 'ASCII:Departamento de Santa Rosa;ID:3835985', '5859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5859', '112', '7736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3835985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7737', '1079', '1', 'Departamento de Santa María', 'AR.05.3836128', 'ASCII:Departamento de Santa Maria;ID:3836128', '5860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5860', '112', '7737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3836128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7738', '1079', '1', 'Departamento de Santa María', 'AR.02.3836129', 'ASCII:Departamento de Santa Maria;ID:3836129', '5861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5861', '112', '7738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3836129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7739', '1079', '1', 'Departamento de Santa Lucía', 'AR.18.3836188', 'ASCII:Departamento de Santa Lucia;ID:3836188', '5862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5862', '112', '7739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3836188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7740', '1079', '1', 'Departamento de Santa Catalina', 'AR.10.3836444', 'ASCII:Departamento de Santa Catalina;ID:3836444', '5863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5863', '112', '7740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3836444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7741', '1079', '1', 'Departamento de Santa Bárbara', 'AR.10.3836473', 'ASCII:Departamento de Santa Barbara;ID:3836473', '5864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5864', '112', '7741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3836473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7742', '1079', '1', 'Departamento de San Sebastián', 'AR.23.3836551', 'ASCII:Departamento de San Sebastian;ID:3836551', '5865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5865', '112', '7742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.23.3836551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7743', '1079', '1', 'Departamento de San Rafael', 'AR.13.3836668', 'ASCII:Departamento de San Rafael;ID:3836668', '5866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5866', '112', '7743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3836668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7744', '1079', '1', 'Departamento de San Pedro', 'AR.10.3836752', 'ASCII:Departamento de San Pedro;ID:3836752', '5867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5867', '112', '7744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3836752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7745', '1079', '1', 'Partido de San Nicolás', 'AR.01.3836848', 'ASCII:Partido de San Nicolas;ID:3836848', '5868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5868', '112', '7745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3836848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7746', '1079', '1', 'Departamento de San Martín', 'AR.13.3836982', 'ASCII:Departamento de San Martin;ID:3836982', '5869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5869', '112', '7746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3836982» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7747', '1079', '1', 'Departamento de San Martín', 'AR.19.3836983', 'ASCII:Departamento de San Martin;ID:3836983', '5870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5870', '112', '7747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.19.3836983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7748', '1079', '1', 'Departamento de San Martín', 'AR.21.3836984', 'ASCII:Departamento de San Martin;ID:3836984', '5871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5871', '112', '7748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3836984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7749', '1079', '1', 'Departamento de San Martín', 'AR.18.3836985', 'ASCII:Departamento de San Martin;ID:3836985', '5872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5872', '112', '7749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3836985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7750', '1079', '1', 'Departamento de San Martín', 'AR.22.3836986', 'ASCII:Departamento de San Martin;ID:3836986', '5873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5873', '112', '7750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3836986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7751', '1079', '1', 'Partido de San Lorenzo', 'AR.03.3837081', 'ASCII:Partido de San Lorenzo;ID:3837081', '5874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5874', '112', '7751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3837081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7752', '1079', '1', 'Departamento de San Lorenzo', 'AR.21.3837090', 'ASCII:Departamento de San Lorenzo;ID:3837090', '5875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5875', '112', '7752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3837090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7753', '1079', '1', 'Departamento de San Justo', 'AR.05.3837121', 'ASCII:Departamento de San Justo;ID:3837121', '5876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5876', '112', '7753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3837121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7754', '1079', '1', 'Departamento de San Justo', 'AR.21.3837122', 'ASCII:Departamento de San Justo;ID:3837122', '5877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5877', '112', '7754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3837122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7755', '1079', '1', 'Departamento de San Jerónimo', 'AR.21.3837460', 'ASCII:Departamento de San Jeronimo;ID:3837460', '5878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5878', '112', '7755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3837460» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7756', '1079', '1', 'Departamento de San Javier', 'AR.05.3837475', 'ASCII:Departamento de San Javier;ID:3837475', '5879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5879', '112', '7756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3837475» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7757', '1079', '1', 'Departamento de San Cristóbal', 'AR.21.3837821', 'ASCII:Departamento de San Cristobal;ID:3837821', '5880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5880', '112', '7757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3837821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7758', '1079', '1', 'Departamento de San Carlos', 'AR.13.3837885', 'ASCII:Departamento de San Carlos;ID:3837885', '5881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5881', '112', '7758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3837885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7759', '1079', '1', 'Departamento de San Carlos', 'AR.17.3837886', 'ASCII:Departamento de San Carlos;ID:3837886', '5882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5882', '112', '7759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3837886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7760', '1079', '1', 'Departamento de San Blas de los Sauces', 'AR.12.3837918', 'ASCII:Departamento de San Blas de los Sauces;ID:3837918', '5883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5883', '112', '7760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3837918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7761', '1079', '1', 'Departamento de San Antonio', 'AR.16.3838028', 'ASCII:Departamento de San Antonio;ID:3838028', '5884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5884', '112', '7761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3838028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7762', '1079', '1', 'Departamento de San Antonio', 'AR.10.3838029', 'ASCII:Departamento de San Antonio;ID:3838029', '5885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5885', '112', '7762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3838029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7763', '1079', '1', 'Departamento de San Alberto', 'AR.05.3838154', 'ASCII:Departamento de San Alberto;ID:3838154', '5886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5886', '112', '7763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3838154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7764', '1079', '1', 'Departamento de Sanagasta', 'AR.12.3838186', 'ASCII:Departamento de Sanagasta;ID:3838186', '5887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5887', '112', '7764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3838186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7765', '1079', '1', 'Partido de Salto', 'AR.01.3838222', 'ASCII:Partido de Salto;ID:3838222', '5888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5888', '112', '7765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3838222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7766', '1079', '1', 'Partido de Salliqueló', 'AR.01.3838240', 'ASCII:Partido de Salliquelo;ID:3838240', '5889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5889', '112', '7766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3838240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7767', '1079', '1', 'Departamento de Salavina', 'AR.22.3838300', 'ASCII:Departamento de Salavina;ID:3838300', '5890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5890', '112', '7767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3838300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7768', '1079', '1', 'Partido de Saavedra', 'AR.01.3838468', 'ASCII:Partido de Saavedra;ID:3838468', '5891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5891', '112', '7768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3838468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7769', '1079', '1', 'Departamento de Rosario de Lerma', 'AR.17.3838560', 'ASCII:Departamento de Rosario de Lerma;ID:3838560', '5892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5892', '112', '7769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3838560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7770', '1079', '1', 'Departamento de Rosario de la Frontera', 'AR.17.3838563', 'ASCII:Departamento de Rosario de la Frontera;ID:3838563', '5893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5893', '112', '7770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3838563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7771', '1079', '1', 'Departamento de Rosario', 'AR.21.3838574', 'ASCII:Departamento de Rosario;ID:3838574', '5894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5894', '112', '7771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3838574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7772', '1079', '1', 'Partido de Rojas', 'AR.01.3838646', 'ASCII:Partido de Rojas;ID:3838646', '5895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5895', '112', '7772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3838646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7773', '1079', '1', 'Departamento de Robles', 'AR.22.3838725', 'ASCII:Departamento de Robles;ID:3838725', '5896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5896', '112', '7773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3838725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7774', '1079', '1', 'Partido de Rivadavia', 'AR.01.3838745', 'ASCII:Partido de Rivadavia;ID:3838745', '5897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5897', '112', '7774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3838745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7775', '1079', '1', 'Departamento de Rivadavia', 'AR.13.3838749', 'ASCII:Departamento de Rivadavia;ID:3838749', '5898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5898', '112', '7775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3838749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7776', '1079', '1', 'Departamento de Rivadavia', 'AR.18.3838750', 'ASCII:Departamento de Rivadavia;ID:3838750', '5899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5899', '112', '7776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3838750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7777', '1079', '1', 'Departamento de Rivadavia', 'AR.12.3838751', 'ASCII:Departamento de Rivadavia;ID:3838751', '5900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5900', '112', '7777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3838751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7778', '1079', '1', 'Departamento de Rivadavia', 'AR.22.3838752', 'ASCII:Departamento de Rivadavia;ID:3838752', '5901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5901', '112', '7778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3838752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7779', '1079', '1', 'Departamento de Rivadavia', 'AR.17.3838753', 'ASCII:Departamento de Rivadavia;ID:3838753', '5902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5902', '112', '7779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3838753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7780', '1079', '1', 'Departamento de Río Senguerr', 'AR.04.3838795', 'ASCII:Departamento de Rio Senguerr;ID:3838795', '5903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5903', '112', '7780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3838795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7781', '1079', '1', 'Departamento de Río Segundo', 'AR.05.3838796', 'ASCII:Departamento de Rio Segundo;ID:3838796', '5904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5904', '112', '7781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3838796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7782', '1079', '1', 'Departamento de Río Seco', 'AR.05.3838801', 'ASCII:Departamento de Rio Seco;ID:3838801', '5905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5905', '112', '7782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3838801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7783', '1079', '1', 'Departamento de Río Primero', 'AR.05.3838822', 'ASCII:Departamento de Rio Primero;ID:3838822', '5906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5906', '112', '7783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3838822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7784', '1079', '1', 'Departamento de Río Hondo', 'AR.22.3838845', 'ASCII:Departamento de Rio Hondo;ID:3838845', '5907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5907', '112', '7784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3838845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7785', '1079', '1', 'Departamento de Río Cuarto', 'AR.05.3838873', 'ASCII:Departamento de Rio Cuarto;ID:3838873', '5908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5908', '112', '7785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3838873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7786', '1079', '1', 'Departamento de Río Chico', 'AR.20.3838892', 'ASCII:Departamento de Rio Chico;ID:3838892', '5909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5909', '112', '7786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.20.3838892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7787', '1079', '1', 'Departamento de Río Chico', 'AR.24.3838893', 'ASCII:Departamento de Rio Chico;ID:3838893', '5910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5910', '112', '7787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3838893» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7788', '1079', '1', 'Departamento de Rinconada', 'AR.10.3839021', 'ASCII:Departamento de Rinconada;ID:3839021', '5911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5911', '112', '7788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3839021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7789', '1079', '1', 'Departamento de Realicó', 'AR.11.3839281', 'ASCII:Departamento de Realico;ID:3839281', '5912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5912', '112', '7789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3839281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7790', '1079', '1', 'Departamento de Rawson', 'AR.04.3839303', 'ASCII:Departamento de Rawson;ID:3839303', '5913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5913', '112', '7790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3839303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7791', '1079', '1', 'Departamento de Rawson', 'AR.18.3839304', 'ASCII:Departamento de Rawson;ID:3839304', '5914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5914', '112', '7791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3839304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7792', '1079', '1', 'Departamento de Rancul', 'AR.11.3839380', 'ASCII:Departamento de Rancul;ID:3839380', '5915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5915', '112', '7792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3839380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7793', '1079', '1', 'Departamento de Ramón Lista', 'AR.09.3839414', 'ASCII:Departamento de Ramon Lista;ID:3839414', '5916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5916', '112', '7793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.09.3839414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7794', '1079', '1', 'Partido de Ramallo', 'AR.01.3839441', 'ASCII:Partido de Ramallo;ID:3839441', '5917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5917', '112', '7794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3839441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7795', '1079', '1', 'Partido de Quitilipi', 'AR.03.3839489', 'ASCII:Partido de Quitilipi;ID:3839489', '5918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5918', '112', '7795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3839489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7796', '1079', '1', 'Departamento de Quemú Quemú', 'AR.11.3839667', 'ASCII:Departamento de Quemu Quemu;ID:3839667', '5919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5919', '112', '7796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3839667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7797', '1079', '1', 'Departamento de Quebrachos', 'AR.22.3839792', 'ASCII:Departamento de Quebrachos;ID:3839792', '5920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5920', '112', '7797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3839792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7798', '1079', '1', 'Departamento de Punilla', 'AR.05.3839996', 'ASCII:Departamento de Punilla;ID:3839996', '5921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5921', '112', '7798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3839996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7799', '1079', '1', 'Departamento de Puelén', 'AR.11.3840188', 'ASCII:Departamento de Puelen;ID:3840188', '5922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5922', '112', '7799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3840188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7800', '1079', '1', 'Partido de Puan', 'AR.01.3840251', 'ASCII:Partido de Puan;ID:3840251', '5923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5923', '112', '7800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3840251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7801', '1079', '1', 'Departamento de Pringles', 'AR.19.3840260', 'ASCII:Departamento de Pringles;ID:3840260', '5924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5924', '112', '7801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.19.3840260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7802', '1079', '1', 'Departamento de Presidente Roque Sáenz Peña', 'AR.05.3840292', 'ASCII:Departamento de Presidente Roque Saenz Pena;ID:3840292', '5925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5925', '112', '7802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3840292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7803', '1079', '1', 'Departamento de Pomán', 'AR.02.3840808', 'ASCII:Departamento de Poman;ID:3840808', '5926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5926', '112', '7803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3840808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7804', '1079', '1', 'Departamento de Pocito', 'AR.18.3840858', 'ASCII:Departamento de Pocito;ID:3840858', '5927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5927', '112', '7804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3840858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7805', '1079', '1', 'Departamento de Pocho', 'AR.05.3840865', 'ASCII:Departamento de Pocho;ID:3840865', '5928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5928', '112', '7805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3840865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7806', '1079', '1', 'Departamento de Pilcaniyeu', 'AR.16.3841139', 'ASCII:Departamento de Pilcaniyeu;ID:3841139', '5929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5929', '112', '7806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3841139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7807', '1079', '1', 'Departamento de Picún Leufú', 'AR.15.3841298', 'ASCII:Departamento de Picun Leufu;ID:3841298', '5930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5930', '112', '7807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3841298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7808', '1079', '1', 'Departamento de Picunches', 'AR.15.3841303', 'ASCII:Departamento de Picunches;ID:3841303', '5931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5931', '112', '7808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3841303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7809', '1079', '1', 'Departamento de Pichi Mahuida', 'AR.16.3841356', 'ASCII:Departamento de Pichi Mahuida;ID:3841356', '5932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5932', '112', '7809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3841356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7810', '1079', '1', 'Partido de Pergamino', 'AR.01.3841488', 'ASCII:Partido de Pergamino;ID:3841488', '5933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5933', '112', '7810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3841488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7811', '1079', '1', 'Partido de Pellegrini', 'AR.01.3841610', 'ASCII:Partido de Pellegrini;ID:3841610', '5934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5934', '112', '7811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3841610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7812', '1079', '1', 'Departamento de Pellegrini', 'AR.22.3841612', 'ASCII:Departamento de Pellegrini;ID:3841612', '5935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5935', '112', '7812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3841612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7813', '1079', '1', 'Departamento de Pehuenches', 'AR.15.3841673', 'ASCII:Departamento de Pehuenches;ID:3841673', '5936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5936', '112', '7813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3841673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7814', '1079', '1', 'Partido de Pehuajó', 'AR.01.3841678', 'ASCII:Partido de Pehuajo;ID:3841678', '5937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5937', '112', '7814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3841678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7815', '1079', '1', 'Partido de Patagones', 'AR.01.3841799', 'ASCII:Partido de Patagones;ID:3841799', '5938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5938', '112', '7815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3841799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7816', '1079', '1', 'Departamento de Paso de Indios', 'AR.04.3841892', 'ASCII:Departamento de Paso de Indios;ID:3841892', '5939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5939', '112', '7816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3841892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7817', '1079', '1', 'Departamento de Paclín', 'AR.02.3842418', 'ASCII:Departamento de Paclin;ID:3842418', '5940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5940', '112', '7817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3842418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7818', '1079', '1', 'Departamento de Orán', 'AR.17.3842606', 'ASCII:Departamento de Oran;ID:3842606', '5941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5941', '112', '7818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3842606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7819', '1079', '1', 'Partido de Olavarría', 'AR.01.3842669', 'ASCII:Partido de Olavarria;ID:3842669', '5942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5942', '112', '7819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3842669» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7820', '1079', '1', 'Departamento de Ojo de Agua', 'AR.22.3842719', 'ASCII:Departamento de Ojo de Agua;ID:3842719', '5943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5943', '112', '7820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3842719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7821', '1079', '1', 'Partido de O''Higgins', 'AR.03.3842751', 'ASCII:Partido de O''Higgins;ID:3842751', '5944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5944', '112', '7821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3842751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7822', '1079', '1', 'Partido de Nueve de Julio', 'AR.01.3842871', 'ASCII:Partido de Nueve de Julio;ID:3842871', '5945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5945', '112', '7822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3842871» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7823', '1079', '1', 'Partido de Nueve de Julio', 'AR.03.3842872', 'ASCII:Partido de Nueve de Julio;ID:3842872', '5946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5946', '112', '7823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3842872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7824', '1079', '1', 'Departamento de Nueve de Julio', 'AR.16.3842875', 'ASCII:Departamento de Nueve de Julio;ID:3842875', '5947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5947', '112', '7824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3842875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7825', '1079', '1', 'Departamento de Nueve de Julio', 'AR.18.3842876', 'ASCII:Departamento de Nueve de Julio;ID:3842876', '5948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5948', '112', '7825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3842876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7826', '1079', '1', 'Departamento de Nueve de Julio', 'AR.21.3842877', 'ASCII:Departamento de Nueve de Julio;ID:3842877', '5949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5949', '112', '7826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3842877» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7827', '1079', '1', 'Departamento de Ñorquincó', 'AR.16.3842988', 'ASCII:Departamento de Norquinco;ID:3842988', '5950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5950', '112', '7827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3842988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7828', '1079', '1', 'Departamento de Ñorquín', 'AR.15.3842991', 'ASCII:Departamento de Norquin;ID:3842991', '5951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5951', '112', '7828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3842991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7829', '1079', '1', 'Departamento de Moreno', 'AR.22.3843684', 'ASCII:Departamento de Moreno;ID:3843684', '5952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5952', '112', '7829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3843684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7830', '1079', '1', 'Departamento de Monteros', 'AR.24.3843802', 'ASCII:Departamento de Monteros;ID:3843802', '5953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5953', '112', '7830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3843802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7831', '1079', '1', 'Departamento de Molinos', 'AR.17.3843991', 'ASCII:Departamento de Molinos;ID:3843991', '5954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5954', '112', '7831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3843991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7832', '1079', '1', 'Departamento de Mitre', 'AR.22.3844110', 'ASCII:Departamento de Mitre;ID:3844110', '5955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5955', '112', '7832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3844110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7833', '1079', '1', 'Departamento de Minas', 'AR.15.3844208', 'ASCII:Departamento de Minas;ID:3844208', '5956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5956', '112', '7833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3844208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7834', '1079', '1', 'Departamento de Minas', 'AR.05.3844209', 'ASCII:Departamento de Minas;ID:3844209', '5957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5957', '112', '7834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3844209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7835', '1079', '1', 'Departamento de Metán', 'AR.17.3844297', 'ASCII:Departamento de Metan;ID:3844297', '5958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5958', '112', '7835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3844297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7836', '1079', '1', 'Partido de Mayor Luis J. Fontana', 'AR.03.3844638', 'ASCII:Partido de Mayor Luis J. Fontana;ID:3844638', '5959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5959', '112', '7836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3844638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7837', '1079', '1', 'Departamento de Matará', 'AR.22.3844706', 'ASCII:Departamento de Matara;ID:3844706', '5960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5960', '112', '7837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3844706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7838', '1079', '1', 'Departamento de Matacos', 'AR.09.3844738', 'ASCII:Departamento de Matacos;ID:3844738', '5961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5961', '112', '7838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.09.3844738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7839', '1079', '1', 'Departamento de Mártires', 'AR.04.3844763', 'ASCII:Departamento de Martires;ID:3844763', '5962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5962', '112', '7839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3844763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7840', '1079', '1', 'Departamento de Marcos Juárez', 'AR.05.3844898', 'ASCII:Departamento de Marcos Juarez;ID:3844898', '5963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5963', '112', '7840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3844898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7841', '1079', '1', 'Departamento de Maracó', 'AR.11.3844924', 'ASCII:Departamento de Maraco;ID:3844924', '5964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5964', '112', '7841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3844924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7842', '1079', '1', 'Departamento de Malargüe', 'AR.13.3845180', 'ASCII:Departamento de Malargue;ID:3845180', '5965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5965', '112', '7842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3845180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7843', '1079', '1', 'Partido de Maipú', 'AR.03.3845238', 'ASCII:Partido de Maipu;ID:3845238', '5966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5966', '112', '7843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3845238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7844', '1079', '1', 'Departamento de Maipú', 'AR.13.3845244', 'ASCII:Departamento de Maipu;ID:3845244', '5967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5967', '112', '7844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3845244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7845', '1079', '1', 'Departamento de Magallanes', 'AR.20.3845272', 'ASCII:Departamento de Magallanes;ID:3845272', '5968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5968', '112', '7845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.20.3845272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7846', '1079', '1', 'Departamento de Luján', 'AR.13.3845397', 'ASCII:Departamento de Lujan;ID:3845397', '5969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5969', '112', '7846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3845397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7847', '1079', '1', 'Departamento de Los Lagos', 'AR.15.3846077', 'ASCII:Departamento de Los Lagos;ID:3846077', '5970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5970', '112', '7847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3846077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7848', '1079', '1', 'Departamento de Los Andes', 'AR.17.3846503', 'ASCII:Departamento de Los Andes;ID:3846503', '5971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5971', '112', '7848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3846503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7849', '1079', '1', 'Departamento de Loreto', 'AR.22.3846597', 'ASCII:Departamento de Loreto;ID:3846597', '5972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5972', '112', '7849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3846597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7850', '1079', '1', 'Departamento de Loncopué', 'AR.15.3846632', 'ASCII:Departamento de Loncopue;ID:3846632', '5973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5973', '112', '7850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3846632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7851', '1079', '1', 'Partido de Lincoln', 'AR.01.3846861', 'ASCII:Partido de Lincoln;ID:3846861', '5974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5974', '112', '7851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3846861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7852', '1079', '1', 'Departamento de Limay Mahuida', 'AR.11.3846879', 'ASCII:Departamento de Limay Mahuida;ID:3846879', '5975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5975', '112', '7852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3846879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7853', '1079', '1', 'Departamento de Lihuel-Calel', 'AR.11.3846896', 'ASCII:Departamento de Lihuel-Calel;ID:3846896', '5976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5976', '112', '7853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3846896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7854', '1079', '1', 'Departamento de Leventué', 'AR.11.3846928', 'ASCII:Departamento de Leventue;ID:3846928', '5977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5977', '112', '7854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3846928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7855', '1079', '1', 'Departamento de Ledesma', 'AR.10.3847087', 'ASCII:Departamento de Ledesma;ID:3847087', '5978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5978', '112', '7855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3847087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7856', '1079', '1', 'Partido de Leandro N. Alem', 'AR.01.3847097', 'ASCII:Partido de Leandro N. Alem;ID:3847097', '5979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5979', '112', '7856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3847097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7857', '1079', '1', 'Departamento de Leales', 'AR.24.3847102', 'ASCII:Departamento de Leales;ID:3847102', '5980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5980', '112', '7857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3847102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7858', '1079', '1', 'Departamento de La Viña', 'AR.17.3847193', 'ASCII:Departamento de La Vina;ID:3847193', '5981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5981', '112', '7858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3847193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7859', '1079', '1', 'Departamento de Lavalle', 'AR.13.3847327', 'ASCII:Departamento de Lavalle;ID:3847327', '5982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5982', '112', '7859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3847327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7860', '1079', '1', 'Departamento de Las Heras', 'AR.13.3848352', 'ASCII:Departamento de Las Heras;ID:3848352', '5983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5983', '112', '7860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3848352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7861', '1079', '1', 'Departamento de Las Colonias', 'AR.21.3848539', 'ASCII:Departamento de Las Colonias;ID:3848539', '5984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5984', '112', '7861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3848539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7862', '1079', '1', 'Partido de Laprida', 'AR.01.3849298', 'ASCII:Partido de Laprida;ID:3849298', '5985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5985', '112', '7862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3849298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7863', '1079', '1', 'Departamento de La Poma', 'AR.17.3849374', 'ASCII:Departamento de La Poma;ID:3849374', '5986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5986', '112', '7863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3849374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7864', '1079', '1', 'Departamento de La Paz', 'AR.13.3849513', 'ASCII:Departamento de La Paz;ID:3849513', '5987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5987', '112', '7864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3849513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7865', '1079', '1', 'Departamento de La Paz', 'AR.02.3849514', 'ASCII:Departamento de La Paz;ID:3849514', '5988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5988', '112', '7865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3849514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7866', '1079', '1', 'Deparamento de Languiñeo', 'AR.04.3849745', 'ASCII:Deparamento de Languineo;ID:3849745', '5989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5989', '112', '7866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3849745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7867', '1079', '1', 'Departamento de Lago Buenos Aires', 'AR.20.3851119', 'ASCII:Departamento de Lago Buenos Aires;ID:3851119', '5990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5990', '112', '7867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.20.3851119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7868', '1079', '1', 'Departamento de Lago Argentino', 'AR.20.3851122', 'ASCII:Departamento de Lago Argentino;ID:3851122', '5991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5991', '112', '7868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.20.3851122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7869', '1079', '1', 'Departamento de Lácar', 'AR.15.3852288', 'ASCII:Departamento de Lacar;ID:3852288', '5992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5992', '112', '7869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3852288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7870', '1079', '1', 'Departamento de La Capital', 'AR.19.3852291', 'ASCII:Departamento de La Capital;ID:3852291', '5993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5993', '112', '7870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.19.3852291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7871', '1079', '1', 'Departamento de La Capital', 'AR.21.3852292', 'ASCII:Departamento de La Capital;ID:3852292', '5994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5994', '112', '7871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3852292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7872', '1079', '1', 'Partido de Junín', 'AR.01.3853351', 'ASCII:Partido de Junin;ID:3853351', '5995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5995', '112', '7872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3853351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7873', '1079', '1', 'Departamento de Junín', 'AR.13.3853352', 'ASCII:Departamento de Junin;ID:3853352', '5996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5996', '112', '7873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3853352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7874', '1079', '1', 'Departamento de Junín', 'AR.19.3853353', 'ASCII:Departamento de Junin;ID:3853353', '5997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5997', '112', '7874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.19.3853353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7875', '1079', '1', 'Departamento de Juárez Celman', 'AR.05.3853410', 'ASCII:Departamento de Juarez Celman;ID:3853410', '5998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5998', '112', '7875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3853410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7876', '1079', '1', 'Departamento de Jiménez', 'AR.22.3853500', 'ASCII:Departamento de Jimenez;ID:3853500', '5999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('5999', '112', '7876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3853500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7877', '1079', '1', 'Departamento de Jáchal', 'AR.18.3853596', 'ASCII:Departamento de Jachal;ID:3853596', '6000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6000', '112', '7877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3853596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7878', '1079', '1', 'Departamento de Isla de los Estados', 'AR.23.3853669', 'ASCII:Departamento de Isla de los Estados;ID:3853669', '6001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6001', '112', '7878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.23.3853669» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7879', '1079', '1', 'Departamento de Ischilín', 'AR.05.3853686', 'ASCII:Departamento de Ischilin;ID:3853686', '6002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6002', '112', '7879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3853686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7880', '1079', '1', 'Departamento de Iruya', 'AR.17.3853698', 'ASCII:Departamento de Iruya;ID:3853698', '6003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6003', '112', '7880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3853698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7881', '1079', '1', 'Departamento de Iriondo', 'AR.21.3853705', 'ASCII:Departamento de Iriondo;ID:3853705', '6004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6004', '112', '7881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3853705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7882', '1079', '1', 'Partido de Independencia', 'AR.03.3853853', 'ASCII:Partido de Independencia;ID:3853853', '6005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6005', '112', '7882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3853853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7883', '1079', '1', 'Departamento de Independencia', 'AR.12.3853854', 'ASCII:Departamento de Independencia;ID:3853854', '6006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6006', '112', '7883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3853854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7884', '1079', '1', 'Departamento de Iglesia', 'AR.18.3853914', 'ASCII:Departamento de Iglesia;ID:3853914', '6007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6007', '112', '7884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3853914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7885', '1079', '1', 'Departamento de Humahuaca', 'AR.10.3853966', 'ASCII:Departamento de Humahuaca;ID:3853966', '6008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6008', '112', '7885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3853966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7886', '1079', '1', 'Departamento de Huiliches', 'AR.15.3853984', 'ASCII:Departamento de Huiliches;ID:3853984', '6009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6009', '112', '7886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3853984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7887', '1079', '1', 'Departamento de Hucal', 'AR.11.3854058', 'ASCII:Departamento de Hucal;ID:3854058', '6010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6010', '112', '7887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3854058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7888', '1079', '1', 'Partido de Hipólito Yrigoyen', 'AR.01.3854283', 'ASCII:Partido de Hipolito Yrigoyen;ID:3854283', '6011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6011', '112', '7888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3854283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7889', '1079', '1', 'Departamento de Güer Aike', 'AR.20.3854444', 'ASCII:Departamento de Guer Aike;ID:3854444', '6012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6012', '112', '7889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.20.3854444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7890', '1079', '1', 'Departamento de Guaymallén', 'AR.13.3854459', 'ASCII:Departamento de Guaymallen;ID:3854459', '6013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6013', '112', '7890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3854459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7891', '1079', '1', 'Departamento de Guatraché', 'AR.11.3854492', 'ASCII:Departamento de Guatrache;ID:3854492', '6014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6014', '112', '7891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3854492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7892', '1079', '1', 'Departamento de Guasayán', 'AR.22.3854499', 'ASCII:Departamento de Guasayan;ID:3854499', '6015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6015', '112', '7892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3854499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7893', '1079', '1', 'Partido de Guaminí', 'AR.01.3854602', 'ASCII:Partido de Guamini;ID:3854602', '6016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6016', '112', '7893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3854602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7894', '1079', '1', 'Departamento de Guachipas', 'AR.17.3854676', 'ASCII:Departamento de Guachipas;ID:3854676', '6017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6017', '112', '7894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3854676» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7895', '1079', '1', 'Departamento de Graneros', 'AR.24.3854723', 'ASCII:Departamento de Graneros;ID:3854723', '6018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6018', '112', '7895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3854723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7896', '1079', '1', 'Partido de González Chaves', 'AR.01.3854937', 'ASCII:Partido de Gonzalez Chaves;ID:3854937', '6019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6019', '112', '7896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3854937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7897', '1079', '1', 'Departamento de Godoy Cruz', 'AR.13.3854963', 'ASCII:Departamento de Godoy Cruz;ID:3854963', '6020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6020', '112', '7897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3854963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7898', '1079', '1', 'Departamento de Gobernador Vicente Dupuy', 'AR.19.3854968', 'ASCII:Departamento de Gobernador Vicente Dupuy;ID:3854968', '6021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6021', '112', '7898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.19.3854968» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7899', '1079', '1', 'Departamento de Gobernador Gordillo', 'AR.12.3854983', 'ASCII:Departamento de Gobernador Gordillo;ID:3854983', '6022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6022', '112', '7899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3854983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7900', '1079', '1', 'Partido de General Villegas', 'AR.01.3855039', 'ASCII:Partido de General Villegas;ID:3855039', '6023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6023', '112', '7900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3855039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7901', '1079', '1', 'Partido de General Viamonte', 'AR.01.3855042', 'ASCII:Partido de General Viamonte;ID:3855042', '6024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6024', '112', '7901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3855042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7902', '1079', '1', 'Departamento de General Taboada', 'AR.22.3855047', 'ASCII:Departamento de General Taboada;ID:3855047', '6025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6025', '112', '7902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3855047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7903', '1079', '1', 'Departamento de General Sarmiento', 'AR.12.3855050', 'ASCII:Departamento de General Sarmiento;ID:3855050', '6026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6026', '112', '7903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3855050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7904', '1079', '1', 'Departamento de General San Martín', 'AR.05.3855053', 'ASCII:Departamento de General San Martin;ID:3855053', '6027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6027', '112', '7904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3855053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7905', '1079', '1', 'Departamento de General San Martín', 'AR.12.3855054', 'ASCII:Departamento de General San Martin;ID:3855054', '6028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6028', '112', '7905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3855054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7906', '1079', '1', 'Departamento de General Roca', 'AR.16.3855061', 'ASCII:Departamento de General Roca;ID:3855061', '6029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6029', '112', '7906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3855061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7907', '1079', '1', 'Departamento de General Roca', 'AR.05.3855062', 'ASCII:Departamento de General Roca;ID:3855062', '6030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6030', '112', '7907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3855062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7908', '1079', '1', 'Departamento de General Roca', 'AR.12.3855063', 'ASCII:Departamento de General Roca;ID:3855063', '6031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6031', '112', '7908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3855063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7909', '1079', '1', 'Partido de General Pinto', 'AR.01.3855071', 'ASCII:Partido de General Pinto;ID:3855071', '6032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6032', '112', '7909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3855071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7910', '1079', '1', 'Departamento de General Pedernera', 'AR.19.3855076', 'ASCII:Departamento de General Pedernera;ID:3855076', '6033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6033', '112', '7910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.19.3855076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7911', '1079', '1', 'Departamento de General Ocampo', 'AR.12.3855082', 'ASCII:Departamento de General Ocampo;ID:3855082', '6034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6034', '112', '7911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3855082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7912', '1079', '1', 'Departamento de General Martín Miguel de Güemes', 'AR.17.3855089', 'ASCII:Departamento de General Martin Miguel de Guemes;ID:3855089', '6035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6035', '112', '7912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3855089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7913', '1079', '1', 'Departamento de General López', 'AR.21.3855095', 'ASCII:Departamento de General Lopez;ID:3855095', '6036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6036', '112', '7913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3855095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7914', '1079', '1', 'Departamento de General Lavalle', 'AR.12.3855099', 'ASCII:Departamento de General Lavalle;ID:3855099', '6037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6037', '112', '7914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3855099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7915', '1079', '1', 'Partido de General La Madrid', 'AR.01.3855102', 'ASCII:Partido de General La Madrid;ID:3855102', '6038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6038', '112', '7915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3855102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7916', '1079', '1', 'Departamento de General La Madrid', 'AR.12.3855103', 'ASCII:Departamento de General La Madrid;ID:3855103', '6039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6039', '112', '7916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3855103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7917', '1079', '1', 'Departamento de General José de San Martín', 'AR.17.3855106', 'ASCII:Departamento de General Jose de San Martin;ID:3855106', '6040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6040', '112', '7917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3855106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7918', '1079', '1', 'Partido de General Güemes', 'AR.03.3855108', 'ASCII:Partido de General Guemes;ID:3855108', '6041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6041', '112', '7918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3855108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7919', '1079', '1', 'Partido de General Belgrano', 'AR.03.3855125', 'ASCII:Partido de General Belgrano;ID:3855125', '6042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6042', '112', '7919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3855125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7920', '1079', '1', 'Departamento de General Belgrano', 'AR.12.3855127', 'ASCII:Departamento de General Belgrano;ID:3855127', '6043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6043', '112', '7920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3855127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7921', '1079', '1', 'Partido de General Arenales', 'AR.01.3855132', 'ASCII:Partido de General Arenales;ID:3855132', '6044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6044', '112', '7921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3855132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7922', '1079', '1', 'Partido de General Alvear', 'AR.01.3855135', 'ASCII:Partido de General Alvear;ID:3855135', '6045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6045', '112', '7922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3855135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7923', '1079', '1', 'Departamento de General Alvear', 'AR.13.3855136', 'ASCII:Departamento de General Alvear;ID:3855136', '6046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6046', '112', '7923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3855136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7924', '1079', '1', 'Departamento de Gastre', 'AR.04.3855185', 'ASCII:Departamento de Gastre;ID:3855185', '6047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6047', '112', '7924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3855185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7925', '1079', '1', 'Departamento de Garay', 'AR.21.3855221', 'ASCII:Departamento de Garay;ID:3855221', '6048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6048', '112', '7925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3855221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7926', '1079', '1', 'Departamento de Gaimán', 'AR.04.3855282', 'ASCII:Departamento de Gaiman;ID:3855282', '6049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6049', '112', '7926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3855282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7927', '1079', '1', 'Departamento de Futaleufú', 'AR.04.3855298', 'ASCII:Departamento de Futaleufu;ID:3855298', '6050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6050', '112', '7927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3855298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7928', '1079', '1', 'Departamento de Fray Mamerto Esquiú', 'AR.02.3855367', 'ASCII:Departamento de Fray Mamerto Esquiu;ID:3855367', '6051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6051', '112', '7928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3855367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7929', '1079', '1', 'Partido de Fray Justo Santa María de Oro', 'AR.03.3855371', 'ASCII:Partido de Fray Justo Santa Maria de Oro;ID:3855371', '6052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6052', '112', '7929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3855371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7930', '1079', '1', 'Departamento de Florentino Ameghino', 'AR.04.3855504', 'ASCII:Departamento de Florentino Ameghino;ID:3855504', '6053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6053', '112', '7930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3855504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7931', '1079', '1', 'Departamento de Figueroa', 'AR.22.3855567', 'ASCII:Departamento de Figueroa;ID:3855567', '6054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6054', '112', '7931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3855567» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7932', '1079', '1', 'Departamento de Famatina', 'AR.12.3855660', 'ASCII:Departamento de Famatina;ID:3855660', '6055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6055', '112', '7932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3855660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7933', '1079', '1', 'Departamento de Famaillá', 'AR.24.3855665', 'ASCII:Departamento de Famailla;ID:3855665', '6056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6056', '112', '7933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3855665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7934', '1079', '1', 'Departamento de Escalante', 'AR.04.3856121', 'ASCII:Departamento de Escalante;ID:3856121', '6057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6057', '112', '7934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3856121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7935', '1079', '1', 'Departamento de El Cuy', 'AR.16.3858240', 'ASCII:Departamento de El Cuy;ID:3858240', '6058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6058', '112', '7935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3858240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7936', '1079', '1', 'Departamento de El Carmen', 'AR.10.3858584', 'ASCII:Departamento de El Carmen;ID:3858584', '6059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6059', '112', '7936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3858584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7937', '1079', '1', 'Departamento de El Alto', 'AR.02.3858933', 'ASCII:Departamento de El Alto;ID:3858933', '6060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6060', '112', '7937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3858933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7938', '1079', '1', 'Partido de Doce de Octubre', 'AR.03.3859289', 'ASCII:Partido de Doce de Octubre;ID:3859289', '6061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6061', '112', '7938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3859289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7939', '1079', '1', 'Dapartamento de Diamante', 'AR.08.3859380', 'ASCII:Dapartamento de Diamante;ID:3859380', '6062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6062', '112', '7939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.08.3859380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7940', '1079', '1', 'Departamento de Deseado', 'AR.20.3859455', 'ASCII:Departamento de Deseado;ID:3859455', '6063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6063', '112', '7940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.20.3859455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7941', '1079', '1', 'Departamento de Cushamen', 'AR.04.3859556', 'ASCII:Departamento de Cushamen;ID:3859556', '6064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6064', '112', '7941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3859556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7942', '1079', '1', 'Departamento de Cura-Có', 'AR.11.3859613', 'ASCII:Departamento de Cura-Co;ID:3859613', '6065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6065', '112', '7942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3859613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7943', '1079', '1', 'Departamento de Cruz del Eje', 'AR.05.3859827', 'ASCII:Departamento de Cruz del Eje;ID:3859827', '6066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6066', '112', '7943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3859827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7944', '1079', '1', 'Departamento de Cruz Alta', 'AR.24.3859838', 'ASCII:Departamento de Cruz Alta;ID:3859838', '6067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6067', '112', '7944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3859838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7945', '1079', '1', 'Departamento de Corpen Aike', 'AR.20.3860153', 'ASCII:Departamento de Corpen Aike;ID:3860153', '6068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6068', '112', '7945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.20.3860153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7946', '1079', '1', 'Partido de Coronel Suárez', 'AR.01.3860163', 'ASCII:Partido de Coronel Suarez;ID:3860163', '6069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6069', '112', '7946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3860163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7947', '1079', '1', 'Partido de Coronel Pringles', 'AR.01.3860172', 'ASCII:Partido de Coronel Pringles;ID:3860172', '6070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6070', '112', '7947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3860172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7948', '1079', '1', 'Partido de Coronel Dorrego', 'AR.01.3860198', 'ASCII:Partido de Coronel Dorrego;ID:3860198', '6071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6071', '112', '7948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3860198» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7949', '1079', '1', 'Partido de Coronel de Marina Leonardo Rosales', 'AR.01.3860201', 'ASCII:Partido de Coronel de Marina Leonardo Rosales;ID:3860201', '6072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6072', '112', '7949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3860201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7950', '1079', '1', 'Departamento de Copo', 'AR.22.3860289', 'ASCII:Departamento de Copo;ID:3860289', '6073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6073', '112', '7950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3860289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7951', '1079', '1', 'Departamento de Constitución', 'AR.21.3860324', 'ASCII:Departamento de Constitucion;ID:3860324', '6074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6074', '112', '7951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3860324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7952', '1079', '1', 'Departamento de Conhello', 'AR.11.3860354', 'ASCII:Departamento de Conhello;ID:3860354', '6075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6075', '112', '7952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3860354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7953', '1079', '1', 'Departamento de Confluencia', 'AR.15.3860360', 'ASCII:Departamento de Confluencia;ID:3860360', '6076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6076', '112', '7953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3860360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7954', '1079', '1', 'Departamento de Conesa', 'AR.16.3860364', 'ASCII:Departamento de Conesa;ID:3860364', '6077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6077', '112', '7954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3860364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7955', '1079', '1', 'Partido de Comandante Fernández', 'AR.03.3860469', 'ASCII:Partido de Comandante Fernandez;ID:3860469', '6078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6078', '112', '7955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3860469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7956', '1079', '1', 'Partido de Colón', 'AR.01.3860822', 'ASCII:Partido de Colon;ID:3860822', '6079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6079', '112', '7956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3860822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7957', '1079', '1', 'Departamento de Colón', 'AR.05.3860825', 'ASCII:Departamento de Colon;ID:3860825', '6080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6080', '112', '7957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3860825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7958', '1079', '1', 'Departamento de Collón-Curá', 'AR.15.3860849', 'ASCII:Departamento de Collon-Cura;ID:3860849', '6081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6081', '112', '7958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3860849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7959', '1079', '1', 'Departamento de Cochinoca', 'AR.10.3860953', 'ASCII:Departamento de Cochinoca;ID:3860953', '6082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6082', '112', '7959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3860953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7960', '1079', '1', 'Departamento de Choya', 'AR.22.3861253', 'ASCII:Departamento de Choya;ID:3861253', '6083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6083', '112', '7960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3861253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7961', '1079', '1', 'Departamento de Chos-Malal', 'AR.15.3861261', 'ASCII:Departamento de Chos-Malal;ID:3861261', '6084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6084', '112', '7961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3861261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7962', '1079', '1', 'Departamento de Chimbas', 'AR.18.3861415', 'ASCII:Departamento de Chimbas;ID:3861415', '6085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6085', '112', '7962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3861415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7963', '1079', '1', 'Departamento de Chilecito', 'AR.12.3861443', 'ASCII:Departamento de Chilecito;ID:3861443', '6086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6086', '112', '7963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3861443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7964', '1079', '1', 'Departamento de Chicoana', 'AR.17.3861493', 'ASCII:Departamento de Chicoana;ID:3861493', '6087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6087', '112', '7964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3861493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7965', '1079', '1', 'Departamento de Chicligasta', 'AR.24.3861525', 'ASCII:Departamento de Chicligasta;ID:3861525', '6088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6088', '112', '7965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3861525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7966', '1079', '1', 'Departamento de Chical-Có', 'AR.11.3861539', 'ASCII:Departamento de Chical-Co;ID:3861539', '6089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6089', '112', '7966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3861539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7967', '1079', '1', 'Departamento de Chapaleufú', 'AR.11.3861714', 'ASCII:Departamento de Chapaleufu;ID:3861714', '6090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6090', '112', '7967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3861714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7968', '1079', '1', 'Departamento de Chalileo', 'AR.11.3861829', 'ASCII:Departamento de Chalileo;ID:3861829', '6091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6091', '112', '7968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3861829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7969', '1079', '1', 'Partido de Chacabuco', 'AR.01.3861944', 'ASCII:Partido de Chacabuco;ID:3861944', '6092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6092', '112', '7969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3861944» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7970', '1079', '1', 'Partido de Chacabuco', 'AR.03.3861945', 'ASCII:Partido de Chacabuco;ID:3861945', '6093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6093', '112', '7970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3861945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7971', '1079', '1', 'Departamento de Chacabuco', 'AR.19.3861949', 'ASCII:Departamento de Chacabuco;ID:3861949', '6094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6094', '112', '7971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.19.3861949» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7972', '1079', '1', 'Departamento de Cerrillos', 'AR.17.3862084', 'ASCII:Departamento de Cerrillos;ID:3862084', '6095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6095', '112', '7972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3862084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7973', '1079', '1', 'Departamento de Caucete', 'AR.18.3862239', 'ASCII:Departamento de Caucete;ID:3862239', '6096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6096', '112', '7973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3862239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7974', '1079', '1', 'Departamento de Catriló', 'AR.11.3862250', 'ASCII:Departamento de Catrilo;ID:3862250', '6097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6097', '112', '7974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3862250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7975', '1079', '1', 'Departamento de Catán-Lil', 'AR.15.3862279', 'ASCII:Departamento de Catan-Lil;ID:3862279', '6098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6098', '112', '7975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3862279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7976', '1079', '1', 'Departamento de Castro Barros', 'AR.12.3862292', 'ASCII:Departamento de Castro Barros;ID:3862292', '6099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6099', '112', '7976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3862292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7977', '1079', '1', 'Departamento de Castellanos', 'AR.21.3862325', 'ASCII:Departamento de Castellanos;ID:3862325', '6100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6100', '112', '7977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3862325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7978', '1079', '1', 'Partido de Caseros', 'AR.01.3862356', 'ASCII:Partido de Caseros;ID:3862356', '6101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6101', '112', '7978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3862356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7979', '1079', '1', 'Departamento de Caseros', 'AR.21.3862359', 'ASCII:Departamento de Caseros;ID:3862359', '6102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6102', '112', '7979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3862359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7980', '1079', '1', 'Partido de Carlos Tejedor', 'AR.01.3862599', 'ASCII:Partido de Carlos Tejedor;ID:3862599', '6103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6103', '112', '7980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3862599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7981', '1079', '1', 'Partido de Carlos Casares', 'AR.01.3862606', 'ASCII:Partido de Carlos Casares;ID:3862606', '6104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6104', '112', '7981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3862606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7982', '1079', '1', 'Departamento de Capital', 'AR.11.3862741', 'ASCII:Departamento de Capital;ID:3862741', '6105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6105', '112', '7982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3862741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7983', '1079', '1', 'Departamento de Capital', 'AR.13.3862742', 'ASCII:Departamento de Capital;ID:3862742', '6106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6106', '112', '7983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.13.3862742» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7984', '1079', '1', 'Departamento de Capital', 'AR.18.3862743', 'ASCII:Departamento de Capital;ID:3862743', '6107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6107', '112', '7984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3862743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7985', '1079', '1', 'Departamento de Capital', 'AR.05.3862744', 'ASCII:Departamento de Capital;ID:3862744', '6108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6108', '112', '7985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3862744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7986', '1079', '1', 'Departamento de Capital', 'AR.12.3862745', 'ASCII:Departamento de Capital;ID:3862745', '6109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6109', '112', '7986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3862745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7987', '1079', '1', 'Departamento de Capital', 'AR.02.3862746', 'ASCII:Departamento de Capital;ID:3862746', '6110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6110', '112', '7987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3862746» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7988', '1079', '1', 'Departamento de Capital', 'AR.22.3862747', 'ASCII:Departamento de Capital;ID:3862747', '6111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6111', '112', '7988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3862747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7989', '1079', '1', 'Departamento de Capital', 'AR.24.3862748', 'ASCII:Departamento de Capital;ID:3862748', '6112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6112', '112', '7989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3862748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7990', '1079', '1', 'Departamento de Capital', 'AR.17.3862749', 'ASCII:Departamento de Capital;ID:3862749', '6113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6113', '112', '7990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3862749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7991', '1079', '1', 'Departamento de Capital', 'AR.10.3862750', 'ASCII:Departamento de Capital;ID:3862750', '6114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6114', '112', '7991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.10.3862750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7992', '1079', '1', 'Departamento de Capayán', 'AR.02.3862771', 'ASCII:Departamento de Capayan;ID:3862771', '6115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6115', '112', '7992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3862771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7993', '1079', '1', 'Departamento de Candelaria', 'AR.17.3862830', 'ASCII:Departamento de Candelaria;ID:3862830', '6116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6116', '112', '7993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3862830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7994', '1079', '1', 'Departamento de Calingasta', 'AR.18.3863361', 'ASCII:Departamento de Calingasta;ID:3863361', '6117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6117', '112', '7994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3863361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7995', '1079', '1', 'Departamento de Caleu-Caleu', 'AR.11.3863378', 'ASCII:Departamento de Caleu-Caleu;ID:3863378', '6118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6118', '112', '7995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3863378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7996', '1079', '1', 'Departamento de Caldera', 'AR.17.3863400', 'ASCII:Departamento de Caldera;ID:3863400', '6119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6119', '112', '7996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3863400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7997', '1079', '1', 'Departamento de Calamuchita', 'AR.05.3863430', 'ASCII:Departamento de Calamuchita;ID:3863430', '6120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6120', '112', '7997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.05.3863430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7998', '1079', '1', 'Departamento de Cafayate', 'AR.17.3863502', 'ASCII:Departamento de Cafayate;ID:3863502', '6121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6121', '112', '7998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3863502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('7999', '1079', '1', 'Departamento de Cachí', 'AR.17.3863554', 'ASCII:Departamento de Cachi;ID:3863554', '6122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6122', '112', '7999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3863554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8000', '1079', '1', 'Departamento de Burruyacú', 'AR.24.3863700', 'ASCII:Departamento de Burruyacu;ID:3863700', '6123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6123', '112', '8000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.24.3863700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8001', '1079', '1', 'Partido de Bragado', 'AR.01.3863881', 'ASCII:Partido de Bragado;ID:3863881', '6124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6124', '112', '8001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3863881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8002', '1079', '1', 'Partido de Bolívar', 'AR.01.3863998', 'ASCII:Partido de Bolivar;ID:3863998', '6125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6125', '112', '8002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3863998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8003', '1079', '1', 'Departamento de Biedma', 'AR.04.3864255', 'ASCII:Departamento de Biedma;ID:3864255', '6126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6126', '112', '8003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.04.3864255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8004', '1079', '1', 'Departamento de Bermejo', 'AR.09.3864297', 'ASCII:Departamento de Bermejo;ID:3864297', '6127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6127', '112', '8004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.09.3864297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8005', '1079', '1', 'Departamento de Belgrano', 'AR.19.3864411', 'ASCII:Departamento de Belgrano;ID:3864411', '6128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6128', '112', '8005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.19.3864411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8006', '1079', '1', 'Departamento de Belgrano', 'AR.21.3864412', 'ASCII:Departamento de Belgrano;ID:3864412', '6129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6129', '112', '8006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.21.3864412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8007', '1079', '1', 'Departamento de Belgrano', 'AR.22.3864413', 'ASCII:Departamento de Belgrano;ID:3864413', '6130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6130', '112', '8007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3864413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8008', '1079', '1', 'Departamento de Belén', 'AR.02.3864427', 'ASCII:Departamento de Belen;ID:3864427', '6131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6131', '112', '8008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3864427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8009', '1079', '1', 'Departamento de Bariloche', 'AR.16.3864759', 'ASCII:Departamento de Bariloche;ID:3864759', '6132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6132', '112', '8009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3864759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8010', '1079', '1', 'Departamento de Banda', 'AR.22.3864853', 'ASCII:Departamento de Banda;ID:3864853', '6133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6133', '112', '8010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3864853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8011', '1079', '1', 'Departamento de Bahía Thetis', 'AR.23.3865075', 'ASCII:Departamento de Bahia Thetis;ID:3865075', '6134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6134', '112', '8011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.23.3865075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8012', '1079', '1', 'Partido de Bahía Blanca', 'AR.01.3865084', 'ASCII:Partido de Bahia Blanca;ID:3865084', '6135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6135', '112', '8012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3865084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8013', '1079', '1', 'Departamento de Ayacucho', 'AR.19.3865174', 'ASCII:Departamento de Ayacucho;ID:3865174', '6136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6136', '112', '8013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.19.3865174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8014', '1079', '1', 'Departamento de Avellaneda', 'AR.16.3865210', 'ASCII:Departamento de Avellaneda;ID:3865210', '6137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6137', '112', '8014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3865210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8015', '1079', '1', 'Departamento de Avellaneda', 'AR.22.3865211', 'ASCII:Departamento de Avellaneda;ID:3865211', '6138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6138', '112', '8015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3865211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8016', '1079', '1', 'Departamento de Atreucó', 'AR.11.3865245', 'ASCII:Departamento de Atreuco;ID:3865245', '6139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6139', '112', '8016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.11.3865245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8017', '1079', '1', 'Departamento de Atamisqui', 'AR.22.3865278', 'ASCII:Departamento de Atamisqui;ID:3865278', '6140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6140', '112', '8017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3865278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8018', '1079', '1', 'Departamento de Arauco', 'AR.12.3865578', 'ASCII:Departamento de Arauco;ID:3865578', '6141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6141', '112', '8018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.12.3865578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8019', '1079', '1', 'Departamento de Antofagasta de la Sierra', 'AR.02.3865661', 'ASCII:Departamento de Antofagasta de la Sierra;ID:3865661', '6142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6142', '112', '8019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3865661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8020', '1079', '1', 'Departamento de Anta', 'AR.17.3865696', 'ASCII:Departamento de Anta;ID:3865696', '6143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6143', '112', '8020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.17.3865696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8021', '1079', '1', 'Departamento de Angaco', 'AR.18.3865769', 'ASCII:Departamento de Angaco;ID:3865769', '6144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6144', '112', '8021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3865769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8022', '1079', '1', 'Departamento de Añelo', 'AR.15.3865775', 'ASCII:Departamento de Anelo;ID:3865775', '6145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6145', '112', '8022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3865775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8023', '1079', '1', 'Departamento de Andalgalá', 'AR.02.3865801', 'ASCII:Departamento de Andalgala;ID:3865801', '6146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6146', '112', '8023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3865801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8024', '1079', '1', 'Departamento de Ancasti', 'AR.02.3865829', 'ASCII:Departamento de Ancasti;ID:3865829', '6147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6147', '112', '8024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3865829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8025', '1079', '1', 'Departamento de Ambato', 'AR.02.3865906', 'ASCII:Departamento de Ambato;ID:3865906', '6148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6148', '112', '8025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.02.3865906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8026', '1079', '1', 'Departamento de Aluminé', 'AR.15.3865999', 'ASCII:Departamento de Alumine;ID:3865999', '6149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6149', '112', '8026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.15.3865999» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8027', '1079', '1', 'Partido de Almirante Brown', 'AR.03.3866226', 'ASCII:Partido de Almirante Brown;ID:3866226', '6150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6150', '112', '8027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.03.3866226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8028', '1079', '1', 'Partido de Alberti', 'AR.01.3866414', 'ASCII:Partido de Alberti;ID:3866414', '6151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6151', '112', '8028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3866414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8029', '1079', '1', 'Departamento de Alberdi', 'AR.22.3866417', 'ASCII:Departamento de Alberdi;ID:3866417', '6152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6152', '112', '8029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3866417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8030', '1079', '1', 'Departamento de Albardón', 'AR.18.3866424', 'ASCII:Departamento de Albardon;ID:3866424', '6153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6153', '112', '8030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.18.3866424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8031', '1079', '1', 'Departamento de Aguirre', 'AR.22.3866489', 'ASCII:Departamento de Aguirre;ID:3866489', '6154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6154', '112', '8031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.22.3866489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8032', '1079', '1', 'Partido de Adolfo Alsina', 'AR.01.3866926', 'ASCII:Partido de Adolfo Alsina;ID:3866926', '6155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6155', '112', '8032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.01.3866926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8033', '1079', '1', 'Departamento de Adolfo Alsina', 'AR.16.3866927', 'ASCII:Departamento de Adolfo Alsina;ID:3866927', '6156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6156', '112', '8033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AR.16.3866927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8034', '1079', '1', 'Politischer Bezirk Zwettl', 'AT.03.325', 'ASCII:Politischer Bezirk Zwettl;ID:2760421', '6157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6157', '112', '8034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8035', '1079', '1', 'Politischer Bezirk Zell am See', 'AT.05.506', 'ASCII:Politischer Bezirk Zell am See;ID:2760633', '6158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6158', '112', '8035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.05.506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8036', '1079', '1', 'Politischer Bezirk Wolfsberg', 'AT.02.209', 'ASCII:Politischer Bezirk Wolfsberg;ID:2760908', '6159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6159', '112', '8036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.02.209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8037', '1079', '1', 'Politischer Bezirk Wien Umgebung', 'AT.03.324', 'ASCII:Politischer Bezirk Wien Umgebung;ID:2761332', '6160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6160', '112', '8037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8038', '1079', '1', 'Politischer Bezirk Wien (Stadt)', 'AT.09.900', 'ASCII:Politischer Bezirk Wien (Stadt);ID:2761333', '6161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6161', '112', '8038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.09.900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8039', '1079', '1', 'Wiener Neustadt Stadt', 'AT.03.304', 'ASCII:Wiener Neustadt Stadt;ID:2761349', '6162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6162', '112', '8039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8040', '1079', '1', 'Politischer Bezirk Wiener Neustadt', 'AT.03.323', 'ASCII:Politischer Bezirk Wiener Neustadt;ID:2761352', '6163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6163', '112', '8040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.323» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8041', '1079', '1', 'Politischer Bezirk Wels', 'AT.04.418', 'ASCII:Politischer Bezirk Wels;ID:2761523', '6164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6164', '112', '8041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8042', '1079', '1', 'Politischer Bezirk Weiz', 'AT.06.617', 'ASCII:Politischer Bezirk Weiz;ID:2761530', '6165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6165', '112', '8042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8043', '1079', '1', 'Politischer Bezirk Waidhofen an der Thaya', 'AT.03.322', 'ASCII:Politischer Bezirk Waidhofen an der Thaya;ID:2762078', '6166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6166', '112', '8043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8044', '1079', '1', 'Politischer Bezirk Völkermarkt', 'AT.02.208', 'ASCII:Politischer Bezirk Volkermarkt;ID:2762314', '6167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6167', '112', '8044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.02.208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8045', '1079', '1', 'Politischer Bezirk Voitsberg', 'AT.06.616', 'ASCII:Politischer Bezirk Voitsberg;ID:2762326', '6168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6168', '112', '8045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8046', '1079', '1', 'Politischer Bezirk Vöcklabruck', 'AT.04.417', 'ASCII:Politischer Bezirk Vocklabruck;ID:2762342', '6169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6169', '112', '8046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8047', '1079', '1', 'Villach Stadt', 'AT.02.202', 'ASCII:Villach Stadt;ID:2762366', '6170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6170', '112', '8047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.02.202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8048', '1079', '1', 'Politischer Bezirk Villach Land', 'AT.02.207', 'ASCII:Politischer Bezirk Villach Land;ID:2762367', '6171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6171', '112', '8048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.02.207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8049', '1079', '1', 'Politischer Bezirk Urfahr Umgebung', 'AT.04.416', 'ASCII:Politischer Bezirk Urfahr Umgebung;ID:2762517', '6172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6172', '112', '8049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8050', '1079', '1', 'Politischer Bezirk Tulln', 'AT.03.321', 'ASCII:Politischer Bezirk Tulln;ID:2763265', '6173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6173', '112', '8050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8051', '1079', '1', 'Politischer Bezirk Tamsweg', 'AT.05.505', 'ASCII:Politischer Bezirk Tamsweg;ID:2763928', '6174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6174', '112', '8051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.05.505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8052', '1079', '1', 'Steyr Stadt', 'AT.04.402', 'ASCII:Steyr Stadt;ID:2764347', '6175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6175', '112', '8052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8053', '1079', '1', 'Politischer Bezirk Steyr', 'AT.04.415', 'ASCII:Politischer Bezirk Steyr;ID:2764357', '6176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6176', '112', '8053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8054', '1079', '1', 'Politischer Bezirk Spittal an der Drau', 'AT.02.206', 'ASCII:Politischer Bezirk Spittal an der Drau;ID:2764785', '6177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6177', '112', '8054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.02.206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8055', '1079', '1', 'Politischer Bezirk Schwaz', 'AT.07.709', 'ASCII:Politischer Bezirk Schwaz;ID:2765389', '6178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6178', '112', '8055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.07.709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8056', '1079', '1', 'Politischer Bezirk Scheibbs', 'AT.03.320', 'ASCII:Politischer Bezirk Scheibbs;ID:2766079', '6179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6179', '112', '8056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8057', '1079', '1', 'Politischer Bezirk Schärding', 'AT.04.414', 'ASCII:Politischer Bezirk Scharding;ID:2766154', '6180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6180', '112', '8057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8058', '1079', '1', 'Politischer Bezirk Sankt Veit an der Glan', 'AT.02.205', 'ASCII:Politischer Bezirk Sankt Veit an der Glan;ID:2766358', '6181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6181', '112', '8058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.02.205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8059', '1079', '1', 'Sankt Pölten Stadt', 'AT.03.302', 'ASCII:Sankt Polten Stadt;ID:2766426', '6182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6182', '112', '8059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8060', '1079', '1', 'Politischer Bezirk Sankt Pölten', 'AT.03.319', 'ASCII:Politischer Bezirk Sankt Polten;ID:2766428', '6183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6183', '112', '8060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8061', '1079', '1', 'Politischer Bezirk Sankt Johann im Pongau', 'AT.05.504', 'ASCII:Politischer Bezirk Sankt Johann im Pongau;ID:2766642', '6184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6184', '112', '8061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.05.504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8062', '1079', '1', 'Politischer Bezirk Salzburg Umgebung', 'AT.05.503', 'ASCII:Politischer Bezirk Salzburg Umgebung;ID:2766817', '6185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6185', '112', '8062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.05.503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8063', '1079', '1', 'Salzburg Stadt', 'AT.05.501', 'ASCII:Salzburg Stadt;ID:2766818', '6186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6186', '112', '8063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.05.501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8064', '1079', '1', 'Rust Stadt', 'AT.01.102', 'ASCII:Rust Stadt;ID:2766935', '6187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6187', '112', '8064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.01.102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8065', '1079', '1', 'Politischer Bezirk Rohrbach', 'AT.04.413', 'ASCII:Politischer Bezirk Rohrbach;ID:2767290', '6188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6188', '112', '8065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8066', '1079', '1', 'Politischer Bezirk Ried im Innkreis', 'AT.04.412', 'ASCII:Politischer Bezirk Ried im Innkreis;ID:2767470', '6189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6189', '112', '8066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8067', '1079', '1', 'Politischer Bezirk Reutte', 'AT.07.708', 'ASCII:Politischer Bezirk Reutte;ID:2767510', '6190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6190', '112', '8067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.07.708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8068', '1079', '1', 'Politischer Bezirk Radkersburg', 'AT.06.615', 'ASCII:Politischer Bezirk Radkersburg;ID:2768118', '6191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6191', '112', '8068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8069', '1079', '1', 'Politischer Bezirk Perg', 'AT.04.411', 'ASCII:Politischer Bezirk Perg;ID:2769104', '6192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6192', '112', '8069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8070', '1079', '1', 'Politischer Bezirk Oberwart', 'AT.01.109', 'ASCII:Politischer Bezirk Oberwart;ID:2769621', '6193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6193', '112', '8070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.01.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8071', '1079', '1', 'Politischer Bezirk Oberpullendorf', 'AT.01.108', 'ASCII:Politischer Bezirk Oberpullendorf;ID:2769811', '6194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6194', '112', '8071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.01.108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8072', '1079', '1', 'Politischer Bezirk Neusiedl am See', 'AT.01.107', 'ASCII:Politischer Bezirk Neusiedl am See;ID:2770682', '6195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6195', '112', '8072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.01.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8073', '1079', '1', 'Politischer Bezirk Neunkirchen', 'AT.03.318', 'ASCII:Politischer Bezirk Neunkirchen;ID:2770710', '6196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6196', '112', '8073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8074', '1079', '1', 'Politischer Bezirk Mürzzuschlag', 'AT.06.613', 'ASCII:Politischer Bezirk Murzzuschlag;ID:2770992', '6197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6197', '112', '8074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8075', '1079', '1', 'Politischer Bezirk Murau', 'AT.06.614', 'ASCII:Politischer Bezirk Murau;ID:2771016', '6198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6198', '112', '8075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8076', '1079', '1', 'Politischer Bezirk Mödling', 'AT.03.317', 'ASCII:Politischer Bezirk Modling;ID:2771333', '6199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6199', '112', '8076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8077', '1079', '1', 'Politischer Bezirk Mistelbach an der Zaya', 'AT.03.316', 'ASCII:Politischer Bezirk Mistelbach an der Zaya;ID:2771556', '6200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6200', '112', '8077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8078', '1079', '1', 'Politischer Bezirk Melk', 'AT.03.315', 'ASCII:Politischer Bezirk Melk;ID:2771680', '6201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6201', '112', '8078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8079', '1079', '1', 'Politischer Bezirk Mattersburg', 'AT.01.106', 'ASCII:Politischer Bezirk Mattersburg;ID:2771816', '6202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6202', '112', '8079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.01.106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8080', '1079', '1', 'Linz Stadt', 'AT.04.401', 'ASCII:Linz Stadt;ID:2772395', '6203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6203', '112', '8080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8081', '1079', '1', 'Politischer Bezirk Linz Land', 'AT.04.410', 'ASCII:Politischer Bezirk Linz Land;ID:2772396', '6204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6204', '112', '8081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8082', '1079', '1', 'Politischer Bezirk Lilienfeld', 'AT.03.314', 'ASCII:Politischer Bezirk Lilienfeld;ID:2772469', '6205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6205', '112', '8082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8083', '1079', '1', 'Politischer Bezirk Liezen', 'AT.06.612', 'ASCII:Politischer Bezirk Liezen;ID:2772479', '6206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6206', '112', '8083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8084', '1079', '1', 'Politischer Bezirk Lienz', 'AT.07.707', 'ASCII:Politischer Bezirk Lienz;ID:2772504', '6207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6207', '112', '8084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.07.707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8085', '1079', '1', 'Politischer Bezirk Leoben', 'AT.06.611', 'ASCII:Politischer Bezirk Leoben;ID:2772648', '6208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6208', '112', '8085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8086', '1079', '1', 'Politischer Bezirk Leibnitz', 'AT.06.610', 'ASCII:Politischer Bezirk Leibnitz;ID:2772752', '6209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6209', '112', '8086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8087', '1079', '1', 'Politischer Bezirk Landeck', 'AT.07.706', 'ASCII:Politischer Bezirk Landeck;ID:2773069', '6210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6210', '112', '8087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.07.706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8088', '1079', '1', 'Politischer Bezirk Kufstein', 'AT.07.705', 'ASCII:Politischer Bezirk Kufstein;ID:2773299', '6211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6211', '112', '8088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.07.705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8089', '1079', '1', 'Krems an der Donau Stadt', 'AT.03.301', 'ASCII:Krems an der Donau Stadt;ID:2773547', '6212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6212', '112', '8089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8090', '1079', '1', 'Politischer Bezirk Krems an der Donau', 'AT.03.313', 'ASCII:Politischer Bezirk Krems an der Donau;ID:2773548', '6213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6213', '112', '8090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8091', '1079', '1', 'Politischer Bezirk Korneuburg', 'AT.03.312', 'ASCII:Politischer Bezirk Korneuburg;ID:2773697', '6214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6214', '112', '8091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8092', '1079', '1', 'Politischer Bezirk Knittelfeld', 'AT.06.609', 'ASCII:Politischer Bezirk Knittelfeld;ID:2773886', '6215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6215', '112', '8092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8093', '1079', '1', 'Klagenfurt Stadt', 'AT.02.201', 'ASCII:Klagenfurt Stadt;ID:2774321', '6216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6216', '112', '8093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.02.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8094', '1079', '1', 'Politischer Bezirk Klagenfurt Land', 'AT.02.204', 'ASCII:Politischer Bezirk Klagenfurt Land;ID:2774323', '6217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6217', '112', '8094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.02.204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8095', '1079', '1', 'Politischer Bezirk Kitzbühel', 'AT.07.704', 'ASCII:Bezirk Kitzbuehel;ID:2774346', '6218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6218', '112', '8095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.07.704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8096', '1079', '1', 'Politischer Bezirk Kirchdorf an der Krems', 'AT.04.409', 'ASCII:Politischer Bezirk Kirchdorf an der Krems;ID:2774389', '6219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6219', '112', '8096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8097', '1079', '1', 'Politischer Bezirk Judenburg', 'AT.06.608', 'ASCII:Politischer Bezirk Judenburg;ID:2775019', '6220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6220', '112', '8097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8098', '1079', '1', 'Politischer Bezirk Jennersdorf', 'AT.01.105', 'ASCII:Politischer Bezirk Jennersdorf;ID:2775088', '6221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6221', '112', '8098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.01.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8099', '1079', '1', 'Innsbruck Stadt', 'AT.07.701', 'ASCII:Innsbruck Stadt;ID:2775216', '6222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6222', '112', '8099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.07.701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8100', '1079', '1', 'Politischer Bezirk Innsbruck', 'AT.07.703', 'ASCII:Politischer Bezirk Innsbruck;ID:2775219', '6223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6223', '112', '8100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.07.703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8101', '1079', '1', 'Politischer Bezirk Imst', 'AT.07.702', 'ASCII:Politischer Bezirk Imst;ID:2775306', '6224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6224', '112', '8101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.07.702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8102', '1079', '1', 'Politischer Bezirk Horn', 'AT.03.311', 'ASCII:Politischer Bezirk Horn;ID:2775515', '6225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6225', '112', '8102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8103', '1079', '1', 'Politischer Bezirk Hollabrunn', 'AT.03.310', 'ASCII:Politischer Bezirk Hollabrunn;ID:2775635', '6226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6226', '112', '8103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8104', '1079', '1', 'Politischer Bezirk Hermagor', 'AT.02.203', 'ASCII:Politischer Bezirk Hermagor;ID:2776496', '6227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6227', '112', '8104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.02.203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8105', '1079', '1', 'Politischer Bezirk Hartberg', 'AT.06.607', 'ASCII:Politischer Bezirk Hartberg;ID:2776799', '6228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6228', '112', '8105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8106', '1079', '1', 'Politischer Bezirk Hallein', 'AT.05.502', 'ASCII:Politischer Bezirk Hallein;ID:2776950', '6229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6229', '112', '8106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.05.502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8107', '1079', '1', 'Politischer Bezirk Güssing', 'AT.01.104', 'ASCII:Politischer Bezirk Gussing;ID:2777215', '6230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6230', '112', '8107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.01.104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8108', '1079', '1', 'Politischer Bezirk Grieskirchen', 'AT.04.408', 'ASCII:Politischer Bezirk Grieskirchen;ID:2777971', '6231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6231', '112', '8108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8109', '1079', '1', 'Politischer Bezirk Graz Umgebung', 'AT.06.606', 'ASCII:Politischer Bezirk Graz Umgebung;ID:2778057', '6232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6232', '112', '8109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8110', '1079', '1', 'Graz Stadt', 'AT.06.601', 'ASCII:Graz Stadt;ID:2778058', '6233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6233', '112', '8110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8111', '1079', '1', 'Politischer Bezirk Gmunden', 'AT.04.407', 'ASCII:Politischer Bezirk Gmunden;ID:2778435', '6234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6234', '112', '8111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8112', '1079', '1', 'Politischer Bezirk Gmünd', 'AT.03.309', 'ASCII:Politischer Bezirk Gmund;ID:2778438', '6235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6235', '112', '8112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8113', '1079', '1', 'Politischer Bezirk Gänserndorf', 'AT.03.308', 'ASCII:Politischer Bezirk Ganserndorf;ID:2778876', '6236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6236', '112', '8113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8114', '1079', '1', 'Politischer Bezirk Fürstenfeld', 'AT.06.605', 'ASCII:Politischer Bezirk Furstenfeld;ID:2779114', '6237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6237', '112', '8114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8115', '1079', '1', 'Politischer Bezirk Freistadt', 'AT.04.406', 'ASCII:Politischer Bezirk Freistadt;ID:2779274', '6238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6238', '112', '8115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8116', '1079', '1', 'Politischer Bezirk Feldkirch', 'AT.08.804', 'ASCII:Politischer Bezirk Feldkirch;ID:2779673', '6239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6239', '112', '8116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.08.804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8117', '1079', '1', 'Politischer Bezirk Feldbach', 'AT.06.604', 'ASCII:Politischer Bezirk Feldbach;ID:2779681', '6240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6240', '112', '8117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8118', '1079', '1', 'Eisenstadt Stadt', 'AT.01.101', 'ASCII:Eisenstadt Stadt;ID:2780188', '6241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6241', '112', '8118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.01.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8119', '1079', '1', 'Politischer Bezirk Eisenstadt', 'AT.01.103', 'ASCII:Politischer Bezirk Eisenstadt;ID:2780189', '6242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6242', '112', '8119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.01.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8120', '1079', '1', 'Politischer Bezirk Eferding', 'AT.04.405', 'ASCII:Politischer Bezirk Eferding;ID:2780393', '6243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6243', '112', '8120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8121', '1079', '1', 'Politischer Bezirk Dornbirn', 'AT.08.803', 'ASCII:Politischer Bezirk Dornbirn;ID:2780740', '6244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6244', '112', '8121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.08.803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8122', '1079', '1', 'Politischer Berzirk Deutschlandsberg', 'AT.06.603', 'ASCII:Politischer Berzirk Deutschlandsberg;ID:2781022', '6245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6245', '112', '8122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8123', '1079', '1', 'Politischer Bezirk Bruck an der Mur', 'AT.06.602', 'ASCII:Politischer Bezirk Bruck an der Mur;ID:2781370', '6246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6246', '112', '8123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.06.602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8124', '1079', '1', 'Politischer Bezirk Bruck an der Leitha', 'AT.03.307', 'ASCII:Politischer Bezirk Bruck an der Leitha;ID:2781372', '6247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6247', '112', '8124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8125', '1079', '1', 'Politischer Bezirk Bregenz', 'AT.08.802', 'ASCII:Politischer Bezirk Bregenz;ID:2781502', '6248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6248', '112', '8125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.08.802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8126', '1079', '1', 'Politischer Bezirk Braunau am Inn', 'AT.04.404', 'ASCII:Politischer Bezirk Braunau am Inn;ID:2781519', '6249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6249', '112', '8126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.04.404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8127', '1079', '1', 'Politischer Bezirk Bludenz', 'AT.08.801', 'ASCII:Politischer Bezirk Bludenz;ID:2781679', '6250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6250', '112', '8127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.08.801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8128', '1079', '1', 'Politischer Bezirk Baden', 'AT.03.306', 'ASCII:Politischer Bezirk Baden;ID:2782066', '6251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6251', '112', '8128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8129', '1079', '1', 'Politischer Bezirk Amstetten', 'AT.03.305', 'ASCII:Politischer Bezirk Amstetten;ID:2782554', '6252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6252', '112', '8129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8130', '1079', '1', 'Feldkirchen', 'AT.02.210', 'ASCII:Feldkirchen;ID:6459021', '6253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6253', '112', '8130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.02.210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8131', '1079', '1', 'Waidhofen an der Ybbs', 'AT.03.303', 'ASCII:Waidhofen an der Ybbs;ID:6621168', '6254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6254', '112', '8131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AT.03.303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8132', '1079', '1', 'City of West Torrens', 'AU.05.2058592', 'ASCII:City of West Torrens;ID:2058592', '6255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6255', '112', '8132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.05.2058592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8133', '1079', '1', 'West Pilbara Shire', 'AU.08.2058606', 'ASCII:West Pilbara Shire;ID:2058606', '6256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6256', '112', '8133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.08.2058606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8134', '1079', '1', 'Plantagenet Shire', 'AU.08.2063213', 'ASCII:Plantagenet Shire;ID:2063213', '6257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6257', '112', '8134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.08.2063213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8135', '1079', '1', 'Kent Shire', 'AU.08.2068570', 'ASCII:Kent Shire;ID:2068570', '6258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6258', '112', '8135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.08.2068570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8136', '1079', '1', 'Wyong Shire', 'AU.02.2142739', 'ASCII:Wyong Shire;ID:2142739', '6259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6259', '112', '8136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.02.2142739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8137', '1079', '1', 'Widgee Shire', 'AU.04.2143702', 'ASCII:Widgee Shire;ID:2143702', '6260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6260', '112', '8137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.04.2143702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8138', '1079', '1', 'Tamworth Municipality', 'AU.02.2147495', 'ASCII:Tamworth Municipality;ID:2147495', '6261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6261', '112', '8138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.02.2147495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8139', '1079', '1', 'South Sydney Municipality', 'AU.02.2148907', 'ASCII:South Sydney Municipality;ID:2148907', '6262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6262', '112', '8139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.02.2148907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8140', '1079', '1', 'Shepparton Shire', 'AU.07.2149644', 'ASCII:Shepparton Shire;ID:2149644', '6263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6263', '112', '8140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.07.2149644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8141', '1079', '1', 'Orange Municipality', 'AU.02.2154212', 'ASCII:Orange Municipality;ID:2154212', '6264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6264', '112', '8141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.02.2154212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8142', '1079', '1', 'Nathalia Shire', 'AU.07.2155686', 'ASCII:Nathalia Shire;ID:2155686', '6265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6265', '112', '8142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.07.2155686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8143', '1079', '1', 'Murrumbidgee Shire', 'AU.02.2156065', 'ASCII:Murrumbidgee Shire;ID:2156065', '6266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6266', '112', '8143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.02.2156065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8144', '1079', '1', 'Lake Macquarie Shire', 'AU.02.2160746', 'ASCII:Lake Macquarie Shire;ID:2160746', '6267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6267', '112', '8144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.02.2160746» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8145', '1079', '1', 'Gosford Shire', 'AU.02.2164848', 'ASCII:Gosford Shire;ID:2164848', '6268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6268', '112', '8145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.02.2164848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8146', '1079', '1', 'Diamond Valley Shire', 'AU.07.2168901', 'ASCII:Diamond Valley Shire;ID:2168901', '6269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6269', '112', '8146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.07.2168901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8147', '1079', '1', 'Blackall Shire', 'AU.04.2175645', 'ASCII:Blackall Shire;ID:2175645', '6270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6270', '112', '8147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.04.2175645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8148', '1079', '1', 'Armidale Dumaresq', 'AU.02.2177670', 'ASCII:Armidale Dumaresq;ID:2177670', '6271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6271', '112', '8148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.02.2177670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8149', '1079', '1', 'City of Sydney', 'AU.02.6619279', 'ASCII:City of Sydney;ID:6619279', '6272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6272', '112', '8149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AU.02.6619279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8150', '1079', '1', 'Şahbuz Rayonu', 'AZ.35.147212', 'ASCII:Sahbuz Rayonu;ID:147212', '6273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6273', '112', '8150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.35.147212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8151', '1079', '1', 'Ordubad Rayonu', 'AZ.35.147365', 'ASCII:Ordubad Rayonu;ID:147365', '6274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6274', '112', '8151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.35.147365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8152', '1079', '1', 'Şǝrur Rayonu', 'AZ.35.147997', 'ASCII:Sarur Rayonu;ID:147997', '6275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6275', '112', '8152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.35.147997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8153', '1079', '1', 'Culfa Rayonu', 'AZ.35.148132', 'ASCII:Culfa Rayonu;ID:148132', '6276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6276', '112', '8153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.35.148132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8154', '1079', '1', 'Nakhjavān', 'AZ.00.148412', 'ASCII:Nakhjavan;ID:148412', '6277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6277', '112', '8154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.00.148412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8155', '1079', '1', 'Sädäräk Rayonu', 'AZ.35.409387', 'ASCII:Sadarak Rayonu;ID:409387', '6278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6278', '112', '8155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.35.409387» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8156', '1079', '1', 'Şaumyan Rayonu', 'AZ.00.585038', 'ASCII:Saumyan Rayonu;ID:585038', '6279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6279', '112', '8156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.00.585038» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8157', '1079', '1', 'Shaumyanovskiy Rayon', 'AZ.09.585039', 'ASCII:Shaumyanovskiy Rayon;ID:585039', '6280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6280', '112', '8157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.09.585039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8158', '1079', '1', 'Ordzhonikidzevskiy Rayon))', 'AZ.09.585320', 'ASCII:Ordzhonikidzevskiy Rayon;ID:585320', '6281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6281', '112', '8158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.09.585320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8159', '1079', '1', 'Oktyabr''skiy Rayon', 'AZ.09.585328', 'ASCII:Oktyabr''skiy Rayon;ID:585328', '6282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6282', '112', '8159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.09.585328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8160', '1079', '1', 'Nizaminskiy Rayon', 'AZ.09.585358', 'ASCII:Nizaminskiy Rayon;ID:585358', '6283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6283', '112', '8160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.09.585358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8161', '1079', '1', 'Mirbǝşir Rayonu', 'AZ.00.585509', 'ASCII:Mirbasir Rayonu;ID:585509', '6284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6284', '112', '8161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.00.585509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8162', '1079', '1', 'Leninskiy Rayon', 'AZ.01.585638', 'ASCII:Leninskiy Rayon;ID:585638', '6285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6285', '112', '8162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.01.585638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8163', '1079', '1', 'Kirovskiy Rayon', 'AZ.01.585882', 'ASCII:Kirovskiy Rayon;ID:585882', '6286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6286', '112', '8163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.01.585882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8164', '1079', '1', 'Qaradağ Rayonu', 'AZ.09.586209', 'ASCII:Qaradag Rayonu;ID:586209', '6287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6287', '112', '8164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.09.586209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8165', '1079', '1', 'Imeni Dvadtsati Shesti Bakinskikh Komissarov Rayon', 'AZ.09.586342', 'ASCII:Imeni Dvadtsati Shesti Bakinskikh Komissarov Rayon;ID:586342', '6288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6288', '112', '8165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «AZ.09.586342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8166', '1079', '1', 'Opština Bileća', 'BA.02.3294539', 'ASCII:Opstina Bileca;ID:3294539', '6289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6289', '112', '8166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8167', '1079', '1', 'Opština Ljubinje', 'BA.02.3294540', 'ASCII:Opstina Ljubinje;ID:3294540', '6290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6290', '112', '8167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8168', '1079', '1', 'Opština Gacko', 'BA.02.3294558', 'ASCII:Opstina Gacko;ID:3294558', '6291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6291', '112', '8168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8169', '1079', '1', 'Opština Nevesinje', 'BA.02.3294561', 'ASCII:Opstina Nevesinje;ID:3294561', '6292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6292', '112', '8169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294561» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8170', '1079', '1', 'Opština Kalinovik', 'BA.02.3294564', 'ASCII:Opstina Kalinovik;ID:3294564', '6293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6293', '112', '8170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294564» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8171', '1079', '1', 'Opština Srbinje', 'BA.02.3294565', 'ASCII:Opstina Srbinje;ID:3294565', '6294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6294', '112', '8171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294565» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8172', '1079', '1', 'Opština Čajniče', 'BA.02.3294566', 'ASCII:Opstina Cajnice;ID:3294566', '6295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6295', '112', '8172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294566» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8173', '1079', '1', 'Opština Rudo', 'BA.02.3294770', 'ASCII:Opstina Rudo;ID:3294770', '6296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6296', '112', '8173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8174', '1079', '1', 'Opština Višegrad', 'BA.02.3294772', 'ASCII:Opstina Visegrad;ID:3294772', '6297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6297', '112', '8174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8175', '1079', '1', 'Opština Pale', 'BA.02.3294773', 'ASCII:Opstina Pale;ID:3294773', '6298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6298', '112', '8175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8176', '1079', '1', 'Opština Rogatica', 'BA.02.3294774', 'ASCII:Opstina Rogatica;ID:3294774', '6299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6299', '112', '8176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8177', '1079', '1', 'Opština Srebrenica', 'BA.02.3294829', 'ASCII:Opstina Srebrenica;ID:3294829', '6300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6300', '112', '8177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8178', '1079', '1', 'Opština Han Pijesak', 'BA.02.3294830', 'ASCII:Opstina Han Pijesak;ID:3294830', '6301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6301', '112', '8178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8179', '1079', '1', 'Opština Vlasenica', 'BA.02.3294839', 'ASCII:Opstina Vlasenica;ID:3294839', '6302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6302', '112', '8179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8180', '1079', '1', 'Opština Teslić', 'BA.02.3294865', 'ASCII:Opstina Teslic;ID:3294865', '6303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6303', '112', '8180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8181', '1079', '1', 'Opština Kotor-Varoš', 'BA.02.3294871', 'ASCII:Opstina Kotor-Varos;ID:3294871', '6304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6304', '112', '8181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294871» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8182', '1079', '1', 'Opština Lopare', 'BA.02.3294873', 'ASCII:Opstina Lopare;ID:3294873', '6305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6305', '112', '8182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8183', '1079', '1', 'Opština Ugljevik', 'BA.02.3294874', 'ASCII:Opstina Ugljevik;ID:3294874', '6306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6306', '112', '8183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8184', '1079', '1', 'Opština Čelinac', 'BA.02.3294889', 'ASCII:Opstina Celinac;ID:3294889', '6307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6307', '112', '8184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8185', '1079', '1', 'Opština Banja Luka', 'BA.02.3294893', 'ASCII:Opstina Banja Luka;ID:3294893', '6308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6308', '112', '8185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294893» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8186', '1079', '1', 'Opština Doboj', 'BA.02.3294894', 'ASCII:Opstina Doboj;ID:3294894', '6309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6309', '112', '8186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8187', '1079', '1', 'Opština Bijeljina', 'BA.02.3294896', 'ASCII:Opstina Bijeljina;ID:3294896', '6310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6310', '112', '8187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8188', '1079', '1', 'Opština Prnjavor', 'BA.02.3294904', 'ASCII:Opstina Prnjavor;ID:3294904', '6311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6311', '112', '8188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8189', '1079', '1', 'Opština Laktaši', 'BA.02.3294906', 'ASCII:Opstina Laktasi;ID:3294906', '6312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6312', '112', '8189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8190', '1079', '1', 'Opština Prijedor', 'BA.02.3294909', 'ASCII:Opstina Prijedor;ID:3294909', '6313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6313', '112', '8190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8191', '1079', '1', 'Opština Derventa', 'BA.02.3294910', 'ASCII:Opstina Derventa;ID:3294910', '6314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6314', '112', '8191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8192', '1079', '1', 'Opština Modriča', 'BA.02.3294911', 'ASCII:Opstina Modrica;ID:3294911', '6315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6315', '112', '8192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8193', '1079', '1', 'Opština Srbac', 'BA.02.3294912', 'ASCII:Opstina Srbac;ID:3294912', '6316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6316', '112', '8193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8194', '1079', '1', 'Općina Bosanski Novi', 'BA.02.3294915', 'ASCII:Opcina Bosanski Novi;ID:3294915', '6317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6317', '112', '8194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8195', '1079', '1', 'Opština Šamac', 'BA.02.3294916', 'ASCII:Opstina Samac;ID:3294916', '6318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6318', '112', '8195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8196', '1079', '1', 'Opština Gradiška', 'BA.02.3294917', 'ASCII:Opstina Gradiska;ID:3294917', '6319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6319', '112', '8196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8197', '1079', '1', 'Opština Srpski Brod', 'BA.02.3294918', 'ASCII:Opstina Srpski Brod;ID:3294918', '6320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6320', '112', '8197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3294918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8198', '1079', '1', 'Unsko-Sanski Kanton', 'BA.01.3343704', 'ASCII:Unsko-Sanski Kanton;ID:3343704', '6321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6321', '112', '8198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.01.3343704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8199', '1079', '1', 'Posavski Kanton', 'BA.01.3343706', 'ASCII:Posavina Canton;ID:3343706', '6322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6322', '112', '8199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.01.3343706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8200', '1079', '1', 'Tuzlanski Kanton', 'BA.01.3343716', 'ASCII:Tuzla Canton;ID:3343716', '6323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6323', '112', '8200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.01.3343716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8201', '1079', '1', 'Zeničko-Dobojski Kanton', 'BA.01.3343722', 'ASCII:Zenica-Doboj Canton;ID:3343722', '6324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6324', '112', '8201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.01.3343722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8202', '1079', '1', 'Bosansko-Podrinjski Kanton', 'BA.01.3343726', 'ASCII:Bosansko-Podrinjski Kanton;ID:3343726', '6325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6325', '112', '8202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.01.3343726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8203', '1079', '1', 'Srednjobosanski Kanton', 'BA.01.3343731', 'ASCII:Central Bosnia Canton;ID:3343731', '6326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6326', '112', '8203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.01.3343731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8204', '1079', '1', 'Hercegovačko-Neretvanski Kanton', 'BA.01.3343733', 'ASCII:Herzegovina-Neretva Canton;ID:3343733', '6327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6327', '112', '8204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.01.3343733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8205', '1079', '1', 'Zapadno-Hercegovački Kanton', 'BA.01.3343736', 'ASCII:West Herzegovina Canton;ID:3343736', '6328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6328', '112', '8205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.01.3343736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8206', '1079', '1', 'Kanton Sarajevo', 'BA.01.3343737', 'ASCII:Sarajevo Canton;ID:3343737', '6329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6329', '112', '8206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.01.3343737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8207', '1079', '1', 'Hercegovačko-Bosanski Kanton', 'BA.01.3343740', 'ASCII:Hercegovacko-Bosanski Kanton;ID:3343740', '6330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6330', '112', '8207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.01.3343740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8208', '1079', '1', 'Općina Bosanska Krupa', 'BA.02.3344087', 'ASCII:Opcina Bosanska Krupa;ID:3344087', '6331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6331', '112', '8208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8209', '1079', '1', 'Općina Bosanska Dubica', 'BA.02.3344088', 'ASCII:Opcina Bosanska Dubica;ID:3344088', '6332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6332', '112', '8209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8210', '1079', '1', 'Općina Sanski Most', 'BA.02.3344089', 'ASCII:Opcina Sanski Most;ID:3344089', '6333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6333', '112', '8210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8211', '1079', '1', 'Općina Odžak', 'BA.02.3344090', 'ASCII:Opcina Odzak;ID:3344090', '6334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6334', '112', '8211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8212', '1079', '1', 'Općina Orašje', 'BA.02.3344091', 'ASCII:Opcina Orasje;ID:3344091', '6335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6335', '112', '8212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8213', '1079', '1', 'Općina Gradačac', 'BA.02.3344092', 'ASCII:Opcina Gradacac;ID:3344092', '6336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6336', '112', '8213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8214', '1079', '1', 'Općina Skender Vakuf', 'BA.02.3344093', 'ASCII:Opcina Skender Vakuf;ID:3344093', '6337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6337', '112', '8214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8215', '1079', '1', 'Opština Mrkonjić-Grad', 'BA.02.3344094', 'ASCII:Opstina Mrkonjic-Grad;ID:3344094', '6338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6338', '112', '8215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8216', '1079', '1', 'Opština Šipovo', 'BA.02.3344095', 'ASCII:Opstina Sipovo;ID:3344095', '6339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6339', '112', '8216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8217', '1079', '1', 'Opština Petrovac', 'BA.02.3344096', 'ASCII:Opstina Petrovac;ID:3344096', '6340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6340', '112', '8217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8218', '1079', '1', 'Općina Drvar', 'BA.02.3344097', 'ASCII:Opcina Drvar;ID:3344097', '6341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6341', '112', '8218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8219', '1079', '1', 'Općina Ključ', 'BA.02.3344098', 'ASCII:Opcina Kljuc;ID:3344098', '6342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6342', '112', '8219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8220', '1079', '1', 'Mrkonjic Grad Jug Opcina', 'BA.02.3344099', 'ASCII:Mrkonjic Grad Jug Opcina;ID:3344099', '6343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6343', '112', '8220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8221', '1079', '1', 'Opština Zvornik', 'BA.02.3344100', 'ASCII:Opstina Zvornik;ID:3344100', '6344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6344', '112', '8221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8222', '1079', '1', 'Opština Osmaci', 'BA.02.3344101', 'ASCII:Opstina Osmaci;ID:3344101', '6345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6345', '112', '8222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8223', '1079', '1', 'Opština Šekovići', 'BA.02.3344102', 'ASCII:Opstina Sekovici;ID:3344102', '6346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6346', '112', '8223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8224', '1079', '1', 'Opština Bratunac', 'BA.02.3344103', 'ASCII:Opstina Bratunac;ID:3344103', '6347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6347', '112', '8224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8225', '1079', '1', 'Opština Sokolac', 'BA.02.3344104', 'ASCII:Opstina Sokolac;ID:3344104', '6348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6348', '112', '8225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8226', '1079', '1', 'Općina Goražde', 'BA.02.3344105', 'ASCII:Opcina Gorazde;ID:3344105', '6349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6349', '112', '8226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8227', '1079', '1', 'Opština Srpski Stari Grad', 'BA.02.3344106', 'ASCII:Opstina Srpski Stari Grad;ID:3344106', '6350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6350', '112', '8227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8228', '1079', '1', 'Općina Novo Sarajevo', 'BA.02.3344107', 'ASCII:Opcina Novo Sarajevo;ID:3344107', '6351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6351', '112', '8228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8229', '1079', '1', 'Općina Ilidža', 'BA.02.3344108', 'ASCII:Opcina Ilidza;ID:3344108', '6352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6352', '112', '8229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8230', '1079', '1', 'Opština Trnovo', 'BA.02.3344109', 'ASCII:Opstina Trnovo;ID:3344109', '6353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6353', '112', '8230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8231', '1079', '1', 'Opština Berkovići', 'BA.02.3344110', 'ASCII:Opstina Berkovici;ID:3344110', '6354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6354', '112', '8231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8232', '1079', '1', 'Općina Mostar', 'BA.02.3344111', 'ASCII:Opcina Mostar;ID:3344111', '6355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6355', '112', '8232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8233', '1079', '1', 'Općina Jajce', 'BA.02.3344112', 'ASCII:Opcina Jajce;ID:3344112', '6356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6356', '112', '8233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8234', '1079', '1', 'Opština Srpski Kupres', 'BA.02.3344113', 'ASCII:Opstina Srpski Kupres;ID:3344113', '6357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6357', '112', '8234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8235', '1079', '1', 'Opština Kostajnica', 'BA.02.3344114', 'ASCII:Opstina Kostajnica;ID:3344114', '6358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6358', '112', '8235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8236', '1079', '1', 'Opština Petrovo', 'BA.02.3344115', 'ASCII:Opstina Petrovo;ID:3344115', '6359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6359', '112', '8236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8237', '1079', '1', 'Opština Trebinje', 'BA.02.3344117', 'ASCII:Opstina Trebinje;ID:3344117', '6360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6360', '112', '8237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8238', '1079', '1', 'Opština Milići', 'BA.02.3344118', 'ASCII:Opstina Milici;ID:3344118', '6361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6361', '112', '8238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8239', '1079', '1', 'Skelani Opština', 'BA.02.3344119', 'ASCII:Skelani Opstina;ID:3344119', '6362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6362', '112', '8239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BA.02.3344119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8240', '1079', '1', 'Kushtia District', 'BD.82.1185185', 'ASCII:Kushtia District;ID:1185185', '6363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6363', '112', '8240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1185185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8241', '1079', '1', 'Parbattya Chattagram District', 'BD.85.1185245', 'ASCII:Parbattya Chattagram District;ID:1185245', '6364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6364', '112', '8241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.85.1185245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8242', '1079', '1', 'Barisāl District', 'BD.84.1185286', 'ASCII:Barisal District;ID:1185286', '6365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6365', '112', '8242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.84.1185286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8243', '1079', '1', 'Panchāgar District', 'BD.83.1337153', 'ASCII:Panchagar District;ID:1337153', '6366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6366', '112', '8243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8244', '1079', '1', 'Thākurgaon District', 'BD.83.1337154', 'ASCII:Thakurgaon District;ID:1337154', '6367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6367', '112', '8244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8245', '1079', '1', 'Dinājpur District', 'BD.83.1337155', 'ASCII:Dinajpur District;ID:1337155', '6368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6368', '112', '8245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8246', '1079', '1', 'Nilphāmāri District', 'BD.83.1337156', 'ASCII:Nilphamari District;ID:1337156', '6369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6369', '112', '8246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8247', '1079', '1', 'Lālmonirhāt District', 'BD.83.1337157', 'ASCII:Lalmonirhat District;ID:1337157', '6370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6370', '112', '8247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8248', '1079', '1', 'Kurīgrām District', 'BD.83.1337158', 'ASCII:Kurigram District;ID:1337158', '6371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6371', '112', '8248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8249', '1079', '1', 'Rangpur District', 'BD.83.1337159', 'ASCII:Rangpur District;ID:1337159', '6372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6372', '112', '8249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8250', '1079', '1', 'Gaibandha District', 'BD.83.1337160', 'ASCII:Gaibandha District;ID:1337160', '6373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6373', '112', '8250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8251', '1079', '1', 'Naogaon District', 'BD.83.1337161', 'ASCII:Naogaon District;ID:1337161', '6374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6374', '112', '8251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8252', '1079', '1', 'Jaipurhāt District', 'BD.83.1337162', 'ASCII:Jaipurhat District;ID:1337162', '6375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6375', '112', '8252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337162» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8253', '1079', '1', 'Bogra District', 'BD.83.1337163', 'ASCII:Bogra District;ID:1337163', '6376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6376', '112', '8253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8254', '1079', '1', 'Chapai Nawābganj District', 'BD.83.1337164', 'ASCII:Chapai Nawabganj District;ID:1337164', '6377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6377', '112', '8254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8255', '1079', '1', 'Rājshāhi District', 'BD.83.1337165', 'ASCII:Rajshahi District;ID:1337165', '6378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6378', '112', '8255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8256', '1079', '1', 'Nator District', 'BD.83.1337167', 'ASCII:Nator District;ID:1337167', '6379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6379', '112', '8256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8257', '1079', '1', 'Sirājganj District', 'BD.83.1337168', 'ASCII:Sirajganj District;ID:1337168', '6380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6380', '112', '8257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8258', '1079', '1', 'Pābna District', 'BD.83.1337169', 'ASCII:Pabna District;ID:1337169', '6381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6381', '112', '8258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.83.1337169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8259', '1079', '1', 'Sherpur District', 'BD.81.1337170', 'ASCII:Sherpur District;ID:1337170', '6382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6382', '112', '8259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8260', '1079', '1', 'Netrakona District', 'BD.81.1337171', 'ASCII:Netrakona District;ID:1337171', '6383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6383', '112', '8260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8261', '1079', '1', 'Jamālpur District', 'BD.81.1337172', 'ASCII:Jamalpur District;ID:1337172', '6384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6384', '112', '8261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8262', '1079', '1', 'Mymensingh District', 'BD.81.1337173', 'ASCII:Mymensingh District;ID:1337173', '6385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6385', '112', '8262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8263', '1079', '1', 'Tangail District', 'BD.81.1337174', 'ASCII:Tangail District;ID:1337174', '6386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6386', '112', '8263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8264', '1079', '1', 'Gāzipur District', 'BD.81.1337175', 'ASCII:Gazipur District;ID:1337175', '6387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6387', '112', '8264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8265', '1079', '1', 'Kishorganj District', 'BD.81.1337176', 'ASCII:Kishorganj District;ID:1337176', '6388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6388', '112', '8265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8266', '1079', '1', 'Narsingdi District', 'BD.81.1337177', 'ASCII:Narsingdi District;ID:1337177', '6389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6389', '112', '8266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8267', '1079', '1', 'Dhaka District', 'BD.81.1337178', 'ASCII:Dhaka District;ID:1337178', '6390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6390', '112', '8267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8268', '1079', '1', 'Rājbāri District', 'BD.81.1337180', 'ASCII:Rajbari District;ID:1337180', '6391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6391', '112', '8268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8269', '1079', '1', 'Farīdpur District', 'BD.81.1337181', 'ASCII:Faridpur District;ID:1337181', '6392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6392', '112', '8269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8270', '1079', '1', 'Nārāyanganj District', 'BD.81.1337182', 'ASCII:Narayanganj District;ID:1337182', '6393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6393', '112', '8270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8271', '1079', '1', 'Munshiganj District', 'BD.81.1337183', 'ASCII:Munshiganj District;ID:1337183', '6394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6394', '112', '8271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8272', '1079', '1', 'Gopālganj District', 'BD.81.1337184', 'ASCII:Gopalganj District;ID:1337184', '6395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6395', '112', '8272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8273', '1079', '1', 'Shariyatpur District', 'BD.81.1337186', 'ASCII:Shariyatpur District;ID:1337186', '6396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6396', '112', '8273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8274', '1079', '1', 'Mādārīpur District', 'BD.81.1337187', 'ASCII:Madaripur District;ID:1337187', '6397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6397', '112', '8274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8275', '1079', '1', 'Sunāmganj District', 'BD.86.1337188', 'ASCII:Sunamganj District;ID:1337188', '6398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6398', '112', '8275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.86.1337188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8276', '1079', '1', 'Sylhet District', 'BD.86.1337189', 'ASCII:Sylhet District;ID:1337189', '6399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6399', '112', '8276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.86.1337189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8277', '1079', '1', 'Moulvibāzār District', 'BD.86.1337190', 'ASCII:Moulvibazar District;ID:1337190', '6400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6400', '112', '8277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.86.1337190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8278', '1079', '1', 'Habiganj District', 'BD.86.1337191', 'ASCII:Habiganj District;ID:1337191', '6401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6401', '112', '8278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.86.1337191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8279', '1079', '1', 'Brāhmanbāria District', 'BD.85.1337192', 'ASCII:Brahmanbaria District;ID:1337192', '6402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6402', '112', '8279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.85.1337192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8280', '1079', '1', 'Comilla District', 'BD.85.1337193', 'ASCII:Comilla District;ID:1337193', '6403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6403', '112', '8280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.85.1337193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8281', '1079', '1', 'Chāndpur District', 'BD.85.1337194', 'ASCII:Chandpur District;ID:1337194', '6404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6404', '112', '8281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.85.1337194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8282', '1079', '1', 'Lakshmipur District', 'BD.85.1337195', 'ASCII:Lakshmipur District;ID:1337195', '6405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6405', '112', '8282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.85.1337195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8283', '1079', '1', 'Noākhāli District', 'BD.85.1337196', 'ASCII:Noakhali District;ID:1337196', '6406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6406', '112', '8283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.85.1337196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8284', '1079', '1', 'Feni District', 'BD.85.1337197', 'ASCII:Feni District;ID:1337197', '6407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6407', '112', '8284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.85.1337197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8285', '1079', '1', 'Khagrāchari District', 'BD.84.1337198', 'ASCII:Khagrachari District;ID:1337198', '6408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6408', '112', '8285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.84.1337198» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8286', '1079', '1', 'Chittagong District', 'BD.84.1337199', 'ASCII:Chittagong District;ID:1337199', '6409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6409', '112', '8286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.84.1337199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8287', '1079', '1', 'Bāndarban District', 'BD.85.1337201', 'ASCII:Bandarban District;ID:1337201', '6410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6410', '112', '8287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.85.1337201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8288', '1079', '1', 'Cox''s Bāzār District', 'BD.84.1337202', 'ASCII:Cox''s Bazar District;ID:1337202', '6411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6411', '112', '8288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.84.1337202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8289', '1079', '1', 'Meherpur District', 'BD.82.1337203', 'ASCII:Meherpur District;ID:1337203', '6412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6412', '112', '8289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1337203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8290', '1079', '1', 'Jhenaidah District', 'BD.82.1337204', 'ASCII:Jhenaidah District;ID:1337204', '6413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6413', '112', '8290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1337204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8291', '1079', '1', 'Chuādānga District', 'BD.82.1337205', 'ASCII:Chuadanga District;ID:1337205', '6414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6414', '112', '8291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1337205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8292', '1079', '1', 'Māgura District', 'BD.82.1337206', 'ASCII:Magura District;ID:1337206', '6415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6415', '112', '8292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1337206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8293', '1079', '1', 'Jessore District', 'BD.82.1337207', 'ASCII:Jessore District;ID:1337207', '6416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6416', '112', '8293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1337207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8294', '1079', '1', 'Narail District', 'BD.82.1337208', 'ASCII:Narail District;ID:1337208', '6417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6417', '112', '8294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1337208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8295', '1079', '1', 'Bāgerhāt District', 'BD.82.1337209', 'ASCII:Bagerhat District;ID:1337209', '6418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6418', '112', '8295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1337209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8296', '1079', '1', 'Khulna District', 'BD.82.1337211', 'ASCII:Khulna District;ID:1337211', '6419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6419', '112', '8296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1337211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8297', '1079', '1', 'Sātkhira District', 'BD.82.1337212', 'ASCII:Satkhira District;ID:1337212', '6420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6420', '112', '8297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1337212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8298', '1079', '1', 'Pirojpur District', 'BD.82.1337213', 'ASCII:Pirojpur District;ID:1337213', '6421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6421', '112', '8298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.82.1337213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8299', '1079', '1', 'Jhālakāti District', 'BD.84.1337214', 'ASCII:Jhalakati District;ID:1337214', '6422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6422', '112', '8299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.84.1337214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8300', '1079', '1', 'Bhola District', 'BD.84.1337215', 'ASCII:Bhola District;ID:1337215', '6423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6423', '112', '8300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.84.1337215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8301', '1079', '1', 'Patuākhāli District', 'BD.84.1337216', 'ASCII:Patuakhali District;ID:1337216', '6424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6424', '112', '8301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.84.1337216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8302', '1079', '1', 'Barguna District', 'BD.84.1337217', 'ASCII:Barguna District;ID:1337217', '6425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6425', '112', '8302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.84.1337217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8303', '1079', '1', 'Mānikganj District', 'BD.81.1337391', 'ASCII:Manikganj District;ID:1337391', '6426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6426', '112', '8303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.81.1337391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8304', '1079', '1', 'Pirojpur District', 'BD.84.1477494', 'ASCII:Pirojpur District;ID:1477494', '6427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6427', '112', '8304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BD.84.1477494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8305', '1079', '1', 'Provincie West-Vlaanderen', 'BE.VLG.VWV', 'ASCII:Provincie West-Vlaanderen;ID:2783770', '6428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6428', '112', '8305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.VLG.VWV» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8306', '1079', '1', 'Provincie Oost-Vlaanderen', 'BE.VLG.VOV', 'ASCII:Provincie Oost-Vlaanderen;ID:2789733', '6429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6429', '112', '8306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.VLG.VOV» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8307', '1079', '1', 'Province de Namur', 'BE.WAL.WNA', 'ASCII:Province de Namur;ID:2790469', '6430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6430', '112', '8307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.WAL.WNA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8308', '1079', '1', 'Province du Luxembourg', 'BE.WAL.WLX', 'ASCII:Province du Luxembourg;ID:2791993', '6431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6431', '112', '8308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.WAL.WLX» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8309', '1079', '1', 'Provincie Limburg', 'BE.VLG.VLI', 'ASCII:Provincie Limburg;ID:2792347', '6432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6432', '112', '8309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.VLG.VLI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8310', '1079', '1', 'Province de Liège', 'BE.WAL.WLG', 'ASCII:Province de Liege;ID:2792411', '6433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6433', '112', '8310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.WAL.WLG» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8311', '1079', '1', 'Province du Hainaut', 'BE.WAL.WHT', 'ASCII:Province du Hainaut;ID:2796741', '6434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6434', '112', '8311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.WAL.WHT» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8312', '1079', '1', 'Provincie Antwerpen', 'BE.VLG.VAN', 'ASCII:Provincie Antwerpen;ID:2803136', '6435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6435', '112', '8312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.VLG.VAN» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8313', '1079', '1', 'Provincie Vlaams-Brabant', 'BE.VLG.VBR', 'ASCII:Provincie Vlaams-Brabant;ID:3333250', '6436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6436', '112', '8313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.VLG.VBR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8314', '1079', '1', 'Province du Brabant Wallon', 'BE.WAL.WBR', 'ASCII:Province du Brabant Wallon;ID:3333251', '6437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6437', '112', '8314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.WAL.WBR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8315', '1079', '1', '(Bruxelles-Capitale)', 'BE.BRU.BRU', 'ASCII:(Bruxelles-Capitale);ID:6693370', '6438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6438', '112', '8315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BE.BRU.BRU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8316', '1079', '1', 'Obshtina Zlatograd', 'BG.57.SML11', 'ASCII:Obshtina Zlatograd;ID:725270', '6439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6439', '112', '8316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.57.SML11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8317', '1079', '1', 'Obshtina Zlataritsa', 'BG.62.VTR14', 'ASCII:Obshtina Zlataritsa;ID:725293', '6440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6440', '112', '8317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.62.VTR14» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8318', '1079', '1', 'Obshtina Zemen', 'BG.49.PER19', 'ASCII:Obshtina Zemen;ID:725401', '6441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6441', '112', '8318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.49.PER19» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8319', '1079', '1', 'Obshtina Zavet', 'BG.52.RAZ11', 'ASCII:Obshtina Zavet;ID:725434', '6442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6442', '112', '8319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.52.RAZ11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8320', '1079', '1', 'Obshtina Yambol', 'BG.65.JAM26', 'ASCII:Obshtina Yambol;ID:725577', '6443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6443', '112', '8320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.65.JAM26» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8321', '1079', '1', 'Obshtina Yakoruda', 'BG.38.BLG53', 'ASCII:Obshtina Yakoruda;ID:725585', '6444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6444', '112', '8321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG53» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8322', '1079', '1', 'Obshtina Yakimovo', 'BG.47.MON38', 'ASCII:Obshtina Yakimovo;ID:725587', '6445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6445', '112', '8322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON38» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8323', '1079', '1', 'Obshtina Yablanitsa', 'BG.46.LOV38', 'ASCII:Obshtina Yablanitsa;ID:725608', '6446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6446', '112', '8323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.46.LOV38» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8324', '1079', '1', 'Obshtina Vŭrshets', 'BG.47.MON12', 'ASCII:Obshtina Vurshets;ID:725622', '6447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6447', '112', '8324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8325', '1079', '1', 'Obshtina Vŭrbitsa', 'BG.54.SHU10', 'ASCII:Obshtina Vurbitsa;ID:725644', '6448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6448', '112', '8325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.54.SHU10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8326', '1079', '1', 'Obshtina Vŭlchidol', 'BG.61.VAR09', 'ASCII:Obshtina Vulchidol;ID:725677', '6449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6449', '112', '8326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8327', '1079', '1', 'Obshtina Vŭlchedrŭm', 'BG.47.MON11', 'ASCII:Obshtina Vulchedrum;ID:725682', '6450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6450', '112', '8327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8328', '1079', '1', 'Obshtina Vratsa', 'BG.64.VRC10', 'ASCII:Obshtina Vratsa;ID:725711', '6451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6451', '112', '8328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.64.VRC10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8329', '1079', '1', 'Obshtina Vidin', 'BG.63.VID09', 'ASCII:Obshtina Vidin;ID:725904', '6452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6452', '112', '8329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8330', '1079', '1', 'Obshtina Vetrino', 'BG.61.VAR08', 'ASCII:Obshtina Vetrino;ID:725923', '6453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6453', '112', '8330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8331', '1079', '1', 'Obshtina Vetovo', 'BG.53.RSE05', 'ASCII:Obshtina Vetovo;ID:725933', '6454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6454', '112', '8331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.53.RSE05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8332', '1079', '1', 'Obshtina Venets', 'BG.54.SHU07', 'ASCII:Obshtina Venets;ID:725966', '6455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6455', '112', '8332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.54.SHU07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8333', '1079', '1', 'Obshtina Velingrad', 'BG.48.PAZ08', 'ASCII:Obshtina Velingrad;ID:725987', '6456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6456', '112', '8333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8334', '1079', '1', 'Obshtina Veliko Tŭrnovo', 'BG.62.VTR04', 'ASCII:Obshtina Veliko Turnovo;ID:725992', '6457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6457', '112', '8334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.62.VTR04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8335', '1079', '1', 'Obshtina Varna', 'BG.61.VAR06', 'ASCII:Obshtina Varna;ID:726048', '6458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6458', '112', '8335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8336', '1079', '1', 'Obshtina Ugŭrchin', 'BG.46.LOV36', 'ASCII:Obshtina Ugurchin;ID:726113', '6459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6459', '112', '8336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.46.LOV36» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8337', '1079', '1', 'Obshtina Tvŭrditsa', 'BG.56.SLV24', 'ASCII:Obshtina Tvurditsa;ID:726128', '6460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6460', '112', '8337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.56.SLV24» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8338', '1079', '1', 'Obshtina Tutrakan', 'BG.55.SLS34', 'ASCII:Obshtina Tutrakan;ID:726140', '6461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6461', '112', '8338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.55.SLS34» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8339', '1079', '1', 'Obshtina Tŭrgovishte', 'BG.60.TGV35', 'ASCII:Obshtina Turgovishte;ID:726172', '6462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6462', '112', '8339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.60.TGV35» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8340', '1079', '1', 'Obshtina Tsenovo', 'BG.53.RSE37', 'ASCII:Obshtina Tsenovo;ID:726244', '6463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6463', '112', '8340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.53.RSE37» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8341', '1079', '1', 'Obshtina Tryavna', 'BG.41.GAB35', 'ASCII:Obshtina Tryavna;ID:726286', '6464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6464', '112', '8341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.41.GAB35» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8342', '1079', '1', 'Obshtina Trŭn', 'BG.49.PER51', 'ASCII:Obshtina Trun;ID:726306', '6465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6465', '112', '8342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.49.PER51» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8343', '1079', '1', 'Obshtina Troyan', 'BG.46.LOV34', 'ASCII:Obshtina Troyan;ID:726319', '6466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6466', '112', '8343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.46.LOV34» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8344', '1079', '1', 'Obshtina Treklyano', 'BG.45.KNL50', 'ASCII:Obshtina Treklyano;ID:726351', '6467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6467', '112', '8344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.45.KNL50» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8345', '1079', '1', 'Obshtina Topolovgrad', 'BG.43.HKV32', 'ASCII:Obshtina Topolovgrad;ID:726383', '6468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6468', '112', '8345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV32» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8346', '1079', '1', 'Obshtina Dobrich', 'BG.40.DOB28', 'ASCII:Obshtina Dobrich;ID:726417', '6469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6469', '112', '8346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.40.DOB28» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8347', '1079', '1', 'Obshtina Teteven', 'BG.46.LOV33', 'ASCII:Obshtina Teteven;ID:726463', '6470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6470', '112', '8347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.46.LOV33» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8348', '1079', '1', 'Obshtina Tervel', 'BG.40.DOB27', 'ASCII:Obshtina Tervel;ID:726473', '6471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6471', '112', '8348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.40.DOB27» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8349', '1079', '1', 'Obshtina Svoge', 'BG.58.SFO43', 'ASCII:Obshtina Svoge;ID:726523', '6472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6472', '112', '8349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO43» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8350', '1079', '1', 'Obshtina Svishtov', 'BG.62.VTR28', 'ASCII:Obshtina Svishtov;ID:726533', '6473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6473', '112', '8350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.62.VTR28» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8351', '1079', '1', 'Obshtina Svilengrad', 'BG.43.HKV28', 'ASCII:Obshtina Svilengrad;ID:726545', '6474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6474', '112', '8351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV28» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8352', '1079', '1', 'Obshtina Suvorovo', 'BG.61.VAR26', 'ASCII:Obshtina Suvorovo;ID:726590', '6475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6475', '112', '8352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR26» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8353', '1079', '1', 'Obshtina Sungurlare', 'BG.39.BGS23', 'ASCII:Obshtina Sungurlare;ID:726628', '6476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6476', '112', '8353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS23» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8354', '1079', '1', 'Obshtina Sukhindol', 'BG.62.VTR32', 'ASCII:Obshtina Sukhindol;ID:726642', '6477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6477', '112', '8354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.62.VTR32» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8355', '1079', '1', 'Obshtina Sŭedinenie', 'BG.51.PDV33', 'ASCII:Obshtina Suedinenie;ID:726653', '6478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6478', '112', '8355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV33» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8356', '1079', '1', 'Obshtina Strumyani', 'BG.38.BLG49', 'ASCII:Obshtina Strumyani;ID:726692', '6479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6479', '112', '8356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG49» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8357', '1079', '1', 'Obshtina Strelcha', 'BG.48.PAZ32', 'ASCII:Obshtina Strelcha;ID:726721', '6480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6480', '112', '8357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ32» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8358', '1079', '1', 'Obshtina Strazhitsa', 'BG.62.VTR31', 'ASCII:Obshtina Strazhitsa;ID:726725', '6481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6481', '112', '8358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.62.VTR31» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8359', '1079', '1', 'Obshtina Straldzha', 'BG.65.JAM22', 'ASCII:Obshtina Straldzha;ID:726747', '6482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6482', '112', '8359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.65.JAM22» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8360', '1079', '1', 'Obshtina Stara Zagora', 'BG.59.SZR31', 'ASCII:Obshtina Stara Zagora;ID:726847', '6483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6483', '112', '8360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR31» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8361', '1079', '1', 'Obshtina Dupnitsa', 'BG.45.KNL48', 'ASCII:Obshtina Dupnitsa;ID:726871', '6484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6484', '112', '8361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.45.KNL48» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8362', '1079', '1', 'Obshtina Stambolovo', 'BG.43.HKV30', 'ASCII:Obshtina Stambolovo;ID:726885', '6485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6485', '112', '8362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV30» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8363', '1079', '1', 'Obshtina Zlatitsa', 'BG.58.SFO47', 'ASCII:Obshtina Zlatitsa;ID:726917', '6486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6486', '112', '8363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO47» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8364', '1079', '1', 'Obshtina Sozopol', 'BG.39.BGS21', 'ASCII:Obshtina Sozopol;ID:726962', '6487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6487', '112', '8364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS21» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8365', '1079', '1', 'Obshtina Smyadovo', 'BG.54.SHU25', 'ASCII:Obshtina Smyadovo;ID:727023', '6488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6488', '112', '8365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.54.SHU25» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8366', '1079', '1', 'Obshtina Smolyan', 'BG.57.SML31', 'ASCII:Obshtina Smolyan;ID:727029', '6489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6489', '112', '8366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.57.SML31» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8367', '1079', '1', 'Obshtina Slivo Pole', 'BG.53.RSE33', 'ASCII:Obshtina Slivo Pole;ID:727066', '6490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6490', '112', '8367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.53.RSE33» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8368', '1079', '1', 'Obshtina Slivnitsa', 'BG.58.SFO45', 'ASCII:Obshtina Slivnitsa;ID:727068', '6491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6491', '112', '8368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO45» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8369', '1079', '1', 'Obshtina Sliven', 'BG.56.SLV20', 'ASCII:Obshtina Sliven;ID:727078', '6492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6492', '112', '8369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.56.SLV20» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8370', '1079', '1', 'Obshtina Sitovo', 'BG.55.SLS32', 'ASCII:Obshtina Sitovo;ID:727174', '6493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6493', '112', '8370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.55.SLS32» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8371', '1079', '1', 'Obshtina Simitli', 'BG.38.BLG44', 'ASCII:Obshtina Simitli;ID:727211', '6494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6494', '112', '8371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG44» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8372', '1079', '1', 'Obshtina Simeonovgrad', 'BG.43.HKV29', 'ASCII:Obshtina Simeonovgrad;ID:727216', '6495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6495', '112', '8372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV29» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8373', '1079', '1', 'Obshtina Silistra', 'BG.55.SLS31', 'ASCII:Obshtina Silistra;ID:727220', '6496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6496', '112', '8373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.55.SLS31» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8374', '1079', '1', 'Obshtina Shumen', 'BG.54.SHU30', 'ASCII:Obshtina Shumen;ID:727232', '6497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6497', '112', '8374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.54.SHU30» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8375', '1079', '1', 'Obshtina Shabla', 'BG.40.DOB29', 'ASCII:Obshtina Shabla;ID:727328', '6498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6498', '112', '8375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.40.DOB29» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8376', '1079', '1', 'Obshtina Sevlievo', 'BG.41.GAB29', 'ASCII:Obshtina Sevlievo;ID:727336', '6499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6499', '112', '8376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.41.GAB29» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8377', '1079', '1', 'Obshtina Septemvri', 'BG.48.PAZ29', 'ASCII:Obshtina Septemvri;ID:727353', '6500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6500', '112', '8377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ29» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8378', '1079', '1', 'Obshtina Satovcha', 'BG.38.BLG42', 'ASCII:Obshtina Satovcha;ID:727422', '6501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6501', '112', '8378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG42» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8379', '1079', '1', 'Obshtina Sapareva Banya', 'BG.45.KNL41', 'ASCII:Obshtina Sapareva Banya;ID:727440', '6502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6502', '112', '8379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.45.KNL41» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8380', '1079', '1', 'Obshtina Sandanski', 'BG.38.BLG40', 'ASCII:Obshtina Sandanski;ID:727446', '6503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6503', '112', '8380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG40» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8381', '1079', '1', 'Obshtina Samuil', 'BG.52.RAZ29', 'ASCII:Obshtina Samuil;ID:727454', '6504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6504', '112', '8381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.52.RAZ29» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8382', '1079', '1', 'Obshtina Samokov', 'BG.58.SFO39', 'ASCII:Obshtina Samokov;ID:727461', '6505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6505', '112', '8382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO39» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8383', '1079', '1', 'Obshtina Sadovo', 'BG.51.PDV28', 'ASCII:Obshtina Sadovo;ID:727476', '6506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6506', '112', '8383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV28» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8384', '1079', '1', 'Obshtina Ruzhintsi', 'BG.63.VID33', 'ASCII:Obshtina Ruzhintsi;ID:727494', '6507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6507', '112', '8384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID33» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8385', '1079', '1', 'Obshtina Ruse', 'BG.53.RSE27', 'ASCII:Obshtina Ruse;ID:727522', '6508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6508', '112', '8385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.53.RSE27» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8386', '1079', '1', 'Obshtina Ruen', 'BG.39.BGS18', 'ASCII:Obshtina Ruen;ID:727546', '6509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6509', '112', '8386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS18» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8387', '1079', '1', 'Obshtina Rudozem', 'BG.57.SML27', 'ASCII:Obshtina Rudozem;ID:727551', '6510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6510', '112', '8387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.57.SML27» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8388', '1079', '1', 'Obshtina Roman', 'BG.64.VRC32', 'ASCII:Obshtina Roman;ID:727597', '6511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6511', '112', '8388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.64.VRC32» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8389', '1079', '1', 'Obshtina Rila', 'BG.45.KNL38', 'ASCII:Obshtina Rila;ID:727627', '6512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6512', '112', '8389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.45.KNL38» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8390', '1079', '1', 'Obshtina Razlog', 'BG.38.BLG37', 'ASCII:Obshtina Razlog;ID:727688', '6513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6513', '112', '8390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG37» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8391', '1079', '1', 'Obshtina Razgrad', 'BG.52.RAZ26', 'ASCII:Obshtina Razgrad;ID:727693', '6514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6514', '112', '8391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.52.RAZ26» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8392', '1079', '1', 'Obshtina Rakovski', 'BG.51.PDV25', 'ASCII:Obshtina Rakovski;ID:727787', '6515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6515', '112', '8392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV25» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8393', '1079', '1', 'Obshtina Rakitovo', 'BG.48.PAZ24', 'ASCII:Obshtina Rakitovo;ID:727800', '6516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6516', '112', '8393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ24» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8394', '1079', '1', 'Obshtina Radomir', 'BG.49.PER36', 'ASCII:Obshtina Radomir;ID:727831', '6517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6517', '112', '8394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.49.PER36» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8395', '1079', '1', 'Obshtina Radnevo', 'BG.59.SZR27', 'ASCII:Obshtina Radnevo;ID:727837', '6518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6518', '112', '8395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR27» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8396', '1079', '1', 'Obshtina Pŭrvomay', 'BG.51.PDV23', 'ASCII:Obshtina Purvomay;ID:727885', '6519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6519', '112', '8396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV23» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8397', '1079', '1', 'Obshtina Provadiya', 'BG.61.VAR24', 'ASCII:Obshtina Provadiya;ID:727919', '6520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6520', '112', '8397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR24» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8398', '1079', '1', 'Obshtina Veliki Preslav', 'BG.54.SHU23', 'ASCII:Obshtina Veliki Preslav;ID:727986', '6521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6521', '112', '8398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.54.SHU23» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8399', '1079', '1', 'Obshtina Pordim', 'BG.50.PVN27', 'ASCII:Obshtina Pordim;ID:728055', '6522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6522', '112', '8399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN27» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8400', '1079', '1', 'Obshtina Popovo', 'BG.60.TGV24', 'ASCII:Obshtina Popovo;ID:728074', '6523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6523', '112', '8400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.60.TGV24» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8401', '1079', '1', 'Obshtina Pomorie', 'BG.39.BGS17', 'ASCII:Obshtina Pomorie;ID:728106', '6524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6524', '112', '8401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS17» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8402', '1079', '1', 'Obshtina Polski Trŭmbesh', 'BG.62.VTR26', 'ASCII:Obshtina Polski Trumbesh;ID:728123', '6525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6525', '112', '8402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.62.VTR26» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8403', '1079', '1', 'Obshtina Plovdiv', 'BG.51.PDV22', 'ASCII:Obshtina Plovdiv;ID:728192', '6526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6526', '112', '8403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV22» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8404', '1079', '1', 'Obshtina Pleven', 'BG.50.PVN24', 'ASCII:Obshtina Pleven;ID:728202', '6527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6527', '112', '8404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN24» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8405', '1079', '1', 'Obshtina Petrich', 'BG.38.BLG33', 'ASCII:Obshtina Petrich;ID:728286', '6528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6528', '112', '8405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG33» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8406', '1079', '1', 'Obshtina Peshtera', 'BG.48.PAZ21', 'ASCII:Obshtina Peshtera;ID:728315', '6529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6529', '112', '8406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ21» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8407', '1079', '1', 'Obshtina Pernik', 'BG.49.PER32', 'ASCII:Obshtina Pernik;ID:728329', '6530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6530', '112', '8407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.49.PER32» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8408', '1079', '1', 'Obshtina Iskŭr', 'BG.50.PVN23', 'ASCII:Obshtina Iskur;ID:728347', '6531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6531', '112', '8408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN23» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8409', '1079', '1', 'Obshtina Pazardzhik', 'BG.48.PAZ19', 'ASCII:Obshtina Pazardzhik;ID:728376', '6532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6532', '112', '8409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ19» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8410', '1079', '1', 'Obshtina Pavlikeni', 'BG.62.VTR22', 'ASCII:Obshtina Pavlikeni;ID:728384', '6533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6533', '112', '8410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.62.VTR22» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8411', '1079', '1', 'Obshtina Pavel Banya', 'BG.59.SZR24', 'ASCII:Obshtina Pavel Banya;ID:728388', '6534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6534', '112', '8411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR24» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8412', '1079', '1', 'Obshtina Panagyurishte', 'BG.48.PAZ20', 'ASCII:Obshtina Panagyurishte;ID:728447', '6535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6535', '112', '8412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ20» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8413', '1079', '1', 'Obshtina Oryakhovo', 'BG.64.VRC31', 'ASCII:Obshtina Oryakhovo;ID:728564', '6536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6536', '112', '8413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.64.VRC31» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8414', '1079', '1', 'Obshtina Opan', 'BG.59.SZR23', 'ASCII:Obshtina Opan;ID:728626', '6537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6537', '112', '8414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR23» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8415', '1079', '1', 'Obshtina Opaka', 'BG.60.TGV23', 'ASCII:Obshtina Opaka;ID:728630', '6538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6538', '112', '8415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.60.TGV23» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8416', '1079', '1', 'Obshtina Omurtag', 'BG.60.TGV22', 'ASCII:Obshtina Omurtag;ID:728633', '6539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6539', '112', '8416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.60.TGV22» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8417', '1079', '1', 'Obshtina Novo Selo', 'BG.63.VID30', 'ASCII:Obshtina Novo Selo;ID:728704', '6540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6540', '112', '8417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID30» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8418', '1079', '1', 'Obshtina Novi Pazar', 'BG.54.SHU22', 'ASCII:Obshtina Novi Pazar;ID:728733', '6541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6541', '112', '8418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.54.SHU22» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8419', '1079', '1', 'Obshtina Nova Zagora', 'BG.56.SLV16', 'ASCII:Obshtina Nova Zagora;ID:728741', '6542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6542', '112', '8419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.56.SLV16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8420', '1079', '1', 'Obshtina Nikopol', 'BG.50.PVN21', 'ASCII:Obshtina Nikopol;ID:728781', '6543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6543', '112', '8420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN21» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8421', '1079', '1', 'Obshtina Nikola-Kozlevo', 'BG.54.SHU21', 'ASCII:Obshtina Nikola-Kozlevo;ID:728790', '6544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6544', '112', '8421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.54.SHU21» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8422', '1079', '1', 'Obshtina Nevestino', 'BG.45.KNL31', 'ASCII:Obshtina Nevestino;ID:728815', '6545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6545', '112', '8422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.45.KNL31» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8423', '1079', '1', 'Obshtina Nesebŭr', 'BG.39.BGS15', 'ASCII:Obshtina Nesebur;ID:728824', '6546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6546', '112', '8423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS15» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8424', '1079', '1', 'Obshtina Nedelino', 'BG.57.SML18', 'ASCII:Obshtina Nedelino;ID:728850', '6547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6547', '112', '8424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.57.SML18» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8425', '1079', '1', 'Obshtina Mŭglizh', 'BG.59.SZR22', 'ASCII:Obshtina Muglizh;ID:728927', '6548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6548', '112', '8425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR22» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8426', '1079', '1', 'Obshtina Momchilgrad', 'BG.44.KRZ21', 'ASCII:Obshtina Momchilgrad;ID:728994', '6549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6549', '112', '8426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.44.KRZ21» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8427', '1079', '1', 'Obshtina Miziya', 'BG.64.VRC28', 'ASCII:Obshtina Miziya;ID:729039', '6550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6550', '112', '8427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.64.VRC28» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8428', '1079', '1', 'Obshtina Mineralni Bani', 'BG.43.HKV19', 'ASCII:Obshtina Mineralni Bani;ID:729072', '6551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6551', '112', '8428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV19» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8429', '1079', '1', 'Obshtina Montana', 'BG.47.MON29', 'ASCII:Obshtina Montana;ID:729113', '6552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6552', '112', '8429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON29» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8430', '1079', '1', 'Obshtina Tsarevo', 'BG.39.BGS13', 'ASCII:Obshtina Tsarevo;ID:729123', '6553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6553', '112', '8430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8431', '1079', '1', 'Obshtina Mezdra', 'BG.64.VRC27', 'ASCII:Obshtina Mezdra;ID:729133', '6554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6554', '112', '8431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.64.VRC27» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8432', '1079', '1', 'Obshtina Medkovets', 'BG.47.MON26', 'ASCII:Obshtina Medkovets;ID:729173', '6555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6555', '112', '8432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON26» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8433', '1079', '1', 'Obshtina Malko Tŭrnovo', 'BG.39.BGS12', 'ASCII:Obshtina Malko Turnovo;ID:729321', '6556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6556', '112', '8433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8434', '1079', '1', 'Obshtina Makresh', 'BG.63.VID25', 'ASCII:Obshtina Makresh;ID:729400', '6557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6557', '112', '8434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID25» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8435', '1079', '1', 'Obshtina Madan', 'BG.57.SML16', 'ASCII:Obshtina Madan;ID:729437', '6558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6558', '112', '8435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.57.SML16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8436', '1079', '1', 'Obshtina Lyubimets', 'BG.43.HKV17', 'ASCII:Obshtina Lyubimets;ID:729465', '6559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6559', '112', '8436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV17» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8437', '1079', '1', 'Obshtina Lyaskovets', 'BG.62.VTR20', 'ASCII:Obshtina Lyaskovets;ID:729488', '6560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6560', '112', '8437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.62.VTR20» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8438', '1079', '1', 'Obshtina Lukovit', 'BG.46.LOV19', 'ASCII:Obshtina Lukovit;ID:729506', '6561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6561', '112', '8438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.46.LOV19» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8439', '1079', '1', 'Obshtina Lŭki', 'BG.51.PDV15', 'ASCII:Obshtina Luki;ID:729508', '6562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6562', '112', '8439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV15» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8440', '1079', '1', 'Obshtina Loznitsa', 'BG.52.RAZ17', 'ASCII:Obshtina Loznitsa;ID:729528', '6563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6563', '112', '8440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.52.RAZ17» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8441', '1079', '1', 'Obshtina Lovech', 'BG.46.LOV18', 'ASCII:Obshtina Lovech;ID:729558', '6564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6564', '112', '8441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.46.LOV18» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8442', '1079', '1', 'Obshtina Lom', 'BG.47.MON24', 'ASCII:Obshtina Lom;ID:729579', '6565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6565', '112', '8442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON24» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8443', '1079', '1', 'Obshtina Levski', 'BG.50.PVN16', 'ASCII:Obshtina Levski;ID:729635', '6566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6566', '112', '8443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8444', '1079', '1', 'Obshtina Letnitsa', 'BG.46.LOV17', 'ASCII:Obshtina Letnitsa;ID:729645', '6567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6567', '112', '8444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.46.LOV17» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8445', '1079', '1', 'Obshtina Lesichevo', 'BG.48.PAZ14', 'ASCII:Obshtina Lesichevo;ID:729666', '6568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6568', '112', '8445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ14» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8446', '1079', '1', 'Obshtina Kyustendil', 'BG.45.KNL29', 'ASCII:Obshtina Kyustendil;ID:729729', '6569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6569', '112', '8446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.45.KNL29» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8447', '1079', '1', 'Obshtina Kŭrdzhali', 'BG.44.KRZ16', 'ASCII:Obshtina Kurdzhali;ID:729792', '6570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6570', '112', '8447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.44.KRZ16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8448', '1079', '1', 'Obshtina Kula', 'BG.63.VID22', 'ASCII:Obshtina Kula;ID:729824', '6571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6571', '112', '8448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID22» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8449', '1079', '1', 'Obshtina Kubrat', 'BG.52.RAZ16', 'ASCII:Obshtina Kubrat;ID:729838', '6572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6572', '112', '8449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.52.RAZ16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8450', '1079', '1', 'Obshtina Krushari', 'BG.40.DOB20', 'ASCII:Obshtina Krushari;ID:729879', '6573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6573', '112', '8450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.40.DOB20» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8451', '1079', '1', 'Obshtina Krumovgrad', 'BG.44.KRZ15', 'ASCII:Obshtina Krumovgrad;ID:729895', '6574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6574', '112', '8451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.44.KRZ15» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8452', '1079', '1', 'Obshtina Krivodol', 'BG.64.VRC21', 'ASCII:Obshtina Krivodol;ID:729907', '6575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6575', '112', '8452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.64.VRC21» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8453', '1079', '1', 'Obshtina Kresna', 'BG.38.BLG28', 'ASCII:Obshtina Kresna;ID:729941', '6576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6576', '112', '8453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG28» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8454', '1079', '1', 'Obshtina Kozloduy', 'BG.64.VRC20', 'ASCII:Obshtina Kozloduy;ID:730012', '6577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6577', '112', '8454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.64.VRC20» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8455', '1079', '1', 'Obshtina Kovachevtsi', 'BG.49.PER22', 'ASCII:Obshtina Kovachevtsi;ID:730049', '6578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6578', '112', '8455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.49.PER22» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8456', '1079', '1', 'Obshtina Kotel', 'BG.56.SLV11', 'ASCII:Obshtina Kotel;ID:730072', '6579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6579', '112', '8456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.56.SLV11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8457', '1079', '1', 'Obshtina Kostinbrod', 'BG.58.SFO26', 'ASCII:Obshtina Kostinbrod;ID:730083', '6580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6580', '112', '8457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO26» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8458', '1079', '1', 'Obshtina Kostenets', 'BG.58.SFO25', 'ASCII:Obshtina Kostenets;ID:730092', '6581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6581', '112', '8458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO25» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8459', '1079', '1', 'Obshtina Koprivshtitsa', 'BG.58.SFO24', 'ASCII:Obshtina Koprivshtitsa;ID:730158', '6582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6582', '112', '8459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO24» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8460', '1079', '1', 'Obshtina Kocherinovo', 'BG.45.KNL27', 'ASCII:Obshtina Kocherinovo;ID:730267', '6583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6583', '112', '8460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.45.KNL27» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8461', '1079', '1', 'Obshtina Knezha', 'BG.50.PVN39', 'ASCII:Obshtina Knezha;ID:730286', '6584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6584', '112', '8461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN39» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8462', '1079', '1', 'Obshtina Kirkovo', 'BG.44.KRZ14', 'ASCII:Obshtina Kirkovo;ID:730353', '6585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6585', '112', '8462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.44.KRZ14» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8463', '1079', '1', 'Obshtina Tsar Kaloyan', 'BG.52.RAZ36', 'ASCII:Obshtina Tsar Kaloyan;ID:730414', '6586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6586', '112', '8463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.52.RAZ36» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8464', '1079', '1', 'Obshtina Khisarya', 'BG.51.PDV37', 'ASCII:Obshtina Khisarya;ID:730418', '6587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6587', '112', '8464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV37» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8465', '1079', '1', 'Obshtina Khaskovo', 'BG.43.HKV34', 'ASCII:Obshtina Khaskovo;ID:730434', '6588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6588', '112', '8465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV34» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8466', '1079', '1', 'Obshtina Kharmanli', 'BG.43.HKV33', 'ASCII:Obshtina Kharmanli;ID:730441', '6589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6589', '112', '8466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV33» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8467', '1079', '1', 'Obshtina Khadzhidimovo', 'BG.38.BLG52', 'ASCII:Obshtina Khadzhidimovo;ID:730463', '6590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6590', '112', '8467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG52» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8468', '1079', '1', 'Obshtina Kazanlŭk', 'BG.59.SZR12', 'ASCII:Obshtina Kazanluk;ID:730495', '6591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6591', '112', '8468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8469', '1079', '1', 'Obshtina Kaynardzha', 'BG.55.SLS15', 'ASCII:Obshtina Kaynardzha;ID:730502', '6592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6592', '112', '8469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.55.SLS15» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8470', '1079', '1', 'Obshtina Kavarna', 'BG.40.DOB17', 'ASCII:Obshtina Kavarna;ID:730517', '6593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6593', '112', '8470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.40.DOB17» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8471', '1079', '1', 'Obshtina Kaspichan', 'BG.54.SHU19', 'ASCII:Obshtina Kaspichan;ID:730540', '6594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6594', '112', '8471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.54.SHU19» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8472', '1079', '1', 'Obshtina Karnobat', 'BG.39.BGS09', 'ASCII:Obshtina Karnobat;ID:730558', '6595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6595', '112', '8472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8473', '1079', '1', 'Obshtina Karlovo', 'BG.51.PDV13', 'ASCII:Obshtina Karlovo;ID:730564', '6596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6596', '112', '8473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8474', '1079', '1', 'Obshtina Kaolinovo', 'BG.54.SHU18', 'ASCII:Obshtina Kaolinovo;ID:730650', '6597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6597', '112', '8474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.54.SHU18» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8475', '1079', '1', 'Obshtina Kameno', 'BG.39.BGS08', 'ASCII:Obshtina Kameno;ID:730679', '6598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6598', '112', '8475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8476', '1079', '1', 'Obshtina Kaloyanovo', 'BG.51.PDV12', 'ASCII:Obshtina Kaloyanovo;ID:730731', '6599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6599', '112', '8476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8477', '1079', '1', 'Obshtina Ivaylovgrad', 'BG.43.HKV11', 'ASCII:Obshtina Ivaylovgrad;ID:730836', '6600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6600', '112', '8477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8478', '1079', '1', 'Obshtina Ivanovo', 'BG.53.RSE13', 'ASCII:Obshtina Ivanovo;ID:730851', '6601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6601', '112', '8478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.53.RSE13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8479', '1079', '1', 'Obshtina Isperikh', 'BG.52.RAZ14', 'ASCII:Obshtina Isperikh;ID:730865', '6602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6602', '112', '8479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.52.RAZ14» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8480', '1079', '1', 'Obshtina Ikhtiman', 'BG.58.SFO20', 'ASCII:Obshtina Ikhtiman;ID:730918', '6603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6603', '112', '8480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO20» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8481', '1079', '1', 'Obshtina Gŭrmen', 'BG.38.BLG13', 'ASCII:Obshtina Gurmen;ID:730959', '6604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6604', '112', '8481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8482', '1079', '1', 'Obshtina Gurkovo', 'BG.59.SZR37', 'ASCII:Obshtina Gurkovo;ID:730965', '6605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6605', '112', '8482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR37» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8483', '1079', '1', 'Obshtina Gulyantsi', 'BG.50.PVN08', 'ASCII:Obshtina Gulyantsi;ID:730981', '6606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6606', '112', '8483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8484', '1079', '1', 'Obshtina Gŭlŭbovo', 'BG.59.SZR07', 'ASCII:Obshtina Gulubovo;ID:730984', '6607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6607', '112', '8484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8485', '1079', '1', 'Obshtina Sredets', 'BG.39.BGS06', 'ASCII:Obshtina Sredets;ID:731015', '6608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6608', '112', '8485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8486', '1079', '1', 'Obshtina Gramada', 'BG.63.VID15', 'ASCII:Obshtina Gramada;ID:731054', '6609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6609', '112', '8486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID15» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8487', '1079', '1', 'Obshtina Gotse Delchev', 'BG.38.BLG11', 'ASCII:Obshtina Gotse Delchev;ID:731107', '6610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6610', '112', '8487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8488', '1079', '1', 'Obshtina Gorna Oryakhovitsa', 'BG.62.VTR06', 'ASCII:Obshtina Gorna Oryakhovitsa;ID:731232', '6611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6611', '112', '8488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.62.VTR06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8489', '1079', '1', 'Obshtina Gorna Malina', 'BG.58.SFO10', 'ASCII:Obshtina Gorna Malina;ID:731238', '6612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6612', '112', '8489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8490', '1079', '1', 'Obshtina Godech', 'BG.58.SFO09', 'ASCII:Obshtina Godech;ID:731383', '6613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6613', '112', '8490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8491', '1079', '1', 'Obshtina Glavinitsa', 'BG.55.SLS07', 'ASCII:Obshtina Glavinitsa;ID:731414', '6614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6614', '112', '8491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.55.SLS07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8492', '1079', '1', 'Obshtina Dolni Chiflik', 'BG.61.VAR13', 'ASCII:Obshtina Dolni Chiflik;ID:731452', '6615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6615', '112', '8492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8493', '1079', '1', 'Obshtina Georgi-Damyanovo', 'BG.47.MON14', 'ASCII:Obshtina Georgi-Damyanovo;ID:731457', '6616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6616', '112', '8493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON14» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8494', '1079', '1', 'Obshtina General-Toshevo', 'BG.40.DOB12', 'ASCII:Obshtina General-Toshevo;ID:731463', '6617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6617', '112', '8494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.40.DOB12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8495', '1079', '1', 'Obshtina Khitrino', 'BG.54.SHU11', 'ASCII:Obshtina Khitrino;ID:731519', '6618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6618', '112', '8495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.54.SHU11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8496', '1079', '1', 'Obshtina Gabrovo', 'BG.41.GAB05', 'ASCII:Obshtina Gabrovo;ID:731548', '6619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6619', '112', '8496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.41.GAB05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8497', '1079', '1', 'Obshtina Etropole', 'BG.58.SFO18', 'ASCII:Obshtina Etropole;ID:731625', '6620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6620', '112', '8497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO18» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8498', '1079', '1', 'Obshtina Elkhovo', 'BG.65.JAM07', 'ASCII:Obshtina Elkhovo;ID:731668', '6621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6621', '112', '8498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.65.JAM07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8499', '1079', '1', 'Obshtina Elin Pelin', 'BG.58.SFO17', 'ASCII:Obshtina Elin Pelin;ID:731674', '6622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6622', '112', '8499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO17» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8500', '1079', '1', 'Obshtina Elena', 'BG.62.VTR13', 'ASCII:Obshtina Elena;ID:731695', '6623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6623', '112', '8500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.62.VTR13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8501', '1079', '1', 'Obshtina Dzhebel', 'BG.44.KRZ08', 'ASCII:Obshtina Dzhebel;ID:731740', '6624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6624', '112', '8501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.44.KRZ08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8502', '1079', '1', 'Obshtina Dve Mogili', 'BG.53.RSE08', 'ASCII:Obshtina Dve Mogili;ID:731770', '6625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6625', '112', '8502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.53.RSE08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8503', '1079', '1', 'Obshtina Dulovo', 'BG.55.SLS10', 'ASCII:Obshtina Dulovo;ID:731816', '6626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6626', '112', '8503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.55.SLS10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8504', '1079', '1', 'Obshtina Dŭlgopol', 'BG.61.VAR16', 'ASCII:Obshtina Dulgopol;ID:731821', '6627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6627', '112', '8504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8505', '1079', '1', 'Obshtina Dryanovo', 'BG.41.GAB12', 'ASCII:Obshtina Dryanovo;ID:731880', '6628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6628', '112', '8505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.41.GAB12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8506', '1079', '1', 'Obshtina Dragoman', 'BG.58.SFO16', 'ASCII:Obshtina Dragoman;ID:731960', '6629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6629', '112', '8506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8507', '1079', '1', 'Obshtina Dospat', 'BG.57.SML10', 'ASCII:Obshtina Dospat;ID:732012', '6630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6630', '112', '8507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.57.SML10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8508', '1079', '1', 'Obshtina Dolni Dŭbnik', 'BG.50.PVN11', 'ASCII:Obshtina Dolni Dubnik;ID:732098', '6631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6631', '112', '8508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8509', '1079', '1', 'Obshtina Dolna Mitropoliya', 'BG.50.PVN10', 'ASCII:Obshtina Dolna Mitropoliya;ID:732121', '6632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6632', '112', '8509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8510', '1079', '1', 'Obshtina Dolna Banya', 'BG.58.SFO59', 'ASCII:Obshtina Dolna Banya;ID:732144', '6633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6633', '112', '8510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO59» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8511', '1079', '1', 'Obshtina Dimovo', 'BG.63.VID16', 'ASCII:Obshtina Dimovo;ID:732252', '6634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6634', '112', '8511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8512', '1079', '1', 'Obshtina Dimitrovgrad', 'BG.43.HKV09', 'ASCII:Obshtina Dimitrovgrad;ID:732262', '6635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6635', '112', '8512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8513', '1079', '1', 'Obshtina Devnya', 'BG.61.VAR14', 'ASCII:Obshtina Devnya;ID:732277', '6636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6636', '112', '8513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR14» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8514', '1079', '1', 'Obshtina Devin', 'BG.51.SML09', 'ASCII:Obshtina Devin;ID:732284', '6637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6637', '112', '8514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.SML09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8515', '1079', '1', 'Obshtina Chuprene', 'BG.63.VID37', 'ASCII:Obshtina Chuprene;ID:732399', '6638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6638', '112', '8515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID37» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8516', '1079', '1', 'Obshtina Chirpan', 'BG.59.SZR36', 'ASCII:Obshtina Chirpan;ID:732451', '6639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6639', '112', '8516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR36» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8517', '1079', '1', 'Obshtina Chiprovtsi', 'BG.47.MON36', 'ASCII:Obshtina Chiprovtsi;ID:732455', '6640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6640', '112', '8517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON36» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8518', '1079', '1', 'Obshtina Cherven Bryag', 'BG.50.PVN37', 'ASCII:Obshtina Cherven Bryag;ID:732490', '6641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6641', '112', '8518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN37» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8519', '1079', '1', 'Obshtina Chernoochene', 'BG.44.KRZ35', 'ASCII:Obshtina Chernoochene;ID:732516', '6642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6642', '112', '8519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.44.KRZ35» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8520', '1079', '1', 'Obshtina Chepelare', 'BG.57.SML38', 'ASCII:Obshtina Chepelare;ID:732617', '6643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6643', '112', '8520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.57.SML38» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8521', '1079', '1', 'Obshtina Byala Slatina', 'BG.64.VRC08', 'ASCII:Obshtina Byala Slatina;ID:732703', '6644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6644', '112', '8521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.64.VRC08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8522', '1079', '1', 'Obshtina Byala', 'BG.61.VAR05', 'ASCII:Obshtina Byala;ID:732718', '6645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6645', '112', '8522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8523', '1079', '1', 'Obshtina Byala', 'BG.53.RSE04', 'ASCII:Obshtina Byala;ID:732719', '6646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6646', '112', '8523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.53.RSE04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8524', '1079', '1', 'Obshtina Burgas', 'BG.39.BGS04', 'ASCII:Obshtina Burgas;ID:732769', '6647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6647', '112', '8524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8525', '1079', '1', 'Obshtina Brusartsi', 'BG.47.MON07', 'ASCII:Obshtina Brusartsi;ID:732861', '6648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6648', '112', '8525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8526', '1079', '1', 'Obshtina Brezovo', 'BG.51.PDV07', 'ASCII:Obshtina Brezovo;ID:732871', '6649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6649', '112', '8526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8527', '1079', '1', 'Obshtina Breznik', 'BG.49.PER08', 'ASCII:Obshtina Breznik;ID:732882', '6650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6650', '112', '8527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.49.PER08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8528', '1079', '1', 'Obshtina Bregovo', 'BG.63.VID06', 'ASCII:Obshtina Bregovo;ID:732914', '6651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6651', '112', '8528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8529', '1079', '1', 'Obshtina Bratya Daskalovi', 'BG.59.SZR04', 'ASCII:Obshtina Bratya Daskalovi;ID:732919', '6652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6652', '112', '8529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8530', '1079', '1', 'Obshtina Bratsigovo', 'BG.48.PAZ06', 'ASCII:Obshtina Bratsigovo;ID:732922', '6653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6653', '112', '8530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8531', '1079', '1', 'Obshtina Bozhurishte', 'BG.58.SFO06', 'ASCII:Obshtina Bozhurishte;ID:732953', '6654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6654', '112', '8531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8532', '1079', '1', 'Obshtina Boynitsa', 'BG.63.VID03', 'ASCII:Obshtina Boynitsa;ID:732972', '6655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6655', '112', '8532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8533', '1079', '1', 'Obshtina Boychinovtsi', 'BG.47.MON04', 'ASCII:Obshtina Boychinovtsi;ID:732984', '6656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6656', '112', '8533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8534', '1079', '1', 'Obshtina Botevgrad', 'BG.58.SFO07', 'ASCII:Obshtina Botevgrad;ID:733013', '6657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6657', '112', '8534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8535', '1079', '1', 'Obshtina Borovo', 'BG.53.RSE03', 'ASCII:Obshtina Borovo;ID:733042', '6658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6658', '112', '8535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.53.RSE03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8536', '1079', '1', 'Obshtina Borovan', 'BG.64.VRC05', 'ASCII:Obshtina Borovan;ID:733057', '6659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6659', '112', '8536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.64.VRC05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8537', '1079', '1', 'Obshtina Borino', 'BG.57.SML05', 'ASCII:Obshtina Borino;ID:733066', '6660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6660', '112', '8537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.57.SML05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8538', '1079', '1', 'Obshtina Bolyarovo', 'BG.65.JAM03', 'ASCII:Obshtina Bolyarovo;ID:733090', '6661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6661', '112', '8538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.65.JAM03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8539', '1079', '1', 'Obshtina Bobovdol', 'BG.45.KNL04', 'ASCII:Obshtina Bobovdol;ID:733150', '6662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6662', '112', '8539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.45.KNL04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8540', '1079', '1', 'Obshtina Boboshevo', 'BG.45.KNL05', 'ASCII:Obshtina Boboshevo;ID:733152', '6663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6663', '112', '8540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.45.KNL05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8541', '1079', '1', 'Obshtina Blagoevgrad', 'BG.38.BLG03', 'ASCII:Obshtina Blagoevgrad;ID:733190', '6664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6664', '112', '8541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8542', '1079', '1', 'Obshtina Berkovitsa', 'BG.47.MON02', 'ASCII:Obshtina Berkovitsa;ID:733263', '6665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6665', '112', '8542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.47.MON02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8543', '1079', '1', 'Obshtina Belovo', 'BG.48.PAZ04', 'ASCII:Obshtina Belovo;ID:733285', '6666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6666', '112', '8543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8544', '1079', '1', 'Obshtina Beloslav', 'BG.61.VAR04', 'ASCII:Obshtina Beloslav;ID:733292', '6667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6667', '112', '8544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8545', '1079', '1', 'Obshtina Belogradchik', 'BG.63.VID01', 'ASCII:Obshtina Belogradchik;ID:733308', '6668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6668', '112', '8545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.63.VID01» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8546', '1079', '1', 'Obshtina Belitsa', 'BG.38.BLG02', 'ASCII:Obshtina Belitsa;ID:733315', '6669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6669', '112', '8546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8547', '1079', '1', 'Obshtina Belene', 'BG.50.PVN03', 'ASCII:Obshtina Belene;ID:733358', '6670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6670', '112', '8547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.50.PVN03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8548', '1079', '1', 'Obshtina Batak', 'BG.48.PAZ03', 'ASCII:Obshtina Batak;ID:733431', '6671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6671', '112', '8548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.48.PAZ03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8549', '1079', '1', 'Obshtina Bansko', 'BG.38.BLG01', 'ASCII:Obshtina Bansko;ID:733461', '6672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6672', '112', '8549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.38.BLG01» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8550', '1079', '1', 'Obshtina Banite', 'BG.57.SML02', 'ASCII:Obshtina Banite;ID:733473', '6673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6673', '112', '8550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.57.SML02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8551', '1079', '1', 'Obshtina Balchik', 'BG.40.DOB03', 'ASCII:Obshtina Balchik;ID:733513', '6674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6674', '112', '8551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.40.DOB03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8552', '1079', '1', 'Obshtina Aytos', 'BG.39.BGS01', 'ASCII:Obshtina Aytos;ID:733578', '6675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6675', '112', '8552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS01» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8553', '1079', '1', 'Obshtina Avren', 'BG.61.VAR01', 'ASCII:Obshtina Avren;ID:733585', '6676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6676', '112', '8553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR01» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8554', '1079', '1', 'Obshtina Asenovgrad', 'BG.51.PDV01', 'ASCII:Obshtina Asenovgrad;ID:733617', '6677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6677', '112', '8554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV01» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8555', '1079', '1', 'Obshtina Ardino', 'BG.44.KRZ02', 'ASCII:Obshtina Ardino;ID:733637', '6678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6678', '112', '8555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.44.KRZ02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8556', '1079', '1', 'Obshtina Apriltsi', 'BG.46.LOV02', 'ASCII:Obshtina Apriltsi;ID:733648', '6679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6679', '112', '8556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.46.LOV02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8557', '1079', '1', 'Obshtina Antonovo', 'BG.60.TGV02', 'ASCII:Obshtina Antonovo;ID:733656', '6680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6680', '112', '8557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.60.TGV02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8558', '1079', '1', 'Obshtina Alfatar', 'BG.55.SLS01', 'ASCII:Obshtina Alfatar;ID:733678', '6681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6681', '112', '8558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.55.SLS01» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8559', '1079', '1', 'Obshtina Aksakovo', 'BG.61.VAR02', 'ASCII:Obshtina Aksakovo;ID:733715', '6682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6682', '112', '8559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.61.VAR02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8560', '1079', '1', 'Obshtina Primorsko', 'BG.39.BGS27', 'ASCII:Obshtina Primorsko;ID:864564', '6683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6683', '112', '8560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.39.BGS27» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8561', '1079', '1', 'Obshtina Dobrich-Selska', 'BG.40.DOB15', 'ASCII:Obshtina Dobrich-Selska;ID:864565', '6684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6684', '112', '8561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.40.DOB15» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8562', '1079', '1', 'Obshtina Khayredin', 'BG.64.VRC35', 'ASCII:Obshtina Khayredin;ID:864566', '6685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6685', '112', '8562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.64.VRC35» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8563', '1079', '1', 'Obshtina Rodopi', 'BG.51.PDV26', 'ASCII:Obshtina Rodopi;ID:864567', '6686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6686', '112', '8563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV26» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8564', '1079', '1', 'Obshtina Perushtitsa', 'BG.51.PDV40', 'ASCII:Obshtina Perushtitsa;ID:864568', '6687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6687', '112', '8564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV40» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8565', '1079', '1', 'Obshtina Krichim', 'BG.51.PDV39', 'ASCII:Obshtina Krichim;ID:864569', '6688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6688', '112', '8565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV39» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8566', '1079', '1', 'Obshtina Stamboliyski', 'BG.51.PDV41', 'ASCII:Obshtina Stamboliyski;ID:864570', '6689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6689', '112', '8566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV41» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8567', '1079', '1', 'Obshtina Maritsa', 'BG.51.PDV17', 'ASCII:Obshtina Maritsa;ID:864571', '6690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6690', '112', '8567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV17» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8568', '1079', '1', 'Obshtina Mirkovo', 'BG.58.SFO56', 'ASCII:Obshtina Mirkovo;ID:864572', '6691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6691', '112', '8568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO56» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8569', '1079', '1', 'Obshtina Chavdar', 'BG.58.SFO57', 'ASCII:Obshtina Chavdar;ID:864573', '6692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6692', '112', '8569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO57» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8570', '1079', '1', 'Obshtina Chelopech', 'BG.58.SFO58', 'ASCII:Obshtina Chelopech;ID:864574', '6693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6693', '112', '8570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO58» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8571', '1079', '1', 'Obshtina Pirdop', 'BG.58.SFO55', 'ASCII:Obshtina Pirdop;ID:864575', '6694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6694', '112', '8571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO55» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8572', '1079', '1', 'Obshtina Anton', 'BG.58.SFO54', 'ASCII:Obshtina Anton;ID:864576', '6695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6695', '112', '8572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO54» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8573', '1079', '1', 'Obshtina Pravets', 'BG.58.SFO34', 'ASCII:Obshtina Pravets;ID:864577', '6696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6696', '112', '8573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.58.SFO34» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8574', '1079', '1', 'Obshtina Nikolaevo', 'BG.59.SZR38', 'ASCII:Obshtina Nikolaevo;ID:864599', '6697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6697', '112', '8574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.59.SZR38» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8575', '1079', '1', 'Obshtina Madzharovo', 'BG.43.HKV18', 'ASCII:Obshtina Madzharovo;ID:864600', '6698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6698', '112', '8575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.43.HKV18» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8576', '1079', '1', 'Obshtina Tundzha', 'BG.65.JAM25', 'ASCII:Obshtina Tundzha;ID:864601', '6699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6699', '112', '8576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.65.JAM25» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8577', '1079', '1', 'Sopot', 'BG.51.PDV43', 'ASCII:Sopot;ID:6458935', '6700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6700', '112', '8577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV43» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8578', '1079', '1', 'Kuklen', 'BG.51.PDV42', 'ASCII:Kuklen;ID:6458938', '6701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6701', '112', '8578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.51.PDV42» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8579', '1079', '1', 'Stolichna Obshtina', 'BG.42.SOF46', 'ASCII:Municipality of the Capital;ID:6458974', '6702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6702', '112', '8579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BG.42.SOF46» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8580', '1079', '1', 'Provincia Chiquitos', 'BO.08.0705', 'ASCII:Provincia Chiquitos;ID:3444670', '6703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6703', '112', '8580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8581', '1079', '1', 'Provincia Ángel Sandoval', 'BO.08.0712', 'ASCII:Provincia Angel Sandoval;ID:3444765', '6704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6704', '112', '8581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8582', '1079', '1', 'Provincia Zudáñez', 'BO.01.0103', 'ASCII:Provincia Zudanez;ID:3900772', '6705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6705', '112', '8582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.01.0103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8583', '1079', '1', 'Provincia Yamparáez', 'BO.01.0106', 'ASCII:Provincia Yamparaez;ID:3901146', '6706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6706', '112', '8583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.01.0106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8584', '1079', '1', 'Provincia Yacuma', 'BO.03.0804', 'ASCII:Provincia Yacuma;ID:3901175', '6707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6707', '112', '8584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.03.0804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8585', '1079', '1', 'Provincia Warnes', 'BO.08.0702', 'ASCII:Provincia Warnes;ID:3901298', '6708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6708', '112', '8585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8586', '1079', '1', 'Provincia Velasco', 'BO.08.0703', 'ASCII:Provincia Velasco;ID:3901825', '6709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6709', '112', '8586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8587', '1079', '1', 'Provincia Vallegrande', 'BO.08.0708', 'ASCII:Provincia Vallegrande;ID:3901872', '6710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6710', '112', '8587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8588', '1079', '1', 'Provincia Vaca Diez', 'BO.03.0802', 'ASCII:Provincia Vaca Diez;ID:3901896', '6711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6711', '112', '8588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.03.0802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8589', '1079', '1', 'Provincia Tomina', 'BO.01.0104', 'ASCII:Provincia Tomina;ID:3902667', '6712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6712', '112', '8589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.01.0104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8590', '1079', '1', 'Provincia Tomás Frías', 'BO.07.0501', 'ASCII:Provincia Tomas Frias;ID:3902683', '6713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6713', '112', '8590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8591', '1079', '1', 'Provincia Tomás Barron', 'BO.05.0411', 'ASCII:Provincia Tomas Barron;ID:3902684', '6714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6714', '112', '8591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.0411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8592', '1079', '1', 'Provincia Tapacarí', 'BO.02.0311', 'ASCII:Provincia Tapacari;ID:3903462', '6715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6715', '112', '8592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8593', '1079', '1', 'Provincia Sur Carangas', 'BO.05.3903880', 'ASCII:Provincia Sur Carangas;ID:3903880', '6716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6716', '112', '8593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.3903880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8594', '1079', '1', 'Provincia Sud Yungas', 'BO.04.0211', 'ASCII:Provincia Sud Yungas;ID:3903975', '6717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6717', '112', '8594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8595', '1079', '1', 'Provincia Sud Lípez', 'BO.07.0510', 'ASCII:Provincia Sud Lipez;ID:3903976', '6718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6718', '112', '8595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8596', '1079', '1', 'Provincia Sud Cinti', 'BO.01.0109', 'ASCII:Provincia Sud Cinti;ID:3903977', '6719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6719', '112', '8596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.01.0109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8597', '1079', '1', 'Provincia Sud Chichas', 'BO.07.0508', 'ASCII:Provincia Sud Chichas;ID:3903978', '6720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6720', '112', '8597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8598', '1079', '1', 'Provincia Saucari', 'BO.05.0410', 'ASCII:Provincia Saucari;ID:3904553', '6721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6721', '112', '8598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.0410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8599', '1079', '1', 'Provincia Sara', 'BO.08.0706', 'ASCII:Provincia Sara;ID:3904588', '6722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6722', '112', '8599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8600', '1079', '1', 'Provincia Santiesteban', 'BO.08.3904660', 'ASCII:Provincia Santiesteban;ID:3904660', '6723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6723', '112', '8600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.3904660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8601', '1079', '1', 'Provincia San Pedro de Totora', 'BO.05.0413', 'ASCII:Provincia San Pedro de Totora;ID:3905117', '6724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6724', '112', '8601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.0413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8602', '1079', '1', 'Provincia Sajama', 'BO.05.0404', 'ASCII:Provincia Sajama;ID:3906107', '6725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6725', '112', '8602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.0404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8603', '1079', '1', 'Provincia Saavedra', 'BO.07.0503', 'ASCII:Provincia Saavedra;ID:3906205', '6726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6726', '112', '8603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8604', '1079', '1', 'Provincia Rafael Bustillos', 'BO.07.0502', 'ASCII:Provincia Rafael Bustillos;ID:3906628', '6727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6727', '112', '8604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8605', '1079', '1', 'Provincia Quillacollo', 'BO.02.0309', 'ASCII:Provincia Quillacollo;ID:3906790', '6728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6728', '112', '8605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8606', '1079', '1', 'Provincia Quijarro', 'BO.07.0512', 'ASCII:Provincia Quijarro;ID:3906809', '6729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6729', '112', '8606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8607', '1079', '1', 'Provincia Punata', 'BO.02.0314', 'ASCII:Provincia Punata;ID:3907079', '6730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6730', '112', '8607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8608', '1079', '1', 'Provincia Poopó', 'BO.05.0406', 'ASCII:Provincia Poopo;ID:3907682', '6731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6731', '112', '8608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.0406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8609', '1079', '1', 'Provincia Pantaleón Dalence', 'BO.05.0407', 'ASCII:Provincia Pantaleon Dalence;ID:3908591', '6732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6732', '112', '8609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.0407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8610', '1079', '1', 'Provincia Pacajes', 'BO.04.0203', 'ASCII:Provincia Pacajes;ID:3909144', '6733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6733', '112', '8610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8611', '1079', '1', 'Provincia Oropeza', 'BO.01.0101', 'ASCII:Provincia Oropeza;ID:3909247', '6734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6734', '112', '8611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.01.0101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8612', '1079', '1', 'Provincia Omasuyos', 'BO.04.0202', 'ASCII:Provincia Omasuyos;ID:3909341', '6735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6735', '112', '8612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8613', '1079', '1', 'Provincia O''Connor', 'BO.09.0606', 'ASCII:Provincia O''Connor;ID:3909412', '6736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6736', '112', '8613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.09.0606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8614', '1079', '1', 'Provincia Ñuflo de Chávez', 'BO.08.0711', 'ASCII:Provincia Nuflo de Chavez;ID:3909446', '6737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6737', '112', '8614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8615', '1079', '1', 'Provincia Nor Yungas', 'BO.04.0214', 'ASCII:Provincia Nor Yungas;ID:3909486', '6738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6738', '112', '8615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8616', '1079', '1', 'Provincia Nor Lípez', 'BO.07.0509', 'ASCII:Provincia Nor Lipez;ID:3909491', '6739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6739', '112', '8616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8617', '1079', '1', 'Provincia Nor Cinti', 'BO.01.0107', 'ASCII:Provincia Nor Cinti;ID:3909495', '6740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6740', '112', '8617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.01.0107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8618', '1079', '1', 'Provincia Nor Chichas', 'BO.07.0506', 'ASCII:Provincia Nor Chichas;ID:3909496', '6741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6741', '112', '8618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8619', '1079', '1', 'Provincia Nicolás Suárez', 'BO.06.0901', 'ASCII:Provincia Nicolas Suarez;ID:3909533', '6742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6742', '112', '8619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.06.0901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8620', '1079', '1', 'Provincia Murillo', 'BO.04.0201', 'ASCII:Provincia Murillo;ID:3909793', '6743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6743', '112', '8620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8621', '1079', '1', 'Provincia Muñecas', 'BO.04.0205', 'ASCII:Provincia Munecas;ID:3909808', '6744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6744', '112', '8621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8622', '1079', '1', 'Provincia Moxos', 'BO.03.0805', 'ASCII:Provincia Moxos;ID:3909868', '6745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6745', '112', '8622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.03.0805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8623', '1079', '1', 'Provincia Modesto Omiste', 'BO.07.0515', 'ASCII:Provincia Modesto Omiste;ID:3910260', '6746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6746', '112', '8623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8624', '1079', '1', 'Provincia Mizque', 'BO.02.0313', 'ASCII:Provincia Mizque;ID:3910289', '6747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6747', '112', '8624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8625', '1079', '1', 'Provincia Méndez', 'BO.09.0605', 'ASCII:Provincia Mendez;ID:3910499', '6748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6748', '112', '8625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.09.0605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8626', '1079', '1', 'Provincia Marbán', 'BO.03.0806', 'ASCII:Provincia Marban;ID:3910725', '6749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6749', '112', '8626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.03.0806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8627', '1079', '1', 'Provincia Manuripi', 'BO.06.0902', 'ASCII:Provincia Manuripi;ID:3910770', '6750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6750', '112', '8627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.06.0902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8628', '1079', '1', 'Provincia Manuel María Caballero', 'BO.08.0713', 'ASCII:Provincia Manuel Maria Caballero;ID:3910776', '6751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6751', '112', '8628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8629', '1079', '1', 'Provincia Manco Kapac', 'BO.04.0217', 'ASCII:Provincia Manco Kapac;ID:3910806', '6752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6752', '112', '8629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8630', '1079', '1', 'Provincia Mamoré', 'BO.03.0807', 'ASCII:Provincia Mamore;ID:3910823', '6753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6753', '112', '8630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.03.0807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8631', '1079', '1', 'Provincia Madre de Dios', 'BO.06.0903', 'ASCII:Provincia Madre de Dios;ID:3910923', '6754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6754', '112', '8631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.06.0903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8632', '1079', '1', 'Provincia Luis Calvo', 'BO.01.0110', 'ASCII:Provincia Luis Calvo;ID:3911048', '6755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6755', '112', '8632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.01.0110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8633', '1079', '1', 'Provincia Los Andes', 'BO.04.0212', 'ASCII:Provincia Los Andes;ID:3911185', '6756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6756', '112', '8633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8634', '1079', '1', 'Provincia Loayza', 'BO.04.0209', 'ASCII:Provincia Loayza;ID:3911271', '6757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6757', '112', '8634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8635', '1079', '1', 'Provincia Litoral', 'BO.05.0405', 'ASCII:Provincia Litoral;ID:3911447', '6758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6758', '112', '8635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.0405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8636', '1079', '1', 'Provincia Linares', 'BO.07.3911502', 'ASCII:Provincia Linares;ID:3911502', '6759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6759', '112', '8636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.3911502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8637', '1079', '1', 'Provincia Larecaja', 'BO.04.0206', 'ASCII:Provincia Larecaja;ID:3911853', '6760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6760', '112', '8637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8638', '1079', '1', 'Provincia Ladislao Cabrera', 'BO.05.0408', 'ASCII:Provincia Ladislao Cabrera;ID:3912280', '6761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6761', '112', '8638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.0408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8639', '1079', '1', 'Provincia Iturralde', 'BO.04.0215', 'ASCII:Provincia Iturralde;ID:3913873', '6762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6762', '112', '8639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8640', '1079', '1', 'Provincia Iténez', 'BO.03.0808', 'ASCII:Provincia Itenez;ID:3913898', '6763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6763', '112', '8640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.03.0808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8641', '1079', '1', 'Provincia Inquisivi', 'BO.04.0210', 'ASCII:Provincia Inquisivi;ID:3914147', '6764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6764', '112', '8641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8642', '1079', '1', 'Provincia Ingavi', 'BO.04.0208', 'ASCII:Provincia Ingavi;ID:3914178', '6765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6765', '112', '8642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8643', '1079', '1', 'Provincia Ichilo', 'BO.08.0704', 'ASCII:Provincia Ichilo;ID:3914360', '6766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6766', '112', '8643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8644', '1079', '1', 'Provincia Hernando Siles', 'BO.01.0105', 'ASCII:Provincia Hernando Siles;ID:3915235', '6767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6767', '112', '8644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.01.0105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8645', '1079', '1', 'Provincia Gualberto Villarroel', 'BO.04.0218', 'ASCII:Provincia Gualberto Villarroel;ID:3915457', '6768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6768', '112', '8645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8646', '1079', '1', 'Provincia Gran Chaco', 'BO.09.0603', 'ASCII:Provincia Gran Chaco;ID:3915555', '6769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6769', '112', '8646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.09.0603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8647', '1079', '1', 'Provincia Germán Jordán', 'BO.02.0308', 'ASCII:Provincia German Jordan;ID:3915586', '6770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6770', '112', '8647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8648', '1079', '1', 'Provincia General José Ballivián', 'BO.03.3915596', 'ASCII:Provincia General Jose Ballivian;ID:3915596', '6771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6771', '112', '8648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.03.3915596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8649', '1079', '1', 'Provincia General Federico Román', 'BO.06.3915598', 'ASCII:Provincia General Federico Roman;ID:3915598', '6772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6772', '112', '8649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.06.3915598» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8650', '1079', '1', 'Provincia General Bilbao', 'BO.07.3915603', 'ASCII:Provincia General Bilbao;ID:3915603', '6773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6773', '112', '8650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.3915603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8651', '1079', '1', 'Provincia Franz Tamayo', 'BO.04.0207', 'ASCII:Provincia Franz Tamayo;ID:3915684', '6774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6774', '112', '8651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8652', '1079', '1', 'Provincia Florida', 'BO.08.0709', 'ASCII:Provincia Florida;ID:3915714', '6775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6775', '112', '8652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8653', '1079', '1', 'Provincia Esteban Arce', 'BO.02.0304', 'ASCII:Provincia Esteban Arce;ID:3915859', '6776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6776', '112', '8653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8654', '1079', '1', 'Provincia Daniel Campos', 'BO.07.0514', 'ASCII:Provincia Daniel Campos;ID:3918497', '6777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6777', '112', '8654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8655', '1079', '1', 'Provincia Cordillera', 'BO.08.0707', 'ASCII:Provincia Cordillera;ID:3919115', '6778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6778', '112', '8655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8656', '1079', '1', 'Provincia Chayanta', 'BO.07.0504', 'ASCII:Provincia Chayanta;ID:3921027', '6779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6779', '112', '8656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8657', '1079', '1', 'Provincia Charcas', 'BO.07.0505', 'ASCII:Provincia Charcas;ID:3921114', '6780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6780', '112', '8657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8658', '1079', '1', 'Provincia Chaparé', 'BO.02.0310', 'ASCII:Provincia Chapare;ID:3921215', '6781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6781', '112', '8658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8659', '1079', '1', 'Provincia Cercado', 'BO.09.0601', 'ASCII:Provincia Cercado;ID:3921628', '6782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6782', '112', '8659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.09.0601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8660', '1079', '1', 'Provincia Cercado', 'BO.05.0401', 'ASCII:Provincia Cercado;ID:3921629', '6783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6783', '112', '8660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.0401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8661', '1079', '1', 'Provincia Cercado', 'BO.02.0301', 'ASCII:Provincia Cercado;ID:3921630', '6784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6784', '112', '8661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8662', '1079', '1', 'Provincia Cercado', 'BO.03.0801', 'ASCII:Provincia Cercado;ID:3921631', '6785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6785', '112', '8662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.03.0801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8663', '1079', '1', 'Provincia Carrasco', 'BO.02.0312', 'ASCII:Provincia Carrasco;ID:3921892', '6786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6786', '112', '8663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8664', '1079', '1', 'Provincia Carangas', 'BO.05.3922026', 'ASCII:Provincia Carangas;ID:3922026', '6787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6787', '112', '8664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.3922026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8665', '1079', '1', 'Provincia Capinota', 'BO.02.0307', 'ASCII:Provincia Capinota;ID:3922124', '6788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6788', '112', '8665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8666', '1079', '1', 'Provincia Campero', 'BO.02.0302', 'ASCII:Provincia Campero;ID:3922371', '6789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6789', '112', '8666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8667', '1079', '1', 'Provincia Camacho', 'BO.04.0204', 'ASCII:Provincia Camacho;ID:3922460', '6790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6790', '112', '8667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8668', '1079', '1', 'Provincia Belisario Boeto', 'BO.01.0108', 'ASCII:Provincia Belisario Boeto;ID:3923228', '6791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6791', '112', '8668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.01.0108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8669', '1079', '1', 'Provincia Bautista Saavedra', 'BO.04.0216', 'ASCII:Provincia Bautista Saavedra;ID:3923271', '6792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6792', '112', '8669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8670', '1079', '1', 'Provincia Azurduy', 'BO.01.0102', 'ASCII:Provincia Azurduy;ID:3923437', '6793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6793', '112', '8670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.01.0102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8671', '1079', '1', 'Provincia Ayopaya', 'BO.02.0303', 'ASCII:Provincia Ayopaya;ID:3923480', '6794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6794', '112', '8671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8672', '1079', '1', 'Provincia Avilez', 'BO.09.0604', 'ASCII:Provincia Avilez;ID:3923512', '6795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6795', '112', '8672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.09.0604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8673', '1079', '1', 'Provincia Avaroa', 'BO.05.0402', 'ASCII:Provincia Avaroa;ID:3923523', '6796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6796', '112', '8673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.0402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8674', '1079', '1', 'Provincia Atahuallpa', 'BO.05.3923586', 'ASCII:Provincia Atahuallpa;ID:3923586', '6797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6797', '112', '8674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.05.3923586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8675', '1079', '1', 'Provincia Arque', 'BO.02.0306', 'ASCII:Provincia Arque;ID:3923681', '6798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6798', '112', '8675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8676', '1079', '1', 'Provincia Aroma', 'BO.04.0213', 'ASCII:Provincia Aroma;ID:3923690', '6799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6799', '112', '8676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.04.0213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8677', '1079', '1', 'Provincia Arce', 'BO.09.0602', 'ASCII:Provincia Arce;ID:3923749', '6800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6800', '112', '8677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.09.0602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8678', '1079', '1', 'Provincia Arani', 'BO.02.0305', 'ASCII:Provincia Arani;ID:3923769', '6801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6801', '112', '8678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.02.0305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8679', '1079', '1', 'Provincia Andrés Ibáñez', 'BO.08.0701', 'ASCII:Provincia Andres Ibanez;ID:3923972', '6802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6802', '112', '8679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.08.0701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8680', '1079', '1', 'Provincia Alonzo de Ibáñez', 'BO.07.0507', 'ASCII:Provincia Alonzo de Ibanez;ID:3924205', '6803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6803', '112', '8680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.07.0507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8681', '1079', '1', 'Provincia Abuná', 'BO.06.0904', 'ASCII:Provincia Abuna;ID:3924631', '6804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6804', '112', '8681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BO.06.0904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8682', '1079', '1', 'Viçosa do Ceará', 'BR.06.2314102', 'ASCII:Vicosa Do Ceara;ID:3385105', '6805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6805', '112', '8682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2314102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8683', '1079', '1', 'Várzea Alegre', 'BR.06.2314003', 'ASCII:Varzea Alegre;ID:3385462', '6806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6806', '112', '8683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2314003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8684', '1079', '1', 'Umari', 'BR.06.2313708', 'ASCII:Umari;ID:3385832', '6807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6807', '112', '8684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8685', '1079', '1', 'Ubajara', 'BR.06.2313609', 'ASCII:Ubajara;ID:3385872', '6808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6808', '112', '8685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8686', '1079', '1', 'Tutóia', 'BR.13.2112506', 'ASCII:Tutoia;ID:3385897', '6809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6809', '112', '8686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8687', '1079', '1', 'Traipu', 'BR.02.2709202', 'ASCII:Traipu;ID:3386197', '6810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6810', '112', '8687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2709202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8688', '1079', '1', 'Timbaúba', 'BR.30.2615300', 'ASCII:Timbauba;ID:3386391', '6811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6811', '112', '8688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2615300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8689', '1079', '1', 'Tianguá', 'BR.06.2313401', 'ASCII:Tiangua;ID:3386448', '6812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6812', '112', '8689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8690', '1079', '1', 'Tauá', 'BR.06.2313302', 'ASCII:Taua;ID:3386566', '6813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6813', '112', '8690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8691', '1079', '1', 'Tamboril', 'BR.06.2313203', 'ASCII:Tamboril;ID:3386859', '6814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6814', '112', '8691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8692', '1079', '1', 'Solonópole', 'BR.06.2313005', 'ASCII:Solonopole;ID:3387241', '6815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6815', '112', '8692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8693', '1079', '1', 'Sobral', 'BR.06.2312908', 'ASCII:Sobral;ID:3387295', '6816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6816', '112', '8693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2312908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8694', '1079', '1', 'Senador Pompeu', 'BR.06.2312700', 'ASCII:Senador Pompeu;ID:3387925', '6817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6817', '112', '8694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2312700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8695', '1079', '1', 'São Benedito', 'BR.06.2312304', 'ASCII:Sao Benedito;ID:3389015', '6818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6818', '112', '8695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2312304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8696', '1079', '1', 'Santa Quitéria', 'BR.06.2312205', 'ASCII:Santa Quiteria;ID:3389359', '6819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6819', '112', '8696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2312205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8697', '1079', '1', 'Santana do Ipanema', 'BR.02.2708006', 'ASCII:Santana Do Ipanema;ID:3389383', '6820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6820', '112', '8697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8698', '1079', '1', 'Santana do Cariri', 'BR.06.2312106', 'ASCII:Santana Do Cariri;ID:3389385', '6821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6821', '112', '8698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2312106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8699', '1079', '1', 'Saboeiro', 'BR.06.2311900', 'ASCII:Saboeiro;ID:3390136', '6822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6822', '112', '8699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8700', '1079', '1', 'Russas', 'BR.06.2311801', 'ASCII:Russas;ID:3390158', '6823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6823', '112', '8700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8701', '1079', '1', 'Reriutaba', 'BR.06.2311702', 'ASCII:Reriutaba;ID:3390658', '6824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6824', '112', '8701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8702', '1079', '1', 'Quixeramobim', 'BR.06.2311405', 'ASCII:Quixeramobim;ID:3390898', '6825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6825', '112', '8702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8703', '1079', '1', 'Quixadá', 'BR.06.2311306', 'ASCII:Quixada;ID:3390906', '6826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6826', '112', '8703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8704', '1079', '1', 'Porto da Folha', 'BR.28.2805604', 'ASCII:Porto Da Folha;ID:3391393', '6827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6827', '112', '8704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2805604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8705', '1079', '1', 'Porteiras', 'BR.06.2311108', 'ASCII:Porteiras;ID:3391418', '6828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6828', '112', '8705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8706', '1079', '1', 'Poço Redondo', 'BR.28.2805406', 'ASCII:Poco Redondo;ID:3391608', '6829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6829', '112', '8706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2805406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8707', '1079', '1', 'Piranhas', 'BR.02.2707107', 'ASCII:Piranhas;ID:3391957', '6830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6830', '112', '8707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2707107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8708', '1079', '1', 'Pereiro', 'BR.06.2310803', 'ASCII:Pereiro;ID:3392307', '6831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6831', '112', '8708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8709', '1079', '1', 'Pentecoste', 'BR.06.2310704', 'ASCII:Pentecoste;ID:3392343', '6832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6832', '112', '8709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8710', '1079', '1', 'Pedra Branca', 'BR.06.2310506', 'ASCII:Pedra Branca;ID:3392608', '6833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6833', '112', '8710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8711', '1079', '1', 'Parambu', 'BR.06.2310308', 'ASCII:Parambu;ID:3393064', '6834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6834', '112', '8711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8712', '1079', '1', 'Pão de Açúcar', 'BR.02.2706406', 'ASCII:Pao De Acucar;ID:3393171', '6835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6835', '112', '8712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8713', '1079', '1', 'Palmeira dos Índios', 'BR.02.2706307', 'ASCII:Palmeira Dos Indios;ID:3393241', '6836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6836', '112', '8713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8714', '1079', '1', 'Pacoti', 'BR.06.2309805', 'ASCII:Pacoti;ID:3393385', '6837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6837', '112', '8714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8715', '1079', '1', 'Pacatuba', 'BR.06.2309706', 'ASCII:Pacatuba;ID:3393398', '6838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6838', '112', '8715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8716', '1079', '1', 'Olho d''Água das Flores', 'BR.02.2705705', 'ASCII:Olho D''Agua Das Flores;ID:3393598', '6839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6839', '112', '8716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2705705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8717', '1079', '1', 'Nova Russas', 'BR.06.2309300', 'ASCII:Nova Russas;ID:3393831', '6840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6840', '112', '8717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8718', '1079', '1', 'Neópolis', 'BR.28.2804409', 'ASCII:Neopolis;ID:3393936', '6841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6841', '112', '8718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8719', '1079', '1', 'Mucambo', 'BR.06.2309003', 'ASCII:Mucambo;ID:3394313', '6842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6842', '112', '8719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8720', '1079', '1', 'Monteiro', 'BR.17.2509701', 'ASCII:Monteiro;ID:3394547', '6843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6843', '112', '8720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8721', '1079', '1', 'Monsenhor Tabosa', 'BR.06.2308609', 'ASCII:Monsenhor Tabosa;ID:3394617', '6844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6844', '112', '8721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8722', '1079', '1', 'Mombaça', 'BR.06.2308500', 'ASCII:Mombaca;ID:3394644', '6845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6845', '112', '8722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8723', '1079', '1', 'Missão Velha', 'BR.06.2308401', 'ASCII:Missao Velha;ID:3394754', '6846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6846', '112', '8723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8724', '1079', '1', 'Milagres', 'BR.06.2308302', 'ASCII:Milagres;ID:3394883', '6847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6847', '112', '8724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8725', '1079', '1', 'Meruoca', 'BR.06.2308203', 'ASCII:Meruoca;ID:3394916', '6848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6848', '112', '8725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8726', '1079', '1', 'Mauriti', 'BR.06.2308104', 'ASCII:Mauriti;ID:3395057', '6849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6849', '112', '8726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8727', '1079', '1', 'Mata Grande', 'BR.02.2705002', 'ASCII:Mata Grande;ID:3395161', '6850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6850', '112', '8727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2705002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8728', '1079', '1', 'Massapê', 'BR.06.2308005', 'ASCII:Massape;ID:3395225', '6851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6851', '112', '8728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8729', '1079', '1', 'Maranguape', 'BR.06.2307700', 'ASCII:Maranguape;ID:3395448', '6852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6852', '112', '8729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8730', '1079', '1', 'Major Isidoro', 'BR.02.2704401', 'ASCII:Major Isidoro;ID:3395879', '6853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6853', '112', '8730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2704401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8731', '1079', '1', 'Limoeiro do Norte', 'BR.06.2307601', 'ASCII:Limoeiro Do Norte;ID:3396265', '6854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6854', '112', '8731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8732', '1079', '1', 'Limoeiro de Anadia', 'BR.02.2704203', 'ASCII:Limoeiro De Anadia;ID:3396269', '6855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6855', '112', '8732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2704203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8733', '1079', '1', 'Lavras da Mangabeira', 'BR.06.2307502', 'ASCII:Lavras Da Mangabeira;ID:3396363', '6856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6856', '112', '8733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8734', '1079', '1', 'Junqueiro', 'BR.02.2704005', 'ASCII:Junqueiro;ID:3397062', '6857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6857', '112', '8734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2704005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8735', '1079', '1', 'Jucás', 'BR.06.2307403', 'ASCII:Jucas;ID:3397117', '6858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6858', '112', '8735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8736', '1079', '1', 'Juazeiro do Norte', 'BR.06.2307304', 'ASCII:Juazeiro Do Norte;ID:3397146', '6859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6859', '112', '8736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8737', '1079', '1', 'Jati', 'BR.06.2307205', 'ASCII:Jati;ID:3397543', '6860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6860', '112', '8737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8738', '1079', '1', 'Jardim', 'BR.06.2307106', 'ASCII:Jardim;ID:3397572', '6861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6861', '112', '8738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8739', '1079', '1', 'Jaguaruana', 'BR.06.2307007', 'ASCII:Jaguaruana;ID:3397664', '6862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6862', '112', '8739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8740', '1079', '1', 'Jaguaribe', 'BR.06.2306900', 'ASCII:Jaguaribe;ID:3397670', '6863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6863', '112', '8740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8741', '1079', '1', 'Jaguaretama', 'BR.06.2306702', 'ASCII:Jaguaretama;ID:3397679', '6864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6864', '112', '8741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8742', '1079', '1', 'Itatira', 'BR.06.2306603', 'ASCII:Itatira;ID:3397876', '6865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6865', '112', '8742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8743', '1079', '1', 'Itapagé', 'BR.06.2306306', 'ASCII:Itapage;ID:3397946', '6866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6866', '112', '8743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8744', '1079', '1', 'Itaituba', 'BR.16.1503606', 'ASCII:Itaituba;ID:3397966', '6867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6867', '112', '8744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8745', '1079', '1', 'Itaiçaba', 'BR.06.2306207', 'ASCII:Itaicaba;ID:3397981', '6868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6868', '112', '8745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8746', '1079', '1', 'Iracema', 'BR.06.2306009', 'ASCII:Iracema;ID:3398051', '6869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6869', '112', '8746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8747', '1079', '1', 'Ipueiras', 'BR.06.2305902', 'ASCII:Ipueiras;ID:3398072', '6870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6870', '112', '8747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8748', '1079', '1', 'Ipu', 'BR.06.2305803', 'ASCII:Ipu;ID:3398110', '6871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6871', '112', '8748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8749', '1079', '1', 'Ipaumirim', 'BR.06.2305704', 'ASCII:Ipaumirim;ID:3398142', '6872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6872', '112', '8749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8750', '1079', '1', 'Independência', 'BR.06.2305605', 'ASCII:Independencia;ID:3398253', '6873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6873', '112', '8750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8751', '1079', '1', 'Iguatu', 'BR.06.2305506', 'ASCII:Iguatu;ID:3398329', '6874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6874', '112', '8751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8752', '1079', '1', 'Icó', 'BR.06.2305407', 'ASCII:Ico;ID:3398375', '6875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6875', '112', '8752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8753', '1079', '1', 'Ibiapina', 'BR.06.2305308', 'ASCII:Ibiapina;ID:3398407', '6876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6876', '112', '8753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8754', '1079', '1', 'Guaraí', 'BR.31.1709302', 'ASCII:Guarai;ID:3398566', '6877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6877', '112', '8754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1709302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8755', '1079', '1', 'Guaraciaba do Norte', 'BR.06.2305001', 'ASCII:Guaraciaba Do Norte;ID:3398568', '6878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6878', '112', '8755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8756', '1079', '1', 'Frecheirinha', 'BR.06.2304509', 'ASCII:Frecheirinha;ID:3399312', '6879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6879', '112', '8756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8757', '1079', '1', 'Fernando de Noronha', 'BR.30.2605459', 'ASCII:Fernando De Noronha;ID:3399637', '6880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6880', '112', '8757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8758', '1079', '1', 'Feira Grande', 'BR.02.2702603', 'ASCII:Feira Grande;ID:3399683', '6881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6881', '112', '8758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8759', '1079', '1', 'Farias Brito', 'BR.06.2304301', 'ASCII:Farias Brito;ID:3400496', '6882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6882', '112', '8759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8760', '1079', '1', 'Delmiro Gouveia', 'BR.02.2702405', 'ASCII:Delmiro Gouveia;ID:3401108', '6883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6883', '112', '8760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8761', '1079', '1', 'Crato', 'BR.06.2304202', 'ASCII:Crato;ID:3401544', '6884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6884', '112', '8761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8762', '1079', '1', 'Crateús', 'BR.06.2304103', 'ASCII:Crateus;ID:3401547', '6885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6885', '112', '8762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8763', '1079', '1', 'Coreaú', 'BR.06.2304004', 'ASCII:Coreau;ID:3401728', '6886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6886', '112', '8763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8764', '1079', '1', 'Cedro', 'BR.06.2303808', 'ASCII:Cedro;ID:3402329', '6887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6887', '112', '8764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8765', '1079', '1', 'Castanhal', 'BR.16.1502400', 'ASCII:Castanhal;ID:3402582', '6888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6888', '112', '8765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8766', '1079', '1', 'Cariús', 'BR.06.2303303', 'ASCII:Carius;ID:3402874', '6889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6889', '112', '8766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8767', '1079', '1', 'Caririaçu', 'BR.06.2303204', 'ASCII:Caririacu;ID:3402881', '6890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6890', '112', '8767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8768', '1079', '1', 'Cariré', 'BR.06.2303105', 'ASCII:Carire;ID:3402891', '6891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6891', '112', '8768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8769', '1079', '1', 'Capistrano', 'BR.06.2302909', 'ASCII:Capistrano;ID:3403145', '6892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6892', '112', '8769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8770', '1079', '1', 'Canindé', 'BR.06.2302800', 'ASCII:Caninde;ID:3403350', '6893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6893', '112', '8770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8771', '1079', '1', 'Campos Sales', 'BR.06.2302701', 'ASCII:Campos Sales;ID:3403533', '6894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6894', '112', '8771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8772', '1079', '1', 'Brejo Santo', 'BR.06.2302503', 'ASCII:Brejo Santo;ID:3404832', '6895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6895', '112', '8772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8773', '1079', '1', 'Bragança', 'BR.16.1501709', 'ASCII:Braganca;ID:3405004', '6896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6896', '112', '8773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8774', '1079', '1', 'Boa Viagem', 'BR.06.2302404', 'ASCII:Boa Viagem;ID:3405614', '6897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6897', '112', '8774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8775', '1079', '1', 'Baturité', 'BR.06.2302107', 'ASCII:Baturite;ID:3405953', '6898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6898', '112', '8775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8776', '1079', '1', 'Batalha', 'BR.02.2700706', 'ASCII:Batalha;ID:3405992', '6899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6899', '112', '8776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2700706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8777', '1079', '1', 'Barro', 'BR.06.2302008', 'ASCII:Barro;ID:3406080', '6900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6900', '112', '8777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8778', '1079', '1', 'Barbalha', 'BR.06.2301901', 'ASCII:Barbalha;ID:3406441', '6901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6901', '112', '8778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8779', '1079', '1', 'Baixio', 'BR.06.2301802', 'ASCII:Baixio;ID:3406622', '6902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6902', '112', '8779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8780', '1079', '1', 'Aurora', 'BR.06.2301703', 'ASCII:Aurora;ID:3406952', '6903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6903', '112', '8780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8781', '1079', '1', 'Assaré', 'BR.06.2301604', 'ASCII:Assare;ID:3407009', '6904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6904', '112', '8781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8782', '1079', '1', 'Areia', 'BR.17.2501104', 'ASCII:Areia;ID:3407206', '6905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6905', '112', '8782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8783', '1079', '1', 'Araripe', 'BR.06.2301307', 'ASCII:Araripe;ID:3407246', '6906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6906', '112', '8783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8784', '1079', '1', 'Arapiraca', 'BR.02.2700300', 'ASCII:Arapiraca;ID:3407326', '6907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6907', '112', '8784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2700300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8785', '1079', '1', 'Aracoiaba', 'BR.06.2301208', 'ASCII:Aracoiaba;ID:3407365', '6908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6908', '112', '8785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8786', '1079', '1', 'Anadia', 'BR.02.2700201', 'ASCII:Anadia;ID:3407692', '6909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6909', '112', '8786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2700201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8787', '1079', '1', 'Aiuaba', 'BR.06.2300408', 'ASCII:Aiuaba;ID:3408131', '6910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6910', '112', '8787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8788', '1079', '1', 'Água Branca', 'BR.02.2700102', 'ASCII:Agua Branca;ID:3408207', '6911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6911', '112', '8788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2700102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8789', '1079', '1', 'Tomar do Geru', 'BR.28.2807501', 'ASCII:Tomar Do Geru;ID:3446362', '6912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6912', '112', '8789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2807501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8790', '1079', '1', 'Tobias Barreto', 'BR.28.2807402', 'ASCII:Tobias Barreto;ID:3446399', '6913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6913', '112', '8790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2807402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8791', '1079', '1', 'Tejupá', 'BR.27.3554201', 'ASCII:Tejupa;ID:3446655', '6914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6914', '112', '8791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8792', '1079', '1', 'Soledade', 'BR.23.4320800', 'ASCII:Soledade;ID:3447422', '6915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6915', '112', '8792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8793', '1079', '1', 'Simão Dias', 'BR.28.2807105', 'ASCII:Simao Dias;ID:3447561', '6916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6916', '112', '8793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2807105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8794', '1079', '1', 'Sertãozinho', 'BR.27.3551702', 'ASCII:Sertaozinho;ID:3447642', '6917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6917', '112', '8794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3551702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8795', '1079', '1', 'São Vicente', 'BR.27.3551009', 'ASCII:Sao Vicente;ID:3448130', '6918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6918', '112', '8795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3551009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8796', '1079', '1', 'São Pedro', 'BR.27.3550407', 'ASCII:Sao Pedro;ID:3448380', '6919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6919', '112', '8796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3550407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8797', '1079', '1', 'São Francisco de Paula', 'BR.23.4318200', 'ASCII:Sao Francisco De Paula;ID:3449120', '6920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6920', '112', '8797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8798', '1079', '1', 'São Brás', 'BR.02.2708204', 'ASCII:Sao Bras;ID:3449334', '6921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6921', '112', '8798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8799', '1079', '1', 'Rio Grande', 'BR.23.4315602', 'ASCII:Rio Grande;ID:3451136', '6922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6922', '112', '8799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8800', '1079', '1', 'Ribeirópolis', 'BR.28.2806008', 'ASCII:Ribeiropolis;ID:3451304', '6923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6923', '112', '8800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2806008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8801', '1079', '1', 'Riachão do Dantas', 'BR.28.2805802', 'ASCII:Riachao Do Dantas;ID:3451475', '6924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6924', '112', '8801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2805802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8802', '1079', '1', 'Realeza', 'BR.18.4121406', 'ASCII:Realeza;ID:3451782', '6925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6925', '112', '8802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8803', '1079', '1', 'Propriá', 'BR.28.2805703', 'ASCII:Propria;ID:3452231', '6926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6926', '112', '8803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2805703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8804', '1079', '1', 'Porto Real do Colégio', 'BR.02.2707503', 'ASCII:Porto Real Do Colegio;ID:3452670', '6927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6927', '112', '8804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2707503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8805', '1079', '1', 'Poço Verde', 'BR.28.2805505', 'ASCII:Poco Verde;ID:3453298', '6928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6928', '112', '8805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2805505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8806', '1079', '1', 'Pinhão', 'BR.28.2805208', 'ASCII:Pinhao;ID:3453776', '6929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6929', '112', '8806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2805208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8807', '1079', '1', 'Penedo', 'BR.02.2706703', 'ASCII:Penedo;ID:3454224', '6930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6930', '112', '8807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8808', '1079', '1', 'Pelotas', 'BR.23.4314407', 'ASCII:Pelotas;ID:3454242', '6931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6931', '112', '8808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8809', '1079', '1', 'Patrocínio Paulista', 'BR.27.3536307', 'ASCII:Patrocinio Paulista;ID:3454760', '6932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6932', '112', '8809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8810', '1079', '1', 'Ouro Fino', 'BR.15.3146008', 'ASCII:Ouro Fino;ID:3455679', '6933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6933', '112', '8810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8811', '1079', '1', 'Nossa Senhora das Dores', 'BR.28.2804607', 'ASCII:Nossa Senhora Das Dores;ID:3456233', '6934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6934', '112', '8811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8812', '1079', '1', 'Nossa Senhora da Glória', 'BR.28.2804508', 'ASCII:Nossa Senhora Da Gloria;ID:3456239', '6935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6935', '112', '8812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8813', '1079', '1', 'Monte Alegre de Sergipe', 'BR.28.2804201', 'ASCII:Monte Alegre De Sergipe;ID:3456878', '6936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6936', '112', '8813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8814', '1079', '1', 'Matias Barbosa', 'BR.15.3140803', 'ASCII:Matias Barbosa;ID:3457478', '6937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6937', '112', '8814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8815', '1079', '1', 'Mar de Espanha', 'BR.15.3139805', 'ASCII:Mar De Espanha;ID:3457775', '6938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6938', '112', '8815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8816', '1079', '1', 'Macambira', 'BR.28.2803708', 'ASCII:Macambira;ID:3458255', '6939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6939', '112', '8816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2803708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8817', '1079', '1', 'Luciára', 'BR.14.5105309', 'ASCII:Luciara;ID:3458382', '6940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6940', '112', '8817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8818', '1079', '1', 'Lindóia', 'BR.27.3527009', 'ASCII:Lindoia;ID:3458505', '6941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6941', '112', '8818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8819', '1079', '1', 'Lagoa Vermelha', 'BR.23.4311304', 'ASCII:Lagoa Vermelha;ID:3459125', '6942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6942', '112', '8819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8820', '1079', '1', 'Lagarto', 'BR.28.2803500', 'ASCII:Lagarto;ID:3459337', '6943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6943', '112', '8820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2803500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8821', '1079', '1', 'Juiz de Fora', 'BR.15.3136702', 'ASCII:Juiz De Fora;ID:3459504', '6944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6944', '112', '8821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8822', '1079', '1', 'Itirapuã', 'BR.27.3523701', 'ASCII:Itirapua;ID:3460550', '6945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6945', '112', '8822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3523701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8823', '1079', '1', 'Itapema', 'BR.26.4208302', 'ASCII:Itapema;ID:3460739', '6946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6946', '112', '8823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8824', '1079', '1', 'Itabi', 'BR.28.2803104', 'ASCII:Itabi;ID:3460961', '6947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6947', '112', '8824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2803104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8825', '1079', '1', 'Itabaianinha', 'BR.28.2803005', 'ASCII:Itabaianinha;ID:3460970', '6948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6948', '112', '8825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2803005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8826', '1079', '1', 'Igreja Nova', 'BR.02.2703205', 'ASCII:Igreja Nova;ID:3461483', '6949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6949', '112', '8826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8827', '1079', '1', 'Herval', 'BR.23.4307104', 'ASCII:Herval;ID:3461679', '6950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6950', '112', '8827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8828', '1079', '1', 'Gararu', 'BR.28.2802403', 'ASCII:Gararu;ID:3462581', '6951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6951', '112', '8828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2802403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8829', '1079', '1', 'Frei Paulo', 'BR.28.2802304', 'ASCII:Frei Paulo;ID:3462943', '6952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6952', '112', '8829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2802304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8830', '1079', '1', 'Curimatá', 'BR.20.2203206', 'ASCII:Curimata;ID:3464981', '6953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6953', '112', '8830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8831', '1079', '1', 'Cumbe', 'BR.28.2801900', 'ASCII:Cumbe;ID:3465015', '6954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6954', '112', '8831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2801900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8832', '1079', '1', 'Concórdia', 'BR.26.4204301', 'ASCII:Concordia;ID:3465719', '6955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6955', '112', '8832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8833', '1079', '1', 'Conceição do Mato Dentro', 'BR.15.3117504', 'ASCII:Conceicao Do Mato Dentro;ID:3465744', '6956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6956', '112', '8833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8834', '1079', '1', 'Charqueada', 'BR.27.3511706', 'ASCII:Charqueada;ID:3466262', '6957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6957', '112', '8834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3511706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8835', '1079', '1', 'Cedro de São João', 'BR.28.2801603', 'ASCII:Cedro De Sao Joao;ID:3466498', '6958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6958', '112', '8835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2801603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8836', '1079', '1', 'Carira', 'BR.28.2801405', 'ASCII:Carira;ID:3466940', '6959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6959', '112', '8836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2801405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8837', '1079', '1', 'Carazinho', 'BR.23.4304705', 'ASCII:Carazinho;ID:3466976', '6960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6960', '112', '8837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8838', '1079', '1', 'Canhoba', 'BR.28.2801108', 'ASCII:Canhoba;ID:3467499', '6961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6961', '112', '8838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2801108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8839', '1079', '1', 'Candeias', 'BR.05.2906501', 'ASCII:Candeias;ID:3467552', '6962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6962', '112', '8839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8840', '1079', '1', 'Campo Limpo Paulista', 'BR.27.3509601', 'ASCII:Campo Limpo Paulista;ID:3467719', '6963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6963', '112', '8840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8841', '1079', '1', 'Campo do Brito', 'BR.28.2801009', 'ASCII:Campo Do Brito;ID:3467779', '6964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6964', '112', '8841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2801009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8842', '1079', '1', 'Campo Bom', 'BR.23.4303905', 'ASCII:Campo Bom;ID:3467789', '6965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6965', '112', '8842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8843', '1079', '1', 'Barreiras', 'BR.05.2903201', 'ASCII:Barreiras;ID:3470579', '6966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6966', '112', '8843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8844', '1079', '1', 'Aquidabã', 'BR.28.2800209', 'ASCII:Aquidaba;ID:3471899', '6967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6967', '112', '8844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2800209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8845', '1079', '1', 'Antônio Prado', 'BR.23.4300802', 'ASCII:Antonio Prado;ID:3471980', '6968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6968', '112', '8845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8846', '1079', '1', 'Analândia', 'BR.27.3502002', 'ASCII:Analandia;ID:3472293', '6969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6969', '112', '8846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8847', '1079', '1', 'Amparo de São Francisco', 'BR.28.2800100', 'ASCII:Amparo De Sao Francisco;ID:3472306', '6970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6970', '112', '8847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2800100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8848', '1079', '1', 'Amparo', 'BR.27.3501905', 'ASCII:Amparo;ID:3472310', '6971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6971', '112', '8848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8849', '1079', '1', 'Américo de Campos', 'BR.27.3501806', 'ASCII:Americo De Campos;ID:3472336', '6972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6972', '112', '8849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8850', '1079', '1', 'Americana', 'BR.27.3501608', 'ASCII:Americana;ID:3472342', '6973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6973', '112', '8850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8851', '1079', '1', 'Álvaro de Carvalho', 'BR.27.3501400', 'ASCII:Alvaro De Carvalho;ID:3472413', '6974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6974', '112', '8851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8852', '1079', '1', 'Álvares Machado', 'BR.27.3501301', 'ASCII:Alvares Machado;ID:3472416', '6975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6975', '112', '8852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8853', '1079', '1', 'Álvares Florence', 'BR.27.3501202', 'ASCII:Alvares Florence;ID:3472418', '6976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6976', '112', '8853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8854', '1079', '1', 'Alto Alegre', 'BR.27.3501103', 'ASCII:Alto Alegre;ID:3472474', '6977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6977', '112', '8854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8855', '1079', '1', 'Altinópolis', 'BR.27.3501004', 'ASCII:Altinopolis;ID:3472484', '6978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6978', '112', '8855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8856', '1079', '1', 'Alfredo Marcondes', 'BR.27.3500808', 'ASCII:Alfredo Marcondes;ID:3472589', '6979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6979', '112', '8856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8857', '1079', '1', 'Alagoinhas', 'BR.05.2900702', 'ASCII:Alagoinhas;ID:3472764', '6980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6980', '112', '8857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2900702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8858', '1079', '1', 'Agudos', 'BR.27.3500709', 'ASCII:Agudos;ID:3472824', '6981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6981', '112', '8858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8859', '1079', '1', 'Águas de São Pedro', 'BR.27.3500600', 'ASCII:Aguas De Sao Pedro;ID:3472867', '6982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6982', '112', '8859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8860', '1079', '1', 'Águas da Prata', 'BR.27.3500402', 'ASCII:Aguas Da Prata;ID:3472872', '6983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6983', '112', '8860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8861', '1079', '1', 'Aguaí', 'BR.27.3500303', 'ASCII:Aguai;ID:3472968', '6984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6984', '112', '8861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8862', '1079', '1', 'Adamantina', 'BR.27.3500105', 'ASCII:Adamantina;ID:3473156', '6985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6985', '112', '8862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8863', '1079', '1', 'Lábrea', 'BR.04.1302405', 'ASCII:Labrea;ID:3663683', '6986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6986', '112', '8863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8864', '1079', '1', 'Guajará-Mirim', 'BR.24.1100106', 'ASCII:Guajara-Mirim;ID:3925074', '6987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6987', '112', '8864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8865', '1079', '1', 'São José do Sul', 'BR.23.4318614', 'ASCII:Sao Jose Do Sul;ID:6318995', '6988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6988', '112', '8865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8866', '1079', '1', 'Capão do Cipó', 'BR.23.4304655', 'ASCII:Capao Do Cipo;ID:6318996', '6989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6989', '112', '8866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8867', '1079', '1', 'Santo Antônio do Içá', 'BR.04.1303700', 'ASCII:Santo Antonio Do Ica;ID:6318997', '6990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6990', '112', '8867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8868', '1079', '1', 'Redenção', 'BR.16.1506138', 'ASCII:Redencao;ID:6318998', '6991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6991', '112', '8868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506138» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8869', '1079', '1', 'Santa Cruz do Arari', 'BR.16.1506401', 'ASCII:Santa Cruz Do Arari;ID:6318999', '6992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6992', '112', '8869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8870', '1079', '1', 'Santa Luzia do Pará', 'BR.16.1506559', 'ASCII:Santa Luzia Do Para;ID:6319000', '6993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6993', '112', '8870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8871', '1079', '1', 'São Miguel do Guamá', 'BR.16.1507607', 'ASCII:Sao Miguel Do Guama;ID:6319001', '6994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6994', '112', '8871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8872', '1079', '1', 'Pau d''Arco', 'BR.31.1716307', 'ASCII:Pau D''Arco;ID:6319002', '6995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6995', '112', '8872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1716307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8873', '1079', '1', 'Santa Fé do Araguaia', 'BR.31.1718865', 'ASCII:Santa Fe Do Araguaia;ID:6319003', '6996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6996', '112', '8873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8874', '1079', '1', 'Santa Maria do Tocantins', 'BR.31.1718881', 'ASCII:Santa Maria Do Tocantins;ID:6319004', '6997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6997', '112', '8874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8875', '1079', '1', 'Açailândia', 'BR.13.2100055', 'ASCII:Acailandia;ID:6319005', '6998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6998', '112', '8875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8876', '1079', '1', 'Alto Alegre do Pindaré', 'BR.13.2100477', 'ASCII:Alto Alegre Do Pindare;ID:6319006', '6999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('6999', '112', '8876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8877', '1079', '1', 'Barão de Grajaú', 'BR.13.2101509', 'ASCII:Barao De Grajau;ID:6319007', '7000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7000', '112', '8877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8878', '1079', '1', 'Chapadinha', 'BR.13.2103208', 'ASCII:Chapadinha;ID:6319008', '7001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7001', '112', '8878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8879', '1079', '1', 'Conceição do Lago-Açu', 'BR.13.2103554', 'ASCII:Conceicao Do Lago-Acu;ID:6319009', '7002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7002', '112', '8879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8880', '1079', '1', 'Governador Archer', 'BR.13.2104503', 'ASCII:Governador Archer;ID:6319010', '7003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7003', '112', '8880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8881', '1079', '1', 'Monção', 'BR.13.2106904', 'ASCII:Moncao;ID:6319011', '7004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7004', '112', '8881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8882', '1079', '1', 'Nina Rodrigues', 'BR.13.2107209', 'ASCII:Nina Rodrigues;ID:6319012', '7005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7005', '112', '8882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8883', '1079', '1', 'Santa Luzia', 'BR.13.2110005', 'ASCII:Santa Luzia;ID:6319013', '7006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7006', '112', '8883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8884', '1079', '1', 'Santa Luzia do Paruá', 'BR.13.2110039', 'ASCII:Santa Luzia Do Parua;ID:6319014', '7007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7007', '112', '8884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8885', '1079', '1', 'Santa Rita', 'BR.13.2110203', 'ASCII:Santa Rita;ID:6319015', '7008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7008', '112', '8885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8886', '1079', '1', 'São João do Paraíso', 'BR.13.2111052', 'ASCII:Sao Joao Do Paraiso;ID:6319016', '7009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7009', '112', '8886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8887', '1079', '1', 'Beneditinos', 'BR.20.2201606', 'ASCII:Beneditinos;ID:6319017', '7010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7010', '112', '8887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8888', '1079', '1', 'Caridade do Piauí', 'BR.20.2202554', 'ASCII:Caridade Do Piaui;ID:6319018', '7011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7011', '112', '8888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8889', '1079', '1', 'Curral Novo do Piauí', 'BR.20.2203271', 'ASCII:Curral Novo Do Piaui;ID:6319019', '7012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7012', '112', '8889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8890', '1079', '1', 'Dirceu Arcoverde', 'BR.20.2203354', 'ASCII:Dirceu Arcoverde;ID:6319020', '7013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7013', '112', '8890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8891', '1079', '1', 'Fronteiras', 'BR.20.2204303', 'ASCII:Fronteiras;ID:6319021', '7014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7014', '112', '8891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8892', '1079', '1', 'Jatobá do Piauí', 'BR.20.2205276', 'ASCII:Jatoba Do Piaui;ID:6319022', '7015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7015', '112', '8892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8893', '1079', '1', 'Jerumenha', 'BR.20.2205300', 'ASCII:Jerumenha;ID:6319023', '7016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7016', '112', '8893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8894', '1079', '1', 'Parnaguá', 'BR.20.2207603', 'ASCII:Parnagua;ID:6319024', '7017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7017', '112', '8894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8895', '1079', '1', 'Pedro Laurentino', 'BR.20.2207934', 'ASCII:Pedro Laurentino;ID:6319025', '7018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7018', '112', '8895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8896', '1079', '1', 'Santa Cruz dos Milagres', 'BR.20.2209153', 'ASCII:Santa Cruz Dos Milagres;ID:6319026', '7019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7019', '112', '8896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8897', '1079', '1', 'São Félix do Piauí', 'BR.20.2209609', 'ASCII:Sao Felix Do Piaui;ID:6319027', '7020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7020', '112', '8897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8898', '1079', '1', 'São José do Piauí', 'BR.20.2210201', 'ASCII:Sao Jose Do Piaui;ID:6319028', '7021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7021', '112', '8898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8899', '1079', '1', 'Simões', 'BR.20.2210706', 'ASCII:Simoes;ID:6319029', '7022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7022', '112', '8899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8900', '1079', '1', 'Alexandria', 'BR.22.2400505', 'ASCII:Alexandria;ID:6319030', '7023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7023', '112', '8900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2400505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8901', '1079', '1', 'Angicos', 'BR.22.2400802', 'ASCII:Angicos;ID:6319031', '7024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7024', '112', '8901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2400802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8902', '1079', '1', 'Bom Jesus', 'BR.22.2401701', 'ASCII:Bom Jesus;ID:6319032', '7025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7025', '112', '8902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8903', '1079', '1', 'Carnaúba dos Dantas', 'BR.22.2402402', 'ASCII:Carnauba Dos Dantas;ID:6319033', '7026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7026', '112', '8903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2402402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8904', '1079', '1', 'Equador', 'BR.22.2403400', 'ASCII:Equador;ID:6319034', '7027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7027', '112', '8904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8905', '1079', '1', 'Jaçanã', 'BR.22.2405009', 'ASCII:Jacana;ID:6319035', '7028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7028', '112', '8905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2405009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8906', '1079', '1', 'Jucurutu', 'BR.22.2406106', 'ASCII:Jucurutu;ID:6319036', '7029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7029', '112', '8906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8907', '1079', '1', 'Maxaranguape', 'BR.22.2407500', 'ASCII:Maxaranguape;ID:6319037', '7030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7030', '112', '8907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8908', '1079', '1', 'Mossoró', 'BR.22.2408003', 'ASCII:Mossoro;ID:6319038', '7031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7031', '112', '8908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8909', '1079', '1', 'Nísia Floresta', 'BR.22.2408201', 'ASCII:Nisia Floresta;ID:6319039', '7032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7032', '112', '8909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8910', '1079', '1', 'Paraú', 'BR.22.2408706', 'ASCII:Parau;ID:6319040', '7033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7033', '112', '8910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8911', '1079', '1', 'Patu', 'BR.22.2409308', 'ASCII:Patu;ID:6319041', '7034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7034', '112', '8911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2409308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8912', '1079', '1', 'Pureza', 'BR.22.2410405', 'ASCII:Pureza;ID:6319042', '7035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7035', '112', '8912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8913', '1079', '1', 'São Tomé', 'BR.22.2412906', 'ASCII:Sao Tome;ID:6319043', '7036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7036', '112', '8913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8914', '1079', '1', 'Touros', 'BR.22.2414407', 'ASCII:Touros;ID:6319044', '7037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7037', '112', '8914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8915', '1079', '1', 'Alhandra', 'BR.17.2500601', 'ASCII:Alhandra;ID:6319045', '7038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7038', '112', '8915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8916', '1079', '1', 'Aparecida', 'BR.17.2500775', 'ASCII:Aparecida;ID:6319046', '7039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7039', '112', '8916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8917', '1079', '1', 'Boqueirão', 'BR.17.2502508', 'ASCII:Boqueirao;ID:6319047', '7040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7040', '112', '8917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8918', '1079', '1', 'Cachoeira dos Índios', 'BR.17.2503308', 'ASCII:Cachoeira Dos Indios;ID:6319048', '7041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7041', '112', '8918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8919', '1079', '1', 'Cajazeiras', 'BR.17.2503704', 'ASCII:Cajazeiras;ID:6319049', '7042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7042', '112', '8919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8920', '1079', '1', 'Conceição', 'BR.17.2504405', 'ASCII:Conceicao;ID:6319050', '7043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7043', '112', '8920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8921', '1079', '1', 'Cruz do Espírito Santo', 'BR.17.2504900', 'ASCII:Cruz Do Espirito Santo;ID:6319051', '7044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7044', '112', '8921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8922', '1079', '1', 'Curral de Cima', 'BR.17.2505279', 'ASCII:Curral De Cima;ID:6319052', '7045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7045', '112', '8922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8923', '1079', '1', 'Frei Martinho', 'BR.17.2506202', 'ASCII:Frei Martinho;ID:6319053', '7046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7046', '112', '8923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8924', '1079', '1', 'Ibiara', 'BR.17.2506608', 'ASCII:Ibiara;ID:6319054', '7047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7047', '112', '8924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8925', '1079', '1', 'Lagoa', 'BR.17.2508109', 'ASCII:Lagoa;ID:6319055', '7048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7048', '112', '8925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8926', '1079', '1', 'Lagoa Seca', 'BR.17.2508307', 'ASCII:Lagoa Seca;ID:6319056', '7049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7049', '112', '8926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8927', '1079', '1', 'Mamanguape', 'BR.17.2508901', 'ASCII:Mamanguape;ID:6319057', '7050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7050', '112', '8927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8928', '1079', '1', 'Mataraca', 'BR.17.2509305', 'ASCII:Mataraca;ID:6319058', '7051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7051', '112', '8928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8929', '1079', '1', 'Pocinhos', 'BR.17.2512002', 'ASCII:Pocinhos;ID:6319059', '7052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7052', '112', '8929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8930', '1079', '1', 'Pombal', 'BR.17.2512101', 'ASCII:Pombal;ID:6319060', '7053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7053', '112', '8930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8931', '1079', '1', 'Rio Tinto', 'BR.17.2512903', 'ASCII:Rio Tinto;ID:6319061', '7054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7054', '112', '8931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8932', '1079', '1', 'Santa Rita', 'BR.17.2513703', 'ASCII:Santa Rita;ID:6319062', '7055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7055', '112', '8932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8933', '1079', '1', 'São José do Bonfim', 'BR.17.2514602', 'ASCII:Sao Jose Do Bonfim;ID:6319063', '7056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7056', '112', '8933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8934', '1079', '1', 'Sousa', 'BR.17.2516201', 'ASCII:Sousa;ID:6319064', '7057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7057', '112', '8934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8935', '1079', '1', 'Triunfo', 'BR.17.2516805', 'ASCII:Triunfo;ID:6319065', '7058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7058', '112', '8935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8936', '1079', '1', 'Zabelê', 'BR.17.2517407', 'ASCII:Zabele;ID:6319066', '7059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7059', '112', '8936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2517407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8937', '1079', '1', 'Araripina', 'BR.30.2601102', 'ASCII:Araripina;ID:6319067', '7060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7060', '112', '8937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8938', '1079', '1', 'Correntes', 'BR.30.2604700', 'ASCII:Correntes;ID:6319068', '7061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7061', '112', '8938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8939', '1079', '1', 'São Benedito do Sul', 'BR.30.2612901', 'ASCII:Sao Benedito Do Sul;ID:6319069', '7062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7062', '112', '8939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8940', '1079', '1', 'Barra de Santo Antônio', 'BR.02.2700508', 'ASCII:Barra De Santo Antonio;ID:6319070', '7063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7063', '112', '8940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2700508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8941', '1079', '1', 'Canapi', 'BR.02.2701605', 'ASCII:Canapi;ID:6319071', '7064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7064', '112', '8941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8942', '1079', '1', 'São Sebastião', 'BR.02.2708808', 'ASCII:Sao Sebastiao;ID:6319072', '7065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7065', '112', '8942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8943', '1079', '1', 'Belmonte', 'BR.05.2903409', 'ASCII:Belmonte;ID:6319073', '7066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7066', '112', '8943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8944', '1079', '1', 'Brejões', 'BR.05.2904308', 'ASCII:Brejoes;ID:6319074', '7067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7067', '112', '8944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8945', '1079', '1', 'Dias d''Ávila', 'BR.05.2910057', 'ASCII:Dias D''Avila;ID:6319075', '7068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7068', '112', '8945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8946', '1079', '1', 'Dom Basílio', 'BR.05.2910107', 'ASCII:Dom Basilio;ID:6319076', '7069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7069', '112', '8946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8947', '1079', '1', 'Iaçu', 'BR.05.2911907', 'ASCII:Iacu;ID:6319077', '7070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7070', '112', '8947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8948', '1079', '1', 'Ituberá', 'BR.05.2917300', 'ASCII:Itubera;ID:6319078', '7071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7071', '112', '8948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8949', '1079', '1', 'Lagoa Real', 'BR.05.2918753', 'ASCII:Lagoa Real;ID:6319079', '7072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7072', '112', '8949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8950', '1079', '1', 'Muquém de São Francisco', 'BR.05.2922250', 'ASCII:Muquem De Sao Francisco;ID:6319080', '7073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7073', '112', '8950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8951', '1079', '1', 'Nilo Peçanha', 'BR.05.2922607', 'ASCII:Nilo Pecanha;ID:6319081', '7074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7074', '112', '8951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8952', '1079', '1', 'Nordestina', 'BR.05.2922656', 'ASCII:Nordestina;ID:6319082', '7075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7075', '112', '8952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8953', '1079', '1', 'Nova Viçosa', 'BR.05.2923001', 'ASCII:Nova Vicosa;ID:6319083', '7076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7076', '112', '8953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8954', '1079', '1', 'Oliveira dos Brejinhos', 'BR.05.2923209', 'ASCII:Oliveira Dos Brejinhos;ID:6319084', '7077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7077', '112', '8954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8955', '1079', '1', 'Poções', 'BR.05.2925105', 'ASCII:Pocoes;ID:6319085', '7078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7078', '112', '8955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8956', '1079', '1', 'Presidente Tancredo Neves', 'BR.05.2925758', 'ASCII:Presidente Tancredo Neves;ID:6319086', '7079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7079', '112', '8956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8957', '1079', '1', 'Santa Maria da Vitória', 'BR.05.2928109', 'ASCII:Santa Maria Da Vitoria;ID:6319087', '7080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7080', '112', '8957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8958', '1079', '1', 'Santana', 'BR.05.2928208', 'ASCII:Santana;ID:6319088', '7081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7081', '112', '8958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8959', '1079', '1', 'Tremedal', 'BR.05.2931806', 'ASCII:Tremedal;ID:6319089', '7082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7082', '112', '8959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8960', '1079', '1', 'Umburanas', 'BR.05.2932457', 'ASCII:Umburanas;ID:6319090', '7083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7083', '112', '8960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8961', '1079', '1', 'Una', 'BR.05.2932507', 'ASCII:Una;ID:6319091', '7084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7084', '112', '8961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8962', '1079', '1', 'Além Paraíba', 'BR.15.3101508', 'ASCII:Alem Paraiba;ID:6319092', '7085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7085', '112', '8962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8963', '1079', '1', 'Araçaí', 'BR.15.3103207', 'ASCII:Aracai;ID:6319093', '7086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7086', '112', '8963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8964', '1079', '1', 'Consolação', 'BR.15.3118502', 'ASCII:Consolacao;ID:6319094', '7087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7087', '112', '8964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3118502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8965', '1079', '1', 'Guidoval', 'BR.15.3128808', 'ASCII:Guidoval;ID:6319095', '7088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7088', '112', '8965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8966', '1079', '1', 'Guimarânia', 'BR.15.3128907', 'ASCII:Guimarania;ID:6319096', '7089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7089', '112', '8966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8967', '1079', '1', 'Patrocínio do Muriaé', 'BR.15.3148202', 'ASCII:Patrocinio Do Muriae;ID:6319097', '7090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7090', '112', '8967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8968', '1079', '1', 'Santa Bárbara do Tugúrio', 'BR.15.3157302', 'ASCII:Santa Barbara Do Tugurio;ID:6319098', '7091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7091', '112', '8968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8969', '1079', '1', 'São Brás do Suaçuí', 'BR.15.3160900', 'ASCII:Sao Bras Do Suacui;ID:6319099', '7092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7092', '112', '8969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8970', '1079', '1', 'São José do Calçado', 'BR.08.3204807', 'ASCII:Sao Jose Do Calcado;ID:6319100', '7093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7093', '112', '8970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8971', '1079', '1', 'Areal', 'BR.21.3300225', 'ASCII:Areal;ID:6319101', '7094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7094', '112', '8971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8972', '1079', '1', 'Armação dos Búzios', 'BR.21.3300233', 'ASCII:Armacao De Buzios;ID:6319102', '7095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7095', '112', '8972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8973', '1079', '1', 'Conceição de Macabu', 'BR.21.3301405', 'ASCII:Conceicao De Macabu;ID:6319103', '7096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7096', '112', '8973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8974', '1079', '1', 'Assis', 'BR.27.3504008', 'ASCII:Assis;ID:6319104', '7097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7097', '112', '8974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3504008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8975', '1079', '1', 'Divinolândia', 'BR.27.3513900', 'ASCII:Divinolandia;ID:6319105', '7098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7098', '112', '8975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8976', '1079', '1', 'Guaraçaí', 'BR.27.3517802', 'ASCII:Guaracai;ID:6319106', '7099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7099', '112', '8976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3517802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8977', '1079', '1', 'Igarapava', 'BR.27.3520103', 'ASCII:Igarapava;ID:6319107', '7100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7100', '112', '8977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8978', '1079', '1', 'José Bonifácio', 'BR.27.3525706', 'ASCII:Jose Bonifacio;ID:6319108', '7101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7101', '112', '8978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8979', '1079', '1', 'Luís Antônio', 'BR.27.3527603', 'ASCII:Luis Antonio;ID:6319109', '7102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7102', '112', '8979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8980', '1079', '1', 'Lupércio', 'BR.27.3527801', 'ASCII:Lupercio;ID:6319110', '7103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7103', '112', '8980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8981', '1079', '1', 'Lutécia', 'BR.27.3527900', 'ASCII:Lutecia;ID:6319111', '7104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7104', '112', '8981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8982', '1079', '1', 'Nova Canaã Paulista', 'BR.27.3532843', 'ASCII:Nova Canaa Paulista;ID:6319112', '7105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7105', '112', '8982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8983', '1079', '1', 'Nova Castilho', 'BR.27.3532868', 'ASCII:Nova Castilho;ID:6319113', '7106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7106', '112', '8983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8984', '1079', '1', 'Saltinho', 'BR.27.3545159', 'ASCII:Saltinho;ID:6319114', '7107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7107', '112', '8984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3545159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8985', '1079', '1', 'Ivaí', 'BR.18.4111407', 'ASCII:Ivai;ID:6319115', '7108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7108', '112', '8985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8986', '1079', '1', 'Ivaiporã', 'BR.18.4111506', 'ASCII:Ivaipora;ID:6319116', '7109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7109', '112', '8986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8987', '1079', '1', 'Lupionópolis', 'BR.18.4113809', 'ASCII:Lupionopolis;ID:6319117', '7110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7110', '112', '8987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8988', '1079', '1', 'Planaltina do Paraná', 'BR.18.4119707', 'ASCII:Planaltina Do Parana;ID:6319118', '7111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7111', '112', '8988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8989', '1079', '1', 'Santa Cecília do Pavão', 'BR.18.4123204', 'ASCII:Santa Cecilia Do Pavao;ID:6319119', '7112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7112', '112', '8989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8990', '1079', '1', 'Santa Cruz de Monte Castelo', 'BR.18.4123303', 'ASCII:Santa Cruz De Monte Castelo;ID:6319120', '7113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7113', '112', '8990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8991', '1079', '1', 'Santa Fé', 'BR.18.4123402', 'ASCII:Santa Fe;ID:6319121', '7114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7114', '112', '8991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8992', '1079', '1', 'Santana do Itararé', 'BR.18.4124004', 'ASCII:Santana Do Itarare;ID:6319122', '7115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7115', '112', '8992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8993', '1079', '1', 'Santo Antônio do Paraíso', 'BR.18.4124301', 'ASCII:Santo Antonio Do Paraiso;ID:6319123', '7116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7116', '112', '8993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8994', '1079', '1', 'São José da Boa Vista', 'BR.18.4125407', 'ASCII:Sao Jose Da Boa Vista;ID:6319124', '7117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7117', '112', '8994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8995', '1079', '1', 'São José das Palmeiras', 'BR.18.4125456', 'ASCII:Sao Jose Das Palmeiras;ID:6319125', '7118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7118', '112', '8995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8996', '1079', '1', 'Serranópolis do Iguaçu', 'BR.18.4126355', 'ASCII:Serranopolis Do Iguacu;ID:6319126', '7119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7119', '112', '8996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8997', '1079', '1', 'Três Barras do Paraná', 'BR.18.4127858', 'ASCII:Tres Barras Do Parana;ID:6319127', '7120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7120', '112', '8997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8998', '1079', '1', 'Campo Erê', 'BR.26.4203501', 'ASCII:Campo Ere;ID:6319128', '7121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7121', '112', '8998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('8999', '1079', '1', 'Correia Pinto', 'BR.26.4204558', 'ASCII:Correia Pinto;ID:6319129', '7122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7122', '112', '8999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9000', '1079', '1', 'Criciúma', 'BR.26.4204608', 'ASCII:Criciuma;ID:6319130', '7123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7123', '112', '9000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9001', '1079', '1', 'Paraíso', 'BR.26.4212239', 'ASCII:Paraiso;ID:6319131', '7124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7124', '112', '9001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9002', '1079', '1', 'Passos Maia', 'BR.26.4212270', 'ASCII:Passos Maia;ID:6319132', '7125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7125', '112', '9002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9003', '1079', '1', 'São Lourenço do Oeste', 'BR.26.4216909', 'ASCII:Sao Lourenco Do Oeste;ID:6319133', '7126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7126', '112', '9003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9004', '1079', '1', 'Barros Cassal', 'BR.23.4302006', 'ASCII:Barros Cassal;ID:6319134', '7127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7127', '112', '9004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9005', '1079', '1', 'Boqueirão do Leão', 'BR.23.4302451', 'ASCII:Boqueirao Do Leao;ID:6319135', '7128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7128', '112', '9005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9006', '1079', '1', 'Cerro Grande', 'BR.23.4305157', 'ASCII:Cerro Grande;ID:6319136', '7129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7129', '112', '9006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9007', '1079', '1', 'David Canabarro', 'BR.23.4306304', 'ASCII:David Canabarro;ID:6319137', '7130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7130', '112', '9007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9008', '1079', '1', 'Derrubadas', 'BR.23.4306320', 'ASCII:Derrubadas;ID:6319138', '7131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7131', '112', '9008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9009', '1079', '1', 'Jaguari', 'BR.23.4311106', 'ASCII:Jaguari;ID:6319139', '7132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7132', '112', '9009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9010', '1079', '1', 'Marques de Souza', 'BR.23.4312054', 'ASCII:Marques De Souza;ID:6319140', '7133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7133', '112', '9010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9011', '1079', '1', 'Monte Belo do Sul', 'BR.23.4312385', 'ASCII:Monte Belo Do Sul;ID:6319141', '7134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7134', '112', '9011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9012', '1079', '1', 'Mormaço', 'BR.23.4312427', 'ASCII:Mormaco;ID:6319142', '7135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7135', '112', '9012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9013', '1079', '1', 'Nova Boa Vista', 'BR.23.4312955', 'ASCII:Nova Boa Vista;ID:6319143', '7136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7136', '112', '9013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9014', '1079', '1', 'Nova Candelária', 'BR.23.4313011', 'ASCII:Nova Candelaria;ID:6319144', '7137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7137', '112', '9014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9015', '1079', '1', 'São José do Povo', 'BR.14.5107297', 'ASCII:Sao Jose Do Povo;ID:6319145', '7138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7138', '112', '9015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9016', '1079', '1', 'Nova Marilândia', 'BR.14.5108857', 'ASCII:Nova Marilandia;ID:6319146', '7139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7139', '112', '9016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9017', '1079', '1', 'Nova Maringá', 'BR.14.5108907', 'ASCII:Nova Maringa;ID:6319147', '7140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7140', '112', '9017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9018', '1079', '1', 'Água Fria de Goiás', 'BR.29.5200175', 'ASCII:Agua Fria De Goias;ID:6319148', '7141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7141', '112', '9018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9019', '1079', '1', 'Alto Paraíso de Goiás', 'BR.29.5200605', 'ASCII:Alto Paraiso De Goias;ID:6319149', '7142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7142', '112', '9019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9020', '1079', '1', 'Aurilândia', 'BR.29.5202601', 'ASCII:Aurilandia;ID:6319150', '7143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7143', '112', '9020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5202601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9021', '1079', '1', 'Baliza', 'BR.29.5203104', 'ASCII:Baliza;ID:6319151', '7144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7144', '112', '9021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9022', '1079', '1', 'Chapadão do Céu', 'BR.29.5205471', 'ASCII:Chapadao Do Ceu;ID:6319152', '7145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7145', '112', '9022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9023', '1079', '1', 'Divinópolis de Goiás', 'BR.29.5208301', 'ASCII:Divinopolis De Goias;ID:6319153', '7146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7146', '112', '9023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5208301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9024', '1079', '1', 'Santa Bárbara de Goiás', 'BR.29.5219100', 'ASCII:Santa Barbara De Goias;ID:6319154', '7147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7147', '112', '9024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9025', '1079', '1', 'Santo Antônio do Descoberto', 'BR.29.5219753', 'ASCII:Santo Antonio Do Descoberto;ID:6319155', '7148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7148', '112', '9025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9026', '1079', '1', 'São Domingos', 'BR.29.5219803', 'ASCII:Sao Domingos;ID:6319156', '7149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7149', '112', '9026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9027', '1079', '1', 'São Francisco de Goiás', 'BR.29.5219902', 'ASCII:Sao Francisco De Goias;ID:6319157', '7150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7150', '112', '9027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9028', '1079', '1', 'Senador Canedo', 'BR.29.5220454', 'ASCII:Senador Canedo;ID:6319158', '7151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7151', '112', '9028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9029', '1079', '1', 'Serranópolis', 'BR.29.5220504', 'ASCII:Serranopolis;ID:6319159', '7152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7152', '112', '9029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9030', '1079', '1', 'Simolândia', 'BR.29.5220686', 'ASCII:Simolandia;ID:6319160', '7153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7153', '112', '9030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9031', '1079', '1', 'São José do Xingu', 'BR.14.5107354', 'ASCII:Sao Jose Do Xingu;ID:6319161', '7154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7154', '112', '9031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9032', '1079', '1', 'Gameleira de Goiás', 'BR.29.5208152', 'ASCII:Gameleira De Goias;ID:6319162', '7155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7155', '112', '9032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5208152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9033', '1079', '1', 'Coruripe', 'BR.02.2702306', 'ASCII:Coruripe;ID:6319163', '7156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7156', '112', '9033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9034', '1079', '1', 'Paulista', 'BR.17.2510907', 'ASCII:Paulista;ID:6319164', '7157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7157', '112', '9034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9035', '1079', '1', 'São João', 'BR.18.4124806', 'ASCII:Sao Joao;ID:6319165', '7158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7158', '112', '9035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9036', '1079', '1', 'Apuiarés', 'BR.06.2300903', 'ASCII:Apuiares;ID:6319166', '7159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7159', '112', '9036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9037', '1079', '1', 'Quixelô', 'BR.06.2311355', 'ASCII:Quixelo;ID:6319167', '7160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7160', '112', '9037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9038', '1079', '1', 'Redenção', 'BR.06.2311603', 'ASCII:Redencao;ID:6319168', '7161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7161', '112', '9038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9039', '1079', '1', 'Canindé de São Francisco', 'BR.28.2801207', 'ASCII:Caninde De Sao Francisco;ID:6319169', '7162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7162', '112', '9039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2801207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9040', '1079', '1', 'São Luiz Gonzaga', 'BR.23.4318903', 'ASCII:Sao Luiz Gonzaga;ID:6319170', '7163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7163', '112', '9040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9041', '1079', '1', 'Caibaté', 'BR.23.4303301', 'ASCII:Caibate;ID:6319171', '7164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7164', '112', '9041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9042', '1079', '1', 'Rolador', 'BR.23.4315958', 'ASCII:Rolador;ID:6319172', '7165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7165', '112', '9042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9043', '1079', '1', 'Mato Queimado', 'BR.23.4312179', 'ASCII:Mato Queimado;ID:6319173', '7166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7166', '112', '9043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9044', '1079', '1', 'Westfalia', 'BR.23.4323770', 'ASCII:Westfalia;ID:6319174', '7167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7167', '112', '9044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9045', '1079', '1', 'Teutônia', 'BR.23.4321451', 'ASCII:Teutonia;ID:6319175', '7168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7168', '112', '9045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9046', '1079', '1', 'Terra de Areia', 'BR.23.4321436', 'ASCII:Terra De Areia;ID:6319176', '7169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7169', '112', '9046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9047', '1079', '1', 'Sobradinho', 'BR.23.4320701', 'ASCII:Sobradinho;ID:6319177', '7170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7170', '112', '9047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9048', '1079', '1', 'Serrinha', 'BR.05.2930501', 'ASCII:Serrinha;ID:6319178', '7171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7171', '112', '9048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9049', '1079', '1', 'Serra Nova Dourada', 'BR.14.5107883', 'ASCII:Serra Nova Dourada;ID:6319179', '7172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7172', '112', '9049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9050', '1079', '1', 'São Pedro das Missões', 'BR.23.4319364', 'ASCII:Sao Pedro Das Missoes;ID:6319180', '7173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7173', '112', '9050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9051', '1079', '1', 'São Miguel das Missões', 'BR.23.4319158', 'ASCII:Sao Miguel Das Missoes;ID:6319181', '7174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7174', '112', '9051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9052', '1079', '1', 'São Félix do Araguaia', 'BR.14.5107859', 'ASCII:Sao Felix Do Araguaia;ID:6319182', '7175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7175', '112', '9052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9053', '1079', '1', 'Santiago', 'BR.23.4317400', 'ASCII:Santiago;ID:6319183', '7176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7176', '112', '9053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9054', '1079', '1', 'Santa Margarida do Sul', 'BR.23.4316972', 'ASCII:Santa Margarida Do Sul;ID:6319184', '7177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7177', '112', '9054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316972» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9055', '1079', '1', 'Salvador do Sul', 'BR.23.4316501', 'ASCII:Salvador Do Sul;ID:6319185', '7178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7178', '112', '9055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9056', '1079', '1', 'Roca Sales', 'BR.23.4315800', 'ASCII:Roca Sales;ID:6319186', '7179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7179', '112', '9056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9057', '1079', '1', 'Ribeirão Cascalheira', 'BR.14.5107180', 'ASCII:Ribeirao Cascalheira;ID:6319187', '7180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7180', '112', '9057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9058', '1079', '1', 'Relvado', 'BR.23.4315453', 'ASCII:Relvado;ID:6319188', '7181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7181', '112', '9058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9059', '1079', '1', 'Quatro Irmãos', 'BR.23.4315313', 'ASCII:Quatro Irmaos;ID:6319189', '7182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7182', '112', '9059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9060', '1079', '1', 'Progresso', 'BR.23.4315156', 'ASCII:Progresso;ID:6319190', '7183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7183', '112', '9060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9061', '1079', '1', 'Ponte Preta', 'BR.23.4314787', 'ASCII:Ponte Preta;ID:6319191', '7184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7184', '112', '9061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314787» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9062', '1079', '1', 'Pinto Bandeira', 'BR.23.431453 ', 'ASCII:Pinto Bandeira;ID:6319192', '7185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7185', '112', '9062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.431453 » pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9063', '1079', '1', 'Paulo Bento', 'BR.23.4314134', 'ASCII:Paulo Bento;ID:6319193', '7186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7186', '112', '9063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314134» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9064', '1079', '1', 'Pau D''arco do Piauí', 'BR.20.2207793', 'ASCII:Pau D''Arco Do Piaui;ID:6319194', '7187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7187', '112', '9064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9065', '1079', '1', 'Palmeira das Missões', 'BR.23.4313706', 'ASCII:Palmeira Das Missoes;ID:6319195', '7188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7188', '112', '9065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9066', '1079', '1', 'Novo Santo Antônio', 'BR.14.5106315', 'ASCII:Novo Santo Antonio;ID:6319196', '7189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7189', '112', '9066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9067', '1079', '1', 'Nova Nazaré', 'BR.14.5106174', 'ASCII:Nova Nazare;ID:6319197', '7190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7190', '112', '9067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9068', '1079', '1', 'Nova Iguaçu', 'BR.21.3303500', 'ASCII:Nova Iguacu;ID:6319198', '7191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7191', '112', '9068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9069', '1079', '1', 'Nova Bréscia', 'BR.23.4313003', 'ASCII:Nova Brescia;ID:6319199', '7192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7192', '112', '9069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9070', '1079', '1', 'Montenegro', 'BR.23.4312401', 'ASCII:Montenegro;ID:6319200', '7193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7193', '112', '9070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9071', '1079', '1', 'Mesquita', 'BR.21.3302858', 'ASCII:Mesquita;ID:6319201', '7194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7194', '112', '9071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9072', '1079', '1', 'Maratá', 'BR.23.4311791', 'ASCII:Marata;ID:6319202', '7195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7195', '112', '9072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311791» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9073', '1079', '1', 'Lajeado', 'BR.23.4311403', 'ASCII:Lajeado;ID:6319203', '7196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7196', '112', '9073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9074', '1079', '1', 'Lagoa Bonita do Sul', 'BR.23.4311239', 'ASCII:Lagoa Bonita Do Sul;ID:6319204', '7197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7197', '112', '9074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9075', '1079', '1', 'Jequiá da Praia', 'BR.02.2703759', 'ASCII:Jequia Da Praia;ID:6319205', '7198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7198', '112', '9075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9076', '1079', '1', 'Jacutinga', 'BR.23.4310900', 'ASCII:Jacutinga;ID:6319206', '7199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7199', '112', '9076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9077', '1079', '1', 'Itati', 'BR.23.4310652', 'ASCII:Itati;ID:6319207', '7200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7200', '112', '9077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9078', '1079', '1', 'Imigrante', 'BR.23.4310363', 'ASCII:Imigrante;ID:6319208', '7201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7201', '112', '9078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310363» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9079', '1079', '1', 'Garibaldi', 'BR.23.4308607', 'ASCII:Garibaldi;ID:6319209', '7202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7202', '112', '9079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9080', '1079', '1', 'Forquetinha', 'BR.23.4308433', 'ASCII:Forquetinha;ID:6319210', '7203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7203', '112', '9080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9081', '1079', '1', 'Erechim', 'BR.23.4307005', 'ASCII:Erechim;ID:6319211', '7204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7204', '112', '9081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9082', '1079', '1', 'Cruzaltense', 'BR.23.4306130', 'ASCII:Cruzaltense;ID:6319212', '7205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7205', '112', '9082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9083', '1079', '1', 'Coronel Pilar', 'BR.23.4305934', 'ASCII:Coronel Pilar;ID:6319213', '7206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7206', '112', '9083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9084', '1079', '1', 'Coqueiro Baixo', 'BR.23.4305835', 'ASCII:Coqueiro Baixo;ID:6319214', '7207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7207', '112', '9084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9085', '1079', '1', 'Cocalinho', 'BR.14.5103106', 'ASCII:Cocalinho;ID:6319215', '7208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7208', '112', '9085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9086', '1079', '1', 'Canudos do Vale', 'BR.23.4304614', 'ASCII:Canudos Do Vale;ID:6319216', '7209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7209', '112', '9086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9087', '1079', '1', 'Campinas do Sul', 'BR.23.4303806', 'ASCII:Campinas Do Sul;ID:6319217', '7210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7210', '112', '9087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9088', '1079', '1', 'Bom Jesus do Araguaia', 'BR.14.5101852', 'ASCII:Bom Jesus Do Araguaia;ID:6319218', '7211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7211', '112', '9088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5101852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9089', '1079', '1', 'Bento Gonçalves', 'BR.23.4302105', 'ASCII:Bento Goncalves;ID:6319219', '7212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7212', '112', '9089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9090', '1079', '1', 'Barrocas', 'BR.05.2903276', 'ASCII:Barrocas;ID:6319220', '7213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7213', '112', '9090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9091', '1079', '1', 'Altos', 'BR.20.2200400', 'ASCII:Altos;ID:6319221', '7214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7214', '112', '9091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9092', '1079', '1', 'Alto Boa Vista', 'BR.14.5100359', 'ASCII:Alto Boa Vista;ID:6319222', '7215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7215', '112', '9092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5100359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9093', '1079', '1', 'Água Boa', 'BR.14.5100201', 'ASCII:Agua Boa;ID:6319223', '7216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7216', '112', '9093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5100201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9094', '1079', '1', 'Aceguá', 'BR.23.4300034', 'ASCII:Acegua;ID:6319224', '7217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7217', '112', '9094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9095', '1079', '1', 'Mirassol d''Oeste', 'BR.14.5105622', 'ASCII:Mirassol D''Oeste;ID:6319225', '7218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7218', '112', '9095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9096', '1079', '1', 'Lambari d''Oeste', 'BR.14.5105234', 'ASCII:Lambari D''Oeste;ID:6319226', '7219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7219', '112', '9096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9097', '1079', '1', 'Curvelândia', 'BR.14.5103437', 'ASCII:Curvelandia;ID:6319227', '7220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7220', '112', '9097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9098', '1079', '1', 'Cáceres', 'BR.14.5102504', 'ASCII:Caceres;ID:6319228', '7221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7221', '112', '9098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5102504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9099', '1079', '1', 'Alta Floresta d''Oeste', 'BR.24.1100015', 'ASCII:Alta Floresta D''Oeste;ID:6319229', '7222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7222', '112', '9099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9100', '1079', '1', 'Ariquemes', 'BR.24.1100023', 'ASCII:Ariquemes;ID:6319230', '7223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7223', '112', '9100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9101', '1079', '1', 'Cabixi', 'BR.24.1100031', 'ASCII:Cabixi;ID:6319231', '7224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7224', '112', '9101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9102', '1079', '1', 'Cacoal', 'BR.24.1100049', 'ASCII:Cacoal;ID:6319232', '7225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7225', '112', '9102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9103', '1079', '1', 'Cerejeiras', 'BR.24.1100056', 'ASCII:Cerejeiras;ID:6319233', '7226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7226', '112', '9103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9104', '1079', '1', 'Colorado do Oeste', 'BR.24.1100064', 'ASCII:Colorado Do Oeste;ID:6319234', '7227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7227', '112', '9104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9105', '1079', '1', 'Corumbiara', 'BR.24.1100072', 'ASCII:Corumbiara;ID:6319235', '7228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7228', '112', '9105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9106', '1079', '1', 'Costa Marques', 'BR.24.1100080', 'ASCII:Costa Marques;ID:6319236', '7229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7229', '112', '9106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9107', '1079', '1', 'Espigão d''Oeste', 'BR.24.1100098', 'ASCII:Espigao D''Oeste;ID:6319237', '7230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7230', '112', '9107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9108', '1079', '1', 'Ji-Paraná', 'BR.24.1100122', 'ASCII:Ji-Parana;ID:6319238', '7231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7231', '112', '9108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9109', '1079', '1', 'Machadinho d''Oeste', 'BR.24.1100130', 'ASCII:Machadinho D''Oeste;ID:6319239', '7232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7232', '112', '9109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9110', '1079', '1', 'Nova Brasilândia d''Oeste', 'BR.24.1100148', 'ASCII:Nova Brasilandia D''Oeste;ID:6319240', '7233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7233', '112', '9110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9111', '1079', '1', 'Ouro Preto do Oeste', 'BR.24.1100155', 'ASCII:Ouro Preto Do Oeste;ID:6319241', '7234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7234', '112', '9111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9112', '1079', '1', 'Pimenta Bueno', 'BR.24.1100189', 'ASCII:Pimenta Bueno;ID:6319242', '7235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7235', '112', '9112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9113', '1079', '1', 'Porto Velho', 'BR.24.1100205', 'ASCII:Porto Velho;ID:6319243', '7236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7236', '112', '9113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9114', '1079', '1', 'Presidente Médici', 'BR.24.1100254', 'ASCII:Presidente Medici;ID:6319244', '7237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7237', '112', '9114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9115', '1079', '1', 'Rio Crespo', 'BR.24.1100262', 'ASCII:Rio Crespo;ID:6319245', '7238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7238', '112', '9115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9116', '1079', '1', 'Rolim de Moura', 'BR.24.1100288', 'ASCII:Rolim De Moura;ID:6319246', '7239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7239', '112', '9116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9117', '1079', '1', 'Santa Luzia d''Oeste', 'BR.24.1100296', 'ASCII:Santa Luzia D''Oeste;ID:6319247', '7240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7240', '112', '9117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9118', '1079', '1', 'Vilhena', 'BR.24.1100304', 'ASCII:Vilhena;ID:6319248', '7241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7241', '112', '9118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9119', '1079', '1', 'São Miguel do Guaporé', 'BR.24.1100320', 'ASCII:Sao Miguel Do Guapore;ID:6319249', '7242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7242', '112', '9119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9120', '1079', '1', 'Alvorada d''Oeste', 'BR.24.1100346', 'ASCII:Alvorada D''Oeste;ID:6319250', '7243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7243', '112', '9120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9121', '1079', '1', 'Alto Alegre dos Parecis', 'BR.24.1100379', 'ASCII:Alto Alegre Dos Parecis;ID:6319251', '7244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7244', '112', '9121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9122', '1079', '1', 'Alto Paraíso', 'BR.24.1100403', 'ASCII:Alto Paraiso;ID:6319252', '7245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7245', '112', '9122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9123', '1079', '1', 'Buritis', 'BR.24.1100452', 'ASCII:Buritis;ID:6319253', '7246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7246', '112', '9123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9124', '1079', '1', 'Novo Horizonte do Oeste', 'BR.24.1100502', 'ASCII:Novo Horizonte Do Oeste;ID:6319254', '7247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7247', '112', '9124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9125', '1079', '1', 'Cacaulândia', 'BR.24.1100601', 'ASCII:Cacaulandia;ID:6319255', '7248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7248', '112', '9125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9126', '1079', '1', 'Campo Novo de Rondônia', 'BR.24.1100700', 'ASCII:Campo Novo De Rondonia;ID:6319256', '7249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7249', '112', '9126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9127', '1079', '1', 'Candeias do Jamari', 'BR.24.1100809', 'ASCII:Candeias Do Jamari;ID:6319257', '7250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7250', '112', '9127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9128', '1079', '1', 'Castanheiras', 'BR.24.1100908', 'ASCII:Castanheiras;ID:6319258', '7251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7251', '112', '9128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9129', '1079', '1', 'Chupinguaia', 'BR.24.1100924', 'ASCII:Chupinguaia;ID:6319259', '7252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7252', '112', '9129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9130', '1079', '1', 'Cujubim', 'BR.24.1100940', 'ASCII:Cujubim;ID:6319260', '7253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7253', '112', '9130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9131', '1079', '1', 'Itapuã do Oeste', 'BR.24.1101104', 'ASCII:Jamari;ID:6319261', '7254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7254', '112', '9131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9132', '1079', '1', 'Ministro Andreazza', 'BR.24.1101203', 'ASCII:Ministro Andreazza;ID:6319262', '7255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7255', '112', '9132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9133', '1079', '1', 'Monte Negro', 'BR.24.1101401', 'ASCII:Monte Negro;ID:6319263', '7256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7256', '112', '9133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9134', '1079', '1', 'Nova União', 'BR.24.1101435', 'ASCII:Nova Uniao;ID:6319264', '7257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7257', '112', '9134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9135', '1079', '1', 'Parecis', 'BR.24.1101450', 'ASCII:Parecis;ID:6319265', '7258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7258', '112', '9135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9136', '1079', '1', 'Pimenteiras do Oeste', 'BR.24.1101468', 'ASCII:Pimenteiras Do Oeste;ID:6319266', '7259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7259', '112', '9136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9137', '1079', '1', 'Primavera de Rondônia', 'BR.24.1101476', 'ASCII:Primavera De Rondonia;ID:6319267', '7260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7260', '112', '9137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9138', '1079', '1', 'São Felipe d''Oeste', 'BR.24.1101484', 'ASCII:Sao Felipe D''Oeste;ID:6319268', '7261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7261', '112', '9138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9139', '1079', '1', 'São Francisco do Guaporé', 'BR.24.1101492', 'ASCII:Sao Francisco Do Guapore;ID:6319269', '7262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7262', '112', '9139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9140', '1079', '1', 'Seringueiras', 'BR.24.1101500', 'ASCII:Seringueiras;ID:6319270', '7263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7263', '112', '9140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9141', '1079', '1', 'Teixeirópolis', 'BR.24.1101559', 'ASCII:Teixeiropolis;ID:6319271', '7264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7264', '112', '9141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9142', '1079', '1', 'Theobroma', 'BR.24.1101609', 'ASCII:Theobroma;ID:6319272', '7265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7265', '112', '9142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9143', '1079', '1', 'Urupá', 'BR.24.1101708', 'ASCII:Urupa;ID:6319273', '7266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7266', '112', '9143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9144', '1079', '1', 'Vale do Anari', 'BR.24.1101757', 'ASCII:Vale Do Anari;ID:6319274', '7267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7267', '112', '9144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9145', '1079', '1', 'Vale do Paraíso', 'BR.24.1101807', 'ASCII:Vale Do Paraiso;ID:6319275', '7268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7268', '112', '9145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9146', '1079', '1', 'Acrelândia', 'BR.01.1200013', 'ASCII:Acrelandia;ID:6319276', '7269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7269', '112', '9146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9147', '1079', '1', 'Assis Brasil', 'BR.01.1200054', 'ASCII:Assis Brasil;ID:6319277', '7270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7270', '112', '9147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9148', '1079', '1', 'Brasiléia', 'BR.01.1200104', 'ASCII:Brasileia;ID:6319278', '7271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7271', '112', '9148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9149', '1079', '1', 'Bujari', 'BR.01.1200138', 'ASCII:Bujari;ID:6319279', '7272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7272', '112', '9149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200138» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9150', '1079', '1', 'Capixaba', 'BR.01.1200179', 'ASCII:Capixaba;ID:6319280', '7273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7273', '112', '9150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9151', '1079', '1', 'Cruzeiro do Sul', 'BR.01.1200203', 'ASCII:Cruzeiro Do Sul;ID:6319281', '7274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7274', '112', '9151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9152', '1079', '1', 'Epitaciolândia', 'BR.01.1200252', 'ASCII:Epitaciolandia;ID:6319282', '7275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7275', '112', '9152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9153', '1079', '1', 'Jordão', 'BR.01.1200328', 'ASCII:Jordao;ID:6319283', '7276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7276', '112', '9153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9154', '1079', '1', 'Mâncio Lima', 'BR.01.1200336', 'ASCII:Mancio Lima;ID:6319284', '7277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7277', '112', '9154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9155', '1079', '1', 'Marechal Thaumaturgo', 'BR.01.1200351', 'ASCII:Marechal Thaumaturgo;ID:6319285', '7278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7278', '112', '9155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9156', '1079', '1', 'Plácido de Castro', 'BR.01.1200385', 'ASCII:Placido De Castro;ID:6319286', '7279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7279', '112', '9156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9157', '1079', '1', 'Porto Walter', 'BR.01.1200393', 'ASCII:Porto Walter;ID:6319287', '7280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7280', '112', '9157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200393» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9158', '1079', '1', 'Rio Branco', 'BR.01.1200401', 'ASCII:Rio Branco;ID:6319288', '7281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7281', '112', '9158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9159', '1079', '1', 'Rodrigues Alves', 'BR.01.1200427', 'ASCII:Rodrigues Alves;ID:6319289', '7282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7282', '112', '9159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9160', '1079', '1', 'Senador Guiomard', 'BR.01.1200450', 'ASCII:Senador Guiomard;ID:6319290', '7283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7283', '112', '9160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9161', '1079', '1', 'Tarauacá', 'BR.01.1200609', 'ASCII:Tarauaca;ID:6319291', '7284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7284', '112', '9161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9162', '1079', '1', 'Xapuri', 'BR.01.1200708', 'ASCII:Xapuri;ID:6319292', '7285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7285', '112', '9162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9163', '1079', '1', 'Porto Acre', 'BR.01.1200807', 'ASCII:Porto Acre;ID:6319293', '7286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7286', '112', '9163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9164', '1079', '1', 'Alvarães', 'BR.04.1300029', 'ASCII:Alvaraes;ID:6319294', '7287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7287', '112', '9164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9165', '1079', '1', 'Amaturá', 'BR.04.1300060', 'ASCII:Amatura;ID:6319295', '7288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7288', '112', '9165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9166', '1079', '1', 'Anamã', 'BR.04.1300086', 'ASCII:Anama;ID:6319296', '7289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7289', '112', '9166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9167', '1079', '1', 'Anori', 'BR.04.1300102', 'ASCII:Anori;ID:6319297', '7290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7290', '112', '9167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9168', '1079', '1', 'Apuí', 'BR.04.1300144', 'ASCII:Apui;ID:6319298', '7291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7291', '112', '9168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9169', '1079', '1', 'Atalaia do Norte', 'BR.04.1300201', 'ASCII:Atalaia Do Norte;ID:6319299', '7292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7292', '112', '9169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9170', '1079', '1', 'Autazes', 'BR.04.1300300', 'ASCII:Autazes;ID:6319300', '7293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7293', '112', '9170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9171', '1079', '1', 'Barcelos', 'BR.04.1300409', 'ASCII:Barcelos;ID:6319301', '7294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7294', '112', '9171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9172', '1079', '1', 'Barreirinha', 'BR.04.1300508', 'ASCII:Barreirinha;ID:6319302', '7295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7295', '112', '9172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9173', '1079', '1', 'Benjamin Constant', 'BR.04.1300607', 'ASCII:Benjamin Constant;ID:6319303', '7296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7296', '112', '9173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9174', '1079', '1', 'Beruri', 'BR.04.1300631', 'ASCII:Beruri;ID:6319304', '7297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7297', '112', '9174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9175', '1079', '1', 'Boa Vista do Ramos', 'BR.04.1300680', 'ASCII:Boa Vista Do Ramos;ID:6319305', '7298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7298', '112', '9175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9176', '1079', '1', 'Boca do Acre', 'BR.04.1300706', 'ASCII:Boca Do Acre;ID:6319306', '7299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7299', '112', '9176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9177', '1079', '1', 'Borba', 'BR.04.1300805', 'ASCII:Borba;ID:6319307', '7300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7300', '112', '9177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9178', '1079', '1', 'Caapiranga', 'BR.04.1300839', 'ASCII:Caapiranga;ID:6319308', '7301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7301', '112', '9178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9179', '1079', '1', 'Carauari', 'BR.04.1301001', 'ASCII:Carauari;ID:6319309', '7302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7302', '112', '9179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9180', '1079', '1', 'Careiro', 'BR.04.1301100', 'ASCII:Careiro;ID:6319310', '7303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7303', '112', '9180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9181', '1079', '1', 'Careiro da Várzea', 'BR.04.1301159', 'ASCII:Careiro Da Varzea;ID:6319311', '7304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7304', '112', '9181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9182', '1079', '1', 'Codajás', 'BR.04.1301308', 'ASCII:Codajas;ID:6319312', '7305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7305', '112', '9182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9183', '1079', '1', 'Eirunepé', 'BR.04.1301407', 'ASCII:Eirunepe;ID:6319313', '7306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7306', '112', '9183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9184', '1079', '1', 'Envira', 'BR.04.1301506', 'ASCII:Envira;ID:6319314', '7307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7307', '112', '9184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9185', '1079', '1', 'Fonte Boa', 'BR.04.1301605', 'ASCII:Fonte Boa;ID:6319315', '7308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7308', '112', '9185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9186', '1079', '1', 'Guajará', 'BR.04.1301654', 'ASCII:Guajara;ID:6319316', '7309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7309', '112', '9186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9187', '1079', '1', 'Humaitá', 'BR.04.1301704', 'ASCII:Humaita;ID:6319317', '7310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7310', '112', '9187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9188', '1079', '1', 'Ipixuna', 'BR.04.1301803', 'ASCII:Ipixuna;ID:6319318', '7311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7311', '112', '9188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9189', '1079', '1', 'Iranduba', 'BR.04.1301852', 'ASCII:Iranduba;ID:6319319', '7312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7312', '112', '9189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9190', '1079', '1', 'Itacoatiara', 'BR.04.1301902', 'ASCII:Itacoatiara;ID:6319320', '7313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7313', '112', '9190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9191', '1079', '1', 'Itamarati', 'BR.04.1301951', 'ASCII:Itamarati;ID:6319321', '7314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7314', '112', '9191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9192', '1079', '1', 'Itapiranga', 'BR.04.1302009', 'ASCII:Itapiranga;ID:6319322', '7315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7315', '112', '9192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9193', '1079', '1', 'Japurá', 'BR.04.1302108', 'ASCII:Japura;ID:6319323', '7316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7316', '112', '9193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9194', '1079', '1', 'Juruá', 'BR.04.1302207', 'ASCII:Jurua;ID:6319324', '7317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7317', '112', '9194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9195', '1079', '1', 'Jutaí', 'BR.04.1302306', 'ASCII:Jutai;ID:6319325', '7318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7318', '112', '9195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9196', '1079', '1', 'Manacapuru', 'BR.04.1302504', 'ASCII:Manacapuru;ID:6319326', '7319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7319', '112', '9196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9197', '1079', '1', 'Manaquiri', 'BR.04.1302553', 'ASCII:Manaquiri;ID:6319327', '7320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7320', '112', '9197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9198', '1079', '1', 'Manaus', 'BR.04.1302603', 'ASCII:Manaus;ID:6319328', '7321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7321', '112', '9198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9199', '1079', '1', 'Manicoré', 'BR.04.1302702', 'ASCII:Manicore;ID:6319329', '7322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7322', '112', '9199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9200', '1079', '1', 'Maraã', 'BR.04.1302801', 'ASCII:Maraa;ID:6319330', '7323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7323', '112', '9200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9201', '1079', '1', 'Maués', 'BR.04.1302900', 'ASCII:Maues;ID:6319331', '7324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7324', '112', '9201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1302900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9202', '1079', '1', 'Nhamundá', 'BR.04.1303007', 'ASCII:Nhamunda;ID:6319332', '7325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7325', '112', '9202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9203', '1079', '1', 'Nova Olinda do Norte', 'BR.04.1303106', 'ASCII:Nova Olinda Do Norte;ID:6319333', '7326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7326', '112', '9203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9204', '1079', '1', 'Novo Airão', 'BR.04.1303205', 'ASCII:Novo Airao;ID:6319334', '7327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7327', '112', '9204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9205', '1079', '1', 'Novo Aripuanã', 'BR.04.1303304', 'ASCII:Novo Aripuana;ID:6319335', '7328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7328', '112', '9205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9206', '1079', '1', 'Parintins', 'BR.04.1303403', 'ASCII:Parintins;ID:6319336', '7329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7329', '112', '9206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9207', '1079', '1', 'Pauini', 'BR.04.1303502', 'ASCII:Pauini;ID:6319337', '7330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7330', '112', '9207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9208', '1079', '1', 'Presidente Figueiredo', 'BR.04.1303536', 'ASCII:Presidente Figueiredo;ID:6319338', '7331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7331', '112', '9208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9209', '1079', '1', 'Rio Preto da Eva', 'BR.04.1303569', 'ASCII:Rio Preto Da Eva;ID:6319339', '7332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7332', '112', '9209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9210', '1079', '1', 'Santa Isabel do Rio Negro', 'BR.04.1303601', 'ASCII:Santa Isabel Do Rio Negro;ID:6319340', '7333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7333', '112', '9210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9211', '1079', '1', 'São Gabriel da Cachoeira', 'BR.04.1303809', 'ASCII:Sao Gabriel Da Cachoeira;ID:6319341', '7334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7334', '112', '9211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9212', '1079', '1', 'São Paulo de Olivença', 'BR.04.1303908', 'ASCII:Sao Paulo De Olivenca;ID:6319342', '7335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7335', '112', '9212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9213', '1079', '1', 'São Sebastião do Uatumã', 'BR.04.1303957', 'ASCII:Sao Sebastiao Do Uatuma;ID:6319343', '7336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7336', '112', '9213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1303957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9214', '1079', '1', 'Silves', 'BR.04.1304005', 'ASCII:Silves;ID:6319344', '7337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7337', '112', '9214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1304005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9215', '1079', '1', 'Tabatinga', 'BR.04.1304062', 'ASCII:Tabatinga;ID:6319345', '7338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7338', '112', '9215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1304062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9216', '1079', '1', 'Tefé', 'BR.04.1304203', 'ASCII:Tefe;ID:6319346', '7339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7339', '112', '9216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1304203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9217', '1079', '1', 'Tonantins', 'BR.04.1304237', 'ASCII:Tonantins;ID:6319347', '7340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7340', '112', '9217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1304237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9218', '1079', '1', 'Uarini', 'BR.04.1304260', 'ASCII:Uarini;ID:6319348', '7341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7341', '112', '9218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1304260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9219', '1079', '1', 'Urucará', 'BR.04.1304302', 'ASCII:Urucara;ID:6319349', '7342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7342', '112', '9219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1304302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9220', '1079', '1', 'Urucurituba', 'BR.04.1304401', 'ASCII:Urucurituba;ID:6319350', '7343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7343', '112', '9220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1304401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9221', '1079', '1', 'Amajari', 'BR.25.1400027', 'ASCII:Amajari;ID:6319351', '7344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7344', '112', '9221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9222', '1079', '1', 'Boa Vista', 'BR.25.1400100', 'ASCII:Boa Vista;ID:6319352', '7345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7345', '112', '9222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9223', '1079', '1', 'Bonfim', 'BR.25.1400159', 'ASCII:Bonfim;ID:6319353', '7346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7346', '112', '9223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9224', '1079', '1', 'Cantá', 'BR.25.1400175', 'ASCII:Canta;ID:6319354', '7347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7347', '112', '9224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9225', '1079', '1', 'Caroebe', 'BR.25.1400233', 'ASCII:Caroebe;ID:6319355', '7348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7348', '112', '9225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9226', '1079', '1', 'Mucajaí', 'BR.25.1400308', 'ASCII:Mucajai;ID:6319356', '7349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7349', '112', '9226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9227', '1079', '1', 'Normandia', 'BR.25.1400407', 'ASCII:Normandia;ID:6319357', '7350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7350', '112', '9227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9228', '1079', '1', 'Pacaraima', 'BR.25.1400456', 'ASCII:Pacaraima;ID:6319358', '7351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7351', '112', '9228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9229', '1079', '1', 'São João da Baliza', 'BR.25.1400506', 'ASCII:Sao Joao Da Baliza;ID:6319359', '7352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7352', '112', '9229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9230', '1079', '1', 'São Luiz', 'BR.25.1400605', 'ASCII:Sao Luiz;ID:6319360', '7353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7353', '112', '9230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9231', '1079', '1', 'Uiramutã', 'BR.25.1400704', 'ASCII:Uiramuta;ID:6319361', '7354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7354', '112', '9231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9232', '1079', '1', 'Abaetetuba', 'BR.16.1500107', 'ASCII:Abaetetuba;ID:6319362', '7355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7355', '112', '9232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9233', '1079', '1', 'Abel Figueiredo', 'BR.16.1500131', 'ASCII:Abel Figueiredo;ID:6319363', '7356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7356', '112', '9233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9234', '1079', '1', 'Acará', 'BR.16.1500206', 'ASCII:Acara;ID:6319364', '7357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7357', '112', '9234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9235', '1079', '1', 'Afuá', 'BR.16.1500305', 'ASCII:Afua;ID:6319365', '7358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7358', '112', '9235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9236', '1079', '1', 'Água Azul do Norte', 'BR.16.1500347', 'ASCII:Agua Azul Do Norte;ID:6319366', '7359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7359', '112', '9236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9237', '1079', '1', 'Alenquer', 'BR.16.1500404', 'ASCII:Alenquer;ID:6319367', '7360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7360', '112', '9237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9238', '1079', '1', 'Anajás', 'BR.16.1500701', 'ASCII:Anajas;ID:6319368', '7361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7361', '112', '9238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9239', '1079', '1', 'Ananindeua', 'BR.16.1500800', 'ASCII:Ananindeua;ID:6319369', '7362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7362', '112', '9239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9240', '1079', '1', 'Anapu', 'BR.16.1500859', 'ASCII:Anapu;ID:6319370', '7363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7363', '112', '9240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9241', '1079', '1', 'Augusto Corrêa', 'BR.16.1500909', 'ASCII:Augusto Correa;ID:6319371', '7364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7364', '112', '9241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9242', '1079', '1', 'Aurora do Pará', 'BR.16.1500958', 'ASCII:Aurora Do Para;ID:6319372', '7365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7365', '112', '9242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9243', '1079', '1', 'Bagre', 'BR.16.1501105', 'ASCII:Bagre;ID:6319373', '7366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7366', '112', '9243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9244', '1079', '1', 'Baião', 'BR.16.1501204', 'ASCII:Baiao;ID:6319374', '7367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7367', '112', '9244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9245', '1079', '1', 'Bannach', 'BR.16.1501253', 'ASCII:Bannach;ID:6319375', '7368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7368', '112', '9245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9246', '1079', '1', 'Barcarena', 'BR.16.1501303', 'ASCII:Barcarena;ID:6319376', '7369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7369', '112', '9246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9247', '1079', '1', 'Belém', 'BR.16.1501402', 'ASCII:Belem;ID:6319377', '7370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7370', '112', '9247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9248', '1079', '1', 'Belterra', 'BR.16.1501451', 'ASCII:Belterra;ID:6319378', '7371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7371', '112', '9248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9249', '1079', '1', 'Benevides', 'BR.16.1501501', 'ASCII:Benevides;ID:6319379', '7372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7372', '112', '9249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9250', '1079', '1', 'Bom Jesus do Tocantins', 'BR.16.1501576', 'ASCII:Bom Jesus Do Tocantins;ID:6319380', '7373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7373', '112', '9250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9251', '1079', '1', 'Bonito', 'BR.16.1501600', 'ASCII:Bonito;ID:6319381', '7374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7374', '112', '9251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9252', '1079', '1', 'Brasil Novo', 'BR.16.1501725', 'ASCII:Brasil Novo;ID:6319382', '7375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7375', '112', '9252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9253', '1079', '1', 'Brejo Grande do Araguaia', 'BR.16.1501758', 'ASCII:Brejo Grande Do Araguaia;ID:6319383', '7376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7376', '112', '9253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9254', '1079', '1', 'Breu Branco', 'BR.16.1501782', 'ASCII:Breu Branco;ID:6319384', '7377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7377', '112', '9254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9255', '1079', '1', 'Breves', 'BR.16.1501808', 'ASCII:Breves;ID:6319385', '7378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7378', '112', '9255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9256', '1079', '1', 'Bujaru', 'BR.16.1501907', 'ASCII:Bujaru;ID:6319386', '7379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7379', '112', '9256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9257', '1079', '1', 'Cachoeira do Piriá', 'BR.16.1501956', 'ASCII:Cachoeira Do Piria;ID:6319387', '7380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7380', '112', '9257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9258', '1079', '1', 'Cachoeira do Arari', 'BR.16.1502004', 'ASCII:Cachoeira Do Arari;ID:6319388', '7381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7381', '112', '9258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9259', '1079', '1', 'Cametá', 'BR.16.1502103', 'ASCII:Cameta;ID:6319389', '7382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7382', '112', '9259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9260', '1079', '1', 'Canaã dos Carajás', 'BR.16.1502152', 'ASCII:Canaa Dos Carajas;ID:6319390', '7383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7383', '112', '9260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9261', '1079', '1', 'Capanema', 'BR.16.1502202', 'ASCII:Capanema;ID:6319391', '7384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7384', '112', '9261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9262', '1079', '1', 'Capitão Poço', 'BR.16.1502301', 'ASCII:Capitao Poco;ID:6319392', '7385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7385', '112', '9262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9263', '1079', '1', 'Chaves', 'BR.16.1502509', 'ASCII:Chaves;ID:6319393', '7386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7386', '112', '9263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9264', '1079', '1', 'Colares', 'BR.16.1502608', 'ASCII:Colares;ID:6319394', '7387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7387', '112', '9264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9265', '1079', '1', 'Conceição do Araguaia', 'BR.16.1502707', 'ASCII:Conceicao Do Araguaia;ID:6319395', '7388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7388', '112', '9265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9266', '1079', '1', 'Concórdia do Pará', 'BR.16.1502756', 'ASCII:Concordia Do Para;ID:6319396', '7389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7389', '112', '9266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9267', '1079', '1', 'Cumaru do Norte', 'BR.16.1502764', 'ASCII:Cumaru Do Norte;ID:6319397', '7390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7390', '112', '9267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9268', '1079', '1', 'Curionópolis', 'BR.16.1502772', 'ASCII:Curionopolis;ID:6319398', '7391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7391', '112', '9268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9269', '1079', '1', 'Curralinho', 'BR.16.1502806', 'ASCII:Curralinho;ID:6319399', '7392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7392', '112', '9269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9270', '1079', '1', 'Curuá', 'BR.16.1502855', 'ASCII:Curua;ID:6319400', '7393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7393', '112', '9270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9271', '1079', '1', 'Curuçá', 'BR.16.1502905', 'ASCII:Curuca;ID:6319401', '7394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7394', '112', '9271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9272', '1079', '1', 'Dom Eliseu', 'BR.16.1502939', 'ASCII:Dom Eliseu;ID:6319402', '7395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7395', '112', '9272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9273', '1079', '1', 'Eldorado dos Carajás', 'BR.16.1502954', 'ASCII:Eldorado Dos Carajas;ID:6319403', '7396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7396', '112', '9273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1502954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9274', '1079', '1', 'Faro', 'BR.16.1503002', 'ASCII:Faro;ID:6319404', '7397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7397', '112', '9274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9275', '1079', '1', 'Floresta do Araguaia', 'BR.16.1503044', 'ASCII:Floresta Do Araguaia;ID:6319405', '7398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7398', '112', '9275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9276', '1079', '1', 'Garrafão do Norte', 'BR.16.1503077', 'ASCII:Garrafao Do Norte;ID:6319406', '7399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7399', '112', '9276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9277', '1079', '1', 'Goianésia do Pará', 'BR.16.1503093', 'ASCII:Goianesia Do Para;ID:6319407', '7400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7400', '112', '9277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9278', '1079', '1', 'Gurupá', 'BR.16.1503101', 'ASCII:Gurupa;ID:6319408', '7401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7401', '112', '9278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9279', '1079', '1', 'Igarapé-Açu', 'BR.16.1503200', 'ASCII:Igarape-Acu;ID:6319409', '7402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7402', '112', '9279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9280', '1079', '1', 'Igarapé-Miri', 'BR.16.1503309', 'ASCII:Igarape-Miri;ID:6319410', '7403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7403', '112', '9280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9281', '1079', '1', 'Ipixuna do Pará', 'BR.16.1503457', 'ASCII:Ipixuna Do Para;ID:6319411', '7404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7404', '112', '9281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9282', '1079', '1', 'Irituia', 'BR.16.1503507', 'ASCII:Irituia;ID:6319412', '7405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7405', '112', '9282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9283', '1079', '1', 'Itupiranga', 'BR.16.1503705', 'ASCII:Itupiranga;ID:6319413', '7406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7406', '112', '9283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9284', '1079', '1', 'Jacareacanga', 'BR.16.1503754', 'ASCII:Jacareacanga;ID:6319414', '7407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7407', '112', '9284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9285', '1079', '1', 'Jacundá', 'BR.16.1503804', 'ASCII:Jacunda;ID:6319415', '7408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7408', '112', '9285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9286', '1079', '1', 'Juruti', 'BR.16.1503903', 'ASCII:Juruti;ID:6319416', '7409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7409', '112', '9286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9287', '1079', '1', 'Limoeiro do Ajuru', 'BR.16.1504000', 'ASCII:Limoeiro Do Ajuru;ID:6319417', '7410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7410', '112', '9287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9288', '1079', '1', 'Mãe do Rio', 'BR.16.1504059', 'ASCII:Mae Do Rio;ID:6319418', '7411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7411', '112', '9288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9289', '1079', '1', 'Magalhães Barata', 'BR.16.1504109', 'ASCII:Magalhaes Barata;ID:6319419', '7412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7412', '112', '9289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9290', '1079', '1', 'Marabá', 'BR.16.1504208', 'ASCII:Maraba;ID:6319420', '7413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7413', '112', '9290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9291', '1079', '1', 'Maracanã', 'BR.16.1504307', 'ASCII:Maracana;ID:6319421', '7414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7414', '112', '9291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9292', '1079', '1', 'Marapanim', 'BR.16.1504406', 'ASCII:Marapanim;ID:6319422', '7415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7415', '112', '9292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9293', '1079', '1', 'Marituba', 'BR.16.1504422', 'ASCII:Marituba;ID:6319423', '7416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7416', '112', '9293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9294', '1079', '1', 'Medicilândia', 'BR.16.1504455', 'ASCII:Medicilandia;ID:6319424', '7417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7417', '112', '9294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9295', '1079', '1', 'Melgaço', 'BR.16.1504505', 'ASCII:Melgaco;ID:6319425', '7418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7418', '112', '9295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9296', '1079', '1', 'Mocajuba', 'BR.16.1504604', 'ASCII:Mocajuba;ID:6319426', '7419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7419', '112', '9296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9297', '1079', '1', 'Moju', 'BR.16.1504703', 'ASCII:Moju;ID:6319427', '7420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7420', '112', '9297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9298', '1079', '1', 'Monte Alegre', 'BR.16.1504802', 'ASCII:Monte Alegre;ID:6319428', '7421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7421', '112', '9298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9299', '1079', '1', 'Muaná', 'BR.16.1504901', 'ASCII:Muana;ID:6319429', '7422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7422', '112', '9299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9300', '1079', '1', 'Nova Esperança do Piriá', 'BR.16.1504950', 'ASCII:Nova Esperanca Do Piria;ID:6319430', '7423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7423', '112', '9300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9301', '1079', '1', 'Nova Ipixuna', 'BR.16.1504976', 'ASCII:Nova Ipixuna;ID:6319431', '7424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7424', '112', '9301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1504976» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9302', '1079', '1', 'Nova Timboteua', 'BR.16.1505007', 'ASCII:Nova Timboteua;ID:6319432', '7425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7425', '112', '9302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9303', '1079', '1', 'Novo Progresso', 'BR.16.1505031', 'ASCII:Novo Progresso;ID:6319433', '7426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7426', '112', '9303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9304', '1079', '1', 'Novo Repartimento', 'BR.16.1505064', 'ASCII:Novo Repartimento;ID:6319434', '7427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7427', '112', '9304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9305', '1079', '1', 'Óbidos', 'BR.16.1505106', 'ASCII:Obidos;ID:6319435', '7428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7428', '112', '9305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9306', '1079', '1', 'Oeiras do Pará', 'BR.16.1505205', 'ASCII:Oeiras Do Para;ID:6319436', '7429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7429', '112', '9306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9307', '1079', '1', 'Oriximiná', 'BR.16.1505304', 'ASCII:Oriximina;ID:6319437', '7430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7430', '112', '9307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9308', '1079', '1', 'Ourém', 'BR.16.1505403', 'ASCII:Ourem;ID:6319438', '7431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7431', '112', '9308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9309', '1079', '1', 'Ourilândia do Norte', 'BR.16.1505437', 'ASCII:Ourilandia Do Norte;ID:6319439', '7432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7432', '112', '9309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9310', '1079', '1', 'Pacajá', 'BR.16.1505486', 'ASCII:Pacaja;ID:6319440', '7433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7433', '112', '9310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9311', '1079', '1', 'Palestina do Pará', 'BR.16.1505494', 'ASCII:Palestina Do Para;ID:6319441', '7434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7434', '112', '9311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9312', '1079', '1', 'Paragominas', 'BR.16.1505502', 'ASCII:Paragominas;ID:6319442', '7435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7435', '112', '9312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9313', '1079', '1', 'Parauapebas', 'BR.16.1505536', 'ASCII:Parauapebas;ID:6319443', '7436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7436', '112', '9313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9314', '1079', '1', 'Pau d''Arco', 'BR.16.1505551', 'ASCII:Pau D''Arco;ID:6319444', '7437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7437', '112', '9314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9315', '1079', '1', 'Peixe-Boi', 'BR.16.1505601', 'ASCII:Peixe-Boi;ID:6319445', '7438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7438', '112', '9315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9316', '1079', '1', 'Piçarra', 'BR.16.1505635', 'ASCII:Picarra;ID:6319446', '7439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7439', '112', '9316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9317', '1079', '1', 'Placas', 'BR.16.1505650', 'ASCII:Placas;ID:6319447', '7440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7440', '112', '9317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9318', '1079', '1', 'Ponta de Pedras', 'BR.16.1505700', 'ASCII:Ponta De Pedras;ID:6319448', '7441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7441', '112', '9318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9319', '1079', '1', 'Portel', 'BR.16.1505809', 'ASCII:Portel;ID:6319449', '7442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7442', '112', '9319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9320', '1079', '1', 'Porto de Moz', 'BR.16.1505908', 'ASCII:Porto De Moz;ID:6319450', '7443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7443', '112', '9320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1505908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9321', '1079', '1', 'Prainha', 'BR.16.1506005', 'ASCII:Prainha;ID:6319451', '7444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7444', '112', '9321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9322', '1079', '1', 'Primavera', 'BR.16.1506104', 'ASCII:Primavera;ID:6319452', '7445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7445', '112', '9322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9323', '1079', '1', 'Quatipuru', 'BR.16.1506112', 'ASCII:Quatipuru;ID:6319453', '7446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7446', '112', '9323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9324', '1079', '1', 'Rio Maria', 'BR.16.1506161', 'ASCII:Rio Maria;ID:6319454', '7447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7447', '112', '9324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9325', '1079', '1', 'Rondon do Pará', 'BR.16.1506187', 'ASCII:Rondon Do Para;ID:6319455', '7448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7448', '112', '9325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9326', '1079', '1', 'Rurópolis', 'BR.16.1506195', 'ASCII:Ruropolis;ID:6319456', '7449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7449', '112', '9326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9327', '1079', '1', 'Salinópolis', 'BR.16.1506203', 'ASCII:Salinopolis;ID:6319457', '7450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7450', '112', '9327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9328', '1079', '1', 'Salvaterra', 'BR.16.1506302', 'ASCII:Salvaterra;ID:6319458', '7451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7451', '112', '9328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9329', '1079', '1', 'Santa Bárbara do Pará', 'BR.16.1506351', 'ASCII:Santa Barbara Do Para;ID:6319459', '7452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7452', '112', '9329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9330', '1079', '1', 'Santa Isabel do Pará', 'BR.16.1506500', 'ASCII:Santa Isabel Do Para;ID:6319460', '7453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7453', '112', '9330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9331', '1079', '1', 'Santa Maria das Barreiras', 'BR.16.1506583', 'ASCII:Santa Maria Das Barreiras;ID:6319461', '7454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7454', '112', '9331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506583» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9332', '1079', '1', 'Santa Maria do Pará', 'BR.16.1506609', 'ASCII:Santa Maria Do Para;ID:6319462', '7455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7455', '112', '9332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9333', '1079', '1', 'Santana do Araguaia', 'BR.16.1506708', 'ASCII:Santana Do Araguaia;ID:6319463', '7456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7456', '112', '9333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9334', '1079', '1', 'Santarém', 'BR.16.1506807', 'ASCII:Santarem;ID:6319464', '7457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7457', '112', '9334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9335', '1079', '1', 'Santarém Novo', 'BR.16.1506906', 'ASCII:Santarem Novo;ID:6319465', '7458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7458', '112', '9335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1506906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9336', '1079', '1', 'Santo Antônio do Tauá', 'BR.16.1507003', 'ASCII:Santo Antonio Do Taua;ID:6319466', '7459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7459', '112', '9336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9337', '1079', '1', 'São Caetano de Odivelas', 'BR.16.1507102', 'ASCII:Sao Caetano De Odivelas;ID:6319467', '7460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7460', '112', '9337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9338', '1079', '1', 'São Domingos do Araguaia', 'BR.16.1507151', 'ASCII:Sao Domingos Do Araguaia;ID:6319468', '7461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7461', '112', '9338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9339', '1079', '1', 'São Domingos do Capim', 'BR.16.1507201', 'ASCII:Sao Domingos Do Capim;ID:6319469', '7462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7462', '112', '9339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9340', '1079', '1', 'São Félix do Xingu', 'BR.16.1507300', 'ASCII:Sao Felix Do Xingu;ID:6319470', '7463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7463', '112', '9340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9341', '1079', '1', 'São Francisco do Pará', 'BR.16.1507409', 'ASCII:Sao Francisco Do Para;ID:6319471', '7464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7464', '112', '9341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9342', '1079', '1', 'São Geraldo do Araguaia', 'BR.16.1507458', 'ASCII:Sao Geraldo Do Araguaia;ID:6319472', '7465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7465', '112', '9342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9343', '1079', '1', 'São João da Ponta', 'BR.16.1507466', 'ASCII:Sao Joao Da Ponta;ID:6319473', '7466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7466', '112', '9343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9344', '1079', '1', 'São João de Pirabas', 'BR.16.1507474', 'ASCII:Sao Joao De Pirabas;ID:6319474', '7467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7467', '112', '9344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9345', '1079', '1', 'São João do Araguaia', 'BR.16.1507508', 'ASCII:Sao Joao Do Araguaia;ID:6319475', '7468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7468', '112', '9345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9346', '1079', '1', 'São Sebastião da Boa Vista', 'BR.16.1507706', 'ASCII:Sao Sebastiao Da Boa Vista;ID:6319476', '7469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7469', '112', '9346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9347', '1079', '1', 'Sapucaia', 'BR.16.1507755', 'ASCII:Sapucaia;ID:6319477', '7470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7470', '112', '9347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9348', '1079', '1', 'Senador José Porfírio', 'BR.16.1507805', 'ASCII:Senador Jose Porfirio;ID:6319478', '7471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7471', '112', '9348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9349', '1079', '1', 'Soure', 'BR.16.1507904', 'ASCII:Soure;ID:6319479', '7472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7472', '112', '9349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9350', '1079', '1', 'Tailândia', 'BR.16.1507953', 'ASCII:Tailandia;ID:6319480', '7473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7473', '112', '9350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9351', '1079', '1', 'Terra Alta', 'BR.16.1507961', 'ASCII:Terra Alta;ID:6319481', '7474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7474', '112', '9351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9352', '1079', '1', 'Terra Santa', 'BR.16.1507979', 'ASCII:Terra Santa;ID:6319482', '7475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7475', '112', '9352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1507979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9353', '1079', '1', 'Tomé-Açu', 'BR.16.1508001', 'ASCII:Tome-Acu;ID:6319483', '7476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7476', '112', '9353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9354', '1079', '1', 'Tracuateua', 'BR.16.1508035', 'ASCII:Tracuateua;ID:6319484', '7477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7477', '112', '9354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9355', '1079', '1', 'Trairão', 'BR.16.1508050', 'ASCII:Trairao;ID:6319485', '7478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7478', '112', '9355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9356', '1079', '1', 'Tucumã', 'BR.16.1508084', 'ASCII:Tucuma;ID:6319486', '7479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7479', '112', '9356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9357', '1079', '1', 'Tucuruí', 'BR.16.1508100', 'ASCII:Tucurui;ID:6319487', '7480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7480', '112', '9357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9358', '1079', '1', 'Ulianópolis', 'BR.16.1508126', 'ASCII:Ulianopolis;ID:6319488', '7481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7481', '112', '9358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508126» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9359', '1079', '1', 'Uruará', 'BR.16.1508159', 'ASCII:Uruara;ID:6319489', '7482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7482', '112', '9359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9360', '1079', '1', 'Vigia', 'BR.16.1508209', 'ASCII:Vigia;ID:6319490', '7483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7483', '112', '9360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9361', '1079', '1', 'Vitória do Xingu', 'BR.16.1508357', 'ASCII:Vitoria Do Xingu;ID:6319491', '7484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7484', '112', '9361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9362', '1079', '1', 'Xinguara', 'BR.16.1508407', 'ASCII:Xinguara;ID:6319492', '7485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7485', '112', '9362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9363', '1079', '1', 'Amapá', 'BR.03.1600105', 'ASCII:Amapa;ID:6319493', '7486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7486', '112', '9363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9364', '1079', '1', 'Calçoene', 'BR.03.1600204', 'ASCII:Calcoene;ID:6319494', '7487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7487', '112', '9364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9365', '1079', '1', 'Cutias', 'BR.03.1600212', 'ASCII:Cutias;ID:6319495', '7488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7488', '112', '9365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9366', '1079', '1', 'Itaubal', 'BR.03.1600253', 'ASCII:Itaubal;ID:6319496', '7489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7489', '112', '9366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9367', '1079', '1', 'Vitória do Jari', 'BR.03.1600808', 'ASCII:Vitoria Do Jari;ID:6319497', '7490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7490', '112', '9367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9368', '1079', '1', 'Macapá', 'BR.03.1600303', 'ASCII:Macapa;ID:6319498', '7491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7491', '112', '9368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9369', '1079', '1', 'Mazagão', 'BR.03.1600402', 'ASCII:Mazagao;ID:6319499', '7492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7492', '112', '9369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9370', '1079', '1', 'Oiapoque', 'BR.03.1600501', 'ASCII:Oiapoque;ID:6319500', '7493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7493', '112', '9370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9371', '1079', '1', 'Pracuúba', 'BR.03.1600550', 'ASCII:Pracuuba;ID:6319501', '7494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7494', '112', '9371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9372', '1079', '1', 'Santana', 'BR.03.1600600', 'ASCII:Santana;ID:6319502', '7495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7495', '112', '9372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9373', '1079', '1', 'Tartarugalzinho', 'BR.03.1600709', 'ASCII:Tartarugalzinho;ID:6319503', '7496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7496', '112', '9373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9374', '1079', '1', 'Abreulândia', 'BR.31.1700251', 'ASCII:Abreulandia;ID:6319504', '7497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7497', '112', '9374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1700251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9375', '1079', '1', 'Aguiarnópolis', 'BR.31.1700301', 'ASCII:Aguiarnopolis;ID:6319505', '7498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7498', '112', '9375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1700301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9376', '1079', '1', 'Aliança do Tocantins', 'BR.31.1700350', 'ASCII:Alianca Do Tocantins;ID:6319506', '7499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7499', '112', '9376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1700350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9377', '1079', '1', 'Almas', 'BR.31.1700400', 'ASCII:Almas;ID:6319507', '7500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7500', '112', '9377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1700400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9378', '1079', '1', 'Alvorada', 'BR.31.1700707', 'ASCII:Alvorada;ID:6319508', '7501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7501', '112', '9378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1700707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9379', '1079', '1', 'Ananás', 'BR.31.1701002', 'ASCII:Ananas;ID:6319509', '7502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7502', '112', '9379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1701002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9380', '1079', '1', 'Angico', 'BR.31.1701051', 'ASCII:Angico;ID:6319510', '7503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7503', '112', '9380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1701051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9381', '1079', '1', 'Aparecida do Rio Negro', 'BR.31.1701101', 'ASCII:Aparecida Do Rio Negro;ID:6319511', '7504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7504', '112', '9381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1701101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9382', '1079', '1', 'Aragominas', 'BR.31.1701309', 'ASCII:Aragominas;ID:6319512', '7505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7505', '112', '9382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1701309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9383', '1079', '1', 'Araguacema', 'BR.31.1701903', 'ASCII:Araguacema;ID:6319513', '7506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7506', '112', '9383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1701903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9384', '1079', '1', 'Araguaçu', 'BR.31.1702000', 'ASCII:Araguacu;ID:6319514', '7507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7507', '112', '9384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1702000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9385', '1079', '1', 'Araguaína', 'BR.31.1702109', 'ASCII:Araguaina;ID:6319515', '7508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7508', '112', '9385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1702109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9386', '1079', '1', 'Araguanã', 'BR.31.1702158', 'ASCII:Araguana;ID:6319516', '7509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7509', '112', '9386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1702158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9387', '1079', '1', 'Araguatins', 'BR.31.1702208', 'ASCII:Araguatins;ID:6319517', '7510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7510', '112', '9387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1702208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9388', '1079', '1', 'Arapoema', 'BR.31.1702307', 'ASCII:Arapoema;ID:6319518', '7511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7511', '112', '9388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1702307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9389', '1079', '1', 'Arraias', 'BR.31.1702406', 'ASCII:Arraias;ID:6319519', '7512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7512', '112', '9389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1702406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9390', '1079', '1', 'Augustinópolis', 'BR.31.1702554', 'ASCII:Augustinopolis;ID:6319520', '7513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7513', '112', '9390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1702554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9391', '1079', '1', 'Aurora do Tocantins', 'BR.31.1702703', 'ASCII:Aurora Do Tocantins;ID:6319521', '7514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7514', '112', '9391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1702703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9392', '1079', '1', 'Axixá do Tocantins', 'BR.31.1702901', 'ASCII:Axixa Do Tocantins;ID:6319522', '7515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7515', '112', '9392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1702901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9393', '1079', '1', 'Babaçulândia', 'BR.31.1703008', 'ASCII:Babaculandia;ID:6319523', '7516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7516', '112', '9393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9394', '1079', '1', 'Bandeirantes do Tocantins', 'BR.31.1703057', 'ASCII:Bandeirantes Do Tocantins;ID:6319524', '7517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7517', '112', '9394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9395', '1079', '1', 'Barra do Ouro', 'BR.31.1703073', 'ASCII:Barra Do Ouro;ID:6319525', '7518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7518', '112', '9395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9396', '1079', '1', 'Barrolândia', 'BR.31.1703107', 'ASCII:Barrolandia;ID:6319526', '7519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7519', '112', '9396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9397', '1079', '1', 'Bernardo Sayão', 'BR.31.1703206', 'ASCII:Bernardo Sayao;ID:6319527', '7520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7520', '112', '9397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9398', '1079', '1', 'Bom Jesus do Tocantins', 'BR.31.1703305', 'ASCII:Bom Jesus Do Tocantins;ID:6319528', '7521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7521', '112', '9398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9399', '1079', '1', 'Brasilândia do Tocantins', 'BR.31.1703602', 'ASCII:Brasilandia Do Tocantins;ID:6319529', '7522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7522', '112', '9399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9400', '1079', '1', 'Brejinho de Nazaré', 'BR.31.1703701', 'ASCII:Brejinho De Nazare;ID:6319530', '7523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7523', '112', '9400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9401', '1079', '1', 'Buriti do Tocantins', 'BR.31.1703800', 'ASCII:Buriti Do Tocantins;ID:6319531', '7524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7524', '112', '9401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9402', '1079', '1', 'Cachoeirinha', 'BR.31.1703826', 'ASCII:Cachoeirinha;ID:6319532', '7525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7525', '112', '9402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9403', '1079', '1', 'Campos Lindos', 'BR.31.1703842', 'ASCII:Campos Lindos;ID:6319533', '7526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7526', '112', '9403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9404', '1079', '1', 'Cariri do Tocantins', 'BR.31.1703867', 'ASCII:Cariri Do Tocantins;ID:6319534', '7527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7527', '112', '9404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9405', '1079', '1', 'Carmolândia', 'BR.31.1703883', 'ASCII:Carmolandia;ID:6319535', '7528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7528', '112', '9405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9406', '1079', '1', 'Carrasco Bonito', 'BR.31.1703891', 'ASCII:Carrasco Bonito;ID:6319536', '7529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7529', '112', '9406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9407', '1079', '1', 'Caseara', 'BR.31.1703909', 'ASCII:Caseara;ID:6319537', '7530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7530', '112', '9407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1703909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9408', '1079', '1', 'Centenário', 'BR.31.1704105', 'ASCII:Centenario;ID:6319538', '7531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7531', '112', '9408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1704105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9409', '1079', '1', 'Chapada de Areia', 'BR.31.1704600', 'ASCII:Chapada De Areia;ID:6319539', '7532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7532', '112', '9409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1704600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9410', '1079', '1', 'Chapada da Natividade', 'BR.31.1705102', 'ASCII:Chapada Da Natividade;ID:6319540', '7533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7533', '112', '9410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1705102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9411', '1079', '1', 'Colinas do Tocantins', 'BR.31.1705508', 'ASCII:Colinas Do Tocantins;ID:6319541', '7534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7534', '112', '9411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1705508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9412', '1079', '1', 'Combinado', 'BR.31.1705557', 'ASCII:Combinado;ID:6319542', '7535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7535', '112', '9412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1705557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9413', '1079', '1', 'Conceição do Tocantins', 'BR.31.1705607', 'ASCII:Conceicao Do Tocantins;ID:6319543', '7536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7536', '112', '9413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1705607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9414', '1079', '1', 'Couto de Magalhães', 'BR.31.1706001', 'ASCII:Couto De Magalhaes;ID:6319544', '7537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7537', '112', '9414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1706001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9415', '1079', '1', 'Cristalândia', 'BR.31.1706100', 'ASCII:Cristalandia;ID:6319545', '7538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7538', '112', '9415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1706100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9416', '1079', '1', 'Crixás do Tocantins', 'BR.31.1706258', 'ASCII:Crixas Do Tocantins;ID:6319546', '7539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7539', '112', '9416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1706258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9417', '1079', '1', 'Darcinópolis', 'BR.31.1706506', 'ASCII:Darcinopolis;ID:6319547', '7540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7540', '112', '9417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1706506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9418', '1079', '1', 'Dianópolis', 'BR.31.1707009', 'ASCII:Dianopolis;ID:6319548', '7541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7541', '112', '9418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1707009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9419', '1079', '1', 'Divinópolis do Tocantins', 'BR.31.1707108', 'ASCII:Divinopolis Do Tocantins;ID:6319549', '7542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7542', '112', '9419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1707108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9420', '1079', '1', 'Dois Irmãos do Tocantins', 'BR.31.1707207', 'ASCII:Dois Irmaos Do Tocantins;ID:6319550', '7543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7543', '112', '9420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1707207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9421', '1079', '1', 'Dueré', 'BR.31.1707306', 'ASCII:Duere;ID:6319551', '7544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7544', '112', '9421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1707306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9422', '1079', '1', 'Esperantina', 'BR.31.1707405', 'ASCII:Esperantina;ID:6319552', '7545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7545', '112', '9422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1707405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9423', '1079', '1', 'Fátima', 'BR.31.1707553', 'ASCII:Fatima;ID:6319553', '7546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7546', '112', '9423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1707553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9424', '1079', '1', 'Figueirópolis', 'BR.31.1707652', 'ASCII:Figueiropolis;ID:6319554', '7547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7547', '112', '9424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1707652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9425', '1079', '1', 'Filadélfia', 'BR.31.1707702', 'ASCII:Filadelfia;ID:6319555', '7548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7548', '112', '9425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1707702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9426', '1079', '1', 'Formoso do Araguaia', 'BR.31.1708205', 'ASCII:Formoso Do Araguaia;ID:6319556', '7549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7549', '112', '9426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1708205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9427', '1079', '1', 'Fortaleza do Tabocão', 'BR.31.1708254', 'ASCII:Fortaleza Do Tabocao;ID:6319557', '7550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7550', '112', '9427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1708254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9428', '1079', '1', 'Goianorte', 'BR.31.1708304', 'ASCII:Goianorte;ID:6319558', '7551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7551', '112', '9428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1708304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9429', '1079', '1', 'Goiatins', 'BR.31.1709005', 'ASCII:Goiatins;ID:6319559', '7552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7552', '112', '9429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1709005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9430', '1079', '1', 'Gurupi', 'BR.31.1709500', 'ASCII:Gurupi;ID:6319560', '7553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7553', '112', '9430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1709500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9431', '1079', '1', 'Itacajá', 'BR.31.1710508', 'ASCII:Itacaja;ID:6319561', '7554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7554', '112', '9431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1710508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9432', '1079', '1', 'Itaguatins', 'BR.31.1710706', 'ASCII:Itaguatins;ID:6319562', '7555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7555', '112', '9432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1710706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9433', '1079', '1', 'Itapiratins', 'BR.31.1710904', 'ASCII:Itapiratins;ID:6319563', '7556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7556', '112', '9433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1710904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9434', '1079', '1', 'Itaporã do Tocantins', 'BR.31.1711100', 'ASCII:Itapora Do Tocantins;ID:6319564', '7557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7557', '112', '9434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1711100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9435', '1079', '1', 'Jaú do Tocantins', 'BR.31.1711506', 'ASCII:Jau Do Tocantins;ID:6319565', '7558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7558', '112', '9435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1711506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9436', '1079', '1', 'Juarina', 'BR.31.1711803', 'ASCII:Juarina;ID:6319566', '7559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7559', '112', '9436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1711803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9437', '1079', '1', 'Lagoa do Tocantins', 'BR.31.1711951', 'ASCII:Lagoa Do Tocantins;ID:6319567', '7560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7560', '112', '9437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1711951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9438', '1079', '1', 'Lajeado', 'BR.31.1712009', 'ASCII:Lajeado;ID:6319568', '7561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7561', '112', '9438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1712009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9439', '1079', '1', 'Lavandeira', 'BR.31.1712157', 'ASCII:Lavandeira;ID:6319569', '7562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7562', '112', '9439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1712157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9440', '1079', '1', 'Lizarda', 'BR.31.1712405', 'ASCII:Lizarda;ID:6319570', '7563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7563', '112', '9440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1712405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9441', '1079', '1', 'Luzinópolis', 'BR.31.1712454', 'ASCII:Luzinopolis;ID:6319571', '7564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7564', '112', '9441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1712454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9442', '1079', '1', 'Marianópolis do Tocantins', 'BR.31.1712504', 'ASCII:Marianopolis Do Tocantins;ID:6319572', '7565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7565', '112', '9442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1712504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9443', '1079', '1', 'Mateiros', 'BR.31.1712702', 'ASCII:Mateiros;ID:6319573', '7566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7566', '112', '9443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1712702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9444', '1079', '1', 'Maurilândia do Tocantins', 'BR.31.1712801', 'ASCII:Maurilandia Do Tocantins;ID:6319574', '7567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7567', '112', '9444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1712801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9445', '1079', '1', 'Miracema do Tocantins', 'BR.31.1713205', 'ASCII:Miracema Do Tocantins;ID:6319575', '7568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7568', '112', '9445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1713205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9446', '1079', '1', 'Miranorte', 'BR.31.1713304', 'ASCII:Miranorte;ID:6319576', '7569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7569', '112', '9446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1713304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9447', '1079', '1', 'Monte Santo do Tocantins', 'BR.31.1713700', 'ASCII:Monte Santo Do Tocantins;ID:6319577', '7570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7570', '112', '9447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1713700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9448', '1079', '1', 'Palmeiras do Tocantins', 'BR.31.1713809', 'ASCII:Mosquito;ID:6319578', '7571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7571', '112', '9448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1713809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9449', '1079', '1', 'Muricilândia', 'BR.31.1713957', 'ASCII:Muricilandia;ID:6319579', '7572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7572', '112', '9449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1713957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9450', '1079', '1', 'Nazaré', 'BR.31.1714302', 'ASCII:Nazare;ID:6319580', '7573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7573', '112', '9450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1714302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9451', '1079', '1', 'Nova Olinda', 'BR.31.1714880', 'ASCII:Nova Olinda;ID:6319581', '7574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7574', '112', '9451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1714880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9452', '1079', '1', 'Nova Rosalândia', 'BR.31.1715002', 'ASCII:Nova Rosalandia;ID:6319582', '7575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7575', '112', '9452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1715002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9453', '1079', '1', 'Novo Acordo', 'BR.31.1715101', 'ASCII:Novo Acordo;ID:6319583', '7576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7576', '112', '9453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1715101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9454', '1079', '1', 'Novo Alegre', 'BR.31.1715150', 'ASCII:Novo Alegre;ID:6319584', '7577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7577', '112', '9454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1715150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9455', '1079', '1', 'Novo Jardim', 'BR.31.1715259', 'ASCII:Novo Jardim;ID:6319585', '7578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7578', '112', '9455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1715259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9456', '1079', '1', 'Oliveira de Fátima', 'BR.31.1715507', 'ASCII:Oliveira De Fatima;ID:6319586', '7579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7579', '112', '9456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1715507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9457', '1079', '1', 'Palmeirante', 'BR.31.1715705', 'ASCII:Palmeirante;ID:6319587', '7580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7580', '112', '9457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1715705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9458', '1079', '1', 'Palmeirópolis', 'BR.31.1715754', 'ASCII:Palmeiropolis;ID:6319588', '7581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7581', '112', '9458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1715754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9459', '1079', '1', 'Paraíso do Tocantins', 'BR.31.1716109', 'ASCII:Paraiso Do Tocantins;ID:6319589', '7582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7582', '112', '9459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1716109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9460', '1079', '1', 'Paranã', 'BR.31.1716208', 'ASCII:Parana;ID:6319590', '7583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7583', '112', '9460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1716208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9461', '1079', '1', 'Pedro Afonso', 'BR.31.1716505', 'ASCII:Pedro Afonso;ID:6319591', '7584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7584', '112', '9461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1716505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9462', '1079', '1', 'Peixe', 'BR.31.1716604', 'ASCII:Peixe;ID:6319592', '7585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7585', '112', '9462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1716604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9463', '1079', '1', 'Pequizeiro', 'BR.31.1716653', 'ASCII:Pequizeiro;ID:6319593', '7586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7586', '112', '9463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1716653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9464', '1079', '1', 'Colméia', 'BR.31.1716703', 'ASCII:Colmeia;ID:6319594', '7587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7587', '112', '9464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1716703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9465', '1079', '1', 'Pindorama do Tocantins', 'BR.31.1717008', 'ASCII:Pindorama Do Tocantins;ID:6319595', '7588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7588', '112', '9465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1717008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9466', '1079', '1', 'Piraquê', 'BR.31.1717206', 'ASCII:Piraque;ID:6319596', '7589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7589', '112', '9466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1717206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9467', '1079', '1', 'Pium', 'BR.31.1717503', 'ASCII:Pium;ID:6319597', '7590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7590', '112', '9467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1717503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9468', '1079', '1', 'Ponte Alta do Bom Jesus', 'BR.31.1717800', 'ASCII:Ponte Alta Do Bom Jesus;ID:6319598', '7591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7591', '112', '9468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1717800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9469', '1079', '1', 'Ponte Alta do Tocantins', 'BR.31.1717909', 'ASCII:Ponte Alta Do Tocantins;ID:6319599', '7592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7592', '112', '9469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1717909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9470', '1079', '1', 'Porto Alegre do Tocantins', 'BR.31.1718006', 'ASCII:Porto Alegre Do Tocantins;ID:6319600', '7593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7593', '112', '9470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9471', '1079', '1', 'Porto Nacional', 'BR.31.1718204', 'ASCII:Porto Nacional;ID:6319601', '7594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7594', '112', '9471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9472', '1079', '1', 'Praia Norte', 'BR.31.1718303', 'ASCII:Praia Norte;ID:6319602', '7595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7595', '112', '9472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9473', '1079', '1', 'Pugmil', 'BR.31.1718451', 'ASCII:Pugmil;ID:6319603', '7596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7596', '112', '9473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9474', '1079', '1', 'Recursolândia', 'BR.31.1718501', 'ASCII:Recursolandia;ID:6319604', '7597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7597', '112', '9474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9475', '1079', '1', 'Riachinho', 'BR.31.1718550', 'ASCII:Riachinho;ID:6319605', '7598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7598', '112', '9475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9476', '1079', '1', 'Rio da Conceição', 'BR.31.1718659', 'ASCII:Rio Da Conceicao;ID:6319606', '7599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7599', '112', '9476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9477', '1079', '1', 'Rio dos Bois', 'BR.31.1718709', 'ASCII:Rio Dos Bois;ID:6319607', '7600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7600', '112', '9477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9478', '1079', '1', 'Rio Sono', 'BR.31.1718758', 'ASCII:Rio Sono;ID:6319608', '7601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7601', '112', '9478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9479', '1079', '1', 'Sampaio', 'BR.31.1718808', 'ASCII:Sampaio;ID:6319609', '7602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7602', '112', '9479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9480', '1079', '1', 'Sandolândia', 'BR.31.1718840', 'ASCII:Sandolandia;ID:6319610', '7603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7603', '112', '9480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9481', '1079', '1', 'Santa Rita do Tocantins', 'BR.31.1718899', 'ASCII:Santa Rita Do Tocantins;ID:6319611', '7604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7604', '112', '9481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9482', '1079', '1', 'Santa Rosa do Tocantins', 'BR.31.1718907', 'ASCII:Santa Rosa Do Tocantins;ID:6319612', '7605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7605', '112', '9482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9483', '1079', '1', 'Santa Tereza do Tocantins', 'BR.31.1719004', 'ASCII:Santa Tereza Do Tocantins;ID:6319613', '7606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7606', '112', '9483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1719004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9484', '1079', '1', 'Santa Terezinha do Tocantins', 'BR.31.1720002', 'ASCII:Santa Terezinha Do Tocantins;ID:6319614', '7607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7607', '112', '9484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9485', '1079', '1', 'São Bento do Tocantins', 'BR.31.1720101', 'ASCII:Sao Bento Do Tocantins;ID:6319615', '7608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7608', '112', '9485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9486', '1079', '1', 'São Félix do Tocantins', 'BR.31.1720150', 'ASCII:Sao Felix Do Tocantins;ID:6319616', '7609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7609', '112', '9486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9487', '1079', '1', 'São Miguel do Tocantins', 'BR.31.1720200', 'ASCII:Sao Miguel Do Tocantins;ID:6319617', '7610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7610', '112', '9487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9488', '1079', '1', 'São Salvador do Tocantins', 'BR.31.1720259', 'ASCII:Sao Salvador Do Tocantins;ID:6319618', '7611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7611', '112', '9488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9489', '1079', '1', 'São Sebastião do Tocantins', 'BR.31.1720309', 'ASCII:Sao Sebastiao Do Tocantins;ID:6319619', '7612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7612', '112', '9489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9490', '1079', '1', 'Silvanópolis', 'BR.31.1720655', 'ASCII:Silvanopolis;ID:6319620', '7613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7613', '112', '9490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9491', '1079', '1', 'Sítio Novo do Tocantins', 'BR.31.1720804', 'ASCII:Sitio Novo Do Tocantins;ID:6319621', '7614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7614', '112', '9491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9492', '1079', '1', 'Sucupira', 'BR.31.1720853', 'ASCII:Sucupira;ID:6319622', '7615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7615', '112', '9492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9493', '1079', '1', 'Taguatinga', 'BR.31.1720903', 'ASCII:Taguatinga;ID:6319623', '7616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7616', '112', '9493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9494', '1079', '1', 'Taipas do Tocantins', 'BR.31.1720937', 'ASCII:Taipas Do Tocantins;ID:6319624', '7617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7617', '112', '9494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9495', '1079', '1', 'Talismã', 'BR.31.1720978', 'ASCII:Talisma;ID:6319625', '7618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7618', '112', '9495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9496', '1079', '1', 'Palmas', 'BR.31.1721000', 'ASCII:Palmas;ID:6319626', '7619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7619', '112', '9496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1721000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9497', '1079', '1', 'Tocantínia', 'BR.31.1721109', 'ASCII:Tocantinia;ID:6319627', '7620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7620', '112', '9497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1721109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9498', '1079', '1', 'Tocantinópolis', 'BR.31.1721208', 'ASCII:Tocantinopolis;ID:6319628', '7621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7621', '112', '9498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1721208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9499', '1079', '1', 'Tupirama', 'BR.31.1721257', 'ASCII:Tupirama;ID:6319629', '7622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7622', '112', '9499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1721257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9500', '1079', '1', 'Wanderlândia', 'BR.31.1722081', 'ASCII:Wanderlandia;ID:6319630', '7623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7623', '112', '9500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1722081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9501', '1079', '1', 'Xambioá', 'BR.31.1722107', 'ASCII:Xambioa;ID:6319631', '7624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7624', '112', '9501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1722107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9502', '1079', '1', 'Afonso Cunha', 'BR.13.2100105', 'ASCII:Afonso Cunha;ID:6319632', '7625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7625', '112', '9502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9503', '1079', '1', 'Água Doce do Maranhão', 'BR.13.2100154', 'ASCII:Agua Doce Do Maranhao;ID:6319633', '7626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7626', '112', '9503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9504', '1079', '1', 'Alcântara', 'BR.13.2100204', 'ASCII:Alcantara;ID:6319634', '7627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7627', '112', '9504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9505', '1079', '1', 'Aldeias Altas', 'BR.13.2100303', 'ASCII:Aldeias Altas;ID:6319635', '7628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7628', '112', '9505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9506', '1079', '1', 'Altamira do Maranhão', 'BR.13.2100402', 'ASCII:Altamira Do Maranhao;ID:6319636', '7629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7629', '112', '9506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9507', '1079', '1', 'Alto Alegre do Maranhão', 'BR.13.2100436', 'ASCII:Alto Alegre Do Maranhao;ID:6319637', '7630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7630', '112', '9507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9508', '1079', '1', 'Alto Parnaíba', 'BR.13.2100501', 'ASCII:Alto Parnaiba;ID:6319638', '7631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7631', '112', '9508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9509', '1079', '1', 'Amapá do Maranhão', 'BR.13.2100550', 'ASCII:Amapa Do Maranhao;ID:6319639', '7632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7632', '112', '9509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9510', '1079', '1', 'Amarante do Maranhão', 'BR.13.2100600', 'ASCII:Amarante Do Maranhao;ID:6319640', '7633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7633', '112', '9510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9511', '1079', '1', 'Anajatuba', 'BR.13.2100709', 'ASCII:Anajatuba;ID:6319641', '7634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7634', '112', '9511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9512', '1079', '1', 'Anapurus', 'BR.13.2100808', 'ASCII:Anapurus;ID:6319642', '7635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7635', '112', '9512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9513', '1079', '1', 'Apicum-Açu', 'BR.13.2100832', 'ASCII:Apicum-Acu;ID:6319643', '7636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7636', '112', '9513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9514', '1079', '1', 'Araguanã', 'BR.13.2100873', 'ASCII:Araguana;ID:6319644', '7637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7637', '112', '9514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9515', '1079', '1', 'Araioses', 'BR.13.2100907', 'ASCII:Araioses;ID:6319645', '7638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7638', '112', '9515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9516', '1079', '1', 'Arame', 'BR.13.2100956', 'ASCII:Arame;ID:6319646', '7639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7639', '112', '9516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2100956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9517', '1079', '1', 'Arari', 'BR.13.2101004', 'ASCII:Arari;ID:6319647', '7640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7640', '112', '9517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9518', '1079', '1', 'Axixá', 'BR.13.2101103', 'ASCII:Axixa;ID:6319648', '7641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7641', '112', '9518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9519', '1079', '1', 'Bacabal', 'BR.13.2101202', 'ASCII:Bacabal;ID:6319649', '7642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7642', '112', '9519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9520', '1079', '1', 'Bacabeira', 'BR.13.2101251', 'ASCII:Bacabeira;ID:6319650', '7643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7643', '112', '9520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9521', '1079', '1', 'Bacuri', 'BR.13.2101301', 'ASCII:Bacuri;ID:6319651', '7644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7644', '112', '9521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9522', '1079', '1', 'Bacurituba', 'BR.13.2101350', 'ASCII:Bacurituba;ID:6319652', '7645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7645', '112', '9522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9523', '1079', '1', 'Balsas', 'BR.13.2101400', 'ASCII:Balsas;ID:6319653', '7646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7646', '112', '9523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9524', '1079', '1', 'Barra do Corda', 'BR.13.2101608', 'ASCII:Barra Do Corda;ID:6319654', '7647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7647', '112', '9524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9525', '1079', '1', 'Barreirinhas', 'BR.13.2101707', 'ASCII:Barreirinhas;ID:6319655', '7648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7648', '112', '9525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9526', '1079', '1', 'Belágua', 'BR.13.2101731', 'ASCII:Belagua;ID:6319656', '7649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7649', '112', '9526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9527', '1079', '1', 'Bela Vista do Maranhão', 'BR.13.2101772', 'ASCII:Bela Vista Do Maranhao;ID:6319657', '7650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7650', '112', '9527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9528', '1079', '1', 'Benedito Leite', 'BR.13.2101806', 'ASCII:Benedito Leite;ID:6319658', '7651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7651', '112', '9528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9529', '1079', '1', 'Bequimão', 'BR.13.2101905', 'ASCII:Bequimao;ID:6319659', '7652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7652', '112', '9529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9530', '1079', '1', 'Bernardo do Mearim', 'BR.13.2101939', 'ASCII:Bernardo Do Mearim;ID:6319660', '7653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7653', '112', '9530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9531', '1079', '1', 'Boa Vista do Gurupi', 'BR.13.2101970', 'ASCII:Boa Vista Do Gurupi;ID:6319661', '7654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7654', '112', '9531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2101970» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9532', '1079', '1', 'Bom Jardim', 'BR.13.2102002', 'ASCII:Bom Jardim;ID:6319662', '7655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7655', '112', '9532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9533', '1079', '1', 'Bom Jesus das Selvas', 'BR.13.2102036', 'ASCII:Bom Jesus Das Selvas;ID:6319663', '7656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7656', '112', '9533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9534', '1079', '1', 'Bom Lugar', 'BR.13.2102077', 'ASCII:Bom Lugar;ID:6319664', '7657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7657', '112', '9534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9535', '1079', '1', 'Brejo', 'BR.13.2102101', 'ASCII:Brejo;ID:6319665', '7658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7658', '112', '9535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9536', '1079', '1', 'Brejo de Areia', 'BR.13.2102150', 'ASCII:Brejo De Areia;ID:6319666', '7659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7659', '112', '9536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9537', '1079', '1', 'Buriti', 'BR.13.2102200', 'ASCII:Buriti;ID:6319667', '7660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7660', '112', '9537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9538', '1079', '1', 'Buriti Bravo', 'BR.13.2102309', 'ASCII:Buriti Bravo;ID:6319668', '7661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7661', '112', '9538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9539', '1079', '1', 'Buriticupu', 'BR.13.2102325', 'ASCII:Buriticupu;ID:6319669', '7662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7662', '112', '9539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9540', '1079', '1', 'Buritirana', 'BR.13.2102358', 'ASCII:Buritirana;ID:6319670', '7663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7663', '112', '9540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9541', '1079', '1', 'Cachoeira Grande', 'BR.13.2102374', 'ASCII:Cachoeira Grande;ID:6319671', '7664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7664', '112', '9541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9542', '1079', '1', 'Cajapió', 'BR.13.2102408', 'ASCII:Cajapio;ID:6319672', '7665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7665', '112', '9542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9543', '1079', '1', 'Cajari', 'BR.13.2102507', 'ASCII:Cajari;ID:6319673', '7666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7666', '112', '9543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9544', '1079', '1', 'Campestre do Maranhão', 'BR.13.2102556', 'ASCII:Campestre Do Maranhao;ID:6319674', '7667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7667', '112', '9544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9545', '1079', '1', 'Cândido Mendes', 'BR.13.2102606', 'ASCII:Candido Mendes;ID:6319675', '7668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7668', '112', '9545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9546', '1079', '1', 'Cantanhede', 'BR.13.2102705', 'ASCII:Cantanhede;ID:6319676', '7669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7669', '112', '9546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9547', '1079', '1', 'Capinzal do Norte', 'BR.13.2102754', 'ASCII:Capinzal Do Norte;ID:6319677', '7670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7670', '112', '9547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9548', '1079', '1', 'Carolina', 'BR.13.2102804', 'ASCII:Carolina;ID:6319678', '7671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7671', '112', '9548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9549', '1079', '1', 'Carutapera', 'BR.13.2102903', 'ASCII:Carutapera;ID:6319679', '7672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7672', '112', '9549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2102903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9550', '1079', '1', 'Caxias', 'BR.13.2103000', 'ASCII:Caxias;ID:6319680', '7673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7673', '112', '9550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9551', '1079', '1', 'Cedral', 'BR.13.2103109', 'ASCII:Cedral;ID:6319681', '7674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7674', '112', '9551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9552', '1079', '1', 'Central do Maranhão', 'BR.13.2103125', 'ASCII:Central Do Maranhao;ID:6319682', '7675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7675', '112', '9552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9553', '1079', '1', 'Centro do Guilherme', 'BR.13.2103158', 'ASCII:Centro Do Guilherme;ID:6319683', '7676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7676', '112', '9553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9554', '1079', '1', 'Centro Novo do Maranhão', 'BR.13.2103174', 'ASCII:Centro Novo Do Maranhao;ID:6319684', '7677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7677', '112', '9554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9555', '1079', '1', 'Cidelândia', 'BR.13.2103257', 'ASCII:Cidelandia;ID:6319685', '7678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7678', '112', '9555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9556', '1079', '1', 'Codó', 'BR.13.2103307', 'ASCII:Codo;ID:6319686', '7679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7679', '112', '9556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9557', '1079', '1', 'Coelho Neto', 'BR.13.2103406', 'ASCII:Coelho Neto;ID:6319687', '7680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7680', '112', '9557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9558', '1079', '1', 'Colinas', 'BR.13.2103505', 'ASCII:Colinas;ID:6319688', '7681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7681', '112', '9558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9559', '1079', '1', 'Coroatá', 'BR.13.2103604', 'ASCII:Coroata;ID:6319689', '7682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7682', '112', '9559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9560', '1079', '1', 'Cururupu', 'BR.13.2103703', 'ASCII:Cururupu;ID:6319690', '7683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7683', '112', '9560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9561', '1079', '1', 'Davinópolis', 'BR.13.2103752', 'ASCII:Davinopolis;ID:6319691', '7684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7684', '112', '9561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9562', '1079', '1', 'Dom Pedro', 'BR.13.2103802', 'ASCII:Dom Pedro;ID:6319692', '7685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7685', '112', '9562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9563', '1079', '1', 'Duque Bacelar', 'BR.13.2103901', 'ASCII:Duque Bacelar;ID:6319693', '7686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7686', '112', '9563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2103901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9564', '1079', '1', 'Esperantinópolis', 'BR.13.2104008', 'ASCII:Esperantinopolis;ID:6319694', '7687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7687', '112', '9564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9565', '1079', '1', 'Estreito', 'BR.13.2104057', 'ASCII:Estreito;ID:6319695', '7688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7688', '112', '9565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9566', '1079', '1', 'Feira Nova do Maranhão', 'BR.13.2104073', 'ASCII:Feira Nova Do Maranhao;ID:6319696', '7689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7689', '112', '9566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9567', '1079', '1', 'Fernando Falcão', 'BR.13.2104081', 'ASCII:Fernando Falcao;ID:6319697', '7690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7690', '112', '9567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9568', '1079', '1', 'Formosa da Serra Negra', 'BR.13.2104099', 'ASCII:Formosa Da Serra Negra;ID:6319698', '7691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7691', '112', '9568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9569', '1079', '1', 'Fortaleza dos Nogueiras', 'BR.13.2104107', 'ASCII:Fortaleza Dos Nogueiras;ID:6319699', '7692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7692', '112', '9569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9570', '1079', '1', 'Fortuna', 'BR.13.2104206', 'ASCII:Fortuna;ID:6319700', '7693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7693', '112', '9570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9571', '1079', '1', 'Godofredo Viana', 'BR.13.2104305', 'ASCII:Godofredo Viana;ID:6319701', '7694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7694', '112', '9571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9572', '1079', '1', 'Gonçalves Dias', 'BR.13.2104404', 'ASCII:Goncalves Dias;ID:6319702', '7695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7695', '112', '9572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9573', '1079', '1', 'Governador Edison Lobão', 'BR.13.2104552', 'ASCII:Governador Edison Lobao;ID:6319703', '7696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7696', '112', '9573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9574', '1079', '1', 'Governador Eugênio Barros', 'BR.13.2104602', 'ASCII:Governador Eugenio Barros;ID:6319704', '7697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7697', '112', '9574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9575', '1079', '1', 'Governador Luiz Rocha', 'BR.13.2104628', 'ASCII:Governador Luiz Rocha;ID:6319705', '7698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7698', '112', '9575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9576', '1079', '1', 'Governador Newton Bello', 'BR.13.2104651', 'ASCII:Governador Newton Bello;ID:6319706', '7699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7699', '112', '9576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9577', '1079', '1', 'Governador Nunes Freire', 'BR.13.2104677', 'ASCII:Governador Nunes Freire;ID:6319707', '7700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7700', '112', '9577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9578', '1079', '1', 'Graça Aranha', 'BR.13.2104701', 'ASCII:Graca Aranha;ID:6319708', '7701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7701', '112', '9578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9579', '1079', '1', 'Grajaú', 'BR.13.2104800', 'ASCII:Grajau;ID:6319709', '7702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7702', '112', '9579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9580', '1079', '1', 'Guimarães', 'BR.13.2104909', 'ASCII:Guimaraes;ID:6319710', '7703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7703', '112', '9580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2104909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9581', '1079', '1', 'Humberto de Campos', 'BR.13.2105005', 'ASCII:Humberto De Campos;ID:6319711', '7704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7704', '112', '9581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9582', '1079', '1', 'Icatu', 'BR.13.2105104', 'ASCII:Icatu;ID:6319712', '7705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7705', '112', '9582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9583', '1079', '1', 'Igarapé do Meio', 'BR.13.2105153', 'ASCII:Igarape Do Meio;ID:6319713', '7706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7706', '112', '9583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9584', '1079', '1', 'Igarapé Grande', 'BR.13.2105203', 'ASCII:Igarape Grande;ID:6319714', '7707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7707', '112', '9584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9585', '1079', '1', 'Imperatriz', 'BR.13.2105302', 'ASCII:Imperatriz;ID:6319715', '7708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7708', '112', '9585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9586', '1079', '1', 'Itaipava do Grajaú', 'BR.13.2105351', 'ASCII:Itaipava Do Grajau;ID:6319716', '7709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7709', '112', '9586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9587', '1079', '1', 'Itapecuru Mirim', 'BR.13.2105401', 'ASCII:Itapecuru Mirim;ID:6319717', '7710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7710', '112', '9587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9588', '1079', '1', 'Itinga do Maranhão', 'BR.13.2105427', 'ASCII:Itinga Do Maranhao;ID:6319718', '7711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7711', '112', '9588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9589', '1079', '1', 'Jatobá', 'BR.13.2105450', 'ASCII:Jatoba;ID:6319719', '7712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7712', '112', '9589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9590', '1079', '1', 'Jenipapo dos Vieiras', 'BR.13.2105476', 'ASCII:Jenipapo Dos Vieiras;ID:6319720', '7713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7713', '112', '9590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9591', '1079', '1', 'João Lisboa', 'BR.13.2105500', 'ASCII:Joao Lisboa;ID:6319721', '7714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7714', '112', '9591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9592', '1079', '1', 'Joselândia', 'BR.13.2105609', 'ASCII:Joselandia;ID:6319722', '7715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7715', '112', '9592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9593', '1079', '1', 'Junco do Maranhão', 'BR.13.2105658', 'ASCII:Junco Do Maranhao;ID:6319723', '7716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7716', '112', '9593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9594', '1079', '1', 'Lago da Pedra', 'BR.13.2105708', 'ASCII:Lago Da Pedra;ID:6319724', '7717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7717', '112', '9594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9595', '1079', '1', 'Lago do Junco', 'BR.13.2105807', 'ASCII:Lago Do Junco;ID:6319725', '7718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7718', '112', '9595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9596', '1079', '1', 'Lago Verde', 'BR.13.2105906', 'ASCII:Lago Verde;ID:6319726', '7719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7719', '112', '9596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9597', '1079', '1', 'Lagoa do Mato', 'BR.13.2105922', 'ASCII:Lagoa Do Mato;ID:6319727', '7720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7720', '112', '9597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9598', '1079', '1', 'Lago dos Rodrigues', 'BR.13.2105948', 'ASCII:Lago Dos Rodrigues;ID:6319728', '7721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7721', '112', '9598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105948» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9599', '1079', '1', 'Lagoa Grande do Maranhão', 'BR.13.2105963', 'ASCII:Lagoa Grande Do Maranhao;ID:6319729', '7722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7722', '112', '9599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9600', '1079', '1', 'Lajeado Novo', 'BR.13.2105989', 'ASCII:Lajeado Novo;ID:6319730', '7723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7723', '112', '9600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2105989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9601', '1079', '1', 'Lima Campos', 'BR.13.2106003', 'ASCII:Lima Campos;ID:6319731', '7724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7724', '112', '9601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9602', '1079', '1', 'Loreto', 'BR.13.2106102', 'ASCII:Loreto;ID:6319732', '7725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7725', '112', '9602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9603', '1079', '1', 'Luís Domingues', 'BR.13.2106201', 'ASCII:Luis Domingues;ID:6319733', '7726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7726', '112', '9603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9604', '1079', '1', 'Magalhães de Almeida', 'BR.13.2106300', 'ASCII:Magalhaes De Almeida;ID:6319734', '7727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7727', '112', '9604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9605', '1079', '1', 'Maracaçumé', 'BR.13.2106326', 'ASCII:Maracacume;ID:6319735', '7728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7728', '112', '9605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9606', '1079', '1', 'Marajá do Sena', 'BR.13.2106359', 'ASCII:Maraja Do Sena;ID:6319736', '7729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7729', '112', '9606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9607', '1079', '1', 'Maranhãozinho', 'BR.13.2106375', 'ASCII:Maranhaozinho;ID:6319737', '7730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7730', '112', '9607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9608', '1079', '1', 'Mata Roma', 'BR.13.2106409', 'ASCII:Mata Roma;ID:6319738', '7731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7731', '112', '9608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9609', '1079', '1', 'Matinha', 'BR.13.2106508', 'ASCII:Matinha;ID:6319739', '7732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7732', '112', '9609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9610', '1079', '1', 'Matões', 'BR.13.2106607', 'ASCII:Matoes;ID:6319740', '7733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7733', '112', '9610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9611', '1079', '1', 'Matões do Norte', 'BR.13.2106631', 'ASCII:Matoes Do Norte;ID:6319741', '7734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7734', '112', '9611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9612', '1079', '1', 'Milagres do Maranhão', 'BR.13.2106672', 'ASCII:Milagres Do Maranhao;ID:6319742', '7735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7735', '112', '9612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9613', '1079', '1', 'Mirador', 'BR.13.2106706', 'ASCII:Mirador;ID:6319743', '7736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7736', '112', '9613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9614', '1079', '1', 'Miranda do Norte', 'BR.13.2106755', 'ASCII:Miranda Do Norte;ID:6319744', '7737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7737', '112', '9614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9615', '1079', '1', 'Mirinzal', 'BR.13.2106805', 'ASCII:Mirinzal;ID:6319745', '7738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7738', '112', '9615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2106805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9616', '1079', '1', 'Montes Altos', 'BR.13.2107001', 'ASCII:Montes Altos;ID:6319746', '7739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7739', '112', '9616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9617', '1079', '1', 'Morros', 'BR.13.2107100', 'ASCII:Morros;ID:6319747', '7740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7740', '112', '9617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9618', '1079', '1', 'Nova Colinas', 'BR.13.2107258', 'ASCII:Nova Colinas;ID:6319748', '7741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7741', '112', '9618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9619', '1079', '1', 'Nova Iorque', 'BR.13.2107308', 'ASCII:Nova Iorque;ID:6319749', '7742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7742', '112', '9619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9620', '1079', '1', 'Nova Olinda do Maranhão', 'BR.13.2107357', 'ASCII:Nova Olinda Do Maranhao;ID:6319750', '7743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7743', '112', '9620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9621', '1079', '1', 'Olho d''Água das Cunhãs', 'BR.13.2107407', 'ASCII:Olho D''Agua Das Cunhas;ID:6319751', '7744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7744', '112', '9621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9622', '1079', '1', 'Olinda Nova do Maranhão', 'BR.13.2107456', 'ASCII:Olinda Nova Do Maranhao;ID:6319752', '7745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7745', '112', '9622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9623', '1079', '1', 'Paço do Lumiar', 'BR.13.2107506', 'ASCII:Paco Do Lumiar;ID:6319753', '7746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7746', '112', '9623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9624', '1079', '1', 'Palmeirândia', 'BR.13.2107605', 'ASCII:Palmeirandia;ID:6319754', '7747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7747', '112', '9624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9625', '1079', '1', 'Paraibano', 'BR.13.2107704', 'ASCII:Paraibano;ID:6319755', '7748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7748', '112', '9625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9626', '1079', '1', 'Parnarama', 'BR.13.2107803', 'ASCII:Parnarama;ID:6319756', '7749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7749', '112', '9626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9627', '1079', '1', 'Passagem Franca', 'BR.13.2107902', 'ASCII:Passagem Franca;ID:6319757', '7750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7750', '112', '9627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2107902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9628', '1079', '1', 'Pastos Bons', 'BR.13.2108009', 'ASCII:Pastos Bons;ID:6319758', '7751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7751', '112', '9628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9629', '1079', '1', 'Paulino Neves', 'BR.13.2108058', 'ASCII:Paulino Neves;ID:6319759', '7752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7752', '112', '9629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9630', '1079', '1', 'Paulo Ramos', 'BR.13.2108108', 'ASCII:Paulo Ramos;ID:6319760', '7753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7753', '112', '9630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9631', '1079', '1', 'Pedreiras', 'BR.13.2108207', 'ASCII:Pedreiras;ID:6319761', '7754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7754', '112', '9631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9632', '1079', '1', 'Pedro do Rosário', 'BR.13.2108256', 'ASCII:Pedro Do Rosario;ID:6319762', '7755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7755', '112', '9632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9633', '1079', '1', 'Penalva', 'BR.13.2108306', 'ASCII:Penalva;ID:6319763', '7756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7756', '112', '9633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9634', '1079', '1', 'Peri Mirim', 'BR.13.2108405', 'ASCII:Peri Mirim;ID:6319764', '7757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7757', '112', '9634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9635', '1079', '1', 'Peritoró', 'BR.13.2108454', 'ASCII:Peritoro;ID:6319765', '7758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7758', '112', '9635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9636', '1079', '1', 'Pindaré-Mirim', 'BR.13.2108504', 'ASCII:Pindare Mirim;ID:6319766', '7759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7759', '112', '9636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9637', '1079', '1', 'Pinheiro', 'BR.13.2108603', 'ASCII:Pinheiro;ID:6319767', '7760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7760', '112', '9637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9638', '1079', '1', 'Pio XII', 'BR.13.2108702', 'ASCII:Pio Xii;ID:6319768', '7761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7761', '112', '9638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9639', '1079', '1', 'Pirapemas', 'BR.13.2108801', 'ASCII:Pirapemas;ID:6319769', '7762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7762', '112', '9639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9640', '1079', '1', 'Poção de Pedras', 'BR.13.2108900', 'ASCII:Pocao De Pedras;ID:6319770', '7763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7763', '112', '9640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2108900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9641', '1079', '1', 'Porto Franco', 'BR.13.2109007', 'ASCII:Porto Franco;ID:6319771', '7764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7764', '112', '9641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9642', '1079', '1', 'Porto Rico do Maranhão', 'BR.13.2109056', 'ASCII:Porto Rico Do Maranhao;ID:6319772', '7765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7765', '112', '9642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9643', '1079', '1', 'Presidente Dutra', 'BR.13.2109106', 'ASCII:Presidente Dutra;ID:6319773', '7766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7766', '112', '9643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9644', '1079', '1', 'Presidente Juscelino', 'BR.13.2109205', 'ASCII:Presidente Juscelino;ID:6319774', '7767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7767', '112', '9644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9645', '1079', '1', 'Presidente Médici', 'BR.13.2109239', 'ASCII:Presidente Medici;ID:6319775', '7768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7768', '112', '9645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9646', '1079', '1', 'Presidente Sarney', 'BR.13.2109270', 'ASCII:Presidente Sarney;ID:6319776', '7769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7769', '112', '9646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9647', '1079', '1', 'Presidente Vargas', 'BR.13.2109304', 'ASCII:Presidente Vargas;ID:6319777', '7770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7770', '112', '9647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9648', '1079', '1', 'Primeira Cruz', 'BR.13.2109403', 'ASCII:Primeira Cruz;ID:6319778', '7771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7771', '112', '9648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9649', '1079', '1', 'Raposa', 'BR.13.2109452', 'ASCII:Raposa;ID:6319779', '7772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7772', '112', '9649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9650', '1079', '1', 'Riachão', 'BR.13.2109502', 'ASCII:Riachao;ID:6319780', '7773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7773', '112', '9650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9651', '1079', '1', 'Ribamar Fiquene', 'BR.13.2109551', 'ASCII:Ribamar Fiquene;ID:6319781', '7774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7774', '112', '9651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9652', '1079', '1', 'Rosário', 'BR.13.2109601', 'ASCII:Rosario;ID:6319782', '7775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7775', '112', '9652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9653', '1079', '1', 'Sambaíba', 'BR.13.2109700', 'ASCII:Sambaiba;ID:6319783', '7776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7776', '112', '9653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9654', '1079', '1', 'Santa Filomena do Maranhão', 'BR.13.2109759', 'ASCII:Santa Filomena Do Maranhao;ID:6319784', '7777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7777', '112', '9654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9655', '1079', '1', 'Santa Helena', 'BR.13.2109809', 'ASCII:Santa Helena;ID:6319785', '7778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7778', '112', '9655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9656', '1079', '1', 'Santa Inês', 'BR.13.2109908', 'ASCII:Santa Ines;ID:6319786', '7779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7779', '112', '9656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2109908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9657', '1079', '1', 'Santa Quitéria do Maranhão', 'BR.13.2110104', 'ASCII:Santa Quiteria Do Maranhao;ID:6319787', '7780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7780', '112', '9657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9658', '1079', '1', 'Santana do Maranhão', 'BR.13.2110237', 'ASCII:Santana Do Maranhao;ID:6319788', '7781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7781', '112', '9658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9659', '1079', '1', 'Santo Amaro do Maranhão', 'BR.13.2110278', 'ASCII:Santo Amaro Do Maranhao;ID:6319789', '7782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7782', '112', '9659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9660', '1079', '1', 'Santo Antônio dos Lopes', 'BR.13.2110302', 'ASCII:Santo Antonio Dos Lopes;ID:6319790', '7783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7783', '112', '9660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9661', '1079', '1', 'São Benedito do Rio Preto', 'BR.13.2110401', 'ASCII:Sao Benedito Do Rio Preto;ID:6319791', '7784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7784', '112', '9661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9662', '1079', '1', 'São Bento', 'BR.13.2110500', 'ASCII:Sao Bento;ID:6319792', '7785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7785', '112', '9662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9663', '1079', '1', 'São Bernardo', 'BR.13.2110609', 'ASCII:Sao Bernardo;ID:6319793', '7786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7786', '112', '9663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9664', '1079', '1', 'São Domingos do Azeitão', 'BR.13.2110658', 'ASCII:Sao Domingos Do Azeitao;ID:6319794', '7787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7787', '112', '9664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9665', '1079', '1', 'São Domingos do Maranhão', 'BR.13.2110708', 'ASCII:Sao Domingos Do Maranhao;ID:6319795', '7788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7788', '112', '9665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9666', '1079', '1', 'São Félix de Balsas', 'BR.13.2110807', 'ASCII:Sao Felix De Balsas;ID:6319796', '7789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7789', '112', '9666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9667', '1079', '1', 'São Francisco do Brejão', 'BR.13.2110856', 'ASCII:Sao Francisco Do Brejao;ID:6319797', '7790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7790', '112', '9667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9668', '1079', '1', 'São Francisco do Maranhão', 'BR.13.2110906', 'ASCII:Sao Francisco Do Maranhao;ID:6319798', '7791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7791', '112', '9668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2110906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9669', '1079', '1', 'São João Batista', 'BR.13.2111003', 'ASCII:Sao Joao Batista;ID:6319799', '7792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7792', '112', '9669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9670', '1079', '1', 'São João do Carú', 'BR.13.2111029', 'ASCII:Sao Joao Do Caru;ID:6319800', '7793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7793', '112', '9670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9671', '1079', '1', 'São João do Soter', 'BR.13.2111078', 'ASCII:Sao Joao Do Soter;ID:6319801', '7794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7794', '112', '9671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9672', '1079', '1', 'São João dos Patos', 'BR.13.2111102', 'ASCII:Sao Joao Dos Patos;ID:6319802', '7795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7795', '112', '9672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9673', '1079', '1', 'São José de Ribamar', 'BR.13.2111201', 'ASCII:Sao Jose De Ribamar;ID:6319803', '7796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7796', '112', '9673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9674', '1079', '1', 'São José dos Basílios', 'BR.13.2111250', 'ASCII:Sao Jose Dos Basilios;ID:6319804', '7797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7797', '112', '9674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9675', '1079', '1', 'São Luís', 'BR.13.2111300', 'ASCII:Sao Luis;ID:6319805', '7798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7798', '112', '9675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9676', '1079', '1', 'São Luís Gonzaga do Maranhão', 'BR.13.2111409', 'ASCII:Sao Luis Gonzaga Do Maranhao;ID:6319806', '7799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7799', '112', '9676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9677', '1079', '1', 'São Mateus do Maranhão', 'BR.13.2111508', 'ASCII:Sao Mateus Do Maranhao;ID:6319807', '7800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7800', '112', '9677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9678', '1079', '1', 'São Pedro da Água Branca', 'BR.13.2111532', 'ASCII:Sao Pedro Da Agua Branca;ID:6319808', '7801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7801', '112', '9678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9679', '1079', '1', 'São Pedro dos Crentes', 'BR.13.2111573', 'ASCII:Sao Pedro Dos Crentes;ID:6319809', '7802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7802', '112', '9679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9680', '1079', '1', 'São Raimundo das Mangabeiras', 'BR.13.2111607', 'ASCII:Sao Raimundo Das Mangabeiras;ID:6319810', '7803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7803', '112', '9680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9681', '1079', '1', 'São Vicente Ferrer', 'BR.13.2111706', 'ASCII:Sao Vicente Ferrer;ID:6319811', '7804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7804', '112', '9681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9682', '1079', '1', 'Satubinha', 'BR.13.2111722', 'ASCII:Satubinha;ID:6319812', '7805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7805', '112', '9682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9683', '1079', '1', 'Senador Alexandre Costa', 'BR.13.2111748', 'ASCII:Senador Alexandre Costa;ID:6319813', '7806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7806', '112', '9683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9684', '1079', '1', 'Senador La Rocque', 'BR.13.2111763', 'ASCII:Senador La Rocque;ID:6319814', '7807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7807', '112', '9684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9685', '1079', '1', 'Serrano do Maranhão', 'BR.13.2111789', 'ASCII:Serrano Do Maranhao;ID:6319815', '7808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7808', '112', '9685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9686', '1079', '1', 'Sítio Novo', 'BR.13.2111805', 'ASCII:Sitio Novo;ID:6319816', '7809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7809', '112', '9686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9687', '1079', '1', 'Sucupira do Norte', 'BR.13.2111904', 'ASCII:Sucupira Do Norte;ID:6319817', '7810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7810', '112', '9687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9688', '1079', '1', 'Sucupira do Riachão', 'BR.13.2111953', 'ASCII:Sucupira Do Riachao;ID:6319818', '7811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7811', '112', '9688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9689', '1079', '1', 'Tasso Fragoso', 'BR.13.2112001', 'ASCII:Tasso Fragoso;ID:6319819', '7812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7812', '112', '9689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9690', '1079', '1', 'Timbiras', 'BR.13.2112100', 'ASCII:Timbiras;ID:6319820', '7813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7813', '112', '9690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9691', '1079', '1', 'Timon', 'BR.13.2112209', 'ASCII:Timon;ID:6319821', '7814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7814', '112', '9691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9692', '1079', '1', 'Trizidela do Vale', 'BR.13.2112233', 'ASCII:Trizidela Do Vale;ID:6319822', '7815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7815', '112', '9692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9693', '1079', '1', 'Tufilândia', 'BR.13.2112274', 'ASCII:Tufilandia;ID:6319823', '7816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7816', '112', '9693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9694', '1079', '1', 'Tuntum', 'BR.13.2112308', 'ASCII:Tuntum;ID:6319824', '7817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7817', '112', '9694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9695', '1079', '1', 'Turiaçu', 'BR.13.2112407', 'ASCII:Turiacu;ID:6319825', '7818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7818', '112', '9695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9696', '1079', '1', 'Turilândia', 'BR.13.2112456', 'ASCII:Turilandia;ID:6319826', '7819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7819', '112', '9696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9697', '1079', '1', 'Urbano Santos', 'BR.13.2112605', 'ASCII:Urbano Santos;ID:6319827', '7820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7820', '112', '9697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9698', '1079', '1', 'Vargem Grande', 'BR.13.2112704', 'ASCII:Vargem Grande;ID:6319828', '7821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7821', '112', '9698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9699', '1079', '1', 'Viana', 'BR.13.2112803', 'ASCII:Viana;ID:6319829', '7822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7822', '112', '9699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9700', '1079', '1', 'Vila Nova dos Martírios', 'BR.13.2112852', 'ASCII:Vila Nova Dos Martirios;ID:6319830', '7823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7823', '112', '9700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9701', '1079', '1', 'Vitória do Mearim', 'BR.13.2112902', 'ASCII:Vitoria Do Mearim;ID:6319831', '7824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7824', '112', '9701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2112902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9702', '1079', '1', 'Vitorino Freire', 'BR.13.2113009', 'ASCII:Vitorino Freire;ID:6319832', '7825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7825', '112', '9702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2113009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9703', '1079', '1', 'Zé Doca', 'BR.13.2114007', 'ASCII:Ze Doca;ID:6319833', '7826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7826', '112', '9703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2114007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9704', '1079', '1', 'Acauã', 'BR.20.2200053', 'ASCII:Acaua;ID:6319834', '7827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7827', '112', '9704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9705', '1079', '1', 'Agricolândia', 'BR.20.2200103', 'ASCII:Agricolandia;ID:6319835', '7828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7828', '112', '9705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9706', '1079', '1', 'Alagoinha do Piauí', 'BR.20.2200251', 'ASCII:Alagoinha Do Piaui;ID:6319836', '7829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7829', '112', '9706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9707', '1079', '1', 'Alegrete do Piauí', 'BR.20.2200277', 'ASCII:Alegrete Do Piaui;ID:6319837', '7830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7830', '112', '9707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9708', '1079', '1', 'Alto Longá', 'BR.20.2200301', 'ASCII:Alto Longa;ID:6319838', '7831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7831', '112', '9708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9709', '1079', '1', 'Alvorada do Gurguéia', 'BR.20.2200459', 'ASCII:Alvorada Do Gurgueia;ID:6319839', '7832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7832', '112', '9709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9710', '1079', '1', 'Amarante', 'BR.20.2200509', 'ASCII:Amarante;ID:6319840', '7833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7833', '112', '9710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9711', '1079', '1', 'Angical do Piauí', 'BR.20.2200608', 'ASCII:Angical Do Piaui;ID:6319841', '7834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7834', '112', '9711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9712', '1079', '1', 'Anísio de Abreu', 'BR.20.2200707', 'ASCII:Anisio De Abreu;ID:6319842', '7835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7835', '112', '9712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9713', '1079', '1', 'Antônio Almeida', 'BR.20.2200806', 'ASCII:Antonio Almeida;ID:6319843', '7836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7836', '112', '9713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9714', '1079', '1', 'Aroazes', 'BR.20.2200905', 'ASCII:Aroazes;ID:6319844', '7837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7837', '112', '9714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9715', '1079', '1', 'Arraial', 'BR.20.2201002', 'ASCII:Arraial;ID:6319845', '7838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7838', '112', '9715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9716', '1079', '1', 'Assunção do Piauí', 'BR.20.2201051', 'ASCII:Assuncao Do Piaui;ID:6319846', '7839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7839', '112', '9716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9717', '1079', '1', 'Baixa Grande do Ribeiro', 'BR.20.2201150', 'ASCII:Baixa Grande Do Ribeiro;ID:6319847', '7840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7840', '112', '9717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9718', '1079', '1', 'Barra d''Alcântara', 'BR.20.2201176', 'ASCII:Barra D''Alcantara;ID:6319848', '7841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7841', '112', '9718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9719', '1079', '1', 'Barras', 'BR.20.2201200', 'ASCII:Barras;ID:6319849', '7842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7842', '112', '9719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9720', '1079', '1', 'Barreiras do Piauí', 'BR.20.2201309', 'ASCII:Barreiras Do Piaui;ID:6319850', '7843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7843', '112', '9720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9721', '1079', '1', 'Barro Duro', 'BR.20.2201408', 'ASCII:Barro Duro;ID:6319851', '7844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7844', '112', '9721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9722', '1079', '1', 'Bela Vista do Piauí', 'BR.20.2201556', 'ASCII:Bela Vista Do Piaui;ID:6319852', '7845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7845', '112', '9722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9723', '1079', '1', 'Belém do Piauí', 'BR.20.2201572', 'ASCII:Belem Do Piaui;ID:6319853', '7846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7846', '112', '9723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9724', '1079', '1', 'Bertolínia', 'BR.20.2201705', 'ASCII:Bertolinia;ID:6319854', '7847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7847', '112', '9724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9725', '1079', '1', 'Betânia do Piauí', 'BR.20.2201739', 'ASCII:Betania Do Piaui;ID:6319855', '7848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7848', '112', '9725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9726', '1079', '1', 'Boa Hora', 'BR.20.2201770', 'ASCII:Boa Hora;ID:6319856', '7849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7849', '112', '9726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9727', '1079', '1', 'Bocaina', 'BR.20.2201804', 'ASCII:Bocaina;ID:6319857', '7850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7850', '112', '9727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9728', '1079', '1', 'Bom Jesus', 'BR.20.2201903', 'ASCII:Bom Jesus;ID:6319858', '7851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7851', '112', '9728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9729', '1079', '1', 'Bom Princípio do Piauí', 'BR.20.2201919', 'ASCII:Bom Principio Do Piaui;ID:6319859', '7852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7852', '112', '9729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9730', '1079', '1', 'Bonfim do Piauí', 'BR.20.2201929', 'ASCII:Bonfim Do Piaui;ID:6319860', '7853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7853', '112', '9730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9731', '1079', '1', 'Boqueirão do Piauí', 'BR.20.2201945', 'ASCII:Boqueirao Do Piaui;ID:6319861', '7854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7854', '112', '9731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9732', '1079', '1', 'Brasileira', 'BR.20.2201960', 'ASCII:Brasileira;ID:6319862', '7855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7855', '112', '9732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9733', '1079', '1', 'Brejo do Piauí', 'BR.20.2201988', 'ASCII:Brejo Do Piaui;ID:6319863', '7856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7856', '112', '9733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9734', '1079', '1', 'Buriti dos Lopes', 'BR.20.2202000', 'ASCII:Buriti Dos Lopes;ID:6319864', '7857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7857', '112', '9734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9735', '1079', '1', 'Buriti dos Montes', 'BR.20.2202026', 'ASCII:Buriti Dos Montes;ID:6319865', '7858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7858', '112', '9735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9736', '1079', '1', 'Cabeceiras do Piauí', 'BR.20.2202059', 'ASCII:Cabeceiras Do Piaui;ID:6319866', '7859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7859', '112', '9736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9737', '1079', '1', 'Cajazeiras do Piauí', 'BR.20.2202075', 'ASCII:Cajazeiras Do Piaui;ID:6319867', '7860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7860', '112', '9737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9738', '1079', '1', 'Cajueiro da Praia', 'BR.20.2202083', 'ASCII:Cajueiro Da Praia;ID:6319868', '7861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7861', '112', '9738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9739', '1079', '1', 'Caldeirão Grande do Piauí', 'BR.20.2202091', 'ASCII:Caldeirao Grande Do Piaui;ID:6319869', '7862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7862', '112', '9739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9740', '1079', '1', 'Campinas do Piauí', 'BR.20.2202109', 'ASCII:Campinas Do Piaui;ID:6319870', '7863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7863', '112', '9740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9741', '1079', '1', 'Campo Alegre do Fidalgo', 'BR.20.2202117', 'ASCII:Campo Alegre Do Fidalgo;ID:6319871', '7864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7864', '112', '9741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9742', '1079', '1', 'Campo Grande do Piauí', 'BR.20.2202133', 'ASCII:Campo Grande Do Piaui;ID:6319872', '7865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7865', '112', '9742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9743', '1079', '1', 'Campo Largo do Piauí', 'BR.20.2202174', 'ASCII:Campo Largo Do Piaui;ID:6319873', '7866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7866', '112', '9743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9744', '1079', '1', 'Campo Maior', 'BR.20.2202208', 'ASCII:Campo Maior;ID:6319874', '7867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7867', '112', '9744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9745', '1079', '1', 'Canavieira', 'BR.20.2202251', 'ASCII:Canavieira;ID:6319875', '7868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7868', '112', '9745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9746', '1079', '1', 'Canto do Buriti', 'BR.20.2202307', 'ASCII:Canto Do Buriti;ID:6319876', '7869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7869', '112', '9746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9747', '1079', '1', 'Capitão de Campos', 'BR.20.2202406', 'ASCII:Capitao De Campos;ID:6319877', '7870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7870', '112', '9747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9748', '1079', '1', 'Capitão Gervásio Oliveira', 'BR.20.2202455', 'ASCII:Capitao Gervasio Oliveira;ID:6319878', '7871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7871', '112', '9748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9749', '1079', '1', 'Caracol', 'BR.20.2202505', 'ASCII:Caracol;ID:6319879', '7872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7872', '112', '9749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9750', '1079', '1', 'Caraúbas do Piauí', 'BR.20.2202539', 'ASCII:Caraubas Do Piaui;ID:6319880', '7873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7873', '112', '9750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9751', '1079', '1', 'Castelo do Piauí', 'BR.20.2202604', 'ASCII:Castelo Do Piaui;ID:6319881', '7874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7874', '112', '9751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9752', '1079', '1', 'Caxingó', 'BR.20.2202653', 'ASCII:Caxingo;ID:6319882', '7875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7875', '112', '9752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9753', '1079', '1', 'Cocal', 'BR.20.2202703', 'ASCII:Cocal;ID:6319883', '7876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7876', '112', '9753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9754', '1079', '1', 'Cocal de Telha', 'BR.20.2202711', 'ASCII:Cocal De Telha;ID:6319884', '7877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7877', '112', '9754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9755', '1079', '1', 'Cocal dos Alves', 'BR.20.2202729', 'ASCII:Cocal Dos Alves;ID:6319885', '7878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7878', '112', '9755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9756', '1079', '1', 'Coivaras', 'BR.20.2202737', 'ASCII:Coivaras;ID:6319886', '7879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7879', '112', '9756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9757', '1079', '1', 'Colônia do Gurguéia', 'BR.20.2202752', 'ASCII:Colonia Do Gurgueia;ID:6319887', '7880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7880', '112', '9757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9758', '1079', '1', 'Colônia do Piauí', 'BR.20.2202778', 'ASCII:Colonia Do Piaui;ID:6319888', '7881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7881', '112', '9758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9759', '1079', '1', 'Conceição do Canindé', 'BR.20.2202802', 'ASCII:Conceicao Do Caninde;ID:6319889', '7882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7882', '112', '9759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9760', '1079', '1', 'Coronel José Dias', 'BR.20.2202851', 'ASCII:Coronel Jose Dias;ID:6319890', '7883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7883', '112', '9760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9761', '1079', '1', 'Corrente', 'BR.20.2202901', 'ASCII:Corrente;ID:6319891', '7884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7884', '112', '9761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2202901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9762', '1079', '1', 'Cristalândia do Piauí', 'BR.20.2203008', 'ASCII:Cristalandia Do Piaui;ID:6319892', '7885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7885', '112', '9762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9763', '1079', '1', 'Cristino Castro', 'BR.20.2203107', 'ASCII:Cristino Castro;ID:6319893', '7886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7886', '112', '9763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9764', '1079', '1', 'Currais', 'BR.20.2203230', 'ASCII:Currais;ID:6319894', '7887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7887', '112', '9764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9765', '1079', '1', 'Curralinhos', 'BR.20.2203255', 'ASCII:Curralinhos;ID:6319895', '7888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7888', '112', '9765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9766', '1079', '1', 'Demerval Lobão', 'BR.20.2203305', 'ASCII:Demerval Lobao;ID:6319896', '7889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7889', '112', '9766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9767', '1079', '1', 'Dom Expedito Lopes', 'BR.20.2203404', 'ASCII:Dom Expedito Lopes;ID:6319897', '7890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7890', '112', '9767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9768', '1079', '1', 'Domingos Mourão', 'BR.20.2203420', 'ASCII:Domingos Mourao;ID:6319898', '7891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7891', '112', '9768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9769', '1079', '1', 'Dom Inocêncio', 'BR.20.2203453', 'ASCII:Dom Inocencio;ID:6319899', '7892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7892', '112', '9769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9770', '1079', '1', 'Elesbão Veloso', 'BR.20.2203503', 'ASCII:Elesbao Veloso;ID:6319900', '7893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7893', '112', '9770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9771', '1079', '1', 'Eliseu Martins', 'BR.20.2203602', 'ASCII:Eliseu Martins;ID:6319901', '7894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7894', '112', '9771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9772', '1079', '1', 'Esperantina', 'BR.20.2203701', 'ASCII:Esperantina;ID:6319902', '7895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7895', '112', '9772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9773', '1079', '1', 'Fartura do Piauí', 'BR.20.2203750', 'ASCII:Fartura Do Piaui;ID:6319903', '7896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7896', '112', '9773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9774', '1079', '1', 'Flores do Piauí', 'BR.20.2203800', 'ASCII:Flores Do Piaui;ID:6319904', '7897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7897', '112', '9774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9775', '1079', '1', 'Floresta do Piauí', 'BR.20.2203859', 'ASCII:Floresta Do Piaui;ID:6319905', '7898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7898', '112', '9775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9776', '1079', '1', 'Francinópolis', 'BR.20.2204006', 'ASCII:Francinopolis;ID:6319906', '7899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7899', '112', '9776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9777', '1079', '1', 'Francisco Ayres', 'BR.20.2204105', 'ASCII:Francisco Ayres;ID:6319907', '7900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7900', '112', '9777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9778', '1079', '1', 'Francisco Macedo', 'BR.20.2204154', 'ASCII:Francisco Macedo;ID:6319908', '7901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7901', '112', '9778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9779', '1079', '1', 'Francisco Santos', 'BR.20.2204204', 'ASCII:Francisco Santos;ID:6319909', '7902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7902', '112', '9779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9780', '1079', '1', 'Geminiano', 'BR.20.2204352', 'ASCII:Geminiano;ID:6319910', '7903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7903', '112', '9780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9781', '1079', '1', 'Gilbués', 'BR.20.2204402', 'ASCII:Gilbues;ID:6319911', '7904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7904', '112', '9781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9782', '1079', '1', 'Guadalupe', 'BR.20.2204501', 'ASCII:Guadalupe;ID:6319912', '7905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7905', '112', '9782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9783', '1079', '1', 'Guaribas', 'BR.20.2204550', 'ASCII:Guaribas;ID:6319913', '7906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7906', '112', '9783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9784', '1079', '1', 'Hugo Napoleão', 'BR.20.2204600', 'ASCII:Hugo Napoleao;ID:6319914', '7907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7907', '112', '9784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9785', '1079', '1', 'Ilha Grande', 'BR.20.2204659', 'ASCII:Ilha Grande;ID:6319915', '7908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7908', '112', '9785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9786', '1079', '1', 'Inhuma', 'BR.20.2204709', 'ASCII:Inhuma;ID:6319916', '7909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7909', '112', '9786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9787', '1079', '1', 'Ipiranga do Piauí', 'BR.20.2204808', 'ASCII:Ipiranga Do Piaui;ID:6319917', '7910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7910', '112', '9787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9788', '1079', '1', 'Isaías Coelho', 'BR.20.2204907', 'ASCII:Isaias Coelho;ID:6319918', '7911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7911', '112', '9788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2204907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9789', '1079', '1', 'Itainópolis', 'BR.20.2205003', 'ASCII:Itainopolis;ID:6319919', '7912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7912', '112', '9789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9790', '1079', '1', 'Itaueira', 'BR.20.2205102', 'ASCII:Itaueira;ID:6319920', '7913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7913', '112', '9790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9791', '1079', '1', 'Jacobina do Piauí', 'BR.20.2205151', 'ASCII:Jacobina Do Piaui;ID:6319921', '7914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7914', '112', '9791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9792', '1079', '1', 'Jaicós', 'BR.20.2205201', 'ASCII:Jaicos;ID:6319922', '7915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7915', '112', '9792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9793', '1079', '1', 'Jardim do Mulato', 'BR.20.2205250', 'ASCII:Jardim Do Mulato;ID:6319923', '7916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7916', '112', '9793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9794', '1079', '1', 'João Costa', 'BR.20.2205359', 'ASCII:Joao Costa;ID:6319924', '7917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7917', '112', '9794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9795', '1079', '1', 'Joaquim Pires', 'BR.20.2205409', 'ASCII:Joaquim Pires;ID:6319925', '7918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7918', '112', '9795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9796', '1079', '1', 'Joca Marques', 'BR.20.2205458', 'ASCII:Joca Marques;ID:6319926', '7919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7919', '112', '9796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9797', '1079', '1', 'José de Freitas', 'BR.20.2205508', 'ASCII:Jose De Freitas;ID:6319927', '7920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7920', '112', '9797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9798', '1079', '1', 'Juazeiro do Piauí', 'BR.20.2205516', 'ASCII:Juazeiro Do Piaui;ID:6319928', '7921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7921', '112', '9798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9799', '1079', '1', 'Júlio Borges', 'BR.20.2205524', 'ASCII:Julio Borges;ID:6319929', '7922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7922', '112', '9799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9800', '1079', '1', 'Jurema', 'BR.20.2205532', 'ASCII:Jurema;ID:6319930', '7923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7923', '112', '9800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9801', '1079', '1', 'Lagoinha do Piauí', 'BR.20.2205540', 'ASCII:Lagoinha Do Piaui;ID:6319931', '7924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7924', '112', '9801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9802', '1079', '1', 'Lagoa Alegre', 'BR.20.2205557', 'ASCII:Lagoa Alegre;ID:6319932', '7925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7925', '112', '9802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9803', '1079', '1', 'Lagoa do Barro do Piauí', 'BR.20.2205565', 'ASCII:Lagoa Do Barro Do Piaui;ID:6319933', '7926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7926', '112', '9803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205565» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9804', '1079', '1', 'Lagoa de São Francisco', 'BR.20.2205573', 'ASCII:Lagoa De Sao Francisco;ID:6319934', '7927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7927', '112', '9804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9805', '1079', '1', 'Lagoa do Piauí', 'BR.20.2205581', 'ASCII:Lagoa Do Piaui;ID:6319935', '7928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7928', '112', '9805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9806', '1079', '1', 'Lagoa do Sítio', 'BR.20.2205599', 'ASCII:Lagoa Do Sitio;ID:6319936', '7929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7929', '112', '9806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9807', '1079', '1', 'Landri Sales', 'BR.20.2205607', 'ASCII:Landri Sales;ID:6319937', '7930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7930', '112', '9807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9808', '1079', '1', 'Luís Correia', 'BR.20.2205706', 'ASCII:Luis Correia;ID:6319938', '7931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7931', '112', '9808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9809', '1079', '1', 'Luzilândia', 'BR.20.2205805', 'ASCII:Luzilandia;ID:6319939', '7932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7932', '112', '9809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9810', '1079', '1', 'Madeiro', 'BR.20.2205854', 'ASCII:Madeiro;ID:6319940', '7933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7933', '112', '9810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9811', '1079', '1', 'Manoel Emídio', 'BR.20.2205904', 'ASCII:Manoel Emidio;ID:6319941', '7934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7934', '112', '9811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9812', '1079', '1', 'Marcolândia', 'BR.20.2205953', 'ASCII:Marcolandia;ID:6319942', '7935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7935', '112', '9812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2205953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9813', '1079', '1', 'Marcos Parente', 'BR.20.2206001', 'ASCII:Marcos Parente;ID:6319943', '7936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7936', '112', '9813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9814', '1079', '1', 'Massapê do Piauí', 'BR.20.2206050', 'ASCII:Massape Do Piaui;ID:6319944', '7937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7937', '112', '9814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9815', '1079', '1', 'Matias Olímpio', 'BR.20.2206100', 'ASCII:Matias Olimpio;ID:6319945', '7938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7938', '112', '9815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9816', '1079', '1', 'Miguel Alves', 'BR.20.2206209', 'ASCII:Miguel Alves;ID:6319946', '7939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7939', '112', '9816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9817', '1079', '1', 'Miguel Leão', 'BR.20.2206308', 'ASCII:Miguel Leao;ID:6319947', '7940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7940', '112', '9817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9818', '1079', '1', 'Milton Brandão', 'BR.20.2206357', 'ASCII:Milton Brandao;ID:6319948', '7941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7941', '112', '9818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9819', '1079', '1', 'Monsenhor Gil', 'BR.20.2206407', 'ASCII:Monsenhor Gil;ID:6319949', '7942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7942', '112', '9819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9820', '1079', '1', 'Monsenhor Hipólito', 'BR.20.2206506', 'ASCII:Monsenhor Hipolito;ID:6319950', '7943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7943', '112', '9820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9821', '1079', '1', 'Monte Alegre do Piauí', 'BR.20.2206605', 'ASCII:Monte Alegre Do Piaui;ID:6319951', '7944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7944', '112', '9821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9822', '1079', '1', 'Morro do Chapéu do Piauí', 'BR.20.2206670', 'ASCII:Morro Do Chapeu Do Piaui;ID:6319952', '7945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7945', '112', '9822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9823', '1079', '1', 'Murici dos Portelas', 'BR.20.2206696', 'ASCII:Murici Dos Portelas;ID:6319953', '7946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7946', '112', '9823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9824', '1079', '1', 'Nazaré do Piauí', 'BR.20.2206704', 'ASCII:Nazare Do Piaui;ID:6319954', '7947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7947', '112', '9824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9825', '1079', '1', 'Nossa Senhora de Nazaré', 'BR.20.2206753', 'ASCII:Nossa Senhora De Nazare;ID:6319955', '7948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7948', '112', '9825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9826', '1079', '1', 'Nossa Senhora dos Remédios', 'BR.20.2206803', 'ASCII:Nossa Senhora Dos Remedios;ID:6319956', '7949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7949', '112', '9826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9827', '1079', '1', 'Novo Oriente do Piauí', 'BR.20.2206902', 'ASCII:Novo Oriente Do Piaui;ID:6319957', '7950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7950', '112', '9827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9828', '1079', '1', 'Novo Santo Antônio', 'BR.20.2206951', 'ASCII:Novo Santo Antonio;ID:6319958', '7951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7951', '112', '9828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9829', '1079', '1', 'Oeiras', 'BR.20.2207009', 'ASCII:Oeiras;ID:6319959', '7952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7952', '112', '9829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9830', '1079', '1', 'Olho d''Água do Piauí', 'BR.20.2207108', 'ASCII:Olho D''Agua Do Piaui;ID:6319960', '7953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7953', '112', '9830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9831', '1079', '1', 'Padre Marcos', 'BR.20.2207207', 'ASCII:Padre Marcos;ID:6319961', '7954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7954', '112', '9831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9832', '1079', '1', 'Paes Landim', 'BR.20.2207306', 'ASCII:Paes Landim;ID:6319962', '7955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7955', '112', '9832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9833', '1079', '1', 'Pajeú do Piauí', 'BR.20.2207355', 'ASCII:Pajeu Do Piaui;ID:6319963', '7956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7956', '112', '9833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9834', '1079', '1', 'Palmeira do Piauí', 'BR.20.2207405', 'ASCII:Palmeira Do Piaui;ID:6319964', '7957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7957', '112', '9834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9835', '1079', '1', 'Palmeirais', 'BR.20.2207504', 'ASCII:Palmeirais;ID:6319965', '7958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7958', '112', '9835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9836', '1079', '1', 'Paquetá', 'BR.20.2207553', 'ASCII:Paqueta;ID:6319966', '7959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7959', '112', '9836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9837', '1079', '1', 'Parnaíba', 'BR.20.2207702', 'ASCII:Parnaiba;ID:6319967', '7960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7960', '112', '9837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9838', '1079', '1', 'Passagem Franca do Piauí', 'BR.20.2207751', 'ASCII:Passagem Franca Do Piaui;ID:6319968', '7961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7961', '112', '9838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9839', '1079', '1', 'Patos do Piauí', 'BR.20.2207777', 'ASCII:Patos Do Piaui;ID:6319969', '7962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7962', '112', '9839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9840', '1079', '1', 'Paulistana', 'BR.20.2207801', 'ASCII:Paulistana;ID:6319970', '7963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7963', '112', '9840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9841', '1079', '1', 'Pavussu', 'BR.20.2207850', 'ASCII:Pavussu;ID:6319971', '7964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7964', '112', '9841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9842', '1079', '1', 'Pedro II', 'BR.20.2207900', 'ASCII:Pedro Ii;ID:6319972', '7965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7965', '112', '9842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9843', '1079', '1', 'Nova Santa Rita', 'BR.20.2207959', 'ASCII:Petronio Portela;ID:6319973', '7966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7966', '112', '9843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2207959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9844', '1079', '1', 'Picos', 'BR.20.2208007', 'ASCII:Picos;ID:6319974', '7967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7967', '112', '9844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9845', '1079', '1', 'Pimenteiras', 'BR.20.2208106', 'ASCII:Pimenteiras;ID:6319975', '7968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7968', '112', '9845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9846', '1079', '1', 'Pio IX', 'BR.20.2208205', 'ASCII:Pio Ix;ID:6319976', '7969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7969', '112', '9846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9847', '1079', '1', 'Piracuruca', 'BR.20.2208304', 'ASCII:Piracuruca;ID:6319977', '7970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7970', '112', '9847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9848', '1079', '1', 'Piripiri', 'BR.20.2208403', 'ASCII:Piripiri;ID:6319978', '7971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7971', '112', '9848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9849', '1079', '1', 'Porto', 'BR.20.2208502', 'ASCII:Porto;ID:6319979', '7972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7972', '112', '9849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9850', '1079', '1', 'Porto Alegre do Piauí', 'BR.20.2208551', 'ASCII:Porto Alegre Do Piaui;ID:6319980', '7973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7973', '112', '9850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9851', '1079', '1', 'Prata do Piauí', 'BR.20.2208601', 'ASCII:Prata Do Piaui;ID:6319981', '7974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7974', '112', '9851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9852', '1079', '1', 'Queimada Nova', 'BR.20.2208650', 'ASCII:Queimada Nova;ID:6319982', '7975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7975', '112', '9852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9853', '1079', '1', 'Redenção do Gurguéia', 'BR.20.2208700', 'ASCII:Redencao Do Gurgueia;ID:6319983', '7976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7976', '112', '9853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9854', '1079', '1', 'Regeneração', 'BR.20.2208809', 'ASCII:Regeneracao;ID:6319984', '7977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7977', '112', '9854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9855', '1079', '1', 'Riacho Frio', 'BR.20.2208858', 'ASCII:Riacho Frio;ID:6319985', '7978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7978', '112', '9855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9856', '1079', '1', 'Ribeira do Piauí', 'BR.20.2208874', 'ASCII:Ribeira Do Piaui;ID:6319986', '7979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7979', '112', '9856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9857', '1079', '1', 'Ribeiro Gonçalves', 'BR.20.2208908', 'ASCII:Ribeiro Goncalves;ID:6319987', '7980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7980', '112', '9857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2208908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9858', '1079', '1', 'Rio Grande do Piauí', 'BR.20.2209005', 'ASCII:Rio Grande Do Piaui;ID:6319988', '7981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7981', '112', '9858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9859', '1079', '1', 'Santa Cruz do Piauí', 'BR.20.2209104', 'ASCII:Santa Cruz Do Piaui;ID:6319989', '7982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7982', '112', '9859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9860', '1079', '1', 'Santa Filomena', 'BR.20.2209203', 'ASCII:Santa Filomena;ID:6319990', '7983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7983', '112', '9860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9861', '1079', '1', 'Santa Luz', 'BR.20.2209302', 'ASCII:Santa Luz;ID:6319991', '7984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7984', '112', '9861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9862', '1079', '1', 'Santana do Piauí', 'BR.20.2209351', 'ASCII:Santana Do Piaui;ID:6319992', '7985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7985', '112', '9862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9863', '1079', '1', 'Santa Rosa do Piauí', 'BR.20.2209377', 'ASCII:Santa Rosa Do Piaui;ID:6319993', '7986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7986', '112', '9863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9864', '1079', '1', 'Santo Antônio de Lisboa', 'BR.20.2209401', 'ASCII:Santo Antonio De Lisboa;ID:6319994', '7987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7987', '112', '9864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9865', '1079', '1', 'Santo Antônio dos Milagres', 'BR.20.2209450', 'ASCII:Santo Antonio Dos Milagres;ID:6319995', '7988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7988', '112', '9865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9866', '1079', '1', 'Santo Inácio do Piauí', 'BR.20.2209500', 'ASCII:Santo Inacio Do Piaui;ID:6319996', '7989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7989', '112', '9866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9867', '1079', '1', 'São Braz do Piauí', 'BR.20.2209559', 'ASCII:Sao Braz Do Piaui;ID:6319997', '7990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7990', '112', '9867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9868', '1079', '1', 'São Francisco de Assis do Piauí', 'BR.20.2209658', 'ASCII:Sao Francisco De Assis Do Piaui;ID:6319998', '7991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7991', '112', '9868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9869', '1079', '1', 'São Francisco do Piauí', 'BR.20.2209708', 'ASCII:Sao Francisco Do Piaui;ID:6319999', '7992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7992', '112', '9869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9870', '1079', '1', 'São Gonçalo do Gurguéia', 'BR.20.2209757', 'ASCII:Sao Goncalo Do Gurgueia;ID:6320000', '7993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7993', '112', '9870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9871', '1079', '1', 'São Gonçalo do Piauí', 'BR.20.2209807', 'ASCII:Sao Goncalo Do Piaui;ID:6320001', '7994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7994', '112', '9871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9872', '1079', '1', 'São João da Canabrava', 'BR.20.2209856', 'ASCII:Sao Joao Da Canabrava;ID:6320002', '7995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7995', '112', '9872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9873', '1079', '1', 'São João da Serra', 'BR.20.2209906', 'ASCII:Sao Joao Da Serra;ID:6320003', '7996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7996', '112', '9873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9874', '1079', '1', 'São João da Varjota', 'BR.20.2209955', 'ASCII:Sao Joao Da Varjota;ID:6320004', '7997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7997', '112', '9874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9875', '1079', '1', 'São João do Arraial', 'BR.20.2209971', 'ASCII:Sao Joao Do Arraial;ID:6320005', '7998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7998', '112', '9875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9876', '1079', '1', 'São João do Piauí', 'BR.20.2210003', 'ASCII:Sao Joao Do Piaui;ID:6320006', '7999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('7999', '112', '9876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9877', '1079', '1', 'São José do Divino', 'BR.20.2210052', 'ASCII:Sao Jose Do Divino;ID:6320007', '8000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8000', '112', '9877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9878', '1079', '1', 'São José do Peixe', 'BR.20.2210102', 'ASCII:Sao Jose Do Peixe;ID:6320008', '8001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8001', '112', '9878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9879', '1079', '1', 'São Julião', 'BR.20.2210300', 'ASCII:Sao Juliao;ID:6320009', '8002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8002', '112', '9879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9880', '1079', '1', 'São Lourenço do Piauí', 'BR.20.2210359', 'ASCII:Sao Lourenco Do Piaui;ID:6320010', '8003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8003', '112', '9880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9881', '1079', '1', 'São Luis do Piauí', 'BR.20.2210375', 'ASCII:Sao Luis Do Piaui;ID:6320011', '8004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8004', '112', '9881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9882', '1079', '1', 'São Miguel da Baixa Grande', 'BR.20.2210383', 'ASCII:Sao Miguel Da Baixa Grande;ID:6320012', '8005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8005', '112', '9882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9883', '1079', '1', 'São Miguel do Fidalgo', 'BR.20.2210391', 'ASCII:Sao Miguel Do Fidalgo;ID:6320013', '8006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8006', '112', '9883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9884', '1079', '1', 'São Miguel do Tapuio', 'BR.20.2210409', 'ASCII:Sao Miguel Do Tapuio;ID:6320014', '8007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8007', '112', '9884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9885', '1079', '1', 'São Pedro do Piauí', 'BR.20.2210508', 'ASCII:Sao Pedro Do Piaui;ID:6320015', '8008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8008', '112', '9885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9886', '1079', '1', 'São Raimundo Nonato', 'BR.20.2210607', 'ASCII:Sao Raimundo Nonato;ID:6320016', '8009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8009', '112', '9886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9887', '1079', '1', 'Sebastião Barros', 'BR.20.2210623', 'ASCII:Sebastiao Barros;ID:6320017', '8010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8010', '112', '9887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9888', '1079', '1', 'Sebastião Leal', 'BR.20.2210631', 'ASCII:Sebastiao Leal;ID:6320018', '8011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8011', '112', '9888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9889', '1079', '1', 'Sigefredo Pacheco', 'BR.20.2210656', 'ASCII:Sigefredo Pacheco;ID:6320019', '8012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8012', '112', '9889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9890', '1079', '1', 'Simplício Mendes', 'BR.20.2210805', 'ASCII:Simplicio Mendes;ID:6320020', '8013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8013', '112', '9890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9891', '1079', '1', 'Socorro do Piauí', 'BR.20.2210904', 'ASCII:Socorro Do Piaui;ID:6320021', '8014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8014', '112', '9891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9892', '1079', '1', 'Sussuapara', 'BR.20.2210938', 'ASCII:Sussuapara;ID:6320022', '8015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8015', '112', '9892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9893', '1079', '1', 'Tamboril do Piauí', 'BR.20.2210953', 'ASCII:Tamboril Do Piaui;ID:6320023', '8016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8016', '112', '9893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9894', '1079', '1', 'Tanque do Piauí', 'BR.20.2210979', 'ASCII:Tanque Do Piaui;ID:6320024', '8017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8017', '112', '9894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2210979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9895', '1079', '1', 'Teresina', 'BR.20.2211001', 'ASCII:Teresina;ID:6320025', '8018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8018', '112', '9895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2211001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9896', '1079', '1', 'União', 'BR.20.2211100', 'ASCII:Uniao;ID:6320026', '8019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8019', '112', '9896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2211100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9897', '1079', '1', 'Uruçuí', 'BR.20.2211209', 'ASCII:Urucui;ID:6320027', '8020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8020', '112', '9897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2211209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9898', '1079', '1', 'Valença do Piauí', 'BR.20.2211308', 'ASCII:Valenca Do Piaui;ID:6320028', '8021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8021', '112', '9898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2211308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9899', '1079', '1', 'Várzea Branca', 'BR.20.2211357', 'ASCII:Varzea Branca;ID:6320029', '8022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8022', '112', '9899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2211357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9900', '1079', '1', 'Várzea Grande', 'BR.20.2211407', 'ASCII:Varzea Grande;ID:6320030', '8023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8023', '112', '9900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2211407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9901', '1079', '1', 'Vera Mendes', 'BR.20.2211506', 'ASCII:Vera Mendes;ID:6320031', '8024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8024', '112', '9901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2211506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9902', '1079', '1', 'Vila Nova do Piauí', 'BR.20.2211605', 'ASCII:Vila Nova Do Piaui;ID:6320032', '8025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8025', '112', '9902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2211605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9903', '1079', '1', 'Wall Ferraz', 'BR.20.2211704', 'ASCII:Wall Ferraz;ID:6320033', '8026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8026', '112', '9903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2211704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9904', '1079', '1', 'Abaiara', 'BR.06.2300101', 'ASCII:Abaiara;ID:6320034', '8027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8027', '112', '9904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9905', '1079', '1', 'Acarapé', 'BR.06.2300150', 'ASCII:Acarape;ID:6320035', '8028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8028', '112', '9905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9906', '1079', '1', 'Acaraú', 'BR.06.2300200', 'ASCII:Acarau;ID:6320036', '8029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8029', '112', '9906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9907', '1079', '1', 'Alcântaras', 'BR.06.2300507', 'ASCII:Alcantaras;ID:6320037', '8030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8030', '112', '9907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9908', '1079', '1', 'Altaneira', 'BR.06.2300606', 'ASCII:Altaneira;ID:6320038', '8031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8031', '112', '9908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9909', '1079', '1', 'Alto Santo', 'BR.06.2300705', 'ASCII:Alto Santo;ID:6320039', '8032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8032', '112', '9909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9910', '1079', '1', 'Itapipoca', 'BR.06.2306405', 'ASCII:Itapipoca;ID:6320040', '8033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8033', '112', '9910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9911', '1079', '1', 'Antonina do Norte', 'BR.06.2300804', 'ASCII:Antonina Do Norte;ID:6320041', '8034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8034', '112', '9911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9912', '1079', '1', 'Aquiraz', 'BR.06.2301000', 'ASCII:Aquiraz;ID:6320042', '8035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8035', '112', '9912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9913', '1079', '1', 'Aratuba', 'BR.06.2301406', 'ASCII:Aratuba;ID:6320043', '8036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8036', '112', '9913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9914', '1079', '1', 'Arneiroz', 'BR.06.2301505', 'ASCII:Arneiroz;ID:6320044', '8037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8037', '112', '9914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9915', '1079', '1', 'Barreira', 'BR.06.2301950', 'ASCII:Barreira;ID:6320045', '8038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8038', '112', '9915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9916', '1079', '1', 'Barroquinha', 'BR.06.2302057', 'ASCII:Barroquinha;ID:6320046', '8039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8039', '112', '9916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9917', '1079', '1', 'Beberibe', 'BR.06.2302206', 'ASCII:Beberibe;ID:6320047', '8040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8040', '112', '9917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9918', '1079', '1', 'Bela Cruz', 'BR.06.2302305', 'ASCII:Bela Cruz;ID:6320048', '8041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8041', '112', '9918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9919', '1079', '1', 'Camocim', 'BR.06.2302602', 'ASCII:Camocim;ID:6320049', '8042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8042', '112', '9919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2302602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9920', '1079', '1', 'Caridade', 'BR.06.2303006', 'ASCII:Caridade;ID:6320050', '8043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8043', '112', '9920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9921', '1079', '1', 'Carnaubal', 'BR.06.2303402', 'ASCII:Carnaubal;ID:6320051', '8044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8044', '112', '9921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9922', '1079', '1', 'Cascavel', 'BR.06.2303501', 'ASCII:Cascavel;ID:6320052', '8045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8045', '112', '9922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9923', '1079', '1', 'Catarina', 'BR.06.2303600', 'ASCII:Catarina;ID:6320053', '8046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8046', '112', '9923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9924', '1079', '1', 'Catunda', 'BR.06.2303659', 'ASCII:Catunda;ID:6320054', '8047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8047', '112', '9924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9925', '1079', '1', 'Caucaia', 'BR.06.2303709', 'ASCII:Caucaia;ID:6320055', '8048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8048', '112', '9925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9926', '1079', '1', 'Chaval', 'BR.06.2303907', 'ASCII:Chaval;ID:6320056', '8049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8049', '112', '9926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9927', '1079', '1', 'Choró', 'BR.06.2303931', 'ASCII:Choro;ID:6320057', '8050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8050', '112', '9927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303931» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9928', '1079', '1', 'Chorozinho', 'BR.06.2303956', 'ASCII:Chorozinho;ID:6320058', '8051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8051', '112', '9928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2303956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9929', '1079', '1', 'Cruz', 'BR.06.2304251', 'ASCII:Cruz;ID:6320059', '8052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8052', '112', '9929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9930', '1079', '1', 'Deputado Irapuan Pinheiro', 'BR.06.2304269', 'ASCII:Deputado Irapuan Pinheiro;ID:6320060', '8053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8053', '112', '9930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9931', '1079', '1', 'Eusébio', 'BR.06.2304285', 'ASCII:Eusebio;ID:6320061', '8054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8054', '112', '9931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9932', '1079', '1', 'Fortaleza', 'BR.06.2304400', 'ASCII:Fortaleza;ID:6320062', '8055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8055', '112', '9932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9933', '1079', '1', 'Fortim', 'BR.06.2304459', 'ASCII:Fortim;ID:6320063', '8056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8056', '112', '9933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9934', '1079', '1', 'General Sampaio', 'BR.06.2304608', 'ASCII:General Sampaio;ID:6320064', '8057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8057', '112', '9934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9935', '1079', '1', 'Granjeiro', 'BR.06.2304806', 'ASCII:Granjeiro;ID:6320065', '8058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8058', '112', '9935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9936', '1079', '1', 'Groaíras', 'BR.06.2304905', 'ASCII:Groairas;ID:6320066', '8059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8059', '112', '9936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9937', '1079', '1', 'Guaiúba', 'BR.06.2304954', 'ASCII:Guaiuba;ID:6320067', '8060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8060', '112', '9937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9938', '1079', '1', 'Guaramiranga', 'BR.06.2305100', 'ASCII:Guaramiranga;ID:6320068', '8061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8061', '112', '9938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9939', '1079', '1', 'Horizonte', 'BR.06.2305233', 'ASCII:Horizonte;ID:6320069', '8062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8062', '112', '9939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9940', '1079', '1', 'Ibaretama', 'BR.06.2305266', 'ASCII:Ibaretama;ID:6320070', '8063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8063', '112', '9940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9941', '1079', '1', 'Ibicuitinga', 'BR.06.2305332', 'ASCII:Ibicuitinga;ID:6320071', '8064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8064', '112', '9941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9942', '1079', '1', 'Icapuí', 'BR.06.2305357', 'ASCII:Icapui;ID:6320072', '8065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8065', '112', '9942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9943', '1079', '1', 'Ipaporanga', 'BR.06.2305654', 'ASCII:Ipaporanga;ID:6320073', '8066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8066', '112', '9943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9944', '1079', '1', 'Amontada', 'BR.06.2300754', 'ASCII:Amontada;ID:6320074', '8067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8067', '112', '9944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9945', '1079', '1', 'Itarema', 'BR.06.2306553', 'ASCII:Itarema;ID:6320075', '8068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8068', '112', '9945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9946', '1079', '1', 'Jijoca de Jericoacoara', 'BR.06.2307254', 'ASCII:Jijoca De Jericoacoara;ID:6320076', '8069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8069', '112', '9946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9947', '1079', '1', 'Maracanaú', 'BR.06.2307650', 'ASCII:Maracanau;ID:6320077', '8070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8070', '112', '9947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9948', '1079', '1', 'Marco', 'BR.06.2307809', 'ASCII:Marco;ID:6320078', '8071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8071', '112', '9948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9949', '1079', '1', 'Martinópole', 'BR.06.2307908', 'ASCII:Martinopole;ID:6320079', '8072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8072', '112', '9949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9950', '1079', '1', 'Miraíma', 'BR.06.2308377', 'ASCII:Miraima;ID:6320080', '8073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8073', '112', '9950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9951', '1079', '1', 'Morada Nova', 'BR.06.2308708', 'ASCII:Morada Nova;ID:6320081', '8074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8074', '112', '9951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9952', '1079', '1', 'Moraújo', 'BR.06.2308807', 'ASCII:Moraujo;ID:6320082', '8075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8075', '112', '9952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9953', '1079', '1', 'Morrinhos', 'BR.06.2308906', 'ASCII:Morrinhos;ID:6320083', '8076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8076', '112', '9953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9954', '1079', '1', 'Mulungu', 'BR.06.2309102', 'ASCII:Mulungu;ID:6320084', '8077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8077', '112', '9954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9955', '1079', '1', 'Novo Oriente', 'BR.06.2309409', 'ASCII:Novo Oriente;ID:6320085', '8078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8078', '112', '9955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9956', '1079', '1', 'Orós', 'BR.06.2309508', 'ASCII:Oros;ID:6320086', '8079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8079', '112', '9956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9957', '1079', '1', 'Pacajus', 'BR.06.2309607', 'ASCII:Pacajus;ID:6320087', '8080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8080', '112', '9957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9958', '1079', '1', 'Pacujá', 'BR.06.2309904', 'ASCII:Pacuja;ID:6320088', '8081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8081', '112', '9958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9959', '1079', '1', 'Palmácia', 'BR.06.2310100', 'ASCII:Palmacia;ID:6320089', '8082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8082', '112', '9959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9960', '1079', '1', 'Paracuru', 'BR.06.2310209', 'ASCII:Paracuru;ID:6320090', '8083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8083', '112', '9960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9961', '1079', '1', 'Paraipaba', 'BR.06.2310258', 'ASCII:Paraipaba;ID:6320091', '8084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8084', '112', '9961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9962', '1079', '1', 'Paramoti', 'BR.06.2310407', 'ASCII:Paramoti;ID:6320092', '8085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8085', '112', '9962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9963', '1079', '1', 'Penaforte', 'BR.06.2310605', 'ASCII:Penaforte;ID:6320093', '8086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8086', '112', '9963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9964', '1079', '1', 'Pindoretama', 'BR.06.2310852', 'ASCII:Pindoretama;ID:6320094', '8087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8087', '112', '9964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9965', '1079', '1', 'Piquet Carneiro', 'BR.06.2310902', 'ASCII:Piquet Carneiro;ID:6320095', '8088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8088', '112', '9965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9966', '1079', '1', 'Pires Ferreira', 'BR.06.2310951', 'ASCII:Pires Ferreira;ID:6320096', '8089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8089', '112', '9966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9967', '1079', '1', 'Poranga', 'BR.06.2311009', 'ASCII:Poranga;ID:6320097', '8090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8090', '112', '9967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9968', '1079', '1', 'Potengi', 'BR.06.2311207', 'ASCII:Potengi;ID:6320098', '8091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8091', '112', '9968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9969', '1079', '1', 'Quiterianópolis', 'BR.06.2311264', 'ASCII:Quiterianopolis;ID:6320099', '8092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8092', '112', '9969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9970', '1079', '1', 'Quixeré', 'BR.06.2311504', 'ASCII:Quixere;ID:6320100', '8093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8093', '112', '9970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9971', '1079', '1', 'Salitre', 'BR.06.2311959', 'ASCII:Salitre;ID:6320101', '8094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8094', '112', '9971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9972', '1079', '1', 'Santana do Acaraú', 'BR.06.2312007', 'ASCII:Santana Do Acarau;ID:6320102', '8095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8095', '112', '9972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2312007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9973', '1079', '1', 'São Gonçalo do Amarante', 'BR.06.2312403', 'ASCII:Sao Goncalo Do Amarante;ID:6320103', '8096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8096', '112', '9973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2312403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9974', '1079', '1', 'São João do Jaguaribe', 'BR.06.2312502', 'ASCII:Sao Joao Do Jaguaribe;ID:6320104', '8097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8097', '112', '9974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2312502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9975', '1079', '1', 'São Luís do Curu', 'BR.06.2312601', 'ASCII:Sao Luis Do Curu;ID:6320105', '8098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8098', '112', '9975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2312601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9976', '1079', '1', 'Tarrafas', 'BR.06.2313252', 'ASCII:Tarrafas;ID:6320106', '8099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8099', '112', '9976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9977', '1079', '1', 'Tejuçuoca', 'BR.06.2313351', 'ASCII:Tejucuoca;ID:6320107', '8100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8100', '112', '9977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9978', '1079', '1', 'Trairi', 'BR.06.2313500', 'ASCII:Trairi;ID:6320108', '8101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8101', '112', '9978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9979', '1079', '1', 'Tururu', 'BR.06.2313559', 'ASCII:Tururu;ID:6320109', '8102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8102', '112', '9979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9980', '1079', '1', 'Umirim', 'BR.06.2313757', 'ASCII:Umirim;ID:6320110', '8103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8103', '112', '9980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9981', '1079', '1', 'Uruburetama', 'BR.06.2313807', 'ASCII:Uruburetama;ID:6320111', '8104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8104', '112', '9981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9982', '1079', '1', 'Uruoca', 'BR.06.2313906', 'ASCII:Uruoca;ID:6320112', '8105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8105', '112', '9982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9983', '1079', '1', 'Acari', 'BR.22.2400109', 'ASCII:Acari;ID:6320113', '8106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8106', '112', '9983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2400109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9984', '1079', '1', 'Açu', 'BR.22.2400208', 'ASCII:Acu;ID:6320114', '8107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8107', '112', '9984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2400208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9985', '1079', '1', 'Afonso Bezerra', 'BR.22.2400307', 'ASCII:Afonso Bezerra;ID:6320115', '8108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8108', '112', '9985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2400307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9986', '1079', '1', 'Água Nova', 'BR.22.2400406', 'ASCII:Agua Nova;ID:6320116', '8109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8109', '112', '9986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2400406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9987', '1079', '1', 'Almino Afonso', 'BR.22.2400604', 'ASCII:Almino Afonso;ID:6320117', '8110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8110', '112', '9987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2400604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9988', '1079', '1', 'Alto do Rodrigues', 'BR.22.2400703', 'ASCII:Alto Do Rodrigues;ID:6320118', '8111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8111', '112', '9988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2400703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9989', '1079', '1', 'Antônio Martins', 'BR.22.2400901', 'ASCII:Antonio Martins;ID:6320119', '8112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8112', '112', '9989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2400901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9990', '1079', '1', 'Apodi', 'BR.22.2401008', 'ASCII:Apodi;ID:6320120', '8113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8113', '112', '9990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9991', '1079', '1', 'Areia Branca', 'BR.22.2401107', 'ASCII:Areia Branca;ID:6320121', '8114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8114', '112', '9991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9992', '1079', '1', 'Arês', 'BR.22.2401206', 'ASCII:Ares;ID:6320122', '8115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8115', '112', '9992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9993', '1079', '1', 'Augusto Severo', 'BR.22.2401305', 'ASCII:Augusto Severo;ID:6320123', '8116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8116', '112', '9993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9994', '1079', '1', 'Baía Formosa', 'BR.22.2401404', 'ASCII:Baia Formosa;ID:6320124', '8117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8117', '112', '9994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9995', '1079', '1', 'Baraúna', 'BR.22.2401453', 'ASCII:Barauna;ID:6320125', '8118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8118', '112', '9995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9996', '1079', '1', 'Barcelona', 'BR.22.2401503', 'ASCII:Barcelona;ID:6320126', '8119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8119', '112', '9996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9997', '1079', '1', 'Bento Fernandes', 'BR.22.2401602', 'ASCII:Bento Fernandes;ID:6320127', '8120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8120', '112', '9997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9998', '1079', '1', 'Bodó', 'BR.22.2401651', 'ASCII:Bodo;ID:6320128', '8121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8121', '112', '9998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('9999', '1079', '1', 'Brejinho', 'BR.22.2401800', 'ASCII:Brejinho;ID:6320129', '8122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8122', '112', '9999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10000', '1079', '1', 'Caiçara do Norte', 'BR.22.2401859', 'ASCII:Caicara Do Norte;ID:6320130', '8123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8123', '112', '10000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10001', '1079', '1', 'Caicó', 'BR.22.2402006', 'ASCII:Caico;ID:6320131', '8124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8124', '112', '10001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2402006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10002', '1079', '1', 'Campo Redondo', 'BR.22.2402105', 'ASCII:Campo Redondo;ID:6320132', '8125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8125', '112', '10002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2402105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10003', '1079', '1', 'Canguaretama', 'BR.22.2402204', 'ASCII:Canguaretama;ID:6320133', '8126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8126', '112', '10003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2402204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10004', '1079', '1', 'Caraúbas', 'BR.22.2402303', 'ASCII:Caraubas;ID:6320134', '8127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8127', '112', '10004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2402303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10005', '1079', '1', 'Carnaubais', 'BR.22.2402501', 'ASCII:Carnaubais;ID:6320135', '8128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8128', '112', '10005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2402501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10006', '1079', '1', 'Ceará-Mirim', 'BR.22.2402600', 'ASCII:Ceara-Mirim;ID:6320136', '8129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8129', '112', '10006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2402600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10007', '1079', '1', 'Cerro Corá', 'BR.22.2402709', 'ASCII:Cerro Cora;ID:6320137', '8130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8130', '112', '10007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2402709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10008', '1079', '1', 'Coronel Ezequiel', 'BR.22.2402808', 'ASCII:Coronel Ezequiel;ID:6320138', '8131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8131', '112', '10008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2402808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10009', '1079', '1', 'Coronel João Pessoa', 'BR.22.2402907', 'ASCII:Coronel Joao Pessoa;ID:6320139', '8132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8132', '112', '10009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2402907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10010', '1079', '1', 'Cruzeta', 'BR.22.2403004', 'ASCII:Cruzeta;ID:6320140', '8133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8133', '112', '10010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10011', '1079', '1', 'Currais Novos', 'BR.22.2403103', 'ASCII:Currais Novos;ID:6320141', '8134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8134', '112', '10011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10012', '1079', '1', 'Doutor Severiano', 'BR.22.2403202', 'ASCII:Doutor Severiano;ID:6320142', '8135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8135', '112', '10012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10013', '1079', '1', 'Parnamirim', 'BR.22.2403251', 'ASCII:Parnamirim;ID:6320143', '8136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8136', '112', '10013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10014', '1079', '1', 'Encanto', 'BR.22.2403301', 'ASCII:Encanto;ID:6320144', '8137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8137', '112', '10014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10015', '1079', '1', 'Extremoz', 'BR.22.2403608', 'ASCII:Extremoz;ID:6320145', '8138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8138', '112', '10015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10016', '1079', '1', 'Felipe Guerra', 'BR.22.2403707', 'ASCII:Felipe Guerra;ID:6320146', '8139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8139', '112', '10016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10017', '1079', '1', 'Fernando Pedroza', 'BR.22.2403756', 'ASCII:Fernando Pedroza;ID:6320147', '8140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8140', '112', '10017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10018', '1079', '1', 'Florânia', 'BR.22.2403806', 'ASCII:Florania;ID:6320148', '8141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8141', '112', '10018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10019', '1079', '1', 'Francisco Dantas', 'BR.22.2403905', 'ASCII:Francisco Dantas;ID:6320149', '8142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8142', '112', '10019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10020', '1079', '1', 'Frutuoso Gomes', 'BR.22.2404002', 'ASCII:Frutuoso Gomes;ID:6320150', '8143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8143', '112', '10020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10021', '1079', '1', 'Galinhos', 'BR.22.2404101', 'ASCII:Galinhos;ID:6320151', '8144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8144', '112', '10021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10022', '1079', '1', 'Goianinha', 'BR.22.2404200', 'ASCII:Goianinha;ID:6320152', '8145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8145', '112', '10022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10023', '1079', '1', 'Governador Dix-Sept Rosado', 'BR.22.2404309', 'ASCII:Governador Dix-Sept Rosado;ID:6320153', '8146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8146', '112', '10023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10024', '1079', '1', 'Grossos', 'BR.22.2404408', 'ASCII:Grossos;ID:6320154', '8147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8147', '112', '10024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10025', '1079', '1', 'Guamaré', 'BR.22.2404507', 'ASCII:Guamare;ID:6320155', '8148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8148', '112', '10025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10026', '1079', '1', 'Ielmo Marinho', 'BR.22.2404606', 'ASCII:Ielmo Marinho;ID:6320156', '8149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8149', '112', '10026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10027', '1079', '1', 'Ipanguaçu', 'BR.22.2404705', 'ASCII:Ipanguacu;ID:6320157', '8150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8150', '112', '10027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10028', '1079', '1', 'Ipueira', 'BR.22.2404804', 'ASCII:Ipueira;ID:6320158', '8151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8151', '112', '10028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10029', '1079', '1', 'Itajá', 'BR.22.2404853', 'ASCII:Itaja;ID:6320159', '8152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8152', '112', '10029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10030', '1079', '1', 'Itaú', 'BR.22.2404903', 'ASCII:Itau;ID:6320160', '8153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8153', '112', '10030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2404903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10031', '1079', '1', 'Jandaíra', 'BR.22.2405108', 'ASCII:Jandaira;ID:6320161', '8154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8154', '112', '10031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2405108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10032', '1079', '1', 'Janduís', 'BR.22.2405207', 'ASCII:Janduis;ID:6320162', '8155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8155', '112', '10032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2405207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10033', '1079', '1', 'Januário Cicco', 'BR.22.2405306', 'ASCII:Januario Cicco;ID:6320163', '8156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8156', '112', '10033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2405306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10034', '1079', '1', 'Japi', 'BR.22.2405405', 'ASCII:Japi;ID:6320164', '8157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8157', '112', '10034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2405405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10035', '1079', '1', 'Jardim de Angicos', 'BR.22.2405504', 'ASCII:Jardim De Angicos;ID:6320165', '8158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8158', '112', '10035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2405504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10036', '1079', '1', 'Jardim de Piranhas', 'BR.22.2405603', 'ASCII:Jardim De Piranhas;ID:6320166', '8159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8159', '112', '10036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2405603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10037', '1079', '1', 'Jardim do Seridó', 'BR.22.2405702', 'ASCII:Jardim Do Serido;ID:6320167', '8160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8160', '112', '10037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2405702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10038', '1079', '1', 'João Câmara', 'BR.22.2405801', 'ASCII:Joao Camara;ID:6320168', '8161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8161', '112', '10038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2405801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10039', '1079', '1', 'João Dias', 'BR.22.2405900', 'ASCII:Joao Dias;ID:6320169', '8162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8162', '112', '10039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2405900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10040', '1079', '1', 'José da Penha', 'BR.22.2406007', 'ASCII:Jose Da Penha;ID:6320170', '8163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8163', '112', '10040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10041', '1079', '1', 'Lagoa d''Anta', 'BR.22.2406205', 'ASCII:Lagoa D''Anta;ID:6320171', '8164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8164', '112', '10041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10042', '1079', '1', 'Lagoa de Pedras', 'BR.22.2406304', 'ASCII:Lagoa De Pedras;ID:6320172', '8165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8165', '112', '10042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10043', '1079', '1', 'Lagoa de Velhos', 'BR.22.2406403', 'ASCII:Lagoa De Velhos;ID:6320173', '8166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8166', '112', '10043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10044', '1079', '1', 'Lagoa Nova', 'BR.22.2406502', 'ASCII:Lagoa Nova;ID:6320174', '8167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8167', '112', '10044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10045', '1079', '1', 'Lagoa Salgada', 'BR.22.2406601', 'ASCII:Lagoa Salgada;ID:6320175', '8168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8168', '112', '10045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10046', '1079', '1', 'Lajes', 'BR.22.2406700', 'ASCII:Lajes;ID:6320176', '8169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8169', '112', '10046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10047', '1079', '1', 'Lajes Pintadas', 'BR.22.2406809', 'ASCII:Lajes Pintadas;ID:6320177', '8170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8170', '112', '10047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10048', '1079', '1', 'Lucrécia', 'BR.22.2406908', 'ASCII:Lucrecia;ID:6320178', '8171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8171', '112', '10048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10049', '1079', '1', 'Luís Gomes', 'BR.22.2407005', 'ASCII:Luis Gomes;ID:6320179', '8172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8172', '112', '10049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10050', '1079', '1', 'Macaíba', 'BR.22.2407104', 'ASCII:Macaiba;ID:6320180', '8173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8173', '112', '10050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10051', '1079', '1', 'Macau', 'BR.22.2407203', 'ASCII:Macau;ID:6320181', '8174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8174', '112', '10051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10052', '1079', '1', 'Major Sales', 'BR.22.2407252', 'ASCII:Major Sales;ID:6320182', '8175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8175', '112', '10052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10053', '1079', '1', 'Marcelino Vieira', 'BR.22.2407302', 'ASCII:Marcelino Vieira;ID:6320183', '8176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8176', '112', '10053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10054', '1079', '1', 'Martins', 'BR.22.2407401', 'ASCII:Martins;ID:6320184', '8177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8177', '112', '10054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10055', '1079', '1', 'Messias Targino', 'BR.22.2407609', 'ASCII:Messias Targino;ID:6320185', '8178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8178', '112', '10055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10056', '1079', '1', 'Montanhas', 'BR.22.2407708', 'ASCII:Montanhas;ID:6320186', '8179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8179', '112', '10056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10057', '1079', '1', 'Monte Alegre', 'BR.22.2407807', 'ASCII:Monte Alegre;ID:6320187', '8180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8180', '112', '10057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10058', '1079', '1', 'Monte das Gameleiras', 'BR.22.2407906', 'ASCII:Monte Das Gameleiras;ID:6320188', '8181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8181', '112', '10058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2407906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10059', '1079', '1', 'Natal', 'BR.22.2408102', 'ASCII:Natal;ID:6320189', '8182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8182', '112', '10059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10060', '1079', '1', 'Nova Cruz', 'BR.22.2408300', 'ASCII:Nova Cruz;ID:6320190', '8183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8183', '112', '10060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10061', '1079', '1', 'Olho-d''Água do Borges', 'BR.22.2408409', 'ASCII:Olho-D''Agua Do Borges;ID:6320191', '8184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8184', '112', '10061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10062', '1079', '1', 'Ouro Branco', 'BR.22.2408508', 'ASCII:Ouro Branco;ID:6320192', '8185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8185', '112', '10062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10063', '1079', '1', 'Paraná', 'BR.22.2408607', 'ASCII:Parana;ID:6320193', '8186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8186', '112', '10063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10064', '1079', '1', 'Parazinho', 'BR.22.2408805', 'ASCII:Parazinho;ID:6320194', '8187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8187', '112', '10064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10065', '1079', '1', 'Parelhas', 'BR.22.2408904', 'ASCII:Parelhas;ID:6320195', '8188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8188', '112', '10065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10066', '1079', '1', 'Rio do Fogo', 'BR.22.2408953', 'ASCII:Rio Do Fogo;ID:6320196', '8189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8189', '112', '10066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2408953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10067', '1079', '1', 'Passa e Fica', 'BR.22.2409100', 'ASCII:Passa E Fica;ID:6320197', '8190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8190', '112', '10067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2409100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10068', '1079', '1', 'Passagem', 'BR.22.2409209', 'ASCII:Passagem;ID:6320198', '8191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8191', '112', '10068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2409209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10069', '1079', '1', 'Santa Maria', 'BR.22.2409332', 'ASCII:Santa Maria;ID:6320199', '8192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8192', '112', '10069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2409332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10070', '1079', '1', 'Pau dos Ferros', 'BR.22.2409407', 'ASCII:Pau Dos Ferros;ID:6320200', '8193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8193', '112', '10070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2409407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10071', '1079', '1', 'Pedra Grande', 'BR.22.2409506', 'ASCII:Pedra Grande;ID:6320201', '8194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8194', '112', '10071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2409506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10072', '1079', '1', 'Pedra Preta', 'BR.22.2409605', 'ASCII:Pedra Preta;ID:6320202', '8195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8195', '112', '10072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2409605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10073', '1079', '1', 'Pedro Avelino', 'BR.22.2409704', 'ASCII:Pedro Avelino;ID:6320203', '8196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8196', '112', '10073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2409704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10074', '1079', '1', 'Pedro Velho', 'BR.22.2409803', 'ASCII:Pedro Velho;ID:6320204', '8197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8197', '112', '10074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2409803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10075', '1079', '1', 'Pendências', 'BR.22.2409902', 'ASCII:Pendencias;ID:6320205', '8198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8198', '112', '10075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2409902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10076', '1079', '1', 'Pilões', 'BR.22.2410009', 'ASCII:Piloes;ID:6320206', '8199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8199', '112', '10076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10077', '1079', '1', 'Poço Branco', 'BR.22.2410108', 'ASCII:Poco Branco;ID:6320207', '8200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8200', '112', '10077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10078', '1079', '1', 'Portalegre', 'BR.22.2410207', 'ASCII:Portalegre;ID:6320208', '8201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8201', '112', '10078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10079', '1079', '1', 'Porto do Mangue', 'BR.22.2410256', 'ASCII:Porto Do Mangue;ID:6320209', '8202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8202', '112', '10079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10080', '1079', '1', 'Presidente Juscelino', 'BR.22.2410306', 'ASCII:Presidente Juscelino;ID:6320210', '8203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8203', '112', '10080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10081', '1079', '1', 'Rafael Fernandes', 'BR.22.2410504', 'ASCII:Rafael Fernandes;ID:6320211', '8204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8204', '112', '10081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10082', '1079', '1', 'Rafael Godeiro', 'BR.22.2410603', 'ASCII:Rafael Godeiro;ID:6320212', '8205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8205', '112', '10082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10083', '1079', '1', 'Riacho da Cruz', 'BR.22.2410702', 'ASCII:Riacho Da Cruz;ID:6320213', '8206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8206', '112', '10083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10084', '1079', '1', 'Riacho de Santana', 'BR.22.2410801', 'ASCII:Riacho De Santana;ID:6320214', '8207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8207', '112', '10084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10085', '1079', '1', 'Riachuelo', 'BR.22.2410900', 'ASCII:Riachuelo;ID:6320215', '8208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8208', '112', '10085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2410900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10086', '1079', '1', 'Rodolfo Fernandes', 'BR.22.2411007', 'ASCII:Rodolfo Fernandes;ID:6320216', '8209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8209', '112', '10086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10087', '1079', '1', 'Tibau', 'BR.22.2411056', 'ASCII:Tibau;ID:6320217', '8210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8210', '112', '10087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10088', '1079', '1', 'Ruy Barbosa', 'BR.22.2411106', 'ASCII:Ruy Barbosa;ID:6320218', '8211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8211', '112', '10088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10089', '1079', '1', 'Santa Cruz', 'BR.22.2411205', 'ASCII:Santa Cruz;ID:6320219', '8212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8212', '112', '10089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10090', '1079', '1', 'Santana do Matos', 'BR.22.2411403', 'ASCII:Santana Do Matos;ID:6320220', '8213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8213', '112', '10090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10091', '1079', '1', 'Santana do Seridó', 'BR.22.2411429', 'ASCII:Santana Do Serido;ID:6320221', '8214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8214', '112', '10091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10092', '1079', '1', 'Santo Antônio', 'BR.22.2411502', 'ASCII:Santo Antonio;ID:6320222', '8215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8215', '112', '10092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10093', '1079', '1', 'São Bento do Norte', 'BR.22.2411601', 'ASCII:Sao Bento Do Norte;ID:6320223', '8216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8216', '112', '10093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10094', '1079', '1', 'São Bento do Trairí', 'BR.22.2411700', 'ASCII:Sao Bento Do Trairi;ID:6320224', '8217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8217', '112', '10094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10095', '1079', '1', 'São Fernando', 'BR.22.2411809', 'ASCII:Sao Fernando;ID:6320225', '8218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8218', '112', '10095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10096', '1079', '1', 'São Francisco do Oeste', 'BR.22.2411908', 'ASCII:Sao Francisco Do Oeste;ID:6320226', '8219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8219', '112', '10096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2411908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10097', '1079', '1', 'São Gonçalo do Amarante', 'BR.22.2412005', 'ASCII:Sao Goncalo Do Amarante;ID:6320227', '8220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8220', '112', '10097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10098', '1079', '1', 'São João do Sabugi', 'BR.22.2412104', 'ASCII:Sao Joao Do Sabugi;ID:6320228', '8221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8221', '112', '10098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10099', '1079', '1', 'São José de Mipibu', 'BR.22.2412203', 'ASCII:Sao Jose De Mipibu;ID:6320229', '8222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8222', '112', '10099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10100', '1079', '1', 'São José do Campestre', 'BR.22.2412302', 'ASCII:Sao Jose Do Campestre;ID:6320230', '8223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8223', '112', '10100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10101', '1079', '1', 'São José do Seridó', 'BR.22.2412401', 'ASCII:Sao Jose Do Serido;ID:6320231', '8224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8224', '112', '10101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10102', '1079', '1', 'São Miguel', 'BR.22.2412500', 'ASCII:Sao Miguel;ID:6320232', '8225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8225', '112', '10102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10103', '1079', '1', 'São Miguel de Touros', 'BR.22.2412559', 'ASCII:Sao Miguel De Touros;ID:6320233', '8226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8226', '112', '10103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10104', '1079', '1', 'São Paulo do Potengi', 'BR.22.2412609', 'ASCII:Sao Paulo Do Potengi;ID:6320234', '8227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8227', '112', '10104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10105', '1079', '1', 'São Rafael', 'BR.22.2412807', 'ASCII:Sao Rafael;ID:6320235', '8228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8228', '112', '10105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10106', '1079', '1', 'Senador Elói de Souza', 'BR.22.2413102', 'ASCII:Senador Eloi De Souza;ID:6320236', '8229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8229', '112', '10106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10107', '1079', '1', 'Senador Georgino Avelino', 'BR.22.2413201', 'ASCII:Senador Georgino Avelino;ID:6320237', '8230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8230', '112', '10107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10108', '1079', '1', 'Serra de São Bento', 'BR.22.2413300', 'ASCII:Serra De Sao Bento;ID:6320238', '8231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8231', '112', '10108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10109', '1079', '1', 'Serra do Mel', 'BR.22.2413359', 'ASCII:Serra Do Mel;ID:6320239', '8232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8232', '112', '10109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10110', '1079', '1', 'Serra Negra do Norte', 'BR.22.2413409', 'ASCII:Serra Negra Do Norte;ID:6320240', '8233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8233', '112', '10110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10111', '1079', '1', 'Serrinha', 'BR.22.2413508', 'ASCII:Serrinha;ID:6320241', '8234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8234', '112', '10111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10112', '1079', '1', 'Serrinha dos Pintos', 'BR.22.2413557', 'ASCII:Serrinha Dos Pintos;ID:6320242', '8235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8235', '112', '10112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10113', '1079', '1', 'Severiano Melo', 'BR.22.2413607', 'ASCII:Severiano Melo;ID:6320243', '8236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8236', '112', '10113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10114', '1079', '1', 'Sítio Novo', 'BR.22.2413706', 'ASCII:Sitio Novo;ID:6320244', '8237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8237', '112', '10114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10115', '1079', '1', 'Taboleiro Grande', 'BR.22.2413805', 'ASCII:Taboleiro Grande;ID:6320245', '8238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8238', '112', '10115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10116', '1079', '1', 'Taipu', 'BR.22.2413904', 'ASCII:Taipu;ID:6320246', '8239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8239', '112', '10116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10117', '1079', '1', 'Tangará', 'BR.22.2414001', 'ASCII:Tangara;ID:6320247', '8240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8240', '112', '10117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10118', '1079', '1', 'Tenente Ananias', 'BR.22.2414100', 'ASCII:Tenente Ananias;ID:6320248', '8241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8241', '112', '10118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10119', '1079', '1', 'Tenente Laurentino Cruz', 'BR.22.2414159', 'ASCII:Tenente Laurentino Cruz;ID:6320249', '8242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8242', '112', '10119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10120', '1079', '1', 'Tibau do Sul', 'BR.22.2414209', 'ASCII:Tibau Do Sul;ID:6320250', '8243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8243', '112', '10120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10121', '1079', '1', 'Timbaúba dos Batistas', 'BR.22.2414308', 'ASCII:Timbauba Dos Batistas;ID:6320251', '8244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8244', '112', '10121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10122', '1079', '1', 'Triunfo Potiguar', 'BR.22.2414456', 'ASCII:Triunfo Potiguar;ID:6320252', '8245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8245', '112', '10122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10123', '1079', '1', 'Umarizal', 'BR.22.2414506', 'ASCII:Umarizal;ID:6320253', '8246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8246', '112', '10123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10124', '1079', '1', 'Upanema', 'BR.22.2414605', 'ASCII:Upanema;ID:6320254', '8247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8247', '112', '10124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10125', '1079', '1', 'Venha-Ver', 'BR.22.2414753', 'ASCII:Venha-Ver;ID:6320255', '8248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8248', '112', '10125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10126', '1079', '1', 'Vera Cruz', 'BR.22.2414803', 'ASCII:Vera Cruz;ID:6320256', '8249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8249', '112', '10126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10127', '1079', '1', 'Viçosa', 'BR.22.2414902', 'ASCII:Vicosa;ID:6320257', '8250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8250', '112', '10127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10128', '1079', '1', 'Vila Flor', 'BR.22.2415008', 'ASCII:Vila Flor;ID:6320258', '8251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8251', '112', '10128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2415008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10129', '1079', '1', 'Aguiar', 'BR.17.2500205', 'ASCII:Aguiar;ID:6320259', '8252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8252', '112', '10129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10130', '1079', '1', 'Alagoa Grande', 'BR.17.2500304', 'ASCII:Alagoa Grande;ID:6320260', '8253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8253', '112', '10130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10131', '1079', '1', 'Alagoa Nova', 'BR.17.2500403', 'ASCII:Alagoa Nova;ID:6320261', '8254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8254', '112', '10131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10132', '1079', '1', 'Alagoinha', 'BR.17.2500502', 'ASCII:Alagoinha;ID:6320262', '8255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8255', '112', '10132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10133', '1079', '1', 'Alcantil', 'BR.17.2500536', 'ASCII:Alcantil;ID:6320263', '8256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8256', '112', '10133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10134', '1079', '1', 'Algodão de Jandaíra', 'BR.17.2500577', 'ASCII:Algodao De Jandaira;ID:6320264', '8257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8257', '112', '10134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10135', '1079', '1', 'São João do Rio do Peixe', 'BR.17.2500700', 'ASCII:Sao Joao Do Rio Do Peixe;ID:6320265', '8258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8258', '112', '10135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10136', '1079', '1', 'Araçagi', 'BR.17.2500809', 'ASCII:Aracagi;ID:6320266', '8259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8259', '112', '10136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10137', '1079', '1', 'Arara', 'BR.17.2500908', 'ASCII:Arara;ID:6320267', '8260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8260', '112', '10137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10138', '1079', '1', 'Araruna', 'BR.17.2501005', 'ASCII:Araruna;ID:6320268', '8261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8261', '112', '10138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10139', '1079', '1', 'Areia de Baraúnas', 'BR.17.2501153', 'ASCII:Areia De Baraunas;ID:6320269', '8262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8262', '112', '10139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10140', '1079', '1', 'Areial', 'BR.17.2501203', 'ASCII:Areial;ID:6320270', '8263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8263', '112', '10140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10141', '1079', '1', 'Aroeiras', 'BR.17.2501302', 'ASCII:Aroeiras;ID:6320271', '8264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8264', '112', '10141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10142', '1079', '1', 'Assunção', 'BR.17.2501351', 'ASCII:Assuncao;ID:6320272', '8265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8265', '112', '10142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10143', '1079', '1', 'Baía da Traição', 'BR.17.2501401', 'ASCII:Baia Da Traicao;ID:6320273', '8266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8266', '112', '10143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10144', '1079', '1', 'Bananeiras', 'BR.17.2501500', 'ASCII:Bananeiras;ID:6320274', '8267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8267', '112', '10144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10145', '1079', '1', 'Baraúna', 'BR.17.2501534', 'ASCII:Barauna;ID:6320275', '8268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8268', '112', '10145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10146', '1079', '1', 'Barra de Santana', 'BR.17.2501575', 'ASCII:Barra De Santana;ID:6320276', '8269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8269', '112', '10146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10147', '1079', '1', 'Barra de Santa Rosa', 'BR.17.2501609', 'ASCII:Barra De Santa Rosa;ID:6320277', '8270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8270', '112', '10147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10148', '1079', '1', 'Barra de São Miguel', 'BR.17.2501708', 'ASCII:Barra De Sao Miguel;ID:6320278', '8271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8271', '112', '10148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10149', '1079', '1', 'Bayeux', 'BR.17.2501807', 'ASCII:Bayeux;ID:6320279', '8272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8272', '112', '10149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10150', '1079', '1', 'Belém', 'BR.17.2501906', 'ASCII:Belem;ID:6320280', '8273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8273', '112', '10150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2501906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10151', '1079', '1', 'Belém do Brejo do Cruz', 'BR.17.2502003', 'ASCII:Belem Do Brejo Do Cruz;ID:6320281', '8274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8274', '112', '10151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10152', '1079', '1', 'Bernardino Batista', 'BR.17.2502052', 'ASCII:Bernardino Batista;ID:6320282', '8275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8275', '112', '10152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10153', '1079', '1', 'Boa Ventura', 'BR.17.2502102', 'ASCII:Boa Ventura;ID:6320283', '8276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8276', '112', '10153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10154', '1079', '1', 'Boa Vista', 'BR.17.2502151', 'ASCII:Boa Vista;ID:6320284', '8277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8277', '112', '10154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10155', '1079', '1', 'Bom Jesus', 'BR.17.2502201', 'ASCII:Bom Jesus;ID:6320285', '8278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8278', '112', '10155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10156', '1079', '1', 'Bom Sucesso', 'BR.17.2502300', 'ASCII:Bom Sucesso;ID:6320286', '8279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8279', '112', '10156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10157', '1079', '1', 'Bonito de Santa Fé', 'BR.17.2502409', 'ASCII:Bonito De Santa Fe;ID:6320287', '8280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8280', '112', '10157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10158', '1079', '1', 'Igaracy', 'BR.17.2502607', 'ASCII:Igaracy;ID:6320288', '8281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8281', '112', '10158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10159', '1079', '1', 'Borborema', 'BR.17.2502706', 'ASCII:Borborema;ID:6320289', '8282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8282', '112', '10159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10160', '1079', '1', 'Brejo do Cruz', 'BR.17.2502805', 'ASCII:Brejo Do Cruz;ID:6320290', '8283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8283', '112', '10160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10161', '1079', '1', 'Brejo dos Santos', 'BR.17.2502904', 'ASCII:Brejo Dos Santos;ID:6320291', '8284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8284', '112', '10161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2502904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10162', '1079', '1', 'Caaporã', 'BR.17.2503001', 'ASCII:Caapora;ID:6320292', '8285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8285', '112', '10162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10163', '1079', '1', 'Cabaceiras', 'BR.17.2503100', 'ASCII:Cabaceiras;ID:6320293', '8286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8286', '112', '10163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10164', '1079', '1', 'Cabedelo', 'BR.17.2503209', 'ASCII:Cabedelo;ID:6320294', '8287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8287', '112', '10164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10165', '1079', '1', 'Cacimba de Areia', 'BR.17.2503407', 'ASCII:Cacimba De Areia;ID:6320295', '8288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8288', '112', '10165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10166', '1079', '1', 'Cacimba de Dentro', 'BR.17.2503506', 'ASCII:Cacimba De Dentro;ID:6320296', '8289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8289', '112', '10166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10167', '1079', '1', 'Cacimbas', 'BR.17.2503555', 'ASCII:Cacimbas;ID:6320297', '8290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8290', '112', '10167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10168', '1079', '1', 'Caiçara', 'BR.17.2503605', 'ASCII:Caicara;ID:6320298', '8291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8291', '112', '10168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10169', '1079', '1', 'Cajazeirinhas', 'BR.17.2503753', 'ASCII:Cajazeirinhas;ID:6320299', '8292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8292', '112', '10169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10170', '1079', '1', 'Caldas Brandão', 'BR.17.2503803', 'ASCII:Caldas Brandao;ID:6320300', '8293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8293', '112', '10170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10171', '1079', '1', 'Camalaú', 'BR.17.2503902', 'ASCII:Camalau;ID:6320301', '8294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8294', '112', '10171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2503902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10172', '1079', '1', 'Campina Grande', 'BR.17.2504009', 'ASCII:Campina Grande;ID:6320302', '8295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8295', '112', '10172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10173', '1079', '1', 'Capim', 'BR.17.2504033', 'ASCII:Capim;ID:6320303', '8296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8296', '112', '10173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10174', '1079', '1', 'Caraúbas', 'BR.17.2504074', 'ASCII:Caraubas;ID:6320304', '8297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8297', '112', '10174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10175', '1079', '1', 'Carrapateira', 'BR.17.2504108', 'ASCII:Carrapateira;ID:6320305', '8298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8298', '112', '10175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10176', '1079', '1', 'Casserengue', 'BR.17.2504157', 'ASCII:Casserengue;ID:6320306', '8299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8299', '112', '10176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10177', '1079', '1', 'Catingueira', 'BR.17.2504207', 'ASCII:Catingueira;ID:6320307', '8300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8300', '112', '10177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10178', '1079', '1', 'Catolé do Rocha', 'BR.17.2504306', 'ASCII:Catole Do Rocha;ID:6320308', '8301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8301', '112', '10178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10179', '1079', '1', 'Caturité', 'BR.17.2504355', 'ASCII:Caturite;ID:6320309', '8302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8302', '112', '10179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10180', '1079', '1', 'Condado', 'BR.17.2504504', 'ASCII:Condado;ID:6320310', '8303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8303', '112', '10180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10181', '1079', '1', 'Conde', 'BR.17.2504603', 'ASCII:Conde;ID:6320311', '8304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8304', '112', '10181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10182', '1079', '1', 'Congo', 'BR.17.2504702', 'ASCII:Congo;ID:6320312', '8305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8305', '112', '10182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10183', '1079', '1', 'Coremas', 'BR.17.2504801', 'ASCII:Coremas;ID:6320313', '8306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8306', '112', '10183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10184', '1079', '1', 'Coxixola', 'BR.17.2504850', 'ASCII:Coxixola;ID:6320314', '8307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8307', '112', '10184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2504850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10185', '1079', '1', 'Cubati', 'BR.17.2505006', 'ASCII:Cubati;ID:6320315', '8308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8308', '112', '10185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10186', '1079', '1', 'Cuité', 'BR.17.2505105', 'ASCII:Cuite;ID:6320316', '8309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8309', '112', '10186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10187', '1079', '1', 'Cuitegi', 'BR.17.2505204', 'ASCII:Cuitegi;ID:6320317', '8310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8310', '112', '10187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10188', '1079', '1', 'Cuité de Mamanguape', 'BR.17.2505238', 'ASCII:Cuite De Mamanguape;ID:6320318', '8311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8311', '112', '10188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10189', '1079', '1', 'Curral Velho', 'BR.17.2505303', 'ASCII:Curral Velho;ID:6320319', '8312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8312', '112', '10189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10190', '1079', '1', 'Damião', 'BR.17.2505352', 'ASCII:Damiao;ID:6320320', '8313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8313', '112', '10190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10191', '1079', '1', 'Desterro', 'BR.17.2505402', 'ASCII:Desterro;ID:6320321', '8314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8314', '112', '10191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10192', '1079', '1', 'Vista Serrana', 'BR.17.2505501', 'ASCII:Vista Serrana;ID:6320322', '8315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8315', '112', '10192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10193', '1079', '1', 'Diamante', 'BR.17.2505600', 'ASCII:Diamante;ID:6320323', '8316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8316', '112', '10193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10194', '1079', '1', 'Dona Inês', 'BR.17.2505709', 'ASCII:Dona Ines;ID:6320324', '8317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8317', '112', '10194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10195', '1079', '1', 'Duas Estradas', 'BR.17.2505808', 'ASCII:Duas Estradas;ID:6320325', '8318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8318', '112', '10195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10196', '1079', '1', 'Emas', 'BR.17.2505907', 'ASCII:Emas;ID:6320326', '8319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8319', '112', '10196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2505907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10197', '1079', '1', 'Esperança', 'BR.17.2506004', 'ASCII:Esperanca;ID:6320327', '8320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8320', '112', '10197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10198', '1079', '1', 'Fagundes', 'BR.17.2506103', 'ASCII:Fagundes;ID:6320328', '8321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8321', '112', '10198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10199', '1079', '1', 'Gado Bravo', 'BR.17.2506251', 'ASCII:Gado Bravo;ID:6320329', '8322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8322', '112', '10199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10200', '1079', '1', 'Guarabira', 'BR.17.2506301', 'ASCII:Guarabira;ID:6320330', '8323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8323', '112', '10200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10201', '1079', '1', 'Gurinhém', 'BR.17.2506400', 'ASCII:Gurinhem;ID:6320331', '8324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8324', '112', '10201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10202', '1079', '1', 'Imaculada', 'BR.17.2506707', 'ASCII:Imaculada;ID:6320332', '8325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8325', '112', '10202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10203', '1079', '1', 'Ingá', 'BR.17.2506806', 'ASCII:Inga;ID:6320333', '8326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8326', '112', '10203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10204', '1079', '1', 'Itabaiana', 'BR.17.2506905', 'ASCII:Itabaiana;ID:6320334', '8327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8327', '112', '10204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10205', '1079', '1', 'Itaporanga', 'BR.17.2507002', 'ASCII:Itaporanga;ID:6320335', '8328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8328', '112', '10205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2507002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10206', '1079', '1', 'Itapororoca', 'BR.17.2507101', 'ASCII:Itapororoca;ID:6320336', '8329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8329', '112', '10206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2507101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10207', '1079', '1', 'Itatuba', 'BR.17.2507200', 'ASCII:Itatuba;ID:6320337', '8330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8330', '112', '10207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2507200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10208', '1079', '1', 'Jacaraú', 'BR.17.2507309', 'ASCII:Jacarau;ID:6320338', '8331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8331', '112', '10208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2507309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10209', '1079', '1', 'Jericó', 'BR.17.2507408', 'ASCII:Jerico;ID:6320339', '8332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8332', '112', '10209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2507408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10210', '1079', '1', 'João Pessoa', 'BR.17.2507507', 'ASCII:Joao Pessoa;ID:6320340', '8333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8333', '112', '10210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2507507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10211', '1079', '1', 'Juarez Távora', 'BR.17.2507606', 'ASCII:Juarez Tavora;ID:6320341', '8334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8334', '112', '10211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2507606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10212', '1079', '1', 'Juazeirinho', 'BR.17.2507705', 'ASCII:Juazeirinho;ID:6320342', '8335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8335', '112', '10212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2507705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10213', '1079', '1', 'Junco do Seridó', 'BR.17.2507804', 'ASCII:Junco Do Serido;ID:6320343', '8336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8336', '112', '10213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2507804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10214', '1079', '1', 'Juripiranga', 'BR.17.2507903', 'ASCII:Juripiranga;ID:6320344', '8337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8337', '112', '10214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2507903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10215', '1079', '1', 'Juru', 'BR.17.2508000', 'ASCII:Juru;ID:6320345', '8338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8338', '112', '10215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10216', '1079', '1', 'Lagoa de Dentro', 'BR.17.2508208', 'ASCII:Lagoa De Dentro;ID:6320346', '8339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8339', '112', '10216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10217', '1079', '1', 'Lastro', 'BR.17.2508406', 'ASCII:Lastro;ID:6320347', '8340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8340', '112', '10217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10218', '1079', '1', 'Livramento', 'BR.17.2508505', 'ASCII:Livramento;ID:6320348', '8341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8341', '112', '10218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10219', '1079', '1', 'Logradouro', 'BR.17.2508554', 'ASCII:Logradouro;ID:6320349', '8342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8342', '112', '10219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10220', '1079', '1', 'Lucena', 'BR.17.2508604', 'ASCII:Lucena;ID:6320350', '8343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8343', '112', '10220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10221', '1079', '1', 'Mãe d''Água', 'BR.17.2508703', 'ASCII:Mae D''Agua;ID:6320351', '8344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8344', '112', '10221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10222', '1079', '1', 'Malta', 'BR.17.2508802', 'ASCII:Malta;ID:6320352', '8345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8345', '112', '10222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2508802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10223', '1079', '1', 'Manaíra', 'BR.17.2509008', 'ASCII:Manaira;ID:6320353', '8346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8346', '112', '10223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10224', '1079', '1', 'Marcação', 'BR.17.2509057', 'ASCII:Marcacao;ID:6320354', '8347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8347', '112', '10224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10225', '1079', '1', 'Mari', 'BR.17.2509107', 'ASCII:Mari;ID:6320355', '8348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8348', '112', '10225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10226', '1079', '1', 'Marizópolis', 'BR.17.2509156', 'ASCII:Marizopolis;ID:6320356', '8349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8349', '112', '10226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10227', '1079', '1', 'Massaranduba', 'BR.17.2509206', 'ASCII:Massaranduba;ID:6320357', '8350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8350', '112', '10227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10228', '1079', '1', 'Matinhas', 'BR.17.2509339', 'ASCII:Matinhas;ID:6320358', '8351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8351', '112', '10228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10229', '1079', '1', 'Mato Grosso', 'BR.17.2509370', 'ASCII:Mato Grosso;ID:6320359', '8352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8352', '112', '10229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10230', '1079', '1', 'Maturéia', 'BR.17.2509396', 'ASCII:Matureia;ID:6320360', '8353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8353', '112', '10230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10231', '1079', '1', 'Mogeiro', 'BR.17.2509404', 'ASCII:Mogeiro;ID:6320361', '8354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8354', '112', '10231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10232', '1079', '1', 'Montadas', 'BR.17.2509503', 'ASCII:Montadas;ID:6320362', '8355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8355', '112', '10232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10233', '1079', '1', 'Monte Horebe', 'BR.17.2509602', 'ASCII:Monte Horebe;ID:6320363', '8356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8356', '112', '10233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10234', '1079', '1', 'Mulungu', 'BR.17.2509800', 'ASCII:Mulungu;ID:6320364', '8357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8357', '112', '10234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10235', '1079', '1', 'Natuba', 'BR.17.2509909', 'ASCII:Natuba;ID:6320365', '8358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8358', '112', '10235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2509909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10236', '1079', '1', 'Nazarezinho', 'BR.17.2510006', 'ASCII:Nazarezinho;ID:6320366', '8359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8359', '112', '10236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10237', '1079', '1', 'Nova Floresta', 'BR.17.2510105', 'ASCII:Nova Floresta;ID:6320367', '8360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8360', '112', '10237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10238', '1079', '1', 'Nova Olinda', 'BR.17.2510204', 'ASCII:Nova Olinda;ID:6320368', '8361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8361', '112', '10238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10239', '1079', '1', 'Nova Palmeira', 'BR.17.2510303', 'ASCII:Nova Palmeira;ID:6320369', '8362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8362', '112', '10239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10240', '1079', '1', 'Olho d''Água', 'BR.17.2510402', 'ASCII:Olho D''Agua;ID:6320370', '8363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8363', '112', '10240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10241', '1079', '1', 'Olivedos', 'BR.17.2510501', 'ASCII:Olivedos;ID:6320371', '8364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8364', '112', '10241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10242', '1079', '1', 'Ouro Velho', 'BR.17.2510600', 'ASCII:Ouro Velho;ID:6320372', '8365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8365', '112', '10242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10243', '1079', '1', 'Parari', 'BR.17.2510659', 'ASCII:Parari;ID:6320373', '8366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8366', '112', '10243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10244', '1079', '1', 'Passagem', 'BR.17.2510709', 'ASCII:Passagem;ID:6320374', '8367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8367', '112', '10244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10245', '1079', '1', 'Patos', 'BR.17.2510808', 'ASCII:Patos;ID:6320375', '8368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8368', '112', '10245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2510808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10246', '1079', '1', 'Pedra Lavrada', 'BR.17.2511103', 'ASCII:Pedra Lavrada;ID:6320376', '8369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8369', '112', '10246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2511103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10247', '1079', '1', 'Pedras de Fogo', 'BR.17.2511202', 'ASCII:Pedras De Fogo;ID:6320377', '8370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8370', '112', '10247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2511202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10248', '1079', '1', 'Picuí', 'BR.17.2511400', 'ASCII:Picui;ID:6320378', '8371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8371', '112', '10248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2511400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10249', '1079', '1', 'Pilar', 'BR.17.2511509', 'ASCII:Pilar;ID:6320379', '8372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8372', '112', '10249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2511509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10250', '1079', '1', 'Pilões', 'BR.17.2511608', 'ASCII:Piloes;ID:6320380', '8373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8373', '112', '10250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2511608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10251', '1079', '1', 'Pilõezinhos', 'BR.17.2511707', 'ASCII:Piloezinhos;ID:6320381', '8374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8374', '112', '10251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2511707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10252', '1079', '1', 'Pirpirituba', 'BR.17.2511806', 'ASCII:Pirpirituba;ID:6320382', '8375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8375', '112', '10252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2511806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10253', '1079', '1', 'Pitimbu', 'BR.17.2511905', 'ASCII:Pitimbu;ID:6320383', '8376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8376', '112', '10253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2511905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10254', '1079', '1', 'Poço Dantas', 'BR.17.2512036', 'ASCII:Poco Dantas;ID:6320384', '8377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8377', '112', '10254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10255', '1079', '1', 'Poço de José de Moura', 'BR.17.2512077', 'ASCII:Poco De Jose De Moura;ID:6320385', '8378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8378', '112', '10255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10256', '1079', '1', 'Princesa Isabel', 'BR.17.2512309', 'ASCII:Princesa Isabel;ID:6320386', '8379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8379', '112', '10256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10257', '1079', '1', 'Puxinanã', 'BR.17.2512408', 'ASCII:Puxinana;ID:6320387', '8380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8380', '112', '10257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10258', '1079', '1', 'Queimadas', 'BR.17.2512507', 'ASCII:Queimadas;ID:6320388', '8381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8381', '112', '10258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10259', '1079', '1', 'Quixabá', 'BR.17.2512606', 'ASCII:Quixaba;ID:6320389', '8382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8382', '112', '10259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10260', '1079', '1', 'Remígio', 'BR.17.2512705', 'ASCII:Remigio;ID:6320390', '8383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8383', '112', '10260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10261', '1079', '1', 'Pedro Régis', 'BR.17.2512721', 'ASCII:Pedro Regio;ID:6320391', '8384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8384', '112', '10261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10262', '1079', '1', 'Riachão', 'BR.17.2512747', 'ASCII:Riachao;ID:6320392', '8385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8385', '112', '10262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10263', '1079', '1', 'Riachão do Bacamarte', 'BR.17.2512754', 'ASCII:Assis Chateaubriand;ID:6320393', '8386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8386', '112', '10263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10264', '1079', '1', 'Riachão do Poço', 'BR.17.2512762', 'ASCII:Riachao Do Poco;ID:6320394', '8387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8387', '112', '10264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512762» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10265', '1079', '1', 'Riacho de Santo Antônio', 'BR.17.2512788', 'ASCII:Riacho De Santo Antonio;ID:6320395', '8388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8388', '112', '10265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512788» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10266', '1079', '1', 'Riacho dos Cavalos', 'BR.17.2512804', 'ASCII:Riacho Dos Cavalos;ID:6320396', '8389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8389', '112', '10266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10267', '1079', '1', 'Salgadinho', 'BR.17.2513000', 'ASCII:Salgadinho;ID:6320397', '8390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8390', '112', '10267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10268', '1079', '1', 'Salgado de São Félix', 'BR.17.2513109', 'ASCII:Salgado De Sao Felix;ID:6320398', '8391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8391', '112', '10268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10269', '1079', '1', 'Santa Cecília', 'BR.17.2513158', 'ASCII:Santa Cecilia;ID:6320399', '8392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8392', '112', '10269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10270', '1079', '1', 'Santa Cruz', 'BR.17.2513208', 'ASCII:Santa Cruz;ID:6320400', '8393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8393', '112', '10270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10271', '1079', '1', 'Santa Helena', 'BR.17.2513307', 'ASCII:Santa Helena;ID:6320401', '8394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8394', '112', '10271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10272', '1079', '1', 'Santa Inês', 'BR.17.2513356', 'ASCII:Santa Ines;ID:6320402', '8395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8395', '112', '10272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10273', '1079', '1', 'Santa Luzia', 'BR.17.2513406', 'ASCII:Santa Luzia;ID:6320403', '8396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8396', '112', '10273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10274', '1079', '1', 'Santana de Mangueira', 'BR.17.2513505', 'ASCII:Santana De Mangueira;ID:6320404', '8397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8397', '112', '10274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10275', '1079', '1', 'Santana dos Garrotes', 'BR.17.2513604', 'ASCII:Santana Dos Garrotes;ID:6320405', '8398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8398', '112', '10275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10276', '1079', '1', 'Santarém', 'BR.17.2513653', 'ASCII:Santarem;ID:6320406', '8399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8399', '112', '10276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10277', '1079', '1', 'Santa Teresinha', 'BR.17.2513802', 'ASCII:Santa Teresinha;ID:6320407', '8400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8400', '112', '10277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10278', '1079', '1', 'Santo André', 'BR.17.2513851', 'ASCII:Santo Andre;ID:6320408', '8401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8401', '112', '10278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10279', '1079', '1', 'São Bento', 'BR.17.2513901', 'ASCII:Sao Bento;ID:6320409', '8402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8402', '112', '10279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10280', '1079', '1', 'São Bentinho', 'BR.17.2513927', 'ASCII:Sao Bento De Pombal;ID:6320410', '8403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8403', '112', '10280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10281', '1079', '1', 'São Domingos do Cariri', 'BR.17.2513943', 'ASCII:Sao Domingos Do Cariri;ID:6320411', '8404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8404', '112', '10281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10282', '1079', '1', 'São Domingos de Pombal', 'BR.17.2513968', 'ASCII:Sao Domingos De Pombal;ID:6320412', '8405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8405', '112', '10282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513968» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10283', '1079', '1', 'São João do Cariri', 'BR.17.2514008', 'ASCII:Sao Joao Do Cariri;ID:6320413', '8406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8406', '112', '10283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10284', '1079', '1', 'São João do Tigre', 'BR.17.2514107', 'ASCII:Sao Joao Do Tigre;ID:6320414', '8407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8407', '112', '10284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10285', '1079', '1', 'São José da Lagoa Tapada', 'BR.17.2514206', 'ASCII:Sao Jose Da Lagoa Tapada;ID:6320415', '8408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8408', '112', '10285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10286', '1079', '1', 'São José de Caiana', 'BR.17.2514305', 'ASCII:Sao Jose De Caiana;ID:6320416', '8409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8409', '112', '10286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10287', '1079', '1', 'São José de Espinharas', 'BR.17.2514404', 'ASCII:Sao Jose De Espinharas;ID:6320417', '8410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8410', '112', '10287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10288', '1079', '1', 'São José dos Ramos', 'BR.17.2514453', 'ASCII:Sao Jose Dos Ramos;ID:6320418', '8411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8411', '112', '10288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10289', '1079', '1', 'São José de Piranhas', 'BR.17.2514503', 'ASCII:Sao Jose De Piranhas;ID:6320419', '8412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8412', '112', '10289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10290', '1079', '1', 'São José de Princesa', 'BR.17.2514552', 'ASCII:Sao Jose De Princesa;ID:6320420', '8413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8413', '112', '10290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10291', '1079', '1', 'São José do Brejo do Cruz', 'BR.17.2514651', 'ASCII:Sao Jose Do Brejo Do Cruz;ID:6320421', '8414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8414', '112', '10291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10292', '1079', '1', 'São José do Sabugi', 'BR.17.2514701', 'ASCII:Sao Jose Do Sabugi;ID:6320422', '8415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8415', '112', '10292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10293', '1079', '1', 'São José dos Cordeiros', 'BR.17.2514800', 'ASCII:Sao Jose Dos Cordeiros;ID:6320423', '8416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8416', '112', '10293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10294', '1079', '1', 'São Mamede', 'BR.17.2514909', 'ASCII:Sao Mamede;ID:6320424', '8417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8417', '112', '10294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2514909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10295', '1079', '1', 'São Miguel de Taipu', 'BR.17.2515005', 'ASCII:Sao Miguel De Taipu;ID:6320425', '8418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8418', '112', '10295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10296', '1079', '1', 'São Sebastião de Lagoa de Roça', 'BR.17.2515104', 'ASCII:Sao Sebastiao De Lagoa De Roca;ID:6320426', '8419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8419', '112', '10296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10297', '1079', '1', 'São Sebastião do Umbuzeiro', 'BR.17.2515203', 'ASCII:Sao Sebastiao Do Umbuzeiro;ID:6320427', '8420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8420', '112', '10297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10298', '1079', '1', 'Sapé', 'BR.17.2515302', 'ASCII:Sape;ID:6320428', '8421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8421', '112', '10298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10299', '1079', '1', 'Seridó', 'BR.17.2515401', 'ASCII:Serido;ID:6320429', '8422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8422', '112', '10299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10300', '1079', '1', 'Serra Branca', 'BR.17.2515500', 'ASCII:Serra Branca;ID:6320430', '8423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8423', '112', '10300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10301', '1079', '1', 'Serra da Raiz', 'BR.17.2515609', 'ASCII:Serra Da Raiz;ID:6320431', '8424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8424', '112', '10301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10302', '1079', '1', 'Serra Grande', 'BR.17.2515708', 'ASCII:Serra Grande;ID:6320432', '8425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8425', '112', '10302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10303', '1079', '1', 'Serra Redonda', 'BR.17.2515807', 'ASCII:Serra Redonda;ID:6320433', '8426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8426', '112', '10303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10304', '1079', '1', 'Serraria', 'BR.17.2515906', 'ASCII:Serraria;ID:6320434', '8427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8427', '112', '10304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10305', '1079', '1', 'Sobrado', 'BR.17.2515971', 'ASCII:Sobrado;ID:6320435', '8428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8428', '112', '10305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10306', '1079', '1', 'Solânea', 'BR.17.2516003', 'ASCII:Solanea;ID:6320436', '8429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8429', '112', '10306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10307', '1079', '1', 'Sossêgo', 'BR.17.2516151', 'ASCII:Sossego;ID:6320437', '8430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8430', '112', '10307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10308', '1079', '1', 'Sumé', 'BR.17.2516300', 'ASCII:Sume;ID:6320438', '8431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8431', '112', '10308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10309', '1079', '1', 'Campo de Santana', 'BR.17.2516409', 'ASCII:Tacima;ID:6320439', '8432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8432', '112', '10309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10310', '1079', '1', 'Taperoá', 'BR.17.2516508', 'ASCII:Taperoa;ID:6320440', '8433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8433', '112', '10310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10311', '1079', '1', 'Tavares', 'BR.17.2516607', 'ASCII:Tavares;ID:6320441', '8434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8434', '112', '10311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10312', '1079', '1', 'Teixeira', 'BR.17.2516706', 'ASCII:Teixeira;ID:6320442', '8435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8435', '112', '10312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10313', '1079', '1', 'Tenório', 'BR.17.2516755', 'ASCII:Tenorio;ID:6320443', '8436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8436', '112', '10313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10314', '1079', '1', 'Uiraúna', 'BR.17.2516904', 'ASCII:Uirauna;ID:6320444', '8437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8437', '112', '10314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10315', '1079', '1', 'Umbuzeiro', 'BR.17.2517001', 'ASCII:Umbuzeiro;ID:6320445', '8438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8438', '112', '10315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2517001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10316', '1079', '1', 'Várzea', 'BR.17.2517100', 'ASCII:Varzea;ID:6320446', '8439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8439', '112', '10316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2517100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10317', '1079', '1', 'Vieirópolis', 'BR.17.2517209', 'ASCII:Vieiropolis;ID:6320447', '8440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8440', '112', '10317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2517209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10318', '1079', '1', 'Abreu e Lima', 'BR.30.2600054', 'ASCII:Abreu E Lima;ID:6320448', '8441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8441', '112', '10318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2600054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10319', '1079', '1', 'Afogados da Ingazeira', 'BR.30.2600104', 'ASCII:Afogados Da Ingazeira;ID:6320449', '8442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8442', '112', '10319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2600104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10320', '1079', '1', 'Afrânio', 'BR.30.2600203', 'ASCII:Afranio;ID:6320450', '8443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8443', '112', '10320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2600203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10321', '1079', '1', 'Agrestina', 'BR.30.2600302', 'ASCII:Agrestina;ID:6320451', '8444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8444', '112', '10321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2600302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10322', '1079', '1', 'Água Preta', 'BR.30.2600401', 'ASCII:Agua Preta;ID:6320452', '8445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8445', '112', '10322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2600401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10323', '1079', '1', 'Águas Belas', 'BR.30.2600500', 'ASCII:Aguas Belas;ID:6320453', '8446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8446', '112', '10323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2600500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10324', '1079', '1', 'Alagoinha', 'BR.30.2600609', 'ASCII:Alagoinha;ID:6320454', '8447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8447', '112', '10324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2600609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10325', '1079', '1', 'Aliança', 'BR.30.2600708', 'ASCII:Alianca;ID:6320455', '8448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8448', '112', '10325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2600708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10326', '1079', '1', 'Altinho', 'BR.30.2600807', 'ASCII:Altinho;ID:6320456', '8449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8449', '112', '10326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2600807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10327', '1079', '1', 'Amaraji', 'BR.30.2600906', 'ASCII:Amaraji;ID:6320457', '8450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8450', '112', '10327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2600906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10328', '1079', '1', 'Angelim', 'BR.30.2601003', 'ASCII:Angelim;ID:6320458', '8451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8451', '112', '10328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10329', '1079', '1', 'Arcoverde', 'BR.30.2601201', 'ASCII:Arcoverde;ID:6320459', '8452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8452', '112', '10329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10330', '1079', '1', 'Barra de Guabiraba', 'BR.30.2601300', 'ASCII:Barra De Guabiraba;ID:6320460', '8453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8453', '112', '10330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10331', '1079', '1', 'Barreiros', 'BR.30.2601409', 'ASCII:Barreiros;ID:6320461', '8454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8454', '112', '10331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10332', '1079', '1', 'Belém de Maria', 'BR.30.2601508', 'ASCII:Belem De Maria;ID:6320462', '8455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8455', '112', '10332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10333', '1079', '1', 'Belém de São Francisco', 'BR.30.2601607', 'ASCII:Belem De Sao Francisco;ID:6320463', '8456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8456', '112', '10333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10334', '1079', '1', 'Belo Jardim', 'BR.30.2601706', 'ASCII:Belo Jardim;ID:6320464', '8457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8457', '112', '10334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10335', '1079', '1', 'Betânia', 'BR.30.2601805', 'ASCII:Betania;ID:6320465', '8458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8458', '112', '10335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10336', '1079', '1', 'Bezerros', 'BR.30.2601904', 'ASCII:Bezerros;ID:6320466', '8459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8459', '112', '10336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10337', '1079', '1', 'Bodocó', 'BR.30.2602001', 'ASCII:Bodoco;ID:6320467', '8460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8460', '112', '10337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2602001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10338', '1079', '1', 'Bom Conselho', 'BR.30.2602100', 'ASCII:Bom Conselho;ID:6320468', '8461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8461', '112', '10338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2602100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10339', '1079', '1', 'Bom Jardim', 'BR.30.2602209', 'ASCII:Bom Jardim;ID:6320469', '8462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8462', '112', '10339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2602209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10340', '1079', '1', 'Bonito', 'BR.30.2602308', 'ASCII:Bonito;ID:6320470', '8463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8463', '112', '10340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2602308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10341', '1079', '1', 'Brejão', 'BR.30.2602407', 'ASCII:Brejao;ID:6320471', '8464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8464', '112', '10341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2602407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10342', '1079', '1', 'Brejinho', 'BR.30.2602506', 'ASCII:Brejinho;ID:6320472', '8465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8465', '112', '10342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2602506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10343', '1079', '1', 'Brejo da Madre de Deus', 'BR.30.2602605', 'ASCII:Brejo Da Madre De Deus;ID:6320473', '8466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8466', '112', '10343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2602605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10344', '1079', '1', 'Buenos Aires', 'BR.30.2602704', 'ASCII:Buenos Aires;ID:6320474', '8467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8467', '112', '10344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2602704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10345', '1079', '1', 'Buíque', 'BR.30.2602803', 'ASCII:Buique;ID:6320475', '8468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8468', '112', '10345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2602803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10346', '1079', '1', 'Cabo de Santo Agostinho', 'BR.30.2602902', 'ASCII:Cabo De Santo Agostinho;ID:6320476', '8469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8469', '112', '10346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2602902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10347', '1079', '1', 'Cabrobó', 'BR.30.2603009', 'ASCII:Cabrobo;ID:6320477', '8470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8470', '112', '10347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10348', '1079', '1', 'Cachoeirinha', 'BR.30.2603108', 'ASCII:Cachoeirinha;ID:6320478', '8471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8471', '112', '10348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10349', '1079', '1', 'Caetés', 'BR.30.2603207', 'ASCII:Caetes;ID:6320479', '8472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8472', '112', '10349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10350', '1079', '1', 'Calçado', 'BR.30.2603306', 'ASCII:Calcado;ID:6320480', '8473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8473', '112', '10350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10351', '1079', '1', 'Calumbi', 'BR.30.2603405', 'ASCII:Calumbi;ID:6320481', '8474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8474', '112', '10351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10352', '1079', '1', 'Camaragibe', 'BR.30.2603454', 'ASCII:Camaragibe;ID:6320482', '8475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8475', '112', '10352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10353', '1079', '1', 'Camocim de São Félix', 'BR.30.2603504', 'ASCII:Camocim De Sao Felix;ID:6320483', '8476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8476', '112', '10353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10354', '1079', '1', 'Camutanga', 'BR.30.2603603', 'ASCII:Camutanga;ID:6320484', '8477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8477', '112', '10354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10355', '1079', '1', 'Canhotinho', 'BR.30.2603702', 'ASCII:Canhotinho;ID:6320485', '8478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8478', '112', '10355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10356', '1079', '1', 'Capoeiras', 'BR.30.2603801', 'ASCII:Capoeiras;ID:6320486', '8479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8479', '112', '10356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10357', '1079', '1', 'Carnaíba', 'BR.30.2603900', 'ASCII:Carnaiba;ID:6320487', '8480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8480', '112', '10357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10358', '1079', '1', 'Carnaubeira da Penha', 'BR.30.2603926', 'ASCII:Carnaubeira Da Penha;ID:6320488', '8481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8481', '112', '10358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2603926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10359', '1079', '1', 'Carpina', 'BR.30.2604007', 'ASCII:Carpina;ID:6320489', '8482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8482', '112', '10359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10360', '1079', '1', 'Caruaru', 'BR.30.2604106', 'ASCII:Caruaru;ID:6320490', '8483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8483', '112', '10360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10361', '1079', '1', 'Casinhas', 'BR.30.2604155', 'ASCII:Casinhas;ID:6320491', '8484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8484', '112', '10361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10362', '1079', '1', 'Catende', 'BR.30.2604205', 'ASCII:Catende;ID:6320492', '8485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8485', '112', '10362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10363', '1079', '1', 'Chã de Alegria', 'BR.30.2604403', 'ASCII:Cha De Alegria;ID:6320493', '8486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8486', '112', '10363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10364', '1079', '1', 'Chã Grande', 'BR.30.2604502', 'ASCII:Cha Grande;ID:6320494', '8487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8487', '112', '10364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10365', '1079', '1', 'Condado', 'BR.30.2604601', 'ASCII:Condado;ID:6320495', '8488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8488', '112', '10365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10366', '1079', '1', 'Cortês', 'BR.30.2604809', 'ASCII:Cortes;ID:6320496', '8489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8489', '112', '10366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10367', '1079', '1', 'Cumaru', 'BR.30.2604908', 'ASCII:Cumaru;ID:6320497', '8490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8490', '112', '10367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10368', '1079', '1', 'Cupira', 'BR.30.2605004', 'ASCII:Cupira;ID:6320498', '8491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8491', '112', '10368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10369', '1079', '1', 'Custódia', 'BR.30.2605103', 'ASCII:Custodia;ID:6320499', '8492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8492', '112', '10369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10370', '1079', '1', 'Dormentes', 'BR.30.2605152', 'ASCII:Dormentes;ID:6320500', '8493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8493', '112', '10370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10371', '1079', '1', 'Escada', 'BR.30.2605202', 'ASCII:Escada;ID:6320501', '8494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8494', '112', '10371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10372', '1079', '1', 'Exu', 'BR.30.2605301', 'ASCII:Exu;ID:6320502', '8495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8495', '112', '10372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10373', '1079', '1', 'Feira Nova', 'BR.30.2605400', 'ASCII:Feira Nova;ID:6320503', '8496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8496', '112', '10373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10374', '1079', '1', 'Floresta', 'BR.30.2605707', 'ASCII:Floresta;ID:6320504', '8497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8497', '112', '10374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10375', '1079', '1', 'Frei Miguelinho', 'BR.30.2605806', 'ASCII:Frei Miguelinho;ID:6320505', '8498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8498', '112', '10375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10376', '1079', '1', 'Gameleira', 'BR.30.2605905', 'ASCII:Gameleira;ID:6320506', '8499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8499', '112', '10376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10377', '1079', '1', 'Garanhuns', 'BR.30.2606002', 'ASCII:Garanhuns;ID:6320507', '8500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8500', '112', '10377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2606002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10378', '1079', '1', 'Glória do Goitá', 'BR.30.2606101', 'ASCII:Gloria Do Goita;ID:6320508', '8501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8501', '112', '10378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2606101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10379', '1079', '1', 'Goiana', 'BR.30.2606200', 'ASCII:Goiana;ID:6320509', '8502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8502', '112', '10379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2606200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10380', '1079', '1', 'Granito', 'BR.30.2606309', 'ASCII:Granito;ID:6320510', '8503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8503', '112', '10380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2606309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10381', '1079', '1', 'Gravatá', 'BR.30.2606408', 'ASCII:Gravata;ID:6320511', '8504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8504', '112', '10381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2606408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10382', '1079', '1', 'Iati', 'BR.30.2606507', 'ASCII:Iati;ID:6320512', '8505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8505', '112', '10382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2606507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10383', '1079', '1', 'Ibimirim', 'BR.30.2606606', 'ASCII:Ibimirim;ID:6320513', '8506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8506', '112', '10383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2606606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10384', '1079', '1', 'Ibirajuba', 'BR.30.2606705', 'ASCII:Ibirajuba;ID:6320514', '8507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8507', '112', '10384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2606705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10385', '1079', '1', 'Igarassu', 'BR.30.2606804', 'ASCII:Igarassu;ID:6320515', '8508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8508', '112', '10385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2606804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10386', '1079', '1', 'Iguaraci', 'BR.30.2606903', 'ASCII:Iguaraci;ID:6320516', '8509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8509', '112', '10386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2606903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10387', '1079', '1', 'Inajá', 'BR.30.2607000', 'ASCII:Inaja;ID:6320517', '8510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8510', '112', '10387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10388', '1079', '1', 'Ingazeira', 'BR.30.2607109', 'ASCII:Ingazeira;ID:6320518', '8511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8511', '112', '10388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10389', '1079', '1', 'Ipojuca', 'BR.30.2607208', 'ASCII:Ipojuca;ID:6320519', '8512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8512', '112', '10389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10390', '1079', '1', 'Ipubi', 'BR.30.2607307', 'ASCII:Ipubi;ID:6320520', '8513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8513', '112', '10390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10391', '1079', '1', 'Itacuruba', 'BR.30.2607406', 'ASCII:Itacuruba;ID:6320521', '8514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8514', '112', '10391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10392', '1079', '1', 'Itaíba', 'BR.30.2607505', 'ASCII:Itaiba;ID:6320522', '8515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8515', '112', '10392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10393', '1079', '1', 'Ilha de Itamaracá', 'BR.30.2607604', 'ASCII:Itamaraca;ID:6320523', '8516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8516', '112', '10393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10394', '1079', '1', 'Itapetim', 'BR.30.2607703', 'ASCII:Itapetim;ID:6320524', '8517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8517', '112', '10394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10395', '1079', '1', 'Itapissuma', 'BR.30.2607752', 'ASCII:Itapissuma;ID:6320525', '8518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8518', '112', '10395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10396', '1079', '1', 'Itaquitinga', 'BR.30.2607802', 'ASCII:Itaquitinga;ID:6320526', '8519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8519', '112', '10396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10397', '1079', '1', 'Jaboatão dos Guararapes', 'BR.30.2607901', 'ASCII:Jaboatao Dos Guararapes;ID:6320527', '8520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8520', '112', '10397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10398', '1079', '1', 'Jaqueira', 'BR.30.2607950', 'ASCII:Jaqueira;ID:6320528', '8521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8521', '112', '10398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10399', '1079', '1', 'Jataúba', 'BR.30.2608008', 'ASCII:Jatauba;ID:6320529', '8522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8522', '112', '10399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10400', '1079', '1', 'Jatobá', 'BR.30.2608057', 'ASCII:Jatoba;ID:6320530', '8523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8523', '112', '10400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10401', '1079', '1', 'João Alfredo', 'BR.30.2608107', 'ASCII:Joao Alfredo;ID:6320531', '8524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8524', '112', '10401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10402', '1079', '1', 'Joaquim Nabuco', 'BR.30.2608206', 'ASCII:Joaquim Nabuco;ID:6320532', '8525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8525', '112', '10402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10403', '1079', '1', 'Jucati', 'BR.30.2608255', 'ASCII:Jucati;ID:6320533', '8526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8526', '112', '10403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10404', '1079', '1', 'Jupi', 'BR.30.2608305', 'ASCII:Jupi;ID:6320534', '8527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8527', '112', '10404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10405', '1079', '1', 'Jurema', 'BR.30.2608404', 'ASCII:Jurema;ID:6320535', '8528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8528', '112', '10405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10406', '1079', '1', 'Lagoa do Carro', 'BR.30.2608453', 'ASCII:Lagoa Do Carro;ID:6320536', '8529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8529', '112', '10406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10407', '1079', '1', 'Lagoa do Itaenga', 'BR.30.2608503', 'ASCII:Lagoa Do Itaenga;ID:6320537', '8530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8530', '112', '10407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10408', '1079', '1', 'Lagoa do Ouro', 'BR.30.2608602', 'ASCII:Lagoa Do Ouro;ID:6320538', '8531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8531', '112', '10408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10409', '1079', '1', 'Lagoa dos Gatos', 'BR.30.2608701', 'ASCII:Lagoa Dos Gatos;ID:6320539', '8532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8532', '112', '10409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10410', '1079', '1', 'Lagoa Grande', 'BR.30.2608750', 'ASCII:Lagoa Grande;ID:6320540', '8533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8533', '112', '10410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10411', '1079', '1', 'Lajedo', 'BR.30.2608800', 'ASCII:Lajedo;ID:6320541', '8534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8534', '112', '10411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10412', '1079', '1', 'Limoeiro', 'BR.30.2608909', 'ASCII:Limoeiro;ID:6320542', '8535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8535', '112', '10412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2608909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10413', '1079', '1', 'Macaparana', 'BR.30.2609006', 'ASCII:Macaparana;ID:6320543', '8536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8536', '112', '10413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10414', '1079', '1', 'Machados', 'BR.30.2609105', 'ASCII:Machados;ID:6320544', '8537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8537', '112', '10414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10415', '1079', '1', 'Manari', 'BR.30.2609154', 'ASCII:Manari;ID:6320545', '8538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8538', '112', '10415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10416', '1079', '1', 'Maraial', 'BR.30.2609204', 'ASCII:Maraial;ID:6320546', '8539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8539', '112', '10416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10417', '1079', '1', 'Mirandiba', 'BR.30.2609303', 'ASCII:Mirandiba;ID:6320547', '8540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8540', '112', '10417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10418', '1079', '1', 'Moreno', 'BR.30.2609402', 'ASCII:Moreno;ID:6320548', '8541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8541', '112', '10418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10419', '1079', '1', 'Nazaré da Mata', 'BR.30.2609501', 'ASCII:Nazare Da Mata;ID:6320549', '8542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8542', '112', '10419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10420', '1079', '1', 'Olinda', 'BR.30.2609600', 'ASCII:Olinda;ID:6320550', '8543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8543', '112', '10420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10421', '1079', '1', 'Orobó', 'BR.30.2609709', 'ASCII:Orobo;ID:6320551', '8544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8544', '112', '10421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10422', '1079', '1', 'Orocó', 'BR.30.2609808', 'ASCII:Oroco;ID:6320552', '8545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8545', '112', '10422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10423', '1079', '1', 'Ouricuri', 'BR.30.2609907', 'ASCII:Ouricuri;ID:6320553', '8546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8546', '112', '10423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2609907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10424', '1079', '1', 'Palmares', 'BR.30.2610004', 'ASCII:Palmares;ID:6320554', '8547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8547', '112', '10424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2610004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10425', '1079', '1', 'Palmeirina', 'BR.30.2610103', 'ASCII:Palmeirina;ID:6320555', '8548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8548', '112', '10425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2610103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10426', '1079', '1', 'Panelas', 'BR.30.2610202', 'ASCII:Panelas;ID:6320556', '8549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8549', '112', '10426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2610202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10427', '1079', '1', 'Paranatama', 'BR.30.2610301', 'ASCII:Paranatama;ID:6320557', '8550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8550', '112', '10427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2610301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10428', '1079', '1', 'Parnamirim', 'BR.30.2610400', 'ASCII:Parnamirim;ID:6320558', '8551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8551', '112', '10428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2610400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10429', '1079', '1', 'Passira', 'BR.30.2610509', 'ASCII:Passira;ID:6320559', '8552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8552', '112', '10429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2610509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10430', '1079', '1', 'Paudalho', 'BR.30.2610608', 'ASCII:Paudalho;ID:6320560', '8553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8553', '112', '10430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2610608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10431', '1079', '1', 'Pedra', 'BR.30.2610806', 'ASCII:Pedra;ID:6320561', '8554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8554', '112', '10431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2610806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10432', '1079', '1', 'Pesqueira', 'BR.30.2610905', 'ASCII:Pesqueira;ID:6320562', '8555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8555', '112', '10432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2610905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10433', '1079', '1', 'Petrolândia', 'BR.30.2611002', 'ASCII:Petrolandia;ID:6320563', '8556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8556', '112', '10433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10434', '1079', '1', 'Petrolina', 'BR.30.2611101', 'ASCII:Petrolina;ID:6320564', '8557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8557', '112', '10434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10435', '1079', '1', 'Poção', 'BR.30.2611200', 'ASCII:Pocao;ID:6320565', '8558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8558', '112', '10435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10436', '1079', '1', 'Pombos', 'BR.30.2611309', 'ASCII:Pombos;ID:6320566', '8559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8559', '112', '10436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10437', '1079', '1', 'Primavera', 'BR.30.2611408', 'ASCII:Primavera;ID:6320567', '8560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8560', '112', '10437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10438', '1079', '1', 'Quipapá', 'BR.30.2611507', 'ASCII:Quipapa;ID:6320568', '8561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8561', '112', '10438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10439', '1079', '1', 'Quixaba', 'BR.30.2611533', 'ASCII:Quixaba;ID:6320569', '8562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8562', '112', '10439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10440', '1079', '1', 'Recife', 'BR.30.2611606', 'ASCII:Recife;ID:6320570', '8563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8563', '112', '10440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10441', '1079', '1', 'Riacho das Almas', 'BR.30.2611705', 'ASCII:Riacho Das Almas;ID:6320571', '8564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8564', '112', '10441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10442', '1079', '1', 'Ribeirão', 'BR.30.2611804', 'ASCII:Ribeirao;ID:6320572', '8565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8565', '112', '10442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10443', '1079', '1', 'Rio Formoso', 'BR.30.2611903', 'ASCII:Rio Formoso;ID:6320573', '8566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8566', '112', '10443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2611903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10444', '1079', '1', 'Sairé', 'BR.30.2612000', 'ASCII:Saire;ID:6320574', '8567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8567', '112', '10444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10445', '1079', '1', 'Salgadinho', 'BR.30.2612109', 'ASCII:Salgadinho;ID:6320575', '8568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8568', '112', '10445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10446', '1079', '1', 'Salgueiro', 'BR.30.2612208', 'ASCII:Salgueiro;ID:6320576', '8569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8569', '112', '10446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10447', '1079', '1', 'Saloá', 'BR.30.2612307', 'ASCII:Saloa;ID:6320577', '8570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8570', '112', '10447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10448', '1079', '1', 'Sanharó', 'BR.30.2612406', 'ASCII:Sanharo;ID:6320578', '8571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8571', '112', '10448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10449', '1079', '1', 'Santa Cruz', 'BR.30.2612455', 'ASCII:Santa Cruz;ID:6320579', '8572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8572', '112', '10449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10450', '1079', '1', 'Santa Cruz da Baixa Verde', 'BR.30.2612471', 'ASCII:Santa Cruz Da Baixa Verde;ID:6320580', '8573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8573', '112', '10450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10451', '1079', '1', 'Santa Cruz do Capibaribe', 'BR.30.2612505', 'ASCII:Santa Cruz Do Capibaribe;ID:6320581', '8574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8574', '112', '10451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10452', '1079', '1', 'Santa Filomena', 'BR.30.2612554', 'ASCII:Santa Filomena;ID:6320582', '8575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8575', '112', '10452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10453', '1079', '1', 'Santa Maria da Boa Vista', 'BR.30.2612604', 'ASCII:Santa Maria Da Boa Vista;ID:6320583', '8576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8576', '112', '10453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10454', '1079', '1', 'Santa Maria do Cambucá', 'BR.30.2612703', 'ASCII:Santa Maria Do Cambuca;ID:6320584', '8577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8577', '112', '10454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10455', '1079', '1', 'Santa Terezinha', 'BR.30.2612802', 'ASCII:Santa Terezinha;ID:6320585', '8578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8578', '112', '10455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2612802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10456', '1079', '1', 'São Bento do Una', 'BR.30.2613008', 'ASCII:Sao Bento Do Una;ID:6320586', '8579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8579', '112', '10456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2613008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10457', '1079', '1', 'São Caitano', 'BR.30.2613107', 'ASCII:Sao Caitano;ID:6320587', '8580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8580', '112', '10457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2613107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10458', '1079', '1', 'São Joaquim do Monte', 'BR.30.2613305', 'ASCII:Sao Joaquim Do Monte;ID:6320588', '8581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8581', '112', '10458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2613305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10459', '1079', '1', 'São José da Coroa Grande', 'BR.30.2613404', 'ASCII:Sao Jose Da Coroa Grande;ID:6320589', '8582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8582', '112', '10459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2613404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10460', '1079', '1', 'São José do Belmonte', 'BR.30.2613503', 'ASCII:Sao Jose Do Belmonte;ID:6320590', '8583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8583', '112', '10460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2613503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10461', '1079', '1', 'São José do Egito', 'BR.30.2613602', 'ASCII:Sao Jose Do Egito;ID:6320591', '8584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8584', '112', '10461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2613602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10462', '1079', '1', 'São Lourenço da Mata', 'BR.30.2613701', 'ASCII:Sao Lourenco Da Mata;ID:6320592', '8585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8585', '112', '10462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2613701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10463', '1079', '1', 'São Vicente Ferrer', 'BR.30.2613800', 'ASCII:Sao Vicente Ferrer;ID:6320593', '8586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8586', '112', '10463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2613800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10464', '1079', '1', 'Serra Talhada', 'BR.30.2613909', 'ASCII:Serra Talhada;ID:6320594', '8587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8587', '112', '10464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2613909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10465', '1079', '1', 'Sertânia', 'BR.30.2614105', 'ASCII:Sertania;ID:6320595', '8588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8588', '112', '10465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2614105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10466', '1079', '1', 'Sirinhaém', 'BR.30.2614204', 'ASCII:Sirinhaem;ID:6320596', '8589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8589', '112', '10466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2614204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10467', '1079', '1', 'Moreilândia', 'BR.30.2614303', 'ASCII:Moreilandia;ID:6320597', '8590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8590', '112', '10467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2614303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10468', '1079', '1', 'Solidão', 'BR.30.2614402', 'ASCII:Solidao;ID:6320598', '8591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8591', '112', '10468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2614402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10469', '1079', '1', 'Surubim', 'BR.30.2614501', 'ASCII:Surubim;ID:6320599', '8592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8592', '112', '10469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2614501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10470', '1079', '1', 'Tabira', 'BR.30.2614600', 'ASCII:Tabira;ID:6320600', '8593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8593', '112', '10470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2614600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10471', '1079', '1', 'Tacaimbó', 'BR.30.2614709', 'ASCII:Tacaimbo;ID:6320601', '8594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8594', '112', '10471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2614709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10472', '1079', '1', 'Tacaratu', 'BR.30.2614808', 'ASCII:Tacaratu;ID:6320602', '8595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8595', '112', '10472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2614808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10473', '1079', '1', 'Tamandaré', 'BR.30.2614857', 'ASCII:Tamandare;ID:6320603', '8596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8596', '112', '10473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2614857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10474', '1079', '1', 'Taquaritinga do Norte', 'BR.30.2615003', 'ASCII:Taquaritinga Do Norte;ID:6320604', '8597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8597', '112', '10474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2615003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10475', '1079', '1', 'Terezinha', 'BR.30.2615102', 'ASCII:Terezinha;ID:6320605', '8598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8598', '112', '10475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2615102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10476', '1079', '1', 'Terra Nova', 'BR.30.2615201', 'ASCII:Terra Nova;ID:6320606', '8599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8599', '112', '10476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2615201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10477', '1079', '1', 'Toritama', 'BR.30.2615409', 'ASCII:Toritama;ID:6320607', '8600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8600', '112', '10477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2615409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10478', '1079', '1', 'Tracunhaém', 'BR.30.2615508', 'ASCII:Tracunhaem;ID:6320608', '8601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8601', '112', '10478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2615508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10479', '1079', '1', 'Trindade', 'BR.30.2615607', 'ASCII:Trindade;ID:6320609', '8602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8602', '112', '10479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2615607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10480', '1079', '1', 'Triunfo', 'BR.30.2615706', 'ASCII:Triunfo;ID:6320610', '8603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8603', '112', '10480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2615706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10481', '1079', '1', 'Tupanatinga', 'BR.30.2615805', 'ASCII:Tupanatinga;ID:6320611', '8604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8604', '112', '10481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2615805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10482', '1079', '1', 'Tuparetama', 'BR.30.2615904', 'ASCII:Tuparetama;ID:6320612', '8605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8605', '112', '10482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2615904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10483', '1079', '1', 'Venturosa', 'BR.30.2616001', 'ASCII:Venturosa;ID:6320613', '8606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8606', '112', '10483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2616001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10484', '1079', '1', 'Verdejante', 'BR.30.2616100', 'ASCII:Verdejante;ID:6320614', '8607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8607', '112', '10484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2616100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10485', '1079', '1', 'Vertente do Lério', 'BR.30.2616183', 'ASCII:Vertente Do Lerio;ID:6320615', '8608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8608', '112', '10485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2616183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10486', '1079', '1', 'Vertentes', 'BR.30.2616209', 'ASCII:Vertentes;ID:6320616', '8609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8609', '112', '10486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2616209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10487', '1079', '1', 'Vicência', 'BR.30.2616308', 'ASCII:Vicencia;ID:6320617', '8610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8610', '112', '10487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2616308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10488', '1079', '1', 'Vitória de Santo Antão', 'BR.30.2616407', 'ASCII:Vitoria De Santo Antao;ID:6320618', '8611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8611', '112', '10488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2616407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10489', '1079', '1', 'Xexéu', 'BR.30.2616506', 'ASCII:Xexeu;ID:6320619', '8612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8612', '112', '10489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2616506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10490', '1079', '1', 'Atalaia', 'BR.02.2700409', 'ASCII:Atalaia;ID:6320620', '8613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8613', '112', '10490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2700409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10491', '1079', '1', 'Barra de São Miguel', 'BR.02.2700607', 'ASCII:Barra De Sao Miguel;ID:6320621', '8614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8614', '112', '10491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2700607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10492', '1079', '1', 'Belém', 'BR.02.2700805', 'ASCII:Belem;ID:6320622', '8615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8615', '112', '10492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2700805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10493', '1079', '1', 'Boca da Mata', 'BR.02.2701001', 'ASCII:Boca Da Mata;ID:6320623', '8616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8616', '112', '10493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10494', '1079', '1', 'Branquinha', 'BR.02.2701100', 'ASCII:Branquinha;ID:6320624', '8617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8617', '112', '10494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10495', '1079', '1', 'Cajueiro', 'BR.02.2701308', 'ASCII:Cajueiro;ID:6320625', '8618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8618', '112', '10495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10496', '1079', '1', 'Campestre', 'BR.02.2701357', 'ASCII:Campestre;ID:6320626', '8619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8619', '112', '10496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10497', '1079', '1', 'Campo Alegre', 'BR.02.2701407', 'ASCII:Campo Alegre;ID:6320627', '8620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8620', '112', '10497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10498', '1079', '1', 'Capela', 'BR.02.2701704', 'ASCII:Capela;ID:6320628', '8621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8621', '112', '10498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10499', '1079', '1', 'Carneiros', 'BR.02.2701803', 'ASCII:Carneiros;ID:6320629', '8622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8622', '112', '10499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10500', '1079', '1', 'Chã Preta', 'BR.02.2701902', 'ASCII:Cha Preta;ID:6320630', '8623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8623', '112', '10500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10501', '1079', '1', 'Coité do Nóia', 'BR.02.2702009', 'ASCII:Coite Do Noia;ID:6320631', '8624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8624', '112', '10501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10502', '1079', '1', 'Colônia Leopoldina', 'BR.02.2702108', 'ASCII:Colonia Leopoldina;ID:6320632', '8625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8625', '112', '10502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10503', '1079', '1', 'Coqueiro Seco', 'BR.02.2702207', 'ASCII:Coqueiro Seco;ID:6320633', '8626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8626', '112', '10503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10504', '1079', '1', 'Dois Riachos', 'BR.02.2702504', 'ASCII:Dois Riachos;ID:6320634', '8627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8627', '112', '10504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10505', '1079', '1', 'Feliz Deserto', 'BR.02.2702702', 'ASCII:Feliz Deserto;ID:6320635', '8628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8628', '112', '10505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10506', '1079', '1', 'Flexeiras', 'BR.02.2702801', 'ASCII:Flexeiras;ID:6320636', '8629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8629', '112', '10506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10507', '1079', '1', 'Ibateguara', 'BR.02.2703007', 'ASCII:Ibateguara;ID:6320637', '8630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8630', '112', '10507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10508', '1079', '1', 'Inhapi', 'BR.02.2703304', 'ASCII:Inhapi;ID:6320638', '8631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8631', '112', '10508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10509', '1079', '1', 'Jacuípe', 'BR.02.2703502', 'ASCII:Jacuipe;ID:6320639', '8632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8632', '112', '10509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10510', '1079', '1', 'Japaratinga', 'BR.02.2703601', 'ASCII:Japaratinga;ID:6320640', '8633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8633', '112', '10510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10511', '1079', '1', 'Jaramataia', 'BR.02.2703700', 'ASCII:Jaramataia;ID:6320641', '8634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8634', '112', '10511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10512', '1079', '1', 'Joaquim Gomes', 'BR.02.2703809', 'ASCII:Joaquim Gomes;ID:6320642', '8635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8635', '112', '10512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10513', '1079', '1', 'Jundiá', 'BR.02.2703908', 'ASCII:Jundia;ID:6320643', '8636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8636', '112', '10513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10514', '1079', '1', 'Lagoa da Canoa', 'BR.02.2704104', 'ASCII:Lagoa Da Canoa;ID:6320644', '8637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8637', '112', '10514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2704104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10515', '1079', '1', 'Maceió', 'BR.02.2704302', 'ASCII:Maceio;ID:6320645', '8638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8638', '112', '10515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2704302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10516', '1079', '1', 'Maragogi', 'BR.02.2704500', 'ASCII:Maragogi;ID:6320646', '8639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8639', '112', '10516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2704500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10517', '1079', '1', 'Maravilha', 'BR.02.2704609', 'ASCII:Maravilha;ID:6320647', '8640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8640', '112', '10517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2704609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10518', '1079', '1', 'Marechal Deodoro', 'BR.02.2704708', 'ASCII:Marechal Deodoro;ID:6320648', '8641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8641', '112', '10518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2704708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10519', '1079', '1', 'Mar Vermelho', 'BR.02.2704906', 'ASCII:Mar Vermelho;ID:6320649', '8642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8642', '112', '10519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2704906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10520', '1079', '1', 'Matriz de Camaragibe', 'BR.02.2705101', 'ASCII:Matriz De Camaragibe;ID:6320650', '8643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8643', '112', '10520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2705101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10521', '1079', '1', 'Messias', 'BR.02.2705200', 'ASCII:Messias;ID:6320651', '8644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8644', '112', '10521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2705200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10522', '1079', '1', 'Minador do Negrão', 'BR.02.2705309', 'ASCII:Minador Do Negrao;ID:6320652', '8645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8645', '112', '10522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2705309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10523', '1079', '1', 'Monteirópolis', 'BR.02.2705408', 'ASCII:Monteiropolis;ID:6320653', '8646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8646', '112', '10523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2705408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10524', '1079', '1', 'Murici', 'BR.02.2705507', 'ASCII:Murici;ID:6320654', '8647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8647', '112', '10524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2705507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10525', '1079', '1', 'Novo Lino', 'BR.02.2705606', 'ASCII:Novo Lino;ID:6320655', '8648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8648', '112', '10525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2705606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10526', '1079', '1', 'Olho d''Água Grande', 'BR.02.2705903', 'ASCII:Olho D''Agua Grande;ID:6320656', '8649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8649', '112', '10526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2705903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10527', '1079', '1', 'Olivença', 'BR.02.2706000', 'ASCII:Olivenca;ID:6320657', '8650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8650', '112', '10527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10528', '1079', '1', 'Ouro Branco', 'BR.02.2706109', 'ASCII:Ouro Branco;ID:6320658', '8651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8651', '112', '10528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10529', '1079', '1', 'Palestina', 'BR.02.2706208', 'ASCII:Palestina;ID:6320659', '8652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8652', '112', '10529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10530', '1079', '1', 'Pariconha', 'BR.02.2706422', 'ASCII:Pariconha;ID:6320660', '8653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8653', '112', '10530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10531', '1079', '1', 'Paripueira', 'BR.02.2706448', 'ASCII:Paripueira;ID:6320661', '8654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8654', '112', '10531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10532', '1079', '1', 'Passo de Camaragibe', 'BR.02.2706505', 'ASCII:Passo De Camaragibe;ID:6320662', '8655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8655', '112', '10532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10533', '1079', '1', 'Paulo Jacinto', 'BR.02.2706604', 'ASCII:Paulo Jacinto;ID:6320663', '8656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8656', '112', '10533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10534', '1079', '1', 'Piaçabuçu', 'BR.02.2706802', 'ASCII:Piacabucu;ID:6320664', '8657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8657', '112', '10534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10535', '1079', '1', 'Pilar', 'BR.02.2706901', 'ASCII:Pilar;ID:6320665', '8658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8658', '112', '10535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2706901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10536', '1079', '1', 'Pindoba', 'BR.02.2707008', 'ASCII:Pindoba;ID:6320666', '8659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8659', '112', '10536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2707008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10537', '1079', '1', 'Porto Calvo', 'BR.02.2707305', 'ASCII:Porto Calvo;ID:6320667', '8660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8660', '112', '10537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2707305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10538', '1079', '1', 'Porto de Pedras', 'BR.02.2707404', 'ASCII:Porto De Pedras;ID:6320668', '8661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8661', '112', '10538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2707404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10539', '1079', '1', 'Quebrangulo', 'BR.02.2707602', 'ASCII:Quebrangulo;ID:6320669', '8662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8662', '112', '10539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2707602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10540', '1079', '1', 'Rio Largo', 'BR.02.2707701', 'ASCII:Rio Largo;ID:6320670', '8663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8663', '112', '10540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2707701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10541', '1079', '1', 'Roteiro', 'BR.02.2707800', 'ASCII:Roteiro;ID:6320671', '8664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8664', '112', '10541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2707800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10542', '1079', '1', 'Santa Luzia do Norte', 'BR.02.2707909', 'ASCII:Santa Luzia Do Norte;ID:6320672', '8665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8665', '112', '10542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2707909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10543', '1079', '1', 'Santana do Mundaú', 'BR.02.2708105', 'ASCII:Santana Do Mundau;ID:6320673', '8666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8666', '112', '10543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10544', '1079', '1', 'São Luís do Quitunde', 'BR.02.2708501', 'ASCII:Sao Luis Do Quitunde;ID:6320674', '8667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8667', '112', '10544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10545', '1079', '1', 'São Miguel dos Milagres', 'BR.02.2708709', 'ASCII:Sao Miguel Dos Milagres;ID:6320675', '8668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8668', '112', '10545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10546', '1079', '1', 'Satuba', 'BR.02.2708907', 'ASCII:Satuba;ID:6320676', '8669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8669', '112', '10546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10547', '1079', '1', 'Tanque d''Arca', 'BR.02.2709004', 'ASCII:Tanque D''Arca;ID:6320677', '8670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8670', '112', '10547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2709004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10548', '1079', '1', 'Taquarana', 'BR.02.2709103', 'ASCII:Taquarana;ID:6320678', '8671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8671', '112', '10548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2709103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10549', '1079', '1', 'Teotônio Vilela', 'BR.02.2709152', 'ASCII:Teotonio Vilela;ID:6320679', '8672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8672', '112', '10549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2709152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10550', '1079', '1', 'União dos Palmares', 'BR.02.2709301', 'ASCII:Uniao Dos Palmares;ID:6320680', '8673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8673', '112', '10550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2709301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10551', '1079', '1', 'Viçosa', 'BR.02.2709400', 'ASCII:Vicosa;ID:6320681', '8674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8674', '112', '10551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2709400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10552', '1079', '1', 'Aracaju', 'BR.28.2800308', 'ASCII:Aracaju;ID:6320682', '8675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8675', '112', '10552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2800308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10553', '1079', '1', 'Arauá', 'BR.28.2800407', 'ASCII:Araua;ID:6320683', '8676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8676', '112', '10553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2800407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10554', '1079', '1', 'Areia Branca', 'BR.28.2800506', 'ASCII:Areia Branca;ID:6320684', '8677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8677', '112', '10554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2800506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10555', '1079', '1', 'Barra dos Coqueiros', 'BR.28.2800605', 'ASCII:Barra Dos Coqueiros;ID:6320685', '8678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8678', '112', '10555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2800605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10556', '1079', '1', 'Boquim', 'BR.28.2800670', 'ASCII:Boquim;ID:6320686', '8679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8679', '112', '10556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2800670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10557', '1079', '1', 'Brejo Grande', 'BR.28.2800704', 'ASCII:Brejo Grande;ID:6320687', '8680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8680', '112', '10557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2800704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10558', '1079', '1', 'Capela', 'BR.28.2801306', 'ASCII:Capela;ID:6320688', '8681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8681', '112', '10558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2801306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10559', '1079', '1', 'Carmópolis', 'BR.28.2801504', 'ASCII:Carmopolis;ID:6320689', '8682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8682', '112', '10559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2801504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10560', '1079', '1', 'Cristinápolis', 'BR.28.2801702', 'ASCII:Cristinapolis;ID:6320690', '8683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8683', '112', '10560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2801702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10561', '1079', '1', 'Divina Pastora', 'BR.28.2802007', 'ASCII:Divina Pastora;ID:6320691', '8684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8684', '112', '10561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2802007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10562', '1079', '1', 'Estância', 'BR.28.2802106', 'ASCII:Estancia;ID:6320692', '8685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8685', '112', '10562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2802106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10563', '1079', '1', 'General Maynard', 'BR.28.2802502', 'ASCII:General Maynard;ID:6320693', '8686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8686', '112', '10563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2802502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10564', '1079', '1', 'Ilha das Flores', 'BR.28.2802700', 'ASCII:Ilha Das Flores;ID:6320694', '8687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8687', '112', '10564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2802700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10565', '1079', '1', 'Indiaroba', 'BR.28.2802809', 'ASCII:Indiaroba;ID:6320695', '8688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8688', '112', '10565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2802809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10566', '1079', '1', 'Itabaiana', 'BR.28.2802908', 'ASCII:Itabaiana;ID:6320696', '8689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8689', '112', '10566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2802908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10567', '1079', '1', 'Itaporanga d''Ajuda', 'BR.28.2803203', 'ASCII:Itaporanga D''Ajuda;ID:6320697', '8690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8690', '112', '10567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2803203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10568', '1079', '1', 'Japaratuba', 'BR.28.2803302', 'ASCII:Japaratuba;ID:6320698', '8691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8691', '112', '10568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2803302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10569', '1079', '1', 'Laranjeiras', 'BR.28.2803609', 'ASCII:Laranjeiras;ID:6320699', '8692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8692', '112', '10569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2803609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10570', '1079', '1', 'Malhada dos Bois', 'BR.28.2803807', 'ASCII:Malhada Dos Bois;ID:6320700', '8693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8693', '112', '10570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2803807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10571', '1079', '1', 'Malhador', 'BR.28.2803906', 'ASCII:Malhador;ID:6320701', '8694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8694', '112', '10571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2803906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10572', '1079', '1', 'Maruim', 'BR.28.2804003', 'ASCII:Maruim;ID:6320702', '8695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8695', '112', '10572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10573', '1079', '1', 'Moita Bonita', 'BR.28.2804102', 'ASCII:Moita Bonita;ID:6320703', '8696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8696', '112', '10573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10574', '1079', '1', 'Muribeca', 'BR.28.2804300', 'ASCII:Muribeca;ID:6320704', '8697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8697', '112', '10574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10575', '1079', '1', 'Nossa Senhora Aparecida', 'BR.28.2804458', 'ASCII:Nossa Senhora Aparecida;ID:6320705', '8698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8698', '112', '10575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10576', '1079', '1', 'Nossa Senhora de Lourdes', 'BR.28.2804706', 'ASCII:Nossa Senhora De Lourdes;ID:6320706', '8699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8699', '112', '10576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10577', '1079', '1', 'Nossa Senhora do Socorro', 'BR.28.2804805', 'ASCII:Nossa Senhora Do Socorro;ID:6320707', '8700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8700', '112', '10577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10578', '1079', '1', 'Pedrinhas', 'BR.28.2805109', 'ASCII:Pedrinhas;ID:6320708', '8701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8701', '112', '10578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2805109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10579', '1079', '1', 'Pirambu', 'BR.28.2805307', 'ASCII:Pirambu;ID:6320709', '8702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8702', '112', '10579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2805307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10580', '1079', '1', 'Riachuelo', 'BR.28.2805901', 'ASCII:Riachuelo;ID:6320710', '8703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8703', '112', '10580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2805901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10581', '1079', '1', 'Rosário do Catete', 'BR.28.2806107', 'ASCII:Rosario Do Catete;ID:6320711', '8704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8704', '112', '10581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2806107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10582', '1079', '1', 'Salgado', 'BR.28.2806206', 'ASCII:Salgado;ID:6320712', '8705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8705', '112', '10582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2806206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10583', '1079', '1', 'Santa Luzia do Itanhy', 'BR.28.2806305', 'ASCII:Santa Luzia Do Itanhy;ID:6320713', '8706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8706', '112', '10583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2806305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10584', '1079', '1', 'Santana do São Francisco', 'BR.28.2806404', 'ASCII:Santana Do Sao Francisco;ID:6320714', '8707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8707', '112', '10584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2806404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10585', '1079', '1', 'Santa Rosa de Lima', 'BR.28.2806503', 'ASCII:Santa Rosa De Lima;ID:6320715', '8708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8708', '112', '10585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2806503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10586', '1079', '1', 'Santo Amaro das Brotas', 'BR.28.2806602', 'ASCII:Santo Amaro Das Brotas;ID:6320716', '8709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8709', '112', '10586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2806602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10587', '1079', '1', 'São Cristóvão', 'BR.28.2806701', 'ASCII:Sao Cristovao;ID:6320717', '8710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8710', '112', '10587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2806701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10588', '1079', '1', 'Siriri', 'BR.28.2807204', 'ASCII:Siriri;ID:6320718', '8711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8711', '112', '10588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2807204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10589', '1079', '1', 'Telha', 'BR.28.2807303', 'ASCII:Telha;ID:6320719', '8712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8712', '112', '10589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2807303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10590', '1079', '1', 'Umbaúba', 'BR.28.2807600', 'ASCII:Umbauba;ID:6320720', '8713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8713', '112', '10590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2807600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10591', '1079', '1', 'Abaíra', 'BR.05.2900108', 'ASCII:Abaira;ID:6320721', '8714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8714', '112', '10591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2900108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10592', '1079', '1', 'Abaré', 'BR.05.2900207', 'ASCII:Abare;ID:6320722', '8715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8715', '112', '10592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2900207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10593', '1079', '1', 'Acajutiba', 'BR.05.2900306', 'ASCII:Acajutiba;ID:6320723', '8716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8716', '112', '10593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2900306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10594', '1079', '1', 'Adustina', 'BR.05.2900355', 'ASCII:Adustina;ID:6320724', '8717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8717', '112', '10594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2900355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10595', '1079', '1', 'Água Fria', 'BR.05.2900405', 'ASCII:Agua Fria;ID:6320725', '8718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8718', '112', '10595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2900405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10596', '1079', '1', 'Érico Cardoso', 'BR.05.2900504', 'ASCII:Erico Cardoso;ID:6320726', '8719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8719', '112', '10596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2900504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10597', '1079', '1', 'Aiquara', 'BR.05.2900603', 'ASCII:Aiquara;ID:6320727', '8720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8720', '112', '10597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2900603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10598', '1079', '1', 'Alcobaça', 'BR.05.2900801', 'ASCII:Alcobaca;ID:6320728', '8721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8721', '112', '10598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2900801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10599', '1079', '1', 'Almadina', 'BR.05.2900900', 'ASCII:Almadina;ID:6320729', '8722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8722', '112', '10599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2900900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10600', '1079', '1', 'Amargosa', 'BR.05.2901007', 'ASCII:Amargosa;ID:6320730', '8723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8723', '112', '10600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10601', '1079', '1', 'Amélia Rodrigues', 'BR.05.2901106', 'ASCII:Amelia Rodrigues;ID:6320731', '8724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8724', '112', '10601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10602', '1079', '1', 'América Dourada', 'BR.05.2901155', 'ASCII:America Dourada;ID:6320732', '8725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8725', '112', '10602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10603', '1079', '1', 'Anagé', 'BR.05.2901205', 'ASCII:Anage;ID:6320733', '8726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8726', '112', '10603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10604', '1079', '1', 'Andaraí', 'BR.05.2901304', 'ASCII:Andarai;ID:6320734', '8727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8727', '112', '10604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10605', '1079', '1', 'Andorinha', 'BR.05.2901353', 'ASCII:Andorinha;ID:6320735', '8728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8728', '112', '10605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10606', '1079', '1', 'Angical', 'BR.05.2901403', 'ASCII:Angical;ID:6320736', '8729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8729', '112', '10606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10607', '1079', '1', 'Anguera', 'BR.05.2901502', 'ASCII:Anguera;ID:6320737', '8730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8730', '112', '10607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10608', '1079', '1', 'Antas', 'BR.05.2901601', 'ASCII:Antas;ID:6320738', '8731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8731', '112', '10608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10609', '1079', '1', 'Antônio Cardoso', 'BR.05.2901700', 'ASCII:Antonio Cardoso;ID:6320739', '8732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8732', '112', '10609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10610', '1079', '1', 'Antônio Gonçalves', 'BR.05.2901809', 'ASCII:Antonio Goncalves;ID:6320740', '8733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8733', '112', '10610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10611', '1079', '1', 'Aporá', 'BR.05.2901908', 'ASCII:Apora;ID:6320741', '8734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8734', '112', '10611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10612', '1079', '1', 'Apuarema', 'BR.05.2901957', 'ASCII:Apuarema;ID:6320742', '8735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8735', '112', '10612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2901957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10613', '1079', '1', 'Aracatu', 'BR.05.2902005', 'ASCII:Aracatu;ID:6320743', '8736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8736', '112', '10613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10614', '1079', '1', 'Araças', 'BR.05.2902054', 'ASCII:Aracas;ID:6320744', '8737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8737', '112', '10614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10615', '1079', '1', 'Araci', 'BR.05.2902104', 'ASCII:Araci;ID:6320745', '8738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8738', '112', '10615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10616', '1079', '1', 'Arataca', 'BR.05.2902252', 'ASCII:Arataca;ID:6320746', '8739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8739', '112', '10616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10617', '1079', '1', 'Aratuípe', 'BR.05.2902302', 'ASCII:Aratuipe;ID:6320747', '8740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8740', '112', '10617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10618', '1079', '1', 'Aurelino Leal', 'BR.05.2902401', 'ASCII:Aurelino Leal;ID:6320748', '8741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8741', '112', '10618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10619', '1079', '1', 'Baianópolis', 'BR.05.2902500', 'ASCII:Baianopolis;ID:6320749', '8742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8742', '112', '10619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10620', '1079', '1', 'Baixa Grande', 'BR.05.2902609', 'ASCII:Baixa Grande;ID:6320750', '8743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8743', '112', '10620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10621', '1079', '1', 'Banzaê', 'BR.05.2902658', 'ASCII:Banzae;ID:6320751', '8744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8744', '112', '10621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10622', '1079', '1', 'Barra', 'BR.05.2902708', 'ASCII:Barra;ID:6320752', '8745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8745', '112', '10622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10623', '1079', '1', 'Barra da Estiva', 'BR.05.2902807', 'ASCII:Barra Da Estiva;ID:6320753', '8746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8746', '112', '10623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10624', '1079', '1', 'Barra do Choça', 'BR.05.2902906', 'ASCII:Barra Do Choca;ID:6320754', '8747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8747', '112', '10624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10625', '1079', '1', 'Barra do Rocha', 'BR.05.2903102', 'ASCII:Barra Do Rocha;ID:6320755', '8748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8748', '112', '10625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10626', '1079', '1', 'Barro Alto', 'BR.05.2903235', 'ASCII:Barro Alto;ID:6320756', '8749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8749', '112', '10626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10627', '1079', '1', 'Governador Lomanto Júnior', 'BR.05.2903300', 'ASCII:Barro Preto;ID:6320757', '8750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8750', '112', '10627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10628', '1079', '1', 'Belo Campo', 'BR.05.2903508', 'ASCII:Belo Campo;ID:6320758', '8751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8751', '112', '10628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10629', '1079', '1', 'Biritinga', 'BR.05.2903607', 'ASCII:Biritinga;ID:6320759', '8752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8752', '112', '10629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10630', '1079', '1', 'Boa Nova', 'BR.05.2903706', 'ASCII:Boa Nova;ID:6320760', '8753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8753', '112', '10630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10631', '1079', '1', 'Boa Vista do Tupim', 'BR.05.2903805', 'ASCII:Boa Vista Do Tupim;ID:6320761', '8754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8754', '112', '10631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10632', '1079', '1', 'Bom Jesus da Lapa', 'BR.05.2903904', 'ASCII:Bom Jesus Da Lapa;ID:6320762', '8755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8755', '112', '10632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10633', '1079', '1', 'Bom Jesus da Serra', 'BR.05.2903953', 'ASCII:Bom Jesus Da Serra;ID:6320763', '8756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8756', '112', '10633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10634', '1079', '1', 'Boninal', 'BR.05.2904001', 'ASCII:Boninal;ID:6320764', '8757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8757', '112', '10634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10635', '1079', '1', 'Bonito', 'BR.05.2904050', 'ASCII:Bonito;ID:6320765', '8758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8758', '112', '10635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10636', '1079', '1', 'Boquira', 'BR.05.2904100', 'ASCII:Boquira;ID:6320766', '8759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8759', '112', '10636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10637', '1079', '1', 'Botuporã', 'BR.05.2904209', 'ASCII:Botupora;ID:6320767', '8760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8760', '112', '10637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10638', '1079', '1', 'Brejolândia', 'BR.05.2904407', 'ASCII:Brejolandia;ID:6320768', '8761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8761', '112', '10638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10639', '1079', '1', 'Brotas de Macaúbas', 'BR.05.2904506', 'ASCII:Brotas De Macaubas;ID:6320769', '8762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8762', '112', '10639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10640', '1079', '1', 'Brumado', 'BR.05.2904605', 'ASCII:Brumado;ID:6320770', '8763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8763', '112', '10640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10641', '1079', '1', 'Buerarema', 'BR.05.2904704', 'ASCII:Buerarema;ID:6320771', '8764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8764', '112', '10641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10642', '1079', '1', 'Buritirama', 'BR.05.2904753', 'ASCII:Buritirama;ID:6320772', '8765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8765', '112', '10642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10643', '1079', '1', 'Caatiba', 'BR.05.2904803', 'ASCII:Caatiba;ID:6320773', '8766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8766', '112', '10643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10644', '1079', '1', 'Cabaceiras do Paraguaçu', 'BR.05.2904852', 'ASCII:Cabaceiras Do Paraguacu;ID:6320774', '8767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8767', '112', '10644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10645', '1079', '1', 'Cachoeira', 'BR.05.2904902', 'ASCII:Cachoeira;ID:6320775', '8768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8768', '112', '10645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2904902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10646', '1079', '1', 'Caculé', 'BR.05.2905008', 'ASCII:Cacule;ID:6320776', '8769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8769', '112', '10646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10647', '1079', '1', 'Caém', 'BR.05.2905107', 'ASCII:Caem;ID:6320777', '8770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8770', '112', '10647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10648', '1079', '1', 'Caetanos', 'BR.05.2905156', 'ASCII:Caetanos;ID:6320778', '8771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8771', '112', '10648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10649', '1079', '1', 'Caetité', 'BR.05.2905206', 'ASCII:Caetite;ID:6320779', '8772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8772', '112', '10649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10650', '1079', '1', 'Cafarnaum', 'BR.05.2905305', 'ASCII:Cafarnaum;ID:6320780', '8773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8773', '112', '10650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10651', '1079', '1', 'Cairu', 'BR.05.2905404', 'ASCII:Cairu;ID:6320781', '8774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8774', '112', '10651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10652', '1079', '1', 'Caldeirão Grande', 'BR.05.2905503', 'ASCII:Caldeirao Grande;ID:6320782', '8775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8775', '112', '10652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10653', '1079', '1', 'Camacan', 'BR.05.2905602', 'ASCII:Camacan;ID:6320783', '8776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8776', '112', '10653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10654', '1079', '1', 'Camaçari', 'BR.05.2905701', 'ASCII:Camacari;ID:6320784', '8777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8777', '112', '10654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10655', '1079', '1', 'Camamu', 'BR.05.2905800', 'ASCII:Camamu;ID:6320785', '8778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8778', '112', '10655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10656', '1079', '1', 'Campo Alegre de Lourdes', 'BR.05.2905909', 'ASCII:Campo Alegre De Lourdes;ID:6320786', '8779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8779', '112', '10656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2905909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10657', '1079', '1', 'Campo Formoso', 'BR.05.2906006', 'ASCII:Campo Formoso;ID:6320787', '8780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8780', '112', '10657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10658', '1079', '1', 'Canápolis', 'BR.05.2906105', 'ASCII:Canapolis;ID:6320788', '8781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8781', '112', '10658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10659', '1079', '1', 'Canarana', 'BR.05.2906204', 'ASCII:Canarana;ID:6320789', '8782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8782', '112', '10659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10660', '1079', '1', 'Canavieiras', 'BR.05.2906303', 'ASCII:Canavieiras;ID:6320790', '8783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8783', '112', '10660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10661', '1079', '1', 'Candeal', 'BR.05.2906402', 'ASCII:Candeal;ID:6320791', '8784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8784', '112', '10661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10662', '1079', '1', 'Candiba', 'BR.05.2906600', 'ASCII:Candiba;ID:6320792', '8785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8785', '112', '10662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10663', '1079', '1', 'Cândido Sales', 'BR.05.2906709', 'ASCII:Candido Sales;ID:6320793', '8786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8786', '112', '10663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10664', '1079', '1', 'Cansanção', 'BR.05.2906808', 'ASCII:Cansancao;ID:6320794', '8787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8787', '112', '10664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10665', '1079', '1', 'Canudos', 'BR.05.2906824', 'ASCII:Canudos;ID:6320795', '8788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8788', '112', '10665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10666', '1079', '1', 'Capela do Alto Alegre', 'BR.05.2906857', 'ASCII:Capela Do Alto Alegre;ID:6320796', '8789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8789', '112', '10666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10667', '1079', '1', 'Capim Grosso', 'BR.05.2906873', 'ASCII:Capim Grosso;ID:6320797', '8790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8790', '112', '10667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10668', '1079', '1', 'Caraíbas', 'BR.05.2906899', 'ASCII:Caraibas;ID:6320798', '8791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8791', '112', '10668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10669', '1079', '1', 'Caravelas', 'BR.05.2906907', 'ASCII:Caravelas;ID:6320799', '8792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8792', '112', '10669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2906907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10670', '1079', '1', 'Cardeal da Silva', 'BR.05.2907004', 'ASCII:Cardeal Da Silva;ID:6320800', '8793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8793', '112', '10670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10671', '1079', '1', 'Carinhanha', 'BR.05.2907103', 'ASCII:Carinhanha;ID:6320801', '8794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8794', '112', '10671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10672', '1079', '1', 'Casa Nova', 'BR.05.2907202', 'ASCII:Casa Nova;ID:6320802', '8795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8795', '112', '10672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10673', '1079', '1', 'Castro Alves', 'BR.05.2907301', 'ASCII:Castro Alves;ID:6320803', '8796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8796', '112', '10673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10674', '1079', '1', 'Catolândia', 'BR.05.2907400', 'ASCII:Catolandia;ID:6320804', '8797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8797', '112', '10674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10675', '1079', '1', 'Catu', 'BR.05.2907509', 'ASCII:Catu;ID:6320805', '8798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8798', '112', '10675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10676', '1079', '1', 'Caturama', 'BR.05.2907558', 'ASCII:Caturama;ID:6320806', '8799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8799', '112', '10676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10677', '1079', '1', 'Central', 'BR.05.2907608', 'ASCII:Central;ID:6320807', '8800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8800', '112', '10677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10678', '1079', '1', 'Cícero Dantas', 'BR.05.2907806', 'ASCII:Cicero Dantas;ID:6320808', '8801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8801', '112', '10678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10679', '1079', '1', 'Cipó', 'BR.05.2907905', 'ASCII:Cipo;ID:6320809', '8802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8802', '112', '10679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10680', '1079', '1', 'Coaraci', 'BR.05.2908002', 'ASCII:Coaraci;ID:6320810', '8803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8803', '112', '10680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2908002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10681', '1079', '1', 'Cocos', 'BR.05.2908101', 'ASCII:Cocos;ID:6320811', '8804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8804', '112', '10681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2908101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10682', '1079', '1', 'Conceição da Feira', 'BR.05.2908200', 'ASCII:Conceicao Da Feira;ID:6320812', '8805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8805', '112', '10682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2908200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10683', '1079', '1', 'Conceição do Almeida', 'BR.05.2908309', 'ASCII:Conceicao Do Almeida;ID:6320813', '8806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8806', '112', '10683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2908309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10684', '1079', '1', 'Conceição do Coité', 'BR.05.2908408', 'ASCII:Conceicao Do Coite;ID:6320814', '8807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8807', '112', '10684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2908408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10685', '1079', '1', 'Conceição do Jacuípe', 'BR.05.2908507', 'ASCII:Conceicao Do Jacuipe;ID:6320815', '8808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8808', '112', '10685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2908507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10686', '1079', '1', 'Conde', 'BR.05.2908606', 'ASCII:Conde;ID:6320816', '8809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8809', '112', '10686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2908606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10687', '1079', '1', 'Condeúba', 'BR.05.2908705', 'ASCII:Condeuba;ID:6320817', '8810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8810', '112', '10687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2908705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10688', '1079', '1', 'Contendas do Sincorá', 'BR.05.2908804', 'ASCII:Contendas Do Sincora;ID:6320818', '8811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8811', '112', '10688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2908804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10689', '1079', '1', 'Coração de Maria', 'BR.05.2908903', 'ASCII:Coracao De Maria;ID:6320819', '8812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8812', '112', '10689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2908903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10690', '1079', '1', 'Cordeiros', 'BR.05.2909000', 'ASCII:Cordeiros;ID:6320820', '8813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8813', '112', '10690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2909000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10691', '1079', '1', 'Coribe', 'BR.05.2909109', 'ASCII:Coribe;ID:6320821', '8814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8814', '112', '10691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2909109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10692', '1079', '1', 'Coronel João Sá', 'BR.05.2909208', 'ASCII:Coronel Joao Sa;ID:6320822', '8815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8815', '112', '10692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2909208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10693', '1079', '1', 'Correntina', 'BR.05.2909307', 'ASCII:Correntina;ID:6320823', '8816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8816', '112', '10693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2909307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10694', '1079', '1', 'Cotegipe', 'BR.05.2909406', 'ASCII:Cotegipe;ID:6320824', '8817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8817', '112', '10694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2909406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10695', '1079', '1', 'Cravolândia', 'BR.05.2909505', 'ASCII:Cravolandia;ID:6320825', '8818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8818', '112', '10695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2909505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10696', '1079', '1', 'Crisópolis', 'BR.05.2909604', 'ASCII:Crisopolis;ID:6320826', '8819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8819', '112', '10696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2909604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10697', '1079', '1', 'Cristópolis', 'BR.05.2909703', 'ASCII:Cristopolis;ID:6320827', '8820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8820', '112', '10697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2909703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10698', '1079', '1', 'Cruz das Almas', 'BR.05.2909802', 'ASCII:Cruz Das Almas;ID:6320828', '8821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8821', '112', '10698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2909802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10699', '1079', '1', 'Curaçá', 'BR.05.2909901', 'ASCII:Curaca;ID:6320829', '8822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8822', '112', '10699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2909901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10700', '1079', '1', 'Dário Meira', 'BR.05.2910008', 'ASCII:Dario Meira;ID:6320830', '8823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8823', '112', '10700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10701', '1079', '1', 'Dom Macedo Costa', 'BR.05.2910206', 'ASCII:Dom Macedo Costa;ID:6320831', '8824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8824', '112', '10701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10702', '1079', '1', 'Elísio Medrado', 'BR.05.2910305', 'ASCII:Elisio Medrado;ID:6320832', '8825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8825', '112', '10702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10703', '1079', '1', 'Encruzilhada', 'BR.05.2910404', 'ASCII:Encruzilhada;ID:6320833', '8826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8826', '112', '10703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10704', '1079', '1', 'Entre Rios', 'BR.05.2910503', 'ASCII:Entre Rios;ID:6320834', '8827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8827', '112', '10704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10705', '1079', '1', 'Esplanada', 'BR.05.2910602', 'ASCII:Esplanada;ID:6320835', '8828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8828', '112', '10705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10706', '1079', '1', 'Euclides da Cunha', 'BR.05.2910701', 'ASCII:Euclides Da Cunha;ID:6320836', '8829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8829', '112', '10706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10707', '1079', '1', 'Eunápolis', 'BR.05.2910727', 'ASCII:Eunapolis;ID:6320837', '8830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8830', '112', '10707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910727» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10708', '1079', '1', 'Fátima', 'BR.05.2910750', 'ASCII:Fatima;ID:6320838', '8831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8831', '112', '10708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10709', '1079', '1', 'Feira da Mata', 'BR.05.2910776', 'ASCII:Feira Da Mata;ID:6320839', '8832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8832', '112', '10709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910776» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10710', '1079', '1', 'Feira de Santana', 'BR.05.2910800', 'ASCII:Feira De Santana;ID:6320840', '8833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8833', '112', '10710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10711', '1079', '1', 'Filadélfia', 'BR.05.2910859', 'ASCII:Filadelfia;ID:6320841', '8834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8834', '112', '10711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10712', '1079', '1', 'Firmino Alves', 'BR.05.2910909', 'ASCII:Firmino Alves;ID:6320842', '8835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8835', '112', '10712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2910909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10713', '1079', '1', 'Floresta Azul', 'BR.05.2911006', 'ASCII:Floresta Azul;ID:6320843', '8836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8836', '112', '10713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10714', '1079', '1', 'Formosa do Rio Preto', 'BR.05.2911105', 'ASCII:Formosa Do Rio Preto;ID:6320844', '8837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8837', '112', '10714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10715', '1079', '1', 'Gandu', 'BR.05.2911204', 'ASCII:Gandu;ID:6320845', '8838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8838', '112', '10715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10716', '1079', '1', 'Gavião', 'BR.05.2911253', 'ASCII:Gaviao;ID:6320846', '8839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8839', '112', '10716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10717', '1079', '1', 'Gentio do Ouro', 'BR.05.2911303', 'ASCII:Gentio Do Ouro;ID:6320847', '8840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8840', '112', '10717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10718', '1079', '1', 'Gongogi', 'BR.05.2911501', 'ASCII:Gongogi;ID:6320848', '8841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8841', '112', '10718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10719', '1079', '1', 'Governador Mangabeira', 'BR.05.2911600', 'ASCII:Governador Mangabeira;ID:6320849', '8842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8842', '112', '10719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10720', '1079', '1', 'Guajeru', 'BR.05.2911659', 'ASCII:Guajeru;ID:6320850', '8843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8843', '112', '10720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10721', '1079', '1', 'Guanambi', 'BR.05.2911709', 'ASCII:Guanambi;ID:6320851', '8844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8844', '112', '10721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10722', '1079', '1', 'Guaratinga', 'BR.05.2911808', 'ASCII:Guaratinga;ID:6320852', '8845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8845', '112', '10722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10723', '1079', '1', 'Heliópolis', 'BR.05.2911857', 'ASCII:Heliopolis;ID:6320853', '8846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8846', '112', '10723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10724', '1079', '1', 'Ibiassucê', 'BR.05.2912004', 'ASCII:Ibiassuce;ID:6320854', '8847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8847', '112', '10724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2912004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10725', '1079', '1', 'Ibicaraí', 'BR.05.2912103', 'ASCII:Ibicarai;ID:6320855', '8848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8848', '112', '10725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2912103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10726', '1079', '1', 'Ibicoara', 'BR.05.2912202', 'ASCII:Ibicoara;ID:6320856', '8849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8849', '112', '10726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2912202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10727', '1079', '1', 'Ibicuí', 'BR.05.2912301', 'ASCII:Ibicui;ID:6320857', '8850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8850', '112', '10727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2912301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10728', '1079', '1', 'Ibipeba', 'BR.05.2912400', 'ASCII:Ibipeba;ID:6320858', '8851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8851', '112', '10728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2912400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10729', '1079', '1', 'Ibipitanga', 'BR.05.2912509', 'ASCII:Ibipitanga;ID:6320859', '8852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8852', '112', '10729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2912509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10730', '1079', '1', 'Ibiquera', 'BR.05.2912608', 'ASCII:Ibiquera;ID:6320860', '8853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8853', '112', '10730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2912608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10731', '1079', '1', 'Ibirapitanga', 'BR.05.2912707', 'ASCII:Ibirapitanga;ID:6320861', '8854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8854', '112', '10731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2912707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10732', '1079', '1', 'Ibirapuã', 'BR.05.2912806', 'ASCII:Ibirapua;ID:6320862', '8855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8855', '112', '10732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2912806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10733', '1079', '1', 'Ibirataia', 'BR.05.2912905', 'ASCII:Ibirataia;ID:6320863', '8856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8856', '112', '10733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2912905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10734', '1079', '1', 'Ibitiara', 'BR.05.2913002', 'ASCII:Ibitiara;ID:6320864', '8857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8857', '112', '10734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10735', '1079', '1', 'Ibititá', 'BR.05.2913101', 'ASCII:Ibitita;ID:6320865', '8858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8858', '112', '10735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10736', '1079', '1', 'Ibotirama', 'BR.05.2913200', 'ASCII:Ibotirama;ID:6320866', '8859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8859', '112', '10736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10737', '1079', '1', 'Ichu', 'BR.05.2913309', 'ASCII:Ichu;ID:6320867', '8860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8860', '112', '10737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10738', '1079', '1', 'Igaporã', 'BR.05.2913408', 'ASCII:Igapora;ID:6320868', '8861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8861', '112', '10738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10739', '1079', '1', 'Igrapiúna', 'BR.05.2913457', 'ASCII:Igrapiuna;ID:6320869', '8862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8862', '112', '10739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10740', '1079', '1', 'Iguaí', 'BR.05.2913507', 'ASCII:Iguai;ID:6320870', '8863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8863', '112', '10740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10741', '1079', '1', 'Ilhéus', 'BR.05.2913606', 'ASCII:Ilheus;ID:6320871', '8864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8864', '112', '10741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10742', '1079', '1', 'Inhambupe', 'BR.05.2913705', 'ASCII:Inhambupe;ID:6320872', '8865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8865', '112', '10742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10743', '1079', '1', 'Ipecaetá', 'BR.05.2913804', 'ASCII:Ipecaeta;ID:6320873', '8866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8866', '112', '10743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10744', '1079', '1', 'Ipiaú', 'BR.05.2913903', 'ASCII:Ipiau;ID:6320874', '8867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8867', '112', '10744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2913903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10745', '1079', '1', 'Ipirá', 'BR.05.2914000', 'ASCII:Ipira;ID:6320875', '8868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8868', '112', '10745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10746', '1079', '1', 'Ipupiara', 'BR.05.2914109', 'ASCII:Ipupiara;ID:6320876', '8869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8869', '112', '10746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10747', '1079', '1', 'Irajuba', 'BR.05.2914208', 'ASCII:Irajuba;ID:6320877', '8870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8870', '112', '10747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10748', '1079', '1', 'Iramaia', 'BR.05.2914307', 'ASCII:Iramaia;ID:6320878', '8871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8871', '112', '10748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10749', '1079', '1', 'Iraquara', 'BR.05.2914406', 'ASCII:Iraquara;ID:6320879', '8872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8872', '112', '10749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10750', '1079', '1', 'Irará', 'BR.05.2914505', 'ASCII:Irara;ID:6320880', '8873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8873', '112', '10750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10751', '1079', '1', 'Irecê', 'BR.05.2914604', 'ASCII:Irece;ID:6320881', '8874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8874', '112', '10751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10752', '1079', '1', 'Itabela', 'BR.05.2914653', 'ASCII:Itabela;ID:6320882', '8875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8875', '112', '10752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10753', '1079', '1', 'Itaberaba', 'BR.05.2914703', 'ASCII:Itaberaba;ID:6320883', '8876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8876', '112', '10753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10754', '1079', '1', 'Itabuna', 'BR.05.2914802', 'ASCII:Itabuna;ID:6320884', '8877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8877', '112', '10754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10755', '1079', '1', 'Itacaré', 'BR.05.2914901', 'ASCII:Itacare;ID:6320885', '8878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8878', '112', '10755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2914901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10756', '1079', '1', 'Itaeté', 'BR.05.2915007', 'ASCII:Itaete;ID:6320886', '8879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8879', '112', '10756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10757', '1079', '1', 'Itagi', 'BR.05.2915106', 'ASCII:Itagi;ID:6320887', '8880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8880', '112', '10757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10758', '1079', '1', 'Itagibá', 'BR.05.2915205', 'ASCII:Itagiba;ID:6320888', '8881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8881', '112', '10758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10759', '1079', '1', 'Itagimirim', 'BR.05.2915304', 'ASCII:Itagimirim;ID:6320889', '8882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8882', '112', '10759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10760', '1079', '1', 'Itaguaçu da Bahia', 'BR.05.2915353', 'ASCII:Itaguacu Da Bahia;ID:6320890', '8883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8883', '112', '10760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10761', '1079', '1', 'Itaju do Colônia', 'BR.05.2915403', 'ASCII:Itaju Do Colonia;ID:6320891', '8884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8884', '112', '10761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10762', '1079', '1', 'Itajuípe', 'BR.05.2915502', 'ASCII:Itajuipe;ID:6320892', '8885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8885', '112', '10762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10763', '1079', '1', 'Itamaraju', 'BR.05.2915601', 'ASCII:Itamaraju;ID:6320893', '8886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8886', '112', '10763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10764', '1079', '1', 'Itamari', 'BR.05.2915700', 'ASCII:Itamari;ID:6320894', '8887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8887', '112', '10764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10765', '1079', '1', 'Itambé', 'BR.05.2915809', 'ASCII:Itambe;ID:6320895', '8888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8888', '112', '10765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10766', '1079', '1', 'Itanagra', 'BR.05.2915908', 'ASCII:Itanagra;ID:6320896', '8889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8889', '112', '10766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2915908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10767', '1079', '1', 'Itanhém', 'BR.05.2916005', 'ASCII:Itanhem;ID:6320897', '8890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8890', '112', '10767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10768', '1079', '1', 'Itaparica', 'BR.05.2916104', 'ASCII:Itaparica;ID:6320898', '8891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8891', '112', '10768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10769', '1079', '1', 'Itapé', 'BR.05.2916203', 'ASCII:Itape;ID:6320899', '8892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8892', '112', '10769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10770', '1079', '1', 'Itapebi', 'BR.05.2916302', 'ASCII:Itapebi;ID:6320900', '8893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8893', '112', '10770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10771', '1079', '1', 'Itapetinga', 'BR.05.2916401', 'ASCII:Itapetinga;ID:6320901', '8894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8894', '112', '10771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10772', '1079', '1', 'Itapitanga', 'BR.05.2916609', 'ASCII:Itapitanga;ID:6320902', '8895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8895', '112', '10772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10773', '1079', '1', 'Itaquara', 'BR.05.2916708', 'ASCII:Itaquara;ID:6320903', '8896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8896', '112', '10773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10774', '1079', '1', 'Itarantim', 'BR.05.2916807', 'ASCII:Itarantim;ID:6320904', '8897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8897', '112', '10774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10775', '1079', '1', 'Itatim', 'BR.05.2916856', 'ASCII:Itatim;ID:6320905', '8898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8898', '112', '10775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10776', '1079', '1', 'Itiruçu', 'BR.05.2916906', 'ASCII:Itirucu;ID:6320906', '8899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8899', '112', '10776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10777', '1079', '1', 'Itiúba', 'BR.05.2917003', 'ASCII:Itiuba;ID:6320907', '8900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8900', '112', '10777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10778', '1079', '1', 'Itororó', 'BR.05.2917102', 'ASCII:Itororo;ID:6320908', '8901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8901', '112', '10778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10779', '1079', '1', 'Ituaçu', 'BR.05.2917201', 'ASCII:Ituacu;ID:6320909', '8902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8902', '112', '10779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10780', '1079', '1', 'Iuiú', 'BR.05.2917334', 'ASCII:Iuiu;ID:6320910', '8903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8903', '112', '10780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10781', '1079', '1', 'Jaborandi', 'BR.05.2917359', 'ASCII:Jaborandi;ID:6320911', '8904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8904', '112', '10781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10782', '1079', '1', 'Jacaraci', 'BR.05.2917409', 'ASCII:Jacaraci;ID:6320912', '8905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8905', '112', '10782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10783', '1079', '1', 'Jacobina', 'BR.05.2917508', 'ASCII:Jacobina;ID:6320913', '8906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8906', '112', '10783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10784', '1079', '1', 'Jaguaquara', 'BR.05.2917607', 'ASCII:Jaguaquara;ID:6320914', '8907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8907', '112', '10784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10785', '1079', '1', 'Jaguarari', 'BR.05.2917706', 'ASCII:Jaguarari;ID:6320915', '8908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8908', '112', '10785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10786', '1079', '1', 'Jaguaripe', 'BR.05.2917805', 'ASCII:Jaguaripe;ID:6320916', '8909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8909', '112', '10786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10787', '1079', '1', 'Jandaíra', 'BR.05.2917904', 'ASCII:Jandaira;ID:6320917', '8910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8910', '112', '10787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2917904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10788', '1079', '1', 'Jequié', 'BR.05.2918001', 'ASCII:Jequie;ID:6320918', '8911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8911', '112', '10788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10789', '1079', '1', 'Jeremoabo', 'BR.05.2918100', 'ASCII:Jeremoabo;ID:6320919', '8912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8912', '112', '10789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10790', '1079', '1', 'Jiquiriçá', 'BR.05.2918209', 'ASCII:Jiquirica;ID:6320920', '8913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8913', '112', '10790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10791', '1079', '1', 'Jitaúna', 'BR.05.2918308', 'ASCII:Jitauna;ID:6320921', '8914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8914', '112', '10791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10792', '1079', '1', 'João Dourado', 'BR.05.2918357', 'ASCII:Joao Dourado;ID:6320922', '8915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8915', '112', '10792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10793', '1079', '1', 'Juazeiro', 'BR.05.2918407', 'ASCII:Juazeiro;ID:6320923', '8916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8916', '112', '10793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10794', '1079', '1', 'Jucuruçu', 'BR.05.2918456', 'ASCII:Jucurucu;ID:6320924', '8917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8917', '112', '10794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10795', '1079', '1', 'Jussara', 'BR.05.2918506', 'ASCII:Jussara;ID:6320925', '8918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8918', '112', '10795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10796', '1079', '1', 'Jussari', 'BR.05.2918555', 'ASCII:Jussari;ID:6320926', '8919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8919', '112', '10796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10797', '1079', '1', 'Jussiape', 'BR.05.2918605', 'ASCII:Jussiape;ID:6320927', '8920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8920', '112', '10797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10798', '1079', '1', 'Lafaiete Coutinho', 'BR.05.2918704', 'ASCII:Lafaiete Coutinho;ID:6320928', '8921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8921', '112', '10798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10799', '1079', '1', 'Laje', 'BR.05.2918803', 'ASCII:Laje;ID:6320929', '8922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8922', '112', '10799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10800', '1079', '1', 'Lajedão', 'BR.05.2918902', 'ASCII:Lajedao;ID:6320930', '8923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8923', '112', '10800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2918902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10801', '1079', '1', 'Lajedinho', 'BR.05.2919009', 'ASCII:Lajedinho;ID:6320931', '8924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8924', '112', '10801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10802', '1079', '1', 'Lajedo do Tabocal', 'BR.05.2919058', 'ASCII:Lajedo Do Tabocal;ID:6320932', '8925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8925', '112', '10802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10803', '1079', '1', 'Lamarão', 'BR.05.2919108', 'ASCII:Lamarao;ID:6320933', '8926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8926', '112', '10803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10804', '1079', '1', 'Lapão', 'BR.05.2919157', 'ASCII:Lapao;ID:6320934', '8927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8927', '112', '10804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10805', '1079', '1', 'Lauro de Freitas', 'BR.05.2919207', 'ASCII:Lauro De Freitas;ID:6320935', '8928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8928', '112', '10805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10806', '1079', '1', 'Lençóis', 'BR.05.2919306', 'ASCII:Lencois;ID:6320936', '8929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8929', '112', '10806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10807', '1079', '1', 'Licínio de Almeida', 'BR.05.2919405', 'ASCII:Licinio De Almeida;ID:6320937', '8930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8930', '112', '10807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10808', '1079', '1', 'Livramento de Nossa Senhora', 'BR.05.2919504', 'ASCII:Livramento Do Brumado;ID:6320938', '8931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8931', '112', '10808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10809', '1079', '1', 'Macajuba', 'BR.05.2919603', 'ASCII:Macajuba;ID:6320939', '8932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8932', '112', '10809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10810', '1079', '1', 'Macarani', 'BR.05.2919702', 'ASCII:Macarani;ID:6320940', '8933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8933', '112', '10810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10811', '1079', '1', 'Macaúbas', 'BR.05.2919801', 'ASCII:Macaubas;ID:6320941', '8934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8934', '112', '10811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10812', '1079', '1', 'Madre de Deus', 'BR.05.2919926', 'ASCII:Madre De Deus;ID:6320942', '8935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8935', '112', '10812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10813', '1079', '1', 'Maetinga', 'BR.05.2919959', 'ASCII:Maetinga;ID:6320943', '8936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8936', '112', '10813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10814', '1079', '1', 'Maiquinique', 'BR.05.2920007', 'ASCII:Maiquinique;ID:6320944', '8937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8937', '112', '10814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10815', '1079', '1', 'Mairi', 'BR.05.2920106', 'ASCII:Mairi;ID:6320945', '8938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8938', '112', '10815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10816', '1079', '1', 'Malhada', 'BR.05.2920205', 'ASCII:Malhada;ID:6320946', '8939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8939', '112', '10816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10817', '1079', '1', 'Malhada de Pedras', 'BR.05.2920304', 'ASCII:Malhada De Pedras;ID:6320947', '8940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8940', '112', '10817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10818', '1079', '1', 'Manoel Vitorino', 'BR.05.2920403', 'ASCII:Manoel Vitorino;ID:6320948', '8941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8941', '112', '10818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10819', '1079', '1', 'Mansidão', 'BR.05.2920452', 'ASCII:Mansidao;ID:6320949', '8942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8942', '112', '10819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10820', '1079', '1', 'Maracás', 'BR.05.2920502', 'ASCII:Maracas;ID:6320950', '8943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8943', '112', '10820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10821', '1079', '1', 'Maragogipe', 'BR.05.2920601', 'ASCII:Maragogipe;ID:6320951', '8944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8944', '112', '10821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10822', '1079', '1', 'Maraú', 'BR.05.2920700', 'ASCII:Marau;ID:6320952', '8945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8945', '112', '10822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10823', '1079', '1', 'Marcionílio Souza', 'BR.05.2920809', 'ASCII:Marcionilio Souza;ID:6320953', '8946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8946', '112', '10823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10824', '1079', '1', 'Mascote', 'BR.05.2920908', 'ASCII:Mascote;ID:6320954', '8947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8947', '112', '10824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2920908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10825', '1079', '1', 'Mata de São João', 'BR.05.2921005', 'ASCII:Mata De Sao Joao;ID:6320955', '8948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8948', '112', '10825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10826', '1079', '1', 'Matina', 'BR.05.2921054', 'ASCII:Matina;ID:6320956', '8949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8949', '112', '10826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10827', '1079', '1', 'Medeiros Neto', 'BR.05.2921104', 'ASCII:Medeiros Neto;ID:6320957', '8950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8950', '112', '10827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10828', '1079', '1', 'Miguel Calmon', 'BR.05.2921203', 'ASCII:Miguel Calmon;ID:6320958', '8951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8951', '112', '10828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10829', '1079', '1', 'Mirangaba', 'BR.05.2921401', 'ASCII:Mirangaba;ID:6320959', '8952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8952', '112', '10829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10830', '1079', '1', 'Mirante', 'BR.05.2921450', 'ASCII:Mirante;ID:6320960', '8953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8953', '112', '10830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10831', '1079', '1', 'Monte Santo', 'BR.05.2921500', 'ASCII:Monte Santo;ID:6320961', '8954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8954', '112', '10831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10832', '1079', '1', 'Morpará', 'BR.05.2921609', 'ASCII:Morpara;ID:6320962', '8955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8955', '112', '10832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10833', '1079', '1', 'Morro do Chapéu', 'BR.05.2921708', 'ASCII:Morro Do Chapeu;ID:6320963', '8956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8956', '112', '10833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10834', '1079', '1', 'Mortugaba', 'BR.05.2921807', 'ASCII:Mortugaba;ID:6320964', '8957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8957', '112', '10834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10835', '1079', '1', 'Mucugê', 'BR.05.2921906', 'ASCII:Mucuge;ID:6320965', '8958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8958', '112', '10835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10836', '1079', '1', 'Mucuri', 'BR.05.2922003', 'ASCII:Mucuri;ID:6320966', '8959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8959', '112', '10836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10837', '1079', '1', 'Mulungu do Morro', 'BR.05.2922052', 'ASCII:Mulungu Do Morro;ID:6320967', '8960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8960', '112', '10837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10838', '1079', '1', 'Mundo Novo', 'BR.05.2922102', 'ASCII:Mundo Novo;ID:6320968', '8961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8961', '112', '10838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10839', '1079', '1', 'Muniz Ferreira', 'BR.05.2922201', 'ASCII:Muniz Ferreira;ID:6320969', '8962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8962', '112', '10839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10840', '1079', '1', 'Muritiba', 'BR.05.2922300', 'ASCII:Muritiba;ID:6320970', '8963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8963', '112', '10840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10841', '1079', '1', 'Mutuípe', 'BR.05.2922409', 'ASCII:Mutuipe;ID:6320971', '8964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8964', '112', '10841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10842', '1079', '1', 'Nazaré', 'BR.05.2922508', 'ASCII:Nazare;ID:6320972', '8965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8965', '112', '10842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10843', '1079', '1', 'Nova Canaã', 'BR.05.2922706', 'ASCII:Nova Canaa;ID:6320973', '8966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8966', '112', '10843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10844', '1079', '1', 'Nova Fátima', 'BR.05.2922730', 'ASCII:Nova Fatima;ID:6320974', '8967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8967', '112', '10844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10845', '1079', '1', 'Nova Ibiá', 'BR.05.2922755', 'ASCII:Nova Ibia;ID:6320975', '8968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8968', '112', '10845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10846', '1079', '1', 'Nova Itarana', 'BR.05.2922805', 'ASCII:Nova Itarana;ID:6320976', '8969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8969', '112', '10846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10847', '1079', '1', 'Nova Redenção', 'BR.05.2922854', 'ASCII:Nova Redencao;ID:6320977', '8970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8970', '112', '10847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10848', '1079', '1', 'Nova Soure', 'BR.05.2922904', 'ASCII:Nova Soure;ID:6320978', '8971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8971', '112', '10848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2922904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10849', '1079', '1', 'Novo Horizonte', 'BR.05.2923035', 'ASCII:Novo Horizonte;ID:6320979', '8972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8972', '112', '10849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10850', '1079', '1', 'Novo Triunfo', 'BR.05.2923050', 'ASCII:Novo Triunfo;ID:6320980', '8973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8973', '112', '10850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10851', '1079', '1', 'Olindina', 'BR.05.2923100', 'ASCII:Olindina;ID:6320981', '8974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8974', '112', '10851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10852', '1079', '1', 'Ouriçangas', 'BR.05.2923308', 'ASCII:Ouricangas;ID:6320982', '8975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8975', '112', '10852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10853', '1079', '1', 'Ourolândia', 'BR.05.2923357', 'ASCII:Ourolandia;ID:6320983', '8976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8976', '112', '10853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10854', '1079', '1', 'Palmas de Monte Alto', 'BR.05.2923407', 'ASCII:Palmas De Monte Alto;ID:6320984', '8977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8977', '112', '10854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10855', '1079', '1', 'Palmeiras', 'BR.05.2923506', 'ASCII:Palmeiras;ID:6320985', '8978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8978', '112', '10855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10856', '1079', '1', 'Paramirim', 'BR.05.2923605', 'ASCII:Paramirim;ID:6320986', '8979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8979', '112', '10856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10857', '1079', '1', 'Paratinga', 'BR.05.2923704', 'ASCII:Paratinga;ID:6320987', '8980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8980', '112', '10857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10858', '1079', '1', 'Paripiranga', 'BR.05.2923803', 'ASCII:Paripiranga;ID:6320988', '8981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8981', '112', '10858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10859', '1079', '1', 'Pau Brasil', 'BR.05.2923902', 'ASCII:Pau Brasil;ID:6320989', '8982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8982', '112', '10859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2923902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10860', '1079', '1', 'Pé de Serra', 'BR.05.2924058', 'ASCII:Pe De Serra;ID:6320990', '8983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8983', '112', '10860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10861', '1079', '1', 'Pedrão', 'BR.05.2924108', 'ASCII:Pedrao;ID:6320991', '8984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8984', '112', '10861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10862', '1079', '1', 'Pedro Alexandre', 'BR.05.2924207', 'ASCII:Pedro Alexandre;ID:6320992', '8985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8985', '112', '10862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10863', '1079', '1', 'Piatã', 'BR.05.2924306', 'ASCII:Piata;ID:6320993', '8986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8986', '112', '10863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10864', '1079', '1', 'Pilão Arcado', 'BR.05.2924405', 'ASCII:Pilao Arcado;ID:6320994', '8987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8987', '112', '10864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10865', '1079', '1', 'Pindaí', 'BR.05.2924504', 'ASCII:Pindai;ID:6320995', '8988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8988', '112', '10865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10866', '1079', '1', 'Pindobaçu', 'BR.05.2924603', 'ASCII:Pindobacu;ID:6320996', '8989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8989', '112', '10866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10867', '1079', '1', 'Pintadas', 'BR.05.2924652', 'ASCII:Pintadas;ID:6320997', '8990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8990', '112', '10867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10868', '1079', '1', 'Piraí do Norte', 'BR.05.2924678', 'ASCII:Pirai Do Norte;ID:6320998', '8991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8991', '112', '10868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10869', '1079', '1', 'Piripá', 'BR.05.2924702', 'ASCII:Piripa;ID:6320999', '8992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8992', '112', '10869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10870', '1079', '1', 'Piritiba', 'BR.05.2924801', 'ASCII:Piritiba;ID:6321000', '8993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8993', '112', '10870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10871', '1079', '1', 'Planaltino', 'BR.05.2924900', 'ASCII:Planaltino;ID:6321001', '8994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8994', '112', '10871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10872', '1079', '1', 'Planalto', 'BR.05.2925006', 'ASCII:Planalto;ID:6321002', '8995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8995', '112', '10872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10873', '1079', '1', 'Pojuca', 'BR.05.2925204', 'ASCII:Pojuca;ID:6321003', '8996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8996', '112', '10873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10874', '1079', '1', 'Ponto Novo', 'BR.05.2925253', 'ASCII:Ponto Novo;ID:6321004', '8997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8997', '112', '10874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10875', '1079', '1', 'Porto Seguro', 'BR.05.2925303', 'ASCII:Porto Seguro;ID:6321005', '8998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8998', '112', '10875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10876', '1079', '1', 'Potiraguá', 'BR.05.2925402', 'ASCII:Potiragua;ID:6321006', '8999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('8999', '112', '10876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10877', '1079', '1', 'Presidente Dutra', 'BR.05.2925600', 'ASCII:Presidente Dutra;ID:6321007', '9000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9000', '112', '10877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10878', '1079', '1', 'Presidente Jânio Quadros', 'BR.05.2925709', 'ASCII:Presidente Janio Quadros;ID:6321008', '9001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9001', '112', '10878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10879', '1079', '1', 'Queimadas', 'BR.05.2925808', 'ASCII:Queimadas;ID:6321009', '9002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9002', '112', '10879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10880', '1079', '1', 'Quijingue', 'BR.05.2925907', 'ASCII:Quijingue;ID:6321010', '9003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9003', '112', '10880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10881', '1079', '1', 'Quixabeira', 'BR.05.2925931', 'ASCII:Quixabeira;ID:6321011', '9004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9004', '112', '10881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925931» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10882', '1079', '1', 'Rafael Jambeiro', 'BR.05.2925956', 'ASCII:Rafael Jambeiro;ID:6321012', '9005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9005', '112', '10882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10883', '1079', '1', 'Remanso', 'BR.05.2926004', 'ASCII:Remanso;ID:6321013', '9006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9006', '112', '10883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10884', '1079', '1', 'Retirolândia', 'BR.05.2926103', 'ASCII:Retirolandia;ID:6321014', '9007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9007', '112', '10884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10885', '1079', '1', 'Riachão das Neves', 'BR.05.2926202', 'ASCII:Riachao Das Neves;ID:6321015', '9008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9008', '112', '10885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10886', '1079', '1', 'Riachão do Jacuípe', 'BR.05.2926301', 'ASCII:Riachao Do Jacuipe;ID:6321016', '9009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9009', '112', '10886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10887', '1079', '1', 'Riacho de Santana', 'BR.05.2926400', 'ASCII:Riacho De Santana;ID:6321017', '9010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9010', '112', '10887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10888', '1079', '1', 'Ribeira do Amparo', 'BR.05.2926509', 'ASCII:Ribeira Do Amparo;ID:6321018', '9011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9011', '112', '10888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10889', '1079', '1', 'Ribeira do Pombal', 'BR.05.2926608', 'ASCII:Ribeira Do Pombal;ID:6321019', '9012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9012', '112', '10889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10890', '1079', '1', 'Ribeirão do Largo', 'BR.05.2926657', 'ASCII:Ribeirao Do Largo;ID:6321020', '9013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9013', '112', '10890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10891', '1079', '1', 'Rio de Contas', 'BR.05.2926707', 'ASCII:Rio De Contas;ID:6321021', '9014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9014', '112', '10891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10892', '1079', '1', 'Rio do Antônio', 'BR.05.2926806', 'ASCII:Rio Do Antonio;ID:6321022', '9015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9015', '112', '10892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10893', '1079', '1', 'Rio do Pires', 'BR.05.2926905', 'ASCII:Rio Do Pires;ID:6321023', '9016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9016', '112', '10893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2926905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10894', '1079', '1', 'Ruy Barbosa', 'BR.05.2927200', 'ASCII:Ruy Barbosa;ID:6321024', '9017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9017', '112', '10894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2927200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10895', '1079', '1', 'Salinas da Margarida', 'BR.05.2927309', 'ASCII:Salinas Da Margarida;ID:6321025', '9018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9018', '112', '10895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2927309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10896', '1079', '1', 'Salvador', 'BR.05.2927408', 'ASCII:Salvador;ID:6321026', '9019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9019', '112', '10896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2927408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10897', '1079', '1', 'Santa Bárbara', 'BR.05.2927507', 'ASCII:Santa Barbara;ID:6321027', '9020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9020', '112', '10897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2927507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10898', '1079', '1', 'Santa Brígida', 'BR.05.2927606', 'ASCII:Santa Brigida;ID:6321028', '9021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9021', '112', '10898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2927606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10899', '1079', '1', 'Santa Cruz Cabrália', 'BR.05.2927705', 'ASCII:Santa Cruz Cabralia;ID:6321029', '9022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9022', '112', '10899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2927705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10900', '1079', '1', 'Santa Cruz da Vitória', 'BR.05.2927804', 'ASCII:Santa Cruz Da Vitoria;ID:6321030', '9023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9023', '112', '10900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2927804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10901', '1079', '1', 'Santa Inês', 'BR.05.2927903', 'ASCII:Santa Ines;ID:6321031', '9024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9024', '112', '10901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2927903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10902', '1079', '1', 'Santaluz', 'BR.05.2928000', 'ASCII:Santaluz;ID:6321032', '9025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9025', '112', '10902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10903', '1079', '1', 'Santa Luzia', 'BR.05.2928059', 'ASCII:Santa Luzia;ID:6321033', '9026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9026', '112', '10903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10904', '1079', '1', 'Santanópolis', 'BR.05.2928307', 'ASCII:Santanopolis;ID:6321034', '9027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9027', '112', '10904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10905', '1079', '1', 'Santa Rita de Cássia', 'BR.05.2928406', 'ASCII:Santa Rita De Cassia;ID:6321035', '9028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9028', '112', '10905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10906', '1079', '1', 'Santa Teresinha', 'BR.05.2928505', 'ASCII:Santa Teresinha;ID:6321036', '9029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9029', '112', '10906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10907', '1079', '1', 'Santo Amaro', 'BR.05.2928604', 'ASCII:Santo Amaro;ID:6321037', '9030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9030', '112', '10907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10908', '1079', '1', 'Santo Antônio de Jesus', 'BR.05.2928703', 'ASCII:Santo Antonio De Jesus;ID:6321038', '9031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9031', '112', '10908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10909', '1079', '1', 'Santo Estêvão', 'BR.05.2928802', 'ASCII:Santo Estevao;ID:6321039', '9032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9032', '112', '10909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10910', '1079', '1', 'São Desidério', 'BR.05.2928901', 'ASCII:Sao Desiderio;ID:6321040', '9033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9033', '112', '10910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10911', '1079', '1', 'São Domingos', 'BR.05.2928950', 'ASCII:Sao Domingos;ID:6321041', '9034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9034', '112', '10911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2928950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10912', '1079', '1', 'São Félix', 'BR.05.2929008', 'ASCII:Sao Felix;ID:6321042', '9035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9035', '112', '10912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10913', '1079', '1', 'São Félix do Coribe', 'BR.05.2929057', 'ASCII:Sao Felix Do Coribe;ID:6321043', '9036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9036', '112', '10913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10914', '1079', '1', 'São Felipe', 'BR.05.2929107', 'ASCII:Sao Felipe;ID:6321044', '9037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9037', '112', '10914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10915', '1079', '1', 'São Francisco do Conde', 'BR.05.2929206', 'ASCII:Sao Francisco Do Conde;ID:6321045', '9038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9038', '112', '10915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10916', '1079', '1', 'São Gabriel', 'BR.05.2929255', 'ASCII:Sao Gabriel;ID:6321046', '9039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9039', '112', '10916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10917', '1079', '1', 'São Gonçalo dos Campos', 'BR.05.2929305', 'ASCII:Sao Goncalo Dos Campos;ID:6321047', '9040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9040', '112', '10917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10918', '1079', '1', 'São José da Vitória', 'BR.05.2929354', 'ASCII:Sao Jose Da Vitoria;ID:6321048', '9041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9041', '112', '10918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10919', '1079', '1', 'São José do Jacuípe', 'BR.05.2929370', 'ASCII:Sao Jose Do Jacuipe;ID:6321049', '9042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9042', '112', '10919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10920', '1079', '1', 'São Miguel das Matas', 'BR.05.2929404', 'ASCII:Sao Miguel Das Matas;ID:6321050', '9043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9043', '112', '10920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10921', '1079', '1', 'São Sebastião do Passé', 'BR.05.2929503', 'ASCII:Sao Sebastiao Do Passe;ID:6321051', '9044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9044', '112', '10921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10922', '1079', '1', 'Sapeaçu', 'BR.05.2929602', 'ASCII:Sapeacu;ID:6321052', '9045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9045', '112', '10922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10923', '1079', '1', 'Sátiro Dias', 'BR.05.2929701', 'ASCII:Satiro Dias;ID:6321053', '9046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9046', '112', '10923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10924', '1079', '1', 'Saubara', 'BR.05.2929750', 'ASCII:Saubara;ID:6321054', '9047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9047', '112', '10924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10925', '1079', '1', 'Saúde', 'BR.05.2929800', 'ASCII:Saude;ID:6321055', '9048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9048', '112', '10925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10926', '1079', '1', 'Seabra', 'BR.05.2929909', 'ASCII:Seabra;ID:6321056', '9049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9049', '112', '10926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2929909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10927', '1079', '1', 'Sebastião Laranjeiras', 'BR.05.2930006', 'ASCII:Sebastiao Laranjeiras;ID:6321057', '9050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9050', '112', '10927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10928', '1079', '1', 'Senhor do Bonfim', 'BR.05.2930105', 'ASCII:Senhor Do Bonfim;ID:6321058', '9051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9051', '112', '10928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10929', '1079', '1', 'Serra do Ramalho', 'BR.05.2930154', 'ASCII:Serra Do Ramalho;ID:6321059', '9052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9052', '112', '10929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10930', '1079', '1', 'Sento Sé', 'BR.05.2930204', 'ASCII:Sento Se;ID:6321060', '9053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9053', '112', '10930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10931', '1079', '1', 'Serra Dourada', 'BR.05.2930303', 'ASCII:Serra Dourada;ID:6321061', '9054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9054', '112', '10931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10932', '1079', '1', 'Serra Preta', 'BR.05.2930402', 'ASCII:Serra Preta;ID:6321062', '9055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9055', '112', '10932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10933', '1079', '1', 'Serrolândia', 'BR.05.2930600', 'ASCII:Serrolandia;ID:6321063', '9056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9056', '112', '10933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10934', '1079', '1', 'Simões Filho', 'BR.05.2930709', 'ASCII:Simoes Filho;ID:6321064', '9057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9057', '112', '10934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10935', '1079', '1', 'Sítio do Mato', 'BR.05.2930758', 'ASCII:Sitio Do Mato;ID:6321065', '9058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9058', '112', '10935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10936', '1079', '1', 'Sítio do Quinto', 'BR.05.2930766', 'ASCII:Sitio Do Quinto;ID:6321066', '9059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9059', '112', '10936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10937', '1079', '1', 'Sobradinho', 'BR.05.2930774', 'ASCII:Sobradinho;ID:6321067', '9060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9060', '112', '10937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10938', '1079', '1', 'Tabocas do Brejo Velho', 'BR.05.2930907', 'ASCII:Tabocas Do Brejo Velho;ID:6321068', '9061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9061', '112', '10938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10939', '1079', '1', 'Tanhaçu', 'BR.05.2931004', 'ASCII:Tanhacu;ID:6321069', '9062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9062', '112', '10939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10940', '1079', '1', 'Tanque Novo', 'BR.05.2931053', 'ASCII:Tanque Novo;ID:6321070', '9063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9063', '112', '10940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10941', '1079', '1', 'Tanquinho', 'BR.05.2931103', 'ASCII:Tanquinho;ID:6321071', '9064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9064', '112', '10941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10942', '1079', '1', 'Taperoá', 'BR.05.2931202', 'ASCII:Taperoa;ID:6321072', '9065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9065', '112', '10942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10943', '1079', '1', 'Tapiramutá', 'BR.05.2931301', 'ASCII:Tapiramuta;ID:6321073', '9066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9066', '112', '10943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10944', '1079', '1', 'Teixeira de Freitas', 'BR.05.2931350', 'ASCII:Teixeira De Freitas;ID:6321074', '9067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9067', '112', '10944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10945', '1079', '1', 'Teodoro Sampaio', 'BR.05.2931400', 'ASCII:Teodoro Sampaio;ID:6321075', '9068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9068', '112', '10945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10946', '1079', '1', 'Teofilândia', 'BR.05.2931509', 'ASCII:Teofilandia;ID:6321076', '9069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9069', '112', '10946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10947', '1079', '1', 'Teolândia', 'BR.05.2931608', 'ASCII:Teolandia;ID:6321077', '9070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9070', '112', '10947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10948', '1079', '1', 'Terra Nova', 'BR.05.2931707', 'ASCII:Terra Nova;ID:6321078', '9071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9071', '112', '10948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10949', '1079', '1', 'Tucano', 'BR.05.2931905', 'ASCII:Tucano;ID:6321079', '9072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9072', '112', '10949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2931905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10950', '1079', '1', 'Uauá', 'BR.05.2932002', 'ASCII:Uaua;ID:6321080', '9073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9073', '112', '10950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10951', '1079', '1', 'Ubaíra', 'BR.05.2932101', 'ASCII:Ubaira;ID:6321081', '9074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9074', '112', '10951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10952', '1079', '1', 'Ubaitaba', 'BR.05.2932200', 'ASCII:Ubaitaba;ID:6321082', '9075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9075', '112', '10952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10953', '1079', '1', 'Ubatã', 'BR.05.2932309', 'ASCII:Ubata;ID:6321083', '9076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9076', '112', '10953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10954', '1079', '1', 'Uibaí', 'BR.05.2932408', 'ASCII:Uibai;ID:6321084', '9077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9077', '112', '10954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10955', '1079', '1', 'Urandi', 'BR.05.2932606', 'ASCII:Urandi;ID:6321085', '9078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9078', '112', '10955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10956', '1079', '1', 'Uruçuca', 'BR.05.2932705', 'ASCII:Urucuca;ID:6321086', '9079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9079', '112', '10956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10957', '1079', '1', 'Utinga', 'BR.05.2932804', 'ASCII:Utinga;ID:6321087', '9080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9080', '112', '10957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10958', '1079', '1', 'Valença', 'BR.05.2932903', 'ASCII:Valenca;ID:6321088', '9081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9081', '112', '10958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2932903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10959', '1079', '1', 'Valente', 'BR.05.2933000', 'ASCII:Valente;ID:6321089', '9082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9082', '112', '10959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10960', '1079', '1', 'Várzea da Roça', 'BR.05.2933059', 'ASCII:Varzea Da Roca;ID:6321090', '9083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9083', '112', '10960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10961', '1079', '1', 'Várzea do Poço', 'BR.05.2933109', 'ASCII:Varzea Do Poco;ID:6321091', '9084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9084', '112', '10961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10962', '1079', '1', 'Várzea Nova', 'BR.05.2933158', 'ASCII:Varzea Nova;ID:6321092', '9085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9085', '112', '10962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10963', '1079', '1', 'Varzedo', 'BR.05.2933174', 'ASCII:Varzedo;ID:6321093', '9086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9086', '112', '10963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10964', '1079', '1', 'Vera Cruz', 'BR.05.2933208', 'ASCII:Vera Cruz;ID:6321094', '9087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9087', '112', '10964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10965', '1079', '1', 'Vereda', 'BR.05.2933257', 'ASCII:Vereda;ID:6321095', '9088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9088', '112', '10965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10966', '1079', '1', 'Vitória da Conquista', 'BR.05.2933307', 'ASCII:Vitoria Da Conquista;ID:6321096', '9089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9089', '112', '10966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10967', '1079', '1', 'Wagner', 'BR.05.2933406', 'ASCII:Wagner;ID:6321097', '9090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9090', '112', '10967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10968', '1079', '1', 'Wanderley', 'BR.05.2933455', 'ASCII:Wanderley;ID:6321098', '9091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9091', '112', '10968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10969', '1079', '1', 'Wenceslau Guimarães', 'BR.05.2933505', 'ASCII:Wenceslau Guimaraes;ID:6321099', '9092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9092', '112', '10969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10970', '1079', '1', 'Xique-Xique', 'BR.05.2933604', 'ASCII:Xique-Xique;ID:6321100', '9093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9093', '112', '10970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2933604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10971', '1079', '1', 'Abadia dos Dourados', 'BR.15.3100104', 'ASCII:Abadia Dos Dourados;ID:6321101', '9094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9094', '112', '10971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3100104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10972', '1079', '1', 'Abaeté', 'BR.15.3100203', 'ASCII:Abaete;ID:6321102', '9095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9095', '112', '10972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3100203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10973', '1079', '1', 'Abre Campo', 'BR.15.3100302', 'ASCII:Abre Campo;ID:6321103', '9096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9096', '112', '10973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3100302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10974', '1079', '1', 'Acaiaca', 'BR.15.3100401', 'ASCII:Acaiaca;ID:6321104', '9097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9097', '112', '10974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3100401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10975', '1079', '1', 'Açucena', 'BR.15.3100500', 'ASCII:Acucena;ID:6321105', '9098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9098', '112', '10975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3100500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10976', '1079', '1', 'Água Boa', 'BR.15.3100609', 'ASCII:Agua Boa;ID:6321106', '9099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9099', '112', '10976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3100609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10977', '1079', '1', 'Água Comprida', 'BR.15.3100708', 'ASCII:Agua Comprida;ID:6321107', '9100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9100', '112', '10977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3100708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10978', '1079', '1', 'Aguanil', 'BR.15.3100807', 'ASCII:Aguanil;ID:6321108', '9101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9101', '112', '10978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3100807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10979', '1079', '1', 'Águas Formosas', 'BR.15.3100906', 'ASCII:Aguas Formosas;ID:6321109', '9102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9102', '112', '10979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3100906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10980', '1079', '1', 'Águas Vermelhas', 'BR.15.3101003', 'ASCII:Aguas Vermelhas;ID:6321110', '9103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9103', '112', '10980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10981', '1079', '1', 'Aimorés', 'BR.15.3101102', 'ASCII:Aimores;ID:6321111', '9104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9104', '112', '10981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10982', '1079', '1', 'Aiuruoca', 'BR.15.3101201', 'ASCII:Aiuruoca;ID:6321112', '9105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9105', '112', '10982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10983', '1079', '1', 'Alagoa', 'BR.15.3101300', 'ASCII:Alagoa;ID:6321113', '9106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9106', '112', '10983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10984', '1079', '1', 'Albertina', 'BR.15.3101409', 'ASCII:Albertina;ID:6321114', '9107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9107', '112', '10984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10985', '1079', '1', 'Alfenas', 'BR.15.3101607', 'ASCII:Alfenas;ID:6321115', '9108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9108', '112', '10985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10986', '1079', '1', 'Alfredo Vasconcelos', 'BR.15.3101631', 'ASCII:Alfredo Vasconcelos;ID:6321116', '9109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9109', '112', '10986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10987', '1079', '1', 'Almenara', 'BR.15.3101706', 'ASCII:Almenara;ID:6321117', '9110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9110', '112', '10987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10988', '1079', '1', 'Alpercata', 'BR.15.3101805', 'ASCII:Alpercata;ID:6321118', '9111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9111', '112', '10988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10989', '1079', '1', 'Alpinópolis', 'BR.15.3101904', 'ASCII:Alpinopolis;ID:6321119', '9112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9112', '112', '10989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3101904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10990', '1079', '1', 'Alterosa', 'BR.15.3102001', 'ASCII:Alterosa;ID:6321120', '9113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9113', '112', '10990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10991', '1079', '1', 'Alto Caparaó', 'BR.15.3102050', 'ASCII:Alto Caparao;ID:6321121', '9114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9114', '112', '10991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10992', '1079', '1', 'Alto Rio Doce', 'BR.15.3102100', 'ASCII:Alto Rio Doce;ID:6321122', '9115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9115', '112', '10992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10993', '1079', '1', 'Alvarenga', 'BR.15.3102209', 'ASCII:Alvarenga;ID:6321123', '9116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9116', '112', '10993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10994', '1079', '1', 'Alvinópolis', 'BR.15.3102308', 'ASCII:Alvinopolis;ID:6321124', '9117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9117', '112', '10994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10995', '1079', '1', 'Alvorada de Minas', 'BR.15.3102407', 'ASCII:Alvorada De Minas;ID:6321125', '9118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9118', '112', '10995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10996', '1079', '1', 'Amparo do Serra', 'BR.15.3102506', 'ASCII:Amparo Do Serra;ID:6321126', '9119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9119', '112', '10996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10997', '1079', '1', 'Andradas', 'BR.15.3102605', 'ASCII:Andradas;ID:6321127', '9120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9120', '112', '10997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10998', '1079', '1', 'Cachoeira de Pajeú', 'BR.15.3102704', 'ASCII:Cachoeira De Pajeu;ID:6321128', '9121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9121', '112', '10998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('10999', '1079', '1', 'Andrelândia', 'BR.15.3102803', 'ASCII:Andrelandia;ID:6321129', '9122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9122', '112', '10999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11000', '1079', '1', 'Angelândia', 'BR.15.3102852', 'ASCII:Angelandia;ID:6321130', '9123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9123', '112', '11000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11001', '1079', '1', 'Antônio Carlos', 'BR.15.3102902', 'ASCII:Antonio Carlos;ID:6321131', '9124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9124', '112', '11001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3102902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11002', '1079', '1', 'Antônio Dias', 'BR.15.3103009', 'ASCII:Antonio Dias;ID:6321132', '9125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9125', '112', '11002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11003', '1079', '1', 'Antônio Prado de Minas', 'BR.15.3103108', 'ASCII:Antonio Prado De Minas;ID:6321133', '9126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9126', '112', '11003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11004', '1079', '1', 'Aracitaba', 'BR.15.3103306', 'ASCII:Aracitaba;ID:6321134', '9127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9127', '112', '11004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11005', '1079', '1', 'Araçuaí', 'BR.15.3103405', 'ASCII:Aracuai;ID:6321135', '9128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9128', '112', '11005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11006', '1079', '1', 'Araguari', 'BR.15.3103504', 'ASCII:Araguari;ID:6321136', '9129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9129', '112', '11006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11007', '1079', '1', 'Arantina', 'BR.15.3103603', 'ASCII:Arantina;ID:6321137', '9130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9130', '112', '11007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11008', '1079', '1', 'Araponga', 'BR.15.3103702', 'ASCII:Araponga;ID:6321138', '9131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9131', '112', '11008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11009', '1079', '1', 'Araporã', 'BR.15.3103751', 'ASCII:Arapora;ID:6321139', '9132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9132', '112', '11009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11010', '1079', '1', 'Arapuá', 'BR.15.3103801', 'ASCII:Arapua;ID:6321140', '9133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9133', '112', '11010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11011', '1079', '1', 'Araújos', 'BR.15.3103900', 'ASCII:Araujos;ID:6321141', '9134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9134', '112', '11011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3103900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11012', '1079', '1', 'Araxá', 'BR.15.3104007', 'ASCII:Araxa;ID:6321142', '9135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9135', '112', '11012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11013', '1079', '1', 'Arceburgo', 'BR.15.3104106', 'ASCII:Arceburgo;ID:6321143', '9136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9136', '112', '11013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11014', '1079', '1', 'Arcos', 'BR.15.3104205', 'ASCII:Arcos;ID:6321144', '9137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9137', '112', '11014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11015', '1079', '1', 'Areado', 'BR.15.3104304', 'ASCII:Areado;ID:6321145', '9138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9138', '112', '11015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11016', '1079', '1', 'Argirita', 'BR.15.3104403', 'ASCII:Argirita;ID:6321146', '9139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9139', '112', '11016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11017', '1079', '1', 'Aricanduva', 'BR.15.3104452', 'ASCII:Aricanduva;ID:6321147', '9140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9140', '112', '11017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11018', '1079', '1', 'Arinos', 'BR.15.3104502', 'ASCII:Arinos;ID:6321148', '9141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9141', '112', '11018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11019', '1079', '1', 'Astolfo Dutra', 'BR.15.3104601', 'ASCII:Astolfo Dutra;ID:6321149', '9142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9142', '112', '11019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11020', '1079', '1', 'Ataléia', 'BR.15.3104700', 'ASCII:Ataleia;ID:6321150', '9143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9143', '112', '11020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11021', '1079', '1', 'Baependi', 'BR.15.3104908', 'ASCII:Baependi;ID:6321151', '9144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9144', '112', '11021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11022', '1079', '1', 'Baldim', 'BR.15.3105004', 'ASCII:Baldim;ID:6321152', '9145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9145', '112', '11022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3105004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11023', '1079', '1', 'Bambuí', 'BR.15.3105103', 'ASCII:Bambui;ID:6321153', '9146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9146', '112', '11023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3105103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11024', '1079', '1', 'Bandeira', 'BR.15.3105202', 'ASCII:Bandeira;ID:6321154', '9147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9147', '112', '11024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3105202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11025', '1079', '1', 'Bandeira do Sul', 'BR.15.3105301', 'ASCII:Bandeira Do Sul;ID:6321155', '9148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9148', '112', '11025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3105301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11026', '1079', '1', 'Barão de Cocais', 'BR.15.3105400', 'ASCII:Barao De Cocais;ID:6321156', '9149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9149', '112', '11026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3105400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11027', '1079', '1', 'Barão de Monte Alto', 'BR.15.3105509', 'ASCII:Barao De Monte Alto;ID:6321157', '9150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9150', '112', '11027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3105509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11028', '1079', '1', 'Barbacena', 'BR.15.3105608', 'ASCII:Barbacena;ID:6321158', '9151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9151', '112', '11028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3105608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11029', '1079', '1', 'Barra Longa', 'BR.15.3105707', 'ASCII:Barra Longa;ID:6321159', '9152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9152', '112', '11029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3105707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11030', '1079', '1', 'Barroso', 'BR.15.3105905', 'ASCII:Barroso;ID:6321160', '9153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9153', '112', '11030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3105905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11031', '1079', '1', 'Bela Vista de Minas', 'BR.15.3106002', 'ASCII:Bela Vista De Minas;ID:6321161', '9154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9154', '112', '11031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11032', '1079', '1', 'Belo Horizonte', 'BR.15.3106200', 'ASCII:Belo Horizonte;ID:6321162', '9155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9155', '112', '11032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11033', '1079', '1', 'Belo Oriente', 'BR.15.3106309', 'ASCII:Belo Oriente;ID:6321163', '9156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9156', '112', '11033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11034', '1079', '1', 'Belo Vale', 'BR.15.3106408', 'ASCII:Belo Vale;ID:6321164', '9157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9157', '112', '11034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11035', '1079', '1', 'Berilo', 'BR.15.3106507', 'ASCII:Berilo;ID:6321165', '9158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9158', '112', '11035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11036', '1079', '1', 'Bertópolis', 'BR.15.3106606', 'ASCII:Bertopolis;ID:6321166', '9159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9159', '112', '11036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11037', '1079', '1', 'Berizal', 'BR.15.3106655', 'ASCII:Berizal;ID:6321167', '9160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9160', '112', '11037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11038', '1079', '1', 'Betim', 'BR.15.3106705', 'ASCII:Betim;ID:6321168', '9161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9161', '112', '11038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11039', '1079', '1', 'Bias Fortes', 'BR.15.3106804', 'ASCII:Bias Fortes;ID:6321169', '9162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9162', '112', '11039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11040', '1079', '1', 'Bicas', 'BR.15.3106903', 'ASCII:Bicas;ID:6321170', '9163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9163', '112', '11040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11041', '1079', '1', 'Biquinhas', 'BR.15.3107000', 'ASCII:Biquinhas;ID:6321171', '9164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9164', '112', '11041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3107000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11042', '1079', '1', 'Boa Esperança', 'BR.15.3107109', 'ASCII:Boa Esperanca;ID:6321172', '9165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9165', '112', '11042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3107109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11043', '1079', '1', 'Bocaina de Minas', 'BR.15.3107208', 'ASCII:Bocaina De Minas;ID:6321173', '9166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9166', '112', '11043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3107208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11044', '1079', '1', 'Bocaiúva', 'BR.15.3107307', 'ASCII:Bocaiuva;ID:6321174', '9167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9167', '112', '11044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3107307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11045', '1079', '1', 'Bom Despacho', 'BR.15.3107406', 'ASCII:Bom Despacho;ID:6321175', '9168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9168', '112', '11045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3107406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11046', '1079', '1', 'Bom Jardim de Minas', 'BR.15.3107505', 'ASCII:Bom Jardim De Minas;ID:6321176', '9169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9169', '112', '11046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3107505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11047', '1079', '1', 'Bom Jesus da Penha', 'BR.15.3107604', 'ASCII:Bom Jesus Da Penha;ID:6321177', '9170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9170', '112', '11047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3107604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11048', '1079', '1', 'Bom Jesus do Amparo', 'BR.15.3107703', 'ASCII:Bom Jesus Do Amparo;ID:6321178', '9171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9171', '112', '11048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3107703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11049', '1079', '1', 'Bom Jesus do Galho', 'BR.15.3107802', 'ASCII:Bom Jesus Do Galho;ID:6321179', '9172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9172', '112', '11049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3107802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11050', '1079', '1', 'Bom Repouso', 'BR.15.3107901', 'ASCII:Bom Repouso;ID:6321180', '9173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9173', '112', '11050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3107901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11051', '1079', '1', 'Bom Sucesso', 'BR.15.3108008', 'ASCII:Bom Sucesso;ID:6321181', '9174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9174', '112', '11051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11052', '1079', '1', 'Bonfim', 'BR.15.3108107', 'ASCII:Bonfim;ID:6321182', '9175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9175', '112', '11052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11053', '1079', '1', 'Bonfinópolis de Minas', 'BR.15.3108206', 'ASCII:Bonfinopolis De Minas;ID:6321183', '9176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9176', '112', '11053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11054', '1079', '1', 'Bonito de Minas', 'BR.15.3108255', 'ASCII:Bonito De Minas;ID:6321184', '9177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9177', '112', '11054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11055', '1079', '1', 'Borda da Mata', 'BR.15.3108305', 'ASCII:Borda Da Mata;ID:6321185', '9178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9178', '112', '11055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11056', '1079', '1', 'Botelhos', 'BR.15.3108404', 'ASCII:Botelhos;ID:6321186', '9179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9179', '112', '11056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11057', '1079', '1', 'Botumirim', 'BR.15.3108503', 'ASCII:Botumirim;ID:6321187', '9180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9180', '112', '11057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11058', '1079', '1', 'Brasilândia de Minas', 'BR.15.3108552', 'ASCII:Brasilandia De Minas;ID:6321188', '9181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9181', '112', '11058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11059', '1079', '1', 'Brasília de Minas', 'BR.15.3108602', 'ASCII:Brasilia De Minas;ID:6321189', '9182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9182', '112', '11059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11060', '1079', '1', 'Brás Pires', 'BR.15.3108701', 'ASCII:Bras Pires;ID:6321190', '9183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9183', '112', '11060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11061', '1079', '1', 'Braúnas', 'BR.15.3108800', 'ASCII:Braunas;ID:6321191', '9184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9184', '112', '11061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11062', '1079', '1', 'Brasópolis', 'BR.15.3108909', 'ASCII:Brasopolis;ID:6321192', '9185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9185', '112', '11062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3108909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11063', '1079', '1', 'Brumadinho', 'BR.15.3109006', 'ASCII:Brumadinho;ID:6321193', '9186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9186', '112', '11063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11064', '1079', '1', 'Bueno Brandão', 'BR.15.3109105', 'ASCII:Bueno Brandao;ID:6321194', '9187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9187', '112', '11064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11065', '1079', '1', 'Bugre', 'BR.15.3109253', 'ASCII:Bugre;ID:6321195', '9188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9188', '112', '11065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11066', '1079', '1', 'Buritis', 'BR.15.3109303', 'ASCII:Buritis;ID:6321196', '9189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9189', '112', '11066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11067', '1079', '1', 'Buritizeiro', 'BR.15.3109402', 'ASCII:Buritizeiro;ID:6321197', '9190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9190', '112', '11067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11068', '1079', '1', 'Cabeceira Grande', 'BR.15.3109451', 'ASCII:Cabeceira Grande;ID:6321198', '9191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9191', '112', '11068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11069', '1079', '1', 'Cabo Verde', 'BR.15.3109501', 'ASCII:Cabo Verde;ID:6321199', '9192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9192', '112', '11069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11070', '1079', '1', 'Cachoeira da Prata', 'BR.15.3109600', 'ASCII:Cachoeira Da Prata;ID:6321200', '9193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9193', '112', '11070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11071', '1079', '1', 'Cachoeira de Minas', 'BR.15.3109709', 'ASCII:Cachoeira De Minas;ID:6321201', '9194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9194', '112', '11071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11072', '1079', '1', 'Cachoeira Dourada', 'BR.15.3109808', 'ASCII:Cachoeira Dourada;ID:6321202', '9195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9195', '112', '11072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11073', '1079', '1', 'Caetanópolis', 'BR.15.3109907', 'ASCII:Caetanopolis;ID:6321203', '9196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9196', '112', '11073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11074', '1079', '1', 'Caeté', 'BR.15.3110004', 'ASCII:Caete;ID:6321204', '9197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9197', '112', '11074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3110004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11075', '1079', '1', 'Caiana', 'BR.15.3110103', 'ASCII:Caiana;ID:6321205', '9198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9198', '112', '11075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3110103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11076', '1079', '1', 'Cajuri', 'BR.15.3110202', 'ASCII:Cajuri;ID:6321206', '9199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9199', '112', '11076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3110202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11077', '1079', '1', 'Caldas', 'BR.15.3110301', 'ASCII:Caldas;ID:6321207', '9200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9200', '112', '11077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3110301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11078', '1079', '1', 'Camacho', 'BR.15.3110400', 'ASCII:Camacho;ID:6321208', '9201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9201', '112', '11078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3110400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11079', '1079', '1', 'Camanducaia', 'BR.15.3110509', 'ASCII:Camanducaia;ID:6321209', '9202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9202', '112', '11079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3110509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11080', '1079', '1', 'Cambuí', 'BR.15.3110608', 'ASCII:Cambui;ID:6321210', '9203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9203', '112', '11080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3110608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11081', '1079', '1', 'Cambuquira', 'BR.15.3110707', 'ASCII:Cambuquira;ID:6321211', '9204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9204', '112', '11081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3110707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11082', '1079', '1', 'Campanário', 'BR.15.3110806', 'ASCII:Campanario;ID:6321212', '9205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9205', '112', '11082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3110806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11083', '1079', '1', 'Campanha', 'BR.15.3110905', 'ASCII:Campanha;ID:6321213', '9206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9206', '112', '11083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3110905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11084', '1079', '1', 'Campestre', 'BR.15.3111002', 'ASCII:Campestre;ID:6321214', '9207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9207', '112', '11084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11085', '1079', '1', 'Campina Verde', 'BR.15.3111101', 'ASCII:Campina Verde;ID:6321215', '9208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9208', '112', '11085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11086', '1079', '1', 'Campo Azul', 'BR.15.3111150', 'ASCII:Campo Azul;ID:6321216', '9209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9209', '112', '11086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11087', '1079', '1', 'Campo Belo', 'BR.15.3111200', 'ASCII:Campo Belo;ID:6321217', '9210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9210', '112', '11087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11088', '1079', '1', 'Campo do Meio', 'BR.15.3111309', 'ASCII:Campo Do Meio;ID:6321218', '9211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9211', '112', '11088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11089', '1079', '1', 'Campo Florido', 'BR.15.3111408', 'ASCII:Campo Florido;ID:6321219', '9212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9212', '112', '11089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11090', '1079', '1', 'Campos Altos', 'BR.15.3111507', 'ASCII:Campos Altos;ID:6321220', '9213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9213', '112', '11090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11091', '1079', '1', 'Campos Gerais', 'BR.15.3111606', 'ASCII:Campos Gerais;ID:6321221', '9214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9214', '112', '11091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11092', '1079', '1', 'Canaã', 'BR.15.3111705', 'ASCII:Canaa;ID:6321222', '9215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9215', '112', '11092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11093', '1079', '1', 'Canápolis', 'BR.15.3111804', 'ASCII:Canapolis;ID:6321223', '9216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9216', '112', '11093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11094', '1079', '1', 'Cana Verde', 'BR.15.3111903', 'ASCII:Cana Verde;ID:6321224', '9217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9217', '112', '11094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3111903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11095', '1079', '1', 'Cantagalo', 'BR.15.3112059', 'ASCII:Cantagalo;ID:6321225', '9218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9218', '112', '11095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11096', '1079', '1', 'Caparaó', 'BR.15.3112109', 'ASCII:Caparao;ID:6321226', '9219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9219', '112', '11096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11097', '1079', '1', 'Capela Nova', 'BR.15.3112208', 'ASCII:Capela Nova;ID:6321227', '9220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9220', '112', '11097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11098', '1079', '1', 'Capelinha', 'BR.15.3112307', 'ASCII:Capelinha;ID:6321228', '9221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9221', '112', '11098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11099', '1079', '1', 'Capetinga', 'BR.15.3112406', 'ASCII:Capetinga;ID:6321229', '9222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9222', '112', '11099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11100', '1079', '1', 'Capim Branco', 'BR.15.3112505', 'ASCII:Capim Branco;ID:6321230', '9223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9223', '112', '11100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11101', '1079', '1', 'Capinópolis', 'BR.15.3112604', 'ASCII:Capinopolis;ID:6321231', '9224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9224', '112', '11101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11102', '1079', '1', 'Capitão Andrade', 'BR.15.3112653', 'ASCII:Capitao Andrade;ID:6321232', '9225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9225', '112', '11102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11103', '1079', '1', 'Capitão Enéas', 'BR.15.3112703', 'ASCII:Capitao Eneas;ID:6321233', '9226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9226', '112', '11103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11104', '1079', '1', 'Capitólio', 'BR.15.3112802', 'ASCII:Capitolio;ID:6321234', '9227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9227', '112', '11104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11105', '1079', '1', 'Caputira', 'BR.15.3112901', 'ASCII:Caputira;ID:6321235', '9228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9228', '112', '11105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11106', '1079', '1', 'Caraí', 'BR.15.3113008', 'ASCII:Carai;ID:6321236', '9229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9229', '112', '11106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3113008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11107', '1079', '1', 'Caranaíba', 'BR.15.3113107', 'ASCII:Caranaiba;ID:6321237', '9230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9230', '112', '11107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3113107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11108', '1079', '1', 'Carandaí', 'BR.15.3113206', 'ASCII:Carandai;ID:6321238', '9231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9231', '112', '11108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3113206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11109', '1079', '1', 'Carangola', 'BR.15.3113305', 'ASCII:Carangola;ID:6321239', '9232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9232', '112', '11109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3113305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11110', '1079', '1', 'Caratinga', 'BR.15.3113404', 'ASCII:Caratinga;ID:6321240', '9233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9233', '112', '11110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3113404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11111', '1079', '1', 'Carbonita', 'BR.15.3113503', 'ASCII:Carbonita;ID:6321241', '9234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9234', '112', '11111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3113503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11112', '1079', '1', 'Careaçu', 'BR.15.3113602', 'ASCII:Careacu;ID:6321242', '9235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9235', '112', '11112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3113602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11113', '1079', '1', 'Carlos Chagas', 'BR.15.3113701', 'ASCII:Carlos Chagas;ID:6321243', '9236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9236', '112', '11113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3113701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11114', '1079', '1', 'Carmésia', 'BR.15.3113800', 'ASCII:Carmesia;ID:6321244', '9237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9237', '112', '11114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3113800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11115', '1079', '1', 'Carmo da Cachoeira', 'BR.15.3113909', 'ASCII:Carmo Da Cachoeira;ID:6321245', '9238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9238', '112', '11115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3113909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11116', '1079', '1', 'Carmo da Mata', 'BR.15.3114006', 'ASCII:Carmo Da Mata;ID:6321246', '9239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9239', '112', '11116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11117', '1079', '1', 'Carmo de Minas', 'BR.15.3114105', 'ASCII:Carmo De Minas;ID:6321247', '9240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9240', '112', '11117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11118', '1079', '1', 'Carmo do Cajuru', 'BR.15.3114204', 'ASCII:Carmo Do Cajuru;ID:6321248', '9241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9241', '112', '11118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11119', '1079', '1', 'Carmo do Paranaíba', 'BR.15.3114303', 'ASCII:Carmo Do Paranaiba;ID:6321249', '9242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9242', '112', '11119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11120', '1079', '1', 'Carmo do Rio Claro', 'BR.15.3114402', 'ASCII:Carmo Do Rio Claro;ID:6321250', '9243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9243', '112', '11120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11121', '1079', '1', 'Carmópolis de Minas', 'BR.15.3114501', 'ASCII:Carmopolis De Minas;ID:6321251', '9244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9244', '112', '11121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11122', '1079', '1', 'Carneirinho', 'BR.15.3114550', 'ASCII:Carneirinho;ID:6321252', '9245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9245', '112', '11122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11123', '1079', '1', 'Carrancas', 'BR.15.3114600', 'ASCII:Carrancas;ID:6321253', '9246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9246', '112', '11123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11124', '1079', '1', 'Carvalhópolis', 'BR.15.3114709', 'ASCII:Carvalhopolis;ID:6321254', '9247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9247', '112', '11124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11125', '1079', '1', 'Carvalhos', 'BR.15.3114808', 'ASCII:Carvalhos;ID:6321255', '9248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9248', '112', '11125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11126', '1079', '1', 'Casa Grande', 'BR.15.3114907', 'ASCII:Casa Grande;ID:6321256', '9249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9249', '112', '11126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3114907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11127', '1079', '1', 'Cascalho Rico', 'BR.15.3115003', 'ASCII:Cascalho Rico;ID:6321257', '9250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9250', '112', '11127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11128', '1079', '1', 'Cássia', 'BR.15.3115102', 'ASCII:Cassia;ID:6321258', '9251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9251', '112', '11128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11129', '1079', '1', 'Conceição da Barra de Minas', 'BR.15.3115201', 'ASCII:Conceicao Da Barra De Minas;ID:6321259', '9252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9252', '112', '11129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11130', '1079', '1', 'Cataguases', 'BR.15.3115300', 'ASCII:Cataguases;ID:6321260', '9253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9253', '112', '11130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11131', '1079', '1', 'Catas Altas', 'BR.15.3115359', 'ASCII:Catas Altas;ID:6321261', '9254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9254', '112', '11131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11132', '1079', '1', 'Catas Altas da Noruega', 'BR.15.3115409', 'ASCII:Catas Altas Da Noruega;ID:6321262', '9255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9255', '112', '11132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11133', '1079', '1', 'Catuji', 'BR.15.3115458', 'ASCII:Catuji;ID:6321263', '9256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9256', '112', '11133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11134', '1079', '1', 'Catuti', 'BR.15.3115474', 'ASCII:Catuti;ID:6321264', '9257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9257', '112', '11134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11135', '1079', '1', 'Caxambu', 'BR.15.3115508', 'ASCII:Caxambu;ID:6321265', '9258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9258', '112', '11135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11136', '1079', '1', 'Cedro do Abaeté', 'BR.15.3115607', 'ASCII:Cedro Do Abaete;ID:6321266', '9259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9259', '112', '11136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11137', '1079', '1', 'Central de Minas', 'BR.15.3115706', 'ASCII:Central De Minas;ID:6321267', '9260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9260', '112', '11137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11138', '1079', '1', 'Centralina', 'BR.15.3115805', 'ASCII:Centralina;ID:6321268', '9261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9261', '112', '11138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11139', '1079', '1', 'Chácara', 'BR.15.3115904', 'ASCII:Chacara;ID:6321269', '9262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9262', '112', '11139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3115904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11140', '1079', '1', 'Chalé', 'BR.15.3116001', 'ASCII:Chale;ID:6321270', '9263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9263', '112', '11140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11141', '1079', '1', 'Chapada do Norte', 'BR.15.3116100', 'ASCII:Chapada Do Norte;ID:6321271', '9264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9264', '112', '11141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11142', '1079', '1', 'Chapada Gaúcha', 'BR.15.3116159', 'ASCII:Chapada Gaucha;ID:6321272', '9265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9265', '112', '11142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11143', '1079', '1', 'Chiador', 'BR.15.3116209', 'ASCII:Chiador;ID:6321273', '9266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9266', '112', '11143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11144', '1079', '1', 'Cipotânea', 'BR.15.3116308', 'ASCII:Cipotanea;ID:6321274', '9267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9267', '112', '11144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11145', '1079', '1', 'Claraval', 'BR.15.3116407', 'ASCII:Claraval;ID:6321275', '9268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9268', '112', '11145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11146', '1079', '1', 'Claro dos Poções', 'BR.15.3116506', 'ASCII:Claro Dos Pocoes;ID:6321276', '9269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9269', '112', '11146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11147', '1079', '1', 'Cláudio', 'BR.15.3116605', 'ASCII:Claudio;ID:6321277', '9270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9270', '112', '11147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11148', '1079', '1', 'Coimbra', 'BR.15.3116704', 'ASCII:Coimbra;ID:6321278', '9271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9271', '112', '11148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11149', '1079', '1', 'Coluna', 'BR.15.3116803', 'ASCII:Coluna;ID:6321279', '9272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9272', '112', '11149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11150', '1079', '1', 'Comendador Gomes', 'BR.15.3116902', 'ASCII:Comendador Gomes;ID:6321280', '9273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9273', '112', '11150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3116902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11151', '1079', '1', 'Comercinho', 'BR.15.3117009', 'ASCII:Comercinho;ID:6321281', '9274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9274', '112', '11151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11152', '1079', '1', 'Conceição da Aparecida', 'BR.15.3117108', 'ASCII:Conceicao Da Aparecida;ID:6321282', '9275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9275', '112', '11152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11153', '1079', '1', 'Conceição das Pedras', 'BR.15.3117207', 'ASCII:Conceicao Das Pedras;ID:6321283', '9276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9276', '112', '11153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11154', '1079', '1', 'Conceição das Alagoas', 'BR.15.3117306', 'ASCII:Conceicao Das Alagoas;ID:6321284', '9277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9277', '112', '11154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11155', '1079', '1', 'Conceição de Ipanema', 'BR.15.3117405', 'ASCII:Conceicao De Ipanema;ID:6321285', '9278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9278', '112', '11155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11156', '1079', '1', 'Conceição do Pará', 'BR.15.3117603', 'ASCII:Conceicao Do Para;ID:6321286', '9279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9279', '112', '11156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11157', '1079', '1', 'Conceição do Rio Verde', 'BR.15.3117702', 'ASCII:Conceicao Do Rio Verde;ID:6321287', '9280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9280', '112', '11157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11158', '1079', '1', 'Conceição dos Ouros', 'BR.15.3117801', 'ASCII:Conceicao Dos Ouros;ID:6321288', '9281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9281', '112', '11158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11159', '1079', '1', 'Cônego Marinho', 'BR.15.3117836', 'ASCII:Conego Marinho;ID:6321289', '9282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9282', '112', '11159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11160', '1079', '1', 'Confins', 'BR.15.3117876', 'ASCII:Confins;ID:6321290', '9283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9283', '112', '11160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11161', '1079', '1', 'Congonhal', 'BR.15.3117900', 'ASCII:Congonhal;ID:6321291', '9284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9284', '112', '11161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3117900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11162', '1079', '1', 'Congonhas', 'BR.15.3118007', 'ASCII:Congonhas;ID:6321292', '9285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9285', '112', '11162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3118007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11163', '1079', '1', 'Congonhas do Norte', 'BR.15.3118106', 'ASCII:Congonhas Do Norte;ID:6321293', '9286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9286', '112', '11163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3118106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11164', '1079', '1', 'Conquista', 'BR.15.3118205', 'ASCII:Conquista;ID:6321294', '9287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9287', '112', '11164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3118205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11165', '1079', '1', 'Conselheiro Lafaiete', 'BR.15.3118304', 'ASCII:Conselheiro Lafaiete;ID:6321295', '9288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9288', '112', '11165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3118304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11166', '1079', '1', 'Conselheiro Pena', 'BR.15.3118403', 'ASCII:Conselheiro Pena;ID:6321296', '9289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9289', '112', '11166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3118403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11167', '1079', '1', 'Contagem', 'BR.15.3118601', 'ASCII:Contagem;ID:6321297', '9290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9290', '112', '11167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3118601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11168', '1079', '1', 'Coqueiral', 'BR.15.3118700', 'ASCII:Coqueiral;ID:6321298', '9291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9291', '112', '11168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3118700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11169', '1079', '1', 'Coração de Jesus', 'BR.15.3118809', 'ASCII:Coracao De Jesus;ID:6321299', '9292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9292', '112', '11169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3118809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11170', '1079', '1', 'Cordisburgo', 'BR.15.3118908', 'ASCII:Cordisburgo;ID:6321300', '9293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9293', '112', '11170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3118908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11171', '1079', '1', 'Cordislândia', 'BR.15.3119005', 'ASCII:Cordislandia;ID:6321301', '9294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9294', '112', '11171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11172', '1079', '1', 'Corinto', 'BR.15.3119104', 'ASCII:Corinto;ID:6321302', '9295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9295', '112', '11172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11173', '1079', '1', 'Coroaci', 'BR.15.3119203', 'ASCII:Coroaci;ID:6321303', '9296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9296', '112', '11173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11174', '1079', '1', 'Coromandel', 'BR.15.3119302', 'ASCII:Coromandel;ID:6321304', '9297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9297', '112', '11174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11175', '1079', '1', 'Coronel Fabriciano', 'BR.15.3119401', 'ASCII:Coronel Fabriciano;ID:6321305', '9298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9298', '112', '11175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11176', '1079', '1', 'Coronel Murta', 'BR.15.3119500', 'ASCII:Coronel Murta;ID:6321306', '9299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9299', '112', '11176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11177', '1079', '1', 'Coronel Pacheco', 'BR.15.3119609', 'ASCII:Coronel Pacheco;ID:6321307', '9300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9300', '112', '11177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11178', '1079', '1', 'Coronel Xavier Chaves', 'BR.15.3119708', 'ASCII:Coronel Xavier Chaves;ID:6321308', '9301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9301', '112', '11178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11179', '1079', '1', 'Córrego Danta', 'BR.15.3119807', 'ASCII:Corrego Danta;ID:6321309', '9302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9302', '112', '11179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11180', '1079', '1', 'Córrego do Bom Jesus', 'BR.15.3119906', 'ASCII:Corrego Do Bom Jesus;ID:6321310', '9303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9303', '112', '11180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11181', '1079', '1', 'Córrego Fundo', 'BR.15.3119955', 'ASCII:Corrego Fundo;ID:6321311', '9304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9304', '112', '11181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3119955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11182', '1079', '1', 'Córrego Novo', 'BR.15.3120003', 'ASCII:Corrego Novo;ID:6321312', '9305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9305', '112', '11182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11183', '1079', '1', 'Couto de Magalhães de Minas', 'BR.15.3120102', 'ASCII:Couto De Magalhaes De Minas;ID:6321313', '9306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9306', '112', '11183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11184', '1079', '1', 'Crisólita', 'BR.15.3120151', 'ASCII:Crisolita;ID:6321314', '9307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9307', '112', '11184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11185', '1079', '1', 'Cristais', 'BR.15.3120201', 'ASCII:Cristais;ID:6321315', '9308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9308', '112', '11185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11186', '1079', '1', 'Cristália', 'BR.15.3120300', 'ASCII:Cristalia;ID:6321316', '9309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9309', '112', '11186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11187', '1079', '1', 'Cristiano Otoni', 'BR.15.3120409', 'ASCII:Cristiano Otoni;ID:6321317', '9310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9310', '112', '11187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11188', '1079', '1', 'Cristina', 'BR.15.3120508', 'ASCII:Cristina;ID:6321318', '9311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9311', '112', '11188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11189', '1079', '1', 'Crucilândia', 'BR.15.3120607', 'ASCII:Crucilandia;ID:6321319', '9312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9312', '112', '11189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11190', '1079', '1', 'Cruzeiro da Fortaleza', 'BR.15.3120706', 'ASCII:Cruzeiro Da Fortaleza;ID:6321320', '9313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9313', '112', '11190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11191', '1079', '1', 'Cruzília', 'BR.15.3120805', 'ASCII:Cruzilia;ID:6321321', '9314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9314', '112', '11191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11192', '1079', '1', 'Cuparaque', 'BR.15.3120839', 'ASCII:Cuparaque;ID:6321322', '9315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9315', '112', '11192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11193', '1079', '1', 'Curral de Dentro', 'BR.15.3120870', 'ASCII:Curral De Dentro;ID:6321323', '9316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9316', '112', '11193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11194', '1079', '1', 'Curvelo', 'BR.15.3120904', 'ASCII:Curvelo;ID:6321324', '9317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9317', '112', '11194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3120904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11195', '1079', '1', 'Datas', 'BR.15.3121001', 'ASCII:Datas;ID:6321325', '9318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9318', '112', '11195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11196', '1079', '1', 'Delfim Moreira', 'BR.15.3121100', 'ASCII:Delfim Moreira;ID:6321326', '9319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9319', '112', '11196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11197', '1079', '1', 'Delfinópolis', 'BR.15.3121209', 'ASCII:Delfinopolis;ID:6321327', '9320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9320', '112', '11197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11198', '1079', '1', 'Delta', 'BR.15.3121258', 'ASCII:Delta;ID:6321328', '9321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9321', '112', '11198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11199', '1079', '1', 'Descoberto', 'BR.15.3121308', 'ASCII:Descoberto;ID:6321329', '9322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9322', '112', '11199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11200', '1079', '1', 'Desterro de Entre Rios', 'BR.15.3121407', 'ASCII:Desterro De Entre Rios;ID:6321330', '9323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9323', '112', '11200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11201', '1079', '1', 'Desterro do Melo', 'BR.15.3121506', 'ASCII:Desterro Do Melo;ID:6321331', '9324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9324', '112', '11201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11202', '1079', '1', 'Diogo de Vasconcelos', 'BR.15.3121704', 'ASCII:Diogo De Vasconcelos;ID:6321332', '9325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9325', '112', '11202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11203', '1079', '1', 'Dionísio', 'BR.15.3121803', 'ASCII:Dionisio;ID:6321333', '9326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9326', '112', '11203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11204', '1079', '1', 'Divinésia', 'BR.15.3121902', 'ASCII:Divinesia;ID:6321334', '9327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9327', '112', '11204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11205', '1079', '1', 'Divino', 'BR.15.3122009', 'ASCII:Divino;ID:6321335', '9328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9328', '112', '11205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11206', '1079', '1', 'Divino das Laranjeiras', 'BR.15.3122108', 'ASCII:Divino Das Laranjeiras;ID:6321336', '9329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9329', '112', '11206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11207', '1079', '1', 'Divinolândia de Minas', 'BR.15.3122207', 'ASCII:Divinolandia De Minas;ID:6321337', '9330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9330', '112', '11207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11208', '1079', '1', 'Divinópolis', 'BR.15.3122306', 'ASCII:Divinopolis;ID:6321338', '9331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9331', '112', '11208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11209', '1079', '1', 'Divisa Alegre', 'BR.15.3122355', 'ASCII:Divisa Alegre;ID:6321339', '9332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9332', '112', '11209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11210', '1079', '1', 'Divisa Nova', 'BR.15.3122405', 'ASCII:Divisa Nova;ID:6321340', '9333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9333', '112', '11210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11211', '1079', '1', 'Divisópolis', 'BR.15.3122454', 'ASCII:Divisopolis;ID:6321341', '9334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9334', '112', '11211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11212', '1079', '1', 'Dom Bosco', 'BR.15.3122470', 'ASCII:Dom Bosco;ID:6321342', '9335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9335', '112', '11212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11213', '1079', '1', 'Dom Cavati', 'BR.15.3122504', 'ASCII:Dom Cavati;ID:6321343', '9336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9336', '112', '11213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11214', '1079', '1', 'Dom Joaquim', 'BR.15.3122603', 'ASCII:Dom Joaquim;ID:6321344', '9337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9337', '112', '11214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11215', '1079', '1', 'Dom Silvério', 'BR.15.3122702', 'ASCII:Dom Silverio;ID:6321345', '9338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9338', '112', '11215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11216', '1079', '1', 'Dom Viçoso', 'BR.15.3122801', 'ASCII:Dom Vicoso;ID:6321346', '9339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9339', '112', '11216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11217', '1079', '1', 'Dona Eusébia', 'BR.15.3122900', 'ASCII:Dona Euzebia;ID:6321347', '9340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9340', '112', '11217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3122900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11218', '1079', '1', 'Dores de Campos', 'BR.15.3123007', 'ASCII:Dores De Campos;ID:6321348', '9341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9341', '112', '11218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11219', '1079', '1', 'Dores de Guanhães', 'BR.15.3123106', 'ASCII:Dores De Guanhaes;ID:6321349', '9342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9342', '112', '11219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11220', '1079', '1', 'Dores do Indaiá', 'BR.15.3123205', 'ASCII:Dores Do Indaia;ID:6321350', '9343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9343', '112', '11220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11221', '1079', '1', 'Dores do Turvo', 'BR.15.3123304', 'ASCII:Dores Do Turvo;ID:6321351', '9344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9344', '112', '11221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11222', '1079', '1', 'Doresópolis', 'BR.15.3123403', 'ASCII:Doresopolis;ID:6321352', '9345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9345', '112', '11222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11223', '1079', '1', 'Douradoquara', 'BR.15.3123502', 'ASCII:Douradoquara;ID:6321353', '9346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9346', '112', '11223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11224', '1079', '1', 'Durandé', 'BR.15.3123528', 'ASCII:Durande;ID:6321354', '9347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9347', '112', '11224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11225', '1079', '1', 'Elói Mendes', 'BR.15.3123601', 'ASCII:Eloi Mendes;ID:6321355', '9348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9348', '112', '11225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11226', '1079', '1', 'Engenheiro Caldas', 'BR.15.3123700', 'ASCII:Engenheiro Caldas;ID:6321356', '9349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9349', '112', '11226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11227', '1079', '1', 'Engenheiro Navarro', 'BR.15.3123809', 'ASCII:Engenheiro Navarro;ID:6321357', '9350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9350', '112', '11227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11228', '1079', '1', 'Entre Folhas', 'BR.15.3123858', 'ASCII:Entre Folhas;ID:6321358', '9351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9351', '112', '11228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11229', '1079', '1', 'Entre Rios de Minas', 'BR.15.3123908', 'ASCII:Entre Rios De Minas;ID:6321359', '9352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9352', '112', '11229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3123908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11230', '1079', '1', 'Ervália', 'BR.15.3124005', 'ASCII:Ervalia;ID:6321360', '9353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9353', '112', '11230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3124005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11231', '1079', '1', 'Esmeraldas', 'BR.15.3124104', 'ASCII:Esmeraldas;ID:6321361', '9354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9354', '112', '11231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3124104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11232', '1079', '1', 'Espera Feliz', 'BR.15.3124203', 'ASCII:Espera Feliz;ID:6321362', '9355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9355', '112', '11232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3124203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11233', '1079', '1', 'Espinosa', 'BR.15.3124302', 'ASCII:Espinosa;ID:6321363', '9356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9356', '112', '11233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3124302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11234', '1079', '1', 'Espírito Santo do Dourado', 'BR.15.3124401', 'ASCII:Espirito Santo Do Dourado;ID:6321364', '9357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9357', '112', '11234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3124401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11235', '1079', '1', 'Estiva', 'BR.15.3124500', 'ASCII:Estiva;ID:6321365', '9358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9358', '112', '11235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3124500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11236', '1079', '1', 'Estrela Dalva', 'BR.15.3124609', 'ASCII:Estrela Dalva;ID:6321366', '9359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9359', '112', '11236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3124609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11237', '1079', '1', 'Estrela do Indaiá', 'BR.15.3124708', 'ASCII:Estrela Do Indaia;ID:6321367', '9360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9360', '112', '11237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3124708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11238', '1079', '1', 'Estrela do Sul', 'BR.15.3124807', 'ASCII:Estrela Do Sul;ID:6321368', '9361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9361', '112', '11238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3124807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11239', '1079', '1', 'Eugenópolis', 'BR.15.3124906', 'ASCII:Eugenopolis;ID:6321369', '9362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9362', '112', '11239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3124906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11240', '1079', '1', 'Ewbank da Câmara', 'BR.15.3125002', 'ASCII:Ewbank Da Camara;ID:6321370', '9363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9363', '112', '11240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11241', '1079', '1', 'Extrema', 'BR.15.3125101', 'ASCII:Extrema;ID:6321371', '9364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9364', '112', '11241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11242', '1079', '1', 'Fama', 'BR.15.3125200', 'ASCII:Fama;ID:6321372', '9365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9365', '112', '11242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11243', '1079', '1', 'Faria Lemos', 'BR.15.3125309', 'ASCII:Faria Lemos;ID:6321373', '9366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9366', '112', '11243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11244', '1079', '1', 'Felício dos Santos', 'BR.15.3125408', 'ASCII:Felicio Dos Santos;ID:6321374', '9367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9367', '112', '11244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11245', '1079', '1', 'São Gonçalo do Rio Preto', 'BR.15.3125507', 'ASCII:Sao Goncalo Do Rio Preto;ID:6321375', '9368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9368', '112', '11245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11246', '1079', '1', 'Felisburgo', 'BR.15.3125606', 'ASCII:Felisburgo;ID:6321376', '9369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9369', '112', '11246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11247', '1079', '1', 'Felixlândia', 'BR.15.3125705', 'ASCII:Felixlandia;ID:6321377', '9370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9370', '112', '11247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11248', '1079', '1', 'Fernandes Tourinho', 'BR.15.3125804', 'ASCII:Fernandes Tourinho;ID:6321378', '9371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9371', '112', '11248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11249', '1079', '1', 'Ferros', 'BR.15.3125903', 'ASCII:Ferros;ID:6321379', '9372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9372', '112', '11249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11250', '1079', '1', 'Fervedouro', 'BR.15.3125952', 'ASCII:Fervedouro;ID:6321380', '9373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9373', '112', '11250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3125952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11251', '1079', '1', 'Florestal', 'BR.15.3126000', 'ASCII:Florestal;ID:6321381', '9374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9374', '112', '11251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11252', '1079', '1', 'Formiga', 'BR.15.3126109', 'ASCII:Formiga;ID:6321382', '9375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9375', '112', '11252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11253', '1079', '1', 'Formoso', 'BR.15.3126208', 'ASCII:Formoso;ID:6321383', '9376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9376', '112', '11253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11254', '1079', '1', 'Fortaleza de Minas', 'BR.15.3126307', 'ASCII:Fortaleza De Minas;ID:6321384', '9377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9377', '112', '11254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11255', '1079', '1', 'Fortuna de Minas', 'BR.15.3126406', 'ASCII:Fortuna De Minas;ID:6321385', '9378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9378', '112', '11255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11256', '1079', '1', 'Francisco Badaró', 'BR.15.3126505', 'ASCII:Francisco Badaro;ID:6321386', '9379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9379', '112', '11256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11257', '1079', '1', 'Francisco Dumont', 'BR.15.3126604', 'ASCII:Francisco Dumont;ID:6321387', '9380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9380', '112', '11257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11258', '1079', '1', 'Francisco Sá', 'BR.15.3126703', 'ASCII:Francisco Sa;ID:6321388', '9381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9381', '112', '11258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11259', '1079', '1', 'Franciscópolis', 'BR.15.3126752', 'ASCII:Franciscopolis;ID:6321389', '9382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9382', '112', '11259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11260', '1079', '1', 'Frei Gaspar', 'BR.15.3126802', 'ASCII:Frei Gaspar;ID:6321390', '9383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9383', '112', '11260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11261', '1079', '1', 'Frei Inocêncio', 'BR.15.3126901', 'ASCII:Frei Inocencio;ID:6321391', '9384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9384', '112', '11261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11262', '1079', '1', 'Frei Lagonegro', 'BR.15.3126950', 'ASCII:Frei Lagonegro;ID:6321392', '9385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9385', '112', '11262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3126950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11263', '1079', '1', 'Fronteira', 'BR.15.3127008', 'ASCII:Fronteira;ID:6321393', '9386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9386', '112', '11263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11264', '1079', '1', 'Fronteira dos Vales', 'BR.15.3127057', 'ASCII:Fronteira Dos Vales;ID:6321394', '9387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9387', '112', '11264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11265', '1079', '1', 'Fruta de Leite', 'BR.15.3127073', 'ASCII:Fruta De Leite;ID:6321395', '9388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9388', '112', '11265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11266', '1079', '1', 'Frutal', 'BR.15.3127107', 'ASCII:Frutal;ID:6321396', '9389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9389', '112', '11266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11267', '1079', '1', 'Funilândia', 'BR.15.3127206', 'ASCII:Funilandia;ID:6321397', '9390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9390', '112', '11267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11268', '1079', '1', 'Galiléia', 'BR.15.3127305', 'ASCII:Galileia;ID:6321398', '9391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9391', '112', '11268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11269', '1079', '1', 'Gameleiras', 'BR.15.3127339', 'ASCII:Gameleiras;ID:6321399', '9392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9392', '112', '11269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11270', '1079', '1', 'Glaucilândia', 'BR.15.3127354', 'ASCII:Glaucilandia;ID:6321400', '9393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9393', '112', '11270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11271', '1079', '1', 'Goiabeira', 'BR.15.3127370', 'ASCII:Goiabeira;ID:6321401', '9394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9394', '112', '11271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11272', '1079', '1', 'Goianá', 'BR.15.3127388', 'ASCII:Goiana;ID:6321402', '9395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9395', '112', '11272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11273', '1079', '1', 'Gonçalves', 'BR.15.3127404', 'ASCII:Goncalves;ID:6321403', '9396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9396', '112', '11273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11274', '1079', '1', 'Gonzaga', 'BR.15.3127503', 'ASCII:Gonzaga;ID:6321404', '9397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9397', '112', '11274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11275', '1079', '1', 'Governador Valadares', 'BR.15.3127701', 'ASCII:Governador Valadares;ID:6321405', '9398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9398', '112', '11275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11276', '1079', '1', 'Grão Mogol', 'BR.15.3127800', 'ASCII:Grao Mogol;ID:6321406', '9399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9399', '112', '11276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11277', '1079', '1', 'Grupiara', 'BR.15.3127909', 'ASCII:Grupiara;ID:6321407', '9400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9400', '112', '11277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11278', '1079', '1', 'Guanhães', 'BR.15.3128006', 'ASCII:Guanhaes;ID:6321408', '9401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9401', '112', '11278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11279', '1079', '1', 'Guapé', 'BR.15.3128105', 'ASCII:Guape;ID:6321409', '9402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9402', '112', '11279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11280', '1079', '1', 'Guaraciaba', 'BR.15.3128204', 'ASCII:Guaraciaba;ID:6321410', '9403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9403', '112', '11280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11281', '1079', '1', 'Guaraciama', 'BR.15.3128253', 'ASCII:Guaraciama;ID:6321411', '9404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9404', '112', '11281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11282', '1079', '1', 'Guaranésia', 'BR.15.3128303', 'ASCII:Guaranesia;ID:6321412', '9405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9405', '112', '11282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11283', '1079', '1', 'Guarani', 'BR.15.3128402', 'ASCII:Guarani;ID:6321413', '9406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9406', '112', '11283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11284', '1079', '1', 'Guarará', 'BR.15.3128501', 'ASCII:Guarara;ID:6321414', '9407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9407', '112', '11284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11285', '1079', '1', 'Guarda-Mor', 'BR.15.3128600', 'ASCII:Guarda-Mor;ID:6321415', '9408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9408', '112', '11285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11286', '1079', '1', 'Guaxupé', 'BR.15.3128709', 'ASCII:Guaxupe;ID:6321416', '9409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9409', '112', '11286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3128709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11287', '1079', '1', 'Guiricema', 'BR.15.3129004', 'ASCII:Guiricema;ID:6321417', '9410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9410', '112', '11287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11288', '1079', '1', 'Gurinhatã', 'BR.15.3129103', 'ASCII:Gurinhata;ID:6321418', '9411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9411', '112', '11288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11289', '1079', '1', 'Heliodora', 'BR.15.3129202', 'ASCII:Heliodora;ID:6321419', '9412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9412', '112', '11289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11290', '1079', '1', 'Iapu', 'BR.15.3129301', 'ASCII:Iapu;ID:6321420', '9413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9413', '112', '11290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11291', '1079', '1', 'Ibertioga', 'BR.15.3129400', 'ASCII:Ibertioga;ID:6321421', '9414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9414', '112', '11291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11292', '1079', '1', 'Ibiá', 'BR.15.3129509', 'ASCII:Ibia;ID:6321422', '9415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9415', '112', '11292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11293', '1079', '1', 'Ibiaí', 'BR.15.3129608', 'ASCII:Ibiai;ID:6321423', '9416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9416', '112', '11293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11294', '1079', '1', 'Ibiracatu', 'BR.15.3129657', 'ASCII:Ibiracatu;ID:6321424', '9417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9417', '112', '11294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11295', '1079', '1', 'Ibiraci', 'BR.15.3129707', 'ASCII:Ibiraci;ID:6321425', '9418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9418', '112', '11295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11296', '1079', '1', 'Ibirité', 'BR.15.3129806', 'ASCII:Ibirite;ID:6321426', '9419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9419', '112', '11296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11297', '1079', '1', 'Ibitiúra de Minas', 'BR.15.3129905', 'ASCII:Ibitiura De Minas;ID:6321427', '9420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9420', '112', '11297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3129905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11298', '1079', '1', 'Ibituruna', 'BR.15.3130002', 'ASCII:Ibituruna;ID:6321428', '9421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9421', '112', '11298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11299', '1079', '1', 'Icaraí de Minas', 'BR.15.3130051', 'ASCII:Icarai De Minas;ID:6321429', '9422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9422', '112', '11299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11300', '1079', '1', 'Igarapé', 'BR.15.3130101', 'ASCII:Igarape;ID:6321430', '9423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9423', '112', '11300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11301', '1079', '1', 'Igaratinga', 'BR.15.3130200', 'ASCII:Igaratinga;ID:6321431', '9424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9424', '112', '11301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11302', '1079', '1', 'Iguatama', 'BR.15.3130309', 'ASCII:Iguatama;ID:6321432', '9425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9425', '112', '11302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11303', '1079', '1', 'Ijaci', 'BR.15.3130408', 'ASCII:Ijaci;ID:6321433', '9426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9426', '112', '11303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11304', '1079', '1', 'Ilicínea', 'BR.15.3130507', 'ASCII:Ilicinea;ID:6321434', '9427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9427', '112', '11304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11305', '1079', '1', 'Imbé de Minas', 'BR.15.3130556', 'ASCII:Imbe De Minas;ID:6321435', '9428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9428', '112', '11305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11306', '1079', '1', 'Inconfidentes', 'BR.15.3130606', 'ASCII:Inconfidentes;ID:6321436', '9429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9429', '112', '11306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11307', '1079', '1', 'Indaiabira', 'BR.15.3130655', 'ASCII:Indaiabira;ID:6321437', '9430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9430', '112', '11307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11308', '1079', '1', 'Indianópolis', 'BR.15.3130705', 'ASCII:Indianopolis;ID:6321438', '9431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9431', '112', '11308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11309', '1079', '1', 'Ingaí', 'BR.15.3130804', 'ASCII:Ingai;ID:6321439', '9432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9432', '112', '11309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11310', '1079', '1', 'Inhapim', 'BR.15.3130903', 'ASCII:Inhapim;ID:6321440', '9433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9433', '112', '11310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3130903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11311', '1079', '1', 'Inhaúma', 'BR.15.3131000', 'ASCII:Inhauma;ID:6321441', '9434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9434', '112', '11311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11312', '1079', '1', 'Inimutaba', 'BR.15.3131109', 'ASCII:Inimutaba;ID:6321442', '9435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9435', '112', '11312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11313', '1079', '1', 'Ipaba', 'BR.15.3131158', 'ASCII:Ipaba;ID:6321443', '9436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9436', '112', '11313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11314', '1079', '1', 'Ipatinga', 'BR.15.3131307', 'ASCII:Ipatinga;ID:6321444', '9437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9437', '112', '11314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11315', '1079', '1', 'Ipiaçu', 'BR.15.3131406', 'ASCII:Ipiacu;ID:6321445', '9438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9438', '112', '11315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11316', '1079', '1', 'Ipuiúna', 'BR.15.3131505', 'ASCII:Ipuiuna;ID:6321446', '9439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9439', '112', '11316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11317', '1079', '1', 'Iraí de Minas', 'BR.15.3131604', 'ASCII:Irai De Minas;ID:6321447', '9440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9440', '112', '11317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11318', '1079', '1', 'Itabira', 'BR.15.3131703', 'ASCII:Itabira;ID:6321448', '9441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9441', '112', '11318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11319', '1079', '1', 'Itabirinha de Mantena', 'BR.15.3131802', 'ASCII:Itabirinha De Mantena;ID:6321449', '9442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9442', '112', '11319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11320', '1079', '1', 'Itabirito', 'BR.15.3131901', 'ASCII:Itabirito;ID:6321450', '9443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9443', '112', '11320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11321', '1079', '1', 'Itacambira', 'BR.15.3132008', 'ASCII:Itacambira;ID:6321451', '9444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9444', '112', '11321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3132008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11322', '1079', '1', 'Itacarambi', 'BR.15.3132107', 'ASCII:Itacarambi;ID:6321452', '9445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9445', '112', '11322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3132107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11323', '1079', '1', 'Itaguara', 'BR.15.3132206', 'ASCII:Itaguara;ID:6321453', '9446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9446', '112', '11323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3132206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11324', '1079', '1', 'Itaipé', 'BR.15.3132305', 'ASCII:Itaipe;ID:6321454', '9447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9447', '112', '11324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3132305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11325', '1079', '1', 'Itajubá', 'BR.15.3132404', 'ASCII:Itajuba;ID:6321455', '9448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9448', '112', '11325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3132404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11326', '1079', '1', 'Itamarandiba', 'BR.15.3132503', 'ASCII:Itamarandiba;ID:6321456', '9449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9449', '112', '11326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3132503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11327', '1079', '1', 'Itamarati de Minas', 'BR.15.3132602', 'ASCII:Itamarati De Minas;ID:6321457', '9450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9450', '112', '11327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3132602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11328', '1079', '1', 'Itambacuri', 'BR.15.3132701', 'ASCII:Itambacuri;ID:6321458', '9451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9451', '112', '11328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3132701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11329', '1079', '1', 'Itambé do Mato Dentro', 'BR.15.3132800', 'ASCII:Itambe Do Mato Dentro;ID:6321459', '9452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9452', '112', '11329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3132800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11330', '1079', '1', 'Itamogi', 'BR.15.3132909', 'ASCII:Itamogi;ID:6321460', '9453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9453', '112', '11330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3132909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11331', '1079', '1', 'Itamonte', 'BR.15.3133006', 'ASCII:Itamonte;ID:6321461', '9454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9454', '112', '11331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11332', '1079', '1', 'Itanhandu', 'BR.15.3133105', 'ASCII:Itanhandu;ID:6321462', '9455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9455', '112', '11332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11333', '1079', '1', 'Itanhomi', 'BR.15.3133204', 'ASCII:Itanhomi;ID:6321463', '9456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9456', '112', '11333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11334', '1079', '1', 'Itaobim', 'BR.15.3133303', 'ASCII:Itaobim;ID:6321464', '9457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9457', '112', '11334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11335', '1079', '1', 'Itapagipe', 'BR.15.3133402', 'ASCII:Itapagipe;ID:6321465', '9458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9458', '112', '11335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11336', '1079', '1', 'Itapecerica', 'BR.15.3133501', 'ASCII:Itapecerica;ID:6321466', '9459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9459', '112', '11336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11337', '1079', '1', 'Itapeva', 'BR.15.3133600', 'ASCII:Itapeva;ID:6321467', '9460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9460', '112', '11337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11338', '1079', '1', 'Itatiaiuçu', 'BR.15.3133709', 'ASCII:Itatiaiucu;ID:6321468', '9461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9461', '112', '11338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11339', '1079', '1', 'Itaú de Minas', 'BR.15.3133758', 'ASCII:Itau De Minas;ID:6321469', '9462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9462', '112', '11339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11340', '1079', '1', 'Itaúna', 'BR.15.3133808', 'ASCII:Itauna;ID:6321470', '9463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9463', '112', '11340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11341', '1079', '1', 'Itaverava', 'BR.15.3133907', 'ASCII:Itaverava;ID:6321471', '9464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9464', '112', '11341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3133907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11342', '1079', '1', 'Itinga', 'BR.15.3134004', 'ASCII:Itinga;ID:6321472', '9465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9465', '112', '11342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3134004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11343', '1079', '1', 'Itueta', 'BR.15.3134103', 'ASCII:Itueta;ID:6321473', '9466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9466', '112', '11343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3134103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11344', '1079', '1', 'Ituiutaba', 'BR.15.3134202', 'ASCII:Ituiutaba;ID:6321474', '9467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9467', '112', '11344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3134202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11345', '1079', '1', 'Itumirim', 'BR.15.3134301', 'ASCII:Itumirim;ID:6321475', '9468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9468', '112', '11345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3134301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11346', '1079', '1', 'Iturama', 'BR.15.3134400', 'ASCII:Iturama;ID:6321476', '9469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9469', '112', '11346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3134400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11347', '1079', '1', 'Itutinga', 'BR.15.3134509', 'ASCII:Itutinga;ID:6321477', '9470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9470', '112', '11347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3134509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11348', '1079', '1', 'Jaboticatubas', 'BR.15.3134608', 'ASCII:Jaboticatubas;ID:6321478', '9471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9471', '112', '11348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3134608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11349', '1079', '1', 'Jacinto', 'BR.15.3134707', 'ASCII:Jacinto;ID:6321479', '9472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9472', '112', '11349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3134707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11350', '1079', '1', 'Jacuí', 'BR.15.3134806', 'ASCII:Jacui;ID:6321480', '9473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9473', '112', '11350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3134806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11351', '1079', '1', 'Jacutinga', 'BR.15.3134905', 'ASCII:Jacutinga;ID:6321481', '9474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9474', '112', '11351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3134905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11352', '1079', '1', 'Jaguaraçu', 'BR.15.3135001', 'ASCII:Jaguaracu;ID:6321482', '9475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9475', '112', '11352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11353', '1079', '1', 'Jaíba', 'BR.15.3135050', 'ASCII:Jaiba;ID:6321483', '9476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9476', '112', '11353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11354', '1079', '1', 'Jampruca', 'BR.15.3135076', 'ASCII:Jampruca;ID:6321484', '9477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9477', '112', '11354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11355', '1079', '1', 'Janaúba', 'BR.15.3135100', 'ASCII:Janauba;ID:6321485', '9478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9478', '112', '11355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11356', '1079', '1', 'Januária', 'BR.15.3135209', 'ASCII:Januaria;ID:6321486', '9479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9479', '112', '11356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11357', '1079', '1', 'Japaraíba', 'BR.15.3135308', 'ASCII:Japaraiba;ID:6321487', '9480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9480', '112', '11357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11358', '1079', '1', 'Japonvar', 'BR.15.3135357', 'ASCII:Japonvar;ID:6321488', '9481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9481', '112', '11358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11359', '1079', '1', 'Jeceaba', 'BR.15.3135407', 'ASCII:Jeceaba;ID:6321489', '9482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9482', '112', '11359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11360', '1079', '1', 'Jenipapo de Minas', 'BR.15.3135456', 'ASCII:Jenipapo De Minas;ID:6321490', '9483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9483', '112', '11360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11361', '1079', '1', 'Jequeri', 'BR.15.3135506', 'ASCII:Jequeri;ID:6321491', '9484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9484', '112', '11361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11362', '1079', '1', 'Jequitaí', 'BR.15.3135605', 'ASCII:Jequitai;ID:6321492', '9485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9485', '112', '11362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11363', '1079', '1', 'Jequitibá', 'BR.15.3135704', 'ASCII:Jequitiba;ID:6321493', '9486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9486', '112', '11363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11364', '1079', '1', 'Jequitinhonha', 'BR.15.3135803', 'ASCII:Jequitinhonha;ID:6321494', '9487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9487', '112', '11364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11365', '1079', '1', 'Jesuânia', 'BR.15.3135902', 'ASCII:Jesuania;ID:6321495', '9488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9488', '112', '11365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3135902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11366', '1079', '1', 'Joaíma', 'BR.15.3136009', 'ASCII:Joaima;ID:6321496', '9489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9489', '112', '11366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11367', '1079', '1', 'Joanésia', 'BR.15.3136108', 'ASCII:Joanesia;ID:6321497', '9490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9490', '112', '11367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11368', '1079', '1', 'João Monlevade', 'BR.15.3136207', 'ASCII:Joao Monlevade;ID:6321498', '9491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9491', '112', '11368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11369', '1079', '1', 'João Pinheiro', 'BR.15.3136306', 'ASCII:Joao Pinheiro;ID:6321499', '9492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9492', '112', '11369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11370', '1079', '1', 'Joaquim Felício', 'BR.15.3136405', 'ASCII:Joaquim Felicio;ID:6321500', '9493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9493', '112', '11370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11371', '1079', '1', 'Jordânia', 'BR.15.3136504', 'ASCII:Jordania;ID:6321501', '9494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9494', '112', '11371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11372', '1079', '1', 'José Gonçalves de Minas', 'BR.15.3136520', 'ASCII:Jose Goncalves De Minas;ID:6321502', '9495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9495', '112', '11372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11373', '1079', '1', 'José Raydan', 'BR.15.3136553', 'ASCII:Jose Raydan;ID:6321503', '9496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9496', '112', '11373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11374', '1079', '1', 'Josenópolis', 'BR.15.3136579', 'ASCII:Josenopolis;ID:6321504', '9497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9497', '112', '11374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11375', '1079', '1', 'Nova União', 'BR.15.3136603', 'ASCII:Nova Uniao;ID:6321505', '9498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9498', '112', '11375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11376', '1079', '1', 'Juatuba', 'BR.15.3136652', 'ASCII:Juatuba;ID:6321506', '9499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9499', '112', '11376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11377', '1079', '1', 'Juramento', 'BR.15.3136801', 'ASCII:Juramento;ID:6321507', '9500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9500', '112', '11377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11378', '1079', '1', 'Juruaia', 'BR.15.3136900', 'ASCII:Juruaia;ID:6321508', '9501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9501', '112', '11378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11379', '1079', '1', 'Juvenília', 'BR.15.3136959', 'ASCII:Juvenilia;ID:6321509', '9502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9502', '112', '11379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3136959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11380', '1079', '1', 'Ladainha', 'BR.15.3137007', 'ASCII:Ladainha;ID:6321510', '9503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9503', '112', '11380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11381', '1079', '1', 'Lagamar', 'BR.15.3137106', 'ASCII:Lagamar;ID:6321511', '9504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9504', '112', '11381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11382', '1079', '1', 'Lagoa da Prata', 'BR.15.3137205', 'ASCII:Lagoa Da Prata;ID:6321512', '9505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9505', '112', '11382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11383', '1079', '1', 'Lagoa dos Patos', 'BR.15.3137304', 'ASCII:Lagoa Dos Patos;ID:6321513', '9506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9506', '112', '11383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11384', '1079', '1', 'Lagoa Dourada', 'BR.15.3137403', 'ASCII:Lagoa Dourada;ID:6321514', '9507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9507', '112', '11384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11385', '1079', '1', 'Lagoa Formosa', 'BR.15.3137502', 'ASCII:Lagoa Formosa;ID:6321515', '9508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9508', '112', '11385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11386', '1079', '1', 'Lagoa Grande', 'BR.15.3137536', 'ASCII:Lagoa Grande;ID:6321516', '9509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9509', '112', '11386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11387', '1079', '1', 'Lagoa Santa', 'BR.15.3137601', 'ASCII:Lagoa Santa;ID:6321517', '9510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9510', '112', '11387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11388', '1079', '1', 'Lajinha', 'BR.15.3137700', 'ASCII:Lajinha;ID:6321518', '9511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9511', '112', '11388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11389', '1079', '1', 'Lambari', 'BR.15.3137809', 'ASCII:Lambari;ID:6321519', '9512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9512', '112', '11389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11390', '1079', '1', 'Lamim', 'BR.15.3137908', 'ASCII:Lamim;ID:6321520', '9513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9513', '112', '11390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3137908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11391', '1079', '1', 'Laranjal', 'BR.15.3138005', 'ASCII:Laranjal;ID:6321521', '9514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9514', '112', '11391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11392', '1079', '1', 'Lassance', 'BR.15.3138104', 'ASCII:Lassance;ID:6321522', '9515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9515', '112', '11392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11393', '1079', '1', 'Lavras', 'BR.15.3138203', 'ASCII:Lavras;ID:6321523', '9516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9516', '112', '11393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11394', '1079', '1', 'Leandro Ferreira', 'BR.15.3138302', 'ASCII:Leandro Ferreira;ID:6321524', '9517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9517', '112', '11394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11395', '1079', '1', 'Leme do Prado', 'BR.15.3138351', 'ASCII:Leme Do Prado;ID:6321525', '9518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9518', '112', '11395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11396', '1079', '1', 'Leopoldina', 'BR.15.3138401', 'ASCII:Leopoldina;ID:6321526', '9519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9519', '112', '11396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11397', '1079', '1', 'Liberdade', 'BR.15.3138500', 'ASCII:Liberdade;ID:6321527', '9520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9520', '112', '11397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11398', '1079', '1', 'Lima Duarte', 'BR.15.3138609', 'ASCII:Lima Duarte;ID:6321528', '9521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9521', '112', '11398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11399', '1079', '1', 'Limeira do Oeste', 'BR.15.3138625', 'ASCII:Limeira Do Oeste;ID:6321529', '9522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9522', '112', '11399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11400', '1079', '1', 'Lontra', 'BR.15.3138658', 'ASCII:Lontra;ID:6321530', '9523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9523', '112', '11400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11401', '1079', '1', 'Luisburgo', 'BR.15.3138674', 'ASCII:Luisburgo;ID:6321531', '9524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9524', '112', '11401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11402', '1079', '1', 'Luislândia', 'BR.15.3138682', 'ASCII:Luislandia;ID:6321532', '9525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9525', '112', '11402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11403', '1079', '1', 'Luminárias', 'BR.15.3138708', 'ASCII:Luminarias;ID:6321533', '9526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9526', '112', '11403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11404', '1079', '1', 'Luz', 'BR.15.3138807', 'ASCII:Luz;ID:6321534', '9527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9527', '112', '11404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11405', '1079', '1', 'Machacalis', 'BR.15.3138906', 'ASCII:Machacalis;ID:6321535', '9528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9528', '112', '11405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3138906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11406', '1079', '1', 'Madre de Deus de Minas', 'BR.15.3139102', 'ASCII:Madre De Deus De Minas;ID:6321536', '9529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9529', '112', '11406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11407', '1079', '1', 'Malacacheta', 'BR.15.3139201', 'ASCII:Malacacheta;ID:6321537', '9530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9530', '112', '11407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11408', '1079', '1', 'Mamonas', 'BR.15.3139250', 'ASCII:Mamonas;ID:6321538', '9531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9531', '112', '11408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11409', '1079', '1', 'Manga', 'BR.15.3139300', 'ASCII:Manga;ID:6321539', '9532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9532', '112', '11409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11410', '1079', '1', 'Manhuaçu', 'BR.15.3139409', 'ASCII:Manhuacu;ID:6321540', '9533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9533', '112', '11410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11411', '1079', '1', 'Manhumirim', 'BR.15.3139508', 'ASCII:Manhumirim;ID:6321541', '9534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9534', '112', '11411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11412', '1079', '1', 'Mantena', 'BR.15.3139607', 'ASCII:Mantena;ID:6321542', '9535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9535', '112', '11412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11413', '1079', '1', 'Maravilhas', 'BR.15.3139706', 'ASCII:Maravilhas;ID:6321543', '9536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9536', '112', '11413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11414', '1079', '1', 'Maria da Fé', 'BR.15.3139904', 'ASCII:Maria Da Fe;ID:6321544', '9537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9537', '112', '11414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11415', '1079', '1', 'Mariana', 'BR.15.3140001', 'ASCII:Mariana;ID:6321545', '9538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9538', '112', '11415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11416', '1079', '1', 'Marilac', 'BR.15.3140100', 'ASCII:Marilac;ID:6321546', '9539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9539', '112', '11416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11417', '1079', '1', 'Mário Campos', 'BR.15.3140159', 'ASCII:Mario Campos;ID:6321547', '9540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9540', '112', '11417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11418', '1079', '1', 'Maripá de Minas', 'BR.15.3140209', 'ASCII:Maripa De Minas;ID:6321548', '9541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9541', '112', '11418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11419', '1079', '1', 'Marliéria', 'BR.15.3140308', 'ASCII:Marlieria;ID:6321549', '9542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9542', '112', '11419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11420', '1079', '1', 'Marmelópolis', 'BR.15.3140407', 'ASCII:Marmelopolis;ID:6321550', '9543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9543', '112', '11420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11421', '1079', '1', 'Martinho Campos', 'BR.15.3140506', 'ASCII:Martinho Campos;ID:6321551', '9544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9544', '112', '11421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11422', '1079', '1', 'Martins Soares', 'BR.15.3140530', 'ASCII:Martins Soares;ID:6321552', '9545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9545', '112', '11422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11423', '1079', '1', 'Mata Verde', 'BR.15.3140555', 'ASCII:Mata Verde;ID:6321553', '9546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9546', '112', '11423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11424', '1079', '1', 'Materlândia', 'BR.15.3140605', 'ASCII:Materlandia;ID:6321554', '9547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9547', '112', '11424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11425', '1079', '1', 'Mateus Leme', 'BR.15.3140704', 'ASCII:Mateus Leme;ID:6321555', '9548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9548', '112', '11425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11426', '1079', '1', 'Matias Cardoso', 'BR.15.3140852', 'ASCII:Matias Cardoso;ID:6321556', '9549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9549', '112', '11426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11427', '1079', '1', 'Matipó', 'BR.15.3140902', 'ASCII:Matipo;ID:6321557', '9550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9550', '112', '11427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3140902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11428', '1079', '1', 'Mato Verde', 'BR.15.3141009', 'ASCII:Mato Verde;ID:6321558', '9551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9551', '112', '11428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3141009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11429', '1079', '1', 'Matozinhos', 'BR.15.3141108', 'ASCII:Matozinhos;ID:6321559', '9552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9552', '112', '11429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3141108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11430', '1079', '1', 'Matutina', 'BR.15.3141207', 'ASCII:Matutina;ID:6321560', '9553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9553', '112', '11430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3141207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11431', '1079', '1', 'Medeiros', 'BR.15.3141306', 'ASCII:Medeiros;ID:6321561', '9554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9554', '112', '11431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3141306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11432', '1079', '1', 'Medina', 'BR.15.3141405', 'ASCII:Medina;ID:6321562', '9555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9555', '112', '11432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3141405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11433', '1079', '1', 'Mendes Pimentel', 'BR.15.3141504', 'ASCII:Mendes Pimentel;ID:6321563', '9556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9556', '112', '11433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3141504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11434', '1079', '1', 'Mercês', 'BR.15.3141603', 'ASCII:Merces;ID:6321564', '9557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9557', '112', '11434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3141603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11435', '1079', '1', 'Mesquita', 'BR.15.3141702', 'ASCII:Mesquita;ID:6321565', '9558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9558', '112', '11435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3141702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11436', '1079', '1', 'Minas Novas', 'BR.15.3141801', 'ASCII:Minas Novas;ID:6321566', '9559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9559', '112', '11436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3141801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11437', '1079', '1', 'Minduri', 'BR.15.3141900', 'ASCII:Minduri;ID:6321567', '9560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9560', '112', '11437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3141900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11438', '1079', '1', 'Mirabela', 'BR.15.3142007', 'ASCII:Mirabela;ID:6321568', '9561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9561', '112', '11438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11439', '1079', '1', 'Miradouro', 'BR.15.3142106', 'ASCII:Miradouro;ID:6321569', '9562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9562', '112', '11439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11440', '1079', '1', 'Miraí', 'BR.15.3142205', 'ASCII:Mirai;ID:6321570', '9563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9563', '112', '11440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11441', '1079', '1', 'Miravânia', 'BR.15.3142254', 'ASCII:Miravania;ID:6321571', '9564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9564', '112', '11441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11442', '1079', '1', 'Moeda', 'BR.15.3142304', 'ASCII:Moeda;ID:6321572', '9565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9565', '112', '11442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11443', '1079', '1', 'Moema', 'BR.15.3142403', 'ASCII:Moema;ID:6321573', '9566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9566', '112', '11443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11444', '1079', '1', 'Monjolos', 'BR.15.3142502', 'ASCII:Monjolos;ID:6321574', '9567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9567', '112', '11444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11445', '1079', '1', 'Monsenhor Paulo', 'BR.15.3142601', 'ASCII:Monsenhor Paulo;ID:6321575', '9568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9568', '112', '11445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11446', '1079', '1', 'Montalvânia', 'BR.15.3142700', 'ASCII:Montalvania;ID:6321576', '9569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9569', '112', '11446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11447', '1079', '1', 'Monte Alegre de Minas', 'BR.15.3142809', 'ASCII:Monte Alegre De Minas;ID:6321577', '9570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9570', '112', '11447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11448', '1079', '1', 'Monte Azul', 'BR.15.3142908', 'ASCII:Monte Azul;ID:6321578', '9571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9571', '112', '11448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3142908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11449', '1079', '1', 'Monte Belo', 'BR.15.3143005', 'ASCII:Monte Belo;ID:6321579', '9572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9572', '112', '11449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11450', '1079', '1', 'Monte Carmelo', 'BR.15.3143104', 'ASCII:Monte Carmelo;ID:6321580', '9573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9573', '112', '11450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11451', '1079', '1', 'Monte Formoso', 'BR.15.3143153', 'ASCII:Monte Formoso;ID:6321581', '9574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9574', '112', '11451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11452', '1079', '1', 'Monte Santo de Minas', 'BR.15.3143203', 'ASCII:Monte Santo De Minas;ID:6321582', '9575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9575', '112', '11452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11453', '1079', '1', 'Montes Claros', 'BR.15.3143302', 'ASCII:Montes Claros;ID:6321583', '9576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9576', '112', '11453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11454', '1079', '1', 'Montezuma', 'BR.15.3143450', 'ASCII:Montezuma;ID:6321584', '9577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9577', '112', '11454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11455', '1079', '1', 'Morada Nova de Minas', 'BR.15.3143500', 'ASCII:Morada Nova De Minas;ID:6321585', '9578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9578', '112', '11455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11456', '1079', '1', 'Morro da Garça', 'BR.15.3143609', 'ASCII:Morro Da Garca;ID:6321586', '9579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9579', '112', '11456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11457', '1079', '1', 'Morro do Pilar', 'BR.15.3143708', 'ASCII:Morro Do Pilar;ID:6321587', '9580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9580', '112', '11457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11458', '1079', '1', 'Munhoz', 'BR.15.3143807', 'ASCII:Munhoz;ID:6321588', '9581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9581', '112', '11458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11459', '1079', '1', 'Muriaé', 'BR.15.3143906', 'ASCII:Muriae;ID:6321589', '9582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9582', '112', '11459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11460', '1079', '1', 'Mutum', 'BR.15.3144003', 'ASCII:Mutum;ID:6321590', '9583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9583', '112', '11460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11461', '1079', '1', 'Muzambinho', 'BR.15.3144102', 'ASCII:Muzambinho;ID:6321591', '9584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9584', '112', '11461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11462', '1079', '1', 'Nacip Raydan', 'BR.15.3144201', 'ASCII:Nacip Raydan;ID:6321592', '9585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9585', '112', '11462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11463', '1079', '1', 'Nanuque', 'BR.15.3144300', 'ASCII:Nanuque;ID:6321593', '9586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9586', '112', '11463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11464', '1079', '1', 'Naque', 'BR.15.3144359', 'ASCII:Naque;ID:6321594', '9587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9587', '112', '11464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11465', '1079', '1', 'Natalândia', 'BR.15.3144375', 'ASCII:Natalandia;ID:6321595', '9588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9588', '112', '11465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11466', '1079', '1', 'Natércia', 'BR.15.3144409', 'ASCII:Natercia;ID:6321596', '9589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9589', '112', '11466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11467', '1079', '1', 'Nazareno', 'BR.15.3144508', 'ASCII:Nazareno;ID:6321597', '9590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9590', '112', '11467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11468', '1079', '1', 'Nepomuceno', 'BR.15.3144607', 'ASCII:Nepomuceno;ID:6321598', '9591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9591', '112', '11468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11469', '1079', '1', 'Ninheira', 'BR.15.3144656', 'ASCII:Ninheira;ID:6321599', '9592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9592', '112', '11469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11470', '1079', '1', 'Nova Belém', 'BR.15.3144672', 'ASCII:Nova Belem;ID:6321600', '9593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9593', '112', '11470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11471', '1079', '1', 'Nova Era', 'BR.15.3144706', 'ASCII:Nova Era;ID:6321601', '9594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9594', '112', '11471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11472', '1079', '1', 'Nova Lima', 'BR.15.3144805', 'ASCII:Nova Lima;ID:6321602', '9595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9595', '112', '11472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11473', '1079', '1', 'Nova Módica', 'BR.15.3144904', 'ASCII:Nova Modica;ID:6321603', '9596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9596', '112', '11473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3144904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11474', '1079', '1', 'Nova Ponte', 'BR.15.3145000', 'ASCII:Nova Ponte;ID:6321604', '9597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9597', '112', '11474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11475', '1079', '1', 'Nova Porteirinha', 'BR.15.3145059', 'ASCII:Nova Porteirinha;ID:6321605', '9598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9598', '112', '11475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11476', '1079', '1', 'Nova Resende', 'BR.15.3145109', 'ASCII:Nova Resende;ID:6321606', '9599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9599', '112', '11476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11477', '1079', '1', 'Nova Serrana', 'BR.15.3145208', 'ASCII:Nova Serrana;ID:6321607', '9600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9600', '112', '11477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11478', '1079', '1', 'Novo Cruzeiro', 'BR.15.3145307', 'ASCII:Novo Cruzeiro;ID:6321608', '9601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9601', '112', '11478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11479', '1079', '1', 'Novo Oriente de Minas', 'BR.15.3145356', 'ASCII:Novo Oriente De Minas;ID:6321609', '9602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9602', '112', '11479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11480', '1079', '1', 'Novorizonte', 'BR.15.3145372', 'ASCII:Novorizonte;ID:6321610', '9603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9603', '112', '11480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145372» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11481', '1079', '1', 'Olaria', 'BR.15.3145406', 'ASCII:Olaria;ID:6321611', '9604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9604', '112', '11481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11482', '1079', '1', 'Olhos-d''Água', 'BR.15.3145455', 'ASCII:Olhos-D''Agua;ID:6321612', '9605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9605', '112', '11482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11483', '1079', '1', 'Olímpio Noronha', 'BR.15.3145505', 'ASCII:Olimpio Noronha;ID:6321613', '9606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9606', '112', '11483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11484', '1079', '1', 'Oliveira', 'BR.15.3145604', 'ASCII:Oliveira;ID:6321614', '9607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9607', '112', '11484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11485', '1079', '1', 'Oliveira Fortes', 'BR.15.3145703', 'ASCII:Oliveira Fortes;ID:6321615', '9608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9608', '112', '11485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11486', '1079', '1', 'Onça de Pitangui', 'BR.15.3145802', 'ASCII:Onca De Pitangui;ID:6321616', '9609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9609', '112', '11486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11487', '1079', '1', 'Oratórios', 'BR.15.3145851', 'ASCII:Oratorios;ID:6321617', '9610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9610', '112', '11487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11488', '1079', '1', 'Orizânia', 'BR.15.3145877', 'ASCII:Orizania;ID:6321618', '9611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9611', '112', '11488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145877» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11489', '1079', '1', 'Ouro Branco', 'BR.15.3145901', 'ASCII:Ouro Branco;ID:6321619', '9612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9612', '112', '11489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3145901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11490', '1079', '1', 'Ouro Preto', 'BR.15.3146107', 'ASCII:Ouro Preto;ID:6321620', '9613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9613', '112', '11490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11491', '1079', '1', 'Ouro Verde de Minas', 'BR.15.3146206', 'ASCII:Ouro Verde De Minas;ID:6321621', '9614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9614', '112', '11491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11492', '1079', '1', 'Padre Carvalho', 'BR.15.3146255', 'ASCII:Padre Carvalho;ID:6321622', '9615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9615', '112', '11492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11493', '1079', '1', 'Padre Paraíso', 'BR.15.3146305', 'ASCII:Padre Paraiso;ID:6321623', '9616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9616', '112', '11493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11494', '1079', '1', 'Paineiras', 'BR.15.3146404', 'ASCII:Paineiras;ID:6321624', '9617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9617', '112', '11494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11495', '1079', '1', 'Pains', 'BR.15.3146503', 'ASCII:Pains;ID:6321625', '9618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9618', '112', '11495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11496', '1079', '1', 'Pai Pedro', 'BR.15.3146552', 'ASCII:Pai Pedro;ID:6321626', '9619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9619', '112', '11496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11497', '1079', '1', 'Paiva', 'BR.15.3146602', 'ASCII:Paiva;ID:6321627', '9620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9620', '112', '11497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11498', '1079', '1', 'Palma', 'BR.15.3146701', 'ASCII:Palma;ID:6321628', '9621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9621', '112', '11498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11499', '1079', '1', 'Palmópolis', 'BR.15.3146750', 'ASCII:Palmopolis;ID:6321629', '9622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9622', '112', '11499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11500', '1079', '1', 'Papagaios', 'BR.15.3146909', 'ASCII:Papagaios;ID:6321630', '9623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9623', '112', '11500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3146909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11501', '1079', '1', 'Paracatu', 'BR.15.3147006', 'ASCII:Paracatu;ID:6321631', '9624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9624', '112', '11501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11502', '1079', '1', 'Pará de Minas', 'BR.15.3147105', 'ASCII:Para De Minas;ID:6321632', '9625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9625', '112', '11502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11503', '1079', '1', 'Paraguaçu', 'BR.15.3147204', 'ASCII:Paraguacu;ID:6321633', '9626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9626', '112', '11503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11504', '1079', '1', 'Paraisópolis', 'BR.15.3147303', 'ASCII:Paraisopolis;ID:6321634', '9627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9627', '112', '11504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11505', '1079', '1', 'Paraopeba', 'BR.15.3147402', 'ASCII:Paraopeba;ID:6321635', '9628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9628', '112', '11505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11506', '1079', '1', 'Passabém', 'BR.15.3147501', 'ASCII:Passabem;ID:6321636', '9629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9629', '112', '11506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11507', '1079', '1', 'Passa Quatro', 'BR.15.3147600', 'ASCII:Passa Quatro;ID:6321637', '9630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9630', '112', '11507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11508', '1079', '1', 'Passa Tempo', 'BR.15.3147709', 'ASCII:Passa Tempo;ID:6321638', '9631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9631', '112', '11508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11509', '1079', '1', 'Passa-Vinte', 'BR.15.3147808', 'ASCII:Passa Vinte;ID:6321639', '9632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9632', '112', '11509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11510', '1079', '1', 'Passos', 'BR.15.3147907', 'ASCII:Passos;ID:6321640', '9633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9633', '112', '11510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11511', '1079', '1', 'Patis', 'BR.15.3147956', 'ASCII:Patis;ID:6321641', '9634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9634', '112', '11511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3147956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11512', '1079', '1', 'Patos de Minas', 'BR.15.3148004', 'ASCII:Patos De Minas;ID:6321642', '9635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9635', '112', '11512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11513', '1079', '1', 'Patrocínio', 'BR.15.3148103', 'ASCII:Patrocinio;ID:6321643', '9636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9636', '112', '11513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11514', '1079', '1', 'Paula Cândido', 'BR.15.3148301', 'ASCII:Paula Candido;ID:6321644', '9637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9637', '112', '11514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11515', '1079', '1', 'Paulistas', 'BR.15.3148400', 'ASCII:Paulistas;ID:6321645', '9638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9638', '112', '11515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11516', '1079', '1', 'Pavão', 'BR.15.3148509', 'ASCII:Pavao;ID:6321646', '9639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9639', '112', '11516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11517', '1079', '1', 'Peçanha', 'BR.15.3148608', 'ASCII:Pecanha;ID:6321647', '9640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9640', '112', '11517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11518', '1079', '1', 'Pedra Azul', 'BR.15.3148707', 'ASCII:Pedra Azul;ID:6321648', '9641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9641', '112', '11518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11519', '1079', '1', 'Pedra Bonita', 'BR.15.3148756', 'ASCII:Pedra Bonita;ID:6321649', '9642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9642', '112', '11519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11520', '1079', '1', 'Pedra do Anta', 'BR.15.3148806', 'ASCII:Pedra Do Anta;ID:6321650', '9643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9643', '112', '11520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11521', '1079', '1', 'Pedra do Indaiá', 'BR.15.3148905', 'ASCII:Pedra Do Indaia;ID:6321651', '9644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9644', '112', '11521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3148905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11522', '1079', '1', 'Pedra Dourada', 'BR.15.3149002', 'ASCII:Pedra Dourada;ID:6321652', '9645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9645', '112', '11522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11523', '1079', '1', 'Pedralva', 'BR.15.3149101', 'ASCII:Pedralva;ID:6321653', '9646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9646', '112', '11523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11524', '1079', '1', 'Pedras de Maria da Cruz', 'BR.15.3149150', 'ASCII:Pedras De Maria Da Cruz;ID:6321654', '9647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9647', '112', '11524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11525', '1079', '1', 'Pedrinópolis', 'BR.15.3149200', 'ASCII:Pedrinopolis;ID:6321655', '9648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9648', '112', '11525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11526', '1079', '1', 'Pedro Leopoldo', 'BR.15.3149309', 'ASCII:Pedro Leopoldo;ID:6321656', '9649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9649', '112', '11526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11527', '1079', '1', 'Pedro Teixeira', 'BR.15.3149408', 'ASCII:Pedro Teixeira;ID:6321657', '9650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9650', '112', '11527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11528', '1079', '1', 'Pequeri', 'BR.15.3149507', 'ASCII:Pequeri;ID:6321658', '9651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9651', '112', '11528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11529', '1079', '1', 'Pequi', 'BR.15.3149606', 'ASCII:Pequi;ID:6321659', '9652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9652', '112', '11529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11530', '1079', '1', 'Perdigão', 'BR.15.3149705', 'ASCII:Perdigao;ID:6321660', '9653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9653', '112', '11530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11531', '1079', '1', 'Perdizes', 'BR.15.3149804', 'ASCII:Perdizes;ID:6321661', '9654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9654', '112', '11531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11532', '1079', '1', 'Perdões', 'BR.15.3149903', 'ASCII:Perdoes;ID:6321662', '9655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9655', '112', '11532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11533', '1079', '1', 'Periquito', 'BR.15.3149952', 'ASCII:Periquito;ID:6321663', '9656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9656', '112', '11533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3149952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11534', '1079', '1', 'Pescador', 'BR.15.3150000', 'ASCII:Pescador;ID:6321664', '9657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9657', '112', '11534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11535', '1079', '1', 'Piau', 'BR.15.3150109', 'ASCII:Piau;ID:6321665', '9658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9658', '112', '11535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11536', '1079', '1', 'Piedade de Caratinga', 'BR.15.3150158', 'ASCII:Piedade De Caratinga;ID:6321666', '9659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9659', '112', '11536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11537', '1079', '1', 'Piedade de Ponte Nova', 'BR.15.3150208', 'ASCII:Piedade De Ponte Nova;ID:6321667', '9660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9660', '112', '11537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11538', '1079', '1', 'Piedade do Rio Grande', 'BR.15.3150307', 'ASCII:Piedade Do Rio Grande;ID:6321668', '9661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9661', '112', '11538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11539', '1079', '1', 'Piedade dos Gerais', 'BR.15.3150406', 'ASCII:Piedade Dos Gerais;ID:6321669', '9662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9662', '112', '11539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11540', '1079', '1', 'Pimenta', 'BR.15.3150505', 'ASCII:Pimenta;ID:6321670', '9663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9663', '112', '11540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11541', '1079', '1', 'Pingo-d''Água', 'BR.15.3150539', 'ASCII:Pingo D''Agua;ID:6321671', '9664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9664', '112', '11541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11542', '1079', '1', 'Pintópolis', 'BR.15.3150570', 'ASCII:Pintopolis;ID:6321672', '9665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9665', '112', '11542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11543', '1079', '1', 'Piracema', 'BR.15.3150604', 'ASCII:Piracema;ID:6321673', '9666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9666', '112', '11543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11544', '1079', '1', 'Pirajuba', 'BR.15.3150703', 'ASCII:Pirajuba;ID:6321674', '9667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9667', '112', '11544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11545', '1079', '1', 'Piranga', 'BR.15.3150802', 'ASCII:Piranga;ID:6321675', '9668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9668', '112', '11545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11546', '1079', '1', 'Piranguçu', 'BR.15.3150901', 'ASCII:Pirangucu;ID:6321676', '9669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9669', '112', '11546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3150901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11547', '1079', '1', 'Piranguinho', 'BR.15.3151008', 'ASCII:Piranguinho;ID:6321677', '9670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9670', '112', '11547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3151008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11548', '1079', '1', 'Pirapetinga', 'BR.15.3151107', 'ASCII:Pirapetinga;ID:6321678', '9671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9671', '112', '11548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3151107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11549', '1079', '1', 'Pirapora', 'BR.15.3151206', 'ASCII:Pirapora;ID:6321679', '9672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9672', '112', '11549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3151206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11550', '1079', '1', 'Piraúba', 'BR.15.3151305', 'ASCII:Pirauba;ID:6321680', '9673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9673', '112', '11550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3151305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11551', '1079', '1', 'Pitangui', 'BR.15.3151404', 'ASCII:Pitangui;ID:6321681', '9674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9674', '112', '11551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3151404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11552', '1079', '1', 'Piumhi', 'BR.15.3151503', 'ASCII:Piui;ID:6321682', '9675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9675', '112', '11552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3151503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11553', '1079', '1', 'Planura', 'BR.15.3151602', 'ASCII:Planura;ID:6321683', '9676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9676', '112', '11553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3151602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11554', '1079', '1', 'Poço Fundo', 'BR.15.3151701', 'ASCII:Poco Fundo;ID:6321684', '9677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9677', '112', '11554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3151701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11555', '1079', '1', 'Poços de Caldas', 'BR.15.3151800', 'ASCII:Pocos De Caldas;ID:6321685', '9678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9678', '112', '11555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3151800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11556', '1079', '1', 'Pocrane', 'BR.15.3151909', 'ASCII:Pocrane;ID:6321686', '9679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9679', '112', '11556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3151909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11557', '1079', '1', 'Pompéu', 'BR.15.3152006', 'ASCII:Pompeu;ID:6321687', '9680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9680', '112', '11557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11558', '1079', '1', 'Ponte Nova', 'BR.15.3152105', 'ASCII:Ponte Nova;ID:6321688', '9681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9681', '112', '11558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11559', '1079', '1', 'Ponto Chique', 'BR.15.3152131', 'ASCII:Ponto Chique;ID:6321689', '9682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9682', '112', '11559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11560', '1079', '1', 'Ponto dos Volantes', 'BR.15.3152170', 'ASCII:Ponto Dos Volantes;ID:6321690', '9683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9683', '112', '11560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11561', '1079', '1', 'Porteirinha', 'BR.15.3152204', 'ASCII:Porteirinha;ID:6321691', '9684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9684', '112', '11561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11562', '1079', '1', 'Porto Firme', 'BR.15.3152303', 'ASCII:Porto Firme;ID:6321692', '9685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9685', '112', '11562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11563', '1079', '1', 'Poté', 'BR.15.3152402', 'ASCII:Pote;ID:6321693', '9686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9686', '112', '11563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11564', '1079', '1', 'Pouso Alegre', 'BR.15.3152501', 'ASCII:Pouso Alegre;ID:6321694', '9687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9687', '112', '11564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11565', '1079', '1', 'Pouso Alto', 'BR.15.3152600', 'ASCII:Pouso Alto;ID:6321695', '9688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9688', '112', '11565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11566', '1079', '1', 'Prados', 'BR.15.3152709', 'ASCII:Prados;ID:6321696', '9689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9689', '112', '11566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11567', '1079', '1', 'Pratápolis', 'BR.15.3152907', 'ASCII:Pratapolis;ID:6321697', '9690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9690', '112', '11567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11568', '1079', '1', 'Pratinha', 'BR.15.3153004', 'ASCII:Pratinha;ID:6321698', '9691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9691', '112', '11568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3153004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11569', '1079', '1', 'Presidente Bernardes', 'BR.15.3153103', 'ASCII:Presidente Bernardes;ID:6321699', '9692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9692', '112', '11569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3153103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11570', '1079', '1', 'Presidente Juscelino', 'BR.15.3153202', 'ASCII:Presidente Juscelino;ID:6321700', '9693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9693', '112', '11570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3153202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11571', '1079', '1', 'Presidente Kubitschek', 'BR.15.3153301', 'ASCII:Presidente Kubitschek;ID:6321701', '9694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9694', '112', '11571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3153301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11572', '1079', '1', 'Presidente Olegário', 'BR.15.3153400', 'ASCII:Presidente Olegario;ID:6321702', '9695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9695', '112', '11572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3153400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11573', '1079', '1', 'Alto Jequitibá', 'BR.15.3153509', 'ASCII:Alto Jequitiba;ID:6321703', '9696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9696', '112', '11573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3153509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11574', '1079', '1', 'Prudente de Morais', 'BR.15.3153608', 'ASCII:Prudente De Morais;ID:6321704', '9697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9697', '112', '11574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3153608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11575', '1079', '1', 'Quartel Geral', 'BR.15.3153707', 'ASCII:Quartel Geral;ID:6321705', '9698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9698', '112', '11575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3153707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11576', '1079', '1', 'Queluzito', 'BR.15.3153806', 'ASCII:Queluzita;ID:6321706', '9699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9699', '112', '11576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3153806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11577', '1079', '1', 'Raposos', 'BR.15.3153905', 'ASCII:Raposos;ID:6321707', '9700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9700', '112', '11577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3153905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11578', '1079', '1', 'Raul Soares', 'BR.15.3154002', 'ASCII:Raul Soares;ID:6321708', '9701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9701', '112', '11578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11579', '1079', '1', 'Recreio', 'BR.15.3154101', 'ASCII:Recreio;ID:6321709', '9702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9702', '112', '11579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11580', '1079', '1', 'Reduto', 'BR.15.3154150', 'ASCII:Reduto;ID:6321710', '9703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9703', '112', '11580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11581', '1079', '1', 'Resende Costa', 'BR.15.3154200', 'ASCII:Resende Costa;ID:6321711', '9704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9704', '112', '11581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11582', '1079', '1', 'Resplendor', 'BR.15.3154309', 'ASCII:Resplendor;ID:6321712', '9705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9705', '112', '11582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11583', '1079', '1', 'Ressaquinha', 'BR.15.3154408', 'ASCII:Ressaquinha;ID:6321713', '9706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9706', '112', '11583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11584', '1079', '1', 'Riachinho', 'BR.15.3154457', 'ASCII:Riachinho;ID:6321714', '9707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9707', '112', '11584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11585', '1079', '1', 'Riacho dos Machados', 'BR.15.3154507', 'ASCII:Riacho Dos Machados;ID:6321715', '9708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9708', '112', '11585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11586', '1079', '1', 'Ribeirão das Neves', 'BR.15.3154606', 'ASCII:Ribeirao Das Neves;ID:6321716', '9709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9709', '112', '11586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11587', '1079', '1', 'Ribeirão Vermelho', 'BR.15.3154705', 'ASCII:Ribeirao Vermelho;ID:6321717', '9710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9710', '112', '11587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11588', '1079', '1', 'Rio Acima', 'BR.15.3154804', 'ASCII:Rio Acima;ID:6321718', '9711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9711', '112', '11588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11589', '1079', '1', 'Rio Casca', 'BR.15.3154903', 'ASCII:Rio Casca;ID:6321719', '9712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9712', '112', '11589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3154903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11590', '1079', '1', 'Rio Doce', 'BR.15.3155009', 'ASCII:Rio Doce;ID:6321720', '9713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9713', '112', '11590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3155009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11591', '1079', '1', 'Rio do Prado', 'BR.15.3155108', 'ASCII:Rio Do Prado;ID:6321721', '9714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9714', '112', '11591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3155108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11592', '1079', '1', 'Rio Espera', 'BR.15.3155207', 'ASCII:Rio Espera;ID:6321722', '9715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9715', '112', '11592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3155207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11593', '1079', '1', 'Rio Manso', 'BR.15.3155306', 'ASCII:Rio Manso;ID:6321723', '9716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9716', '112', '11593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3155306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11594', '1079', '1', 'Rio Novo', 'BR.15.3155405', 'ASCII:Rio Novo;ID:6321724', '9717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9717', '112', '11594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3155405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11595', '1079', '1', 'Rio Paranaíba', 'BR.15.3155504', 'ASCII:Rio Paranaiba;ID:6321725', '9718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9718', '112', '11595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3155504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11596', '1079', '1', 'Rio Pardo de Minas', 'BR.15.3155603', 'ASCII:Rio Pardo De Minas;ID:6321726', '9719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9719', '112', '11596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3155603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11597', '1079', '1', 'Rio Piracicaba', 'BR.15.3155702', 'ASCII:Rio Piracicaba;ID:6321727', '9720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9720', '112', '11597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3155702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11598', '1079', '1', 'Rio Pomba', 'BR.15.3155801', 'ASCII:Rio Pomba;ID:6321728', '9721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9721', '112', '11598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3155801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11599', '1079', '1', 'Rio Preto', 'BR.15.3155900', 'ASCII:Rio Preto;ID:6321729', '9722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9722', '112', '11599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3155900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11600', '1079', '1', 'Rio Vermelho', 'BR.15.3156007', 'ASCII:Rio Vermelho;ID:6321730', '9723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9723', '112', '11600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11601', '1079', '1', 'Ritápolis', 'BR.15.3156106', 'ASCII:Ritapolis;ID:6321731', '9724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9724', '112', '11601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11602', '1079', '1', 'Rochedo de Minas', 'BR.15.3156205', 'ASCII:Rochedo De Minas;ID:6321732', '9725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9725', '112', '11602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11603', '1079', '1', 'Rodeiro', 'BR.15.3156304', 'ASCII:Rodeiro;ID:6321733', '9726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9726', '112', '11603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11604', '1079', '1', 'Romaria', 'BR.15.3156403', 'ASCII:Romaria;ID:6321734', '9727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9727', '112', '11604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11605', '1079', '1', 'Rosário da Limeira', 'BR.15.3156452', 'ASCII:Rosario Da Limeira;ID:6321735', '9728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9728', '112', '11605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11606', '1079', '1', 'Rubelita', 'BR.15.3156502', 'ASCII:Rubelita;ID:6321736', '9729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9729', '112', '11606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11607', '1079', '1', 'Rubim', 'BR.15.3156601', 'ASCII:Rubim;ID:6321737', '9730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9730', '112', '11607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11608', '1079', '1', 'Sabará', 'BR.15.3156700', 'ASCII:Sabara;ID:6321738', '9731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9731', '112', '11608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11609', '1079', '1', 'Sabinópolis', 'BR.15.3156809', 'ASCII:Sabinopolis;ID:6321739', '9732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9732', '112', '11609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11610', '1079', '1', 'Sacramento', 'BR.15.3156908', 'ASCII:Sacramento;ID:6321740', '9733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9733', '112', '11610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3156908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11611', '1079', '1', 'Salinas', 'BR.15.3157005', 'ASCII:Salinas;ID:6321741', '9734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9734', '112', '11611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11612', '1079', '1', 'Salto da Divisa', 'BR.15.3157104', 'ASCII:Salto Da Divisa;ID:6321742', '9735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9735', '112', '11612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11613', '1079', '1', 'Santa Bárbara', 'BR.15.3157203', 'ASCII:Santa Barbara;ID:6321743', '9736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9736', '112', '11613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11614', '1079', '1', 'Santa Bárbara do Leste', 'BR.15.3157252', 'ASCII:Santa Barbara Do Leste;ID:6321744', '9737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9737', '112', '11614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11615', '1079', '1', 'Santa Bárbara do Monte Verde', 'BR.15.3157278', 'ASCII:Santa Barbara Do Monte Verde;ID:6321745', '9738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9738', '112', '11615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11616', '1079', '1', 'Santa Cruz de Minas', 'BR.15.3157336', 'ASCII:Santa Cruz De Minas;ID:6321746', '9739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9739', '112', '11616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11617', '1079', '1', 'Santa Cruz de Salinas', 'BR.15.3157377', 'ASCII:Santa Cruz De Salinas;ID:6321747', '9740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9740', '112', '11617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11618', '1079', '1', 'Santa Cruz do Escalvado', 'BR.15.3157401', 'ASCII:Santa Cruz Do Escalvado;ID:6321748', '9741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9741', '112', '11618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11619', '1079', '1', 'Santa Efigênia de Minas', 'BR.15.3157500', 'ASCII:Santa Efigenia De Minas;ID:6321749', '9742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9742', '112', '11619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11620', '1079', '1', 'Santa Fé de Minas', 'BR.15.3157609', 'ASCII:Santa Fe De Minas;ID:6321750', '9743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9743', '112', '11620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11621', '1079', '1', 'Santa Helena de Minas', 'BR.15.3157658', 'ASCII:Santa Helena De Minas;ID:6321751', '9744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9744', '112', '11621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11622', '1079', '1', 'Santa Juliana', 'BR.15.3157708', 'ASCII:Santa Juliana;ID:6321752', '9745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9745', '112', '11622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11623', '1079', '1', 'Santa Luzia', 'BR.15.3157807', 'ASCII:Santa Luzia;ID:6321753', '9746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9746', '112', '11623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11624', '1079', '1', 'Santa Margarida', 'BR.15.3157906', 'ASCII:Santa Margarida;ID:6321754', '9747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9747', '112', '11624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3157906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11625', '1079', '1', 'Santa Maria de Itabira', 'BR.15.3158003', 'ASCII:Santa Maria De Itabira;ID:6321755', '9748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9748', '112', '11625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11626', '1079', '1', 'Santa Maria do Salto', 'BR.15.3158102', 'ASCII:Santa Maria Do Salto;ID:6321756', '9749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9749', '112', '11626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11627', '1079', '1', 'Santa Maria do Suaçuí', 'BR.15.3158201', 'ASCII:Santa Maria Do Suacui;ID:6321757', '9750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9750', '112', '11627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11628', '1079', '1', 'Santana da Vargem', 'BR.15.3158300', 'ASCII:Santana Da Vargem;ID:6321758', '9751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9751', '112', '11628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11629', '1079', '1', 'Santana de Cataguases', 'BR.15.3158409', 'ASCII:Santana De Cataguases;ID:6321759', '9752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9752', '112', '11629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11630', '1079', '1', 'Santana de Pirapama', 'BR.15.3158508', 'ASCII:Santana De Pirapama;ID:6321760', '9753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9753', '112', '11630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11631', '1079', '1', 'Santana do Deserto', 'BR.15.3158607', 'ASCII:Santana Do Deserto;ID:6321761', '9754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9754', '112', '11631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11632', '1079', '1', 'Santana do Garambéu', 'BR.15.3158706', 'ASCII:Santana Do Garambeu;ID:6321762', '9755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9755', '112', '11632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11633', '1079', '1', 'Santana do Jacaré', 'BR.15.3158805', 'ASCII:Santana Do Jacare;ID:6321763', '9756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9756', '112', '11633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11634', '1079', '1', 'Santana do Manhuaçu', 'BR.15.3158904', 'ASCII:Santana Do Manhuacu;ID:6321764', '9757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9757', '112', '11634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11635', '1079', '1', 'Santana do Paraíso', 'BR.15.3158953', 'ASCII:Santana Do Paraiso;ID:6321765', '9758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9758', '112', '11635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3158953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11636', '1079', '1', 'Santana do Riacho', 'BR.15.3159001', 'ASCII:Santana Do Riacho;ID:6321766', '9759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9759', '112', '11636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11637', '1079', '1', 'Santana dos Montes', 'BR.15.3159100', 'ASCII:Santana Dos Montes;ID:6321767', '9760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9760', '112', '11637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11638', '1079', '1', 'Santa Rita de Caldas', 'BR.15.3159209', 'ASCII:Santa Rita De Caldas;ID:6321768', '9761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9761', '112', '11638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11639', '1079', '1', 'Santa Rita de Jacutinga', 'BR.15.3159308', 'ASCII:Santa Rita De Jacutinga;ID:6321769', '9762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9762', '112', '11639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11640', '1079', '1', 'Santa Rita de Minas', 'BR.15.3159357', 'ASCII:Santa Rita De Minas;ID:6321770', '9763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9763', '112', '11640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11641', '1079', '1', 'Santa Rita de Ibitipoca', 'BR.15.3159407', 'ASCII:Santa Rita De Ibitipoca;ID:6321771', '9764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9764', '112', '11641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11642', '1079', '1', 'Santa Rita do Itueto', 'BR.15.3159506', 'ASCII:Santa Rita Do Itueto;ID:6321772', '9765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9765', '112', '11642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11643', '1079', '1', 'Santa Rita do Sapucaí', 'BR.15.3159605', 'ASCII:Santa Rita Do Sapucai;ID:6321773', '9766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9766', '112', '11643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11644', '1079', '1', 'Santa Rosa da Serra', 'BR.15.3159704', 'ASCII:Santa Rosa Da Serra;ID:6321774', '9767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9767', '112', '11644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11645', '1079', '1', 'Santa Vitória', 'BR.15.3159803', 'ASCII:Santa Vitoria;ID:6321775', '9768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9768', '112', '11645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11646', '1079', '1', 'Santo Antônio do Amparo', 'BR.15.3159902', 'ASCII:Santo Antonio Do Amparo;ID:6321776', '9769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9769', '112', '11646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3159902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11647', '1079', '1', 'Santo Antônio do Aventureiro', 'BR.15.3160009', 'ASCII:Santo Antonio Do Aventureiro;ID:6321777', '9770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9770', '112', '11647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11648', '1079', '1', 'Santo Antônio do Grama', 'BR.15.3160108', 'ASCII:Santo Antonio Do Grama;ID:6321778', '9771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9771', '112', '11648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11649', '1079', '1', 'Santo Antônio do Itambé', 'BR.15.3160207', 'ASCII:Santo Antonio Do Itambe;ID:6321779', '9772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9772', '112', '11649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11650', '1079', '1', 'Santo Antônio do Jacinto', 'BR.15.3160306', 'ASCII:Santo Antonio Do Jacinto;ID:6321780', '9773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9773', '112', '11650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11651', '1079', '1', 'Santo Antônio do Monte', 'BR.15.3160405', 'ASCII:Santo Antonio Do Monte;ID:6321781', '9774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9774', '112', '11651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11652', '1079', '1', 'Santo Antônio do Retiro', 'BR.15.3160454', 'ASCII:Santo Antonio Do Retiro;ID:6321782', '9775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9775', '112', '11652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11653', '1079', '1', 'Santo Antônio do Rio Abaixo', 'BR.15.3160504', 'ASCII:Santo Antonio Do Rio Abaixo;ID:6321783', '9776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9776', '112', '11653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11654', '1079', '1', 'Santo Hipólito', 'BR.15.3160603', 'ASCII:Santo Hipolito;ID:6321784', '9777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9777', '112', '11654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11655', '1079', '1', 'Santos Dumont', 'BR.15.3160702', 'ASCII:Santos Dumont;ID:6321785', '9778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9778', '112', '11655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11656', '1079', '1', 'São Bento Abade', 'BR.15.3160801', 'ASCII:Sao Bento Abade;ID:6321786', '9779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9779', '112', '11656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11657', '1079', '1', 'São Domingos das Dores', 'BR.15.3160959', 'ASCII:Sao Domingos Das Dores;ID:6321787', '9780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9780', '112', '11657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3160959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11658', '1079', '1', 'São Domingos do Prata', 'BR.15.3161007', 'ASCII:Sao Domingos Do Prata;ID:6321788', '9781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9781', '112', '11658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11659', '1079', '1', 'São Félix de Minas', 'BR.15.3161056', 'ASCII:Sao Felix De Minas;ID:6321789', '9782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9782', '112', '11659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11660', '1079', '1', 'São Francisco de Sales', 'BR.15.3161304', 'ASCII:Sao Francisco De Sales;ID:6321790', '9783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9783', '112', '11660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11661', '1079', '1', 'São Francisco do Glória', 'BR.15.3161403', 'ASCII:Sao Francisco Do Gloria;ID:6321791', '9784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9784', '112', '11661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11662', '1079', '1', 'São Geraldo', 'BR.15.3161502', 'ASCII:Sao Geraldo;ID:6321792', '9785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9785', '112', '11662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11663', '1079', '1', 'São Geraldo da Piedade', 'BR.15.3161601', 'ASCII:Sao Geraldo Da Piedade;ID:6321793', '9786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9786', '112', '11663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11664', '1079', '1', 'São Geraldo do Baixio', 'BR.15.3161650', 'ASCII:Sao Geraldo Do Baixio;ID:6321794', '9787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9787', '112', '11664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11665', '1079', '1', 'São Gonçalo do Abaeté', 'BR.15.3161700', 'ASCII:Sao Goncalo Do Abaete;ID:6321795', '9788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9788', '112', '11665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11666', '1079', '1', 'São Gonçalo do Pará', 'BR.15.3161809', 'ASCII:Sao Goncalo Do Para;ID:6321796', '9789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9789', '112', '11666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11667', '1079', '1', 'São Gonçalo do Rio Abaixo', 'BR.15.3161908', 'ASCII:Sao Goncalo Do Rio Abaixo;ID:6321797', '9790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9790', '112', '11667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11668', '1079', '1', 'São Gonçalo do Sapucaí', 'BR.15.3162005', 'ASCII:Sao Goncalo Do Sapucai;ID:6321798', '9791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9791', '112', '11668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11669', '1079', '1', 'São Gotardo', 'BR.15.3162104', 'ASCII:Sao Gotardo;ID:6321799', '9792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9792', '112', '11669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11670', '1079', '1', 'São João Batista do Glória', 'BR.15.3162203', 'ASCII:Sao Joao Batista Do Gloria;ID:6321800', '9793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9793', '112', '11670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11671', '1079', '1', 'São João da Lagoa', 'BR.15.3162252', 'ASCII:Sao Joao Da Lagoa;ID:6321801', '9794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9794', '112', '11671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11672', '1079', '1', 'São João da Mata', 'BR.15.3162302', 'ASCII:Sao Joao Da Mata;ID:6321802', '9795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9795', '112', '11672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11673', '1079', '1', 'São João da Ponte', 'BR.15.3162401', 'ASCII:Sao Joao Da Ponte;ID:6321803', '9796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9796', '112', '11673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11674', '1079', '1', 'São João das Missões', 'BR.15.3162450', 'ASCII:Sao Joao Das Missoes;ID:6321804', '9797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9797', '112', '11674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11675', '1079', '1', 'São João del Rei', 'BR.15.3162500', 'ASCII:Sao Joao Del Rei;ID:6321805', '9798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9798', '112', '11675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11676', '1079', '1', 'São João do Manhuaçu', 'BR.15.3162559', 'ASCII:Sao Joao Do Manhuacu;ID:6321806', '9799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9799', '112', '11676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11677', '1079', '1', 'São João do Manteninha', 'BR.15.3162575', 'ASCII:Sao Joao Do Manteninha;ID:6321807', '9800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9800', '112', '11677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11678', '1079', '1', 'São João do Oriente', 'BR.15.3162609', 'ASCII:Sao Joao Do Oriente;ID:6321808', '9801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9801', '112', '11678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11679', '1079', '1', 'São João do Pacuí', 'BR.15.3162658', 'ASCII:Sao Joao Do Pacui;ID:6321809', '9802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9802', '112', '11679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11680', '1079', '1', 'São João do Paraíso', 'BR.15.3162708', 'ASCII:Sao Joao Do Paraiso;ID:6321810', '9803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9803', '112', '11680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11681', '1079', '1', 'São João Evangelista', 'BR.15.3162807', 'ASCII:Sao Joao Evangelista;ID:6321811', '9804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9804', '112', '11681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11682', '1079', '1', 'São João Nepomuceno', 'BR.15.3162906', 'ASCII:Sao Joao Nepomuceno;ID:6321812', '9805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9805', '112', '11682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11683', '1079', '1', 'São Joaquim de Bicas', 'BR.15.3162922', 'ASCII:Sao Joaquim De Bicas;ID:6321813', '9806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9806', '112', '11683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11684', '1079', '1', 'São José da Barra', 'BR.15.3162948', 'ASCII:Sao Jose Da Barra;ID:6321814', '9807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9807', '112', '11684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162948» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11685', '1079', '1', 'São José da Lapa', 'BR.15.3162955', 'ASCII:Sao Jose Da Lapa;ID:6321815', '9808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9808', '112', '11685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3162955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11686', '1079', '1', 'São José da Safira', 'BR.15.3163003', 'ASCII:Sao Jose Da Safira;ID:6321816', '9809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9809', '112', '11686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3163003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11687', '1079', '1', 'São José da Varginha', 'BR.15.3163102', 'ASCII:Sao Jose Da Varginha;ID:6321817', '9810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9810', '112', '11687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3163102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11688', '1079', '1', 'São José do Alegre', 'BR.15.3163201', 'ASCII:Sao Jose Do Alegre;ID:6321818', '9811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9811', '112', '11688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3163201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11689', '1079', '1', 'São José do Divino', 'BR.15.3163300', 'ASCII:Sao Jose Do Divino;ID:6321819', '9812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9812', '112', '11689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3163300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11690', '1079', '1', 'São José do Goiabal', 'BR.15.3163409', 'ASCII:Sao Jose Do Goiabal;ID:6321820', '9813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9813', '112', '11690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3163409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11691', '1079', '1', 'São José do Jacuri', 'BR.15.3163508', 'ASCII:Sao Jose Do Jacuri;ID:6321821', '9814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9814', '112', '11691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3163508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11692', '1079', '1', 'São José do Mantimento', 'BR.15.3163607', 'ASCII:Sao Jose Do Mantimento;ID:6321822', '9815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9815', '112', '11692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3163607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11693', '1079', '1', 'São Lourenço', 'BR.15.3163706', 'ASCII:Sao Lourenco;ID:6321823', '9816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9816', '112', '11693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3163706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11694', '1079', '1', 'São Miguel do Anta', 'BR.15.3163805', 'ASCII:Sao Miguel Do Anta;ID:6321824', '9817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9817', '112', '11694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3163805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11695', '1079', '1', 'São Pedro da União', 'BR.15.3163904', 'ASCII:Sao Pedro Da Uniao;ID:6321825', '9818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9818', '112', '11695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3163904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11696', '1079', '1', 'São Pedro dos Ferros', 'BR.15.3164001', 'ASCII:Sao Pedro Dos Ferros;ID:6321826', '9819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9819', '112', '11696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11697', '1079', '1', 'São Pedro do Suaçuí', 'BR.15.3164100', 'ASCII:Sao Pedro Do Suacui;ID:6321827', '9820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9820', '112', '11697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11698', '1079', '1', 'São Romão', 'BR.15.3164209', 'ASCII:Sao Romao;ID:6321828', '9821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9821', '112', '11698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11699', '1079', '1', 'São Roque de Minas', 'BR.15.3164308', 'ASCII:Sao Roque De Minas;ID:6321829', '9822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9822', '112', '11699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11700', '1079', '1', 'São Sebastião da Bela Vista', 'BR.15.3164407', 'ASCII:Sao Sebastiao Da Bela Vista;ID:6321830', '9823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9823', '112', '11700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11701', '1079', '1', 'São Sebastião da Vargem Alegre', 'BR.15.3164431', 'ASCII:Sao Sebastiao Da Vargem Alegre;ID:6321831', '9824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9824', '112', '11701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11702', '1079', '1', 'São Sebastião do Anta', 'BR.15.3164472', 'ASCII:Sao Sebastiao Do Anta;ID:6321832', '9825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9825', '112', '11702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11703', '1079', '1', 'São Sebastião do Maranhão', 'BR.15.3164506', 'ASCII:Sao Sebastiao Do Maranhao;ID:6321833', '9826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9826', '112', '11703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11704', '1079', '1', 'São Sebastião do Oeste', 'BR.15.3164605', 'ASCII:Sao Sebastiao Do Oeste;ID:6321834', '9827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9827', '112', '11704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11705', '1079', '1', 'São Sebastião do Paraíso', 'BR.15.3164704', 'ASCII:Sao Sebastiao Do Paraiso;ID:6321835', '9828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9828', '112', '11705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11706', '1079', '1', 'São Sebastião do Rio Preto', 'BR.15.3164803', 'ASCII:Sao Sebastiao Do Rio Preto;ID:6321836', '9829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9829', '112', '11706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11707', '1079', '1', 'São Sebastião do Rio Verde', 'BR.15.3164902', 'ASCII:Sao Sebastiao Do Rio Verde;ID:6321837', '9830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9830', '112', '11707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3164902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11708', '1079', '1', 'São Tiago', 'BR.15.3165008', 'ASCII:Sao Tiago;ID:6321838', '9831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9831', '112', '11708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11709', '1079', '1', 'São Tomás de Aquino', 'BR.15.3165107', 'ASCII:Sao Tomas De Aquino;ID:6321839', '9832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9832', '112', '11709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11710', '1079', '1', 'São Thomé das Letras', 'BR.15.3165206', 'ASCII:Sao Thome Das Letras;ID:6321840', '9833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9833', '112', '11710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11711', '1079', '1', 'São Vicente de Minas', 'BR.15.3165305', 'ASCII:Sao Vicente De Minas;ID:6321841', '9834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9834', '112', '11711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11712', '1079', '1', 'Sapucaí-Mirim', 'BR.15.3165404', 'ASCII:Sapucai-Mirim;ID:6321842', '9835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9835', '112', '11712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11713', '1079', '1', 'Sardoá', 'BR.15.3165503', 'ASCII:Sardoa;ID:6321843', '9836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9836', '112', '11713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11714', '1079', '1', 'Sarzedo', 'BR.15.3165537', 'ASCII:Sarzedo;ID:6321844', '9837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9837', '112', '11714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165537» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11715', '1079', '1', 'Setubinha', 'BR.15.3165552', 'ASCII:Setubinha;ID:6321845', '9838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9838', '112', '11715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11716', '1079', '1', 'Sem-Peixe', 'BR.15.3165560', 'ASCII:Sem-Peixe;ID:6321846', '9839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9839', '112', '11716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11717', '1079', '1', 'Senador Amaral', 'BR.15.3165578', 'ASCII:Senador Amaral;ID:6321847', '9840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9840', '112', '11717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11718', '1079', '1', 'Senador Cortes', 'BR.15.3165602', 'ASCII:Senador Cortes;ID:6321848', '9841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9841', '112', '11718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11719', '1079', '1', 'Senador Firmino', 'BR.15.3165701', 'ASCII:Senador Firmino;ID:6321849', '9842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9842', '112', '11719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11720', '1079', '1', 'Senador José Bento', 'BR.15.3165800', 'ASCII:Senador Jose Bento;ID:6321850', '9843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9843', '112', '11720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11721', '1079', '1', 'Senador Modestino Gonçalves', 'BR.15.3165909', 'ASCII:Senador Modestino Goncalves;ID:6321851', '9844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9844', '112', '11721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3165909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11722', '1079', '1', 'Senhora de Oliveira', 'BR.15.3166006', 'ASCII:Senhora De Oliveira;ID:6321852', '9845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9845', '112', '11722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11723', '1079', '1', 'Senhora do Porto', 'BR.15.3166105', 'ASCII:Senhora Do Porto;ID:6321853', '9846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9846', '112', '11723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11724', '1079', '1', 'Senhora dos Remédios', 'BR.15.3166204', 'ASCII:Senhora Dos Remedios;ID:6321854', '9847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9847', '112', '11724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11725', '1079', '1', 'Sericita', 'BR.15.3166303', 'ASCII:Sericita;ID:6321855', '9848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9848', '112', '11725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11726', '1079', '1', 'Seritinga', 'BR.15.3166402', 'ASCII:Seritinga;ID:6321856', '9849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9849', '112', '11726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11727', '1079', '1', 'Serra Azul de Minas', 'BR.15.3166501', 'ASCII:Serra Azul De Minas;ID:6321857', '9850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9850', '112', '11727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11728', '1079', '1', 'Serra da Saudade', 'BR.15.3166600', 'ASCII:Serra Da Saudade;ID:6321858', '9851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9851', '112', '11728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11729', '1079', '1', 'Serra dos Aimorés', 'BR.15.3166709', 'ASCII:Serra Dos Aimores;ID:6321859', '9852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9852', '112', '11729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11730', '1079', '1', 'Serra do Salitre', 'BR.15.3166808', 'ASCII:Serra Do Salitre;ID:6321860', '9853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9853', '112', '11730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11731', '1079', '1', 'Serrania', 'BR.15.3166907', 'ASCII:Serrania;ID:6321861', '9854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9854', '112', '11731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11732', '1079', '1', 'Serranópolis de Minas', 'BR.15.3166956', 'ASCII:Serranopolis De Minas;ID:6321862', '9855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9855', '112', '11732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3166956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11733', '1079', '1', 'Serranos', 'BR.15.3167004', 'ASCII:Serranos;ID:6321863', '9856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9856', '112', '11733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3167004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11734', '1079', '1', 'Serro', 'BR.15.3167103', 'ASCII:Serro;ID:6321864', '9857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9857', '112', '11734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3167103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11735', '1079', '1', 'Sete Lagoas', 'BR.15.3167202', 'ASCII:Sete Lagoas;ID:6321865', '9858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9858', '112', '11735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3167202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11736', '1079', '1', 'Silveirânia', 'BR.15.3167301', 'ASCII:Silveirania;ID:6321866', '9859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9859', '112', '11736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3167301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11737', '1079', '1', 'Silvianópolis', 'BR.15.3167400', 'ASCII:Silvianopolis;ID:6321867', '9860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9860', '112', '11737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3167400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11738', '1079', '1', 'Simão Pereira', 'BR.15.3167509', 'ASCII:Simao Pereira;ID:6321868', '9861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9861', '112', '11738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3167509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11739', '1079', '1', 'Simonésia', 'BR.15.3167608', 'ASCII:Simonesia;ID:6321869', '9862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9862', '112', '11739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3167608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11740', '1079', '1', 'Sobrália', 'BR.15.3167707', 'ASCII:Sobralia;ID:6321870', '9863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9863', '112', '11740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3167707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11741', '1079', '1', 'Soledade de Minas', 'BR.15.3167806', 'ASCII:Soledade De Minas;ID:6321871', '9864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9864', '112', '11741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3167806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11742', '1079', '1', 'Tabuleiro', 'BR.15.3167905', 'ASCII:Tabuleiro;ID:6321872', '9865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9865', '112', '11742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3167905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11743', '1079', '1', 'Taiobeiras', 'BR.15.3168002', 'ASCII:Taiobeiras;ID:6321873', '9866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9866', '112', '11743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11744', '1079', '1', 'Taparuba', 'BR.15.3168051', 'ASCII:Taparuba;ID:6321874', '9867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9867', '112', '11744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11745', '1079', '1', 'Tapira', 'BR.15.3168101', 'ASCII:Tapira;ID:6321875', '9868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9868', '112', '11745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11746', '1079', '1', 'Tapiraí', 'BR.15.3168200', 'ASCII:Tapirai;ID:6321876', '9869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9869', '112', '11746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11747', '1079', '1', 'Taquaraçu de Minas', 'BR.15.3168309', 'ASCII:Taquaracu De Minas;ID:6321877', '9870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9870', '112', '11747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11748', '1079', '1', 'Tarumirim', 'BR.15.3168408', 'ASCII:Tarumirim;ID:6321878', '9871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9871', '112', '11748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11749', '1079', '1', 'Teixeiras', 'BR.15.3168507', 'ASCII:Teixeiras;ID:6321879', '9872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9872', '112', '11749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11750', '1079', '1', 'Teófilo Otoni', 'BR.15.3168606', 'ASCII:Teofilo Otoni;ID:6321880', '9873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9873', '112', '11750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11751', '1079', '1', 'Timóteo', 'BR.15.3168705', 'ASCII:Timoteo;ID:6321881', '9874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9874', '112', '11751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11752', '1079', '1', 'Tiradentes', 'BR.15.3168804', 'ASCII:Tiradentes;ID:6321882', '9875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9875', '112', '11752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11753', '1079', '1', 'Tiros', 'BR.15.3168903', 'ASCII:Tiros;ID:6321883', '9876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9876', '112', '11753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3168903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11754', '1079', '1', 'Tocantins', 'BR.15.3169000', 'ASCII:Tocantins;ID:6321884', '9877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9877', '112', '11754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11755', '1079', '1', 'Tocos do Moji', 'BR.15.3169059', 'ASCII:Tocos Do Moji;ID:6321885', '9878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9878', '112', '11755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11756', '1079', '1', 'Toledo', 'BR.15.3169109', 'ASCII:Toledo;ID:6321886', '9879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9879', '112', '11756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11757', '1079', '1', 'Tombos', 'BR.15.3169208', 'ASCII:Tombos;ID:6321887', '9880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9880', '112', '11757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11758', '1079', '1', 'Três Corações', 'BR.15.3169307', 'ASCII:Tres Coracoes;ID:6321888', '9881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9881', '112', '11758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11759', '1079', '1', 'Três Marias', 'BR.15.3169356', 'ASCII:Tres Marias;ID:6321889', '9882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9882', '112', '11759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11760', '1079', '1', 'Três Pontas', 'BR.15.3169406', 'ASCII:Tres Pontas;ID:6321890', '9883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9883', '112', '11760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11761', '1079', '1', 'Tumiritinga', 'BR.15.3169505', 'ASCII:Tumiritinga;ID:6321891', '9884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9884', '112', '11761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11762', '1079', '1', 'Tupaciguara', 'BR.15.3169604', 'ASCII:Tupaciguara;ID:6321892', '9885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9885', '112', '11762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11763', '1079', '1', 'Turmalina', 'BR.15.3169703', 'ASCII:Turmalina;ID:6321893', '9886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9886', '112', '11763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11764', '1079', '1', 'Turvolândia', 'BR.15.3169802', 'ASCII:Turvolandia;ID:6321894', '9887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9887', '112', '11764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11765', '1079', '1', 'Ubá', 'BR.15.3169901', 'ASCII:Uba;ID:6321895', '9888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9888', '112', '11765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3169901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11766', '1079', '1', 'Ubaí', 'BR.15.3170008', 'ASCII:Ubai;ID:6321896', '9889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9889', '112', '11766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11767', '1079', '1', 'Ubaporanga', 'BR.15.3170057', 'ASCII:Ubaporanga;ID:6321897', '9890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9890', '112', '11767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11768', '1079', '1', 'Uberaba', 'BR.15.3170107', 'ASCII:Uberaba;ID:6321898', '9891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9891', '112', '11768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11769', '1079', '1', 'Uberlândia', 'BR.15.3170206', 'ASCII:Uberlandia;ID:6321899', '9892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9892', '112', '11769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11770', '1079', '1', 'Umburatiba', 'BR.15.3170305', 'ASCII:Umburatiba;ID:6321900', '9893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9893', '112', '11770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11771', '1079', '1', 'Unaí', 'BR.15.3170404', 'ASCII:Unai;ID:6321901', '9894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9894', '112', '11771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11772', '1079', '1', 'União de Minas', 'BR.15.3170438', 'ASCII:Uniao De Minas;ID:6321902', '9895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9895', '112', '11772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11773', '1079', '1', 'Uruana de Minas', 'BR.15.3170479', 'ASCII:Uruana De Minas;ID:6321903', '9896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9896', '112', '11773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11774', '1079', '1', 'Urucânia', 'BR.15.3170503', 'ASCII:Urucania;ID:6321904', '9897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9897', '112', '11774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11775', '1079', '1', 'Urucuia', 'BR.15.3170529', 'ASCII:Urucuia;ID:6321905', '9898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9898', '112', '11775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11776', '1079', '1', 'Vargem Alegre', 'BR.15.3170578', 'ASCII:Vargem Alegre;ID:6321906', '9899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9899', '112', '11776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11777', '1079', '1', 'Vargem Bonita', 'BR.15.3170602', 'ASCII:Vargem Bonita;ID:6321907', '9900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9900', '112', '11777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11778', '1079', '1', 'Vargem Grande do Rio Pardo', 'BR.15.3170651', 'ASCII:Vargem Grande Do Rio Pardo;ID:6321908', '9901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9901', '112', '11778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11779', '1079', '1', 'Varginha', 'BR.15.3170701', 'ASCII:Varginha;ID:6321909', '9902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9902', '112', '11779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11780', '1079', '1', 'Varjão de MInas', 'BR.15.3170750', 'ASCII:Varjao De Minas;ID:6321910', '9903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9903', '112', '11780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11781', '1079', '1', 'Várzea da Palma', 'BR.15.3170800', 'ASCII:Varzea Da Palma;ID:6321911', '9904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9904', '112', '11781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11782', '1079', '1', 'Varzelândia', 'BR.15.3170909', 'ASCII:Varzelandia;ID:6321912', '9905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9905', '112', '11782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3170909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11783', '1079', '1', 'Vazante', 'BR.15.3171006', 'ASCII:Vazante;ID:6321913', '9906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9906', '112', '11783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11784', '1079', '1', 'Verdelândia', 'BR.15.3171030', 'ASCII:Verdelandia;ID:6321914', '9907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9907', '112', '11784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11785', '1079', '1', 'Veredinha', 'BR.15.3171071', 'ASCII:Veredinha;ID:6321915', '9908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9908', '112', '11785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11786', '1079', '1', 'Veríssimo', 'BR.15.3171105', 'ASCII:Verissimo;ID:6321916', '9909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9909', '112', '11786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11787', '1079', '1', 'Vermelho Novo', 'BR.15.3171154', 'ASCII:Vermelho Novo;ID:6321917', '9910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9910', '112', '11787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11788', '1079', '1', 'Vespasiano', 'BR.15.3171204', 'ASCII:Vespasiano;ID:6321918', '9911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9911', '112', '11788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11789', '1079', '1', 'Viçosa', 'BR.15.3171303', 'ASCII:Vicosa;ID:6321919', '9912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9912', '112', '11789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11790', '1079', '1', 'Vieiras', 'BR.15.3171402', 'ASCII:Vieiras;ID:6321920', '9913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9913', '112', '11790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11791', '1079', '1', 'Mathias Lobato', 'BR.15.3171501', 'ASCII:Mathias Lobato;ID:6321921', '9914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9914', '112', '11791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11792', '1079', '1', 'Virgem da Lapa', 'BR.15.3171600', 'ASCII:Virgem Da Lapa;ID:6321922', '9915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9915', '112', '11792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11793', '1079', '1', 'Virgínia', 'BR.15.3171709', 'ASCII:Virginia;ID:6321923', '9916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9916', '112', '11793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11794', '1079', '1', 'Virginópolis', 'BR.15.3171808', 'ASCII:Virginopolis;ID:6321924', '9917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9917', '112', '11794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11795', '1079', '1', 'Virgolândia', 'BR.15.3171907', 'ASCII:Virgolandia;ID:6321925', '9918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9918', '112', '11795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3171907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11796', '1079', '1', 'Visconde do Rio Branco', 'BR.15.3172004', 'ASCII:Visconde Do Rio Branco;ID:6321926', '9919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9919', '112', '11796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3172004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11797', '1079', '1', 'Volta Grande', 'BR.15.3172103', 'ASCII:Volta Grande;ID:6321927', '9920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9920', '112', '11797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3172103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11798', '1079', '1', 'Wenceslau Braz', 'BR.15.3172202', 'ASCII:Wenceslau Braz;ID:6321928', '9921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9921', '112', '11798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3172202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11799', '1079', '1', 'Afonso Cláudio', 'BR.08.3200102', 'ASCII:Afonso Claudio;ID:6321929', '9922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9922', '112', '11799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11800', '1079', '1', 'Águia Branca', 'BR.08.3200136', 'ASCII:Aguia Branca;ID:6321930', '9923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9923', '112', '11800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11801', '1079', '1', 'Água Doce do Norte', 'BR.08.3200169', 'ASCII:Agua Doce Do Norte;ID:6321931', '9924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9924', '112', '11801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11802', '1079', '1', 'Alfredo Chaves', 'BR.08.3200300', 'ASCII:Alfredo Chaves;ID:6321932', '9925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9925', '112', '11802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11803', '1079', '1', 'Alto Rio Novo', 'BR.08.3200359', 'ASCII:Alto Rio Novo;ID:6321933', '9926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9926', '112', '11803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11804', '1079', '1', 'Anchieta', 'BR.08.3200409', 'ASCII:Anchieta;ID:6321934', '9927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9927', '112', '11804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11805', '1079', '1', 'Apiacá', 'BR.08.3200508', 'ASCII:Apiaca;ID:6321935', '9928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9928', '112', '11805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11806', '1079', '1', 'Aracruz', 'BR.08.3200607', 'ASCII:Aracruz;ID:6321936', '9929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9929', '112', '11806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11807', '1079', '1', 'Atilio Vivacqua', 'BR.08.3200706', 'ASCII:Atilio Vivacqua;ID:6321937', '9930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9930', '112', '11807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11808', '1079', '1', 'Baixo Guandu', 'BR.08.3200805', 'ASCII:Baixo Guandu;ID:6321938', '9931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9931', '112', '11808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11809', '1079', '1', 'Barra de São Francisco', 'BR.08.3200904', 'ASCII:Barra De Sao Francisco;ID:6321939', '9932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9932', '112', '11809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11810', '1079', '1', 'Boa Esperança', 'BR.08.3201001', 'ASCII:Boa Esperanca;ID:6321940', '9933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9933', '112', '11810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11811', '1079', '1', 'Bom Jesus do Norte', 'BR.08.3201100', 'ASCII:Bom Jesus Do Norte;ID:6321941', '9934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9934', '112', '11811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11812', '1079', '1', 'Brejetuba', 'BR.08.3201159', 'ASCII:Brejetuba;ID:6321942', '9935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9935', '112', '11812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11813', '1079', '1', 'Cachoeiro de Itapemirim', 'BR.08.3201209', 'ASCII:Cachoeiro De Itapemirim;ID:6321943', '9936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9936', '112', '11813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11814', '1079', '1', 'Cariacica', 'BR.08.3201308', 'ASCII:Cariacica;ID:6321944', '9937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9937', '112', '11814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11815', '1079', '1', 'Castelo', 'BR.08.3201407', 'ASCII:Castelo;ID:6321945', '9938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9938', '112', '11815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11816', '1079', '1', 'Conceição da Barra', 'BR.08.3201605', 'ASCII:Conceicao Da Barra;ID:6321946', '9939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9939', '112', '11816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11817', '1079', '1', 'Conceição do Castelo', 'BR.08.3201704', 'ASCII:Conceicao Do Castelo;ID:6321947', '9940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9940', '112', '11817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11818', '1079', '1', 'Divino de São Lourenço', 'BR.08.3201803', 'ASCII:Divino De Sao Lourenco;ID:6321948', '9941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9941', '112', '11818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11819', '1079', '1', 'Domingos Martins', 'BR.08.3201902', 'ASCII:Domingos Martins;ID:6321949', '9942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9942', '112', '11819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11820', '1079', '1', 'Dores do Rio Preto', 'BR.08.3202009', 'ASCII:Dores Do Rio Preto;ID:6321950', '9943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9943', '112', '11820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11821', '1079', '1', 'Ecoporanga', 'BR.08.3202108', 'ASCII:Ecoporanga;ID:6321951', '9944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9944', '112', '11821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11822', '1079', '1', 'Fundão', 'BR.08.3202207', 'ASCII:Fundao;ID:6321952', '9945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9945', '112', '11822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11823', '1079', '1', 'Guaçuí', 'BR.08.3202306', 'ASCII:Guacui;ID:6321953', '9946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9946', '112', '11823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11824', '1079', '1', 'Guarapari', 'BR.08.3202405', 'ASCII:Guarapari;ID:6321954', '9947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9947', '112', '11824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11825', '1079', '1', 'Ibatiba', 'BR.08.3202454', 'ASCII:Ibatiba;ID:6321955', '9948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9948', '112', '11825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11826', '1079', '1', 'Ibiraçu', 'BR.08.3202504', 'ASCII:Ibiracu;ID:6321956', '9949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9949', '112', '11826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11827', '1079', '1', 'Ibitirama', 'BR.08.3202553', 'ASCII:Ibitirama;ID:6321957', '9950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9950', '112', '11827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11828', '1079', '1', 'Iconha', 'BR.08.3202603', 'ASCII:Iconha;ID:6321958', '9951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9951', '112', '11828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11829', '1079', '1', 'Irupi', 'BR.08.3202652', 'ASCII:Irupi;ID:6321959', '9952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9952', '112', '11829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11830', '1079', '1', 'Itaguaçu', 'BR.08.3202702', 'ASCII:Itaguacu;ID:6321960', '9953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9953', '112', '11830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11831', '1079', '1', 'Itapemirim', 'BR.08.3202801', 'ASCII:Itapemirim;ID:6321961', '9954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9954', '112', '11831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11832', '1079', '1', 'Itarana', 'BR.08.3202900', 'ASCII:Itarana;ID:6321962', '9955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9955', '112', '11832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11833', '1079', '1', 'Iúna', 'BR.08.3203007', 'ASCII:Iuna;ID:6321963', '9956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9956', '112', '11833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11834', '1079', '1', 'Jaguaré', 'BR.08.3203056', 'ASCII:Jaguare;ID:6321964', '9957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9957', '112', '11834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11835', '1079', '1', 'Jerônimo Monteiro', 'BR.08.3203106', 'ASCII:Jeronimo Monteiro;ID:6321965', '9958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9958', '112', '11835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11836', '1079', '1', 'João Neiva', 'BR.08.3203130', 'ASCII:Joao Neiva;ID:6321966', '9959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9959', '112', '11836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11837', '1079', '1', 'Laranja da Terra', 'BR.08.3203163', 'ASCII:Laranja Da Terra;ID:6321967', '9960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9960', '112', '11837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11838', '1079', '1', 'Linhares', 'BR.08.3203205', 'ASCII:Linhares;ID:6321968', '9961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9961', '112', '11838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11839', '1079', '1', 'Mantenópolis', 'BR.08.3203304', 'ASCII:Mantenopolis;ID:6321969', '9962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9962', '112', '11839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11840', '1079', '1', 'Marataízes', 'BR.08.3203320', 'ASCII:Marataizes;ID:6321970', '9963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9963', '112', '11840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11841', '1079', '1', 'Marechal Floriano', 'BR.08.3203346', 'ASCII:Marechal Floriano;ID:6321971', '9964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9964', '112', '11841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11842', '1079', '1', 'Marilândia', 'BR.08.3203353', 'ASCII:Marilandia;ID:6321972', '9965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9965', '112', '11842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11843', '1079', '1', 'Mimoso do Sul', 'BR.08.3203403', 'ASCII:Mimoso Do Sul;ID:6321973', '9966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9966', '112', '11843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11844', '1079', '1', 'Montanha', 'BR.08.3203502', 'ASCII:Montanha;ID:6321974', '9967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9967', '112', '11844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11845', '1079', '1', 'Mucurici', 'BR.08.3203601', 'ASCII:Mucurici;ID:6321975', '9968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9968', '112', '11845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11846', '1079', '1', 'Muniz Freire', 'BR.08.3203700', 'ASCII:Muniz Freire;ID:6321976', '9969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9969', '112', '11846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11847', '1079', '1', 'Muqui', 'BR.08.3203809', 'ASCII:Muqui;ID:6321977', '9970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9970', '112', '11847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11848', '1079', '1', 'Nova Venécia', 'BR.08.3203908', 'ASCII:Nova Venecia;ID:6321978', '9971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9971', '112', '11848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3203908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11849', '1079', '1', 'Pancas', 'BR.08.3204005', 'ASCII:Pancas;ID:6321979', '9972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9972', '112', '11849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11850', '1079', '1', 'Pedro Canário', 'BR.08.3204054', 'ASCII:Pedro Canario;ID:6321980', '9973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9973', '112', '11850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11851', '1079', '1', 'Pinheiros', 'BR.08.3204104', 'ASCII:Pinheiros;ID:6321981', '9974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9974', '112', '11851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11852', '1079', '1', 'Piúma', 'BR.08.3204203', 'ASCII:Piuma;ID:6321982', '9975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9975', '112', '11852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11853', '1079', '1', 'Ponto Belo', 'BR.08.3204252', 'ASCII:Ponto Belo;ID:6321983', '9976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9976', '112', '11853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11854', '1079', '1', 'Presidente Kennedy', 'BR.08.3204302', 'ASCII:Presidente Kennedy;ID:6321984', '9977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9977', '112', '11854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11855', '1079', '1', 'Rio Bananal', 'BR.08.3204351', 'ASCII:Rio Bananal;ID:6321985', '9978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9978', '112', '11855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11856', '1079', '1', 'Rio Novo do Sul', 'BR.08.3204401', 'ASCII:Rio Novo Do Sul;ID:6321986', '9979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9979', '112', '11856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11857', '1079', '1', 'Santa Teresa', 'BR.08.3204609', 'ASCII:Santa Teresa;ID:6321987', '9980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9980', '112', '11857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11858', '1079', '1', 'São Domingos do Norte', 'BR.08.3204658', 'ASCII:Sao Domingos Do Norte;ID:6321988', '9981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9981', '112', '11858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11859', '1079', '1', 'São Gabriel da Palha', 'BR.08.3204708', 'ASCII:Sao Gabriel Da Palha;ID:6321989', '9982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9982', '112', '11859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11860', '1079', '1', 'São Mateus', 'BR.08.3204906', 'ASCII:Sao Mateus;ID:6321990', '9983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9983', '112', '11860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11861', '1079', '1', 'São Roque do Canaã', 'BR.08.3204955', 'ASCII:Sao Roque Do Canaa;ID:6321991', '9984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9984', '112', '11861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11862', '1079', '1', 'Serra', 'BR.08.3205002', 'ASCII:Serra;ID:6321992', '9985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9985', '112', '11862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3205002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11863', '1079', '1', 'Sooretama', 'BR.08.3205010', 'ASCII:Sooretama;ID:6321993', '9986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9986', '112', '11863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3205010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11864', '1079', '1', 'Vargem Alta', 'BR.08.3205036', 'ASCII:Vargem Alta;ID:6321994', '9987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9987', '112', '11864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3205036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11865', '1079', '1', 'Venda Nova do Imigrante', 'BR.08.3205069', 'ASCII:Venda Nova Do Imigrante;ID:6321995', '9988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9988', '112', '11865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3205069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11866', '1079', '1', 'Viana', 'BR.08.3205101', 'ASCII:Viana;ID:6321996', '9989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9989', '112', '11866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3205101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11867', '1079', '1', 'Vila Pavão', 'BR.08.3205150', 'ASCII:Vila Pavao;ID:6321997', '9990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9990', '112', '11867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3205150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11868', '1079', '1', 'Vila Valério', 'BR.08.3205176', 'ASCII:Vila Valerio;ID:6321998', '9991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9991', '112', '11868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3205176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11869', '1079', '1', 'Vila Velha', 'BR.08.3205200', 'ASCII:Vila Velha;ID:6321999', '9992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9992', '112', '11869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3205200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11870', '1079', '1', 'Vitória', 'BR.08.3205309', 'ASCII:Vitoria;ID:6322000', '9993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9993', '112', '11870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3205309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11871', '1079', '1', 'Angra dos Reis', 'BR.21.3300100', 'ASCII:Angra Dos Reis;ID:6322001', '9994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9994', '112', '11871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11872', '1079', '1', 'Aperibé', 'BR.21.3300159', 'ASCII:Aperibe;ID:6322002', '9995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9995', '112', '11872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11873', '1079', '1', 'Araruama', 'BR.21.3300209', 'ASCII:Araruama;ID:6322003', '9996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9996', '112', '11873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11874', '1079', '1', 'Arraial do Cabo', 'BR.21.3300258', 'ASCII:Arraial Do Cabo;ID:6322004', '9997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9997', '112', '11874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11875', '1079', '1', 'Barra do Piraí', 'BR.21.3300308', 'ASCII:Barra Do Pirai;ID:6322005', '9998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9998', '112', '11875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11876', '1079', '1', 'Barra Mansa', 'BR.21.3300407', 'ASCII:Barra Mansa;ID:6322006', '9999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('9999', '112', '11876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11877', '1079', '1', 'Belford Roxo', 'BR.21.3300456', 'ASCII:Belford Roxo;ID:6322007', '10000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10000', '112', '11877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11878', '1079', '1', 'Bom Jardim', 'BR.21.3300506', 'ASCII:Bom Jardim;ID:6322008', '10001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10001', '112', '11878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11879', '1079', '1', 'Bom Jesus do Itabapoana', 'BR.21.3300605', 'ASCII:Bom Jesus Do Itabapoana;ID:6322009', '10002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10002', '112', '11879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11880', '1079', '1', 'Cabo Frio', 'BR.21.3300704', 'ASCII:Cabo Frio;ID:6322010', '10003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10003', '112', '11880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11881', '1079', '1', 'Cachoeiras de Macacu', 'BR.21.3300803', 'ASCII:Cachoeiras De Macacu;ID:6322011', '10004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10004', '112', '11881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11882', '1079', '1', 'Cambuci', 'BR.21.3300902', 'ASCII:Cambuci;ID:6322012', '10005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10005', '112', '11882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11883', '1079', '1', 'Carapebus', 'BR.21.3300936', 'ASCII:Carapebus;ID:6322013', '10006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10006', '112', '11883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11884', '1079', '1', 'Comendador Levy Gasparian', 'BR.21.3300951', 'ASCII:Comendador Levy Gasparian;ID:6322014', '10007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10007', '112', '11884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3300951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11885', '1079', '1', 'Campos dos Goytacazes', 'BR.21.3301009', 'ASCII:Campos Dos Goytacazes;ID:6322015', '10008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10008', '112', '11885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11886', '1079', '1', 'Cardoso Moreira', 'BR.21.3301157', 'ASCII:Cardoso Moreira;ID:6322016', '10009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10009', '112', '11886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11887', '1079', '1', 'Casimiro de Abreu', 'BR.21.3301306', 'ASCII:Casimiro De Abreu;ID:6322017', '10010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10010', '112', '11887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11888', '1079', '1', 'Cordeiro', 'BR.21.3301504', 'ASCII:Cordeiro;ID:6322018', '10011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10011', '112', '11888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11889', '1079', '1', 'Duque de Caxias', 'BR.21.3301702', 'ASCII:Duque De Caxias;ID:6322019', '10012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10012', '112', '11889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11890', '1079', '1', 'Engenheiro Paulo de Frontin', 'BR.21.3301801', 'ASCII:Engenheiro Paulo De Frontin;ID:6322020', '10013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10013', '112', '11890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11891', '1079', '1', 'Guapimirim', 'BR.21.3301850', 'ASCII:Guapimirim;ID:6322021', '10014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10014', '112', '11891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11892', '1079', '1', 'Iguaba Grande', 'BR.21.3301876', 'ASCII:Iguaba Grande;ID:6322022', '10015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10015', '112', '11892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11893', '1079', '1', 'Itaboraí', 'BR.21.3301900', 'ASCII:Itaborai;ID:6322023', '10016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10016', '112', '11893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11894', '1079', '1', 'Itaguaí', 'BR.21.3302007', 'ASCII:Itaguai;ID:6322024', '10017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10017', '112', '11894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11895', '1079', '1', 'Italva', 'BR.21.3302056', 'ASCII:Italva;ID:6322025', '10018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10018', '112', '11895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11896', '1079', '1', 'Itaocara', 'BR.21.3302106', 'ASCII:Itaocara;ID:6322026', '10019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10019', '112', '11896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11897', '1079', '1', 'Itaperuna', 'BR.21.3302205', 'ASCII:Itaperuna;ID:6322027', '10020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10020', '112', '11897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11898', '1079', '1', 'Itatiaia', 'BR.21.3302254', 'ASCII:Itatiaia;ID:6322028', '10021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10021', '112', '11898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11899', '1079', '1', 'Japeri', 'BR.21.3302270', 'ASCII:Japeri;ID:6322029', '10022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10022', '112', '11899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11900', '1079', '1', 'Laje do Muriaé', 'BR.21.3302304', 'ASCII:Laje Do Muriae;ID:6322030', '10023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10023', '112', '11900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11901', '1079', '1', 'Macaé', 'BR.21.3302403', 'ASCII:Macae;ID:6322031', '10024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10024', '112', '11901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11902', '1079', '1', 'Macuco', 'BR.21.3302452', 'ASCII:Macuco;ID:6322032', '10025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10025', '112', '11902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11903', '1079', '1', 'Magé', 'BR.21.3302502', 'ASCII:Mage;ID:6322033', '10026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10026', '112', '11903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11904', '1079', '1', 'Mangaratiba', 'BR.21.3302601', 'ASCII:Mangaratiba;ID:6322034', '10027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10027', '112', '11904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11905', '1079', '1', 'Maricá', 'BR.21.3302700', 'ASCII:Marica;ID:6322035', '10028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10028', '112', '11905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11906', '1079', '1', 'Mendes', 'BR.21.3302809', 'ASCII:Mendes;ID:6322036', '10029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10029', '112', '11906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11907', '1079', '1', 'Miguel Pereira', 'BR.21.3302908', 'ASCII:Miguel Pereira;ID:6322037', '10030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10030', '112', '11907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3302908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11908', '1079', '1', 'Miracema', 'BR.21.3303005', 'ASCII:Miracema;ID:6322038', '10031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10031', '112', '11908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11909', '1079', '1', 'Natividade', 'BR.21.3303104', 'ASCII:Natividade;ID:6322039', '10032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10032', '112', '11909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11910', '1079', '1', 'Nilópolis', 'BR.21.3303203', 'ASCII:Nilopolis;ID:6322040', '10033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10033', '112', '11910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11911', '1079', '1', 'Niterói', 'BR.21.3303302', 'ASCII:Niteroi;ID:6322041', '10034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10034', '112', '11911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11912', '1079', '1', 'Nova Friburgo', 'BR.21.3303401', 'ASCII:Nova Friburgo;ID:6322042', '10035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10035', '112', '11912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11913', '1079', '1', 'Paracambi', 'BR.21.3303609', 'ASCII:Paracambi;ID:6322043', '10036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10036', '112', '11913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11914', '1079', '1', 'Paraíba do Sul', 'BR.21.3303708', 'ASCII:Paraiba Do Sul;ID:6322044', '10037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10037', '112', '11914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11915', '1079', '1', 'Parati', 'BR.21.3303807', 'ASCII:Parati;ID:6322045', '10038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10038', '112', '11915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11916', '1079', '1', 'Paty do Alferes', 'BR.21.3303856', 'ASCII:Paty Do Alferes;ID:6322046', '10039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10039', '112', '11916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11917', '1079', '1', 'Petrópolis', 'BR.21.3303906', 'ASCII:Petropolis;ID:6322047', '10040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10040', '112', '11917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11918', '1079', '1', 'Pinheiral', 'BR.21.3303955', 'ASCII:Pinheiral;ID:6322048', '10041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10041', '112', '11918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3303955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11919', '1079', '1', 'Piraí', 'BR.21.3304003', 'ASCII:Pirai;ID:6322049', '10042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10042', '112', '11919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11920', '1079', '1', 'Porciúncula', 'BR.21.3304102', 'ASCII:Porciuncula;ID:6322050', '10043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10043', '112', '11920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11921', '1079', '1', 'Porto Real', 'BR.21.3304110', 'ASCII:Porto Real;ID:6322051', '10044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10044', '112', '11921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11922', '1079', '1', 'Quatis', 'BR.21.3304128', 'ASCII:Quatis;ID:6322052', '10045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10045', '112', '11922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11923', '1079', '1', 'Queimados', 'BR.21.3304144', 'ASCII:Queimados;ID:6322053', '10046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10046', '112', '11923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11924', '1079', '1', 'Quissamã', 'BR.21.3304151', 'ASCII:Quissama;ID:6322054', '10047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10047', '112', '11924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11925', '1079', '1', 'Resende', 'BR.21.3304201', 'ASCII:Resende;ID:6322055', '10048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10048', '112', '11925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11926', '1079', '1', 'Rio Bonito', 'BR.21.3304300', 'ASCII:Rio Bonito;ID:6322056', '10049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10049', '112', '11926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11927', '1079', '1', 'Rio Claro', 'BR.21.3304409', 'ASCII:Rio Claro;ID:6322057', '10050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10050', '112', '11927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11928', '1079', '1', 'Rio das Flores', 'BR.21.3304508', 'ASCII:Rio Das Flores;ID:6322058', '10051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10051', '112', '11928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11929', '1079', '1', 'Rio das Ostras', 'BR.21.3304524', 'ASCII:Rio Das Ostras;ID:6322059', '10052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10052', '112', '11929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11930', '1079', '1', 'Rio de Janeiro', 'BR.21.3304557', 'ASCII:Rio De Janeiro;ID:6322060', '10053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10053', '112', '11930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11931', '1079', '1', 'Santa Maria Madalena', 'BR.21.3304607', 'ASCII:Santa Maria Madalena;ID:6322061', '10054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10054', '112', '11931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11932', '1079', '1', 'Santo Antônio de Pádua', 'BR.21.3304706', 'ASCII:Santo Antonio De Padua;ID:6322062', '10055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10055', '112', '11932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11933', '1079', '1', 'São Francisco de Itabapoana', 'BR.21.3304755', 'ASCII:Sao Francisco De Itabapoana;ID:6322063', '10056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10056', '112', '11933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11934', '1079', '1', 'São Fidélis', 'BR.21.3304805', 'ASCII:Sao Fidelis;ID:6322064', '10057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10057', '112', '11934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11935', '1079', '1', 'São Gonçalo', 'BR.21.3304904', 'ASCII:Sao Goncalo;ID:6322065', '10058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10058', '112', '11935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3304904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11936', '1079', '1', 'São João da Barra', 'BR.21.3305000', 'ASCII:Sao Joao Da Barra;ID:6322066', '10059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10059', '112', '11936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11937', '1079', '1', 'São João de Meriti', 'BR.21.3305109', 'ASCII:Sao Joao De Meriti;ID:6322067', '10060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10060', '112', '11937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11938', '1079', '1', 'São José de Ubá', 'BR.21.3305133', 'ASCII:Sao Jose De Uba;ID:6322068', '10061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10061', '112', '11938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11939', '1079', '1', 'São José do Vale do Rio Preto', 'BR.21.3305158', 'ASCII:Sao Jose Do Vale Do Rio Preto;ID:6322069', '10062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10062', '112', '11939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11940', '1079', '1', 'São Pedro da Aldeia', 'BR.21.3305208', 'ASCII:Sao Pedro Da Aldeia;ID:6322070', '10063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10063', '112', '11940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11941', '1079', '1', 'São Sebastião do Alto', 'BR.21.3305307', 'ASCII:Sao Sebastiao Do Alto;ID:6322071', '10064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10064', '112', '11941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11942', '1079', '1', 'Sapucaia', 'BR.21.3305406', 'ASCII:Sapucaia;ID:6322072', '10065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10065', '112', '11942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11943', '1079', '1', 'Saquarema', 'BR.21.3305505', 'ASCII:Saquarema;ID:6322073', '10066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10066', '112', '11943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11944', '1079', '1', 'Seropédica', 'BR.21.3305554', 'ASCII:Seropedica;ID:6322074', '10067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10067', '112', '11944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11945', '1079', '1', 'Silva Jardim', 'BR.21.3305604', 'ASCII:Silva Jardim;ID:6322075', '10068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10068', '112', '11945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11946', '1079', '1', 'Sumidouro', 'BR.21.3305703', 'ASCII:Sumidouro;ID:6322076', '10069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10069', '112', '11946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11947', '1079', '1', 'Tanguá', 'BR.21.3305752', 'ASCII:Tangua;ID:6322077', '10070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10070', '112', '11947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11948', '1079', '1', 'Teresópolis', 'BR.21.3305802', 'ASCII:Teresopolis;ID:6322078', '10071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10071', '112', '11948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11949', '1079', '1', 'Trajano de Morais', 'BR.21.3305901', 'ASCII:Trajano De Morais;ID:6322079', '10072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10072', '112', '11949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3305901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11950', '1079', '1', 'Três Rios', 'BR.21.3306008', 'ASCII:Tres Rios;ID:6322080', '10073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10073', '112', '11950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3306008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11951', '1079', '1', 'Valença', 'BR.21.3306107', 'ASCII:Valenca;ID:6322081', '10074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10074', '112', '11951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3306107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11952', '1079', '1', 'Varre-Sai', 'BR.21.3306156', 'ASCII:Varre-Sai;ID:6322082', '10075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10075', '112', '11952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3306156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11953', '1079', '1', 'Vassouras', 'BR.21.3306206', 'ASCII:Vassouras;ID:6322083', '10076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10076', '112', '11953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3306206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11954', '1079', '1', 'Volta Redonda', 'BR.21.3306305', 'ASCII:Volta Redonda;ID:6322084', '10077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10077', '112', '11954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3306305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11955', '1079', '1', 'Adolfo', 'BR.27.3500204', 'ASCII:Adolfo;ID:6322085', '10078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10078', '112', '11955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11956', '1079', '1', 'Águas de Lindóia', 'BR.27.3500501', 'ASCII:Aguas De Lindoia;ID:6322086', '10079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10079', '112', '11956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11957', '1079', '1', 'Águas de Santa Bárbara', 'BR.27.3500550', 'ASCII:Aguas De Santa Barbara;ID:6322087', '10080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10080', '112', '11957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11958', '1079', '1', 'Alambari', 'BR.27.3500758', 'ASCII:Alambari;ID:6322088', '10081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10081', '112', '11958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11959', '1079', '1', 'Altair', 'BR.27.3500907', 'ASCII:Altair;ID:6322089', '10082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10082', '112', '11959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3500907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11960', '1079', '1', 'Alumínio', 'BR.27.3501152', 'ASCII:Aluminio;ID:6322090', '10083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10083', '112', '11960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11961', '1079', '1', 'Alvinlândia', 'BR.27.3501509', 'ASCII:Alvinlandia;ID:6322091', '10084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10084', '112', '11961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11962', '1079', '1', 'Américo Brasiliense', 'BR.27.3501707', 'ASCII:Americo Brasiliense;ID:6322092', '10085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10085', '112', '11962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3501707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11963', '1079', '1', 'Andradina', 'BR.27.3502101', 'ASCII:Andradina;ID:6322093', '10086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10086', '112', '11963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11964', '1079', '1', 'Angatuba', 'BR.27.3502200', 'ASCII:Angatuba;ID:6322094', '10087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10087', '112', '11964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11965', '1079', '1', 'Anhembi', 'BR.27.3502309', 'ASCII:Anhembi;ID:6322095', '10088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10088', '112', '11965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11966', '1079', '1', 'Aparecida', 'BR.27.3502507', 'ASCII:Aparecida;ID:6322096', '10089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10089', '112', '11966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11967', '1079', '1', 'Aparecida d''Oeste', 'BR.27.3502606', 'ASCII:Aparecida D''Oeste;ID:6322097', '10090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10090', '112', '11967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11968', '1079', '1', 'Apiaí', 'BR.27.3502705', 'ASCII:Apiai;ID:6322098', '10091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10091', '112', '11968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11969', '1079', '1', 'Araçariguama', 'BR.27.3502754', 'ASCII:Aracariguama;ID:6322099', '10092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10092', '112', '11969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11970', '1079', '1', 'Araçatuba', 'BR.27.3502804', 'ASCII:Aracatuba;ID:6322100', '10093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10093', '112', '11970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11971', '1079', '1', 'Araçoiaba da Serra', 'BR.27.3502903', 'ASCII:Aracoiaba Da Serra;ID:6322101', '10094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10094', '112', '11971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11972', '1079', '1', 'Aramina', 'BR.27.3503000', 'ASCII:Aramina;ID:6322102', '10095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10095', '112', '11972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11973', '1079', '1', 'Arandu', 'BR.27.3503109', 'ASCII:Arandu;ID:6322103', '10096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10096', '112', '11973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11974', '1079', '1', 'Arapeí', 'BR.27.3503158', 'ASCII:Arapei;ID:6322104', '10097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10097', '112', '11974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11975', '1079', '1', 'Araraquara', 'BR.27.3503208', 'ASCII:Araraquara;ID:6322105', '10098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10098', '112', '11975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11976', '1079', '1', 'Araras', 'BR.27.3503307', 'ASCII:Araras;ID:6322106', '10099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10099', '112', '11976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11977', '1079', '1', 'Arco-Íris', 'BR.27.3503356', 'ASCII:Arco-Iris;ID:6322107', '10100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10100', '112', '11977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11978', '1079', '1', 'Areias', 'BR.27.3503505', 'ASCII:Areias;ID:6322108', '10101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10101', '112', '11978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11979', '1079', '1', 'Areiópolis', 'BR.27.3503604', 'ASCII:Areiopolis;ID:6322109', '10102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10102', '112', '11979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11980', '1079', '1', 'Ariranha', 'BR.27.3503703', 'ASCII:Ariranha;ID:6322110', '10103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10103', '112', '11980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11981', '1079', '1', 'Artur Nogueira', 'BR.27.3503802', 'ASCII:Artur Nogueira;ID:6322111', '10104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10104', '112', '11981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11982', '1079', '1', 'Arujá', 'BR.27.3503901', 'ASCII:Aruja;ID:6322112', '10105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10105', '112', '11982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11983', '1079', '1', 'Aspásia', 'BR.27.3503950', 'ASCII:Aspasia;ID:6322113', '10106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10106', '112', '11983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11984', '1079', '1', 'Atibaia', 'BR.27.3504107', 'ASCII:Atibaia;ID:6322114', '10107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10107', '112', '11984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3504107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11985', '1079', '1', 'Auriflama', 'BR.27.3504206', 'ASCII:Auriflama;ID:6322115', '10108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10108', '112', '11985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3504206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11986', '1079', '1', 'Avaí', 'BR.27.3504305', 'ASCII:Avai;ID:6322116', '10109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10109', '112', '11986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3504305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11987', '1079', '1', 'Avanhandava', 'BR.27.3504404', 'ASCII:Avanhandava;ID:6322117', '10110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10110', '112', '11987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3504404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11988', '1079', '1', 'Avaré', 'BR.27.3504503', 'ASCII:Avare;ID:6322118', '10111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10111', '112', '11988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3504503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11989', '1079', '1', 'Bady Bassitt', 'BR.27.3504602', 'ASCII:Bady Bassitt;ID:6322119', '10112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10112', '112', '11989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3504602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11990', '1079', '1', 'Balbinos', 'BR.27.3504701', 'ASCII:Balbinos;ID:6322120', '10113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10113', '112', '11990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3504701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11991', '1079', '1', 'Bálsamo', 'BR.27.3504800', 'ASCII:Balsamo;ID:6322121', '10114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10114', '112', '11991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3504800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11992', '1079', '1', 'Bananal', 'BR.27.3504909', 'ASCII:Bananal;ID:6322122', '10115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10115', '112', '11992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3504909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11993', '1079', '1', 'Barão de Antonina', 'BR.27.3505005', 'ASCII:Barao De Antonina;ID:6322123', '10116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10116', '112', '11993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11994', '1079', '1', 'Bariri', 'BR.27.3505203', 'ASCII:Bariri;ID:6322124', '10117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10117', '112', '11994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11995', '1079', '1', 'Barra Bonita', 'BR.27.3505302', 'ASCII:Barra Bonita;ID:6322125', '10118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10118', '112', '11995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11996', '1079', '1', 'Barra do Chapéu', 'BR.27.3505351', 'ASCII:Barra Do Chapeu;ID:6322126', '10119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10119', '112', '11996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11997', '1079', '1', 'Barra do Turvo', 'BR.27.3505401', 'ASCII:Barra Do Turvo;ID:6322127', '10120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10120', '112', '11997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11998', '1079', '1', 'Barretos', 'BR.27.3505500', 'ASCII:Barretos;ID:6322128', '10121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10121', '112', '11998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('11999', '1079', '1', 'Barrinha', 'BR.27.3505609', 'ASCII:Barrinha;ID:6322129', '10122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10122', '112', '11999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12000', '1079', '1', 'Barueri', 'BR.27.3505708', 'ASCII:Barueri;ID:6322130', '10123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10123', '112', '12000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12001', '1079', '1', 'Bastos', 'BR.27.3505807', 'ASCII:Bastos;ID:6322131', '10124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10124', '112', '12001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12002', '1079', '1', 'Batatais', 'BR.27.3505906', 'ASCII:Batatais;ID:6322132', '10125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10125', '112', '12002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12003', '1079', '1', 'Bauru', 'BR.27.3506003', 'ASCII:Bauru;ID:6322133', '10126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10126', '112', '12003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12004', '1079', '1', 'Bebedouro', 'BR.27.3506102', 'ASCII:Bebedouro;ID:6322134', '10127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10127', '112', '12004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12005', '1079', '1', 'Bento de Abreu', 'BR.27.3506201', 'ASCII:Bento De Abreu;ID:6322135', '10128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10128', '112', '12005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12006', '1079', '1', 'Bernardino de Campos', 'BR.27.3506300', 'ASCII:Bernardino De Campos;ID:6322136', '10129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10129', '112', '12006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12007', '1079', '1', 'Bertioga', 'BR.27.3506359', 'ASCII:Bertioga;ID:6322137', '10130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10130', '112', '12007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12008', '1079', '1', 'Bilac', 'BR.27.3506409', 'ASCII:Bilac;ID:6322138', '10131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10131', '112', '12008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12009', '1079', '1', 'Birigui', 'BR.27.3506508', 'ASCII:Birigui;ID:6322139', '10132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10132', '112', '12009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12010', '1079', '1', 'Biritiba-Mirim', 'BR.27.3506607', 'ASCII:Biritiba-Mirim;ID:6322140', '10133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10133', '112', '12010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12011', '1079', '1', 'Boa Esperança do Sul', 'BR.27.3506706', 'ASCII:Boa Esperanca Do Sul;ID:6322141', '10134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10134', '112', '12011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12012', '1079', '1', 'Bocaina', 'BR.27.3506805', 'ASCII:Bocaina;ID:6322142', '10135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10135', '112', '12012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12013', '1079', '1', 'Bofete', 'BR.27.3506904', 'ASCII:Bofete;ID:6322143', '10136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10136', '112', '12013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3506904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12014', '1079', '1', 'Boituva', 'BR.27.3507001', 'ASCII:Boituva;ID:6322144', '10137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10137', '112', '12014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12015', '1079', '1', 'Bom Jesus dos Perdões', 'BR.27.3507100', 'ASCII:Bom Jesus Dos Perdoes;ID:6322145', '10138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10138', '112', '12015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12016', '1079', '1', 'Bom Sucesso de Itararé', 'BR.27.3507159', 'ASCII:Bom Sucesso De Itarare;ID:6322146', '10139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10139', '112', '12016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12017', '1079', '1', 'Borá', 'BR.27.3507209', 'ASCII:Bora;ID:6322147', '10140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10140', '112', '12017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12018', '1079', '1', 'Boracéia', 'BR.27.3507308', 'ASCII:Boraceia;ID:6322148', '10141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10141', '112', '12018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12019', '1079', '1', 'Borborema', 'BR.27.3507407', 'ASCII:Borborema;ID:6322149', '10142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10142', '112', '12019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12020', '1079', '1', 'Borebi', 'BR.27.3507456', 'ASCII:Borebi;ID:6322150', '10143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10143', '112', '12020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12021', '1079', '1', 'Botucatu', 'BR.27.3507506', 'ASCII:Botucatu;ID:6322151', '10144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10144', '112', '12021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12022', '1079', '1', 'Bragança Paulista', 'BR.27.3507605', 'ASCII:Braganca Paulista;ID:6322152', '10145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10145', '112', '12022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12023', '1079', '1', 'Braúna', 'BR.27.3507704', 'ASCII:Brauna;ID:6322153', '10146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10146', '112', '12023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12024', '1079', '1', 'Brejo Alegre', 'BR.27.3507753', 'ASCII:Brejo Alegre;ID:6322154', '10147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10147', '112', '12024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12025', '1079', '1', 'Brodowski', 'BR.27.3507803', 'ASCII:Brodosqui;ID:6322155', '10148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10148', '112', '12025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12026', '1079', '1', 'Brotas', 'BR.27.3507902', 'ASCII:Brotas;ID:6322156', '10149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10149', '112', '12026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3507902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12027', '1079', '1', 'Buri', 'BR.27.3508009', 'ASCII:Buri;ID:6322157', '10150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10150', '112', '12027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3508009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12028', '1079', '1', 'Buritama', 'BR.27.3508108', 'ASCII:Buritama;ID:6322158', '10151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10151', '112', '12028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3508108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12029', '1079', '1', 'Buritizal', 'BR.27.3508207', 'ASCII:Buritizal;ID:6322159', '10152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10152', '112', '12029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3508207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12030', '1079', '1', 'Cabrália Paulista', 'BR.27.3508306', 'ASCII:Cabralia Paulista;ID:6322160', '10153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10153', '112', '12030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3508306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12031', '1079', '1', 'Cabreúva', 'BR.27.3508405', 'ASCII:Cabreuva;ID:6322161', '10154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10154', '112', '12031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3508405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12032', '1079', '1', 'Caçapava', 'BR.27.3508504', 'ASCII:Cacapava;ID:6322162', '10155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10155', '112', '12032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3508504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12033', '1079', '1', 'Cachoeira Paulista', 'BR.27.3508603', 'ASCII:Cachoeira Paulista;ID:6322163', '10156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10156', '112', '12033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3508603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12034', '1079', '1', 'Caconde', 'BR.27.3508702', 'ASCII:Caconde;ID:6322164', '10157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10157', '112', '12034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3508702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12035', '1079', '1', 'Cafelândia', 'BR.27.3508801', 'ASCII:Cafelandia;ID:6322165', '10158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10158', '112', '12035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3508801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12036', '1079', '1', 'Caiabu', 'BR.27.3508900', 'ASCII:Caiabu;ID:6322166', '10159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10159', '112', '12036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3508900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12037', '1079', '1', 'Caieiras', 'BR.27.3509007', 'ASCII:Caieiras;ID:6322167', '10160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10160', '112', '12037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12038', '1079', '1', 'Caiuá', 'BR.27.3509106', 'ASCII:Caiua;ID:6322168', '10161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10161', '112', '12038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12039', '1079', '1', 'Cajamar', 'BR.27.3509205', 'ASCII:Cajamar;ID:6322169', '10162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10162', '112', '12039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12040', '1079', '1', 'Cajati', 'BR.27.3509254', 'ASCII:Cajati;ID:6322170', '10163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10163', '112', '12040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12041', '1079', '1', 'Cajobi', 'BR.27.3509304', 'ASCII:Cajobi;ID:6322171', '10164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10164', '112', '12041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12042', '1079', '1', 'Cajuru', 'BR.27.3509403', 'ASCII:Cajuru;ID:6322172', '10165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10165', '112', '12042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12043', '1079', '1', 'Campina do Monte Alegre', 'BR.27.3509452', 'ASCII:Campina Do Monte Alegre;ID:6322173', '10166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10166', '112', '12043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12044', '1079', '1', 'Campos do Jordão', 'BR.27.3509700', 'ASCII:Campos Do Jordao;ID:6322174', '10167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10167', '112', '12044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12045', '1079', '1', 'Campos Novos Paulista', 'BR.27.3509809', 'ASCII:Campos Novos Paulista;ID:6322175', '10168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10168', '112', '12045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12046', '1079', '1', 'Cananéia', 'BR.27.3509908', 'ASCII:Cananeia;ID:6322176', '10169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10169', '112', '12046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12047', '1079', '1', 'Canas', 'BR.27.3509957', 'ASCII:Canas;ID:6322177', '10170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10170', '112', '12047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12048', '1079', '1', 'Cândido Mota', 'BR.27.3510005', 'ASCII:Candido Mota;ID:6322178', '10171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10171', '112', '12048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12049', '1079', '1', 'Cândido Rodrigues', 'BR.27.3510104', 'ASCII:Candido Rodrigues;ID:6322179', '10172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10172', '112', '12049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12050', '1079', '1', 'Canitar', 'BR.27.3510153', 'ASCII:Canitar;ID:6322180', '10173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10173', '112', '12050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12051', '1079', '1', 'Capão Bonito', 'BR.27.3510203', 'ASCII:Capao Bonito;ID:6322181', '10174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10174', '112', '12051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12052', '1079', '1', 'Capela do Alto', 'BR.27.3510302', 'ASCII:Capela Do Alto;ID:6322182', '10175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10175', '112', '12052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12053', '1079', '1', 'Capivari', 'BR.27.3510401', 'ASCII:Capivari;ID:6322183', '10176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10176', '112', '12053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12054', '1079', '1', 'Caraguatatuba', 'BR.27.3510500', 'ASCII:Caraguatatuba;ID:6322184', '10177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10177', '112', '12054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12055', '1079', '1', 'Carapicuíba', 'BR.27.3510609', 'ASCII:Carapicuiba;ID:6322185', '10178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10178', '112', '12055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12056', '1079', '1', 'Cardoso', 'BR.27.3510708', 'ASCII:Cardoso;ID:6322186', '10179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10179', '112', '12056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12057', '1079', '1', 'Casa Branca', 'BR.27.3510807', 'ASCII:Casa Branca;ID:6322187', '10180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10180', '112', '12057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12058', '1079', '1', 'Cássia dos Coqueiros', 'BR.27.3510906', 'ASCII:Cassia Dos Coqueiros;ID:6322188', '10181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10181', '112', '12058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3510906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12059', '1079', '1', 'Castilho', 'BR.27.3511003', 'ASCII:Castilho;ID:6322189', '10182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10182', '112', '12059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3511003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12060', '1079', '1', 'Catanduva', 'BR.27.3511102', 'ASCII:Catanduva;ID:6322190', '10183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10183', '112', '12060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3511102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12061', '1079', '1', 'Catiguá', 'BR.27.3511201', 'ASCII:Catigua;ID:6322191', '10184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10184', '112', '12061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3511201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12062', '1079', '1', 'Cedral', 'BR.27.3511300', 'ASCII:Cedral;ID:6322192', '10185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10185', '112', '12062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3511300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12063', '1079', '1', 'Cerqueira César', 'BR.27.3511409', 'ASCII:Cerqueira Cesar;ID:6322193', '10186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10186', '112', '12063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3511409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12064', '1079', '1', 'Cerquilho', 'BR.27.3511508', 'ASCII:Cerquilho;ID:6322194', '10187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10187', '112', '12064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3511508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12065', '1079', '1', 'Cesário Lange', 'BR.27.3511607', 'ASCII:Cesario Lange;ID:6322195', '10188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10188', '112', '12065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3511607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12066', '1079', '1', 'Clementina', 'BR.27.3511904', 'ASCII:Clementina;ID:6322196', '10189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10189', '112', '12066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3511904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12067', '1079', '1', 'Colina', 'BR.27.3512001', 'ASCII:Colina;ID:6322197', '10190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10190', '112', '12067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3512001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12068', '1079', '1', 'Colômbia', 'BR.27.3512100', 'ASCII:Colombia;ID:6322198', '10191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10191', '112', '12068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3512100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12069', '1079', '1', 'Conchal', 'BR.27.3512209', 'ASCII:Conchal;ID:6322199', '10192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10192', '112', '12069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3512209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12070', '1079', '1', 'Conchas', 'BR.27.3512308', 'ASCII:Conchas;ID:6322200', '10193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10193', '112', '12070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3512308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12071', '1079', '1', 'Cordeirópolis', 'BR.27.3512407', 'ASCII:Cordeiropolis;ID:6322201', '10194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10194', '112', '12071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3512407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12072', '1079', '1', 'Coronel Macedo', 'BR.27.3512605', 'ASCII:Coronel Macedo;ID:6322202', '10195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10195', '112', '12072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3512605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12073', '1079', '1', 'Cosmópolis', 'BR.27.3512803', 'ASCII:Cosmopolis;ID:6322203', '10196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10196', '112', '12073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3512803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12074', '1079', '1', 'Cotia', 'BR.27.3513009', 'ASCII:Cotia;ID:6322204', '10197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10197', '112', '12074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12075', '1079', '1', 'Cravinhos', 'BR.27.3513108', 'ASCII:Cravinhos;ID:6322205', '10198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10198', '112', '12075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12076', '1079', '1', 'Cristais Paulista', 'BR.27.3513207', 'ASCII:Cristais Paulista;ID:6322206', '10199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10199', '112', '12076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12077', '1079', '1', 'Cruzália', 'BR.27.3513306', 'ASCII:Cruzalia;ID:6322207', '10200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10200', '112', '12077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12078', '1079', '1', 'Cruzeiro', 'BR.27.3513405', 'ASCII:Cruzeiro;ID:6322208', '10201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10201', '112', '12078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12079', '1079', '1', 'Cubatão', 'BR.27.3513504', 'ASCII:Cubatao;ID:6322209', '10202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10202', '112', '12079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12080', '1079', '1', 'Cunha', 'BR.27.3513603', 'ASCII:Cunha;ID:6322210', '10203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10203', '112', '12080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12081', '1079', '1', 'Descalvado', 'BR.27.3513702', 'ASCII:Descalvado;ID:6322211', '10204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10204', '112', '12081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12082', '1079', '1', 'Diadema', 'BR.27.3513801', 'ASCII:Diadema;ID:6322212', '10205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10205', '112', '12082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12083', '1079', '1', 'Dirce Reis', 'BR.27.3513850', 'ASCII:Dirce Reis;ID:6322213', '10206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10206', '112', '12083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3513850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12084', '1079', '1', 'Dobrada', 'BR.27.3514007', 'ASCII:Dobrada;ID:6322214', '10207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10207', '112', '12084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12085', '1079', '1', 'Dois Córregos', 'BR.27.3514106', 'ASCII:Dois Corregos;ID:6322215', '10208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10208', '112', '12085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12086', '1079', '1', 'Dolcinópolis', 'BR.27.3514205', 'ASCII:Dolcinopolis;ID:6322216', '10209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10209', '112', '12086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12087', '1079', '1', 'Dourado', 'BR.27.3514304', 'ASCII:Dourado;ID:6322217', '10210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10210', '112', '12087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12088', '1079', '1', 'Dracena', 'BR.27.3514403', 'ASCII:Dracena;ID:6322218', '10211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10211', '112', '12088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12089', '1079', '1', 'Duartina', 'BR.27.3514502', 'ASCII:Duartina;ID:6322219', '10212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10212', '112', '12089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12090', '1079', '1', 'Dumont', 'BR.27.3514601', 'ASCII:Dumont;ID:6322220', '10213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10213', '112', '12090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12091', '1079', '1', 'Echaporã', 'BR.27.3514700', 'ASCII:Echapora;ID:6322221', '10214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10214', '112', '12091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12092', '1079', '1', 'Eldorado', 'BR.27.3514809', 'ASCII:Eldorado;ID:6322222', '10215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10215', '112', '12092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12093', '1079', '1', 'Elias Fausto', 'BR.27.3514908', 'ASCII:Elias Fausto;ID:6322223', '10216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10216', '112', '12093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12094', '1079', '1', 'Elisiário', 'BR.27.3514924', 'ASCII:Elisiario;ID:6322224', '10217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10217', '112', '12094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12095', '1079', '1', 'Embaúba', 'BR.27.3514957', 'ASCII:Embauba;ID:6322225', '10218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10218', '112', '12095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3514957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12096', '1079', '1', 'Embu', 'BR.27.3515004', 'ASCII:Embu;ID:6322226', '10219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10219', '112', '12096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12097', '1079', '1', 'Embu-Guaçu', 'BR.27.3515103', 'ASCII:Embu-Guacu;ID:6322227', '10220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10220', '112', '12097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12098', '1079', '1', 'Emilianópolis', 'BR.27.3515129', 'ASCII:Emilianopolis;ID:6322228', '10221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10221', '112', '12098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12099', '1079', '1', 'Engenheiro Coelho', 'BR.27.3515152', 'ASCII:Engenheiro Coelho;ID:6322229', '10222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10222', '112', '12099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12100', '1079', '1', 'Espírito Santo do Pinhal', 'BR.27.3515186', 'ASCII:Espirito Santo Do Pinhal;ID:6322230', '10223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10223', '112', '12100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12101', '1079', '1', 'Espírito Santo do Turvo', 'BR.27.3515194', 'ASCII:Espirito Santo Do Turvo;ID:6322231', '10224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10224', '112', '12101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12102', '1079', '1', 'Estrela d''Oeste', 'BR.27.3515202', 'ASCII:Estrela D''Oeste;ID:6322232', '10225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10225', '112', '12102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12103', '1079', '1', 'Estrela do Norte', 'BR.27.3515301', 'ASCII:Estrela Do Norte;ID:6322233', '10226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10226', '112', '12103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12104', '1079', '1', 'Euclides da Cunha Paulista', 'BR.27.3515350', 'ASCII:Euclides Da Cunha Paulista;ID:6322234', '10227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10227', '112', '12104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12105', '1079', '1', 'Fartura', 'BR.27.3515400', 'ASCII:Fartura;ID:6322235', '10228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10228', '112', '12105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12106', '1079', '1', 'Fernandópolis', 'BR.27.3515509', 'ASCII:Fernandopolis;ID:6322236', '10229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10229', '112', '12106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12107', '1079', '1', 'Fernando Prestes', 'BR.27.3515608', 'ASCII:Fernando Prestes;ID:6322237', '10230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10230', '112', '12107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12108', '1079', '1', 'Fernão', 'BR.27.3515657', 'ASCII:Fernao;ID:6322238', '10231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10231', '112', '12108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12109', '1079', '1', 'Ferraz de Vasconcelos', 'BR.27.3515707', 'ASCII:Ferraz De Vasconcelos;ID:6322239', '10232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10232', '112', '12109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12110', '1079', '1', 'Flora Rica', 'BR.27.3515806', 'ASCII:Flora Rica;ID:6322240', '10233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10233', '112', '12110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12111', '1079', '1', 'Floreal', 'BR.27.3515905', 'ASCII:Floreal;ID:6322241', '10234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10234', '112', '12111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3515905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12112', '1079', '1', 'Flórida Paulista', 'BR.27.3516002', 'ASCII:Florida Paulista;ID:6322242', '10235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10235', '112', '12112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12113', '1079', '1', 'Florínia', 'BR.27.3516101', 'ASCII:Florinia;ID:6322243', '10236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10236', '112', '12113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12114', '1079', '1', 'Francisco Morato', 'BR.27.3516309', 'ASCII:Francisco Morato;ID:6322244', '10237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10237', '112', '12114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12115', '1079', '1', 'Franco da Rocha', 'BR.27.3516408', 'ASCII:Franco Da Rocha;ID:6322245', '10238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10238', '112', '12115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12116', '1079', '1', 'Gabriel Monteiro', 'BR.27.3516507', 'ASCII:Gabriel Monteiro;ID:6322246', '10239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10239', '112', '12116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12117', '1079', '1', 'Gália', 'BR.27.3516606', 'ASCII:Galia;ID:6322247', '10240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10240', '112', '12117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12118', '1079', '1', 'Gastão Vidigal', 'BR.27.3516804', 'ASCII:Gastao Vidigal;ID:6322248', '10241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10241', '112', '12118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12119', '1079', '1', 'Gavião Peixoto', 'BR.27.3516853', 'ASCII:Gaviao Peixoto;ID:6322249', '10242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10242', '112', '12119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12120', '1079', '1', 'General Salgado', 'BR.27.3516903', 'ASCII:General Salgado;ID:6322250', '10243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10243', '112', '12120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12121', '1079', '1', 'Getulina', 'BR.27.3517000', 'ASCII:Getulina;ID:6322251', '10244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10244', '112', '12121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3517000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12122', '1079', '1', 'Glicério', 'BR.27.3517109', 'ASCII:Glicerio;ID:6322252', '10245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10245', '112', '12122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3517109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12123', '1079', '1', 'Guaiçara', 'BR.27.3517208', 'ASCII:Guaicara;ID:6322253', '10246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10246', '112', '12123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3517208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12124', '1079', '1', 'Guaimbê', 'BR.27.3517307', 'ASCII:Guaimbe;ID:6322254', '10247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10247', '112', '12124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3517307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12125', '1079', '1', 'Guaíra', 'BR.27.3517406', 'ASCII:Guaira;ID:6322255', '10248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10248', '112', '12125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3517406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12126', '1079', '1', 'Guapiaçu', 'BR.27.3517505', 'ASCII:Guapiacu;ID:6322256', '10249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10249', '112', '12126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3517505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12127', '1079', '1', 'Guapiara', 'BR.27.3517604', 'ASCII:Guapiara;ID:6322257', '10250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10250', '112', '12127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3517604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12128', '1079', '1', 'Guará', 'BR.27.3517703', 'ASCII:Guara;ID:6322258', '10251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10251', '112', '12128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3517703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12129', '1079', '1', 'Guaraci', 'BR.27.3517901', 'ASCII:Guaraci;ID:6322259', '10252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10252', '112', '12129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3517901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12130', '1079', '1', 'Guarani d''Oeste', 'BR.27.3518008', 'ASCII:Guarani D''Oeste;ID:6322260', '10253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10253', '112', '12130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12131', '1079', '1', 'Guarantã', 'BR.27.3518107', 'ASCII:Guaranta;ID:6322261', '10254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10254', '112', '12131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12132', '1079', '1', 'Guararapes', 'BR.27.3518206', 'ASCII:Guararapes;ID:6322262', '10255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10255', '112', '12132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12133', '1079', '1', 'Guararema', 'BR.27.3518305', 'ASCII:Guararema;ID:6322263', '10256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10256', '112', '12133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12134', '1079', '1', 'Guaratinguetá', 'BR.27.3518404', 'ASCII:Guaratingueta;ID:6322264', '10257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10257', '112', '12134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12135', '1079', '1', 'Guareí', 'BR.27.3518503', 'ASCII:Guarei;ID:6322265', '10258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10258', '112', '12135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12136', '1079', '1', 'Guariba', 'BR.27.3518602', 'ASCII:Guariba;ID:6322266', '10259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10259', '112', '12136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12137', '1079', '1', 'Guarujá', 'BR.27.3518701', 'ASCII:Guaruja;ID:6322267', '10260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10260', '112', '12137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12138', '1079', '1', 'Guarulhos', 'BR.27.3518800', 'ASCII:Guarulhos;ID:6322268', '10261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10261', '112', '12138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12139', '1079', '1', 'Guatapará', 'BR.27.3518859', 'ASCII:Guatapara;ID:6322269', '10262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10262', '112', '12139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12140', '1079', '1', 'Guzolândia', 'BR.27.3518909', 'ASCII:Guzolandia;ID:6322270', '10263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10263', '112', '12140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3518909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12141', '1079', '1', 'Herculândia', 'BR.27.3519006', 'ASCII:Herculandia;ID:6322271', '10264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10264', '112', '12141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12142', '1079', '1', 'Holambra', 'BR.27.3519055', 'ASCII:Holambra;ID:6322272', '10265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10265', '112', '12142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12143', '1079', '1', 'Hortolândia', 'BR.27.3519071', 'ASCII:Hortolandia;ID:6322273', '10266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10266', '112', '12143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12144', '1079', '1', 'Iacri', 'BR.27.3519204', 'ASCII:Iacri;ID:6322274', '10267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10267', '112', '12144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12145', '1079', '1', 'Iaras', 'BR.27.3519253', 'ASCII:Iaras;ID:6322275', '10268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10268', '112', '12145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12146', '1079', '1', 'Ibaté', 'BR.27.3519303', 'ASCII:Ibate;ID:6322276', '10269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10269', '112', '12146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12147', '1079', '1', 'Ibirá', 'BR.27.3519402', 'ASCII:Ibira;ID:6322277', '10270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10270', '112', '12147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12148', '1079', '1', 'Ibirarema', 'BR.27.3519501', 'ASCII:Ibirarema;ID:6322278', '10271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10271', '112', '12148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12149', '1079', '1', 'Ibitinga', 'BR.27.3519600', 'ASCII:Ibitinga;ID:6322279', '10272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10272', '112', '12149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12150', '1079', '1', 'Ibiúna', 'BR.27.3519709', 'ASCII:Ibiuna;ID:6322280', '10273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10273', '112', '12150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12151', '1079', '1', 'Icém', 'BR.27.3519808', 'ASCII:Icem;ID:6322281', '10274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10274', '112', '12151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12152', '1079', '1', 'Iepê', 'BR.27.3519907', 'ASCII:Iepe;ID:6322282', '10275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10275', '112', '12152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12153', '1079', '1', 'Igaraçu do Tietê', 'BR.27.3520004', 'ASCII:Igaracu Do Tiete;ID:6322283', '10276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10276', '112', '12153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12154', '1079', '1', 'Igaratá', 'BR.27.3520202', 'ASCII:Igarata;ID:6322284', '10277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10277', '112', '12154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12155', '1079', '1', 'Iguape', 'BR.27.3520301', 'ASCII:Iguape;ID:6322285', '10278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10278', '112', '12155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12156', '1079', '1', 'Ilhabela', 'BR.27.3520400', 'ASCII:Ilhabela;ID:6322286', '10279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10279', '112', '12156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12157', '1079', '1', 'Ilha Comprida', 'BR.27.3520426', 'ASCII:Ilha Comprida;ID:6322287', '10280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10280', '112', '12157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12158', '1079', '1', 'Ilha Solteira', 'BR.27.3520442', 'ASCII:Ilha Solteira;ID:6322288', '10281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10281', '112', '12158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12159', '1079', '1', 'Indaiatuba', 'BR.27.3520509', 'ASCII:Indaiatuba;ID:6322289', '10282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10282', '112', '12159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12160', '1079', '1', 'Indiana', 'BR.27.3520608', 'ASCII:Indiana;ID:6322290', '10283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10283', '112', '12160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12161', '1079', '1', 'Indiaporã', 'BR.27.3520707', 'ASCII:Indiapora;ID:6322291', '10284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10284', '112', '12161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12162', '1079', '1', 'Inúbia Paulista', 'BR.27.3520806', 'ASCII:Inubia Paulista;ID:6322292', '10285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10285', '112', '12162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12163', '1079', '1', 'Ipaussu', 'BR.27.3520905', 'ASCII:Ipaucu;ID:6322293', '10286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10286', '112', '12163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3520905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12164', '1079', '1', 'Iperó', 'BR.27.3521002', 'ASCII:Ipero;ID:6322294', '10287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10287', '112', '12164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12165', '1079', '1', 'Ipeúna', 'BR.27.3521101', 'ASCII:Ipeuna;ID:6322295', '10288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10288', '112', '12165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12166', '1079', '1', 'Ipiguá', 'BR.27.3521150', 'ASCII:Ipigua;ID:6322296', '10289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10289', '112', '12166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12167', '1079', '1', 'Ipuã', 'BR.27.3521309', 'ASCII:Ipua;ID:6322297', '10290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10290', '112', '12167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12168', '1079', '1', 'Iracemápolis', 'BR.27.3521408', 'ASCII:Iracemapolis;ID:6322298', '10291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10291', '112', '12168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12169', '1079', '1', 'Irapuã', 'BR.27.3521507', 'ASCII:Irapua;ID:6322299', '10292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10292', '112', '12169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12170', '1079', '1', 'Irapuru', 'BR.27.3521606', 'ASCII:Irapuru;ID:6322300', '10293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10293', '112', '12170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12171', '1079', '1', 'Itaberá', 'BR.27.3521705', 'ASCII:Itabera;ID:6322301', '10294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10294', '112', '12171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12172', '1079', '1', 'Itaí', 'BR.27.3521804', 'ASCII:Itai;ID:6322302', '10295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10295', '112', '12172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12173', '1079', '1', 'Itajobi', 'BR.27.3521903', 'ASCII:Itajobi;ID:6322303', '10296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10296', '112', '12173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12174', '1079', '1', 'Itaju', 'BR.27.3522000', 'ASCII:Itaju;ID:6322304', '10297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10297', '112', '12174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12175', '1079', '1', 'Itanhaém', 'BR.27.3522109', 'ASCII:Itanhaem;ID:6322305', '10298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10298', '112', '12175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12176', '1079', '1', 'Itaóca', 'BR.27.3522158', 'ASCII:Itaoca;ID:6322306', '10299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10299', '112', '12176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12177', '1079', '1', 'Itapecerica da Serra', 'BR.27.3522208', 'ASCII:Itapecerica Da Serra;ID:6322307', '10300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10300', '112', '12177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12178', '1079', '1', 'Itapetininga', 'BR.27.3522307', 'ASCII:Itapetininga;ID:6322308', '10301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10301', '112', '12178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12179', '1079', '1', 'Itapeva', 'BR.27.3522406', 'ASCII:Itapeva;ID:6322309', '10302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10302', '112', '12179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12180', '1079', '1', 'Itapevi', 'BR.27.3522505', 'ASCII:Itapevi;ID:6322310', '10303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10303', '112', '12180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12181', '1079', '1', 'Itapirapuã Paulista', 'BR.27.3522653', 'ASCII:Itapirapua Paulista;ID:6322311', '10304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10304', '112', '12181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12182', '1079', '1', 'Itápolis', 'BR.27.3522703', 'ASCII:Itapolis;ID:6322312', '10305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10305', '112', '12182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12183', '1079', '1', 'Itaporanga', 'BR.27.3522802', 'ASCII:Itaporanga;ID:6322313', '10306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10306', '112', '12183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12184', '1079', '1', 'Itapuí', 'BR.27.3522901', 'ASCII:Itapui;ID:6322314', '10307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10307', '112', '12184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12185', '1079', '1', 'Itapura', 'BR.27.3523008', 'ASCII:Itapura;ID:6322315', '10308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10308', '112', '12185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3523008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12186', '1079', '1', 'Itaquaquecetuba', 'BR.27.3523107', 'ASCII:Itaquaquecetuba;ID:6322316', '10309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10309', '112', '12186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3523107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12187', '1079', '1', 'Itararé', 'BR.27.3523206', 'ASCII:Itarare;ID:6322317', '10310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10310', '112', '12187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3523206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12188', '1079', '1', 'Itariri', 'BR.27.3523305', 'ASCII:Itariri;ID:6322318', '10311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10311', '112', '12188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3523305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12189', '1079', '1', 'Itatiba', 'BR.27.3523404', 'ASCII:Itatiba;ID:6322319', '10312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10312', '112', '12189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3523404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12190', '1079', '1', 'Itatinga', 'BR.27.3523503', 'ASCII:Itatinga;ID:6322320', '10313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10313', '112', '12190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3523503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12191', '1079', '1', 'Itirapina', 'BR.27.3523602', 'ASCII:Itirapina;ID:6322321', '10314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10314', '112', '12191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3523602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12192', '1079', '1', 'Itobi', 'BR.27.3523800', 'ASCII:Itobi;ID:6322322', '10315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10315', '112', '12192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3523800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12193', '1079', '1', 'Itu', 'BR.27.3523909', 'ASCII:Itu;ID:6322323', '10316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10316', '112', '12193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3523909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12194', '1079', '1', 'Itupeva', 'BR.27.3524006', 'ASCII:Itupeva;ID:6322324', '10317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10317', '112', '12194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3524006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12195', '1079', '1', 'Ituverava', 'BR.27.3524105', 'ASCII:Ituverava;ID:6322325', '10318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10318', '112', '12195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3524105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12196', '1079', '1', 'Jaborandi', 'BR.27.3524204', 'ASCII:Jaborandi;ID:6322326', '10319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10319', '112', '12196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3524204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12197', '1079', '1', 'Jaboticabal', 'BR.27.3524303', 'ASCII:Jaboticabal;ID:6322327', '10320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10320', '112', '12197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3524303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12198', '1079', '1', 'Jacareí', 'BR.27.3524402', 'ASCII:Jacarei;ID:6322328', '10321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10321', '112', '12198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3524402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12199', '1079', '1', 'Jaci', 'BR.27.3524501', 'ASCII:Jaci;ID:6322329', '10322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10322', '112', '12199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3524501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12200', '1079', '1', 'Jacupiranga', 'BR.27.3524600', 'ASCII:Jacupiranga;ID:6322330', '10323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10323', '112', '12200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3524600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12201', '1079', '1', 'Jaguariúna', 'BR.27.3524709', 'ASCII:Jaguariuna;ID:6322331', '10324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10324', '112', '12201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3524709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12202', '1079', '1', 'Jales', 'BR.27.3524808', 'ASCII:Jales;ID:6322332', '10325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10325', '112', '12202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3524808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12203', '1079', '1', 'Jambeiro', 'BR.27.3524907', 'ASCII:Jambeiro;ID:6322333', '10326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10326', '112', '12203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3524907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12204', '1079', '1', 'Jandira', 'BR.27.3525003', 'ASCII:Jandira;ID:6322334', '10327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10327', '112', '12204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12205', '1079', '1', 'Jaú', 'BR.27.3525300', 'ASCII:Jau;ID:6322335', '10328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10328', '112', '12205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12206', '1079', '1', 'Jeriquara', 'BR.27.3525409', 'ASCII:Jeriquara;ID:6322336', '10329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10329', '112', '12206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12207', '1079', '1', 'Joanópolis', 'BR.27.3525508', 'ASCII:Joanopolis;ID:6322337', '10330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10330', '112', '12207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12208', '1079', '1', 'João Ramalho', 'BR.27.3525607', 'ASCII:Joao Ramalho;ID:6322338', '10331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10331', '112', '12208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12209', '1079', '1', 'Júlio Mesquita', 'BR.27.3525805', 'ASCII:Julio Mesquita;ID:6322339', '10332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10332', '112', '12209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12210', '1079', '1', 'Jumirim', 'BR.27.3525854', 'ASCII:Jumirim;ID:6322340', '10333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10333', '112', '12210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12211', '1079', '1', 'Jundiaí', 'BR.27.3525904', 'ASCII:Jundiai;ID:6322341', '10334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10334', '112', '12211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12212', '1079', '1', 'Junqueirópolis', 'BR.27.3526001', 'ASCII:Junqueiropolis;ID:6322342', '10335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10335', '112', '12212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3526001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12213', '1079', '1', 'Juquiá', 'BR.27.3526100', 'ASCII:Juquia;ID:6322343', '10336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10336', '112', '12213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3526100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12214', '1079', '1', 'Juquitiba', 'BR.27.3526209', 'ASCII:Juquitiba;ID:6322344', '10337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10337', '112', '12214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3526209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12215', '1079', '1', 'Lagoinha', 'BR.27.3526308', 'ASCII:Lagoinha;ID:6322345', '10338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10338', '112', '12215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3526308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12216', '1079', '1', 'Laranjal Paulista', 'BR.27.3526407', 'ASCII:Laranjal Paulista;ID:6322346', '10339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10339', '112', '12216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3526407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12217', '1079', '1', 'Lavínia', 'BR.27.3526506', 'ASCII:Lavinia;ID:6322347', '10340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10340', '112', '12217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3526506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12218', '1079', '1', 'Lavrinhas', 'BR.27.3526605', 'ASCII:Lavrinhas;ID:6322348', '10341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10341', '112', '12218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3526605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12219', '1079', '1', 'Leme', 'BR.27.3526704', 'ASCII:Leme;ID:6322349', '10342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10342', '112', '12219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3526704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12220', '1079', '1', 'Lençóis Paulista', 'BR.27.3526803', 'ASCII:Lencois Paulista;ID:6322350', '10343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10343', '112', '12220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3526803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12221', '1079', '1', 'Limeira', 'BR.27.3526902', 'ASCII:Limeira;ID:6322351', '10344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10344', '112', '12221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3526902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12222', '1079', '1', 'Lins', 'BR.27.3527108', 'ASCII:Lins;ID:6322352', '10345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10345', '112', '12222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12223', '1079', '1', 'Lorena', 'BR.27.3527207', 'ASCII:Lorena;ID:6322353', '10346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10346', '112', '12223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12224', '1079', '1', 'Lourdes', 'BR.27.3527256', 'ASCII:Lourdes;ID:6322354', '10347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10347', '112', '12224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12225', '1079', '1', 'Louveira', 'BR.27.3527306', 'ASCII:Louveira;ID:6322355', '10348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10348', '112', '12225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12226', '1079', '1', 'Lucianópolis', 'BR.27.3527504', 'ASCII:Lucianopolis;ID:6322356', '10349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10349', '112', '12226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12227', '1079', '1', 'Luiziânia', 'BR.27.3527702', 'ASCII:Luiziania;ID:6322357', '10350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10350', '112', '12227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12228', '1079', '1', 'Macatuba', 'BR.27.3528007', 'ASCII:Macatuba;ID:6322358', '10351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10351', '112', '12228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12229', '1079', '1', 'Macaubal', 'BR.27.3528106', 'ASCII:Macaubal;ID:6322359', '10352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10352', '112', '12229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12230', '1079', '1', 'Macedônia', 'BR.27.3528205', 'ASCII:Macedonia;ID:6322360', '10353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10353', '112', '12230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12231', '1079', '1', 'Magda', 'BR.27.3528304', 'ASCII:Magda;ID:6322361', '10354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10354', '112', '12231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12232', '1079', '1', 'Mairinque', 'BR.27.3528403', 'ASCII:Mairinque;ID:6322362', '10355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10355', '112', '12232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12233', '1079', '1', 'Mairiporã', 'BR.27.3528502', 'ASCII:Mairipora;ID:6322363', '10356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10356', '112', '12233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12234', '1079', '1', 'Manduri', 'BR.27.3528601', 'ASCII:Manduri;ID:6322364', '10357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10357', '112', '12234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12235', '1079', '1', 'Marabá Paulista', 'BR.27.3528700', 'ASCII:Maraba Paulista;ID:6322365', '10358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10358', '112', '12235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12236', '1079', '1', 'Maracaí', 'BR.27.3528809', 'ASCII:Maracai;ID:6322366', '10359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10359', '112', '12236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12237', '1079', '1', 'Marapoama', 'BR.27.3528858', 'ASCII:Marapoama;ID:6322367', '10360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10360', '112', '12237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12238', '1079', '1', 'Mariápolis', 'BR.27.3528908', 'ASCII:Mariapolis;ID:6322368', '10361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10361', '112', '12238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3528908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12239', '1079', '1', 'Marília', 'BR.27.3529005', 'ASCII:Marilia;ID:6322369', '10362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10362', '112', '12239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12240', '1079', '1', 'Marinópolis', 'BR.27.3529104', 'ASCII:Marinopolis;ID:6322370', '10363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10363', '112', '12240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12241', '1079', '1', 'Martinópolis', 'BR.27.3529203', 'ASCII:Martinopolis;ID:6322371', '10364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10364', '112', '12241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12242', '1079', '1', 'Matão', 'BR.27.3529302', 'ASCII:Matao;ID:6322372', '10365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10365', '112', '12242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12243', '1079', '1', 'Mauá', 'BR.27.3529401', 'ASCII:Maua;ID:6322373', '10366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10366', '112', '12243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12244', '1079', '1', 'Mendonça', 'BR.27.3529500', 'ASCII:Mendonca;ID:6322374', '10367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10367', '112', '12244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12245', '1079', '1', 'Meridiano', 'BR.27.3529609', 'ASCII:Meridiano;ID:6322375', '10368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10368', '112', '12245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12246', '1079', '1', 'Mesópolis', 'BR.27.3529658', 'ASCII:Mesopolis;ID:6322376', '10369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10369', '112', '12246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12247', '1079', '1', 'Miguelópolis', 'BR.27.3529708', 'ASCII:Miguelopolis;ID:6322377', '10370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10370', '112', '12247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12248', '1079', '1', 'Mineiros do Tietê', 'BR.27.3529807', 'ASCII:Mineiros Do Tiete;ID:6322378', '10371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10371', '112', '12248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12249', '1079', '1', 'Miracatu', 'BR.27.3529906', 'ASCII:Miracatu;ID:6322379', '10372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10372', '112', '12249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3529906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12250', '1079', '1', 'Mira Estrela', 'BR.27.3530003', 'ASCII:Mira Estrela;ID:6322380', '10373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10373', '112', '12250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3530003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12251', '1079', '1', 'Mirandópolis', 'BR.27.3530102', 'ASCII:Mirandopolis;ID:6322381', '10374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10374', '112', '12251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3530102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12252', '1079', '1', 'Mirante do Paranapanema', 'BR.27.3530201', 'ASCII:Mirante Do Paranapanema;ID:6322382', '10375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10375', '112', '12252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3530201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12253', '1079', '1', 'Mirassol', 'BR.27.3530300', 'ASCII:Mirassol;ID:6322383', '10376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10376', '112', '12253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3530300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12254', '1079', '1', 'Mirassolândia', 'BR.27.3530409', 'ASCII:Mirassolandia;ID:6322384', '10377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10377', '112', '12254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3530409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12255', '1079', '1', 'Mococa', 'BR.27.3530508', 'ASCII:Mococa;ID:6322385', '10378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10378', '112', '12255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3530508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12256', '1079', '1', 'Moji das Cruzes', 'BR.27.3530607', 'ASCII:Moji Das Cruzes;ID:6322386', '10379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10379', '112', '12256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3530607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12257', '1079', '1', 'Moji-Mirim', 'BR.27.3530805', 'ASCII:Moji-Mirim;ID:6322387', '10380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10380', '112', '12257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3530805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12258', '1079', '1', 'Mombuca', 'BR.27.3530904', 'ASCII:Mombuca;ID:6322388', '10381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10381', '112', '12258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3530904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12259', '1079', '1', 'Monções', 'BR.27.3531001', 'ASCII:Moncoes;ID:6322389', '10382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10382', '112', '12259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3531001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12260', '1079', '1', 'Mongaguá', 'BR.27.3531100', 'ASCII:Mongagua;ID:6322390', '10383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10383', '112', '12260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3531100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12261', '1079', '1', 'Monte Alegre do Sul', 'BR.27.3531209', 'ASCII:Monte Alegre Do Sul;ID:6322391', '10384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10384', '112', '12261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3531209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12262', '1079', '1', 'Monte Alto', 'BR.27.3531308', 'ASCII:Monte Alto;ID:6322392', '10385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10385', '112', '12262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3531308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12263', '1079', '1', 'Monte Aprazível', 'BR.27.3531407', 'ASCII:Monte Aprazivel;ID:6322393', '10386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10386', '112', '12263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3531407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12264', '1079', '1', 'Monte Azul Paulista', 'BR.27.3531506', 'ASCII:Monte Azul Paulista;ID:6322394', '10387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10387', '112', '12264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3531506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12265', '1079', '1', 'Monte Castelo', 'BR.27.3531605', 'ASCII:Monte Castelo;ID:6322395', '10388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10388', '112', '12265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3531605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12266', '1079', '1', 'Monteiro Lobato', 'BR.27.3531704', 'ASCII:Monteiro Lobato;ID:6322396', '10389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10389', '112', '12266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3531704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12267', '1079', '1', 'Monte Mor', 'BR.27.3531803', 'ASCII:Monte Mor;ID:6322397', '10390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10390', '112', '12267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3531803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12268', '1079', '1', 'Morro Agudo', 'BR.27.3531902', 'ASCII:Morro Agudo;ID:6322398', '10391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10391', '112', '12268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3531902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12269', '1079', '1', 'Morungaba', 'BR.27.3532009', 'ASCII:Morungaba;ID:6322399', '10392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10392', '112', '12269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12270', '1079', '1', 'Motuca', 'BR.27.3532058', 'ASCII:Motuca;ID:6322400', '10393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10393', '112', '12270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12271', '1079', '1', 'Murutinga do Sul', 'BR.27.3532108', 'ASCII:Murutinga Do Sul;ID:6322401', '10394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10394', '112', '12271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12272', '1079', '1', 'Nantes', 'BR.27.3532157', 'ASCII:Nantes;ID:6322402', '10395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10395', '112', '12272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12273', '1079', '1', 'Narandiba', 'BR.27.3532207', 'ASCII:Narandiba;ID:6322403', '10396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10396', '112', '12273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12274', '1079', '1', 'Natividade da Serra', 'BR.27.3532306', 'ASCII:Natividade Da Serra;ID:6322404', '10397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10397', '112', '12274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12275', '1079', '1', 'Nazaré Paulista', 'BR.27.3532405', 'ASCII:Nazare Paulista;ID:6322405', '10398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10398', '112', '12275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12276', '1079', '1', 'Neves Paulista', 'BR.27.3532504', 'ASCII:Neves Paulista;ID:6322406', '10399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10399', '112', '12276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12277', '1079', '1', 'Nhandeara', 'BR.27.3532603', 'ASCII:Nhandeara;ID:6322407', '10400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10400', '112', '12277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12278', '1079', '1', 'Nipoã', 'BR.27.3532702', 'ASCII:Nipoa;ID:6322408', '10401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10401', '112', '12278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12279', '1079', '1', 'Nova Aliança', 'BR.27.3532801', 'ASCII:Nova Alianca;ID:6322409', '10402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10402', '112', '12279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12280', '1079', '1', 'Nova Campina', 'BR.27.3532827', 'ASCII:Nova Campina;ID:6322410', '10403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10403', '112', '12280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12281', '1079', '1', 'Nova Europa', 'BR.27.3532900', 'ASCII:Nova Europa;ID:6322411', '10404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10404', '112', '12281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3532900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12282', '1079', '1', 'Nova Granada', 'BR.27.3533007', 'ASCII:Nova Granada;ID:6322412', '10405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10405', '112', '12282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12283', '1079', '1', 'Nova Guataporanga', 'BR.27.3533106', 'ASCII:Nova Guataporanga;ID:6322413', '10406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10406', '112', '12283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12284', '1079', '1', 'Nova Independência', 'BR.27.3533205', 'ASCII:Nova Independencia;ID:6322414', '10407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10407', '112', '12284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12285', '1079', '1', 'Novais', 'BR.27.3533254', 'ASCII:Novais;ID:6322415', '10408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10408', '112', '12285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12286', '1079', '1', 'Nova Luzitânia', 'BR.27.3533304', 'ASCII:Nova Luzitania;ID:6322416', '10409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10409', '112', '12286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12287', '1079', '1', 'Novo Horizonte', 'BR.27.3533502', 'ASCII:Novo Horizonte;ID:6322417', '10410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10410', '112', '12287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12288', '1079', '1', 'Nuporanga', 'BR.27.3533601', 'ASCII:Nuporanga;ID:6322418', '10411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10411', '112', '12288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12289', '1079', '1', 'Ocauçu', 'BR.27.3533700', 'ASCII:Ocaucu;ID:6322419', '10412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10412', '112', '12289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12290', '1079', '1', 'Óleo', 'BR.27.3533809', 'ASCII:Oleo;ID:6322420', '10413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10413', '112', '12290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12291', '1079', '1', 'Olímpia', 'BR.27.3533908', 'ASCII:Olimpia;ID:6322421', '10414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10414', '112', '12291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12292', '1079', '1', 'Onda Verde', 'BR.27.3534005', 'ASCII:Onda Verde;ID:6322422', '10415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10415', '112', '12292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12293', '1079', '1', 'Oriente', 'BR.27.3534104', 'ASCII:Oriente;ID:6322423', '10416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10416', '112', '12293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12294', '1079', '1', 'Orindiúva', 'BR.27.3534203', 'ASCII:Orindiuva;ID:6322424', '10417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10417', '112', '12294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12295', '1079', '1', 'Orlândia', 'BR.27.3534302', 'ASCII:Orlandia;ID:6322425', '10418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10418', '112', '12295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12296', '1079', '1', 'Osasco', 'BR.27.3534401', 'ASCII:Osasco;ID:6322426', '10419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10419', '112', '12296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12297', '1079', '1', 'Oscar Bressane', 'BR.27.3534500', 'ASCII:Oscar Bressane;ID:6322427', '10420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10420', '112', '12297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12298', '1079', '1', 'Osvaldo Cruz', 'BR.27.3534609', 'ASCII:Osvaldo Cruz;ID:6322428', '10421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10421', '112', '12298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12299', '1079', '1', 'Ourinhos', 'BR.27.3534708', 'ASCII:Ourinhos;ID:6322429', '10422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10422', '112', '12299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12300', '1079', '1', 'Ouroeste', 'BR.27.3534757', 'ASCII:Ouroeste;ID:6322430', '10423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10423', '112', '12300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12301', '1079', '1', 'Ouro Verde', 'BR.27.3534807', 'ASCII:Ouro Verde;ID:6322431', '10424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10424', '112', '12301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12302', '1079', '1', 'Pacaembu', 'BR.27.3534906', 'ASCII:Pacaembu;ID:6322432', '10425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10425', '112', '12302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3534906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12303', '1079', '1', 'Palestina', 'BR.27.3535002', 'ASCII:Palestina;ID:6322433', '10426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10426', '112', '12303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3535002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12304', '1079', '1', 'Palmares Paulista', 'BR.27.3535101', 'ASCII:Palmares Paulista;ID:6322434', '10427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10427', '112', '12304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3535101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12305', '1079', '1', 'Palmeira d''Oeste', 'BR.27.3535200', 'ASCII:Palmeira D''Oeste;ID:6322435', '10428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10428', '112', '12305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3535200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12306', '1079', '1', 'Palmital', 'BR.27.3535309', 'ASCII:Palmital;ID:6322436', '10429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10429', '112', '12306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3535309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12307', '1079', '1', 'Panorama', 'BR.27.3535408', 'ASCII:Panorama;ID:6322437', '10430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10430', '112', '12307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3535408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12308', '1079', '1', 'Paraguaçu Paulista', 'BR.27.3535507', 'ASCII:Paraguacu Paulista;ID:6322438', '10431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10431', '112', '12308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3535507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12309', '1079', '1', 'Paraibuna', 'BR.27.3535606', 'ASCII:Paraibuna;ID:6322439', '10432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10432', '112', '12309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3535606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12310', '1079', '1', 'Paraíso', 'BR.27.3535705', 'ASCII:Paraiso;ID:6322440', '10433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10433', '112', '12310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3535705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12311', '1079', '1', 'Paranapanema', 'BR.27.3535804', 'ASCII:Paranapanema;ID:6322441', '10434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10434', '112', '12311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3535804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12312', '1079', '1', 'Paranapuã', 'BR.27.3535903', 'ASCII:Paranapua;ID:6322442', '10435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10435', '112', '12312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3535903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12313', '1079', '1', 'Parapuã', 'BR.27.3536000', 'ASCII:Parapua;ID:6322443', '10436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10436', '112', '12313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12314', '1079', '1', 'Pardinho', 'BR.27.3536109', 'ASCII:Pardinho;ID:6322444', '10437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10437', '112', '12314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12315', '1079', '1', 'Pariquera-Açu', 'BR.27.3536208', 'ASCII:Pariquera-Acu;ID:6322445', '10438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10438', '112', '12315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12316', '1079', '1', 'Parisi', 'BR.27.3536257', 'ASCII:Parisi;ID:6322446', '10439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10439', '112', '12316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12317', '1079', '1', 'Paulicéia', 'BR.27.3536406', 'ASCII:Pauliceia;ID:6322447', '10440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10440', '112', '12317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12318', '1079', '1', 'Paulínia', 'BR.27.3536505', 'ASCII:Paulinia;ID:6322448', '10441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10441', '112', '12318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12319', '1079', '1', 'Paulo de Faria', 'BR.27.3536604', 'ASCII:Paulo De Faria;ID:6322449', '10442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10442', '112', '12319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12320', '1079', '1', 'Pederneiras', 'BR.27.3536703', 'ASCII:Pederneiras;ID:6322450', '10443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10443', '112', '12320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12321', '1079', '1', 'Pedra Bela', 'BR.27.3536802', 'ASCII:Pedra Bela;ID:6322451', '10444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10444', '112', '12321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12322', '1079', '1', 'Pedranópolis', 'BR.27.3536901', 'ASCII:Pedranopolis;ID:6322452', '10445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10445', '112', '12322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12323', '1079', '1', 'Pedregulho', 'BR.27.3537008', 'ASCII:Pedregulho;ID:6322453', '10446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10446', '112', '12323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12324', '1079', '1', 'Pedrinhas Paulista', 'BR.27.3537156', 'ASCII:Pedrinhas Paulista;ID:6322454', '10447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10447', '112', '12324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12325', '1079', '1', 'Pedro de Toledo', 'BR.27.3537206', 'ASCII:Pedro De Toledo;ID:6322455', '10448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10448', '112', '12325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12326', '1079', '1', 'Pereira Barreto', 'BR.27.3537404', 'ASCII:Pereira Barreto;ID:6322456', '10449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10449', '112', '12326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12327', '1079', '1', 'Pereiras', 'BR.27.3537503', 'ASCII:Pereiras;ID:6322457', '10450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10450', '112', '12327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12328', '1079', '1', 'Peruíbe', 'BR.27.3537602', 'ASCII:Peruibe;ID:6322458', '10451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10451', '112', '12328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12329', '1079', '1', 'Piacatu', 'BR.27.3537701', 'ASCII:Piacatu;ID:6322459', '10452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10452', '112', '12329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12330', '1079', '1', 'Piedade', 'BR.27.3537800', 'ASCII:Piedade;ID:6322460', '10453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10453', '112', '12330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12331', '1079', '1', 'Pilar do Sul', 'BR.27.3537909', 'ASCII:Pilar Do Sul;ID:6322461', '10454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10454', '112', '12331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12332', '1079', '1', 'Pindamonhangaba', 'BR.27.3538006', 'ASCII:Pindamonhangaba;ID:6322462', '10455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10455', '112', '12332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3538006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12333', '1079', '1', 'Pindorama', 'BR.27.3538105', 'ASCII:Pindorama;ID:6322463', '10456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10456', '112', '12333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3538105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12334', '1079', '1', 'Pinhalzinho', 'BR.27.3538204', 'ASCII:Pinhalzinho;ID:6322464', '10457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10457', '112', '12334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3538204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12335', '1079', '1', 'Piquerobi', 'BR.27.3538303', 'ASCII:Piquerobi;ID:6322465', '10458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10458', '112', '12335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3538303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12336', '1079', '1', 'Piquete', 'BR.27.3538501', 'ASCII:Piquete;ID:6322466', '10459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10459', '112', '12336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3538501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12337', '1079', '1', 'Piracaia', 'BR.27.3538600', 'ASCII:Piracaia;ID:6322467', '10460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10460', '112', '12337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3538600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12338', '1079', '1', 'Piraju', 'BR.27.3538808', 'ASCII:Piraju;ID:6322468', '10461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10461', '112', '12338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3538808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12339', '1079', '1', 'Pirajuí', 'BR.27.3538907', 'ASCII:Pirajui;ID:6322469', '10462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10462', '112', '12339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3538907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12340', '1079', '1', 'Pirangi', 'BR.27.3539004', 'ASCII:Pirangi;ID:6322470', '10463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10463', '112', '12340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3539004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12341', '1079', '1', 'Pirapora do Bom Jesus', 'BR.27.3539103', 'ASCII:Pirapora Do Bom Jesus;ID:6322471', '10464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10464', '112', '12341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3539103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12342', '1079', '1', 'Pirassununga', 'BR.27.3539301', 'ASCII:Pirassununga;ID:6322472', '10465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10465', '112', '12342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3539301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12343', '1079', '1', 'Pitangueiras', 'BR.27.3539509', 'ASCII:Pitangueiras;ID:6322473', '10466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10466', '112', '12343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3539509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12344', '1079', '1', 'Planalto', 'BR.27.3539608', 'ASCII:Planalto;ID:6322474', '10467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10467', '112', '12344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3539608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12345', '1079', '1', 'Platina', 'BR.27.3539707', 'ASCII:Platina;ID:6322475', '10468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10468', '112', '12345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3539707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12346', '1079', '1', 'Poá', 'BR.27.3539806', 'ASCII:Poa;ID:6322476', '10469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10469', '112', '12346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3539806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12347', '1079', '1', 'Poloni', 'BR.27.3539905', 'ASCII:Poloni;ID:6322477', '10470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10470', '112', '12347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3539905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12348', '1079', '1', 'Pompéia', 'BR.27.3540002', 'ASCII:Pompeia;ID:6322478', '10471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10471', '112', '12348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12349', '1079', '1', 'Pongaí', 'BR.27.3540101', 'ASCII:Pongai;ID:6322479', '10472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10472', '112', '12349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12350', '1079', '1', 'Pontal', 'BR.27.3540200', 'ASCII:Pontal;ID:6322480', '10473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10473', '112', '12350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12351', '1079', '1', 'Pontalinda', 'BR.27.3540259', 'ASCII:Pontalinda;ID:6322481', '10474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10474', '112', '12351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12352', '1079', '1', 'Populina', 'BR.27.3540408', 'ASCII:Populina;ID:6322482', '10475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10475', '112', '12352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12353', '1079', '1', 'Porangaba', 'BR.27.3540507', 'ASCII:Porangaba;ID:6322483', '10476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10476', '112', '12353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12354', '1079', '1', 'Porto Feliz', 'BR.27.3540606', 'ASCII:Porto Feliz;ID:6322484', '10477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10477', '112', '12354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12355', '1079', '1', 'Porto Ferreira', 'BR.27.3540705', 'ASCII:Porto Ferreira;ID:6322485', '10478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10478', '112', '12355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12356', '1079', '1', 'Potim', 'BR.27.3540754', 'ASCII:Potim;ID:6322486', '10479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10479', '112', '12356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12357', '1079', '1', 'Potirendaba', 'BR.27.3540804', 'ASCII:Potirendaba;ID:6322487', '10480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10480', '112', '12357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12358', '1079', '1', 'Pracinha', 'BR.27.3540853', 'ASCII:Pracinha;ID:6322488', '10481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10481', '112', '12358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12359', '1079', '1', 'Pradópolis', 'BR.27.3540903', 'ASCII:Pradopolis;ID:6322489', '10482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10482', '112', '12359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12360', '1079', '1', 'Pratânia', 'BR.27.3541059', 'ASCII:Pratania;ID:6322490', '10483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10483', '112', '12360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12361', '1079', '1', 'Presidente Alves', 'BR.27.3541109', 'ASCII:Presidente Alves;ID:6322491', '10484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10484', '112', '12361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12362', '1079', '1', 'Presidente Epitácio', 'BR.27.3541307', 'ASCII:Presidente Epitacio;ID:6322492', '10485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10485', '112', '12362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12363', '1079', '1', 'Presidente Venceslau', 'BR.27.3541505', 'ASCII:Presidente Venceslau;ID:6322493', '10486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10486', '112', '12363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12364', '1079', '1', 'Promissão', 'BR.27.3541604', 'ASCII:Promissao;ID:6322494', '10487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10487', '112', '12364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12365', '1079', '1', 'Quadra', 'BR.27.3541653', 'ASCII:Quadra;ID:6322495', '10488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10488', '112', '12365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12366', '1079', '1', 'Quatá', 'BR.27.3541703', 'ASCII:Quata;ID:6322496', '10489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10489', '112', '12366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12367', '1079', '1', 'Queiroz', 'BR.27.3541802', 'ASCII:Queiroz;ID:6322497', '10490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10490', '112', '12367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12368', '1079', '1', 'Queluz', 'BR.27.3541901', 'ASCII:Queluz;ID:6322498', '10491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10491', '112', '12368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12369', '1079', '1', 'Quintana', 'BR.27.3542008', 'ASCII:Quintana;ID:6322499', '10492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10492', '112', '12369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3542008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12370', '1079', '1', 'Rafard', 'BR.27.3542107', 'ASCII:Rafard;ID:6322500', '10493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10493', '112', '12370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3542107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12371', '1079', '1', 'Rancharia', 'BR.27.3542206', 'ASCII:Rancharia;ID:6322501', '10494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10494', '112', '12371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3542206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12372', '1079', '1', 'Redenção da Serra', 'BR.27.3542305', 'ASCII:Redencao Da Serra;ID:6322502', '10495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10495', '112', '12372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3542305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12373', '1079', '1', 'Regente Feijó', 'BR.27.3542404', 'ASCII:Regente Feijo;ID:6322503', '10496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10496', '112', '12373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3542404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12374', '1079', '1', 'Reginópolis', 'BR.27.3542503', 'ASCII:Reginopolis;ID:6322504', '10497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10497', '112', '12374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3542503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12375', '1079', '1', 'Registro', 'BR.27.3542602', 'ASCII:Registro;ID:6322505', '10498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10498', '112', '12375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3542602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12376', '1079', '1', 'Restinga', 'BR.27.3542701', 'ASCII:Restinga;ID:6322506', '10499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10499', '112', '12376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3542701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12377', '1079', '1', 'Ribeira', 'BR.27.3542800', 'ASCII:Ribeira;ID:6322507', '10500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10500', '112', '12377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3542800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12378', '1079', '1', 'Ribeirão Bonito', 'BR.27.3542909', 'ASCII:Ribeirao Bonito;ID:6322508', '10501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10501', '112', '12378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3542909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12379', '1079', '1', 'Ribeirão Branco', 'BR.27.3543006', 'ASCII:Ribeirao Branco;ID:6322509', '10502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10502', '112', '12379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12380', '1079', '1', 'Ribeirão Corrente', 'BR.27.3543105', 'ASCII:Ribeirao Corrente;ID:6322510', '10503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10503', '112', '12380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12381', '1079', '1', 'Ribeirão do Sul', 'BR.27.3543204', 'ASCII:Ribeirao Do Sul;ID:6322511', '10504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10504', '112', '12381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12382', '1079', '1', 'Ribeirão dos Índios', 'BR.27.3543238', 'ASCII:Ribeirao Dos Indios;ID:6322512', '10505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10505', '112', '12382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12383', '1079', '1', 'Ribeirão Grande', 'BR.27.3543253', 'ASCII:Ribeirao Grande;ID:6322513', '10506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10506', '112', '12383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12384', '1079', '1', 'Ribeirão Pires', 'BR.27.3543303', 'ASCII:Ribeirao Pires;ID:6322514', '10507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10507', '112', '12384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12385', '1079', '1', 'Ribeirão Preto', 'BR.27.3543402', 'ASCII:Ribeirao Preto;ID:6322515', '10508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10508', '112', '12385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12386', '1079', '1', 'Riversul', 'BR.27.3543501', 'ASCII:Riversul;ID:6322516', '10509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10509', '112', '12386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12387', '1079', '1', 'Rifaina', 'BR.27.3543600', 'ASCII:Rifaina;ID:6322517', '10510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10510', '112', '12387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12388', '1079', '1', 'Rincão', 'BR.27.3543709', 'ASCII:Rincao;ID:6322518', '10511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10511', '112', '12388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12389', '1079', '1', 'Rinópolis', 'BR.27.3543808', 'ASCII:Rinopolis;ID:6322519', '10512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10512', '112', '12389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12390', '1079', '1', 'Rio Claro', 'BR.27.3543907', 'ASCII:Rio Claro;ID:6322520', '10513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10513', '112', '12390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3543907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12391', '1079', '1', 'Rio das Pedras', 'BR.27.3544004', 'ASCII:Rio Das Pedras;ID:6322521', '10514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10514', '112', '12391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12392', '1079', '1', 'Rio Grande da Serra', 'BR.27.3544103', 'ASCII:Rio Grande Da Serra;ID:6322522', '10515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10515', '112', '12392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12393', '1079', '1', 'Rosana', 'BR.27.3544251', 'ASCII:Rosana;ID:6322523', '10516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10516', '112', '12393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12394', '1079', '1', 'Roseira', 'BR.27.3544301', 'ASCII:Roseira;ID:6322524', '10517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10517', '112', '12394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12395', '1079', '1', 'Rubiácea', 'BR.27.3544400', 'ASCII:Rubiacea;ID:6322525', '10518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10518', '112', '12395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12396', '1079', '1', 'Rubinéia', 'BR.27.3544509', 'ASCII:Rubineia;ID:6322526', '10519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10519', '112', '12396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12397', '1079', '1', 'Sabino', 'BR.27.3544608', 'ASCII:Sabino;ID:6322527', '10520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10520', '112', '12397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12398', '1079', '1', 'Sagres', 'BR.27.3544707', 'ASCII:Sagres;ID:6322528', '10521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10521', '112', '12398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12399', '1079', '1', 'Sales Oliveira', 'BR.27.3544905', 'ASCII:Sales Oliveira;ID:6322529', '10522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10522', '112', '12399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12400', '1079', '1', 'Salesópolis', 'BR.27.3545001', 'ASCII:Salesopolis;ID:6322530', '10523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10523', '112', '12400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3545001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12401', '1079', '1', 'Salmourão', 'BR.27.3545100', 'ASCII:Salmourao;ID:6322531', '10524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10524', '112', '12401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3545100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12402', '1079', '1', 'Salto', 'BR.27.3545209', 'ASCII:Salto;ID:6322532', '10525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10525', '112', '12402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3545209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12403', '1079', '1', 'Salto de Pirapora', 'BR.27.3545308', 'ASCII:Salto De Pirapora;ID:6322533', '10526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10526', '112', '12403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3545308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12404', '1079', '1', 'Salto Grande', 'BR.27.3545407', 'ASCII:Salto Grande;ID:6322534', '10527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10527', '112', '12404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3545407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12405', '1079', '1', 'Sandovalina', 'BR.27.3545506', 'ASCII:Sandovalina;ID:6322535', '10528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10528', '112', '12405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3545506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12406', '1079', '1', 'Santa Adélia', 'BR.27.3545605', 'ASCII:Santa Adelia;ID:6322536', '10529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10529', '112', '12406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3545605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12407', '1079', '1', 'Santa Albertina', 'BR.27.3545704', 'ASCII:Santa Albertina;ID:6322537', '10530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10530', '112', '12407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3545704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12408', '1079', '1', 'Santa Bárbara d''Oeste', 'BR.27.3545803', 'ASCII:Santa Barbara D''Oeste;ID:6322538', '10531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10531', '112', '12408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3545803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12409', '1079', '1', 'Santa Branca', 'BR.27.3546009', 'ASCII:Santa Branca;ID:6322539', '10532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10532', '112', '12409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12410', '1079', '1', 'Santa Clara d''Oeste', 'BR.27.3546108', 'ASCII:Santa Clara D''Oeste;ID:6322540', '10533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10533', '112', '12410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12411', '1079', '1', 'Santa Cruz da Esperança', 'BR.27.3546256', 'ASCII:Santa Cruz Da Esperanca;ID:6322541', '10534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10534', '112', '12411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12412', '1079', '1', 'Santa Cruz das Palmeiras', 'BR.27.3546306', 'ASCII:Santa Cruz Das Palmeiras;ID:6322542', '10535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10535', '112', '12412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12413', '1079', '1', 'Santa Cruz do Rio Pardo', 'BR.27.3546405', 'ASCII:Santa Cruz Do Rio Pardo;ID:6322543', '10536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10536', '112', '12413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12414', '1079', '1', 'Santa Ernestina', 'BR.27.3546504', 'ASCII:Santa Ernestina;ID:6322544', '10537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10537', '112', '12414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12415', '1079', '1', 'Santa Fé do Sul', 'BR.27.3546603', 'ASCII:Santa Fe Do Sul;ID:6322545', '10538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10538', '112', '12415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12416', '1079', '1', 'Santa Gertrudes', 'BR.27.3546702', 'ASCII:Santa Gertrudes;ID:6322546', '10539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10539', '112', '12416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12417', '1079', '1', 'Santa Isabel', 'BR.27.3546801', 'ASCII:Santa Isabel;ID:6322547', '10540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10540', '112', '12417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12418', '1079', '1', 'Santa Lúcia', 'BR.27.3546900', 'ASCII:Santa Lucia;ID:6322548', '10541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10541', '112', '12418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12419', '1079', '1', 'Santa Maria da Serra', 'BR.27.3547007', 'ASCII:Santa Maria Da Serra;ID:6322549', '10542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10542', '112', '12419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12420', '1079', '1', 'Santa Mercedes', 'BR.27.3547106', 'ASCII:Santa Mercedes;ID:6322550', '10543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10543', '112', '12420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12421', '1079', '1', 'Santana da Ponte Pensa', 'BR.27.3547205', 'ASCII:Santana Da Ponte Pensa;ID:6322551', '10544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10544', '112', '12421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12422', '1079', '1', 'Santana de Parnaíba', 'BR.27.3547304', 'ASCII:Santana De Parnaiba;ID:6322552', '10545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10545', '112', '12422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12423', '1079', '1', 'Santa Rita d''Oeste', 'BR.27.3547403', 'ASCII:Santa Rita D''Oeste;ID:6322553', '10546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10546', '112', '12423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12424', '1079', '1', 'Santa Rita do Passa Quatro', 'BR.27.3547502', 'ASCII:Santa Rita Do Passa Quatro;ID:6322554', '10547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10547', '112', '12424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12425', '1079', '1', 'Santa Rosa de Viterbo', 'BR.27.3547601', 'ASCII:Santa Rosa De Viterbo;ID:6322555', '10548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10548', '112', '12425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12426', '1079', '1', 'Santa Salete', 'BR.27.3547650', 'ASCII:Santa Salete;ID:6322556', '10549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10549', '112', '12426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12427', '1079', '1', 'Santo Anastácio', 'BR.27.3547700', 'ASCII:Santo Anastacio;ID:6322557', '10550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10550', '112', '12427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12428', '1079', '1', 'Santo André', 'BR.27.3547809', 'ASCII:Santo Andre;ID:6322558', '10551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10551', '112', '12428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12429', '1079', '1', 'Santo Antônio da Alegria', 'BR.27.3547908', 'ASCII:Santo Antonio Da Alegria;ID:6322559', '10552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10552', '112', '12429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3547908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12430', '1079', '1', 'Santo Antônio de Posse', 'BR.27.3548005', 'ASCII:Santo Antonio De Posse;ID:6322560', '10553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10553', '112', '12430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12431', '1079', '1', 'Santo Antônio do Aracanguá', 'BR.27.3548054', 'ASCII:Santo Antonio Do Aracangua;ID:6322561', '10554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10554', '112', '12431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12432', '1079', '1', 'Santo Antônio do Jardim', 'BR.27.3548104', 'ASCII:Santo Antonio Do Jardim;ID:6322562', '10555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10555', '112', '12432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12433', '1079', '1', 'Santo Antônio do Pinhal', 'BR.27.3548203', 'ASCII:Santo Antonio Do Pinhal;ID:6322563', '10556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10556', '112', '12433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12434', '1079', '1', 'Santo Expedito', 'BR.27.3548302', 'ASCII:Santo Expedito;ID:6322564', '10557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10557', '112', '12434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12435', '1079', '1', 'Santópolis do Aguapeí', 'BR.27.3548401', 'ASCII:Santopolis Do Aguapei;ID:6322565', '10558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10558', '112', '12435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12436', '1079', '1', 'Santos', 'BR.27.3548500', 'ASCII:Santos;ID:6322566', '10559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10559', '112', '12436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12437', '1079', '1', 'São Bento do Sapucaí', 'BR.27.3548609', 'ASCII:Sao Bento Do Sapucai;ID:6322567', '10560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10560', '112', '12437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12438', '1079', '1', 'São Caetano do Sul', 'BR.27.3548807', 'ASCII:Sao Caetano Do Sul;ID:6322568', '10561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10561', '112', '12438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12439', '1079', '1', 'São Carlos', 'BR.27.3548906', 'ASCII:Sao Carlos;ID:6322569', '10562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10562', '112', '12439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12440', '1079', '1', 'São João das Duas Pontes', 'BR.27.3549201', 'ASCII:Sao Joao Das Duas Pontes;ID:6322570', '10563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10563', '112', '12440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12441', '1079', '1', 'São João de Iracema', 'BR.27.3549250', 'ASCII:Sao Joao De Iracema;ID:6322571', '10564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10564', '112', '12441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12442', '1079', '1', 'São João do Pau d''Alho', 'BR.27.3549300', 'ASCII:Sao Joao Do Pau D''Alho;ID:6322572', '10565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10565', '112', '12442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12443', '1079', '1', 'São Joaquim da Barra', 'BR.27.3549409', 'ASCII:Sao Joaquim Da Barra;ID:6322573', '10566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10566', '112', '12443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12444', '1079', '1', 'São José da Bela Vista', 'BR.27.3549508', 'ASCII:Sao Jose Da Bela Vista;ID:6322574', '10567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10567', '112', '12444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12445', '1079', '1', 'São José do Barreiro', 'BR.27.3549607', 'ASCII:Sao Jose Do Barreiro;ID:6322575', '10568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10568', '112', '12445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12446', '1079', '1', 'São José do Rio Pardo', 'BR.27.3549706', 'ASCII:Sao Jose Do Rio Pardo;ID:6322576', '10569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10569', '112', '12446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12447', '1079', '1', 'São José do Rio Preto', 'BR.27.3549805', 'ASCII:Sao Jose Do Rio Preto;ID:6322577', '10570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10570', '112', '12447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12448', '1079', '1', 'São José dos Campos', 'BR.27.3549904', 'ASCII:Sao Jose Dos Campos;ID:6322578', '10571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10571', '112', '12448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12449', '1079', '1', 'São Lourenço da Serra', 'BR.27.3549953', 'ASCII:Sao Lourenco Da Serra;ID:6322579', '10572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10572', '112', '12449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12450', '1079', '1', 'São Luís do Paraitinga', 'BR.27.3550001', 'ASCII:Sao Luis Do Paraitinga;ID:6322580', '10573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10573', '112', '12450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3550001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12451', '1079', '1', 'São Manuel', 'BR.27.3550100', 'ASCII:Sao Manuel;ID:6322581', '10574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10574', '112', '12451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3550100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12452', '1079', '1', 'São Miguel Arcanjo', 'BR.27.3550209', 'ASCII:Sao Miguel Arcanjo;ID:6322582', '10575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10575', '112', '12452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3550209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12453', '1079', '1', 'São Pedro do Turvo', 'BR.27.3550506', 'ASCII:Sao Pedro Do Turvo;ID:6322583', '10576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10576', '112', '12453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3550506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12454', '1079', '1', 'São Roque', 'BR.27.3550605', 'ASCII:Sao Roque;ID:6322584', '10577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10577', '112', '12454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3550605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12455', '1079', '1', 'São Sebastião', 'BR.27.3550704', 'ASCII:Sao Sebastiao;ID:6322585', '10578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10578', '112', '12455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3550704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12456', '1079', '1', 'São Sebastião da Grama', 'BR.27.3550803', 'ASCII:Sao Sebastiao Da Grama;ID:6322586', '10579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10579', '112', '12456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3550803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12457', '1079', '1', 'São Simão', 'BR.27.3550902', 'ASCII:Sao Simao;ID:6322587', '10580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10580', '112', '12457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3550902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12458', '1079', '1', 'Sarapuí', 'BR.27.3551108', 'ASCII:Sarapui;ID:6322588', '10581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10581', '112', '12458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3551108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12459', '1079', '1', 'Sarutaiá', 'BR.27.3551207', 'ASCII:Sarutaia;ID:6322589', '10582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10582', '112', '12459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3551207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12460', '1079', '1', 'Sebastianópolis do Sul', 'BR.27.3551306', 'ASCII:Sebastianopolis Do Sul;ID:6322590', '10583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10583', '112', '12460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3551306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12461', '1079', '1', 'Serra Azul', 'BR.27.3551405', 'ASCII:Serra Azul;ID:6322591', '10584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10584', '112', '12461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3551405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12462', '1079', '1', 'Serrana', 'BR.27.3551504', 'ASCII:Serrana;ID:6322592', '10585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10585', '112', '12462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3551504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12463', '1079', '1', 'Serra Negra', 'BR.27.3551603', 'ASCII:Serra Negra;ID:6322593', '10586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10586', '112', '12463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3551603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12464', '1079', '1', 'Sete Barras', 'BR.27.3551801', 'ASCII:Sete Barras;ID:6322594', '10587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10587', '112', '12464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3551801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12465', '1079', '1', 'Severínia', 'BR.27.3551900', 'ASCII:Severinia;ID:6322595', '10588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10588', '112', '12465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3551900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12466', '1079', '1', 'Silveiras', 'BR.27.3552007', 'ASCII:Silveiras;ID:6322596', '10589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10589', '112', '12466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12467', '1079', '1', 'Socorro', 'BR.27.3552106', 'ASCII:Socorro;ID:6322597', '10590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10590', '112', '12467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12468', '1079', '1', 'Sorocaba', 'BR.27.3552205', 'ASCII:Sorocaba;ID:6322598', '10591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10591', '112', '12468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12469', '1079', '1', 'Sud Mennucci', 'BR.27.3552304', 'ASCII:Sud Menucci;ID:6322599', '10592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10592', '112', '12469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12470', '1079', '1', 'Sumaré', 'BR.27.3552403', 'ASCII:Sumare;ID:6322600', '10593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10593', '112', '12470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12471', '1079', '1', 'Suzano', 'BR.27.3552502', 'ASCII:Suzano;ID:6322601', '10594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10594', '112', '12471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12472', '1079', '1', 'Suzanápolis', 'BR.27.3552551', 'ASCII:Suzanapolis;ID:6322602', '10595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10595', '112', '12472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12473', '1079', '1', 'Tabapuã', 'BR.27.3552601', 'ASCII:Tabapua;ID:6322603', '10596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10596', '112', '12473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12474', '1079', '1', 'Tabatinga', 'BR.27.3552700', 'ASCII:Tabatinga;ID:6322604', '10597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10597', '112', '12474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12475', '1079', '1', 'Taboão da Serra', 'BR.27.3552809', 'ASCII:Taboao Da Serra;ID:6322605', '10598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10598', '112', '12475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12476', '1079', '1', 'Taciba', 'BR.27.3552908', 'ASCII:Taciba;ID:6322606', '10599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10599', '112', '12476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3552908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12477', '1079', '1', 'Taguaí', 'BR.27.3553005', 'ASCII:Taguai;ID:6322607', '10600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10600', '112', '12477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12478', '1079', '1', 'Taiaçu', 'BR.27.3553104', 'ASCII:Taiacu;ID:6322608', '10601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10601', '112', '12478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12479', '1079', '1', 'Taiúva', 'BR.27.3553203', 'ASCII:Taiuva;ID:6322609', '10602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10602', '112', '12479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12480', '1079', '1', 'Tambaú', 'BR.27.3553302', 'ASCII:Tambau;ID:6322610', '10603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10603', '112', '12480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12481', '1079', '1', 'Tanabi', 'BR.27.3553401', 'ASCII:Tanabi;ID:6322611', '10604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10604', '112', '12481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12482', '1079', '1', 'Tapiraí', 'BR.27.3553500', 'ASCII:Tapirai;ID:6322612', '10605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10605', '112', '12482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12483', '1079', '1', 'Tapiratiba', 'BR.27.3553609', 'ASCII:Tapiratiba;ID:6322613', '10606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10606', '112', '12483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12484', '1079', '1', 'Taquaral', 'BR.27.3553658', 'ASCII:Taquaral;ID:6322614', '10607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10607', '112', '12484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12485', '1079', '1', 'Taquaritinga', 'BR.27.3553708', 'ASCII:Taquaritinga;ID:6322615', '10608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10608', '112', '12485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12486', '1079', '1', 'Taquarituba', 'BR.27.3553807', 'ASCII:Taquarituba;ID:6322616', '10609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10609', '112', '12486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12487', '1079', '1', 'Taquarivaí', 'BR.27.3553856', 'ASCII:Taquarivai;ID:6322617', '10610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10610', '112', '12487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12488', '1079', '1', 'Tarabai', 'BR.27.3553906', 'ASCII:Tarabai;ID:6322618', '10611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10611', '112', '12488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12489', '1079', '1', 'Tarumã', 'BR.27.3553955', 'ASCII:Taruma;ID:6322619', '10612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10612', '112', '12489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3553955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12490', '1079', '1', 'Tatuí', 'BR.27.3554003', 'ASCII:Tatui;ID:6322620', '10613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10613', '112', '12490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12491', '1079', '1', 'Taubaté', 'BR.27.3554102', 'ASCII:Taubate;ID:6322621', '10614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10614', '112', '12491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12492', '1079', '1', 'Teodoro Sampaio', 'BR.27.3554300', 'ASCII:Teodoro Sampaio;ID:6322622', '10615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10615', '112', '12492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12493', '1079', '1', 'Terra Roxa', 'BR.27.3554409', 'ASCII:Terra Roxa;ID:6322623', '10616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10616', '112', '12493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12494', '1079', '1', 'Tietê', 'BR.27.3554508', 'ASCII:Tiete;ID:6322624', '10617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10617', '112', '12494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12495', '1079', '1', 'Timburi', 'BR.27.3554607', 'ASCII:Timburi;ID:6322625', '10618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10618', '112', '12495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12496', '1079', '1', 'Torre de Pedra', 'BR.27.3554656', 'ASCII:Torre De Pedra;ID:6322626', '10619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10619', '112', '12496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12497', '1079', '1', 'Torrinha', 'BR.27.3554706', 'ASCII:Torrinha;ID:6322627', '10620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10620', '112', '12497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12498', '1079', '1', 'Trabiju', 'BR.27.3554755', 'ASCII:Trabiju;ID:6322628', '10621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10621', '112', '12498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12499', '1079', '1', 'Tremembé', 'BR.27.3554805', 'ASCII:Tremembe;ID:6322629', '10622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10622', '112', '12499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12500', '1079', '1', 'Três Fronteiras', 'BR.27.3554904', 'ASCII:Tres Fronteiras;ID:6322630', '10623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10623', '112', '12500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12501', '1079', '1', 'Tuiuti', 'BR.27.3554953', 'ASCII:Tuiuti;ID:6322631', '10624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10624', '112', '12501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3554953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12502', '1079', '1', 'Tupã', 'BR.27.3555000', 'ASCII:Tupa;ID:6322632', '10625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10625', '112', '12502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12503', '1079', '1', 'Tupi Paulista', 'BR.27.3555109', 'ASCII:Tupi Paulista;ID:6322633', '10626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10626', '112', '12503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12504', '1079', '1', 'Turiúba', 'BR.27.3555208', 'ASCII:Turiuba;ID:6322634', '10627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10627', '112', '12504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12505', '1079', '1', 'Turmalina', 'BR.27.3555307', 'ASCII:Turmalina;ID:6322635', '10628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10628', '112', '12505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12506', '1079', '1', 'Ubarana', 'BR.27.3555356', 'ASCII:Ubarana;ID:6322636', '10629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10629', '112', '12506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12507', '1079', '1', 'Ubatuba', 'BR.27.3555406', 'ASCII:Ubatuba;ID:6322637', '10630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10630', '112', '12507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12508', '1079', '1', 'Ubirajara', 'BR.27.3555505', 'ASCII:Ubirajara;ID:6322638', '10631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10631', '112', '12508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12509', '1079', '1', 'Uchoa', 'BR.27.3555604', 'ASCII:Uchoa;ID:6322639', '10632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10632', '112', '12509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12510', '1079', '1', 'União Paulista', 'BR.27.3555703', 'ASCII:Uniao Paulista;ID:6322640', '10633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10633', '112', '12510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12511', '1079', '1', 'Urânia', 'BR.27.3555802', 'ASCII:Urania;ID:6322641', '10634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10634', '112', '12511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12512', '1079', '1', 'Uru', 'BR.27.3555901', 'ASCII:Uru;ID:6322642', '10635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10635', '112', '12512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3555901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12513', '1079', '1', 'Urupês', 'BR.27.3556008', 'ASCII:Urupes;ID:6322643', '10636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10636', '112', '12513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12514', '1079', '1', 'Valentim Gentil', 'BR.27.3556107', 'ASCII:Valentim Gentil;ID:6322644', '10637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10637', '112', '12514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12515', '1079', '1', 'Valinhos', 'BR.27.3556206', 'ASCII:Valinhos;ID:6322645', '10638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10638', '112', '12515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12516', '1079', '1', 'Valparaíso', 'BR.27.3556305', 'ASCII:Valparaiso;ID:6322646', '10639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10639', '112', '12516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12517', '1079', '1', 'Vargem', 'BR.27.3556354', 'ASCII:Vargem;ID:6322647', '10640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10640', '112', '12517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12518', '1079', '1', 'Vargem Grande do Sul', 'BR.27.3556404', 'ASCII:Vargem Grande Do Sul;ID:6322648', '10641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10641', '112', '12518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12519', '1079', '1', 'Vargem Grande Paulista', 'BR.27.3556453', 'ASCII:Vargem Grande Paulista;ID:6322649', '10642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10642', '112', '12519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12520', '1079', '1', 'Várzea Paulista', 'BR.27.3556503', 'ASCII:Varzea Paulista;ID:6322650', '10643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10643', '112', '12520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12521', '1079', '1', 'Vinhedo', 'BR.27.3556701', 'ASCII:Vinhedo;ID:6322651', '10644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10644', '112', '12521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12522', '1079', '1', 'Viradouro', 'BR.27.3556800', 'ASCII:Viradouro;ID:6322652', '10645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10645', '112', '12522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12523', '1079', '1', 'Vista Alegre do Alto', 'BR.27.3556909', 'ASCII:Vista Alegre Do Alto;ID:6322653', '10646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10646', '112', '12523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12524', '1079', '1', 'Vitória Brasil', 'BR.27.3556958', 'ASCII:Vitoria Brasil;ID:6322654', '10647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10647', '112', '12524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12525', '1079', '1', 'Votorantim', 'BR.27.3557006', 'ASCII:Votorantim;ID:6322655', '10648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10648', '112', '12525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3557006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12526', '1079', '1', 'Zacarias', 'BR.27.3557154', 'ASCII:Zacarias;ID:6322656', '10649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10649', '112', '12526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3557154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12527', '1079', '1', 'Chavantes', 'BR.27.3557204', 'ASCII:Chavantes;ID:6322657', '10650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10650', '112', '12527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3557204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12528', '1079', '1', 'Estiva Gerbi', 'BR.27.3557303', 'ASCII:Estiva Gerbi;ID:6322658', '10651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10651', '112', '12528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3557303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12529', '1079', '1', 'Abatiá', 'BR.18.4100103', 'ASCII:Abatia;ID:6322659', '10652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10652', '112', '12529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4100103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12530', '1079', '1', 'Adrianópolis', 'BR.18.4100202', 'ASCII:Adrianopolis;ID:6322660', '10653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10653', '112', '12530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4100202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12531', '1079', '1', 'Agudos do Sul', 'BR.18.4100301', 'ASCII:Agudos Do Sul;ID:6322661', '10654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10654', '112', '12531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4100301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12532', '1079', '1', 'Almirante Tamandaré', 'BR.18.4100400', 'ASCII:Almirante Tamandare;ID:6322662', '10655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10655', '112', '12532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4100400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12533', '1079', '1', 'Altamira do Paraná', 'BR.18.4100459', 'ASCII:Altamira Do Parana;ID:6322663', '10656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10656', '112', '12533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4100459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12534', '1079', '1', 'Altônia', 'BR.18.4100509', 'ASCII:Altonia;ID:6322664', '10657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10657', '112', '12534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4100509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12535', '1079', '1', 'Alto Paraná', 'BR.18.4100608', 'ASCII:Alto Parana;ID:6322665', '10658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10658', '112', '12535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4100608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12536', '1079', '1', 'Alto Piquiri', 'BR.18.4100707', 'ASCII:Alto Piquiri;ID:6322666', '10659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10659', '112', '12536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4100707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12537', '1079', '1', 'Alvorada do Sul', 'BR.18.4100806', 'ASCII:Alvorada Do Sul;ID:6322667', '10660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10660', '112', '12537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4100806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12538', '1079', '1', 'Amaporã', 'BR.18.4100905', 'ASCII:Amapora;ID:6322668', '10661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10661', '112', '12538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4100905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12539', '1079', '1', 'Ampére', 'BR.18.4101002', 'ASCII:Ampere;ID:6322669', '10662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10662', '112', '12539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12540', '1079', '1', 'Anahy', 'BR.18.4101051', 'ASCII:Anahy;ID:6322670', '10663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10663', '112', '12540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12541', '1079', '1', 'Andirá', 'BR.18.4101101', 'ASCII:Andira;ID:6322671', '10664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10664', '112', '12541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12542', '1079', '1', 'Ângulo', 'BR.18.4101150', 'ASCII:Angulo;ID:6322672', '10665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10665', '112', '12542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12543', '1079', '1', 'Antonina', 'BR.18.4101200', 'ASCII:Antonina;ID:6322673', '10666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10666', '112', '12543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12544', '1079', '1', 'Antônio Olinto', 'BR.18.4101309', 'ASCII:Antonio Olinto;ID:6322674', '10667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10667', '112', '12544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12545', '1079', '1', 'Apucarana', 'BR.18.4101408', 'ASCII:Apucarana;ID:6322675', '10668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10668', '112', '12545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12546', '1079', '1', 'Arapongas', 'BR.18.4101507', 'ASCII:Arapongas;ID:6322676', '10669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10669', '112', '12546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12547', '1079', '1', 'Arapoti', 'BR.18.4101606', 'ASCII:Arapoti;ID:6322677', '10670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10670', '112', '12547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12548', '1079', '1', 'Arapuã', 'BR.18.4101655', 'ASCII:Arapua;ID:6322678', '10671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10671', '112', '12548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12549', '1079', '1', 'Araruna', 'BR.18.4101705', 'ASCII:Araruna;ID:6322679', '10672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10672', '112', '12549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12550', '1079', '1', 'Araucária', 'BR.18.4101804', 'ASCII:Araucaria;ID:6322680', '10673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10673', '112', '12550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12551', '1079', '1', 'Ariranha do Ivaí', 'BR.18.4101853', 'ASCII:Ariranha Do Ivai;ID:6322681', '10674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10674', '112', '12551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12552', '1079', '1', 'Assaí', 'BR.18.4101903', 'ASCII:Assai;ID:6322682', '10675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10675', '112', '12552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4101903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12553', '1079', '1', 'Assis Chateaubriand', 'BR.18.4102000', 'ASCII:Assis Chateaubriand;ID:6322683', '10676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10676', '112', '12553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12554', '1079', '1', 'Astorga', 'BR.18.4102109', 'ASCII:Astorga;ID:6322684', '10677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10677', '112', '12554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12555', '1079', '1', 'Atalaia', 'BR.18.4102208', 'ASCII:Atalaia;ID:6322685', '10678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10678', '112', '12555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12556', '1079', '1', 'Balsa Nova', 'BR.18.4102307', 'ASCII:Balsa Nova;ID:6322686', '10679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10679', '112', '12556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12557', '1079', '1', 'Bandeirantes', 'BR.18.4102406', 'ASCII:Bandeirantes;ID:6322687', '10680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10680', '112', '12557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12558', '1079', '1', 'Barbosa Ferraz', 'BR.18.4102505', 'ASCII:Barbosa Ferraz;ID:6322688', '10681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10681', '112', '12558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12559', '1079', '1', 'Barracão', 'BR.18.4102604', 'ASCII:Barracao;ID:6322689', '10682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10682', '112', '12559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12560', '1079', '1', 'Barra do Jacaré', 'BR.18.4102703', 'ASCII:Barra Do Jacare;ID:6322690', '10683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10683', '112', '12560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12561', '1079', '1', 'Bela Vista da Caroba', 'BR.18.4102752', 'ASCII:Bela Vista Do Caroba;ID:6322691', '10684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10684', '112', '12561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12562', '1079', '1', 'Bela Vista do Paraíso', 'BR.18.4102802', 'ASCII:Bela Vista Do Paraiso;ID:6322692', '10685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10685', '112', '12562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12563', '1079', '1', 'Bituruna', 'BR.18.4102901', 'ASCII:Bituruna;ID:6322693', '10686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10686', '112', '12563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4102901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12564', '1079', '1', 'Boa Esperança', 'BR.18.4103008', 'ASCII:Boa Esperanca;ID:6322694', '10687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10687', '112', '12564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12565', '1079', '1', 'Boa Esperança do Iguaçu', 'BR.18.4103024', 'ASCII:Boa Esperanca Do Iguacu;ID:6322695', '10688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10688', '112', '12565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12566', '1079', '1', 'Boa Ventura de São Roque', 'BR.18.4103040', 'ASCII:Boa Ventura De Sao Roque;ID:6322696', '10689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10689', '112', '12566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12567', '1079', '1', 'Boa Vista da Aparecida', 'BR.18.4103057', 'ASCII:Boa Vista Da Aparecida;ID:6322697', '10690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10690', '112', '12567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12568', '1079', '1', 'Bocaiúva do Sul', 'BR.18.4103107', 'ASCII:Bocaiuva Do Sul;ID:6322698', '10691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10691', '112', '12568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12569', '1079', '1', 'Bom Jesus do Sul', 'BR.18.4103156', 'ASCII:Bom Jesus Do Sul;ID:6322699', '10692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10692', '112', '12569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12570', '1079', '1', 'Bom Sucesso', 'BR.18.4103206', 'ASCII:Bom Sucesso;ID:6322700', '10693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10693', '112', '12570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12571', '1079', '1', 'Bom Sucesso do Sul', 'BR.18.4103222', 'ASCII:Bom Sucesso Do Sul;ID:6322701', '10694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10694', '112', '12571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12572', '1079', '1', 'Borrazópolis', 'BR.18.4103305', 'ASCII:Borrazopolis;ID:6322702', '10695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10695', '112', '12572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12573', '1079', '1', 'Braganey', 'BR.18.4103354', 'ASCII:Braganey;ID:6322703', '10696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10696', '112', '12573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12574', '1079', '1', 'Brasilândia do Sul', 'BR.18.4103370', 'ASCII:Brasilandia Do Sul;ID:6322704', '10697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10697', '112', '12574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12575', '1079', '1', 'Cafeara', 'BR.18.4103404', 'ASCII:Cafeara;ID:6322705', '10698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10698', '112', '12575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12576', '1079', '1', 'Cafelândia', 'BR.18.4103453', 'ASCII:Cafelandia;ID:6322706', '10699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10699', '112', '12576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12577', '1079', '1', 'Cafezal do Sul', 'BR.18.4103479', 'ASCII:Cafezal Do Sul;ID:6322707', '10700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10700', '112', '12577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12578', '1079', '1', 'Califórnia', 'BR.18.4103503', 'ASCII:California;ID:6322708', '10701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10701', '112', '12578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12579', '1079', '1', 'Cambará', 'BR.18.4103602', 'ASCII:Cambara;ID:6322709', '10702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10702', '112', '12579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12580', '1079', '1', 'Cambé', 'BR.18.4103701', 'ASCII:Cambe;ID:6322710', '10703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10703', '112', '12580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12581', '1079', '1', 'Cambira', 'BR.18.4103800', 'ASCII:Cambira;ID:6322711', '10704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10704', '112', '12581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12582', '1079', '1', 'Campina da Lagoa', 'BR.18.4103909', 'ASCII:Campina Da Lagoa;ID:6322712', '10705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10705', '112', '12582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12583', '1079', '1', 'Campina do Simão', 'BR.18.4103958', 'ASCII:Campina Do Simao;ID:6322713', '10706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10706', '112', '12583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4103958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12584', '1079', '1', 'Campina Grande do Sul', 'BR.18.4104006', 'ASCII:Campina Grande Do Sul;ID:6322714', '10707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10707', '112', '12584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12585', '1079', '1', 'Campo Bonito', 'BR.18.4104055', 'ASCII:Campo Bonito;ID:6322715', '10708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10708', '112', '12585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12586', '1079', '1', 'Campo do Tenente', 'BR.18.4104105', 'ASCII:Campo Do Tenente;ID:6322716', '10709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10709', '112', '12586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12587', '1079', '1', 'Campo Largo', 'BR.18.4104204', 'ASCII:Campo Largo;ID:6322717', '10710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10710', '112', '12587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12588', '1079', '1', 'Campo Magro', 'BR.18.4104253', 'ASCII:Campo Magro;ID:6322718', '10711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10711', '112', '12588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12589', '1079', '1', 'Campo Mourão', 'BR.18.4104303', 'ASCII:Campo Mourao;ID:6322719', '10712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10712', '112', '12589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12590', '1079', '1', 'Cândido de Abreu', 'BR.18.4104402', 'ASCII:Candido De Abreu;ID:6322720', '10713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10713', '112', '12590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12591', '1079', '1', 'Candói', 'BR.18.4104428', 'ASCII:Candoi;ID:6322721', '10714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10714', '112', '12591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12592', '1079', '1', 'Cantagalo', 'BR.18.4104451', 'ASCII:Cantagalo;ID:6322722', '10715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10715', '112', '12592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12593', '1079', '1', 'Capanema', 'BR.18.4104501', 'ASCII:Capanema;ID:6322723', '10716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10716', '112', '12593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12594', '1079', '1', 'Capitão Leônidas Marques', 'BR.18.4104600', 'ASCII:Capitao Leonidas Marques;ID:6322724', '10717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10717', '112', '12594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12595', '1079', '1', 'Carambeí', 'BR.18.4104659', 'ASCII:Carambei;ID:6322725', '10718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10718', '112', '12595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12596', '1079', '1', 'Carlópolis', 'BR.18.4104709', 'ASCII:Carlopolis;ID:6322726', '10719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10719', '112', '12596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12597', '1079', '1', 'Cascavel', 'BR.18.4104808', 'ASCII:Cascavel;ID:6322727', '10720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10720', '112', '12597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12598', '1079', '1', 'Castro', 'BR.18.4104907', 'ASCII:Castro;ID:6322728', '10721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10721', '112', '12598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4104907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12599', '1079', '1', 'Catanduvas', 'BR.18.4105003', 'ASCII:Catanduvas;ID:6322729', '10722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10722', '112', '12599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4105003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12600', '1079', '1', 'Centenário do Sul', 'BR.18.4105102', 'ASCII:Centenario Do Sul;ID:6322730', '10723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10723', '112', '12600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4105102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12601', '1079', '1', 'Cerro Azul', 'BR.18.4105201', 'ASCII:Cerro Azul;ID:6322731', '10724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10724', '112', '12601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4105201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12602', '1079', '1', 'Céu Azul', 'BR.18.4105300', 'ASCII:Ceu Azul;ID:6322732', '10725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10725', '112', '12602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4105300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12603', '1079', '1', 'Chopinzinho', 'BR.18.4105409', 'ASCII:Chopinzinho;ID:6322733', '10726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10726', '112', '12603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4105409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12604', '1079', '1', 'Cianorte', 'BR.18.4105508', 'ASCII:Cianorte;ID:6322734', '10727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10727', '112', '12604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4105508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12605', '1079', '1', 'Cidade Gaúcha', 'BR.18.4105607', 'ASCII:Cidade Gaucha;ID:6322735', '10728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10728', '112', '12605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4105607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12606', '1079', '1', 'Clevelândia', 'BR.18.4105706', 'ASCII:Clevelandia;ID:6322736', '10729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10729', '112', '12606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4105706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12607', '1079', '1', 'Colombo', 'BR.18.4105805', 'ASCII:Colombo;ID:6322737', '10730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10730', '112', '12607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4105805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12608', '1079', '1', 'Colorado', 'BR.18.4105904', 'ASCII:Colorado;ID:6322738', '10731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10731', '112', '12608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4105904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12609', '1079', '1', 'Congonhinhas', 'BR.18.4106001', 'ASCII:Congonhinhas;ID:6322739', '10732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10732', '112', '12609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12610', '1079', '1', 'Conselheiro Mairinck', 'BR.18.4106100', 'ASCII:Conselheiro Mairinck;ID:6322740', '10733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10733', '112', '12610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12611', '1079', '1', 'Contenda', 'BR.18.4106209', 'ASCII:Contenda;ID:6322741', '10734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10734', '112', '12611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12612', '1079', '1', 'Corbélia', 'BR.18.4106308', 'ASCII:Corbelia;ID:6322742', '10735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10735', '112', '12612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12613', '1079', '1', 'Cornélio Procópio', 'BR.18.4106407', 'ASCII:Cornelio Procopio;ID:6322743', '10736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10736', '112', '12613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12614', '1079', '1', 'Coronel Domingos Soares', 'BR.18.4106456', 'ASCII:Coronel Domingos Soares;ID:6322744', '10737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10737', '112', '12614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12615', '1079', '1', 'Coronel Vivida', 'BR.18.4106506', 'ASCII:Coronel Vivida;ID:6322745', '10738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10738', '112', '12615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12616', '1079', '1', 'Corumbataí do Sul', 'BR.18.4106555', 'ASCII:Corumbatai Do Sul;ID:6322746', '10739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10739', '112', '12616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12617', '1079', '1', 'Cruzeiro do Iguaçu', 'BR.18.4106571', 'ASCII:Cruzeiro Do Iguacu;ID:6322747', '10740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10740', '112', '12617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12618', '1079', '1', 'Cruzeiro do Oeste', 'BR.18.4106605', 'ASCII:Cruzeiro Do Oeste;ID:6322748', '10741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10741', '112', '12618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12619', '1079', '1', 'Cruzeiro do Sul', 'BR.18.4106704', 'ASCII:Cruzeiro Do Sul;ID:6322749', '10742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10742', '112', '12619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12620', '1079', '1', 'Cruz Machado', 'BR.18.4106803', 'ASCII:Cruz Machado;ID:6322750', '10743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10743', '112', '12620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12621', '1079', '1', 'Cruzmaltina', 'BR.18.4106852', 'ASCII:Cruzmaltina;ID:6322751', '10744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10744', '112', '12621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12622', '1079', '1', 'Curitiba', 'BR.18.4106902', 'ASCII:Curitiba;ID:6322752', '10745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10745', '112', '12622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4106902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12623', '1079', '1', 'Curiúva', 'BR.18.4107009', 'ASCII:Curiuva;ID:6322753', '10746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10746', '112', '12623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12624', '1079', '1', 'Diamante do Norte', 'BR.18.4107108', 'ASCII:Diamante Do Norte;ID:6322754', '10747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10747', '112', '12624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12625', '1079', '1', 'Diamante do Sul', 'BR.18.4107124', 'ASCII:Diamante Do Sul;ID:6322755', '10748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10748', '112', '12625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12626', '1079', '1', 'Diamante d''Oeste', 'BR.18.4107157', 'ASCII:Diamante D''Oeste;ID:6322756', '10749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10749', '112', '12626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12627', '1079', '1', 'Dois Vizinhos', 'BR.18.4107207', 'ASCII:Dois Vizinhos;ID:6322757', '10750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10750', '112', '12627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12628', '1079', '1', 'Douradina', 'BR.18.4107256', 'ASCII:Douradina;ID:6322758', '10751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10751', '112', '12628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12629', '1079', '1', 'Doutor Camargo', 'BR.18.4107306', 'ASCII:Doutor Camargo;ID:6322759', '10752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10752', '112', '12629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12630', '1079', '1', 'Enéas Marques', 'BR.18.4107405', 'ASCII:Eneas Marques;ID:6322760', '10753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10753', '112', '12630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12631', '1079', '1', 'Engenheiro Beltrão', 'BR.18.4107504', 'ASCII:Engenheiro Beltrao;ID:6322761', '10754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10754', '112', '12631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12632', '1079', '1', 'Esperança Nova', 'BR.18.4107520', 'ASCII:Esperanca Nova;ID:6322762', '10755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10755', '112', '12632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12633', '1079', '1', 'Entre Rios do Oeste', 'BR.18.4107538', 'ASCII:Entre Rios Do Oeste;ID:6322763', '10756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10756', '112', '12633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12634', '1079', '1', 'Espigão Alto do Iguaçu', 'BR.18.4107546', 'ASCII:Espigao Alto Do Iguacu;ID:6322764', '10757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10757', '112', '12634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12635', '1079', '1', 'Farol', 'BR.18.4107553', 'ASCII:Farol;ID:6322765', '10758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10758', '112', '12635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12636', '1079', '1', 'Faxinal', 'BR.18.4107603', 'ASCII:Faxinal;ID:6322766', '10759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10759', '112', '12636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12637', '1079', '1', 'Fazenda Rio Grande', 'BR.18.4107652', 'ASCII:Fazenda Rio Grande;ID:6322767', '10760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10760', '112', '12637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12638', '1079', '1', 'Fênix', 'BR.18.4107702', 'ASCII:Fenix;ID:6322768', '10761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10761', '112', '12638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12639', '1079', '1', 'Fernandes Pinheiro', 'BR.18.4107736', 'ASCII:Fernandes Pinheiro;ID:6322769', '10762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10762', '112', '12639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12640', '1079', '1', 'Figueira', 'BR.18.4107751', 'ASCII:Figueira;ID:6322770', '10763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10763', '112', '12640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12641', '1079', '1', 'Floraí', 'BR.18.4107801', 'ASCII:Florai;ID:6322771', '10764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10764', '112', '12641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12642', '1079', '1', 'Flor da Serra do Sul', 'BR.18.4107850', 'ASCII:Flor Da Serra Do Sul;ID:6322772', '10765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10765', '112', '12642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12643', '1079', '1', 'Floresta', 'BR.18.4107900', 'ASCII:Floresta;ID:6322773', '10766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10766', '112', '12643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4107900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12644', '1079', '1', 'Florestópolis', 'BR.18.4108007', 'ASCII:Florestopolis;ID:6322774', '10767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10767', '112', '12644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12645', '1079', '1', 'Flórida', 'BR.18.4108106', 'ASCII:Florida;ID:6322775', '10768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10768', '112', '12645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12646', '1079', '1', 'Formosa do Oeste', 'BR.18.4108205', 'ASCII:Formosa Do Oeste;ID:6322776', '10769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10769', '112', '12646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12647', '1079', '1', 'Foz do Iguaçu', 'BR.18.4108304', 'ASCII:Foz Do Iguacu;ID:6322777', '10770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10770', '112', '12647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12648', '1079', '1', 'Francisco Alves', 'BR.18.4108320', 'ASCII:Francisco Alves;ID:6322778', '10771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10771', '112', '12648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12649', '1079', '1', 'Francisco Beltrão', 'BR.18.4108403', 'ASCII:Francisco Beltrao;ID:6322779', '10772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10772', '112', '12649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12650', '1079', '1', 'Foz do Jordão', 'BR.18.4108452', 'ASCII:Foz Do Jordao;ID:6322780', '10773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10773', '112', '12650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12651', '1079', '1', 'General Carneiro', 'BR.18.4108502', 'ASCII:General Carneiro;ID:6322781', '10774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10774', '112', '12651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12652', '1079', '1', 'Godoy Moreira', 'BR.18.4108551', 'ASCII:Godoy Moreira;ID:6322782', '10775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10775', '112', '12652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12653', '1079', '1', 'Goioerê', 'BR.18.4108601', 'ASCII:Goioere;ID:6322783', '10776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10776', '112', '12653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12654', '1079', '1', 'Goioxim', 'BR.18.4108650', 'ASCII:Goioxim;ID:6322784', '10777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10777', '112', '12654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12655', '1079', '1', 'Grandes Rios', 'BR.18.4108700', 'ASCII:Grandes Rios;ID:6322785', '10778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10778', '112', '12655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12656', '1079', '1', 'Guaíra', 'BR.18.4108809', 'ASCII:Guaira;ID:6322786', '10779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10779', '112', '12656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12657', '1079', '1', 'Guairaçá', 'BR.18.4108908', 'ASCII:Guairaca;ID:6322787', '10780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10780', '112', '12657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12658', '1079', '1', 'Guamiranga', 'BR.18.4108957', 'ASCII:Guamiranga;ID:6322788', '10781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10781', '112', '12658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4108957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12659', '1079', '1', 'Guapirama', 'BR.18.4109005', 'ASCII:Guapirama;ID:6322789', '10782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10782', '112', '12659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12660', '1079', '1', 'Guaporema', 'BR.18.4109104', 'ASCII:Guaporema;ID:6322790', '10783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10783', '112', '12660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12661', '1079', '1', 'Guaraci', 'BR.18.4109203', 'ASCII:Guaraci;ID:6322791', '10784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10784', '112', '12661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12662', '1079', '1', 'Guaraniaçu', 'BR.18.4109302', 'ASCII:Guaraniacu;ID:6322792', '10785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10785', '112', '12662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12663', '1079', '1', 'Guarapuava', 'BR.18.4109401', 'ASCII:Guarapuava;ID:6322793', '10786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10786', '112', '12663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12664', '1079', '1', 'Guaraqueçaba', 'BR.18.4109500', 'ASCII:Guaraquecaba;ID:6322794', '10787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10787', '112', '12664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12665', '1079', '1', 'Guaratuba', 'BR.18.4109609', 'ASCII:Guaratuba;ID:6322795', '10788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10788', '112', '12665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12666', '1079', '1', 'Honório Serpa', 'BR.18.4109658', 'ASCII:Honorio Serpa;ID:6322796', '10789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10789', '112', '12666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12667', '1079', '1', 'Ibaiti', 'BR.18.4109708', 'ASCII:Ibaiti;ID:6322797', '10790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10790', '112', '12667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12668', '1079', '1', 'Ibema', 'BR.18.4109757', 'ASCII:Ibema;ID:6322798', '10791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10791', '112', '12668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12669', '1079', '1', 'Ibiporã', 'BR.18.4109807', 'ASCII:Ibipora;ID:6322799', '10792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10792', '112', '12669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12670', '1079', '1', 'Icaraíma', 'BR.18.4109906', 'ASCII:Icaraima;ID:6322800', '10793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10793', '112', '12670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4109906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12671', '1079', '1', 'Iguaraçu', 'BR.18.4110003', 'ASCII:Iguaracu;ID:6322801', '10794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10794', '112', '12671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12672', '1079', '1', 'Imbaú', 'BR.18.4110078', 'ASCII:Imbau;ID:6322802', '10795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10795', '112', '12672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12673', '1079', '1', 'Imbituva', 'BR.18.4110102', 'ASCII:Imbituva;ID:6322803', '10796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10796', '112', '12673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12674', '1079', '1', 'Inácio Martins', 'BR.18.4110201', 'ASCII:Inacio Martins;ID:6322804', '10797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10797', '112', '12674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12675', '1079', '1', 'Inajá', 'BR.18.4110300', 'ASCII:Inaja;ID:6322805', '10798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10798', '112', '12675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12676', '1079', '1', 'Indianópolis', 'BR.18.4110409', 'ASCII:Indianopolis;ID:6322806', '10799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10799', '112', '12676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12677', '1079', '1', 'Ipiranga', 'BR.18.4110508', 'ASCII:Ipiranga;ID:6322807', '10800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10800', '112', '12677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12678', '1079', '1', 'Iporã', 'BR.18.4110607', 'ASCII:Ipora;ID:6322808', '10801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10801', '112', '12678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12679', '1079', '1', 'Iracema do Oeste', 'BR.18.4110656', 'ASCII:Iracema Do Oeste;ID:6322809', '10802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10802', '112', '12679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12680', '1079', '1', 'Irati', 'BR.18.4110706', 'ASCII:Irati;ID:6322810', '10803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10803', '112', '12680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12681', '1079', '1', 'Iretama', 'BR.18.4110805', 'ASCII:Iretama;ID:6322811', '10804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10804', '112', '12681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12682', '1079', '1', 'Itaguajé', 'BR.18.4110904', 'ASCII:Itaguaje;ID:6322812', '10805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10805', '112', '12682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12683', '1079', '1', 'Itaipulândia', 'BR.18.4110953', 'ASCII:Itaipulandia;ID:6322813', '10806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10806', '112', '12683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12684', '1079', '1', 'Itambaracá', 'BR.18.4111001', 'ASCII:Itambaraca;ID:6322814', '10807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10807', '112', '12684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12685', '1079', '1', 'Itambé', 'BR.18.4111100', 'ASCII:Itambe;ID:6322815', '10808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10808', '112', '12685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12686', '1079', '1', 'Itapejara d''Oeste', 'BR.18.4111209', 'ASCII:Itapejara D''Oeste;ID:6322816', '10809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10809', '112', '12686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12687', '1079', '1', 'Itaperuçu', 'BR.18.4111258', 'ASCII:Itaperucu;ID:6322817', '10810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10810', '112', '12687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12688', '1079', '1', 'Itaúna do Sul', 'BR.18.4111308', 'ASCII:Itauna Do Sul;ID:6322818', '10811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10811', '112', '12688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12689', '1079', '1', 'Ivaté', 'BR.18.4111555', 'ASCII:Ivate;ID:6322819', '10812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10812', '112', '12689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12690', '1079', '1', 'Ivatuba', 'BR.18.4111605', 'ASCII:Ivatuba;ID:6322820', '10813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10813', '112', '12690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12691', '1079', '1', 'Jaboti', 'BR.18.4111704', 'ASCII:Jaboti;ID:6322821', '10814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10814', '112', '12691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12692', '1079', '1', 'Jacarezinho', 'BR.18.4111803', 'ASCII:Jacarezinho;ID:6322822', '10815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10815', '112', '12692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12693', '1079', '1', 'Jaguapitã', 'BR.18.4111902', 'ASCII:Jaguapita;ID:6322823', '10816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10816', '112', '12693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4111902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12694', '1079', '1', 'Jaguariaíva', 'BR.18.4112009', 'ASCII:Jaguariaiva;ID:6322824', '10817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10817', '112', '12694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12695', '1079', '1', 'Jandaia do Sul', 'BR.18.4112108', 'ASCII:Jandaia Do Sul;ID:6322825', '10818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10818', '112', '12695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12696', '1079', '1', 'Janiópolis', 'BR.18.4112207', 'ASCII:Janiopolis;ID:6322826', '10819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10819', '112', '12696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12697', '1079', '1', 'Japira', 'BR.18.4112306', 'ASCII:Japira;ID:6322827', '10820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10820', '112', '12697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12698', '1079', '1', 'Japurá', 'BR.18.4112405', 'ASCII:Japura;ID:6322828', '10821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10821', '112', '12698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12699', '1079', '1', 'Jardim Alegre', 'BR.18.4112504', 'ASCII:Jardim Alegre;ID:6322829', '10822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10822', '112', '12699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12700', '1079', '1', 'Jardim Olinda', 'BR.18.4112603', 'ASCII:Jardim Olinda;ID:6322830', '10823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10823', '112', '12700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12701', '1079', '1', 'Jataizinho', 'BR.18.4112702', 'ASCII:Jataizinho;ID:6322831', '10824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10824', '112', '12701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12702', '1079', '1', 'Jesuítas', 'BR.18.4112751', 'ASCII:Jesuitas;ID:6322832', '10825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10825', '112', '12702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12703', '1079', '1', 'Joaquim Távora', 'BR.18.4112801', 'ASCII:Joaquim Tavora;ID:6322833', '10826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10826', '112', '12703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12704', '1079', '1', 'Jundiaí do Sul', 'BR.18.4112900', 'ASCII:Jundiai Do Sul;ID:6322834', '10827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10827', '112', '12704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12705', '1079', '1', 'Juranda', 'BR.18.4112959', 'ASCII:Juranda;ID:6322835', '10828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10828', '112', '12705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4112959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12706', '1079', '1', 'Jussara', 'BR.18.4113007', 'ASCII:Jussara;ID:6322836', '10829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10829', '112', '12706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12707', '1079', '1', 'Kaloré', 'BR.18.4113106', 'ASCII:Kalore;ID:6322837', '10830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10830', '112', '12707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12708', '1079', '1', 'Lapa', 'BR.18.4113205', 'ASCII:Lapa;ID:6322838', '10831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10831', '112', '12708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12709', '1079', '1', 'Laranjal', 'BR.18.4113254', 'ASCII:Laranjal;ID:6322839', '10832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10832', '112', '12709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12710', '1079', '1', 'Laranjeiras do Sul', 'BR.18.4113304', 'ASCII:Laranjeiras Do Sul;ID:6322840', '10833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10833', '112', '12710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12711', '1079', '1', 'Leópolis', 'BR.18.4113403', 'ASCII:Leopolis;ID:6322841', '10834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10834', '112', '12711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12712', '1079', '1', 'Lidianópolis', 'BR.18.4113429', 'ASCII:Lidianopolis;ID:6322842', '10835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10835', '112', '12712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12713', '1079', '1', 'Lindoeste', 'BR.18.4113452', 'ASCII:Lindoeste;ID:6322843', '10836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10836', '112', '12713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12714', '1079', '1', 'Loanda', 'BR.18.4113502', 'ASCII:Loanda;ID:6322844', '10837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10837', '112', '12714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12715', '1079', '1', 'Lobato', 'BR.18.4113601', 'ASCII:Lobato;ID:6322845', '10838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10838', '112', '12715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12716', '1079', '1', 'Londrina', 'BR.18.4113700', 'ASCII:Londrina;ID:6322846', '10839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10839', '112', '12716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12717', '1079', '1', 'Luiziana', 'BR.18.4113734', 'ASCII:Luiziana;ID:6322847', '10840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10840', '112', '12717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12718', '1079', '1', 'Lunardelli', 'BR.18.4113759', 'ASCII:Lunardelli;ID:6322848', '10841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10841', '112', '12718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12719', '1079', '1', 'Mallet', 'BR.18.4113908', 'ASCII:Mallet;ID:6322849', '10842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10842', '112', '12719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4113908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12720', '1079', '1', 'Mamborê', 'BR.18.4114005', 'ASCII:Mambore;ID:6322850', '10843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10843', '112', '12720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12721', '1079', '1', 'Mandaguaçu', 'BR.18.4114104', 'ASCII:Mandaguacu;ID:6322851', '10844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10844', '112', '12721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12722', '1079', '1', 'Mandaguari', 'BR.18.4114203', 'ASCII:Mandaguari;ID:6322852', '10845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10845', '112', '12722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12723', '1079', '1', 'Mandirituba', 'BR.18.4114302', 'ASCII:Mandirituba;ID:6322853', '10846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10846', '112', '12723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12724', '1079', '1', 'Manfrinópolis', 'BR.18.4114351', 'ASCII:Manfrinopolis;ID:6322854', '10847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10847', '112', '12724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12725', '1079', '1', 'Mangueirinha', 'BR.18.4114401', 'ASCII:Mangueirinha;ID:6322855', '10848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10848', '112', '12725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12726', '1079', '1', 'Manoel Ribas', 'BR.18.4114500', 'ASCII:Manoel Ribas;ID:6322856', '10849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10849', '112', '12726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12727', '1079', '1', 'Marechal Cândido Rondon', 'BR.18.4114609', 'ASCII:Marechal Candido Rondon;ID:6322857', '10850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10850', '112', '12727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12728', '1079', '1', 'Maria Helena', 'BR.18.4114708', 'ASCII:Maria Helena;ID:6322858', '10851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10851', '112', '12728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12729', '1079', '1', 'Marialva', 'BR.18.4114807', 'ASCII:Marialva;ID:6322859', '10852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10852', '112', '12729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12730', '1079', '1', 'Marilândia do Sul', 'BR.18.4114906', 'ASCII:Marilandia Do Sul;ID:6322860', '10853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10853', '112', '12730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4114906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12731', '1079', '1', 'Marilena', 'BR.18.4115002', 'ASCII:Marilena;ID:6322861', '10854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10854', '112', '12731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12732', '1079', '1', 'Mariluz', 'BR.18.4115101', 'ASCII:Mariluz;ID:6322862', '10855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10855', '112', '12732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12733', '1079', '1', 'Maringá', 'BR.18.4115200', 'ASCII:Maringa;ID:6322863', '10856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10856', '112', '12733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12734', '1079', '1', 'Mariópolis', 'BR.18.4115309', 'ASCII:Mariopolis;ID:6322864', '10857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10857', '112', '12734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12735', '1079', '1', 'Maripá', 'BR.18.4115358', 'ASCII:Maripa;ID:6322865', '10858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10858', '112', '12735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12736', '1079', '1', 'Marmeleiro', 'BR.18.4115408', 'ASCII:Marmeleiro;ID:6322866', '10859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10859', '112', '12736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12737', '1079', '1', 'Marquinho', 'BR.18.4115457', 'ASCII:Marquinho;ID:6322867', '10860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10860', '112', '12737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12738', '1079', '1', 'Marumbi', 'BR.18.4115507', 'ASCII:Marumbi;ID:6322868', '10861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10861', '112', '12738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12739', '1079', '1', 'Matelândia', 'BR.18.4115606', 'ASCII:Matelandia;ID:6322869', '10862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10862', '112', '12739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12740', '1079', '1', 'Matinhos', 'BR.18.4115705', 'ASCII:Matinhos;ID:6322870', '10863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10863', '112', '12740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12741', '1079', '1', 'Mato Rico', 'BR.18.4115739', 'ASCII:Mato Rico;ID:6322871', '10864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10864', '112', '12741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12742', '1079', '1', 'Mauá da Serra', 'BR.18.4115754', 'ASCII:Maua Da Serra;ID:6322872', '10865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10865', '112', '12742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12743', '1079', '1', 'Medianeira', 'BR.18.4115804', 'ASCII:Medianeira;ID:6322873', '10866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10866', '112', '12743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12744', '1079', '1', 'Mercedes', 'BR.18.4115853', 'ASCII:Mercedes;ID:6322874', '10867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10867', '112', '12744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12745', '1079', '1', 'Mirador', 'BR.18.4115903', 'ASCII:Mirador;ID:6322875', '10868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10868', '112', '12745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4115903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12746', '1079', '1', 'Miraselva', 'BR.18.4116000', 'ASCII:Miraselva;ID:6322876', '10869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10869', '112', '12746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12747', '1079', '1', 'Missal', 'BR.18.4116059', 'ASCII:Missal;ID:6322877', '10870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10870', '112', '12747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12748', '1079', '1', 'Moreira Sales', 'BR.18.4116109', 'ASCII:Moreira Sales;ID:6322878', '10871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10871', '112', '12748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12749', '1079', '1', 'Morretes', 'BR.18.4116208', 'ASCII:Morretes;ID:6322879', '10872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10872', '112', '12749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12750', '1079', '1', 'Munhoz de Melo', 'BR.18.4116307', 'ASCII:Munhoz De Melo;ID:6322880', '10873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10873', '112', '12750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12751', '1079', '1', 'Nossa Senhora das Graças', 'BR.18.4116406', 'ASCII:Nossa Senhora Das Gracas;ID:6322881', '10874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10874', '112', '12751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12752', '1079', '1', 'Nova Aliança do Ivaí', 'BR.18.4116505', 'ASCII:Nova Alianca Do Ivai;ID:6322882', '10875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10875', '112', '12752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12753', '1079', '1', 'Nova América da Colina', 'BR.18.4116604', 'ASCII:Nova America Da Colina;ID:6322883', '10876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10876', '112', '12753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12754', '1079', '1', 'Nova Aurora', 'BR.18.4116703', 'ASCII:Nova Aurora;ID:6322884', '10877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10877', '112', '12754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12755', '1079', '1', 'Nova Cantu', 'BR.18.4116802', 'ASCII:Nova Cantu;ID:6322885', '10878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10878', '112', '12755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12756', '1079', '1', 'Nova Esperança', 'BR.18.4116901', 'ASCII:Nova Esperanca;ID:6322886', '10879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10879', '112', '12756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12757', '1079', '1', 'Nova Esperança do Sudoeste', 'BR.18.4116950', 'ASCII:Nova Esperanca Do Sudoeste;ID:6322887', '10880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10880', '112', '12757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4116950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12758', '1079', '1', 'Nova Fátima', 'BR.18.4117008', 'ASCII:Nova Fatima;ID:6322888', '10881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10881', '112', '12758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12759', '1079', '1', 'Nova Laranjeiras', 'BR.18.4117057', 'ASCII:Nova Laranjeiras;ID:6322889', '10882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10882', '112', '12759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12760', '1079', '1', 'Nova Londrina', 'BR.18.4117107', 'ASCII:Nova Londrina;ID:6322890', '10883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10883', '112', '12760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12761', '1079', '1', 'Nova Olímpia', 'BR.18.4117206', 'ASCII:Nova Olimpia;ID:6322891', '10884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10884', '112', '12761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12762', '1079', '1', 'Nova Santa Bárbara', 'BR.18.4117214', 'ASCII:Nova Santa Barbara;ID:6322892', '10885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10885', '112', '12762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12763', '1079', '1', 'Nova Santa Rosa', 'BR.18.4117222', 'ASCII:Nova Santa Rosa;ID:6322893', '10886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10886', '112', '12763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12764', '1079', '1', 'Nova Prata do Iguaçu', 'BR.18.4117255', 'ASCII:Nova Prata Do Iguacu;ID:6322894', '10887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10887', '112', '12764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12765', '1079', '1', 'Nova Tebas', 'BR.18.4117271', 'ASCII:Nova Tebas;ID:6322895', '10888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10888', '112', '12765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12766', '1079', '1', 'Novo Itacolomi', 'BR.18.4117297', 'ASCII:Novo Itacolomi;ID:6322896', '10889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10889', '112', '12766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12767', '1079', '1', 'Ourizona', 'BR.18.4117404', 'ASCII:Ourizona;ID:6322897', '10890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10890', '112', '12767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12768', '1079', '1', 'Ouro Verde do Oeste', 'BR.18.4117453', 'ASCII:Ouro Verde Do Oeste;ID:6322898', '10891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10891', '112', '12768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12769', '1079', '1', 'Paiçandu', 'BR.18.4117503', 'ASCII:Paicandu;ID:6322899', '10892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10892', '112', '12769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12770', '1079', '1', 'Palmas', 'BR.18.4117602', 'ASCII:Palmas;ID:6322900', '10893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10893', '112', '12770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12771', '1079', '1', 'Palmeira', 'BR.18.4117701', 'ASCII:Palmeira;ID:6322901', '10894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10894', '112', '12771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12772', '1079', '1', 'Palmital', 'BR.18.4117800', 'ASCII:Palmital;ID:6322902', '10895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10895', '112', '12772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12773', '1079', '1', 'Palotina', 'BR.18.4117909', 'ASCII:Palotina;ID:6322903', '10896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10896', '112', '12773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12774', '1079', '1', 'Paraíso do Norte', 'BR.18.4118006', 'ASCII:Paraiso Do Norte;ID:6322904', '10897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10897', '112', '12774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12775', '1079', '1', 'Paranacity', 'BR.18.4118105', 'ASCII:Paranacity;ID:6322905', '10898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10898', '112', '12775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12776', '1079', '1', 'Paranaguá', 'BR.18.4118204', 'ASCII:Paranagua;ID:6322906', '10899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10899', '112', '12776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12777', '1079', '1', 'Paranapoema', 'BR.18.4118303', 'ASCII:Paranapoema;ID:6322907', '10900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10900', '112', '12777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12778', '1079', '1', 'Paranavaí', 'BR.18.4118402', 'ASCII:Paranavai;ID:6322908', '10901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10901', '112', '12778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12779', '1079', '1', 'Pato Bragado', 'BR.18.4118451', 'ASCII:Pato Bragado;ID:6322909', '10902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10902', '112', '12779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12780', '1079', '1', 'Pato Branco', 'BR.18.4118501', 'ASCII:Pato Branco;ID:6322910', '10903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10903', '112', '12780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12781', '1079', '1', 'Paula Freitas', 'BR.18.4118600', 'ASCII:Paula Freitas;ID:6322911', '10904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10904', '112', '12781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12782', '1079', '1', 'Paulo Frontin', 'BR.18.4118709', 'ASCII:Paulo Frontin;ID:6322912', '10905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10905', '112', '12782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12783', '1079', '1', 'Peabiru', 'BR.18.4118808', 'ASCII:Peabiru;ID:6322913', '10906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10906', '112', '12783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12784', '1079', '1', 'Perobal', 'BR.18.4118857', 'ASCII:Perobal;ID:6322914', '10907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10907', '112', '12784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12785', '1079', '1', 'Pérola', 'BR.18.4118907', 'ASCII:Perola;ID:6322915', '10908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10908', '112', '12785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4118907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12786', '1079', '1', 'Pérola d''Oeste', 'BR.18.4119004', 'ASCII:Perola D''Oeste;ID:6322916', '10909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10909', '112', '12786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12787', '1079', '1', 'Piên', 'BR.18.4119103', 'ASCII:Pien;ID:6322917', '10910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10910', '112', '12787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12788', '1079', '1', 'Pinhais', 'BR.18.4119152', 'ASCII:Pinhais;ID:6322918', '10911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10911', '112', '12788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12789', '1079', '1', 'Pinhalão', 'BR.18.4119202', 'ASCII:Pinhalao;ID:6322919', '10912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10912', '112', '12789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12790', '1079', '1', 'Pinhal de São Bento', 'BR.18.4119251', 'ASCII:Pinhal De Sao Bento;ID:6322920', '10913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10913', '112', '12790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12791', '1079', '1', 'Piraí do Sul', 'BR.18.4119400', 'ASCII:Pirai Do Sul;ID:6322921', '10914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10914', '112', '12791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12792', '1079', '1', 'Piraquara', 'BR.18.4119509', 'ASCII:Piraquara;ID:6322922', '10915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10915', '112', '12792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12793', '1079', '1', 'Pitanga', 'BR.18.4119608', 'ASCII:Pitanga;ID:6322923', '10916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10916', '112', '12793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12794', '1079', '1', 'Pitangueiras', 'BR.18.4119657', 'ASCII:Pitangueiras;ID:6322924', '10917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10917', '112', '12794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12795', '1079', '1', 'Planalto', 'BR.18.4119806', 'ASCII:Planalto;ID:6322925', '10918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10918', '112', '12795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12796', '1079', '1', 'Ponta Grossa', 'BR.18.4119905', 'ASCII:Ponta Grossa;ID:6322926', '10919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10919', '112', '12796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12797', '1079', '1', 'Pontal do Paraná', 'BR.18.4119954', 'ASCII:Pontal Do Parana;ID:6322927', '10920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10920', '112', '12797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12798', '1079', '1', 'Porecatu', 'BR.18.4120002', 'ASCII:Porecatu;ID:6322928', '10921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10921', '112', '12798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12799', '1079', '1', 'Porto Amazonas', 'BR.18.4120101', 'ASCII:Porto Amazonas;ID:6322929', '10922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10922', '112', '12799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12800', '1079', '1', 'Porto Barreiro', 'BR.18.4120150', 'ASCII:Porto Barreiro;ID:6322930', '10923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10923', '112', '12800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12801', '1079', '1', 'Porto Rico', 'BR.18.4120200', 'ASCII:Porto Rico;ID:6322931', '10924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10924', '112', '12801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12802', '1079', '1', 'Porto Vitória', 'BR.18.4120309', 'ASCII:Porto Vitoria;ID:6322932', '10925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10925', '112', '12802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12803', '1079', '1', 'Prado Ferreira', 'BR.18.4120333', 'ASCII:Prado Ferreira;ID:6322933', '10926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10926', '112', '12803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12804', '1079', '1', 'Pranchita', 'BR.18.4120358', 'ASCII:Pranchita;ID:6322934', '10927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10927', '112', '12804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12805', '1079', '1', 'Presidente Castelo Branco', 'BR.18.4120408', 'ASCII:Presidente Castelo Branco;ID:6322935', '10928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10928', '112', '12805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12806', '1079', '1', 'Primeiro de Maio', 'BR.18.4120507', 'ASCII:Primeiro De Maio;ID:6322936', '10929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10929', '112', '12806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12807', '1079', '1', 'Prudentópolis', 'BR.18.4120606', 'ASCII:Prudentopolis;ID:6322937', '10930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10930', '112', '12807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12808', '1079', '1', 'Quarto Centenário', 'BR.18.4120655', 'ASCII:Quarto Centenario;ID:6322938', '10931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10931', '112', '12808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12809', '1079', '1', 'Quatiguá', 'BR.18.4120705', 'ASCII:Quatigua;ID:6322939', '10932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10932', '112', '12809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12810', '1079', '1', 'Quatro Barras', 'BR.18.4120804', 'ASCII:Quatro Barras;ID:6322940', '10933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10933', '112', '12810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12811', '1079', '1', 'Quatro Pontes', 'BR.18.4120853', 'ASCII:Quatro Pontes;ID:6322941', '10934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10934', '112', '12811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12812', '1079', '1', 'Quedas do Iguaçu', 'BR.18.4120903', 'ASCII:Quedas Do Iguacu;ID:6322942', '10935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10935', '112', '12812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4120903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12813', '1079', '1', 'Querência do Norte', 'BR.18.4121000', 'ASCII:Querencia Do Norte;ID:6322943', '10936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10936', '112', '12813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12814', '1079', '1', 'Quinta do Sol', 'BR.18.4121109', 'ASCII:Quinta Do Sol;ID:6322944', '10937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10937', '112', '12814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12815', '1079', '1', 'Quitandinha', 'BR.18.4121208', 'ASCII:Quitandinha;ID:6322945', '10938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10938', '112', '12815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12816', '1079', '1', 'Ramilândia', 'BR.18.4121257', 'ASCII:Ramilandia;ID:6322946', '10939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10939', '112', '12816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12817', '1079', '1', 'Rancho Alegre', 'BR.18.4121307', 'ASCII:Rancho Alegre;ID:6322947', '10940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10940', '112', '12817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12818', '1079', '1', 'Rancho Alegre d''Oeste', 'BR.18.4121356', 'ASCII:Rancho Alegre D''Oeste;ID:6322948', '10941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10941', '112', '12818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12819', '1079', '1', 'Rebouças', 'BR.18.4121505', 'ASCII:Reboucas;ID:6322949', '10942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10942', '112', '12819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12820', '1079', '1', 'Renascença', 'BR.18.4121604', 'ASCII:Renascenca;ID:6322950', '10943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10943', '112', '12820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12821', '1079', '1', 'Reserva', 'BR.18.4121703', 'ASCII:Reserva;ID:6322951', '10944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10944', '112', '12821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12822', '1079', '1', 'Reserva do Iguaçu', 'BR.18.4121752', 'ASCII:Reserva Do Iguacu;ID:6322952', '10945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10945', '112', '12822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12823', '1079', '1', 'Ribeirão Claro', 'BR.18.4121802', 'ASCII:Ribeirao Claro;ID:6322953', '10946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10946', '112', '12823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12824', '1079', '1', 'Ribeirão do Pinhal', 'BR.18.4121901', 'ASCII:Ribeirao Do Pinhal;ID:6322954', '10947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10947', '112', '12824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4121901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12825', '1079', '1', 'Rio Azul', 'BR.18.4122008', 'ASCII:Rio Azul;ID:6322955', '10948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10948', '112', '12825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12826', '1079', '1', 'Rio Bom', 'BR.18.4122107', 'ASCII:Rio Bom;ID:6322956', '10949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10949', '112', '12826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12827', '1079', '1', 'Rio Bonito do Iguaçu', 'BR.18.4122156', 'ASCII:Rio Bonito Do Iguacu;ID:6322957', '10950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10950', '112', '12827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12828', '1079', '1', 'Rio Branco do Ivaí', 'BR.18.4122172', 'ASCII:Rio Branco Do Ivai;ID:6322958', '10951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10951', '112', '12828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12829', '1079', '1', 'Rio Branco do Sul', 'BR.18.4122206', 'ASCII:Rio Branco Do Sul;ID:6322959', '10952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10952', '112', '12829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12830', '1079', '1', 'Rio Negro', 'BR.18.4122305', 'ASCII:Rio Negro;ID:6322960', '10953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10953', '112', '12830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12831', '1079', '1', 'Rolândia', 'BR.18.4122404', 'ASCII:Rolandia;ID:6322961', '10954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10954', '112', '12831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12832', '1079', '1', 'Roncador', 'BR.18.4122503', 'ASCII:Roncador;ID:6322962', '10955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10955', '112', '12832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12833', '1079', '1', 'Rondon', 'BR.18.4122602', 'ASCII:Rondon;ID:6322963', '10956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10956', '112', '12833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12834', '1079', '1', 'Rosário do Ivaí', 'BR.18.4122651', 'ASCII:Rosario Do Ivai;ID:6322964', '10957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10957', '112', '12834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12835', '1079', '1', 'Sabáudia', 'BR.18.4122701', 'ASCII:Sabaudia;ID:6322965', '10958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10958', '112', '12835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12836', '1079', '1', 'Salgado Filho', 'BR.18.4122800', 'ASCII:Salgado Filho;ID:6322966', '10959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10959', '112', '12836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12837', '1079', '1', 'Salto do Itararé', 'BR.18.4122909', 'ASCII:Salto Do Itarare;ID:6322967', '10960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10960', '112', '12837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4122909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12838', '1079', '1', 'Salto do Lontra', 'BR.18.4123006', 'ASCII:Salto Do Lontra;ID:6322968', '10961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10961', '112', '12838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12839', '1079', '1', 'Santa Amélia', 'BR.18.4123105', 'ASCII:Santa Amelia;ID:6322969', '10962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10962', '112', '12839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12840', '1079', '1', 'Santa Helena', 'BR.18.4123501', 'ASCII:Santa Helena;ID:6322970', '10963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10963', '112', '12840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12841', '1079', '1', 'Santa Inês', 'BR.18.4123600', 'ASCII:Santa Ines;ID:6322971', '10964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10964', '112', '12841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12842', '1079', '1', 'Santa Isabel do Ivaí', 'BR.18.4123709', 'ASCII:Santa Isabel Do Ivai;ID:6322972', '10965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10965', '112', '12842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12843', '1079', '1', 'Santa Izabel do Oeste', 'BR.18.4123808', 'ASCII:Santa Izabel Do Oeste;ID:6322973', '10966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10966', '112', '12843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12844', '1079', '1', 'Santa Lúcia', 'BR.18.4123824', 'ASCII:Santa Lucia;ID:6322974', '10967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10967', '112', '12844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12845', '1079', '1', 'Santa Maria do Oeste', 'BR.18.4123857', 'ASCII:Santa Maria Do Oeste;ID:6322975', '10968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10968', '112', '12845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12846', '1079', '1', 'Santa Mariana', 'BR.18.4123907', 'ASCII:Santa Mariana;ID:6322976', '10969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10969', '112', '12846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12847', '1079', '1', 'Santa Mônica', 'BR.18.4123956', 'ASCII:Santa Monica;ID:6322977', '10970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10970', '112', '12847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4123956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12848', '1079', '1', 'Santa Tereza do Oeste', 'BR.18.4124020', 'ASCII:Santa Tereza Do Oeste;ID:6322978', '10971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10971', '112', '12848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12849', '1079', '1', 'Santa Terezinha de Itaipu', 'BR.18.4124053', 'ASCII:Santa Terezinha De Itaipu;ID:6322979', '10972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10972', '112', '12849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12850', '1079', '1', 'Santo Antônio da Platina', 'BR.18.4124103', 'ASCII:Santo Antonio Da Platina;ID:6322980', '10973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10973', '112', '12850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12851', '1079', '1', 'Santo Antônio do Caiuá', 'BR.18.4124202', 'ASCII:Santo Antonio Do Caiua;ID:6322981', '10974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10974', '112', '12851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12852', '1079', '1', 'Santo Antônio do Sudoeste', 'BR.18.4124400', 'ASCII:Santo Antonio Do Sudoeste;ID:6322982', '10975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10975', '112', '12852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12853', '1079', '1', 'Santo Inácio', 'BR.18.4124509', 'ASCII:Santo Inacio;ID:6322983', '10976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10976', '112', '12853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12854', '1079', '1', 'São Carlos do Ivaí', 'BR.18.4124608', 'ASCII:Sao Carlos Do Ivai;ID:6322984', '10977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10977', '112', '12854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12855', '1079', '1', 'São Jerônimo da Serra', 'BR.18.4124707', 'ASCII:Sao Jeronimo Da Serra;ID:6322985', '10978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10978', '112', '12855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12856', '1079', '1', 'São João do Caiuá', 'BR.18.4124905', 'ASCII:Sao Joao Do Caiua;ID:6322986', '10979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10979', '112', '12856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4124905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12857', '1079', '1', 'São João do Ivaí', 'BR.18.4125001', 'ASCII:Sao Joao Do Ivai;ID:6322987', '10980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10980', '112', '12857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12858', '1079', '1', 'São João do Triunfo', 'BR.18.4125100', 'ASCII:Sao Joao Do Triunfo;ID:6322988', '10981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10981', '112', '12858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12859', '1079', '1', 'São Jorge d''Oeste', 'BR.18.4125209', 'ASCII:Sao Jorge D''Oeste;ID:6322989', '10982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10982', '112', '12859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12860', '1079', '1', 'São Jorge do Ivaí', 'BR.18.4125308', 'ASCII:Sao Jorge Do Ivai;ID:6322990', '10983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10983', '112', '12860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12861', '1079', '1', 'São Jorge do Patrocínio', 'BR.18.4125357', 'ASCII:Sao Jorge Do Patrocinio;ID:6322991', '10984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10984', '112', '12861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12862', '1079', '1', 'São José dos Pinhais', 'BR.18.4125506', 'ASCII:Sao Jose Dos Pinhais;ID:6322992', '10985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10985', '112', '12862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12863', '1079', '1', 'São Manoel do Paraná', 'BR.18.4125555', 'ASCII:Sao Manoel Do Parana;ID:6322993', '10986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10986', '112', '12863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12864', '1079', '1', 'São Mateus do Sul', 'BR.18.4125605', 'ASCII:Sao Mateus Do Sul;ID:6322994', '10987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10987', '112', '12864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12865', '1079', '1', 'São Miguel do Iguaçu', 'BR.18.4125704', 'ASCII:Sao Miguel Do Iguacu;ID:6322995', '10988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10988', '112', '12865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12866', '1079', '1', 'São Pedro do Iguaçu', 'BR.18.4125753', 'ASCII:Sao Pedro Do Iguacu;ID:6322996', '10989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10989', '112', '12866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12867', '1079', '1', 'São Pedro do Ivaí', 'BR.18.4125803', 'ASCII:Sao Pedro Do Ivai;ID:6322997', '10990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10990', '112', '12867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12868', '1079', '1', 'São Pedro do Paraná', 'BR.18.4125902', 'ASCII:Sao Pedro Do Parana;ID:6322998', '10991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10991', '112', '12868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4125902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12869', '1079', '1', 'São Sebastião da Amoreira', 'BR.18.4126009', 'ASCII:Sao Sebastiao Da Amoreira;ID:6322999', '10992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10992', '112', '12869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12870', '1079', '1', 'São Tomé', 'BR.18.4126108', 'ASCII:Sao Tome;ID:6323000', '10993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10993', '112', '12870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12871', '1079', '1', 'Sapopema', 'BR.18.4126207', 'ASCII:Sapopema;ID:6323001', '10994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10994', '112', '12871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12872', '1079', '1', 'Sarandi', 'BR.18.4126256', 'ASCII:Sarandi;ID:6323002', '10995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10995', '112', '12872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12873', '1079', '1', 'Saudade do Iguaçu', 'BR.18.4126272', 'ASCII:Saudade Do Iguacu;ID:6323003', '10996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10996', '112', '12873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12874', '1079', '1', 'Sengés', 'BR.18.4126306', 'ASCII:Senges;ID:6323004', '10997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10997', '112', '12874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12875', '1079', '1', 'Sertaneja', 'BR.18.4126405', 'ASCII:Sertaneja;ID:6323005', '10998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10998', '112', '12875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12876', '1079', '1', 'Sertanópolis', 'BR.18.4126504', 'ASCII:Sertanopolis;ID:6323006', '10999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('10999', '112', '12876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12877', '1079', '1', 'Siqueira Campos', 'BR.18.4126603', 'ASCII:Siqueira Campos;ID:6323007', '11000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11000', '112', '12877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12878', '1079', '1', 'Sulina', 'BR.18.4126652', 'ASCII:Sulina;ID:6323008', '11001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11001', '112', '12878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12879', '1079', '1', 'Tamarana', 'BR.18.4126678', 'ASCII:Tamarana;ID:6323009', '11002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11002', '112', '12879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12880', '1079', '1', 'Tamboara', 'BR.18.4126702', 'ASCII:Tamboara;ID:6323010', '11003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11003', '112', '12880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12881', '1079', '1', 'Tapejara', 'BR.18.4126801', 'ASCII:Tapejara;ID:6323011', '11004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11004', '112', '12881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12882', '1079', '1', 'Tapira', 'BR.18.4126900', 'ASCII:Tapira;ID:6323012', '11005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11005', '112', '12882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4126900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12883', '1079', '1', 'Teixeira Soares', 'BR.18.4127007', 'ASCII:Teixeira Soares;ID:6323013', '11006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11006', '112', '12883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12884', '1079', '1', 'Terra Boa', 'BR.18.4127205', 'ASCII:Terra Boa;ID:6323014', '11007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11007', '112', '12884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12885', '1079', '1', 'Terra Rica', 'BR.18.4127304', 'ASCII:Terra Rica;ID:6323015', '11008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11008', '112', '12885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12886', '1079', '1', 'Terra Roxa', 'BR.18.4127403', 'ASCII:Terra Roxa;ID:6323016', '11009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11009', '112', '12886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12887', '1079', '1', 'Tibagi', 'BR.18.4127502', 'ASCII:Tibagi;ID:6323017', '11010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11010', '112', '12887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12888', '1079', '1', 'Tijucas do Sul', 'BR.18.4127601', 'ASCII:Tijucas Do Sul;ID:6323018', '11011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11011', '112', '12888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12889', '1079', '1', 'Toledo', 'BR.18.4127700', 'ASCII:Toledo;ID:6323019', '11012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11012', '112', '12889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12890', '1079', '1', 'Tomazina', 'BR.18.4127809', 'ASCII:Tomazina;ID:6323020', '11013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11013', '112', '12890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12891', '1079', '1', 'Tunas do Paraná', 'BR.18.4127882', 'ASCII:Tunas Do Parana;ID:6323021', '11014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11014', '112', '12891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12892', '1079', '1', 'Tuneiras do Oeste', 'BR.18.4127908', 'ASCII:Tuneiras Do Oeste;ID:6323022', '11015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11015', '112', '12892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12893', '1079', '1', 'Tupãssi', 'BR.18.4127957', 'ASCII:Tupassi;ID:6323023', '11016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11016', '112', '12893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12894', '1079', '1', 'Turvo', 'BR.18.4127965', 'ASCII:Turvo;ID:6323024', '11017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11017', '112', '12894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12895', '1079', '1', 'Ubiratã', 'BR.18.4128005', 'ASCII:Ubirata;ID:6323025', '11018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11018', '112', '12895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12896', '1079', '1', 'Umuarama', 'BR.18.4128104', 'ASCII:Umuarama;ID:6323026', '11019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11019', '112', '12896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12897', '1079', '1', 'União da Vitória', 'BR.18.4128203', 'ASCII:Uniao Da Vitoria;ID:6323027', '11020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11020', '112', '12897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12898', '1079', '1', 'Uniflor', 'BR.18.4128302', 'ASCII:Uniflor;ID:6323028', '11021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11021', '112', '12898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12899', '1079', '1', 'Uraí', 'BR.18.4128401', 'ASCII:Urai;ID:6323029', '11022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11022', '112', '12899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12900', '1079', '1', 'Wenceslau Braz', 'BR.18.4128500', 'ASCII:Wenceslau Braz;ID:6323030', '11023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11023', '112', '12900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12901', '1079', '1', 'Ventania', 'BR.18.4128534', 'ASCII:Ventania;ID:6323031', '11024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11024', '112', '12901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12902', '1079', '1', 'Vera Cruz do Oeste', 'BR.18.4128559', 'ASCII:Vera Cruz Do Oeste;ID:6323032', '11025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11025', '112', '12902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12903', '1079', '1', 'Verê', 'BR.18.4128609', 'ASCII:Vere;ID:6323033', '11026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11026', '112', '12903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12904', '1079', '1', 'Vila Alta', 'BR.18.4128625', 'ASCII:Vila Alta;ID:6323034', '11027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11027', '112', '12904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12905', '1079', '1', 'Doutor Ulysses', 'BR.18.4128633', 'ASCII:Doutor Ulysses;ID:6323035', '11028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11028', '112', '12905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12906', '1079', '1', 'Virmond', 'BR.18.4128658', 'ASCII:Virmond;ID:6323036', '11029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11029', '112', '12906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12907', '1079', '1', 'Vitorino', 'BR.18.4128708', 'ASCII:Vitorino;ID:6323037', '11030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11030', '112', '12907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12908', '1079', '1', 'Xambrê', 'BR.18.4128807', 'ASCII:Xambre;ID:6323038', '11031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11031', '112', '12908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4128807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12909', '1079', '1', 'Abdon Batista', 'BR.26.4200051', 'ASCII:Abdon Batista;ID:6323039', '11032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11032', '112', '12909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12910', '1079', '1', 'Abelardo Luz', 'BR.26.4200101', 'ASCII:Abelardo Luz;ID:6323040', '11033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11033', '112', '12910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12911', '1079', '1', 'Agrolândia', 'BR.26.4200200', 'ASCII:Agrolandia;ID:6323041', '11034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11034', '112', '12911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12912', '1079', '1', 'Agronômica', 'BR.26.4200309', 'ASCII:Agronomica;ID:6323042', '11035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11035', '112', '12912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12913', '1079', '1', 'Água Doce', 'BR.26.4200408', 'ASCII:Agua Doce;ID:6323043', '11036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11036', '112', '12913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12914', '1079', '1', 'Águas de Chapecó', 'BR.26.4200507', 'ASCII:Aguas De Chapeco;ID:6323044', '11037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11037', '112', '12914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12915', '1079', '1', 'Águas Frias', 'BR.26.4200556', 'ASCII:Aguas Frias;ID:6323045', '11038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11038', '112', '12915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12916', '1079', '1', 'Águas Mornas', 'BR.26.4200606', 'ASCII:Aguas Mornas;ID:6323046', '11039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11039', '112', '12916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12917', '1079', '1', 'Alfredo Wagner', 'BR.26.4200705', 'ASCII:Alfredo Wagner;ID:6323047', '11040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11040', '112', '12917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12918', '1079', '1', 'Alto Bela Vista', 'BR.26.4200754', 'ASCII:Alto Bela Vista;ID:6323048', '11041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11041', '112', '12918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12919', '1079', '1', 'Anchieta', 'BR.26.4200804', 'ASCII:Anchieta;ID:6323049', '11042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11042', '112', '12919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12920', '1079', '1', 'Angelina', 'BR.26.4200903', 'ASCII:Angelina;ID:6323050', '11043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11043', '112', '12920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4200903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12921', '1079', '1', 'Anita Garibaldi', 'BR.26.4201000', 'ASCII:Anita Garibaldi;ID:6323051', '11044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11044', '112', '12921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12922', '1079', '1', 'Anitápolis', 'BR.26.4201109', 'ASCII:Anitapolis;ID:6323052', '11045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11045', '112', '12922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12923', '1079', '1', 'Antônio Carlos', 'BR.26.4201208', 'ASCII:Antonio Carlos;ID:6323053', '11046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11046', '112', '12923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12924', '1079', '1', 'Apiúna', 'BR.26.4201257', 'ASCII:Apiuna;ID:6323054', '11047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11047', '112', '12924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12925', '1079', '1', 'Arabutã', 'BR.26.4201273', 'ASCII:Arabuta;ID:6323055', '11048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11048', '112', '12925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12926', '1079', '1', 'Araquari', 'BR.26.4201307', 'ASCII:Araquari;ID:6323056', '11049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11049', '112', '12926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12927', '1079', '1', 'Araranguá', 'BR.26.4201406', 'ASCII:Ararangua;ID:6323057', '11050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11050', '112', '12927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12928', '1079', '1', 'Armazém', 'BR.26.4201505', 'ASCII:Armazem;ID:6323058', '11051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11051', '112', '12928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12929', '1079', '1', 'Arroio Trinta', 'BR.26.4201604', 'ASCII:Arroio Trinta;ID:6323059', '11052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11052', '112', '12929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12930', '1079', '1', 'Arvoredo', 'BR.26.4201653', 'ASCII:Arvoredo;ID:6323060', '11053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11053', '112', '12930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12931', '1079', '1', 'Ascurra', 'BR.26.4201703', 'ASCII:Ascurra;ID:6323061', '11054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11054', '112', '12931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12932', '1079', '1', 'Atalanta', 'BR.26.4201802', 'ASCII:Atalanta;ID:6323062', '11055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11055', '112', '12932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12933', '1079', '1', 'Balneário Arroio do Silva', 'BR.26.4201950', 'ASCII:Balneario Arroio Do Silva;ID:6323063', '11056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11056', '112', '12933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12934', '1079', '1', 'Balneário Camboriú', 'BR.26.4202008', 'ASCII:Balneario Camboriu;ID:6323064', '11057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11057', '112', '12934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12935', '1079', '1', 'Balneário Barra do Sul', 'BR.26.4202057', 'ASCII:Balneario Barra Do Sul;ID:6323065', '11058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11058', '112', '12935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12936', '1079', '1', 'Balneário Gaivota', 'BR.26.4202073', 'ASCII:Balneario Gaivota;ID:6323066', '11059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11059', '112', '12936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12937', '1079', '1', 'Bandeirante', 'BR.26.4202081', 'ASCII:Bandeirante;ID:6323067', '11060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11060', '112', '12937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12938', '1079', '1', 'Barra Bonita', 'BR.26.4202099', 'ASCII:Barra Bonita;ID:6323068', '11061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11061', '112', '12938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12939', '1079', '1', 'Barra Velha', 'BR.26.4202107', 'ASCII:Barra Velha;ID:6323069', '11062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11062', '112', '12939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12940', '1079', '1', 'Bela Vista do Toldo', 'BR.26.4202131', 'ASCII:Bela Vista Do Toldo;ID:6323070', '11063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11063', '112', '12940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12941', '1079', '1', 'Belmonte', 'BR.26.4202156', 'ASCII:Belmonte;ID:6323071', '11064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11064', '112', '12941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12942', '1079', '1', 'Benedito Novo', 'BR.26.4202206', 'ASCII:Benedito Novo;ID:6323072', '11065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11065', '112', '12942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12943', '1079', '1', 'Biguaçu', 'BR.26.4202305', 'ASCII:Biguacu;ID:6323073', '11066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11066', '112', '12943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12944', '1079', '1', 'Blumenau', 'BR.26.4202404', 'ASCII:Blumenau;ID:6323074', '11067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11067', '112', '12944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12945', '1079', '1', 'Bocaina do Sul', 'BR.26.4202438', 'ASCII:Bocaina Do Sul;ID:6323075', '11068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11068', '112', '12945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12946', '1079', '1', 'Bombinhas', 'BR.26.4202453', 'ASCII:Bombinhas;ID:6323076', '11069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11069', '112', '12946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12947', '1079', '1', 'Bom Jardim da Serra', 'BR.26.4202503', 'ASCII:Bom Jardim Da Serra;ID:6323077', '11070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11070', '112', '12947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12948', '1079', '1', 'Bom Jesus', 'BR.26.4202537', 'ASCII:Bom Jesus;ID:6323078', '11071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11071', '112', '12948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202537» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12949', '1079', '1', 'Bom Jesus do Oeste', 'BR.26.4202578', 'ASCII:Bom Jesus Do Oeste;ID:6323079', '11072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11072', '112', '12949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12950', '1079', '1', 'Bom Retiro', 'BR.26.4202602', 'ASCII:Bom Retiro;ID:6323080', '11073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11073', '112', '12950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12951', '1079', '1', 'Botuverá', 'BR.26.4202701', 'ASCII:Botuvera;ID:6323081', '11074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11074', '112', '12951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12952', '1079', '1', 'Braço do Norte', 'BR.26.4202800', 'ASCII:Braco Do Norte;ID:6323082', '11075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11075', '112', '12952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12953', '1079', '1', 'Braço do Trombudo', 'BR.26.4202859', 'ASCII:Braco Do Trombudo;ID:6323083', '11076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11076', '112', '12953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12954', '1079', '1', 'Brunópolis', 'BR.26.4202875', 'ASCII:Brunopolis;ID:6323084', '11077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11077', '112', '12954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12955', '1079', '1', 'Brusque', 'BR.26.4202909', 'ASCII:Brusque;ID:6323085', '11078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11078', '112', '12955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4202909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12956', '1079', '1', 'Caçador', 'BR.26.4203006', 'ASCII:Cacador;ID:6323086', '11079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11079', '112', '12956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12957', '1079', '1', 'Caibi', 'BR.26.4203105', 'ASCII:Caibi;ID:6323087', '11080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11080', '112', '12957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12958', '1079', '1', 'Calmon', 'BR.26.4203154', 'ASCII:Calmon;ID:6323088', '11081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11081', '112', '12958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12959', '1079', '1', 'Camboriú', 'BR.26.4203204', 'ASCII:Camboriu;ID:6323089', '11082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11082', '112', '12959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12960', '1079', '1', 'Capão Alto', 'BR.26.4203253', 'ASCII:Capao Alto;ID:6323090', '11083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11083', '112', '12960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12961', '1079', '1', 'Campo Alegre', 'BR.26.4203303', 'ASCII:Campo Alegre;ID:6323091', '11084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11084', '112', '12961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12962', '1079', '1', 'Campo Belo do Sul', 'BR.26.4203402', 'ASCII:Campo Belo Do Sul;ID:6323092', '11085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11085', '112', '12962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12963', '1079', '1', 'Campos Novos', 'BR.26.4203600', 'ASCII:Campos Novos;ID:6323093', '11086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11086', '112', '12963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12964', '1079', '1', 'Canelinha', 'BR.26.4203709', 'ASCII:Canelinha;ID:6323094', '11087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11087', '112', '12964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12965', '1079', '1', 'Canoinhas', 'BR.26.4203808', 'ASCII:Canoinhas;ID:6323095', '11088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11088', '112', '12965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12966', '1079', '1', 'Capinzal', 'BR.26.4203907', 'ASCII:Capinzal;ID:6323096', '11089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11089', '112', '12966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12967', '1079', '1', 'Capivari de Baixo', 'BR.26.4203956', 'ASCII:Capivari De Baixo;ID:6323097', '11090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11090', '112', '12967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4203956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12968', '1079', '1', 'Catanduvas', 'BR.26.4204004', 'ASCII:Catanduvas;ID:6323098', '11091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11091', '112', '12968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12969', '1079', '1', 'Caxambu do Sul', 'BR.26.4204103', 'ASCII:Caxambu Do Sul;ID:6323099', '11092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11092', '112', '12969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12970', '1079', '1', 'Celso Ramos', 'BR.26.4204152', 'ASCII:Celso Ramos;ID:6323100', '11093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11093', '112', '12970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12971', '1079', '1', 'Cerro Negro', 'BR.26.4204178', 'ASCII:Cerro Negro;ID:6323101', '11094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11094', '112', '12971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12972', '1079', '1', 'Chapadão do Lageado', 'BR.26.4204194', 'ASCII:Chapadao Do Lageado;ID:6323102', '11095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11095', '112', '12972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12973', '1079', '1', 'Chapecó', 'BR.26.4204202', 'ASCII:Chapeco;ID:6323103', '11096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11096', '112', '12973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12974', '1079', '1', 'Cocal do Sul', 'BR.26.4204251', 'ASCII:Cocal Do Sul;ID:6323104', '11097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11097', '112', '12974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12975', '1079', '1', 'Cordilheira Alta', 'BR.26.4204350', 'ASCII:Cordilheira Alta;ID:6323105', '11098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11098', '112', '12975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12976', '1079', '1', 'Coronel Freitas', 'BR.26.4204400', 'ASCII:Coronel Freitas;ID:6323106', '11099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11099', '112', '12976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12977', '1079', '1', 'Coronel Martins', 'BR.26.4204459', 'ASCII:Coronel Martins;ID:6323107', '11100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11100', '112', '12977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12978', '1079', '1', 'Corupá', 'BR.26.4204509', 'ASCII:Corupa;ID:6323108', '11101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11101', '112', '12978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12979', '1079', '1', 'Cunha Porã', 'BR.26.4204707', 'ASCII:Cunha Pora;ID:6323109', '11102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11102', '112', '12979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12980', '1079', '1', 'Cunhataí', 'BR.26.4204756', 'ASCII:Cunhatai;ID:6323110', '11103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11103', '112', '12980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12981', '1079', '1', 'Curitibanos', 'BR.26.4204806', 'ASCII:Curitibanos;ID:6323111', '11104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11104', '112', '12981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12982', '1079', '1', 'Descanso', 'BR.26.4204905', 'ASCII:Descanso;ID:6323112', '11105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11105', '112', '12982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4204905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12983', '1079', '1', 'Dionísio Cerqueira', 'BR.26.4205001', 'ASCII:Dionisio Cerqueira;ID:6323113', '11106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11106', '112', '12983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12984', '1079', '1', 'Dona Emma', 'BR.26.4205100', 'ASCII:Dona Emma;ID:6323114', '11107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11107', '112', '12984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12985', '1079', '1', 'Doutor Pedrinho', 'BR.26.4205159', 'ASCII:Doutor Pedrinho;ID:6323115', '11108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11108', '112', '12985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12986', '1079', '1', 'Entre Rios', 'BR.26.4205175', 'ASCII:Entre Rios;ID:6323116', '11109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11109', '112', '12986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12987', '1079', '1', 'Ermo', 'BR.26.4205191', 'ASCII:Ermo;ID:6323117', '11110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11110', '112', '12987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12988', '1079', '1', 'Erval Velho', 'BR.26.4205209', 'ASCII:Erval Velho;ID:6323118', '11111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11111', '112', '12988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12989', '1079', '1', 'Faxinal dos Guedes', 'BR.26.4205308', 'ASCII:Faxinal Dos Guedes;ID:6323119', '11112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11112', '112', '12989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12990', '1079', '1', 'Flor do Sertão', 'BR.26.4205357', 'ASCII:Flor Do Sertao;ID:6323120', '11113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11113', '112', '12990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12991', '1079', '1', 'Florianópolis', 'BR.26.4205407', 'ASCII:Florianopolis;ID:6323121', '11114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11114', '112', '12991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12992', '1079', '1', 'Formosa do Sul', 'BR.26.4205431', 'ASCII:Formosa Do Sul;ID:6323122', '11115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11115', '112', '12992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12993', '1079', '1', 'Forquilhinha', 'BR.26.4205456', 'ASCII:Forquilhinha;ID:6323123', '11116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11116', '112', '12993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12994', '1079', '1', 'Fraiburgo', 'BR.26.4205506', 'ASCII:Fraiburgo;ID:6323124', '11117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11117', '112', '12994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12995', '1079', '1', 'Frei Rogério', 'BR.26.4205555', 'ASCII:Frei Rogerio;ID:6323125', '11118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11118', '112', '12995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12996', '1079', '1', 'Galvão', 'BR.26.4205605', 'ASCII:Galvao;ID:6323126', '11119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11119', '112', '12996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12997', '1079', '1', 'Garopaba', 'BR.26.4205704', 'ASCII:Garopaba;ID:6323127', '11120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11120', '112', '12997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12998', '1079', '1', 'Garuva', 'BR.26.4205803', 'ASCII:Garuva;ID:6323128', '11121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11121', '112', '12998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('12999', '1079', '1', 'Gaspar', 'BR.26.4205902', 'ASCII:Gaspar;ID:6323129', '11122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11122', '112', '12999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4205902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13000', '1079', '1', 'Governador Celso Ramos', 'BR.26.4206009', 'ASCII:Governador Celso Ramos;ID:6323130', '11123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11123', '112', '13000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13001', '1079', '1', 'Grão Pará', 'BR.26.4206108', 'ASCII:Grao Para;ID:6323131', '11124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11124', '112', '13001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13002', '1079', '1', 'Gravatal', 'BR.26.4206207', 'ASCII:Gravatal;ID:6323132', '11125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11125', '112', '13002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13003', '1079', '1', 'Guabiruba', 'BR.26.4206306', 'ASCII:Guabiruba;ID:6323133', '11126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11126', '112', '13003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13004', '1079', '1', 'Guaraciaba', 'BR.26.4206405', 'ASCII:Guaraciaba;ID:6323134', '11127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11127', '112', '13004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13005', '1079', '1', 'Guaramirim', 'BR.26.4206504', 'ASCII:Guaramirim;ID:6323135', '11128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11128', '112', '13005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13006', '1079', '1', 'Guarujá do Sul', 'BR.26.4206603', 'ASCII:Guaruja Do Sul;ID:6323136', '11129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11129', '112', '13006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13007', '1079', '1', 'Guatambú', 'BR.26.4206652', 'ASCII:Guatambu;ID:6323137', '11130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11130', '112', '13007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13008', '1079', '1', 'Herval d''Oeste', 'BR.26.4206702', 'ASCII:Herval D''Oeste;ID:6323138', '11131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11131', '112', '13008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13009', '1079', '1', 'Ibiam', 'BR.26.4206751', 'ASCII:Ibiam;ID:6323139', '11132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11132', '112', '13009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13010', '1079', '1', 'Ibicaré', 'BR.26.4206801', 'ASCII:Ibicare;ID:6323140', '11133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11133', '112', '13010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13011', '1079', '1', 'Ibirama', 'BR.26.4206900', 'ASCII:Ibirama;ID:6323141', '11134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11134', '112', '13011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4206900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13012', '1079', '1', 'Içara', 'BR.26.4207007', 'ASCII:Icara;ID:6323142', '11135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11135', '112', '13012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13013', '1079', '1', 'Ilhota', 'BR.26.4207106', 'ASCII:Ilhota;ID:6323143', '11136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11136', '112', '13013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13014', '1079', '1', 'Imaruí', 'BR.26.4207205', 'ASCII:Imarui;ID:6323144', '11137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11137', '112', '13014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13015', '1079', '1', 'Imbituba', 'BR.26.4207304', 'ASCII:Imbituba;ID:6323145', '11138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11138', '112', '13015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13016', '1079', '1', 'Imbuia', 'BR.26.4207403', 'ASCII:Imbuia;ID:6323146', '11139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11139', '112', '13016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13017', '1079', '1', 'Indaial', 'BR.26.4207502', 'ASCII:Indaial;ID:6323147', '11140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11140', '112', '13017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13018', '1079', '1', 'Iomerê', 'BR.26.4207577', 'ASCII:Iomere;ID:6323148', '11141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11141', '112', '13018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13019', '1079', '1', 'Ipira', 'BR.26.4207601', 'ASCII:Ipira;ID:6323149', '11142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11142', '112', '13019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13020', '1079', '1', 'Iporã do Oeste', 'BR.26.4207650', 'ASCII:Ipora Do Oeste;ID:6323150', '11143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11143', '112', '13020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13021', '1079', '1', 'Ipuaçu', 'BR.26.4207684', 'ASCII:Ipuacu;ID:6323151', '11144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11144', '112', '13021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13022', '1079', '1', 'Ipumirim', 'BR.26.4207700', 'ASCII:Ipumirim;ID:6323152', '11145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11145', '112', '13022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13023', '1079', '1', 'Iraceminha', 'BR.26.4207759', 'ASCII:Iraceminha;ID:6323153', '11146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11146', '112', '13023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13024', '1079', '1', 'Irani', 'BR.26.4207809', 'ASCII:Irani;ID:6323154', '11147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11147', '112', '13024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13025', '1079', '1', 'Irati', 'BR.26.4207858', 'ASCII:Irati;ID:6323155', '11148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11148', '112', '13025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13026', '1079', '1', 'Irineópolis', 'BR.26.4207908', 'ASCII:Irineopolis;ID:6323156', '11149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11149', '112', '13026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4207908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13027', '1079', '1', 'Itá', 'BR.26.4208005', 'ASCII:Ita;ID:6323157', '11150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11150', '112', '13027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13028', '1079', '1', 'Itaiópolis', 'BR.26.4208104', 'ASCII:Itaiopolis;ID:6323158', '11151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11151', '112', '13028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13029', '1079', '1', 'Itajaí', 'BR.26.4208203', 'ASCII:Itajai;ID:6323159', '11152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11152', '112', '13029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13030', '1079', '1', 'Itapiranga', 'BR.26.4208401', 'ASCII:Itapiranga;ID:6323160', '11153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11153', '112', '13030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13031', '1079', '1', 'Itapoá', 'BR.26.4208450', 'ASCII:Itapoa;ID:6323161', '11154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11154', '112', '13031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13032', '1079', '1', 'Ituporanga', 'BR.26.4208500', 'ASCII:Ituporanga;ID:6323162', '11155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11155', '112', '13032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13033', '1079', '1', 'Jaborá', 'BR.26.4208609', 'ASCII:Jabora;ID:6323163', '11156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11156', '112', '13033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13034', '1079', '1', 'Jacinto Machado', 'BR.26.4208708', 'ASCII:Jacinto Machado;ID:6323164', '11157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11157', '112', '13034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13035', '1079', '1', 'Jaguaruna', 'BR.26.4208807', 'ASCII:Jaguaruna;ID:6323165', '11158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11158', '112', '13035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13036', '1079', '1', 'Jaraguá do Sul', 'BR.26.4208906', 'ASCII:Jaragua Do Sul;ID:6323166', '11159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11159', '112', '13036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13037', '1079', '1', 'Jardinópolis', 'BR.26.4208955', 'ASCII:Jardinopolis;ID:6323167', '11160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11160', '112', '13037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4208955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13038', '1079', '1', 'Joaçaba', 'BR.26.4209003', 'ASCII:Joacaba;ID:6323168', '11161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11161', '112', '13038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13039', '1079', '1', 'Joinville', 'BR.26.4209102', 'ASCII:Joinville;ID:6323169', '11162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11162', '112', '13039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13040', '1079', '1', 'José Boiteux', 'BR.26.4209151', 'ASCII:Jose Boiteux;ID:6323170', '11163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11163', '112', '13040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13041', '1079', '1', 'Jupiá', 'BR.26.4209177', 'ASCII:Jupia;ID:6323171', '11164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11164', '112', '13041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13042', '1079', '1', 'Lacerdópolis', 'BR.26.4209201', 'ASCII:Lacerdopolis;ID:6323172', '11165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11165', '112', '13042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13043', '1079', '1', 'Lages', 'BR.26.4209300', 'ASCII:Lages;ID:6323173', '11166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11166', '112', '13043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13044', '1079', '1', 'Laguna', 'BR.26.4209409', 'ASCII:Laguna;ID:6323174', '11167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11167', '112', '13044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13045', '1079', '1', 'Lajeado Grande', 'BR.26.4209458', 'ASCII:Lajeado Grande;ID:6323175', '11168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11168', '112', '13045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13046', '1079', '1', 'Laurentino', 'BR.26.4209508', 'ASCII:Laurentino;ID:6323176', '11169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11169', '112', '13046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13047', '1079', '1', 'Lauro Muller', 'BR.26.4209607', 'ASCII:Lauro Muller;ID:6323177', '11170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11170', '112', '13047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13048', '1079', '1', 'Lebon Régis', 'BR.26.4209706', 'ASCII:Lebon Regis;ID:6323178', '11171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11171', '112', '13048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13049', '1079', '1', 'Leoberto Leal', 'BR.26.4209805', 'ASCII:Leoberto Leal;ID:6323179', '11172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11172', '112', '13049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13050', '1079', '1', 'Lindóia do Sul', 'BR.26.4209854', 'ASCII:Lindoia Do Sul;ID:6323180', '11173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11173', '112', '13050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13051', '1079', '1', 'Lontras', 'BR.26.4209904', 'ASCII:Lontras;ID:6323181', '11174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11174', '112', '13051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4209904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13052', '1079', '1', 'Luiz Alves', 'BR.26.4210001', 'ASCII:Luiz Alves;ID:6323182', '11175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11175', '112', '13052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13053', '1079', '1', 'Luzerna', 'BR.26.4210035', 'ASCII:Luzerna;ID:6323183', '11176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11176', '112', '13053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13054', '1079', '1', 'Macieira', 'BR.26.4210050', 'ASCII:Macieira;ID:6323184', '11177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11177', '112', '13054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13055', '1079', '1', 'Mafra', 'BR.26.4210100', 'ASCII:Mafra;ID:6323185', '11178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11178', '112', '13055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13056', '1079', '1', 'Major Gercino', 'BR.26.4210209', 'ASCII:Major Gercino;ID:6323186', '11179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11179', '112', '13056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13057', '1079', '1', 'Major Vieira', 'BR.26.4210308', 'ASCII:Major Vieira;ID:6323187', '11180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11180', '112', '13057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13058', '1079', '1', 'Maracajá', 'BR.26.4210407', 'ASCII:Maracaja;ID:6323188', '11181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11181', '112', '13058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13059', '1079', '1', 'Maravilha', 'BR.26.4210506', 'ASCII:Maravilha;ID:6323189', '11182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11182', '112', '13059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13060', '1079', '1', 'Marema', 'BR.26.4210555', 'ASCII:Marema;ID:6323190', '11183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11183', '112', '13060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13061', '1079', '1', 'Massaranduba', 'BR.26.4210605', 'ASCII:Massaranduba;ID:6323191', '11184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11184', '112', '13061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13062', '1079', '1', 'Matos Costa', 'BR.26.4210704', 'ASCII:Matos Costa;ID:6323192', '11185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11185', '112', '13062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13063', '1079', '1', 'Meleiro', 'BR.26.4210803', 'ASCII:Meleiro;ID:6323193', '11186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11186', '112', '13063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13064', '1079', '1', 'Mirim Doce', 'BR.26.4210852', 'ASCII:Mirim Doce;ID:6323194', '11187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11187', '112', '13064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13065', '1079', '1', 'Modelo', 'BR.26.4210902', 'ASCII:Modelo;ID:6323195', '11188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11188', '112', '13065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4210902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13066', '1079', '1', 'Mondaí', 'BR.26.4211009', 'ASCII:Mondai;ID:6323196', '11189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11189', '112', '13066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13067', '1079', '1', 'Monte Carlo', 'BR.26.4211058', 'ASCII:Monte Carlo;ID:6323197', '11190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11190', '112', '13067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13068', '1079', '1', 'Monte Castelo', 'BR.26.4211108', 'ASCII:Monte Castelo;ID:6323198', '11191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11191', '112', '13068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13069', '1079', '1', 'Morro da Fumaça', 'BR.26.4211207', 'ASCII:Morro Da Fumaca;ID:6323199', '11192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11192', '112', '13069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13070', '1079', '1', 'Morro Grande', 'BR.26.4211256', 'ASCII:Morro Grande;ID:6323200', '11193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11193', '112', '13070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13071', '1079', '1', 'Navegantes', 'BR.26.4211306', 'ASCII:Navegantes;ID:6323201', '11194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11194', '112', '13071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13072', '1079', '1', 'Nova Erechim', 'BR.26.4211405', 'ASCII:Nova Erechim;ID:6323202', '11195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11195', '112', '13072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13073', '1079', '1', 'Nova Itaberaba', 'BR.26.4211454', 'ASCII:Nova Itaberaba;ID:6323203', '11196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11196', '112', '13073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13074', '1079', '1', 'Nova Trento', 'BR.26.4211504', 'ASCII:Nova Trento;ID:6323204', '11197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11197', '112', '13074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13075', '1079', '1', 'Nova Veneza', 'BR.26.4211603', 'ASCII:Nova Veneza;ID:6323205', '11198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11198', '112', '13075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13076', '1079', '1', 'Novo Horizonte', 'BR.26.4211652', 'ASCII:Novo Horizonte;ID:6323206', '11199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11199', '112', '13076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13077', '1079', '1', 'Orleans', 'BR.26.4211702', 'ASCII:Orleans;ID:6323207', '11200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11200', '112', '13077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13078', '1079', '1', 'Otacílio Costa', 'BR.26.4211751', 'ASCII:Otacilio Costa;ID:6323208', '11201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11201', '112', '13078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13079', '1079', '1', 'Ouro', 'BR.26.4211801', 'ASCII:Ouro;ID:6323209', '11202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11202', '112', '13079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13080', '1079', '1', 'Ouro Verde', 'BR.26.4211850', 'ASCII:Ouro Verde;ID:6323210', '11203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11203', '112', '13080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13081', '1079', '1', 'Paial', 'BR.26.4211876', 'ASCII:Paial;ID:6323211', '11204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11204', '112', '13081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13082', '1079', '1', 'Painel', 'BR.26.4211892', 'ASCII:Painel;ID:6323212', '11205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11205', '112', '13082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13083', '1079', '1', 'Palhoça', 'BR.26.4211900', 'ASCII:Palhoca;ID:6323213', '11206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11206', '112', '13083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4211900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13084', '1079', '1', 'Palma Sola', 'BR.26.4212007', 'ASCII:Palma Sola;ID:6323214', '11207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11207', '112', '13084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13085', '1079', '1', 'Palmeira', 'BR.26.4212056', 'ASCII:Palmeira;ID:6323215', '11208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11208', '112', '13085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13086', '1079', '1', 'Palmitos', 'BR.26.4212106', 'ASCII:Palmitos;ID:6323216', '11209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11209', '112', '13086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13087', '1079', '1', 'Papanduva', 'BR.26.4212205', 'ASCII:Papanduva;ID:6323217', '11210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11210', '112', '13087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13088', '1079', '1', 'Passo de Torres', 'BR.26.4212254', 'ASCII:Passo De Torres;ID:6323218', '11211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11211', '112', '13088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13089', '1079', '1', 'Paulo Lopes', 'BR.26.4212304', 'ASCII:Paulo Lopes;ID:6323219', '11212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11212', '112', '13089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13090', '1079', '1', 'Pedras Grandes', 'BR.26.4212403', 'ASCII:Pedras Grandes;ID:6323220', '11213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11213', '112', '13090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13091', '1079', '1', 'Penha', 'BR.26.4212502', 'ASCII:Penha;ID:6323221', '11214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11214', '112', '13091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13092', '1079', '1', 'Peritiba', 'BR.26.4212601', 'ASCII:Peritiba;ID:6323222', '11215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11215', '112', '13092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13093', '1079', '1', 'Petrolândia', 'BR.26.4212700', 'ASCII:Petrolandia;ID:6323223', '11216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11216', '112', '13093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13094', '1079', '1', 'Piçarras', 'BR.26.4212809', 'ASCII:Picarras;ID:6323224', '11217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11217', '112', '13094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13095', '1079', '1', 'Pinhalzinho', 'BR.26.4212908', 'ASCII:Pinhalzinho;ID:6323225', '11218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11218', '112', '13095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4212908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13096', '1079', '1', 'Pinheiro Preto', 'BR.26.4213005', 'ASCII:Pinheiro Preto;ID:6323226', '11219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11219', '112', '13096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13097', '1079', '1', 'Piratuba', 'BR.26.4213104', 'ASCII:Piratuba;ID:6323227', '11220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11220', '112', '13097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13098', '1079', '1', 'Planalto Alegre', 'BR.26.4213153', 'ASCII:Planalto Alegre;ID:6323228', '11221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11221', '112', '13098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13099', '1079', '1', 'Pomerode', 'BR.26.4213203', 'ASCII:Pomerode;ID:6323229', '11222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11222', '112', '13099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13100', '1079', '1', 'Ponte Alta', 'BR.26.4213302', 'ASCII:Ponte Alta;ID:6323230', '11223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11223', '112', '13100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13101', '1079', '1', 'Ponte Alta do Norte', 'BR.26.4213351', 'ASCII:Ponte Alta Do Norte;ID:6323231', '11224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11224', '112', '13101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13102', '1079', '1', 'Ponte Serrada', 'BR.26.4213401', 'ASCII:Ponte Serrada;ID:6323232', '11225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11225', '112', '13102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13103', '1079', '1', 'Porto Belo', 'BR.26.4213500', 'ASCII:Porto Belo;ID:6323233', '11226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11226', '112', '13103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13104', '1079', '1', 'Porto União', 'BR.26.4213609', 'ASCII:Porto Uniao;ID:6323234', '11227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11227', '112', '13104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13105', '1079', '1', 'Pouso Redondo', 'BR.26.4213708', 'ASCII:Pouso Redondo;ID:6323235', '11228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11228', '112', '13105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13106', '1079', '1', 'Praia Grande', 'BR.26.4213807', 'ASCII:Praia Grande;ID:6323236', '11229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11229', '112', '13106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13107', '1079', '1', 'Presidente Castelo Branco', 'BR.26.4213906', 'ASCII:Presidente Castelo Branco;ID:6323237', '11230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11230', '112', '13107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4213906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13108', '1079', '1', 'Presidente Getúlio', 'BR.26.4214003', 'ASCII:Presidente Getulio;ID:6323238', '11231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11231', '112', '13108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13109', '1079', '1', 'Presidente Nereu', 'BR.26.4214102', 'ASCII:Presidente Nereu;ID:6323239', '11232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11232', '112', '13109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13110', '1079', '1', 'Princesa', 'BR.26.4214151', 'ASCII:Princesa;ID:6323240', '11233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11233', '112', '13110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13111', '1079', '1', 'Quilombo', 'BR.26.4214201', 'ASCII:Quilombo;ID:6323241', '11234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11234', '112', '13111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13112', '1079', '1', 'Rancho Queimado', 'BR.26.4214300', 'ASCII:Rancho Queimado;ID:6323242', '11235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11235', '112', '13112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13113', '1079', '1', 'Rio das Antas', 'BR.26.4214409', 'ASCII:Rio Das Antas;ID:6323243', '11236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11236', '112', '13113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13114', '1079', '1', 'Rio do Oeste', 'BR.26.4214607', 'ASCII:Rio Do Oeste;ID:6323244', '11237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11237', '112', '13114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13115', '1079', '1', 'Rio dos Cedros', 'BR.26.4214706', 'ASCII:Rio Dos Cedros;ID:6323245', '11238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11238', '112', '13115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13116', '1079', '1', 'Rio do Sul', 'BR.26.4214805', 'ASCII:Rio Do Sul;ID:6323246', '11239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11239', '112', '13116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13117', '1079', '1', 'Rio Fortuna', 'BR.26.4214904', 'ASCII:Rio Fortuna;ID:6323247', '11240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11240', '112', '13117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13118', '1079', '1', 'Rio Negrinho', 'BR.26.4215000', 'ASCII:Rio Negrinho;ID:6323248', '11241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11241', '112', '13118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13119', '1079', '1', 'Rio Rufino', 'BR.26.4215059', 'ASCII:Rio Rufino;ID:6323249', '11242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11242', '112', '13119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13120', '1079', '1', 'Riqueza', 'BR.26.4215075', 'ASCII:Riqueza;ID:6323250', '11243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11243', '112', '13120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13121', '1079', '1', 'Rodeio', 'BR.26.4215109', 'ASCII:Rodeio;ID:6323251', '11244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11244', '112', '13121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13122', '1079', '1', 'Romelândia', 'BR.26.4215208', 'ASCII:Romelandia;ID:6323252', '11245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11245', '112', '13122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13123', '1079', '1', 'Saltinho', 'BR.26.4215356', 'ASCII:Saltinho;ID:6323253', '11246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11246', '112', '13123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13124', '1079', '1', 'Salto Veloso', 'BR.26.4215406', 'ASCII:Salto Veloso;ID:6323254', '11247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11247', '112', '13124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13125', '1079', '1', 'Sangão', 'BR.26.4215455', 'ASCII:Sangao;ID:6323255', '11248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11248', '112', '13125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13126', '1079', '1', 'Santa Cecília', 'BR.26.4215505', 'ASCII:Santa Cecilia;ID:6323256', '11249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11249', '112', '13126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13127', '1079', '1', 'Santa Helena', 'BR.26.4215554', 'ASCII:Santa Helena;ID:6323257', '11250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11250', '112', '13127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13128', '1079', '1', 'Santa Rosa de Lima', 'BR.26.4215604', 'ASCII:Santa Rosa De Lima;ID:6323258', '11251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11251', '112', '13128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13129', '1079', '1', 'Santa Rosa do Sul', 'BR.26.4215653', 'ASCII:Santa Rosa Do Sul;ID:6323259', '11252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11252', '112', '13129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13130', '1079', '1', 'Santa Terezinha', 'BR.26.4215679', 'ASCII:Santa Terezinha;ID:6323260', '11253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11253', '112', '13130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13131', '1079', '1', 'Santa Terezinha do Progresso', 'BR.26.4215687', 'ASCII:Santa Terezinha Do Progresso;ID:6323261', '11254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11254', '112', '13131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13132', '1079', '1', 'Santiago do Sul', 'BR.26.4215695', 'ASCII:Santiago Do Sul;ID:6323262', '11255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11255', '112', '13132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13133', '1079', '1', 'Santo Amaro da Imperatriz', 'BR.26.4215703', 'ASCII:Santo Amaro Da Imperatriz;ID:6323263', '11256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11256', '112', '13133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13134', '1079', '1', 'São Bernardino', 'BR.26.4215752', 'ASCII:Sao Bernardino;ID:6323264', '11257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11257', '112', '13134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13135', '1079', '1', 'São Bento do Sul', 'BR.26.4215802', 'ASCII:Sao Bento Do Sul;ID:6323265', '11258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11258', '112', '13135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13136', '1079', '1', 'São Bonifácio', 'BR.26.4215901', 'ASCII:Sao Bonifacio;ID:6323266', '11259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11259', '112', '13136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13137', '1079', '1', 'São Carlos', 'BR.26.4216008', 'ASCII:Sao Carlos;ID:6323267', '11260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11260', '112', '13137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13138', '1079', '1', 'São Cristovão do Sul', 'BR.26.4216057', 'ASCII:Sao Cristovao Do Sul;ID:6323268', '11261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11261', '112', '13138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13139', '1079', '1', 'São Domingos', 'BR.26.4216107', 'ASCII:Sao Domingos;ID:6323269', '11262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11262', '112', '13139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13140', '1079', '1', 'São Francisco do Sul', 'BR.26.4216206', 'ASCII:Sao Francisco Do Sul;ID:6323270', '11263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11263', '112', '13140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13141', '1079', '1', 'São João do Oeste', 'BR.26.4216255', 'ASCII:Sao Joao Do Oeste;ID:6323271', '11264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11264', '112', '13141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13142', '1079', '1', 'São João Batista', 'BR.26.4216305', 'ASCII:Sao Joao Batista;ID:6323272', '11265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11265', '112', '13142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13143', '1079', '1', 'São João do Itaperiú', 'BR.26.4216354', 'ASCII:Sao Joao Do Itaperiu;ID:6323273', '11266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11266', '112', '13143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13144', '1079', '1', 'São João do Sul', 'BR.26.4216404', 'ASCII:Sao Joao Do Sul;ID:6323274', '11267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11267', '112', '13144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13145', '1079', '1', 'São Joaquim', 'BR.26.4216503', 'ASCII:Sao Joaquim;ID:6323275', '11268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11268', '112', '13145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13146', '1079', '1', 'São José', 'BR.26.4216602', 'ASCII:Sao Jose;ID:6323276', '11269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11269', '112', '13146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13147', '1079', '1', 'São José do Cedro', 'BR.26.4216701', 'ASCII:Sao Jose Do Cedro;ID:6323277', '11270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11270', '112', '13147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13148', '1079', '1', 'São José do Cerrito', 'BR.26.4216800', 'ASCII:Sao Jose Do Cerrito;ID:6323278', '11271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11271', '112', '13148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4216800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13149', '1079', '1', 'São Ludgero', 'BR.26.4217006', 'ASCII:Sao Ludgero;ID:6323279', '11272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11272', '112', '13149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13150', '1079', '1', 'São Martinho', 'BR.26.4217105', 'ASCII:Sao Martinho;ID:6323280', '11273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11273', '112', '13150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13151', '1079', '1', 'São Miguel da Boa Vista', 'BR.26.4217154', 'ASCII:Sao Miguel Da Boa Vista;ID:6323281', '11274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11274', '112', '13151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13152', '1079', '1', 'São Miguel do Oeste', 'BR.26.4217204', 'ASCII:Sao Miguel D''Oeste;ID:6323282', '11275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11275', '112', '13152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13153', '1079', '1', 'São Pedro de Alcântara', 'BR.26.4217253', 'ASCII:Sao Pedro De Alcantara;ID:6323283', '11276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11276', '112', '13153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13154', '1079', '1', 'Saudades', 'BR.26.4217303', 'ASCII:Saudades;ID:6323284', '11277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11277', '112', '13154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13155', '1079', '1', 'Schroeder', 'BR.26.4217402', 'ASCII:Schroeder;ID:6323285', '11278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11278', '112', '13155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13156', '1079', '1', 'Seara', 'BR.26.4217501', 'ASCII:Seara;ID:6323286', '11279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11279', '112', '13156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13157', '1079', '1', 'Serra Alta', 'BR.26.4217550', 'ASCII:Serra Alta;ID:6323287', '11280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11280', '112', '13157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13158', '1079', '1', 'Siderópolis', 'BR.26.4217600', 'ASCII:Sideropolis;ID:6323288', '11281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11281', '112', '13158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13159', '1079', '1', 'Sombrio', 'BR.26.4217709', 'ASCII:Sombrio;ID:6323289', '11282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11282', '112', '13159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13160', '1079', '1', 'Sul Brasil', 'BR.26.4217758', 'ASCII:Sul Brasil;ID:6323290', '11283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11283', '112', '13160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13161', '1079', '1', 'Tangará', 'BR.26.4217907', 'ASCII:Tangara;ID:6323291', '11284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11284', '112', '13161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13162', '1079', '1', 'Tigrinhos', 'BR.26.4217956', 'ASCII:Tigrinhos;ID:6323292', '11285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11285', '112', '13162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13163', '1079', '1', 'Timbé do Sul', 'BR.26.4218103', 'ASCII:Timbe Do Sul;ID:6323293', '11286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11286', '112', '13163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13164', '1079', '1', 'Timbó', 'BR.26.4218202', 'ASCII:Timbo;ID:6323294', '11287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11287', '112', '13164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13165', '1079', '1', 'Timbó Grande', 'BR.26.4218251', 'ASCII:Timbo Grande;ID:6323295', '11288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11288', '112', '13165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13166', '1079', '1', 'Três Barras', 'BR.26.4218301', 'ASCII:Tres Barras;ID:6323296', '11289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11289', '112', '13166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13167', '1079', '1', 'Treviso', 'BR.26.4218350', 'ASCII:Treviso;ID:6323297', '11290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11290', '112', '13167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13168', '1079', '1', 'Treze de Maio', 'BR.26.4218400', 'ASCII:Treze De Maio;ID:6323298', '11291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11291', '112', '13168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13169', '1079', '1', 'Treze Tílias', 'BR.26.4218509', 'ASCII:Treze Tilias;ID:6323299', '11292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11292', '112', '13169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13170', '1079', '1', 'Trombudo Central', 'BR.26.4218608', 'ASCII:Trombudo Central;ID:6323300', '11293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11293', '112', '13170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13171', '1079', '1', 'Tubarão', 'BR.26.4218707', 'ASCII:Tubarao;ID:6323301', '11294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11294', '112', '13171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13172', '1079', '1', 'Tunápolis', 'BR.26.4218756', 'ASCII:Tunapolis;ID:6323302', '11295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11295', '112', '13172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13173', '1079', '1', 'Turvo', 'BR.26.4218806', 'ASCII:Turvo;ID:6323303', '11296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11296', '112', '13173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13174', '1079', '1', 'União do Oeste', 'BR.26.4218855', 'ASCII:Uniao Do Oeste;ID:6323304', '11297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11297', '112', '13174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13175', '1079', '1', 'Urubici', 'BR.26.4218905', 'ASCII:Urubici;ID:6323305', '11298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11298', '112', '13175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13176', '1079', '1', 'Urupema', 'BR.26.4218954', 'ASCII:Urupema;ID:6323306', '11299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11299', '112', '13176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13177', '1079', '1', 'Urussanga', 'BR.26.4219002', 'ASCII:Urussanga;ID:6323307', '11300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11300', '112', '13177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13178', '1079', '1', 'Vargeão', 'BR.26.4219101', 'ASCII:Vargeao;ID:6323308', '11301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11301', '112', '13178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13179', '1079', '1', 'Vargem', 'BR.26.4219150', 'ASCII:Vargem;ID:6323309', '11302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11302', '112', '13179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13180', '1079', '1', 'Vargem Bonita', 'BR.26.4219176', 'ASCII:Vargem Bonita;ID:6323310', '11303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11303', '112', '13180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13181', '1079', '1', 'Vidal Ramos', 'BR.26.4219200', 'ASCII:Vidal Ramos;ID:6323311', '11304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11304', '112', '13181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13182', '1079', '1', 'Videira', 'BR.26.4219309', 'ASCII:Videira;ID:6323312', '11305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11305', '112', '13182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13183', '1079', '1', 'Vitor Meireles', 'BR.26.4219358', 'ASCII:Vitor Meireles;ID:6323313', '11306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11306', '112', '13183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13184', '1079', '1', 'Witmarsum', 'BR.26.4219408', 'ASCII:Witmarsum;ID:6323314', '11307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11307', '112', '13184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13185', '1079', '1', 'Xanxerê', 'BR.26.4219507', 'ASCII:Xanxere;ID:6323315', '11308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11308', '112', '13185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13186', '1079', '1', 'Xavantina', 'BR.26.4219606', 'ASCII:Xavantina;ID:6323316', '11309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11309', '112', '13186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13187', '1079', '1', 'Xaxim', 'BR.26.4219705', 'ASCII:Xaxim;ID:6323317', '11310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11310', '112', '13187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13188', '1079', '1', 'Zortéa', 'BR.26.4219853', 'ASCII:Zortea;ID:6323318', '11311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11311', '112', '13188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4219853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13189', '1079', '1', 'Agudo', 'BR.23.4300109', 'ASCII:Agudo;ID:6323319', '11312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11312', '112', '13189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13190', '1079', '1', 'Ajuricaba', 'BR.23.4300208', 'ASCII:Ajuricaba;ID:6323320', '11313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11313', '112', '13190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13191', '1079', '1', 'Alecrim', 'BR.23.4300307', 'ASCII:Alecrim;ID:6323321', '11314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11314', '112', '13191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13192', '1079', '1', 'Alegrete', 'BR.23.4300406', 'ASCII:Alegrete;ID:6323322', '11315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11315', '112', '13192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13193', '1079', '1', 'Alegria', 'BR.23.4300455', 'ASCII:Alegria;ID:6323323', '11316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11316', '112', '13193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13194', '1079', '1', 'Alpestre', 'BR.23.4300505', 'ASCII:Alpestre;ID:6323324', '11317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11317', '112', '13194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13195', '1079', '1', 'Alto Feliz', 'BR.23.4300570', 'ASCII:Alto Feliz;ID:6323325', '11318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11318', '112', '13195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13196', '1079', '1', 'Alvorada', 'BR.23.4300604', 'ASCII:Alvorada;ID:6323326', '11319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11319', '112', '13196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13197', '1079', '1', 'Amaral Ferrador', 'BR.23.4300638', 'ASCII:Amaral Ferrador;ID:6323327', '11320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11320', '112', '13197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13198', '1079', '1', 'Ametista do Sul', 'BR.23.4300646', 'ASCII:Ametista Do Sul;ID:6323328', '11321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11321', '112', '13198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13199', '1079', '1', 'André da Rocha', 'BR.23.4300661', 'ASCII:Andre Da Rocha;ID:6323329', '11322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11322', '112', '13199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13200', '1079', '1', 'Anta Gorda', 'BR.23.4300703', 'ASCII:Anta Gorda;ID:6323330', '11323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11323', '112', '13200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13201', '1079', '1', 'Arambaré', 'BR.23.4300851', 'ASCII:Arambare;ID:6323331', '11324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11324', '112', '13201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13202', '1079', '1', 'Araricá', 'BR.23.4300877', 'ASCII:Ararica;ID:6323332', '11325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11325', '112', '13202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300877» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13203', '1079', '1', 'Aratiba', 'BR.23.4300901', 'ASCII:Aratiba;ID:6323333', '11326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11326', '112', '13203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13204', '1079', '1', 'Arroio do Meio', 'BR.23.4301008', 'ASCII:Arroio Do Meio;ID:6323334', '11327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11327', '112', '13204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13205', '1079', '1', 'Arroio do Sal', 'BR.23.4301057', 'ASCII:Arroio Do Sal;ID:6323335', '11328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11328', '112', '13205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13206', '1079', '1', 'Arroio dos Ratos', 'BR.23.4301107', 'ASCII:Arroio Dos Ratos;ID:6323336', '11329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11329', '112', '13206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13207', '1079', '1', 'Arroio do Tigre', 'BR.23.4301206', 'ASCII:Arroio Do Tigre;ID:6323337', '11330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11330', '112', '13207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13208', '1079', '1', 'Arvorezinha', 'BR.23.4301404', 'ASCII:Arvorezinha;ID:6323338', '11331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11331', '112', '13208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13209', '1079', '1', 'Áurea', 'BR.23.4301552', 'ASCII:Aurea;ID:6323339', '11332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11332', '112', '13209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13210', '1079', '1', 'Balneário Pinhal', 'BR.23.4301636', 'ASCII:Balneario Pinhal;ID:6323340', '11333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11333', '112', '13210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13211', '1079', '1', 'Barão', 'BR.23.4301651', 'ASCII:Barao;ID:6323341', '11334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11334', '112', '13211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13212', '1079', '1', 'Barão do Triunfo', 'BR.23.4301750', 'ASCII:Barao Do Triunfo;ID:6323342', '11335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11335', '112', '13212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13213', '1079', '1', 'Barracão', 'BR.23.4301800', 'ASCII:Barracao;ID:6323343', '11336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11336', '112', '13213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13214', '1079', '1', 'Barra do Guarita', 'BR.23.4301859', 'ASCII:Barra Do Guarita;ID:6323344', '11337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11337', '112', '13214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13215', '1079', '1', 'Barra do Quaraí', 'BR.23.4301875', 'ASCII:Barra Do Quarai;ID:6323345', '11338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11338', '112', '13215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13216', '1079', '1', 'Barra do Ribeiro', 'BR.23.4301909', 'ASCII:Barra Do Ribeiro;ID:6323346', '11339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11339', '112', '13216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13217', '1079', '1', 'Barra do Rio Azul', 'BR.23.4301925', 'ASCII:Barra Do Rio Azul;ID:6323347', '11340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11340', '112', '13217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13218', '1079', '1', 'Barra Funda', 'BR.23.4301958', 'ASCII:Barra Funda;ID:6323348', '11341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11341', '112', '13218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13219', '1079', '1', 'Benjamin Constant do Sul', 'BR.23.4302055', 'ASCII:Benjamin Constant Do Sul;ID:6323349', '11342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11342', '112', '13219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13220', '1079', '1', 'Boa Vista das Missões', 'BR.23.4302154', 'ASCII:Boa Vista Das Missoes;ID:6323350', '11343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11343', '112', '13220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13221', '1079', '1', 'Boa Vista do Buricá', 'BR.23.4302204', 'ASCII:Boa Vista Do Burica;ID:6323351', '11344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11344', '112', '13221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13222', '1079', '1', 'Boa Vista do Sul', 'BR.23.4302253', 'ASCII:Boa Vista Do Sul;ID:6323352', '11345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11345', '112', '13222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13223', '1079', '1', 'Bom Jesus', 'BR.23.4302303', 'ASCII:Bom Jesus;ID:6323353', '11346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11346', '112', '13223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13224', '1079', '1', 'Bom Princípio', 'BR.23.4302352', 'ASCII:Bom Principio;ID:6323354', '11347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11347', '112', '13224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13225', '1079', '1', 'Bom Progresso', 'BR.23.4302378', 'ASCII:Bom Progresso;ID:6323355', '11348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11348', '112', '13225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13226', '1079', '1', 'Bom Retiro do Sul', 'BR.23.4302402', 'ASCII:Bom Retiro Do Sul;ID:6323356', '11349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11349', '112', '13226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13227', '1079', '1', 'Bossoroca', 'BR.23.4302501', 'ASCII:Bossoroca;ID:6323357', '11350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11350', '112', '13227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13228', '1079', '1', 'Braga', 'BR.23.4302600', 'ASCII:Braga;ID:6323358', '11351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11351', '112', '13228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13229', '1079', '1', 'Brochier', 'BR.23.4302659', 'ASCII:Brochier;ID:6323359', '11352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11352', '112', '13229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13230', '1079', '1', 'Butiá', 'BR.23.4302709', 'ASCII:Butia;ID:6323360', '11353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11353', '112', '13230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13231', '1079', '1', 'Caçapava do Sul', 'BR.23.4302808', 'ASCII:Cacapava Do Sul;ID:6323361', '11354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11354', '112', '13231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13232', '1079', '1', 'Cacequi', 'BR.23.4302907', 'ASCII:Cacequi;ID:6323362', '11355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11355', '112', '13232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13233', '1079', '1', 'Cachoeira do Sul', 'BR.23.4303004', 'ASCII:Cachoeira Do Sul;ID:6323363', '11356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11356', '112', '13233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13234', '1079', '1', 'Cachoeirinha', 'BR.23.4303103', 'ASCII:Cachoeirinha;ID:6323364', '11357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11357', '112', '13234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13235', '1079', '1', 'Cacique Doble', 'BR.23.4303202', 'ASCII:Cacique Doble;ID:6323365', '11358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11358', '112', '13235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13236', '1079', '1', 'Caiçara', 'BR.23.4303400', 'ASCII:Caicara;ID:6323366', '11359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11359', '112', '13236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13237', '1079', '1', 'Camaquã', 'BR.23.4303509', 'ASCII:Camaqua;ID:6323367', '11360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11360', '112', '13237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13238', '1079', '1', 'Camargo', 'BR.23.4303558', 'ASCII:Camargo;ID:6323368', '11361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11361', '112', '13238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13239', '1079', '1', 'Cambará do Sul', 'BR.23.4303608', 'ASCII:Cambara Do Sul;ID:6323369', '11362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11362', '112', '13239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13240', '1079', '1', 'Campestre da Serra', 'BR.23.4303673', 'ASCII:Campestre Da Serra;ID:6323370', '11363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11363', '112', '13240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13241', '1079', '1', 'Campina das Missões', 'BR.23.4303707', 'ASCII:Campina Das Missoes;ID:6323371', '11364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11364', '112', '13241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4303707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13242', '1079', '1', 'Campo Novo', 'BR.23.4304002', 'ASCII:Campo Novo;ID:6323372', '11365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11365', '112', '13242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13243', '1079', '1', 'Campos Borges', 'BR.23.4304101', 'ASCII:Campos Borges;ID:6323373', '11366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11366', '112', '13243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13244', '1079', '1', 'Candelária', 'BR.23.4304200', 'ASCII:Candelaria;ID:6323374', '11367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11367', '112', '13244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13245', '1079', '1', 'Cândido Godói', 'BR.23.4304309', 'ASCII:Candido Godoi;ID:6323375', '11368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11368', '112', '13245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13246', '1079', '1', 'Candiota', 'BR.23.4304358', 'ASCII:Candiota;ID:6323376', '11369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11369', '112', '13246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13247', '1079', '1', 'Canela', 'BR.23.4304408', 'ASCII:Canela;ID:6323377', '11370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11370', '112', '13247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13248', '1079', '1', 'Canoas', 'BR.23.4304606', 'ASCII:Canoas;ID:6323378', '11371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11371', '112', '13248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13249', '1079', '1', 'Capão da Canoa', 'BR.23.4304630', 'ASCII:Capao Da Canoa;ID:6323379', '11372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11372', '112', '13249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13250', '1079', '1', 'Capão do Leão', 'BR.23.4304663', 'ASCII:Capao Do Leao;ID:6323380', '11373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11373', '112', '13250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13251', '1079', '1', 'Capivari do Sul', 'BR.23.4304671', 'ASCII:Capivari Do Sul;ID:6323381', '11374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11374', '112', '13251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13252', '1079', '1', 'Capela de Santana', 'BR.23.4304689', 'ASCII:Capela De Santana;ID:6323382', '11375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11375', '112', '13252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13253', '1079', '1', 'Capitão', 'BR.23.4304697', 'ASCII:Capitao;ID:6323383', '11376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11376', '112', '13253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304697» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13254', '1079', '1', 'Caraá', 'BR.23.4304713', 'ASCII:Caraa;ID:6323384', '11377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11377', '112', '13254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13255', '1079', '1', 'Carlos Gomes', 'BR.23.4304853', 'ASCII:Carlos Gomes;ID:6323385', '11378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11378', '112', '13255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13256', '1079', '1', 'Casca', 'BR.23.4304903', 'ASCII:Casca;ID:6323386', '11379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11379', '112', '13256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13257', '1079', '1', 'Catuípe', 'BR.23.4305009', 'ASCII:Catuipe;ID:6323387', '11380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11380', '112', '13257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13258', '1079', '1', 'Caxias do Sul', 'BR.23.4305108', 'ASCII:Caxias Do Sul;ID:6323388', '11381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11381', '112', '13258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13259', '1079', '1', 'Centenário', 'BR.23.4305116', 'ASCII:Centenario;ID:6323389', '11382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11382', '112', '13259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13260', '1079', '1', 'Cerrito', 'BR.23.4305124', 'ASCII:Cerrito;ID:6323390', '11383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11383', '112', '13260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13261', '1079', '1', 'Cerro Branco', 'BR.23.4305132', 'ASCII:Cerro Branco;ID:6323391', '11384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11384', '112', '13261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13262', '1079', '1', 'Cerro Grande do Sul', 'BR.23.4305173', 'ASCII:Cerro Grande Do Sul;ID:6323392', '11385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11385', '112', '13262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13263', '1079', '1', 'Cerro Largo', 'BR.23.4305207', 'ASCII:Cerro Largo;ID:6323393', '11386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11386', '112', '13263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13264', '1079', '1', 'Chapada', 'BR.23.4305306', 'ASCII:Chapada;ID:6323394', '11387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11387', '112', '13264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13265', '1079', '1', 'Charqueadas', 'BR.23.4305355', 'ASCII:Charqueadas;ID:6323395', '11388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11388', '112', '13265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13266', '1079', '1', 'Charrua', 'BR.23.4305371', 'ASCII:Charrua;ID:6323396', '11389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11389', '112', '13266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13267', '1079', '1', 'Chiapetta', 'BR.23.4305405', 'ASCII:Chiapeta;ID:6323397', '11390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11390', '112', '13267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13268', '1079', '1', 'Chuí', 'BR.23.4305439', 'ASCII:Chui;ID:6323398', '11391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11391', '112', '13268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13269', '1079', '1', 'Chuvisca', 'BR.23.4305447', 'ASCII:Chuvisca;ID:6323399', '11392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11392', '112', '13269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13270', '1079', '1', 'Cidreira', 'BR.23.4305454', 'ASCII:Cidreira;ID:6323400', '11393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11393', '112', '13270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13271', '1079', '1', 'Ciríaco', 'BR.23.4305504', 'ASCII:Ciriaco;ID:6323401', '11394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11394', '112', '13271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13272', '1079', '1', 'Colinas', 'BR.23.4305587', 'ASCII:Colinas;ID:6323402', '11395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11395', '112', '13272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13273', '1079', '1', 'Colorado', 'BR.23.4305603', 'ASCII:Colorado;ID:6323403', '11396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11396', '112', '13273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13274', '1079', '1', 'Condor', 'BR.23.4305702', 'ASCII:Condor;ID:6323404', '11397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11397', '112', '13274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13275', '1079', '1', 'Coqueiros do Sul', 'BR.23.4305850', 'ASCII:Coqueiros Do Sul;ID:6323405', '11398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11398', '112', '13275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13276', '1079', '1', 'Coronel Barros', 'BR.23.4305871', 'ASCII:Coronel Barros;ID:6323406', '11399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11399', '112', '13276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305871» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13277', '1079', '1', 'Coronel Bicaco', 'BR.23.4305900', 'ASCII:Coronel Bicaco;ID:6323407', '11400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11400', '112', '13277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13278', '1079', '1', 'Cotiporã', 'BR.23.4305959', 'ASCII:Cotipora;ID:6323408', '11401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11401', '112', '13278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13279', '1079', '1', 'Coxilha', 'BR.23.4305975', 'ASCII:Coxilha;ID:6323409', '11402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11402', '112', '13279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13280', '1079', '1', 'Crissiumal', 'BR.23.4306007', 'ASCII:Crissiumal;ID:6323410', '11403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11403', '112', '13280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13281', '1079', '1', 'Cristal', 'BR.23.4306056', 'ASCII:Cristal;ID:6323411', '11404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11404', '112', '13281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13282', '1079', '1', 'Cristal do Sul', 'BR.23.4306072', 'ASCII:Cristal Do Sul;ID:6323412', '11405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11405', '112', '13282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13283', '1079', '1', 'Cruzeiro do Sul', 'BR.23.4306205', 'ASCII:Cruzeiro Do Sul;ID:6323413', '11406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11406', '112', '13283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13284', '1079', '1', 'Dezesseis de Novembro', 'BR.23.4306353', 'ASCII:Dezesseis De Novembro;ID:6323414', '11407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11407', '112', '13284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13285', '1079', '1', 'Dilermando de Aguiar', 'BR.23.4306379', 'ASCII:Dilermando De Aguiar;ID:6323415', '11408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11408', '112', '13285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13286', '1079', '1', 'Dois Irmãos', 'BR.23.4306403', 'ASCII:Dois Irmaos;ID:6323416', '11409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11409', '112', '13286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13287', '1079', '1', 'Dois Irmãos das Missões', 'BR.23.4306429', 'ASCII:Dois Irmaos Das Missoes;ID:6323417', '11410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11410', '112', '13287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13288', '1079', '1', 'Dois Lajeados', 'BR.23.4306452', 'ASCII:Dois Lajeados;ID:6323418', '11411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11411', '112', '13288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13289', '1079', '1', 'Dom Feliciano', 'BR.23.4306502', 'ASCII:Dom Feliciano;ID:6323419', '11412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11412', '112', '13289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13290', '1079', '1', 'Dom Pedro de Alcântara', 'BR.23.4306551', 'ASCII:Dom Pedro De Alcantara;ID:6323420', '11413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11413', '112', '13290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13291', '1079', '1', 'Dom Pedrito', 'BR.23.4306601', 'ASCII:Dom Pedrito;ID:6323421', '11414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11414', '112', '13291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13292', '1079', '1', 'Dona Francisca', 'BR.23.4306700', 'ASCII:Dona Francisca;ID:6323422', '11415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11415', '112', '13292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13293', '1079', '1', 'Doutor Maurício Cardoso', 'BR.23.4306734', 'ASCII:Doutor Mauricio Cardoso;ID:6323423', '11416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11416', '112', '13293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13294', '1079', '1', 'Doutor Ricardo', 'BR.23.4306759', 'ASCII:Doutor Ricardo;ID:6323424', '11417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11417', '112', '13294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13295', '1079', '1', 'Eldorado do Sul', 'BR.23.4306767', 'ASCII:Eldorado Do Sul;ID:6323425', '11418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11418', '112', '13295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306767» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13296', '1079', '1', 'Encantado', 'BR.23.4306809', 'ASCII:Encantado;ID:6323426', '11419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11419', '112', '13296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13297', '1079', '1', 'Encruzilhada do Sul', 'BR.23.4306908', 'ASCII:Encruzilhada Do Sul;ID:6323427', '11420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11420', '112', '13297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13298', '1079', '1', 'Engenho Velho', 'BR.23.4306924', 'ASCII:Engenho Velho;ID:6323428', '11421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11421', '112', '13298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13299', '1079', '1', 'Entre-Ijuís', 'BR.23.4306932', 'ASCII:Entre-Ijuis;ID:6323429', '11422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11422', '112', '13299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306932» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13300', '1079', '1', 'Entre Rios do Sul', 'BR.23.4306957', 'ASCII:Entre Rios Do Sul;ID:6323430', '11423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11423', '112', '13300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13301', '1079', '1', 'Erebango', 'BR.23.4306973', 'ASCII:Erebango;ID:6323431', '11424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11424', '112', '13301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306973» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13302', '1079', '1', 'Erval Grande', 'BR.23.4307203', 'ASCII:Erval Grande;ID:6323432', '11425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11425', '112', '13302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13303', '1079', '1', 'Erval Seco', 'BR.23.4307302', 'ASCII:Erval Seco;ID:6323433', '11426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11426', '112', '13303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13304', '1079', '1', 'Esperança do Sul', 'BR.23.4307450', 'ASCII:Esperanca Do Sul;ID:6323434', '11427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11427', '112', '13304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13305', '1079', '1', 'Estação', 'BR.23.4307559', 'ASCII:Estacao;ID:6323435', '11428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11428', '112', '13305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13306', '1079', '1', 'Estância Velha', 'BR.23.4307609', 'ASCII:Estancia Velha;ID:6323436', '11429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11429', '112', '13306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13307', '1079', '1', 'Esteio', 'BR.23.4307708', 'ASCII:Esteio;ID:6323437', '11430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11430', '112', '13307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13308', '1079', '1', 'Estrela', 'BR.23.4307807', 'ASCII:Estrela;ID:6323438', '11431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11431', '112', '13308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13309', '1079', '1', 'Estrela Velha', 'BR.23.4307815', 'ASCII:Estrela Velha;ID:6323439', '11432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11432', '112', '13309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13310', '1079', '1', 'Eugênio de Castro', 'BR.23.4307831', 'ASCII:Eugenio De Castro;ID:6323440', '11433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11433', '112', '13310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307831» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13311', '1079', '1', 'Fagundes Varela', 'BR.23.4307864', 'ASCII:Fagundes Varela;ID:6323441', '11434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11434', '112', '13311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13312', '1079', '1', 'Farroupilha', 'BR.23.4307906', 'ASCII:Farroupilha;ID:6323442', '11435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11435', '112', '13312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13313', '1079', '1', 'Faxinal do Soturno', 'BR.23.4308003', 'ASCII:Faxinal Do Soturno;ID:6323443', '11436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11436', '112', '13313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13314', '1079', '1', 'Faxinalzinho', 'BR.23.4308052', 'ASCII:Faxinalzinho;ID:6323444', '11437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11437', '112', '13314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13315', '1079', '1', 'Fazenda Vilanova', 'BR.23.4308078', 'ASCII:Fazenda Vilanova;ID:6323445', '11438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11438', '112', '13315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13316', '1079', '1', 'Feliz', 'BR.23.4308102', 'ASCII:Feliz;ID:6323446', '11439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11439', '112', '13316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13317', '1079', '1', 'Flores da Cunha', 'BR.23.4308201', 'ASCII:Flores Da Cunha;ID:6323447', '11440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11440', '112', '13317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13318', '1079', '1', 'Floriano Peixoto', 'BR.23.4308250', 'ASCII:Floriano Peixoto;ID:6323448', '11441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11441', '112', '13318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13319', '1079', '1', 'Fontoura Xavier', 'BR.23.4308300', 'ASCII:Fontoura Xavier;ID:6323449', '11442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11442', '112', '13319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13320', '1079', '1', 'Formigueiro', 'BR.23.4308409', 'ASCII:Formigueiro;ID:6323450', '11443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11443', '112', '13320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13321', '1079', '1', 'Frederico Westphalen', 'BR.23.4308508', 'ASCII:Frederico Westphalen;ID:6323451', '11444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11444', '112', '13321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13322', '1079', '1', 'Garruchos', 'BR.23.4308656', 'ASCII:Garruchos;ID:6323452', '11445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11445', '112', '13322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13323', '1079', '1', 'Gaurama', 'BR.23.4308706', 'ASCII:Gaurama;ID:6323453', '11446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11446', '112', '13323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13324', '1079', '1', 'General Câmara', 'BR.23.4308805', 'ASCII:General Camara;ID:6323454', '11447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11447', '112', '13324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13325', '1079', '1', 'Gentil', 'BR.23.4308854', 'ASCII:Gentil;ID:6323455', '11448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11448', '112', '13325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13326', '1079', '1', 'Getúlio Vargas', 'BR.23.4308904', 'ASCII:Getulio Vargas;ID:6323456', '11449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11449', '112', '13326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13327', '1079', '1', 'Giruá', 'BR.23.4309001', 'ASCII:Girua;ID:6323457', '11450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11450', '112', '13327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13328', '1079', '1', 'Glorinha', 'BR.23.4309050', 'ASCII:Glorinha;ID:6323458', '11451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11451', '112', '13328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13329', '1079', '1', 'Gramado', 'BR.23.4309100', 'ASCII:Gramado;ID:6323459', '11452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11452', '112', '13329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13330', '1079', '1', 'Gramado dos Loureiros', 'BR.23.4309126', 'ASCII:Gramado Dos Loureiros;ID:6323460', '11453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11453', '112', '13330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309126» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13331', '1079', '1', 'Gramado Xavier', 'BR.23.4309159', 'ASCII:Gramado Xavier;ID:6323461', '11454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11454', '112', '13331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13332', '1079', '1', 'Gravataí', 'BR.23.4309209', 'ASCII:Gravatai;ID:6323462', '11455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11455', '112', '13332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13333', '1079', '1', 'Guabiju', 'BR.23.4309258', 'ASCII:Guabiju;ID:6323463', '11456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11456', '112', '13333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13334', '1079', '1', 'Guaíba', 'BR.23.4309308', 'ASCII:Guaiba;ID:6323464', '11457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11457', '112', '13334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13335', '1079', '1', 'Guaporé', 'BR.23.4309407', 'ASCII:Guapore;ID:6323465', '11458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11458', '112', '13335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13336', '1079', '1', 'Guarani das Missões', 'BR.23.4309506', 'ASCII:Guarani Das Missoes;ID:6323466', '11459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11459', '112', '13336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13337', '1079', '1', 'Harmonia', 'BR.23.4309555', 'ASCII:Harmonia;ID:6323467', '11460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11460', '112', '13337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13338', '1079', '1', 'Herveiras', 'BR.23.4309571', 'ASCII:Herveiras;ID:6323468', '11461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11461', '112', '13338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13339', '1079', '1', 'Horizontina', 'BR.23.4309605', 'ASCII:Horizontina;ID:6323469', '11462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11462', '112', '13339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13340', '1079', '1', 'Hulha Negra', 'BR.23.4309654', 'ASCII:Hulha Negra;ID:6323470', '11463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11463', '112', '13340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13341', '1079', '1', 'Humaitá', 'BR.23.4309704', 'ASCII:Humaita;ID:6323471', '11464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11464', '112', '13341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13342', '1079', '1', 'Ibarama', 'BR.23.4309753', 'ASCII:Ibarama;ID:6323472', '11465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11465', '112', '13342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13343', '1079', '1', 'Ibiraiaras', 'BR.23.4309902', 'ASCII:Ibiraiaras;ID:6323473', '11466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11466', '112', '13343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13344', '1079', '1', 'Ibirubá', 'BR.23.4310009', 'ASCII:Ibiruba;ID:6323474', '11467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11467', '112', '13344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13345', '1079', '1', 'Igrejinha', 'BR.23.4310108', 'ASCII:Igrejinha;ID:6323475', '11468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11468', '112', '13345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13346', '1079', '1', 'Ilópolis', 'BR.23.4310306', 'ASCII:Ilopolis;ID:6323476', '11469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11469', '112', '13346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13347', '1079', '1', 'Imbé', 'BR.23.4310330', 'ASCII:Imbe;ID:6323477', '11470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11470', '112', '13347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13348', '1079', '1', 'Inhacorá', 'BR.23.4310413', 'ASCII:Inhacora;ID:6323478', '11471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11471', '112', '13348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13349', '1079', '1', 'Ipê', 'BR.23.4310439', 'ASCII:Ipe;ID:6323479', '11472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11472', '112', '13349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13350', '1079', '1', 'Ipiranga do Sul', 'BR.23.4310462', 'ASCII:Ipiranga Do Sul;ID:6323480', '11473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11473', '112', '13350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13351', '1079', '1', 'Iraí', 'BR.23.4310504', 'ASCII:Irai;ID:6323481', '11474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11474', '112', '13351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13352', '1079', '1', 'Itaara', 'BR.23.4310538', 'ASCII:Itaara;ID:6323482', '11475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11475', '112', '13352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13353', '1079', '1', 'Itacurubi', 'BR.23.4310553', 'ASCII:Itacurubi;ID:6323483', '11476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11476', '112', '13353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13354', '1079', '1', 'Itapuca', 'BR.23.4310579', 'ASCII:Itapuca;ID:6323484', '11477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11477', '112', '13354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13355', '1079', '1', 'Itaqui', 'BR.23.4310603', 'ASCII:Itaqui;ID:6323485', '11478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11478', '112', '13355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13356', '1079', '1', 'Itatiba do Sul', 'BR.23.4310702', 'ASCII:Itatiba Do Sul;ID:6323486', '11479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11479', '112', '13356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13357', '1079', '1', 'Ivorá', 'BR.23.4310751', 'ASCII:Ivora;ID:6323487', '11480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11480', '112', '13357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13358', '1079', '1', 'Ivoti', 'BR.23.4310801', 'ASCII:Ivoti;ID:6323488', '11481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11481', '112', '13358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13359', '1079', '1', 'Jaboticaba', 'BR.23.4310850', 'ASCII:Jaboticaba;ID:6323489', '11482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11482', '112', '13359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13360', '1079', '1', 'Jaguarão', 'BR.23.4311007', 'ASCII:Jaguarao;ID:6323490', '11483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11483', '112', '13360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13361', '1079', '1', 'Jaquirana', 'BR.23.4311122', 'ASCII:Jaquirana;ID:6323491', '11484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11484', '112', '13361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13362', '1079', '1', 'Jari', 'BR.23.4311130', 'ASCII:Jari;ID:6323492', '11485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11485', '112', '13362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13363', '1079', '1', 'Jóia', 'BR.23.4311155', 'ASCII:Joia;ID:6323493', '11486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11486', '112', '13363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13364', '1079', '1', 'Júlio de Castilhos', 'BR.23.4311205', 'ASCII:Julio De Castilhos;ID:6323494', '11487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11487', '112', '13364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13365', '1079', '1', 'Lagoão', 'BR.23.4311254', 'ASCII:Lagoao;ID:6323495', '11488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11488', '112', '13365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13366', '1079', '1', 'Lagoa dos Três Cantos', 'BR.23.4311270', 'ASCII:Lagoa Dos Tres Cantos;ID:6323496', '11489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11489', '112', '13366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13367', '1079', '1', 'Lajeado do Bugre', 'BR.23.4311429', 'ASCII:Lajeado Do Bugre;ID:6323497', '11490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11490', '112', '13367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13368', '1079', '1', 'Lavras do Sul', 'BR.23.4311502', 'ASCII:Lavras Do Sul;ID:6323498', '11491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11491', '112', '13368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13369', '1079', '1', 'Liberato Salzano', 'BR.23.4311601', 'ASCII:Liberato Salzano;ID:6323499', '11492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11492', '112', '13369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13370', '1079', '1', 'Lindolfo Collor', 'BR.23.4311627', 'ASCII:Lindolfo Collor;ID:6323500', '11493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11493', '112', '13370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13371', '1079', '1', 'Linha Nova', 'BR.23.4311643', 'ASCII:Linha Nova;ID:6323501', '11494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11494', '112', '13371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311643» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13372', '1079', '1', 'Machadinho', 'BR.23.4311700', 'ASCII:Machadinho;ID:6323502', '11495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11495', '112', '13372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13373', '1079', '1', 'Maçambara', 'BR.23.4311718', 'ASCII:Macambara;ID:6323503', '11496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11496', '112', '13373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13374', '1079', '1', 'Mampituba', 'BR.23.4311734', 'ASCII:Mampituba;ID:6323504', '11497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11497', '112', '13374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13375', '1079', '1', 'Manoel Viana', 'BR.23.4311759', 'ASCII:Manoel Viana;ID:6323505', '11498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11498', '112', '13375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13376', '1079', '1', 'Maquiné', 'BR.23.4311775', 'ASCII:Maquine;ID:6323506', '11499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11499', '112', '13376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13377', '1079', '1', 'Marau', 'BR.23.4311809', 'ASCII:Marau;ID:6323507', '11500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11500', '112', '13377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13378', '1079', '1', 'Marcelino Ramos', 'BR.23.4311908', 'ASCII:Marcelino Ramos;ID:6323508', '11501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11501', '112', '13378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13379', '1079', '1', 'Mariana Pimentel', 'BR.23.4311981', 'ASCII:Mariana Pimentel;ID:6323509', '11502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11502', '112', '13379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4311981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13380', '1079', '1', 'Mariano Moro', 'BR.23.4312005', 'ASCII:Mariano Moro;ID:6323510', '11503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11503', '112', '13380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13381', '1079', '1', 'Mata', 'BR.23.4312104', 'ASCII:Mata;ID:6323511', '11504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11504', '112', '13381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13382', '1079', '1', 'Mato Castelhano', 'BR.23.4312138', 'ASCII:Mato Castelhano;ID:6323512', '11505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11505', '112', '13382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312138» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13383', '1079', '1', 'Mato Leitão', 'BR.23.4312153', 'ASCII:Mato Leitao;ID:6323513', '11506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11506', '112', '13383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13384', '1079', '1', 'Maximiliano de Almeida', 'BR.23.4312203', 'ASCII:Maximiliano De Almeida;ID:6323514', '11507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11507', '112', '13384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13385', '1079', '1', 'Minas do Leão', 'BR.23.4312252', 'ASCII:Minas Do Leao;ID:6323515', '11508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11508', '112', '13385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13386', '1079', '1', 'Miraguaí', 'BR.23.4312302', 'ASCII:Miraguai;ID:6323516', '11509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11509', '112', '13386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13387', '1079', '1', 'Montauri', 'BR.23.4312351', 'ASCII:Montauri;ID:6323517', '11510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11510', '112', '13387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13388', '1079', '1', 'Monte Alegre dos Campos', 'BR.23.4312377', 'ASCII:Monte Alegre Dos Campos;ID:6323518', '11511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11511', '112', '13388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13389', '1079', '1', 'Morrinhos do Sul', 'BR.23.4312443', 'ASCII:Morrinhos Do Sul;ID:6323519', '11512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11512', '112', '13389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13390', '1079', '1', 'Morro Redondo', 'BR.23.4312450', 'ASCII:Morro Redondo;ID:6323520', '11513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11513', '112', '13390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13391', '1079', '1', 'Morro Reuter', 'BR.23.4312476', 'ASCII:Morro Reuter;ID:6323521', '11514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11514', '112', '13391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13392', '1079', '1', 'Mostardas', 'BR.23.4312500', 'ASCII:Mostardas;ID:6323522', '11515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11515', '112', '13392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13393', '1079', '1', 'Muçum', 'BR.23.4312609', 'ASCII:Mucum;ID:6323523', '11516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11516', '112', '13393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13394', '1079', '1', 'Muitos Capões', 'BR.23.4312617', 'ASCII:Muitos Capoes;ID:6323524', '11517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11517', '112', '13394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13395', '1079', '1', 'Muliterno', 'BR.23.4312625', 'ASCII:Muliterno;ID:6323525', '11518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11518', '112', '13395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13396', '1079', '1', 'Não-Me-Toque', 'BR.23.4312658', 'ASCII:Nao-Me-Toque;ID:6323526', '11519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11519', '112', '13396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13397', '1079', '1', 'Nicolau Vergueiro', 'BR.23.4312674', 'ASCII:Nicolau Vergueiro;ID:6323527', '11520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11520', '112', '13397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13398', '1079', '1', 'Nonoai', 'BR.23.4312708', 'ASCII:Nonoai;ID:6323528', '11521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11521', '112', '13398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13399', '1079', '1', 'Nova Alvorada', 'BR.23.4312757', 'ASCII:Nova Alvorada;ID:6323529', '11522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11522', '112', '13399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13400', '1079', '1', 'Nova Araçá', 'BR.23.4312807', 'ASCII:Nova Araca;ID:6323530', '11523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11523', '112', '13400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13401', '1079', '1', 'Nova Bassano', 'BR.23.4312906', 'ASCII:Nova Bassano;ID:6323531', '11524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11524', '112', '13401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4312906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13402', '1079', '1', 'Nova Esperança do Sul', 'BR.23.4313037', 'ASCII:Nova Esperanca Do Sul;ID:6323532', '11525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11525', '112', '13402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13403', '1079', '1', 'Nova Hartz', 'BR.23.4313060', 'ASCII:Nova Hartz;ID:6323533', '11526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11526', '112', '13403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13404', '1079', '1', 'Nova Pádua', 'BR.23.4313086', 'ASCII:Nova Padua;ID:6323534', '11527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11527', '112', '13404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13405', '1079', '1', 'Nova Palma', 'BR.23.4313102', 'ASCII:Nova Palma;ID:6323535', '11528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11528', '112', '13405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13406', '1079', '1', 'Nova Petrópolis', 'BR.23.4313201', 'ASCII:Nova Petropolis;ID:6323536', '11529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11529', '112', '13406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13407', '1079', '1', 'Nova Prata', 'BR.23.4313300', 'ASCII:Nova Prata;ID:6323537', '11530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11530', '112', '13407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13408', '1079', '1', 'Nova Ramada', 'BR.23.4313334', 'ASCII:Nova Ramada;ID:6323538', '11531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11531', '112', '13408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13409', '1079', '1', 'Nova Roma do Sul', 'BR.23.4313359', 'ASCII:Nova Roma Do Sul;ID:6323539', '11532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11532', '112', '13409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13410', '1079', '1', 'Nova Santa Rita', 'BR.23.4313375', 'ASCII:Nova Santa Rita;ID:6323540', '11533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11533', '112', '13410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13411', '1079', '1', 'Novo Cabrais', 'BR.23.4313391', 'ASCII:Novo Cabrais;ID:6323541', '11534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11534', '112', '13411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13412', '1079', '1', 'Novo Machado', 'BR.23.4313425', 'ASCII:Novo Machado;ID:6323542', '11535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11535', '112', '13412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13413', '1079', '1', 'Novo Tiradentes', 'BR.23.4313441', 'ASCII:Novo Tiradentes;ID:6323543', '11536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11536', '112', '13413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13414', '1079', '1', 'Novo Barreiro', 'BR.23.4313490', 'ASCII:Novo Barreiro;ID:6323544', '11537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11537', '112', '13414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13415', '1079', '1', 'Osório', 'BR.23.4313508', 'ASCII:Osorio;ID:6323545', '11538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11538', '112', '13415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13416', '1079', '1', 'Paim Filho', 'BR.23.4313607', 'ASCII:Paim Filho;ID:6323546', '11539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11539', '112', '13416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13417', '1079', '1', 'Palmares do Sul', 'BR.23.4313656', 'ASCII:Palmares Do Sul;ID:6323547', '11540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11540', '112', '13417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13418', '1079', '1', 'Palmitinho', 'BR.23.4313805', 'ASCII:Palmitinho;ID:6323548', '11541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11541', '112', '13418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13419', '1079', '1', 'Panambi', 'BR.23.4313904', 'ASCII:Panambi;ID:6323549', '11542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11542', '112', '13419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13420', '1079', '1', 'Pantano Grande', 'BR.23.4313953', 'ASCII:Pantano Grande;ID:6323550', '11543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11543', '112', '13420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13421', '1079', '1', 'Paraí', 'BR.23.4314001', 'ASCII:Parai;ID:6323551', '11544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11544', '112', '13421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13422', '1079', '1', 'Paraíso do Sul', 'BR.23.4314027', 'ASCII:Paraiso Do Sul;ID:6323552', '11545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11545', '112', '13422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13423', '1079', '1', 'Pareci Novo', 'BR.23.4314035', 'ASCII:Pareci Novo;ID:6323553', '11546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11546', '112', '13423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13424', '1079', '1', 'Parobé', 'BR.23.4314050', 'ASCII:Parobe;ID:6323554', '11547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11547', '112', '13424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13425', '1079', '1', 'Passa Sete', 'BR.23.4314068', 'ASCII:Passa Sete;ID:6323555', '11548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11548', '112', '13425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13426', '1079', '1', 'Passo do Sobrado', 'BR.23.4314076', 'ASCII:Passo Do Sobrado;ID:6323556', '11549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11549', '112', '13426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13427', '1079', '1', 'Passo Fundo', 'BR.23.4314100', 'ASCII:Passo Fundo;ID:6323557', '11550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11550', '112', '13427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13428', '1079', '1', 'Paverama', 'BR.23.4314159', 'ASCII:Paverama;ID:6323558', '11551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11551', '112', '13428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13429', '1079', '1', 'Pedro Osório', 'BR.23.4314209', 'ASCII:Pedro Osorio;ID:6323559', '11552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11552', '112', '13429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13430', '1079', '1', 'Pejuçara', 'BR.23.4314308', 'ASCII:Pejucara;ID:6323560', '11553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11553', '112', '13430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13431', '1079', '1', 'Picada Café', 'BR.23.4314423', 'ASCII:Picada Cafe;ID:6323561', '11554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11554', '112', '13431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13432', '1079', '1', 'Pinhal', 'BR.23.4314456', 'ASCII:Pinhal;ID:6323562', '11555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11555', '112', '13432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13433', '1079', '1', 'Pinhal Grande', 'BR.23.4314472', 'ASCII:Pinhal Grande;ID:6323563', '11556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11556', '112', '13433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13434', '1079', '1', 'Pinheirinho do Vale', 'BR.23.4314498', 'ASCII:Pinheirinho Do Vale;ID:6323564', '11557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11557', '112', '13434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13435', '1079', '1', 'Pirapó', 'BR.23.4314555', 'ASCII:Pirapo;ID:6323565', '11558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11558', '112', '13435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13436', '1079', '1', 'Piratini', 'BR.23.4314605', 'ASCII:Piratini;ID:6323566', '11559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11559', '112', '13436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13437', '1079', '1', 'Planalto', 'BR.23.4314704', 'ASCII:Planalto;ID:6323567', '11560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11560', '112', '13437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13438', '1079', '1', 'Poço das Antas', 'BR.23.4314753', 'ASCII:Poco Das Antas;ID:6323568', '11561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11561', '112', '13438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13439', '1079', '1', 'Pontão', 'BR.23.4314779', 'ASCII:Pontao;ID:6323569', '11562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11562', '112', '13439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13440', '1079', '1', 'Portão', 'BR.23.4314803', 'ASCII:Portao;ID:6323570', '11563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11563', '112', '13440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13441', '1079', '1', 'Porto Alegre', 'BR.23.4314902', 'ASCII:Porto Alegre;ID:6323571', '11564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11564', '112', '13441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13442', '1079', '1', 'Porto Lucena', 'BR.23.4315008', 'ASCII:Porto Lucena;ID:6323572', '11565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11565', '112', '13442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13443', '1079', '1', 'Porto Mauá', 'BR.23.4315057', 'ASCII:Porto Maua;ID:6323573', '11566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11566', '112', '13443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13444', '1079', '1', 'Porto Vera Cruz', 'BR.23.4315073', 'ASCII:Porto Vera Cruz;ID:6323574', '11567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11567', '112', '13444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13445', '1079', '1', 'Porto Xavier', 'BR.23.4315107', 'ASCII:Porto Xavier;ID:6323575', '11568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11568', '112', '13445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13446', '1079', '1', 'Pouso Novo', 'BR.23.4315131', 'ASCII:Pouso Novo;ID:6323576', '11569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11569', '112', '13446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13447', '1079', '1', 'Presidente Lucena', 'BR.23.4315149', 'ASCII:Presidente Lucena;ID:6323577', '11570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11570', '112', '13447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13448', '1079', '1', 'Protásio Alves', 'BR.23.4315172', 'ASCII:Protasio Alves;ID:6323578', '11571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11571', '112', '13448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13449', '1079', '1', 'Putinga', 'BR.23.4315206', 'ASCII:Putinga;ID:6323579', '11572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11572', '112', '13449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13450', '1079', '1', 'Quaraí', 'BR.23.4315305', 'ASCII:Quarai;ID:6323580', '11573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11573', '112', '13450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13451', '1079', '1', 'Quevedos', 'BR.23.4315321', 'ASCII:Quevedos;ID:6323581', '11574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11574', '112', '13451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13452', '1079', '1', 'Quinze de Novembro', 'BR.23.4315354', 'ASCII:Quinze De Novembro;ID:6323582', '11575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11575', '112', '13452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13453', '1079', '1', 'Redentora', 'BR.23.4315404', 'ASCII:Redentora;ID:6323583', '11576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11576', '112', '13453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13454', '1079', '1', 'Restinga Seca', 'BR.23.4315503', 'ASCII:Restinga Seca;ID:6323584', '11577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11577', '112', '13454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13455', '1079', '1', 'Rio dos Índios', 'BR.23.4315552', 'ASCII:Rio Dos Indios;ID:6323585', '11578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11578', '112', '13455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13456', '1079', '1', 'Rio Pardo', 'BR.23.4315701', 'ASCII:Rio Pardo;ID:6323586', '11579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11579', '112', '13456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13457', '1079', '1', 'Riozinho', 'BR.23.4315750', 'ASCII:Riozinho;ID:6323587', '11580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11580', '112', '13457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13458', '1079', '1', 'Rodeio Bonito', 'BR.23.4315909', 'ASCII:Rodeio Bonito;ID:6323588', '11581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11581', '112', '13458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4315909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13459', '1079', '1', 'Rolante', 'BR.23.4316006', 'ASCII:Rolante;ID:6323589', '11582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11582', '112', '13459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13460', '1079', '1', 'Ronda Alta', 'BR.23.4316105', 'ASCII:Ronda Alta;ID:6323590', '11583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11583', '112', '13460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13461', '1079', '1', 'Rondinha', 'BR.23.4316204', 'ASCII:Rondinha;ID:6323591', '11584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11584', '112', '13461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13462', '1079', '1', 'Roque Gonzales', 'BR.23.4316303', 'ASCII:Roque Gonzales;ID:6323592', '11585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11585', '112', '13462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13463', '1079', '1', 'Rosário do Sul', 'BR.23.4316402', 'ASCII:Rosario Do Sul;ID:6323593', '11586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11586', '112', '13463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13464', '1079', '1', 'Sagrada Família', 'BR.23.4316428', 'ASCII:Sagrada Familia;ID:6323594', '11587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11587', '112', '13464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13465', '1079', '1', 'Saldanha Marinho', 'BR.23.4316436', 'ASCII:Saldanha Marinho;ID:6323595', '11588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11588', '112', '13465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13466', '1079', '1', 'Salvador das Missões', 'BR.23.4316477', 'ASCII:Salvador Das Missoes;ID:6323596', '11589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11589', '112', '13466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13467', '1079', '1', 'Sananduva', 'BR.23.4316600', 'ASCII:Sananduva;ID:6323597', '11590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11590', '112', '13467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13468', '1079', '1', 'Santa Bárbara do Sul', 'BR.23.4316709', 'ASCII:Santa Barbara Do Sul;ID:6323598', '11591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11591', '112', '13468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13469', '1079', '1', 'Santa Clara do Sul', 'BR.23.4316758', 'ASCII:Santa Clara Do Sul;ID:6323599', '11592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11592', '112', '13469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13470', '1079', '1', 'Santa Cruz do Sul', 'BR.23.4316808', 'ASCII:Santa Cruz Do Sul;ID:6323600', '11593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11593', '112', '13470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13471', '1079', '1', 'Santa Maria do Herval', 'BR.23.4316956', 'ASCII:Santa Maria Do Herval;ID:6323601', '11594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11594', '112', '13471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13472', '1079', '1', 'Santana da Boa Vista', 'BR.23.4317004', 'ASCII:Santana Da Boa Vista;ID:6323602', '11595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11595', '112', '13472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13473', '1079', '1', 'Santana do Livramento', 'BR.23.4317103', 'ASCII:Santana Do Livramento;ID:6323603', '11596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11596', '112', '13473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13474', '1079', '1', 'Santa Rosa', 'BR.23.4317202', 'ASCII:Santa Rosa;ID:6323604', '11597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11597', '112', '13474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13475', '1079', '1', 'Santa Tereza', 'BR.23.4317251', 'ASCII:Santa Tereza;ID:6323605', '11598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11598', '112', '13475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13476', '1079', '1', 'Santa Vitória do Palmar', 'BR.23.4317301', 'ASCII:Santa Vitoria Do Palmar;ID:6323606', '11599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11599', '112', '13476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13477', '1079', '1', 'Santo Ângelo', 'BR.23.4317509', 'ASCII:Santo Angelo;ID:6323607', '11600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11600', '112', '13477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13478', '1079', '1', 'Santo Antônio do Palma', 'BR.23.4317558', 'ASCII:Santo Antonio Do Palma;ID:6323608', '11601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11601', '112', '13478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13479', '1079', '1', 'Santo Antônio da Patrulha', 'BR.23.4317608', 'ASCII:Santo Antonio Da Patrulha;ID:6323609', '11602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11602', '112', '13479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13480', '1079', '1', 'Santo Antônio das Missões', 'BR.23.4317707', 'ASCII:Santo Antonio Das Missoes;ID:6323610', '11603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11603', '112', '13480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13481', '1079', '1', 'Santo Antônio do Planalto', 'BR.23.4317756', 'ASCII:Santo Antonio Do Planalto;ID:6323611', '11604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11604', '112', '13481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13482', '1079', '1', 'Santo Augusto', 'BR.23.4317806', 'ASCII:Santo Augusto;ID:6323612', '11605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11605', '112', '13482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13483', '1079', '1', 'Santo Cristo', 'BR.23.4317905', 'ASCII:Santo Cristo;ID:6323613', '11606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11606', '112', '13483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13484', '1079', '1', 'Santo Expedito do Sul', 'BR.23.4317954', 'ASCII:Santo Expedito Do Sul;ID:6323614', '11607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11607', '112', '13484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4317954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13485', '1079', '1', 'São Borja', 'BR.23.4318002', 'ASCII:Sao Borja;ID:6323615', '11608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11608', '112', '13485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13486', '1079', '1', 'São Domingos do Sul', 'BR.23.4318051', 'ASCII:Sao Domingos Do Sul;ID:6323616', '11609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11609', '112', '13486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13487', '1079', '1', 'São Francisco de Assis', 'BR.23.4318101', 'ASCII:Sao Francisco De Assis;ID:6323617', '11610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11610', '112', '13487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13488', '1079', '1', 'São Jerônimo', 'BR.23.4318408', 'ASCII:Sao Jeronimo;ID:6323618', '11611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11611', '112', '13488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13489', '1079', '1', 'São João da Urtiga', 'BR.23.4318424', 'ASCII:Sao Joao Da Urtiga;ID:6323619', '11612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11612', '112', '13489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13490', '1079', '1', 'São João do Polêsine', 'BR.23.4318432', 'ASCII:Sao Joao Do Polesine;ID:6323620', '11613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11613', '112', '13490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13491', '1079', '1', 'São Jorge', 'BR.23.4318440', 'ASCII:Sao Jorge;ID:6323621', '11614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11614', '112', '13491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13492', '1079', '1', 'São José das Missões', 'BR.23.4318457', 'ASCII:Sao Jose Das Missoes;ID:6323622', '11615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11615', '112', '13492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13493', '1079', '1', 'São José do Herval', 'BR.23.4318465', 'ASCII:Sao Jose Do Herval;ID:6323623', '11616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11616', '112', '13493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13494', '1079', '1', 'São José do Hortêncio', 'BR.23.4318481', 'ASCII:Sao Jose Do Hortencio;ID:6323624', '11617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11617', '112', '13494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13495', '1079', '1', 'São José do Inhacorá', 'BR.23.4318499', 'ASCII:Sao Jose Do Inhacora;ID:6323625', '11618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11618', '112', '13495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13496', '1079', '1', 'São José do Norte', 'BR.23.4318507', 'ASCII:Sao Jose Do Norte;ID:6323626', '11619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11619', '112', '13496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13497', '1079', '1', 'São José do Ouro', 'BR.23.4318606', 'ASCII:Sao Jose Do Ouro;ID:6323627', '11620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11620', '112', '13497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13498', '1079', '1', 'São José dos Ausentes', 'BR.23.4318622', 'ASCII:Sao Jose Dos Ausentes;ID:6323628', '11621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11621', '112', '13498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13499', '1079', '1', 'São Leopoldo', 'BR.23.4318705', 'ASCII:Sao Leopoldo;ID:6323629', '11622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11622', '112', '13499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13500', '1079', '1', 'São Lourenço do Sul', 'BR.23.4318804', 'ASCII:Sao Lourenco Do Sul;ID:6323630', '11623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11623', '112', '13500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13501', '1079', '1', 'São Marcos', 'BR.23.4319000', 'ASCII:Sao Marcos;ID:6323631', '11624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11624', '112', '13501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13502', '1079', '1', 'São Martinho', 'BR.23.4319109', 'ASCII:Sao Martinho;ID:6323632', '11625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11625', '112', '13502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13503', '1079', '1', 'São Martinho da Serra', 'BR.23.4319125', 'ASCII:Sao Martinho Da Serra;ID:6323633', '11626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11626', '112', '13503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13504', '1079', '1', 'São Nicolau', 'BR.23.4319208', 'ASCII:Sao Nicolau;ID:6323634', '11627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11627', '112', '13504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13505', '1079', '1', 'São Paulo das Missões', 'BR.23.4319307', 'ASCII:Sao Paulo Das Missoes;ID:6323635', '11628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11628', '112', '13505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13506', '1079', '1', 'São Pedro da Serra', 'BR.23.4319356', 'ASCII:Sao Pedro Da Serra;ID:6323636', '11629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11629', '112', '13506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13507', '1079', '1', 'São Pedro do Butiá', 'BR.23.4319372', 'ASCII:Sao Pedro Do Butia;ID:6323637', '11630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11630', '112', '13507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319372» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13508', '1079', '1', 'São Pedro do Sul', 'BR.23.4319406', 'ASCII:Sao Pedro Do Sul;ID:6323638', '11631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11631', '112', '13508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13509', '1079', '1', 'São Sebastião do Caí', 'BR.23.4319505', 'ASCII:Sao Sebastiao Do Cai;ID:6323639', '11632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11632', '112', '13509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13510', '1079', '1', 'São Sepé', 'BR.23.4319604', 'ASCII:Sao Sepe;ID:6323640', '11633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11633', '112', '13510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13511', '1079', '1', 'São Valentim', 'BR.23.4319703', 'ASCII:Sao Valentim;ID:6323641', '11634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11634', '112', '13511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13512', '1079', '1', 'São Valentim do Sul', 'BR.23.4319711', 'ASCII:Sao Valentim Do Sul;ID:6323642', '11635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11635', '112', '13512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13513', '1079', '1', 'São Valério do Sul', 'BR.23.4319737', 'ASCII:Sao Valerio Do Sul;ID:6323643', '11636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11636', '112', '13513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13514', '1079', '1', 'São Vendelino', 'BR.23.4319752', 'ASCII:Sao Vendelino;ID:6323644', '11637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11637', '112', '13514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13515', '1079', '1', 'São Vicente do Sul', 'BR.23.4319802', 'ASCII:Sao Vicente Do Sul;ID:6323645', '11638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11638', '112', '13515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13516', '1079', '1', 'Sapiranga', 'BR.23.4319901', 'ASCII:Sapiranga;ID:6323646', '11639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11639', '112', '13516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4319901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13517', '1079', '1', 'Sapucaia do Sul', 'BR.23.4320008', 'ASCII:Sapucaia Do Sul;ID:6323647', '11640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11640', '112', '13517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13518', '1079', '1', 'Sarandi', 'BR.23.4320107', 'ASCII:Sarandi;ID:6323648', '11641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11641', '112', '13518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13519', '1079', '1', 'Seberi', 'BR.23.4320206', 'ASCII:Seberi;ID:6323649', '11642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11642', '112', '13519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13520', '1079', '1', 'Sede Nova', 'BR.23.4320230', 'ASCII:Sede Nova;ID:6323650', '11643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11643', '112', '13520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13521', '1079', '1', 'Segredo', 'BR.23.4320263', 'ASCII:Segredo;ID:6323651', '11644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11644', '112', '13521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13522', '1079', '1', 'Selbach', 'BR.23.4320305', 'ASCII:Selbach;ID:6323652', '11645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11645', '112', '13522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13523', '1079', '1', 'Senador Salgado Filho', 'BR.23.4320321', 'ASCII:Senador Salgado Filho;ID:6323653', '11646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11646', '112', '13523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13524', '1079', '1', 'Sentinela do Sul', 'BR.23.4320354', 'ASCII:Sentinela Do Sul;ID:6323654', '11647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11647', '112', '13524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13525', '1079', '1', 'Serafina Corrêa', 'BR.23.4320404', 'ASCII:Serafina Correa;ID:6323655', '11648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11648', '112', '13525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13526', '1079', '1', 'Sério', 'BR.23.4320453', 'ASCII:Serio;ID:6323656', '11649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11649', '112', '13526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13527', '1079', '1', 'Sertão', 'BR.23.4320503', 'ASCII:Sertao;ID:6323657', '11650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11650', '112', '13527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13528', '1079', '1', 'Sertão Santana', 'BR.23.4320552', 'ASCII:Sertao Santana;ID:6323658', '11651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11651', '112', '13528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13529', '1079', '1', 'Sete de Setembro', 'BR.23.4320578', 'ASCII:Sete De Setembro;ID:6323659', '11652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11652', '112', '13529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13530', '1079', '1', 'Severiano de Almeida', 'BR.23.4320602', 'ASCII:Severiano De Almeida;ID:6323660', '11653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11653', '112', '13530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13531', '1079', '1', 'Silveira Martins', 'BR.23.4320651', 'ASCII:Silveira Martins;ID:6323661', '11654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11654', '112', '13531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13532', '1079', '1', 'Sinimbu', 'BR.23.4320677', 'ASCII:Sinimbu;ID:6323662', '11655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11655', '112', '13532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13533', '1079', '1', 'Tabaí', 'BR.23.4320859', 'ASCII:Tabai;ID:6323663', '11656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11656', '112', '13533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13534', '1079', '1', 'Tapera', 'BR.23.4321006', 'ASCII:Tapera;ID:6323664', '11657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11657', '112', '13534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13535', '1079', '1', 'Tapes', 'BR.23.4321105', 'ASCII:Tapes;ID:6323665', '11658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11658', '112', '13535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13536', '1079', '1', 'Taquara', 'BR.23.4321204', 'ASCII:Taquara;ID:6323666', '11659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11659', '112', '13536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13537', '1079', '1', 'Taquari', 'BR.23.4321303', 'ASCII:Taquari;ID:6323667', '11660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11660', '112', '13537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13538', '1079', '1', 'Taquaruçu do Sul', 'BR.23.4321329', 'ASCII:Taquarucu Do Sul;ID:6323668', '11661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11661', '112', '13538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13539', '1079', '1', 'Tavares', 'BR.23.4321352', 'ASCII:Tavares;ID:6323669', '11662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11662', '112', '13539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13540', '1079', '1', 'Tenente Portela', 'BR.23.4321402', 'ASCII:Tenente Portela;ID:6323670', '11663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11663', '112', '13540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13541', '1079', '1', 'Tiradentes do Sul', 'BR.23.4321477', 'ASCII:Tiradentes Do Sul;ID:6323671', '11664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11664', '112', '13541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13542', '1079', '1', 'Toropi', 'BR.23.4321493', 'ASCII:Toropi;ID:6323672', '11665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11665', '112', '13542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13543', '1079', '1', 'Torres', 'BR.23.4321501', 'ASCII:Torres;ID:6323673', '11666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11666', '112', '13543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13544', '1079', '1', 'Tramandaí', 'BR.23.4321600', 'ASCII:Tramandai;ID:6323674', '11667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11667', '112', '13544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13545', '1079', '1', 'Travesseiro', 'BR.23.4321626', 'ASCII:Travesseiro;ID:6323675', '11668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11668', '112', '13545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13546', '1079', '1', 'Três Arroios', 'BR.23.4321634', 'ASCII:Tres Arroios;ID:6323676', '11669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11669', '112', '13546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13547', '1079', '1', 'Três Cachoeiras', 'BR.23.4321667', 'ASCII:Tres Cachoeiras;ID:6323677', '11670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11670', '112', '13547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13548', '1079', '1', 'Três Coroas', 'BR.23.4321709', 'ASCII:Tres Coroas;ID:6323678', '11671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11671', '112', '13548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13549', '1079', '1', 'Três de Maio', 'BR.23.4321808', 'ASCII:Tres De Maio;ID:6323679', '11672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11672', '112', '13549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13550', '1079', '1', 'Três Forquilhas', 'BR.23.4321832', 'ASCII:Tres Forquilhas;ID:6323680', '11673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11673', '112', '13550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13551', '1079', '1', 'Três Palmeiras', 'BR.23.4321857', 'ASCII:Tres Palmeiras;ID:6323681', '11674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11674', '112', '13551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13552', '1079', '1', 'Três Passos', 'BR.23.4321907', 'ASCII:Tres Passos;ID:6323682', '11675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11675', '112', '13552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13553', '1079', '1', 'Trindade do Sul', 'BR.23.4321956', 'ASCII:Trindade Do Sul;ID:6323683', '11676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11676', '112', '13553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13554', '1079', '1', 'Triunfo', 'BR.23.4322004', 'ASCII:Triunfo;ID:6323684', '11677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11677', '112', '13554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13555', '1079', '1', 'Tucunduva', 'BR.23.4322103', 'ASCII:Tucunduva;ID:6323685', '11678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11678', '112', '13555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13556', '1079', '1', 'Tunas', 'BR.23.4322152', 'ASCII:Tunas;ID:6323686', '11679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11679', '112', '13556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13557', '1079', '1', 'Tupanci do Sul', 'BR.23.4322186', 'ASCII:Tupanci Do Sul;ID:6323687', '11680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11680', '112', '13557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13558', '1079', '1', 'Tupanciretã', 'BR.23.4322202', 'ASCII:Tupancireta;ID:6323688', '11681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11681', '112', '13558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13559', '1079', '1', 'Tupandi', 'BR.23.4322251', 'ASCII:Tupandi;ID:6323689', '11682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11682', '112', '13559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13560', '1079', '1', 'Tuparendi', 'BR.23.4322301', 'ASCII:Tuparendi;ID:6323690', '11683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11683', '112', '13560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13561', '1079', '1', 'Turuçu', 'BR.23.4322327', 'ASCII:Turucu;ID:6323691', '11684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11684', '112', '13561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13562', '1079', '1', 'Ubiretama', 'BR.23.4322343', 'ASCII:Ubiretama;ID:6323692', '11685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11685', '112', '13562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13563', '1079', '1', 'União da Serra', 'BR.23.4322350', 'ASCII:Uniao Da Serra;ID:6323693', '11686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11686', '112', '13563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13564', '1079', '1', 'Unistalda', 'BR.23.4322376', 'ASCII:Unistalda;ID:6323694', '11687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11687', '112', '13564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13565', '1079', '1', 'Uruguaiana', 'BR.23.4322400', 'ASCII:Uruguaiana;ID:6323695', '11688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11688', '112', '13565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13566', '1079', '1', 'Vacaria', 'BR.23.4322509', 'ASCII:Vacaria;ID:6323696', '11689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11689', '112', '13566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13567', '1079', '1', 'Vale Verde', 'BR.23.4322525', 'ASCII:Vale Verde;ID:6323697', '11690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11690', '112', '13567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13568', '1079', '1', 'Vale do Sol', 'BR.23.4322533', 'ASCII:Vale Do Sol;ID:6323698', '11691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11691', '112', '13568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13569', '1079', '1', 'Vale Real', 'BR.23.4322541', 'ASCII:Vale Real;ID:6323699', '11692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11692', '112', '13569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13570', '1079', '1', 'Vanini', 'BR.23.4322558', 'ASCII:Vanini;ID:6323700', '11693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11693', '112', '13570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13571', '1079', '1', 'Venâncio Aires', 'BR.23.4322608', 'ASCII:Venancio Aires;ID:6323701', '11694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11694', '112', '13571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13572', '1079', '1', 'Vera Cruz', 'BR.23.4322707', 'ASCII:Vera Cruz;ID:6323702', '11695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11695', '112', '13572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13573', '1079', '1', 'Veranópolis', 'BR.23.4322806', 'ASCII:Veranopolis;ID:6323703', '11696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11696', '112', '13573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13574', '1079', '1', 'Vespasiano Correa', 'BR.23.4322855', 'ASCII:Vespasiano Correa;ID:6323704', '11697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11697', '112', '13574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13575', '1079', '1', 'Viadutos', 'BR.23.4322905', 'ASCII:Viadutos;ID:6323705', '11698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11698', '112', '13575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4322905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13576', '1079', '1', 'Viamão', 'BR.23.4323002', 'ASCII:Viamao;ID:6323706', '11699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11699', '112', '13576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13577', '1079', '1', 'Vicente Dutra', 'BR.23.4323101', 'ASCII:Vicente Dutra;ID:6323707', '11700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11700', '112', '13577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13578', '1079', '1', 'Vila Flores', 'BR.23.4323309', 'ASCII:Vila Flores;ID:6323708', '11701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11701', '112', '13578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13579', '1079', '1', 'Vila Lângaro', 'BR.23.4323358', 'ASCII:Vila Langaro;ID:6323709', '11702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11702', '112', '13579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13580', '1079', '1', 'Vila Maria', 'BR.23.4323408', 'ASCII:Vila Maria;ID:6323710', '11703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11703', '112', '13580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13581', '1079', '1', 'Vila Nova do Sul', 'BR.23.4323457', 'ASCII:Vila Nova Do Sul;ID:6323711', '11704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11704', '112', '13581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13582', '1079', '1', 'Vista Alegre', 'BR.23.4323507', 'ASCII:Vista Alegre;ID:6323712', '11705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11705', '112', '13582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13583', '1079', '1', 'Vista Alegre do Prata', 'BR.23.4323606', 'ASCII:Vista Alegre Do Prata;ID:6323713', '11706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11706', '112', '13583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13584', '1079', '1', 'Vista Gaúcha', 'BR.23.4323705', 'ASCII:Vista Gaucha;ID:6323714', '11707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11707', '112', '13584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13585', '1079', '1', 'Vitória das Missões', 'BR.23.4323754', 'ASCII:Vitoria Das Missoes;ID:6323715', '11708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11708', '112', '13585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13586', '1079', '1', 'Xangri-lá', 'BR.23.4323804', 'ASCII:Xangri-La;ID:6323716', '11709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11709', '112', '13586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13587', '1079', '1', 'Água Clara', 'BR.11.5000203', 'ASCII:Agua Clara;ID:6323717', '11710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11710', '112', '13587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5000203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13588', '1079', '1', 'Alcinópolis', 'BR.11.5000252', 'ASCII:Alcinopolis;ID:6323718', '11711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11711', '112', '13588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5000252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13589', '1079', '1', 'Amambaí', 'BR.11.5000609', 'ASCII:Amambai;ID:6323719', '11712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11712', '112', '13589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5000609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13590', '1079', '1', 'Anastácio', 'BR.11.5000708', 'ASCII:Anastacio;ID:6323720', '11713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11713', '112', '13590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5000708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13591', '1079', '1', 'Anaurilândia', 'BR.11.5000807', 'ASCII:Anaurilandia;ID:6323721', '11714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11714', '112', '13591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5000807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13592', '1079', '1', 'Angélica', 'BR.11.5000856', 'ASCII:Angelica;ID:6323722', '11715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11715', '112', '13592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5000856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13593', '1079', '1', 'Antônio João', 'BR.11.5000906', 'ASCII:Antonio Joao;ID:6323723', '11716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11716', '112', '13593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5000906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13594', '1079', '1', 'Aparecida do Taboado', 'BR.11.5001003', 'ASCII:Aparecida Do Taboado;ID:6323724', '11717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11717', '112', '13594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5001003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13595', '1079', '1', 'Aquidauana', 'BR.11.5001102', 'ASCII:Aquidauana;ID:6323725', '11718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11718', '112', '13595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5001102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13596', '1079', '1', 'Aral Moreira', 'BR.11.5001243', 'ASCII:Aral Moreira;ID:6323726', '11719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11719', '112', '13596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5001243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13597', '1079', '1', 'Bandeirantes', 'BR.11.5001508', 'ASCII:Bandeirantes;ID:6323727', '11720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11720', '112', '13597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5001508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13598', '1079', '1', 'Bataguassu', 'BR.11.5001904', 'ASCII:Bataguassu;ID:6323728', '11721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11721', '112', '13598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5001904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13599', '1079', '1', 'Batayporã', 'BR.11.5002001', 'ASCII:Bataipora;ID:6323729', '11722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11722', '112', '13599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13600', '1079', '1', 'Bela Vista', 'BR.11.5002100', 'ASCII:Bela Vista;ID:6323730', '11723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11723', '112', '13600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13601', '1079', '1', 'Bodoquena', 'BR.11.5002159', 'ASCII:Bodoquena;ID:6323731', '11724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11724', '112', '13601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13602', '1079', '1', 'Bonito', 'BR.11.5002209', 'ASCII:Bonito;ID:6323732', '11725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11725', '112', '13602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13603', '1079', '1', 'Brasilândia', 'BR.11.5002308', 'ASCII:Brasilandia;ID:6323733', '11726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11726', '112', '13603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13604', '1079', '1', 'Caarapó', 'BR.11.5002407', 'ASCII:Caarapo;ID:6323734', '11727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11727', '112', '13604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13605', '1079', '1', 'Camapuã', 'BR.11.5002605', 'ASCII:Camapua;ID:6323735', '11728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11728', '112', '13605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13606', '1079', '1', 'Campo Grande', 'BR.11.5002704', 'ASCII:Campo Grande;ID:6323736', '11729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11729', '112', '13606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13607', '1079', '1', 'Caracol', 'BR.11.5002803', 'ASCII:Caracol;ID:6323737', '11730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11730', '112', '13607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13608', '1079', '1', 'Cassilândia', 'BR.11.5002902', 'ASCII:Cassilandia;ID:6323738', '11731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11731', '112', '13608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13609', '1079', '1', 'Chapadão do Sul', 'BR.11.5002951', 'ASCII:Chapadao Do Sul;ID:6323739', '11732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11732', '112', '13609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5002951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13610', '1079', '1', 'Corguinho', 'BR.11.5003108', 'ASCII:Corguinho;ID:6323740', '11733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11733', '112', '13610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13611', '1079', '1', 'Coronel Sapucaia', 'BR.11.5003157', 'ASCII:Coronel Sapucaia;ID:6323741', '11734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11734', '112', '13611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13612', '1079', '1', 'Corumbá', 'BR.11.5003207', 'ASCII:Corumba;ID:6323742', '11735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11735', '112', '13612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13613', '1079', '1', 'Costa Rica', 'BR.11.5003256', 'ASCII:Costa Rica;ID:6323743', '11736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11736', '112', '13613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13614', '1079', '1', 'Coxim', 'BR.11.5003306', 'ASCII:Coxim;ID:6323744', '11737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11737', '112', '13614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13615', '1079', '1', 'Deodápolis', 'BR.11.5003454', 'ASCII:Deodapolis;ID:6323745', '11738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11738', '112', '13615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13616', '1079', '1', 'Dois Irmãos do Buriti', 'BR.11.5003488', 'ASCII:Dois Irmaos Do Buriti;ID:6323746', '11739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11739', '112', '13616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13617', '1079', '1', 'Douradina', 'BR.11.5003504', 'ASCII:Douradina;ID:6323747', '11740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11740', '112', '13617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13618', '1079', '1', 'Dourados', 'BR.11.5003702', 'ASCII:Dourados;ID:6323748', '11741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11741', '112', '13618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13619', '1079', '1', 'Eldorado', 'BR.11.5003751', 'ASCII:Eldorado;ID:6323749', '11742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11742', '112', '13619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13620', '1079', '1', 'Fátima do Sul', 'BR.11.5003801', 'ASCII:Fatima Do Sul;ID:6323750', '11743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11743', '112', '13620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5003801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13621', '1079', '1', 'Glória de Dourados', 'BR.11.5004007', 'ASCII:Gloria De Dourados;ID:6323751', '11744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11744', '112', '13621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5004007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13622', '1079', '1', 'Guia Lopes da Laguna', 'BR.11.5004106', 'ASCII:Guia Lopes Da Laguna;ID:6323752', '11745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11745', '112', '13622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5004106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13623', '1079', '1', 'Iguatemi', 'BR.11.5004304', 'ASCII:Iguatemi;ID:6323753', '11746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11746', '112', '13623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5004304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13624', '1079', '1', 'Inocência', 'BR.11.5004403', 'ASCII:Inocencia;ID:6323754', '11747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11747', '112', '13624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5004403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13625', '1079', '1', 'Itaporã', 'BR.11.5004502', 'ASCII:Itapora;ID:6323755', '11748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11748', '112', '13625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5004502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13626', '1079', '1', 'Itaquiraí', 'BR.11.5004601', 'ASCII:Itaquirai;ID:6323756', '11749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11749', '112', '13626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5004601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13627', '1079', '1', 'Ivinhema', 'BR.11.5004700', 'ASCII:Ivinhema;ID:6323757', '11750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11750', '112', '13627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5004700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13628', '1079', '1', 'Japorã', 'BR.11.5004809', 'ASCII:Japora;ID:6323758', '11751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11751', '112', '13628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5004809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13629', '1079', '1', 'Jaraguari', 'BR.11.5004908', 'ASCII:Jaraguari;ID:6323759', '11752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11752', '112', '13629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5004908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13630', '1079', '1', 'Jateí', 'BR.11.5005103', 'ASCII:Jatei;ID:6323760', '11753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11753', '112', '13630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5005103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13631', '1079', '1', 'Juti', 'BR.11.5005152', 'ASCII:Juti;ID:6323761', '11754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11754', '112', '13631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5005152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13632', '1079', '1', 'Ladário', 'BR.11.5005202', 'ASCII:Ladario;ID:6323762', '11755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11755', '112', '13632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5005202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13633', '1079', '1', 'Laguna Carapã', 'BR.11.5005251', 'ASCII:Laguna Carapa;ID:6323763', '11756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11756', '112', '13633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5005251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13634', '1079', '1', 'Maracaju', 'BR.11.5005400', 'ASCII:Maracaju;ID:6323764', '11757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11757', '112', '13634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5005400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13635', '1079', '1', 'Miranda', 'BR.11.5005608', 'ASCII:Miranda;ID:6323765', '11758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11758', '112', '13635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5005608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13636', '1079', '1', 'Mundo Novo', 'BR.11.5005681', 'ASCII:Mundo Novo;ID:6323766', '11759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11759', '112', '13636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5005681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13637', '1079', '1', 'Naviraí', 'BR.11.5005707', 'ASCII:Navirai;ID:6323767', '11760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11760', '112', '13637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5005707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13638', '1079', '1', 'Nioaque', 'BR.11.5005806', 'ASCII:Nioaque;ID:6323768', '11761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11761', '112', '13638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5005806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13639', '1079', '1', 'Nova Alvorada do Sul', 'BR.11.5006002', 'ASCII:Nova Alvorada Do Sul;ID:6323769', '11762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11762', '112', '13639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5006002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13640', '1079', '1', 'Nova Andradina', 'BR.11.5006200', 'ASCII:Nova Andradina;ID:6323770', '11763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11763', '112', '13640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5006200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13641', '1079', '1', 'Novo Horizonte do Sul', 'BR.11.5006259', 'ASCII:Novo Horizonte Do Sul;ID:6323771', '11764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11764', '112', '13641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5006259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13642', '1079', '1', 'Paranaíba', 'BR.11.5006309', 'ASCII:Paranaiba;ID:6323772', '11765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11765', '112', '13642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5006309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13643', '1079', '1', 'Paranhos', 'BR.11.5006358', 'ASCII:Paranhos;ID:6323773', '11766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11766', '112', '13643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5006358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13644', '1079', '1', 'Pedro Gomes', 'BR.11.5006408', 'ASCII:Pedro Gomes;ID:6323774', '11767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11767', '112', '13644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5006408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13645', '1079', '1', 'Ponta Porã', 'BR.11.5006606', 'ASCII:Ponta Pora;ID:6323775', '11768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11768', '112', '13645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5006606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13646', '1079', '1', 'Porto Murtinho', 'BR.11.5006903', 'ASCII:Porto Murtinho;ID:6323776', '11769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11769', '112', '13646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5006903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13647', '1079', '1', 'Ribas do Rio Pardo', 'BR.11.5007109', 'ASCII:Ribas Do Rio Pardo;ID:6323777', '11770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11770', '112', '13647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13648', '1079', '1', 'Rio Brilhante', 'BR.11.5007208', 'ASCII:Rio Brilhante;ID:6323778', '11771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11771', '112', '13648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13649', '1079', '1', 'Rio Negro', 'BR.11.5007307', 'ASCII:Rio Negro;ID:6323779', '11772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11772', '112', '13649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13650', '1079', '1', 'Rio Verde de Mato Grosso', 'BR.11.5007406', 'ASCII:Rio Verde De Mato Grosso;ID:6323780', '11773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11773', '112', '13650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13651', '1079', '1', 'Rochedo', 'BR.11.5007505', 'ASCII:Rochedo;ID:6323781', '11774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11774', '112', '13651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13652', '1079', '1', 'Santa Rita do Pardo', 'BR.11.5007554', 'ASCII:Santa Rita Do Pardo;ID:6323782', '11775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11775', '112', '13652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13653', '1079', '1', 'São Gabriel do Oeste', 'BR.11.5007695', 'ASCII:Sao Gabriel Do Oeste;ID:6323783', '11776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11776', '112', '13653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13654', '1079', '1', 'Sete Quedas', 'BR.11.5007703', 'ASCII:Sete Quedas;ID:6323784', '11777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11777', '112', '13654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13655', '1079', '1', 'Selvíria', 'BR.11.5007802', 'ASCII:Selviria;ID:6323785', '11778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11778', '112', '13655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13656', '1079', '1', 'Sonora', 'BR.11.5007935', 'ASCII:Sonora;ID:6323786', '11779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11779', '112', '13656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13657', '1079', '1', 'Tacuru', 'BR.11.5007950', 'ASCII:Tacuru;ID:6323787', '11780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11780', '112', '13657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13658', '1079', '1', 'Taquarussu', 'BR.11.5007976', 'ASCII:Taquarussu;ID:6323788', '11781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11781', '112', '13658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007976» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13659', '1079', '1', 'Terenos', 'BR.11.5008008', 'ASCII:Terenos;ID:6323789', '11782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11782', '112', '13659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5008008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13660', '1079', '1', 'Três Lagoas', 'BR.11.5008305', 'ASCII:Tres Lagoas;ID:6323790', '11783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11783', '112', '13660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5008305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13661', '1079', '1', 'Vicentina', 'BR.11.5008404', 'ASCII:Vicentina;ID:6323791', '11784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11784', '112', '13661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5008404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13662', '1079', '1', 'Acorizal', 'BR.14.5100102', 'ASCII:Acorizal;ID:6323792', '11785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11785', '112', '13662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5100102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13663', '1079', '1', 'Alta Floresta', 'BR.14.5100250', 'ASCII:Alta Floresta;ID:6323793', '11786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11786', '112', '13663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5100250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13664', '1079', '1', 'Alto Araguaia', 'BR.14.5100300', 'ASCII:Alto Araguaia;ID:6323794', '11787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11787', '112', '13664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5100300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13665', '1079', '1', 'Alto Garças', 'BR.14.5100409', 'ASCII:Alto Garcas;ID:6323795', '11788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11788', '112', '13665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5100409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13666', '1079', '1', 'Alto Paraguai', 'BR.14.5100508', 'ASCII:Alto Paraguai;ID:6323796', '11789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11789', '112', '13666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5100508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13667', '1079', '1', 'Alto Taquari', 'BR.14.5100607', 'ASCII:Alto Taquari;ID:6323797', '11790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11790', '112', '13667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5100607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13668', '1079', '1', 'Apiacás', 'BR.14.5100805', 'ASCII:Apiacas;ID:6323798', '11791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11791', '112', '13668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5100805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13669', '1079', '1', 'Araguaiana', 'BR.14.5101001', 'ASCII:Araguaiana;ID:6323799', '11792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11792', '112', '13669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5101001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13670', '1079', '1', 'Araguainha', 'BR.14.5101209', 'ASCII:Araguainha;ID:6323800', '11793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11793', '112', '13670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5101209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13671', '1079', '1', 'Araputanga', 'BR.14.5101258', 'ASCII:Araputanga;ID:6323801', '11794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11794', '112', '13671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5101258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13672', '1079', '1', 'Arenápolis', 'BR.14.5101308', 'ASCII:Arenapolis;ID:6323802', '11795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11795', '112', '13672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5101308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13673', '1079', '1', 'Barão de Melgaço', 'BR.14.5101605', 'ASCII:Barao De Melgaco;ID:6323803', '11796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11796', '112', '13673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5101605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13674', '1079', '1', 'Barra do Bugres', 'BR.14.5101704', 'ASCII:Barra Do Bugres;ID:6323804', '11797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11797', '112', '13674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5101704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13675', '1079', '1', 'Barra do Garças', 'BR.14.5101803', 'ASCII:Barra Do Garcas;ID:6323805', '11798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11798', '112', '13675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5101803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13676', '1079', '1', 'Brasnorte', 'BR.14.5101902', 'ASCII:Brasnorte;ID:6323806', '11799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11799', '112', '13676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5101902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13677', '1079', '1', 'Campinápolis', 'BR.14.5102603', 'ASCII:Campinapolis;ID:6323807', '11800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11800', '112', '13677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5102603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13678', '1079', '1', 'Campo Novo do Parecis', 'BR.14.5102637', 'ASCII:Campo Novo Do Parecis;ID:6323808', '11801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11801', '112', '13678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5102637» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13679', '1079', '1', 'Campo Verde', 'BR.14.5102678', 'ASCII:Campo Verde;ID:6323809', '11802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11802', '112', '13679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5102678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13680', '1079', '1', 'Campos de Júlio', 'BR.14.5102686', 'ASCII:Campos De Julio;ID:6323810', '11803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11803', '112', '13680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5102686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13681', '1079', '1', 'CanaBrava do Norte', 'BR.14.5102694', 'ASCII:Cana Brava Do Norte;ID:6323811', '11804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11804', '112', '13681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5102694» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13682', '1079', '1', 'Canarana', 'BR.14.5102702', 'ASCII:Canarana;ID:6323812', '11805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11805', '112', '13682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5102702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13683', '1079', '1', 'Castanheira', 'BR.14.5102850', 'ASCII:Castanheira;ID:6323813', '11806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11806', '112', '13683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5102850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13684', '1079', '1', 'Chapada dos Guimarães', 'BR.14.5103007', 'ASCII:Chapada Dos Guimaraes;ID:6323814', '11807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11807', '112', '13684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13685', '1079', '1', 'Cláudia', 'BR.14.5103056', 'ASCII:Claudia;ID:6323815', '11808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11808', '112', '13685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13686', '1079', '1', 'Colíder', 'BR.14.5103205', 'ASCII:Colider;ID:6323816', '11809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11809', '112', '13686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13687', '1079', '1', 'Comodoro', 'BR.14.5103304', 'ASCII:Comodoro;ID:6323817', '11810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11810', '112', '13687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13688', '1079', '1', 'Confresa', 'BR.14.5103353', 'ASCII:Confresa;ID:6323818', '11811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11811', '112', '13688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13689', '1079', '1', 'Cotriguaçu', 'BR.14.5103379', 'ASCII:Cotriguacu;ID:6323819', '11812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11812', '112', '13689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13690', '1079', '1', 'Cuiabá', 'BR.14.5103403', 'ASCII:Cuiaba;ID:6323820', '11813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11813', '112', '13690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13691', '1079', '1', 'Denise', 'BR.14.5103452', 'ASCII:Denise;ID:6323821', '11814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11814', '112', '13691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13692', '1079', '1', 'Diamantino', 'BR.14.5103502', 'ASCII:Diamantino;ID:6323822', '11815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11815', '112', '13692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13693', '1079', '1', 'Dom Aquino', 'BR.14.5103601', 'ASCII:Dom Aquino;ID:6323823', '11816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11816', '112', '13693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13694', '1079', '1', 'Feliz Natal', 'BR.14.5103700', 'ASCII:Feliz Natal;ID:6323824', '11817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11817', '112', '13694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13695', '1079', '1', 'Figueirópolis d''Oeste', 'BR.14.5103809', 'ASCII:Figueiropolis D''Oeste;ID:6323825', '11818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11818', '112', '13695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13696', '1079', '1', 'Gaúcha do Norte', 'BR.14.5103858', 'ASCII:Gaucha Do Norte;ID:6323826', '11819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11819', '112', '13696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13697', '1079', '1', 'General Carneiro', 'BR.14.5103908', 'ASCII:General Carneiro;ID:6323827', '11820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11820', '112', '13697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13698', '1079', '1', 'Glória d''Oeste', 'BR.14.5103957', 'ASCII:Gloria D''Oeste;ID:6323828', '11821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11821', '112', '13698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13699', '1079', '1', 'Guiratinga', 'BR.14.5104203', 'ASCII:Guiratinga;ID:6323829', '11822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11822', '112', '13699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5104203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13700', '1079', '1', 'Indiavaí', 'BR.14.5104500', 'ASCII:Indiavai;ID:6323830', '11823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11823', '112', '13700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5104500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13701', '1079', '1', 'Itiquira', 'BR.14.5104609', 'ASCII:Itiquira;ID:6323831', '11824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11824', '112', '13701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5104609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13702', '1079', '1', 'Jaciara', 'BR.14.5104807', 'ASCII:Jaciara;ID:6323832', '11825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11825', '112', '13702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5104807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13703', '1079', '1', 'Jangada', 'BR.14.5104906', 'ASCII:Jangada;ID:6323833', '11826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11826', '112', '13703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5104906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13704', '1079', '1', 'Jauru', 'BR.14.5105002', 'ASCII:Jauru;ID:6323834', '11827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11827', '112', '13704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13705', '1079', '1', 'Juara', 'BR.14.5105101', 'ASCII:Juara;ID:6323835', '11828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11828', '112', '13705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13706', '1079', '1', 'Juína', 'BR.14.5105150', 'ASCII:Juina;ID:6323836', '11829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11829', '112', '13706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13707', '1079', '1', 'Juruena', 'BR.14.5105176', 'ASCII:Juruena;ID:6323837', '11830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11830', '112', '13707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13708', '1079', '1', 'Juscimeira', 'BR.14.5105200', 'ASCII:Juscimeira;ID:6323838', '11831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11831', '112', '13708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13709', '1079', '1', 'Vila Bela da Santíssima Trindade', 'BR.14.5105507', 'ASCII:Vila Bela Da Santissima Trindade;ID:6323839', '11832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11832', '112', '13709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13710', '1079', '1', 'Nortelândia', 'BR.14.5106000', 'ASCII:Nortelandia;ID:6323840', '11833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11833', '112', '13710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13711', '1079', '1', 'Nossa Senhora do Livramento', 'BR.14.5106109', 'ASCII:Nossa Senhora Do Livramento;ID:6323841', '11834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11834', '112', '13711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13712', '1079', '1', 'Nova Bandeirantes', 'BR.14.5106158', 'ASCII:Nova Bandeirantes;ID:6323842', '11835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11835', '112', '13712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13713', '1079', '1', 'Nova Lacerda', 'BR.14.5106182', 'ASCII:Nova Lacerda;ID:6323843', '11836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11836', '112', '13713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13714', '1079', '1', 'Nova Brasilândia', 'BR.14.5106208', 'ASCII:Nova Brasilandia;ID:6323844', '11837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11837', '112', '13714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13715', '1079', '1', 'Nova Canaã do Norte', 'BR.14.5106216', 'ASCII:Nova Canaa Do Norte;ID:6323845', '11838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11838', '112', '13715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13716', '1079', '1', 'Nova Olímpia', 'BR.14.5106232', 'ASCII:Nova Olimpia;ID:6323846', '11839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11839', '112', '13716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106232» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13717', '1079', '1', 'Nova Ubiratã', 'BR.14.5106240', 'ASCII:Nova Ubirata;ID:6323847', '11840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11840', '112', '13717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13718', '1079', '1', 'Nova Xavantina', 'BR.14.5106257', 'ASCII:Nova Xavantina;ID:6323848', '11841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11841', '112', '13718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13719', '1079', '1', 'Novo Horizonte do Norte', 'BR.14.5106273', 'ASCII:Novo Horizonte Do Norte;ID:6323849', '11842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11842', '112', '13719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13720', '1079', '1', 'Paranaíta', 'BR.14.5106299', 'ASCII:Paranaita;ID:6323850', '11843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11843', '112', '13720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106299» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13721', '1079', '1', 'Paranatinga', 'BR.14.5106307', 'ASCII:Paranatinga;ID:6323851', '11844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11844', '112', '13721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13722', '1079', '1', 'Pedra Preta', 'BR.14.5106372', 'ASCII:Pedra Preta;ID:6323852', '11845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11845', '112', '13722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106372» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13723', '1079', '1', 'Planalto da Serra', 'BR.14.5106455', 'ASCII:Planalto Da Serra;ID:6323853', '11846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11846', '112', '13723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13724', '1079', '1', 'Poconé', 'BR.14.5106505', 'ASCII:Pocone;ID:6323854', '11847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11847', '112', '13724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13725', '1079', '1', 'Pontal do Araguaia', 'BR.14.5106653', 'ASCII:Pontal Do Araguaia;ID:6323855', '11848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11848', '112', '13725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13726', '1079', '1', 'Ponte Branca', 'BR.14.5106703', 'ASCII:Ponte Branca;ID:6323856', '11849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11849', '112', '13726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13727', '1079', '1', 'Porto Alegre do Norte', 'BR.14.5106778', 'ASCII:Porto Alegre Do Norte;ID:6323857', '11850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11850', '112', '13727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13728', '1079', '1', 'Porto dos Gaúchos', 'BR.14.5106802', 'ASCII:Porto Dos Gauchos;ID:6323858', '11851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11851', '112', '13728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13729', '1079', '1', 'Porto Esperidião', 'BR.14.5106828', 'ASCII:Porto Esperidiao;ID:6323859', '11852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11852', '112', '13729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13730', '1079', '1', 'Porto Estrela', 'BR.14.5106851', 'ASCII:Porto Estrela;ID:6323860', '11853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11853', '112', '13730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13731', '1079', '1', 'Poxoréo', 'BR.14.5107008', 'ASCII:Poxoreo;ID:6323861', '11854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11854', '112', '13731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13732', '1079', '1', 'Primavera do Leste', 'BR.14.5107040', 'ASCII:Primavera Do Leste;ID:6323862', '11855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11855', '112', '13732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13733', '1079', '1', 'Querência', 'BR.14.5107065', 'ASCII:Querencia;ID:6323863', '11856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11856', '112', '13733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13734', '1079', '1', 'São José dos Quatro Marcos', 'BR.14.5107107', 'ASCII:Sao Jose Dos Quatro Marcos;ID:6323864', '11857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11857', '112', '13734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13735', '1079', '1', 'Reserva do Cabaçal', 'BR.14.5107156', 'ASCII:Reserva Do Cabacal;ID:6323865', '11858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11858', '112', '13735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13736', '1079', '1', 'Ribeirãozinho', 'BR.14.5107198', 'ASCII:Ribeiraozinho;ID:6323866', '11859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11859', '112', '13736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107198» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13737', '1079', '1', 'Rio Branco', 'BR.14.5107206', 'ASCII:Rio Branco;ID:6323867', '11860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11860', '112', '13737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13738', '1079', '1', 'Santa Carmem', 'BR.14.5107248', 'ASCII:Santa Carmem;ID:6323868', '11861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11861', '112', '13738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13739', '1079', '1', 'Santo Afonso', 'BR.14.5107263', 'ASCII:Santo Afonso;ID:6323869', '11862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11862', '112', '13739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13740', '1079', '1', 'São José do Rio Claro', 'BR.14.5107305', 'ASCII:Sao Jose Do Rio Claro;ID:6323870', '11863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11863', '112', '13740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13741', '1079', '1', 'São Pedro da Cipa', 'BR.14.5107404', 'ASCII:Sao Pedro Da Cipa;ID:6323871', '11864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11864', '112', '13741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13742', '1079', '1', 'Rondonópolis', 'BR.14.5107602', 'ASCII:Rondonopolis;ID:6323872', '11865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11865', '112', '13742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13743', '1079', '1', 'Rosário Oeste', 'BR.14.5107701', 'ASCII:Rosario Oeste;ID:6323873', '11866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11866', '112', '13743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13744', '1079', '1', 'Salto do Céu', 'BR.14.5107750', 'ASCII:Salto Do Ceu;ID:6323874', '11867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11867', '112', '13744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13745', '1079', '1', 'Santo Antônio do Leverger', 'BR.14.5107800', 'ASCII:Santo Antonio Do Leverger;ID:6323875', '11868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11868', '112', '13745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13746', '1079', '1', 'Sapezal', 'BR.14.5107875', 'ASCII:Sapezal;ID:6323876', '11869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11869', '112', '13746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13747', '1079', '1', 'Sinop', 'BR.14.5107909', 'ASCII:Sinop;ID:6323877', '11870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11870', '112', '13747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13748', '1079', '1', 'Tabaporã', 'BR.14.5107941', 'ASCII:Tabapora;ID:6323878', '11871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11871', '112', '13748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13749', '1079', '1', 'Tangará da Serra', 'BR.14.5107958', 'ASCII:Tangara Da Serra;ID:6323879', '11872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11872', '112', '13749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13750', '1079', '1', 'Tapurah', 'BR.14.5108006', 'ASCII:Tapurah;ID:6323880', '11873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11873', '112', '13750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13751', '1079', '1', 'Terra Nova do Norte', 'BR.14.5108055', 'ASCII:Terra Nova Do Norte;ID:6323881', '11874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11874', '112', '13751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13752', '1079', '1', 'Tesouro', 'BR.14.5108105', 'ASCII:Tesouro;ID:6323882', '11875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11875', '112', '13752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13753', '1079', '1', 'Torixoréu', 'BR.14.5108204', 'ASCII:Torixoreu;ID:6323883', '11876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11876', '112', '13753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13754', '1079', '1', 'União do Sul', 'BR.14.5108303', 'ASCII:Uniao Do Sul;ID:6323884', '11877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11877', '112', '13754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13755', '1079', '1', 'Várzea Grande', 'BR.14.5108402', 'ASCII:Varzea Grande;ID:6323885', '11878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11878', '112', '13755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13756', '1079', '1', 'Vera', 'BR.14.5108501', 'ASCII:Vera;ID:6323886', '11879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11879', '112', '13756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13757', '1079', '1', 'Vila Rica', 'BR.14.5108600', 'ASCII:Vila Rica;ID:6323887', '11880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11880', '112', '13757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13758', '1079', '1', 'Nova Guarita', 'BR.14.5108808', 'ASCII:Nova Guarita;ID:6323888', '11881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11881', '112', '13758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13759', '1079', '1', 'Nova Monte Verde', 'BR.14.5108956', 'ASCII:Nova Monte Verde;ID:6323889', '11882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11882', '112', '13759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13760', '1079', '1', 'Abadia de Goiás', 'BR.29.5200050', 'ASCII:Abadia De Goias;ID:6323890', '11883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11883', '112', '13760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13761', '1079', '1', 'Abadiânia', 'BR.29.5200100', 'ASCII:Abadiania;ID:6323891', '11884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11884', '112', '13761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13762', '1079', '1', 'Acreúna', 'BR.29.5200134', 'ASCII:Acreuna;ID:6323892', '11885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11885', '112', '13762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200134» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13763', '1079', '1', 'Adelândia', 'BR.29.5200159', 'ASCII:Adelandia;ID:6323893', '11886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11886', '112', '13763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13764', '1079', '1', 'Água Limpa', 'BR.29.5200209', 'ASCII:Agua Limpa;ID:6323894', '11887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11887', '112', '13764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13765', '1079', '1', 'Águas Lindas de Goiás', 'BR.29.5200258', 'ASCII:Aguas Lindas De Goias;ID:6323895', '11888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11888', '112', '13765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13766', '1079', '1', 'Alexânia', 'BR.29.5200308', 'ASCII:Alexania;ID:6323896', '11889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11889', '112', '13766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13767', '1079', '1', 'Aloândia', 'BR.29.5200506', 'ASCII:Aloandia;ID:6323897', '11890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11890', '112', '13767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13768', '1079', '1', 'Alto Horizonte', 'BR.29.5200555', 'ASCII:Alto Horizonte;ID:6323898', '11891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11891', '112', '13768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13769', '1079', '1', 'Alvorada do Norte', 'BR.29.5200803', 'ASCII:Alvorada Do Norte;ID:6323899', '11892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11892', '112', '13769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13770', '1079', '1', 'Amaralina', 'BR.29.5200829', 'ASCII:Amaralina;ID:6323900', '11893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11893', '112', '13770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13771', '1079', '1', 'Americano do Brasil', 'BR.29.5200852', 'ASCII:Americano Do Brasil;ID:6323901', '11894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11894', '112', '13771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13772', '1079', '1', 'Amorinópolis', 'BR.29.5200902', 'ASCII:Amorinopolis;ID:6323902', '11895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11895', '112', '13772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5200902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13773', '1079', '1', 'Anhanguera', 'BR.29.5201207', 'ASCII:Anhanguera;ID:6323903', '11896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11896', '112', '13773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5201207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13774', '1079', '1', 'Anicuns', 'BR.29.5201306', 'ASCII:Anicuns;ID:6323904', '11897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11897', '112', '13774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5201306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13775', '1079', '1', 'Aparecida de Goiânia', 'BR.29.5201405', 'ASCII:Aparecida De Goiania;ID:6323905', '11898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11898', '112', '13775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5201405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13776', '1079', '1', 'Aparecida do Rio Doce', 'BR.29.5201454', 'ASCII:Aparecida Do Rio Doce;ID:6323906', '11899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11899', '112', '13776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5201454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13777', '1079', '1', 'Aporé', 'BR.29.5201504', 'ASCII:Apore;ID:6323907', '11900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11900', '112', '13777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5201504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13778', '1079', '1', 'Araçu', 'BR.29.5201603', 'ASCII:Aracu;ID:6323908', '11901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11901', '112', '13778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5201603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13779', '1079', '1', 'Aragarças', 'BR.29.5201702', 'ASCII:Aragarcas;ID:6323909', '11902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11902', '112', '13779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5201702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13780', '1079', '1', 'Aragoiânia', 'BR.29.5201801', 'ASCII:Aragoiania;ID:6323910', '11903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11903', '112', '13780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5201801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13781', '1079', '1', 'Araguapaz', 'BR.29.5202155', 'ASCII:Araguapaz;ID:6323911', '11904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11904', '112', '13781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5202155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13782', '1079', '1', 'Arenópolis', 'BR.29.5202353', 'ASCII:Arenopolis;ID:6323912', '11905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11905', '112', '13782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5202353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13783', '1079', '1', 'Aruanã', 'BR.29.5202502', 'ASCII:Aruana;ID:6323913', '11906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11906', '112', '13783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5202502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13784', '1079', '1', 'Avelinópolis', 'BR.29.5202809', 'ASCII:Avelinopolis;ID:6323914', '11907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11907', '112', '13784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5202809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13785', '1079', '1', 'Barro Alto', 'BR.29.5203203', 'ASCII:Barro Alto;ID:6323915', '11908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11908', '112', '13785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13786', '1079', '1', 'Bela Vista de Goiás', 'BR.29.5203302', 'ASCII:Bela Vista De Goias;ID:6323916', '11909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11909', '112', '13786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13787', '1079', '1', 'Bom Jardim de Goiás', 'BR.29.5203401', 'ASCII:Bom Jardim De Goias;ID:6323917', '11910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11910', '112', '13787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13788', '1079', '1', 'Bom Jesus de Goiás', 'BR.29.5203500', 'ASCII:Bom Jesus De Goias;ID:6323918', '11911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11911', '112', '13788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13789', '1079', '1', 'Bonfinópolis', 'BR.29.5203559', 'ASCII:Bonfinopolis;ID:6323919', '11912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11912', '112', '13789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13790', '1079', '1', 'Bonópolis', 'BR.29.5203575', 'ASCII:Bonopolis;ID:6323920', '11913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11913', '112', '13790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13791', '1079', '1', 'Brazabrantes', 'BR.29.5203609', 'ASCII:Brazabrantes;ID:6323921', '11914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11914', '112', '13791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13792', '1079', '1', 'Britânia', 'BR.29.5203807', 'ASCII:Britania;ID:6323922', '11915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11915', '112', '13792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13793', '1079', '1', 'Buriti Alegre', 'BR.29.5203906', 'ASCII:Buriti Alegre;ID:6323923', '11916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11916', '112', '13793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13794', '1079', '1', 'Buriti de Goiás', 'BR.29.5203939', 'ASCII:Buriti De Goias;ID:6323924', '11917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11917', '112', '13794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13795', '1079', '1', 'Buritinópolis', 'BR.29.5203962', 'ASCII:Buritinopolis;ID:6323925', '11918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11918', '112', '13795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5203962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13796', '1079', '1', 'Cabeceiras', 'BR.29.5204003', 'ASCII:Cabeceiras;ID:6323926', '11919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11919', '112', '13796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13797', '1079', '1', 'Cachoeira Alta', 'BR.29.5204102', 'ASCII:Cachoeira Alta;ID:6323927', '11920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11920', '112', '13797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13798', '1079', '1', 'Cachoeira de Goiás', 'BR.29.5204201', 'ASCII:Cachoeira De Goias;ID:6323928', '11921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11921', '112', '13798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13799', '1079', '1', 'Cachoeira Dourada', 'BR.29.5204250', 'ASCII:Cachoeira Dourada;ID:6323929', '11922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11922', '112', '13799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13800', '1079', '1', 'Caçu', 'BR.29.5204300', 'ASCII:Cacu;ID:6323930', '11923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11923', '112', '13800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13801', '1079', '1', 'Caiapônia', 'BR.29.5204409', 'ASCII:Caiaponia;ID:6323931', '11924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11924', '112', '13801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13802', '1079', '1', 'Caldas Novas', 'BR.29.5204508', 'ASCII:Caldas Novas;ID:6323932', '11925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11925', '112', '13802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13803', '1079', '1', 'Caldazinha', 'BR.29.5204557', 'ASCII:Caldazinha;ID:6323933', '11926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11926', '112', '13803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13804', '1079', '1', 'Campestre de Goiás', 'BR.29.5204607', 'ASCII:Campestre De Goias;ID:6323934', '11927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11927', '112', '13804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13805', '1079', '1', 'Campinaçu', 'BR.29.5204656', 'ASCII:Campinacu;ID:6323935', '11928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11928', '112', '13805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13806', '1079', '1', 'Campinorte', 'BR.29.5204706', 'ASCII:Campinorte;ID:6323936', '11929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11929', '112', '13806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13807', '1079', '1', 'Campo Alegre de Goiás', 'BR.29.5204805', 'ASCII:Campo Alegre De Goias;ID:6323937', '11930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11930', '112', '13807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13808', '1079', '1', 'Campos Belos', 'BR.29.5204904', 'ASCII:Campos Belos;ID:6323938', '11931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11931', '112', '13808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13809', '1079', '1', 'Campos Verdes', 'BR.29.5204953', 'ASCII:Campos Verdes;ID:6323939', '11932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11932', '112', '13809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13810', '1079', '1', 'Carmo do Rio Verde', 'BR.29.5205000', 'ASCII:Carmo Do Rio Verde;ID:6323940', '11933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11933', '112', '13810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13811', '1079', '1', 'Castelândia', 'BR.29.5205059', 'ASCII:Castelandia;ID:6323941', '11934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11934', '112', '13811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13812', '1079', '1', 'Catalão', 'BR.29.5205109', 'ASCII:Catalao;ID:6323942', '11935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11935', '112', '13812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13813', '1079', '1', 'Caturaí', 'BR.29.5205208', 'ASCII:Caturai;ID:6323943', '11936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11936', '112', '13813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13814', '1079', '1', 'Cavalcante', 'BR.29.5205307', 'ASCII:Cavalcante;ID:6323944', '11937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11937', '112', '13814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13815', '1079', '1', 'Cezarina', 'BR.29.5205455', 'ASCII:Cezarina;ID:6323945', '11938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11938', '112', '13815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13816', '1079', '1', 'Cidade Ocidental', 'BR.29.5205497', 'ASCII:Cidade Ocidental;ID:6323946', '11939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11939', '112', '13816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13817', '1079', '1', 'Cocalzinho de Goiás', 'BR.29.5205513', 'ASCII:Cocalzinho De Goias;ID:6323947', '11940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11940', '112', '13817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13818', '1079', '1', 'Colinas do Sul', 'BR.29.5205521', 'ASCII:Colinas Do Sul;ID:6323948', '11941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11941', '112', '13818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13819', '1079', '1', 'Córrego do Ouro', 'BR.29.5205703', 'ASCII:Corrego Do Ouro;ID:6323949', '11942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11942', '112', '13819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13820', '1079', '1', 'Corumbá de Goiás', 'BR.29.5205802', 'ASCII:Corumba De Goias;ID:6323950', '11943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11943', '112', '13820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13821', '1079', '1', 'Corumbaíba', 'BR.29.5205901', 'ASCII:Corumbaiba;ID:6323951', '11944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11944', '112', '13821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13822', '1079', '1', 'Cristalina', 'BR.29.5206206', 'ASCII:Cristalina;ID:6323952', '11945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11945', '112', '13822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5206206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13823', '1079', '1', 'Cristianópolis', 'BR.29.5206305', 'ASCII:Cristianopolis;ID:6323953', '11946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11946', '112', '13823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5206305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13824', '1079', '1', 'Crixás', 'BR.29.5206404', 'ASCII:Crixas;ID:6323954', '11947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11947', '112', '13824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5206404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13825', '1079', '1', 'Cromínia', 'BR.29.5206503', 'ASCII:Crominia;ID:6323955', '11948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11948', '112', '13825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5206503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13826', '1079', '1', 'Cumari', 'BR.29.5206602', 'ASCII:Cumari;ID:6323956', '11949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11949', '112', '13826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5206602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13827', '1079', '1', 'Damianópolis', 'BR.29.5206701', 'ASCII:Damianopolis;ID:6323957', '11950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11950', '112', '13827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5206701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13828', '1079', '1', 'Damolândia', 'BR.29.5206800', 'ASCII:Damolandia;ID:6323958', '11951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11951', '112', '13828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5206800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13829', '1079', '1', 'Davinópolis', 'BR.29.5206909', 'ASCII:Davinopolis;ID:6323959', '11952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11952', '112', '13829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5206909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13830', '1079', '1', 'Diorama', 'BR.29.5207105', 'ASCII:Diorama;ID:6323960', '11953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11953', '112', '13830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5207105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13831', '1079', '1', 'Doverlândia', 'BR.29.5207253', 'ASCII:Doverlandia;ID:6323961', '11954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11954', '112', '13831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5207253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13832', '1079', '1', 'Edealina', 'BR.29.5207352', 'ASCII:Edealina;ID:6323962', '11955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11955', '112', '13832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5207352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13833', '1079', '1', 'Edéia', 'BR.29.5207402', 'ASCII:Edeia;ID:6323963', '11956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11956', '112', '13833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5207402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13834', '1079', '1', 'Estrela do Norte', 'BR.29.5207501', 'ASCII:Estrela Do Norte;ID:6323964', '11957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11957', '112', '13834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5207501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13835', '1079', '1', 'Faina', 'BR.29.5207535', 'ASCII:Faina;ID:6323965', '11958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11958', '112', '13835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5207535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13836', '1079', '1', 'Fazenda Nova', 'BR.29.5207600', 'ASCII:Fazenda Nova;ID:6323966', '11959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11959', '112', '13836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5207600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13837', '1079', '1', 'Firminópolis', 'BR.29.5207808', 'ASCII:Firminopolis;ID:6323967', '11960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11960', '112', '13837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5207808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13838', '1079', '1', 'Flores de Goiás', 'BR.29.5207907', 'ASCII:Flores De Goias;ID:6323968', '11961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11961', '112', '13838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5207907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13839', '1079', '1', 'Formosa', 'BR.29.5208004', 'ASCII:Formosa;ID:6323969', '11962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11962', '112', '13839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5208004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13840', '1079', '1', 'Formoso', 'BR.29.5208103', 'ASCII:Formoso;ID:6323970', '11963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11963', '112', '13840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5208103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13841', '1079', '1', 'Goianápolis', 'BR.29.5208400', 'ASCII:Goianapolis;ID:6323971', '11964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11964', '112', '13841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5208400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13842', '1079', '1', 'Goiandira', 'BR.29.5208509', 'ASCII:Goiandira;ID:6323972', '11965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11965', '112', '13842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5208509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13843', '1079', '1', 'Goianésia', 'BR.29.5208608', 'ASCII:Goianesia;ID:6323973', '11966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11966', '112', '13843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5208608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13844', '1079', '1', 'Goiânia', 'BR.29.5208707', 'ASCII:Goiania;ID:6323974', '11967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11967', '112', '13844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5208707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13845', '1079', '1', 'Goianira', 'BR.29.5208806', 'ASCII:Goianira;ID:6323975', '11968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11968', '112', '13845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5208806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13846', '1079', '1', 'Goiás', 'BR.29.5208905', 'ASCII:Goias;ID:6323976', '11969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11969', '112', '13846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5208905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13847', '1079', '1', 'Goiatuba', 'BR.29.5209101', 'ASCII:Goiatuba;ID:6323977', '11970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11970', '112', '13847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13848', '1079', '1', 'Gouvelândia', 'BR.29.5209150', 'ASCII:Gouvelandia;ID:6323978', '11971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11971', '112', '13848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13849', '1079', '1', 'Guapó', 'BR.29.5209200', 'ASCII:Guapo;ID:6323979', '11972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11972', '112', '13849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13850', '1079', '1', 'Guaraíta', 'BR.29.5209291', 'ASCII:Guaraita;ID:6323980', '11973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11973', '112', '13850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13851', '1079', '1', 'Guarani de Goiás', 'BR.29.5209408', 'ASCII:Guarani De Goias;ID:6323981', '11974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11974', '112', '13851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13852', '1079', '1', 'Guarinos', 'BR.29.5209457', 'ASCII:Guarinos;ID:6323982', '11975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11975', '112', '13852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13853', '1079', '1', 'Heitoraí', 'BR.29.5209606', 'ASCII:Heitorai;ID:6323983', '11976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11976', '112', '13853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13854', '1079', '1', 'Hidrolândia', 'BR.29.5209705', 'ASCII:Hidrolandia;ID:6323984', '11977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11977', '112', '13854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13855', '1079', '1', 'Hidrolina', 'BR.29.5209804', 'ASCII:Hidrolina;ID:6323985', '11978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11978', '112', '13855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13856', '1079', '1', 'Iaciara', 'BR.29.5209903', 'ASCII:Iaciara;ID:6323986', '11979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11979', '112', '13856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13857', '1079', '1', 'Inaciolândia', 'BR.29.5209937', 'ASCII:Inaciolandia;ID:6323987', '11980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11980', '112', '13857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13858', '1079', '1', 'Indiara', 'BR.29.5209952', 'ASCII:Indiara;ID:6323988', '11981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11981', '112', '13858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5209952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13859', '1079', '1', 'Inhumas', 'BR.29.5210000', 'ASCII:Inhumas;ID:6323989', '11982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11982', '112', '13859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5210000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13860', '1079', '1', 'Ipameri', 'BR.29.5210109', 'ASCII:Ipameri;ID:6323990', '11983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11983', '112', '13860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5210109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13861', '1079', '1', 'Iporá', 'BR.29.5210208', 'ASCII:Ipora;ID:6323991', '11984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11984', '112', '13861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5210208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13862', '1079', '1', 'Israelândia', 'BR.29.5210307', 'ASCII:Israelandia;ID:6323992', '11985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11985', '112', '13862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5210307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13863', '1079', '1', 'Itaberaí', 'BR.29.5210406', 'ASCII:Itaberai;ID:6323993', '11986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11986', '112', '13863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5210406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13864', '1079', '1', 'Itaguari', 'BR.29.5210562', 'ASCII:Itaguari;ID:6323994', '11987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11987', '112', '13864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5210562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13865', '1079', '1', 'Itaguaru', 'BR.29.5210604', 'ASCII:Itaguaru;ID:6323995', '11988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11988', '112', '13865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5210604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13866', '1079', '1', 'Itapaci', 'BR.29.5210901', 'ASCII:Itapaci;ID:6323996', '11989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11989', '112', '13866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5210901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13867', '1079', '1', 'Itapirapuã', 'BR.29.5211008', 'ASCII:Itapirapua;ID:6323997', '11990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11990', '112', '13867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5211008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13868', '1079', '1', 'Itapuranga', 'BR.29.5211206', 'ASCII:Itapuranga;ID:6323998', '11991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11991', '112', '13868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5211206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13869', '1079', '1', 'Itarumã', 'BR.29.5211305', 'ASCII:Itaruma;ID:6323999', '11992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11992', '112', '13869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5211305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13870', '1079', '1', 'Itauçu', 'BR.29.5211404', 'ASCII:Itaucu;ID:6324000', '11993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11993', '112', '13870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5211404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13871', '1079', '1', 'Itumbiara', 'BR.29.5211503', 'ASCII:Itumbiara;ID:6324001', '11994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11994', '112', '13871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5211503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13872', '1079', '1', 'Ivolândia', 'BR.29.5211602', 'ASCII:Ivolandia;ID:6324002', '11995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11995', '112', '13872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5211602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13873', '1079', '1', 'Jandaia', 'BR.29.5211701', 'ASCII:Jandaia;ID:6324003', '11996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11996', '112', '13873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5211701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13874', '1079', '1', 'Jaraguá', 'BR.29.5211800', 'ASCII:Jaragua;ID:6324004', '11997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11997', '112', '13874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5211800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13875', '1079', '1', 'Jataí', 'BR.29.5211909', 'ASCII:Jatai;ID:6324005', '11998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11998', '112', '13875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5211909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13876', '1079', '1', 'Jaupaci', 'BR.29.5212006', 'ASCII:Jaupaci;ID:6324006', '11999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('11999', '112', '13876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13877', '1079', '1', 'Jesúpolis', 'BR.29.5212055', 'ASCII:Jesupolis;ID:6324007', '12000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12000', '112', '13877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13878', '1079', '1', 'Joviânia', 'BR.29.5212105', 'ASCII:Joviania;ID:6324008', '12001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12001', '112', '13878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13879', '1079', '1', 'Jussara', 'BR.29.5212204', 'ASCII:Jussara;ID:6324009', '12002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12002', '112', '13879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13880', '1079', '1', 'Leopoldo de Bulhões', 'BR.29.5212303', 'ASCII:Leopoldo De Bulhoes;ID:6324010', '12003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12003', '112', '13880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13881', '1079', '1', 'Luziânia', 'BR.29.5212501', 'ASCII:Luziania;ID:6324011', '12004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12004', '112', '13881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13882', '1079', '1', 'Mairipotaba', 'BR.29.5212600', 'ASCII:Mairipotaba;ID:6324012', '12005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12005', '112', '13882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13883', '1079', '1', 'Mambaí', 'BR.29.5212709', 'ASCII:Mambai;ID:6324013', '12006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12006', '112', '13883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13884', '1079', '1', 'Mara Rosa', 'BR.29.5212808', 'ASCII:Mara Rosa;ID:6324014', '12007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12007', '112', '13884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13885', '1079', '1', 'Marzagão', 'BR.29.5212907', 'ASCII:Marzagao;ID:6324015', '12008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12008', '112', '13885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13886', '1079', '1', 'Matrinchã', 'BR.29.5212956', 'ASCII:Matrincha;ID:6324016', '12009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12009', '112', '13886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13887', '1079', '1', 'Maurilândia', 'BR.29.5213004', 'ASCII:Maurilandia;ID:6324017', '12010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12010', '112', '13887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13888', '1079', '1', 'Mimoso de Goiás', 'BR.29.5213053', 'ASCII:Mimoso De Goias;ID:6324018', '12011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12011', '112', '13888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13889', '1079', '1', 'Minaçu', 'BR.29.5213087', 'ASCII:Minacu;ID:6324019', '12012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12012', '112', '13889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13890', '1079', '1', 'Mineiros', 'BR.29.5213103', 'ASCII:Mineiros;ID:6324020', '12013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12013', '112', '13890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13891', '1079', '1', 'Moiporá', 'BR.29.5213400', 'ASCII:Moipora;ID:6324021', '12014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12014', '112', '13891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13892', '1079', '1', 'Monte Alegre de Goiás', 'BR.29.5213509', 'ASCII:Monte Alegre De Goias;ID:6324022', '12015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12015', '112', '13892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13893', '1079', '1', 'Montes Claros de Goiás', 'BR.29.5213707', 'ASCII:Montes Claros De Goias;ID:6324023', '12016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12016', '112', '13893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13894', '1079', '1', 'Montividiu', 'BR.29.5213756', 'ASCII:Montividiu;ID:6324024', '12017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12017', '112', '13894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13895', '1079', '1', 'Montividiu do Norte', 'BR.29.5213772', 'ASCII:Montividiu Do Norte;ID:6324025', '12018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12018', '112', '13895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13896', '1079', '1', 'Morrinhos', 'BR.29.5213806', 'ASCII:Morrinhos;ID:6324026', '12019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12019', '112', '13896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13897', '1079', '1', 'Morro Agudo de Goiás', 'BR.29.5213855', 'ASCII:Morro Agudo De Goias;ID:6324027', '12020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12020', '112', '13897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13898', '1079', '1', 'Mossâmedes', 'BR.29.5213905', 'ASCII:Mossamedes;ID:6324028', '12021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12021', '112', '13898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5213905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13899', '1079', '1', 'Mozarlândia', 'BR.29.5214002', 'ASCII:Mozarlandia;ID:6324029', '12022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12022', '112', '13899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13900', '1079', '1', 'Mundo Novo', 'BR.29.5214051', 'ASCII:Mundo Novo;ID:6324030', '12023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12023', '112', '13900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13901', '1079', '1', 'Mutunópolis', 'BR.29.5214101', 'ASCII:Mutunopolis;ID:6324031', '12024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12024', '112', '13901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13902', '1079', '1', 'Nazário', 'BR.29.5214408', 'ASCII:Nazario;ID:6324032', '12025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12025', '112', '13902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13903', '1079', '1', 'Nerópolis', 'BR.29.5214507', 'ASCII:Neropolis;ID:6324033', '12026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12026', '112', '13903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13904', '1079', '1', 'Niquelândia', 'BR.29.5214606', 'ASCII:Niquelandia;ID:6324034', '12027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12027', '112', '13904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13905', '1079', '1', 'Nova América', 'BR.29.5214705', 'ASCII:Nova America;ID:6324035', '12028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12028', '112', '13905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13906', '1079', '1', 'Nova Aurora', 'BR.29.5214804', 'ASCII:Nova Aurora;ID:6324036', '12029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12029', '112', '13906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13907', '1079', '1', 'Nova Crixás', 'BR.29.5214838', 'ASCII:Nova Crixas;ID:6324037', '12030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12030', '112', '13907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13908', '1079', '1', 'Nova Glória', 'BR.29.5214861', 'ASCII:Nova Gloria;ID:6324038', '12031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12031', '112', '13908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13909', '1079', '1', 'Nova Iguaçu de Goiás', 'BR.29.5214879', 'ASCII:Nova Iguacu De Goias;ID:6324039', '12032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12032', '112', '13909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13910', '1079', '1', 'Nova Roma', 'BR.29.5214903', 'ASCII:Nova Roma;ID:6324040', '12033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12033', '112', '13910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5214903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13911', '1079', '1', 'Nova Veneza', 'BR.29.5215009', 'ASCII:Nova Veneza;ID:6324041', '12034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12034', '112', '13911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13912', '1079', '1', 'Novo Brasil', 'BR.29.5215207', 'ASCII:Novo Brasil;ID:6324042', '12035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12035', '112', '13912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13913', '1079', '1', 'Novo Gama', 'BR.29.5215231', 'ASCII:Novo Gama;ID:6324043', '12036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12036', '112', '13913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13914', '1079', '1', 'Novo Planalto', 'BR.29.5215256', 'ASCII:Novo Planalto;ID:6324044', '12037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12037', '112', '13914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13915', '1079', '1', 'Orizona', 'BR.29.5215306', 'ASCII:Orizona;ID:6324045', '12038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12038', '112', '13915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13916', '1079', '1', 'Ouro Verde de Goiás', 'BR.29.5215405', 'ASCII:Ouro Verde De Goias;ID:6324046', '12039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12039', '112', '13916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13917', '1079', '1', 'Ouvidor', 'BR.29.5215504', 'ASCII:Ouvidor;ID:6324047', '12040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12040', '112', '13917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13918', '1079', '1', 'Padre Bernardo', 'BR.29.5215603', 'ASCII:Padre Bernardo;ID:6324048', '12041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12041', '112', '13918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13919', '1079', '1', 'Palestina de Goiás', 'BR.29.5215652', 'ASCII:Palestina De Goias;ID:6324049', '12042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12042', '112', '13919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13920', '1079', '1', 'Palmeiras de Goiás', 'BR.29.5215702', 'ASCII:Palmeiras De Goias;ID:6324050', '12043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12043', '112', '13920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13921', '1079', '1', 'Palmelo', 'BR.29.5215801', 'ASCII:Palmelo;ID:6324051', '12044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12044', '112', '13921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13922', '1079', '1', 'Palminópolis', 'BR.29.5215900', 'ASCII:Palminopolis;ID:6324052', '12045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12045', '112', '13922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5215900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13923', '1079', '1', 'Panamá', 'BR.29.5216007', 'ASCII:Panama;ID:6324053', '12046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12046', '112', '13923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5216007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13924', '1079', '1', 'Paranaiguara', 'BR.29.5216304', 'ASCII:Paranaiguara;ID:6324054', '12047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12047', '112', '13924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5216304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13925', '1079', '1', 'Paraúna', 'BR.29.5216403', 'ASCII:Parauna;ID:6324055', '12048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12048', '112', '13925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5216403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13926', '1079', '1', 'Perolândia', 'BR.29.5216452', 'ASCII:Perolandia;ID:6324056', '12049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12049', '112', '13926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5216452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13927', '1079', '1', 'Petrolina de Goiás', 'BR.29.5216809', 'ASCII:Petrolina De Goias;ID:6324057', '12050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12050', '112', '13927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5216809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13928', '1079', '1', 'Pilar de Goiás', 'BR.29.5216908', 'ASCII:Pilar De Goias;ID:6324058', '12051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12051', '112', '13928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5216908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13929', '1079', '1', 'Piracanjuba', 'BR.29.5217104', 'ASCII:Piracanjuba;ID:6324059', '12052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12052', '112', '13929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5217104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13930', '1079', '1', 'Pirenópolis', 'BR.29.5217302', 'ASCII:Pirenopolis;ID:6324060', '12053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12053', '112', '13930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5217302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13931', '1079', '1', 'Pires do Rio', 'BR.29.5217401', 'ASCII:Pires Do Rio;ID:6324061', '12054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12054', '112', '13931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5217401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13932', '1079', '1', 'Planaltina', 'BR.29.5217609', 'ASCII:Planaltina;ID:6324062', '12055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12055', '112', '13932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5217609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13933', '1079', '1', 'Pontalina', 'BR.29.5217708', 'ASCII:Pontalina;ID:6324063', '12056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12056', '112', '13933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5217708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13934', '1079', '1', 'Porangatu', 'BR.29.5218003', 'ASCII:Porangatu;ID:6324064', '12057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12057', '112', '13934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13935', '1079', '1', 'Porteirão', 'BR.29.5218052', 'ASCII:Porteirao;ID:6324065', '12058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12058', '112', '13935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13936', '1079', '1', 'Portelândia', 'BR.29.5218102', 'ASCII:Portelandia;ID:6324066', '12059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12059', '112', '13936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13937', '1079', '1', 'Posse', 'BR.29.5218300', 'ASCII:Posse;ID:6324067', '12060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12060', '112', '13937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13938', '1079', '1', 'Professor Jamil', 'BR.29.5218391', 'ASCII:Professor Jamil;ID:6324068', '12061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12061', '112', '13938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13939', '1079', '1', 'Quirinópolis', 'BR.29.5218508', 'ASCII:Quirinopolis;ID:6324069', '12062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12062', '112', '13939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13940', '1079', '1', 'Rialma', 'BR.29.5218607', 'ASCII:Rialma;ID:6324070', '12063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12063', '112', '13940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13941', '1079', '1', 'Rianápolis', 'BR.29.5218706', 'ASCII:Rianapolis;ID:6324071', '12064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12064', '112', '13941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13942', '1079', '1', 'Rio Quente', 'BR.29.5218789', 'ASCII:Rio Quente;ID:6324072', '12065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12065', '112', '13942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13943', '1079', '1', 'Rio Verde', 'BR.29.5218805', 'ASCII:Rio Verde;ID:6324073', '12066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12066', '112', '13943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13944', '1079', '1', 'Rubiataba', 'BR.29.5218904', 'ASCII:Rubiataba;ID:6324074', '12067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12067', '112', '13944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5218904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13945', '1079', '1', 'Sanclerlândia', 'BR.29.5219001', 'ASCII:Sanclerlandia;ID:6324075', '12068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12068', '112', '13945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13946', '1079', '1', 'Santa Cruz de Goiás', 'BR.29.5219209', 'ASCII:Santa Cruz De Goias;ID:6324076', '12069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12069', '112', '13946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13947', '1079', '1', 'Santa Fé de Goiás', 'BR.29.5219258', 'ASCII:Santa Fe De Goias;ID:6324077', '12070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12070', '112', '13947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13948', '1079', '1', 'Santa Helena de Goiás', 'BR.29.5219308', 'ASCII:Santa Helena De Goias;ID:6324078', '12071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12071', '112', '13948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13949', '1079', '1', 'Santa Isabel', 'BR.29.5219357', 'ASCII:Santa Isabel;ID:6324079', '12072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12072', '112', '13949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13950', '1079', '1', 'Santa Rita do Araguaia', 'BR.29.5219407', 'ASCII:Santa Rita Do Araguaia;ID:6324080', '12073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12073', '112', '13950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13951', '1079', '1', 'Santa Rita do Novo Destino', 'BR.29.5219456', 'ASCII:Santa Rita Do Novo Destino;ID:6324081', '12074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12074', '112', '13951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13952', '1079', '1', 'Santa Rosa de Goiás', 'BR.29.5219506', 'ASCII:Santa Rosa De Goias;ID:6324082', '12075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12075', '112', '13952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13953', '1079', '1', 'Santa Tereza de Goiás', 'BR.29.5219605', 'ASCII:Santa Tereza De Goias;ID:6324083', '12076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12076', '112', '13953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13954', '1079', '1', 'Santa Terezinha de Goiás', 'BR.29.5219704', 'ASCII:Santa Terezinha De Goias;ID:6324084', '12077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12077', '112', '13954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13955', '1079', '1', 'Santo Antônio da Barra', 'BR.29.5219712', 'ASCII:Santo Antonio Da Barra;ID:6324085', '12078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12078', '112', '13955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13956', '1079', '1', 'Santo Antônio de Goiás', 'BR.29.5219738', 'ASCII:Santo Antonio De Goias;ID:6324086', '12079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12079', '112', '13956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5219738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13957', '1079', '1', 'São João d''Aliança', 'BR.29.5220009', 'ASCII:Sao Joao D''Alianca;ID:6324087', '12080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12080', '112', '13957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13958', '1079', '1', 'São João da Paraúna', 'BR.29.5220058', 'ASCII:Sao Joao Da Parauna;ID:6324088', '12081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12081', '112', '13958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13959', '1079', '1', 'São Luís de Montes Belos', 'BR.29.5220108', 'ASCII:Sao Luis De Montes Belos;ID:6324089', '12082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12082', '112', '13959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13960', '1079', '1', 'São Luíz do Norte', 'BR.29.5220157', 'ASCII:Sao Luiz Do Norte;ID:6324090', '12083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12083', '112', '13960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13961', '1079', '1', 'São Miguel do Araguaia', 'BR.29.5220207', 'ASCII:Sao Miguel Do Araguaia;ID:6324091', '12084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12084', '112', '13961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13962', '1079', '1', 'São Miguel do Passa Quatro', 'BR.29.5220264', 'ASCII:Sao Miguel Do Passa Quatro;ID:6324092', '12085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12085', '112', '13962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13963', '1079', '1', 'São Patrício', 'BR.29.5220280', 'ASCII:Sao Patricio;ID:6324093', '12086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12086', '112', '13963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13964', '1079', '1', 'São Simão', 'BR.29.5220405', 'ASCII:Sao Simao;ID:6324094', '12087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12087', '112', '13964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13965', '1079', '1', 'Sítio d''Abadia', 'BR.29.5220702', 'ASCII:Sitio D''Abadia;ID:6324095', '12088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12088', '112', '13965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13966', '1079', '1', 'Taquaral de Goiás', 'BR.29.5221007', 'ASCII:Taquaral De Goias;ID:6324096', '12089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12089', '112', '13966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13967', '1079', '1', 'Teresina de Goiás', 'BR.29.5221080', 'ASCII:Teresina De Goias;ID:6324097', '12090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12090', '112', '13967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13968', '1079', '1', 'Terezópolis de Goiás', 'BR.29.5221197', 'ASCII:Terezopolis De Goias;ID:6324098', '12091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12091', '112', '13968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13969', '1079', '1', 'Três Ranchos', 'BR.29.5221304', 'ASCII:Tres Ranchos;ID:6324099', '12092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12092', '112', '13969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13970', '1079', '1', 'Trindade', 'BR.29.5221403', 'ASCII:Trindade;ID:6324100', '12093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12093', '112', '13970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13971', '1079', '1', 'Trombas', 'BR.29.5221452', 'ASCII:Trombas;ID:6324101', '12094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12094', '112', '13971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13972', '1079', '1', 'Turvânia', 'BR.29.5221502', 'ASCII:Turvania;ID:6324102', '12095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12095', '112', '13972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13973', '1079', '1', 'Turvelândia', 'BR.29.5221551', 'ASCII:Turvelandia;ID:6324103', '12096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12096', '112', '13973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13974', '1079', '1', 'Uirapuru', 'BR.29.5221577', 'ASCII:Uirapuru;ID:6324104', '12097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12097', '112', '13974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13975', '1079', '1', 'Uruaçu', 'BR.29.5221601', 'ASCII:Uruacu;ID:6324105', '12098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12098', '112', '13975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13976', '1079', '1', 'Uruana', 'BR.29.5221700', 'ASCII:Uruana;ID:6324106', '12099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12099', '112', '13976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13977', '1079', '1', 'Urutaí', 'BR.29.5221809', 'ASCII:Urutai;ID:6324107', '12100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12100', '112', '13977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13978', '1079', '1', 'Valparaíso de Goiás', 'BR.29.5221858', 'ASCII:Valparaiso De Goias;ID:6324108', '12101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12101', '112', '13978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13979', '1079', '1', 'Varjão', 'BR.29.5221908', 'ASCII:Varjao;ID:6324109', '12102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12102', '112', '13979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5221908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13980', '1079', '1', 'Vianópolis', 'BR.29.5222005', 'ASCII:Vianopolis;ID:6324110', '12103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12103', '112', '13980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5222005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13981', '1079', '1', 'Vicentinópolis', 'BR.29.5222054', 'ASCII:Vicentinopolis;ID:6324111', '12104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12104', '112', '13981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5222054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13982', '1079', '1', 'Vila Boa', 'BR.29.5222203', 'ASCII:Vila Boa;ID:6324112', '12105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12105', '112', '13982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5222203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13983', '1079', '1', 'Vila Propício', 'BR.29.5222302', 'ASCII:Vila Propicio;ID:6324113', '12106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12106', '112', '13983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5222302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13984', '1079', '1', 'Novo Xingu', 'BR.23.4313466', 'ASCII:Novo Xingu;ID:6324114', '12107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12107', '112', '13984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13985', '1079', '1', 'Constantina', 'BR.23.4305801', 'ASCII:Constantina;ID:6324115', '12108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12108', '112', '13985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4305801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13986', '1079', '1', 'Barão de Cotegipe', 'BR.23.4301701', 'ASCII:Barao De Cotegipe;ID:6324116', '12109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12109', '112', '13986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13987', '1079', '1', 'Arroio do Padre', 'BR.23.4301073', 'ASCII:Arroio Do Padre;ID:6324117', '12110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12110', '112', '13987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13988', '1079', '1', 'Bagé', 'BR.23.4301602', 'ASCII:Bage;ID:6324118', '12111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12111', '112', '13988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13989', '1079', '1', 'Pedras Altas', 'BR.23.4314175', 'ASCII:Pedras Altas;ID:6324119', '12112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12112', '112', '13989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13990', '1079', '1', 'Pinheiro Machado', 'BR.23.4314506', 'ASCII:Pinheiro Machado;ID:6324120', '12113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12113', '112', '13990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13991', '1079', '1', 'Augusto Pestana', 'BR.23.4301503', 'ASCII:Augusto Pestana;ID:6324121', '12114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12114', '112', '13991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13992', '1079', '1', 'Ijuí', 'BR.23.4310207', 'ASCII:Ijui;ID:6324122', '12115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12115', '112', '13992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13993', '1079', '1', 'Boa Vista do Cadeado', 'BR.23.4302220', 'ASCII:Boa Vista Do Cadeado;ID:6324123', '12116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12116', '112', '13993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302220» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13994', '1079', '1', 'Bozano', 'BR.23.4302584', 'ASCII:Bozano;ID:6324124', '12117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12117', '112', '13994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13995', '1079', '1', 'Cruz Alta', 'BR.23.4306106', 'ASCII:Cruz Alta;ID:6324125', '12118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12118', '112', '13995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4306106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13996', '1079', '1', 'Fortaleza dos Valos', 'BR.23.4308458', 'ASCII:Fortaleza Dos Valos;ID:6324126', '12119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12119', '112', '13996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4308458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13997', '1079', '1', 'Boa Vista do Incra', 'BR.23.4302238', 'ASCII:Boa Vista Do Incra;ID:6324127', '12120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12120', '112', '13997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4302238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13998', '1079', '1', 'Salto do Jacuí', 'BR.23.4316451', 'ASCII:Salto Do Jacui;ID:6324128', '12121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12121', '112', '13998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('13999', '1079', '1', 'Jacuizinho', 'BR.23.4310876', 'ASCII:Jacuizinho;ID:6324129', '12122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12122', '112', '13999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14000', '1079', '1', 'Espumoso', 'BR.23.4307500', 'ASCII:Espumoso;ID:6324130', '12123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12123', '112', '14000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14001', '1079', '1', 'Victor Graeff', 'BR.23.4323200', 'ASCII:Victor Graeff;ID:6324131', '12124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12124', '112', '14001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4323200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14002', '1079', '1', 'Tio Hugo', 'BR.23.4321469', 'ASCII:Tio Hugo;ID:6324132', '12125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12125', '112', '14002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4321469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14003', '1079', '1', 'Ibirapuitã', 'BR.23.4309951', 'ASCII:Ibirapuita;ID:6324133', '12126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12126', '112', '14003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14004', '1079', '1', 'Ernestina', 'BR.23.4307054', 'ASCII:Ernestina;ID:6324134', '12127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12127', '112', '14004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14005', '1079', '1', 'Água Santa', 'BR.23.4300059', 'ASCII:Agua Santa;ID:6324135', '12128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12128', '112', '14005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14006', '1079', '1', 'Tapejara', 'BR.23.4320909', 'ASCII:Tapejara;ID:6324136', '12129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12129', '112', '14006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4320909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14007', '1079', '1', 'Caseiros', 'BR.23.4304952', 'ASCII:Caseiros;ID:6324137', '12130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12130', '112', '14007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14008', '1079', '1', 'Santa Cecília do Sul', 'BR.23.4316733', 'ASCII:Santa Cecilia Do Sul;ID:6324138', '12131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12131', '112', '14008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14009', '1079', '1', 'Ibiaçá', 'BR.23.4309803', 'ASCII:Ibiaca;ID:6324139', '12132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12132', '112', '14009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4309803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14010', '1079', '1', 'Esmeralda', 'BR.23.4307401', 'ASCII:Esmeralda;ID:6324140', '12133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12133', '112', '14010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4307401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14011', '1079', '1', 'Pinhal da Serra', 'BR.23.4314464', 'ASCII:Pinhal Da Serra;ID:6324141', '12134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12134', '112', '14011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4314464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14012', '1079', '1', 'Rondolândia', 'BR.14.5107578', 'ASCII:Rondolandia;ID:6324142', '12135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12135', '112', '14012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14013', '1079', '1', 'Aripuanã', 'BR.14.5101407', 'ASCII:Aripuana;ID:6324143', '12136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12136', '112', '14013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5101407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14014', '1079', '1', 'Colniza', 'BR.14.5103254', 'ASCII:Colniza;ID:6324144', '12137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12137', '112', '14014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14015', '1079', '1', 'Pontes e Lacerda', 'BR.14.5106752', 'ASCII:Pontes E Lacerda;ID:6324145', '12138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12138', '112', '14015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14016', '1079', '1', 'Vale de São Domingos', 'BR.14.5108352', 'ASCII:Vale De Sao Domingos;ID:6324146', '12139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12139', '112', '14016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5108352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14017', '1079', '1', 'Conquista D''oeste', 'BR.14.5103361', 'ASCII:Conquista D''Oeste;ID:6324147', '12140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12140', '112', '14017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5103361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14018', '1079', '1', 'Santo Antônio do Leste', 'BR.14.5107792', 'ASCII:Santo Antonio Do Leste;ID:6324148', '12141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12141', '112', '14018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14019', '1079', '1', 'Novo São Joaquim', 'BR.14.5106281', 'ASCII:Novo Sao Joaquim;ID:6324149', '12142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12142', '112', '14019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14020', '1079', '1', 'Santa Cruz do Xingu', 'BR.14.5107743', 'ASCII:Santa Cruz Do Xingu;ID:6324150', '12143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12143', '112', '14020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14021', '1079', '1', 'Luís Eduardo Magalhães', 'BR.05.2919553', 'ASCII:Luis Eduardo Magalhaes;ID:6324151', '12144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12144', '112', '14021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14022', '1079', '1', 'Colatina', 'BR.08.3201506', 'ASCII:Colatina;ID:6324152', '12145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12145', '112', '14022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3201506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14023', '1079', '1', 'Governador Lindenberg', 'BR.08.3202256', 'ASCII:Governador Lindenberg;ID:6324153', '12146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12146', '112', '14023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3202256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14024', '1079', '1', 'Ipiranga de Goiás', 'BR.29.5210158', 'ASCII:Ipiranga De Goias;ID:6324154', '12147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12147', '112', '14024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5210158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14025', '1079', '1', 'Ceres', 'BR.29.5205406', 'ASCII:Ceres;ID:6324155', '12148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12148', '112', '14025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5205406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14026', '1079', '1', 'Itajá', 'BR.29.5210802', 'ASCII:Itaja;ID:6324156', '12149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12149', '112', '14026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5210802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14027', '1079', '1', 'Lagoa Santa', 'BR.29.5212253', 'ASCII:Lagoa Santa;ID:6324157', '12150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12150', '112', '14027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5212253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14028', '1079', '1', 'Anápolis', 'BR.29.5201108', 'ASCII:Anapolis;ID:6324158', '12151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12151', '112', '14028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5201108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14029', '1079', '1', 'Silvânia', 'BR.29.5220603', 'ASCII:Silvania;ID:6324159', '12152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12152', '112', '14029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5220603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14030', '1079', '1', 'Campo Limpo de Goiás', 'BR.29.5204854', 'ASCII:Campo Limpo De Goias;ID:6324160', '12153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12153', '112', '14030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5204854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14031', '1079', '1', 'São Miguel dos Campos', 'BR.02.2708600', 'ASCII:Sao Miguel Dos Campos;ID:6324161', '12154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12154', '112', '14031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14032', '1079', '1', 'Nobres', 'BR.14.5105903', 'ASCII:Nobres;ID:6324162', '12155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12155', '112', '14032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14033', '1079', '1', 'Santa Rita do Trivelato', 'BR.14.5107768', 'ASCII:Santa Rita Do Trivelato;ID:6324163', '12156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12156', '112', '14033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107768» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14034', '1079', '1', 'Marcelândia', 'BR.14.5105580', 'ASCII:Marcelandia;ID:6324164', '12157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12157', '112', '14034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14035', '1079', '1', 'Nova Santa Helena', 'BR.14.5106190', 'ASCII:Nova Santa Helena;ID:6324165', '12158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12158', '112', '14035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14036', '1079', '1', 'Itaúba', 'BR.14.5104559', 'ASCII:Itauba;ID:6324166', '12159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12159', '112', '14036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5104559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14037', '1079', '1', 'Várzea', 'BR.22.2414704', 'ASCII:Varzea;ID:6324167', '12160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12160', '112', '14037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2414704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14038', '1079', '1', 'Jundiá', 'BR.22.2406155', 'ASCII:Jundia;ID:6324168', '12161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12161', '112', '14038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2406155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14039', '1079', '1', 'Espírito Santo', 'BR.22.2403509', 'ASCII:Espirito Santo;ID:6324169', '12162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12162', '112', '14039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2403509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14040', '1079', '1', 'Buenópolis', 'BR.15.3109204', 'ASCII:Buenopolis;ID:6324170', '12163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12163', '112', '14040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3109204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14041', '1079', '1', 'São Gabriel', 'BR.23.4318309', 'ASCII:Sao Gabriel;ID:6324171', '12164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12164', '112', '14041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4318309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14042', '1079', '1', 'Jaru', 'BR.24.1100114', 'ASCII:Jaru;ID:6324172', '12165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12165', '112', '14042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14043', '1079', '1', 'Governador Jorge Teixeira', 'BR.24.1101005', 'ASCII:Governador Jorge Teixeira;ID:6324173', '12166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12166', '112', '14043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14044', '1079', '1', 'Mirante da Serra', 'BR.24.1101302', 'ASCII:Mirante Da Serra;ID:6324174', '12167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12167', '112', '14044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1101302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14045', '1079', '1', 'Feijó', 'BR.01.1200302', 'ASCII:Feijo;ID:6324175', '12168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12168', '112', '14045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14046', '1079', '1', 'Manoel Urbano', 'BR.01.1200344', 'ASCII:Manoel Urbano;ID:6324176', '12169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12169', '112', '14046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200344» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14047', '1079', '1', 'Santa Rosa do Purus', 'BR.01.1200435', 'ASCII:Santa Rosa Do Purus;ID:6324177', '12170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12170', '112', '14047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14048', '1079', '1', 'Sena Madureira', 'BR.01.1200500', 'ASCII:Sena Madureira;ID:6324178', '12171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12171', '112', '14048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.01.1200500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14049', '1079', '1', 'Coari', 'BR.04.1301209', 'ASCII:Coari;ID:6324179', '12172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12172', '112', '14049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1301209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14050', '1079', '1', 'Caracaraí', 'BR.25.1400209', 'ASCII:Caracarai;ID:6324180', '12173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12173', '112', '14050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14051', '1079', '1', 'Rorainópolis', 'BR.25.1400472', 'ASCII:Rorainopolis;ID:6324181', '12174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12174', '112', '14051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14052', '1079', '1', 'Almeirim', 'BR.16.1500503', 'ASCII:Almeirim;ID:6324182', '12175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12175', '112', '14052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14053', '1079', '1', 'Altamira', 'BR.16.1500602', 'ASCII:Altamira;ID:6324183', '12176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12176', '112', '14053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1500602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14054', '1079', '1', 'Serra do Navio', 'BR.03.1600055', 'ASCII:Serra Do Navio;ID:6324184', '12177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12177', '112', '14054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14055', '1079', '1', 'Pedra Branca do Amaparí', 'BR.03.1600154', 'ASCII:Pedra Branca Do Amapari;ID:6324185', '12178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12178', '112', '14055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14056', '1079', '1', 'Ferreira Gomes', 'BR.03.1600238', 'ASCII:Ferreira Gomes;ID:6324186', '12179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12179', '112', '14056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14057', '1079', '1', 'Porto Grande', 'BR.03.1600535', 'ASCII:Porto Grande;ID:6324187', '12180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12180', '112', '14057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14058', '1079', '1', 'Laranjal do Jari', 'BR.03.1600279', 'ASCII:Laranjal Do Jari;ID:6324188', '12181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12181', '112', '14058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.03.1600279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14059', '1079', '1', 'Monte do Carmo', 'BR.31.1713601', 'ASCII:Monte Do Carmo;ID:6324189', '12182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12182', '112', '14059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1713601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14060', '1079', '1', 'Natividade', 'BR.31.1714203', 'ASCII:Natividade;ID:6324190', '12183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12183', '112', '14060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1714203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14061', '1079', '1', 'São Valério da Natividade', 'BR.31.1720499', 'ASCII:Sao Valerio Da Natividade;ID:6324191', '12184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12184', '112', '14061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1720499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14062', '1079', '1', 'São Raimundo do Doca Bezerra', 'BR.13.2111631', 'ASCII:Sao Raimundo Do Doca Bezerra;ID:6324192', '12185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12185', '112', '14062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14063', '1079', '1', 'São Roberto', 'BR.13.2111672', 'ASCII:Sao Roberto;ID:6324193', '12186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12186', '112', '14063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.13.2111672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14064', '1079', '1', 'Floriano', 'BR.20.2203909', 'ASCII:Floriano;ID:6324194', '12187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12187', '112', '14064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2203909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14065', '1079', '1', 'Caiçara do Rio do Vento', 'BR.22.2401909', 'ASCII:Caicara Do Rio Do Vento;ID:6324195', '12188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12188', '112', '14065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2401909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14066', '1079', '1', 'Gurjão', 'BR.17.2506509', 'ASCII:Gurjao;ID:6324196', '12189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12189', '112', '14066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2506509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14067', '1079', '1', 'São José da Laje', 'BR.02.2708303', 'ASCII:Sao Jose Da Laje;ID:6324197', '12190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12190', '112', '14067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14068', '1079', '1', 'Barra do Mendes', 'BR.05.2903003', 'ASCII:Barra Do Mendes;ID:6324198', '12191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12191', '112', '14068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2903003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14069', '1079', '1', 'Souto Soares', 'BR.05.2930808', 'ASCII:Souto Soares;ID:6324199', '12192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12192', '112', '14069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2930808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14070', '1079', '1', 'Augusto de Lima', 'BR.15.3104809', 'ASCII:Augusto De Lima;ID:6324200', '12193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12193', '112', '14070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3104809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14071', '1079', '1', 'Diamantina', 'BR.15.3121605', 'ASCII:Diamantina;ID:6324201', '12194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12194', '112', '14071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3121605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14072', '1079', '1', 'Santa Leopoldina', 'BR.08.3204500', 'ASCII:Santa Leopoldina;ID:6324202', '12195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12195', '112', '14072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14073', '1079', '1', 'Santa Maria de Jetibá', 'BR.08.3204559', 'ASCII:Santa Maria De Jetiba;ID:6324203', '12196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12196', '112', '14073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3204559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14074', '1079', '1', 'Carmo', 'BR.21.3301207', 'ASCII:Carmo;ID:6324204', '12197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12197', '112', '14074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14075', '1079', '1', 'Duas Barras', 'BR.21.3301603', 'ASCII:Duas Barras;ID:6324205', '12198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12198', '112', '14075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14076', '1079', '1', 'Arealva', 'BR.27.3503406', 'ASCII:Arealva;ID:6324206', '12199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12199', '112', '14076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3503406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14077', '1079', '1', 'Iacanga', 'BR.27.3519105', 'ASCII:Iacanga;ID:6324207', '12200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12200', '112', '14077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3519105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14078', '1079', '1', 'Iporanga', 'BR.27.3521200', 'ASCII:Iporanga;ID:6324208', '12201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12201', '112', '14078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3521200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14079', '1079', '1', 'Ortigueira', 'BR.18.4117305', 'ASCII:Ortigueira;ID:6324209', '12202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12202', '112', '14079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4117305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14080', '1079', '1', 'Telêmaco Borba', 'BR.18.4127106', 'ASCII:Telemaco Borba;ID:6324210', '12203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12203', '112', '14080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4127106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14081', '1079', '1', 'Rio do Campo', 'BR.26.4214508', 'ASCII:Rio Do Campo;ID:6324211', '12204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12204', '112', '14081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4214508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14082', '1079', '1', 'Salete', 'BR.26.4215307', 'ASCII:Salete;ID:6324212', '12205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12205', '112', '14082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4215307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14083', '1079', '1', 'Taió', 'BR.26.4217808', 'ASCII:Taio;ID:6324213', '12206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12206', '112', '14083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4217808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14084', '1079', '1', 'Santa Maria', 'BR.23.4316907', 'ASCII:Santa Maria;ID:6324214', '12207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12207', '112', '14084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4316907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14085', '1079', '1', 'Sidrolândia', 'BR.11.5007901', 'ASCII:Sidrolandia;ID:6324215', '12208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12208', '112', '14085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5007901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14086', '1079', '1', 'Guarantã do Norte', 'BR.14.5104104', 'ASCII:Guaranta Do Norte;ID:6324216', '12209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12209', '112', '14086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5104104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14087', '1079', '1', 'Lucas do Rio Verde', 'BR.14.5105259', 'ASCII:Lucas Do Rio Verde;ID:6324217', '12210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12210', '112', '14087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14088', '1079', '1', 'Matupá', 'BR.14.5105606', 'ASCII:Matupa;ID:6324218', '12211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12211', '112', '14088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5105606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14089', '1079', '1', 'Nova Mutum', 'BR.14.5106224', 'ASCII:Nova Mutum;ID:6324219', '12212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12212', '112', '14089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14090', '1079', '1', 'Peixoto de Azevedo', 'BR.14.5106422', 'ASCII:Peixoto De Azevedo;ID:6324220', '12213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12213', '112', '14090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14091', '1079', '1', 'Sorriso', 'BR.14.5107925', 'ASCII:Sorriso;ID:6324221', '12214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12214', '112', '14091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14092', '1079', '1', 'Brasília', 'BR.07.5300108', 'ASCII:Brasilia;ID:6324222', '12215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12215', '112', '14092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.07.5300108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14093', '1079', '1', 'São João da Fronteira', 'BR.20.2209872', 'ASCII:Sao Joao Da Fronteira;ID:6324223', '12216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12216', '112', '14093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2209872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14094', '1079', '1', 'Glória', 'BR.05.2911402', 'ASCII:Gloria;ID:6324224', '12217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12217', '112', '14094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2911402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14095', '1079', '1', 'Prata', 'BR.17.2512200', 'ASCII:Prata;ID:6324225', '12218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12218', '112', '14095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2512200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14096', '1079', '1', 'São Francisco', 'BR.17.2513984', 'ASCII:Sao Francisco;ID:6324226', '12219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12219', '112', '14096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2513984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14097', '1079', '1', 'Flores', 'BR.30.2605608', 'ASCII:Flores;ID:6324227', '12220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12220', '112', '14097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14098', '1079', '1', 'Paulista', 'BR.30.2610707', 'ASCII:Paulista;ID:6324228', '12221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12221', '112', '14098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2610707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14099', '1079', '1', 'São João', 'BR.30.2613206', 'ASCII:Sao Joao;ID:6324229', '12222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12222', '112', '14099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2613206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14100', '1079', '1', 'Prado', 'BR.05.2925501', 'ASCII:Prado;ID:6324230', '12223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12223', '112', '14100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2925501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14101', '1079', '1', 'Gouveia', 'BR.15.3127602', 'ASCII:Gouvea;ID:6324231', '12224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12224', '112', '14101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3127602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14102', '1079', '1', 'Ipanema', 'BR.15.3131208', 'ASCII:Ipanema;ID:6324232', '12225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12225', '112', '14102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3131208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14103', '1079', '1', 'Machado', 'BR.15.3139003', 'ASCII:Machado;ID:6324233', '12226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12226', '112', '14103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3139003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14104', '1079', '1', 'Prata', 'BR.15.3152808', 'ASCII:Prata;ID:6324234', '12227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12227', '112', '14104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3152808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14105', '1079', '1', 'São Francisco', 'BR.15.3161106', 'ASCII:Sao Francisco;ID:6324235', '12228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12228', '112', '14105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14106', '1079', '1', 'Alegre', 'BR.08.3200201', 'ASCII:Alegre;ID:6324236', '12229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12229', '112', '14106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.08.3200201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14107', '1079', '1', 'Barbosa', 'BR.27.3505104', 'ASCII:Barbosa;ID:6324237', '12230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12230', '112', '14107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3505104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14108', '1079', '1', 'Sales', 'BR.27.3544806', 'ASCII:Sales;ID:6324238', '12231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12231', '112', '14108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14109', '1079', '1', 'São Francisco', 'BR.27.3549003', 'ASCII:Sao Francisco;ID:6324239', '12232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12232', '112', '14109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14110', '1079', '1', 'São Vicente', 'BR.22.2413003', 'ASCII:Sao Vicente;ID:6324240', '12233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12233', '112', '14110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2413003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14111', '1079', '1', 'São Francisco de Paula', 'BR.15.3161205', 'ASCII:Sao Francisco De Paula;ID:6324241', '12234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12234', '112', '14111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3161205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14112', '1079', '1', 'Água Branca', 'BR.20.2200202', 'ASCII:Agua Branca;ID:6324242', '12235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12235', '112', '14112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2200202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14113', '1079', '1', 'São Pedro', 'BR.22.2412708', 'ASCII:Sao Pedro;ID:6324243', '12236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12236', '112', '14113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.22.2412708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14114', '1079', '1', 'Água Branca', 'BR.17.2500106', 'ASCII:Agua Branca;ID:6324244', '12237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12237', '112', '14114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14115', '1079', '1', 'Sertãozinho', 'BR.17.2515930', 'ASCII:Sertaozinho;ID:6324245', '12238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12238', '112', '14115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2515930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14116', '1079', '1', 'Araçoiaba', 'BR.30.2601052', 'ASCII:Aracoiaba;ID:6324246', '12239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12239', '112', '14116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2601052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14117', '1079', '1', 'Pinhão', 'BR.18.4119301', 'ASCII:Pinhao;ID:6324247', '12240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12240', '112', '14117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4119301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14118', '1079', '1', 'Independência', 'BR.23.4310405', 'ASCII:Independencia;ID:6324248', '12241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12241', '112', '14118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4310405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14119', '1079', '1', 'Alto Alegre', 'BR.25.1400050', 'ASCII:Alto Alegre;ID:6324249', '12242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12242', '112', '14119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14120', '1079', '1', 'Iguatu', 'BR.18.4110052', 'ASCII:Iguatu;ID:6324250', '12243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12243', '112', '14120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.18.4110052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14121', '1079', '1', 'Iracema', 'BR.25.1400282', 'ASCII:Iracema;ID:6324251', '12244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12244', '112', '14121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.25.1400282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14122', '1079', '1', 'Ipueiras', 'BR.31.1709807', 'ASCII:Ipueiras;ID:6324252', '12245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12245', '112', '14122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1709807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14123', '1079', '1', 'Batalha', 'BR.20.2201507', 'ASCII:Batalha;ID:6324253', '12246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12246', '112', '14123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14124', '1079', '1', 'Amparo', 'BR.17.2500734', 'ASCII:Amparo;ID:6324254', '12247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12247', '112', '14124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2500734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14125', '1079', '1', 'Pedra Branca', 'BR.17.2511004', 'ASCII:Pedra Branca;ID:6324255', '12248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12248', '112', '14125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2511004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14126', '1079', '1', 'Soledade', 'BR.17.2516102', 'ASCII:Soledade;ID:6324256', '12249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12249', '112', '14126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2516102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14127', '1079', '1', 'Cedro', 'BR.30.2604304', 'ASCII:Cedro;ID:6324257', '12250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12250', '112', '14127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2604304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14128', '1079', '1', 'Pacatuba', 'BR.28.2804904', 'ASCII:Pacatuba;ID:6324258', '12251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12251', '112', '14128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2804904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14129', '1079', '1', 'Milagres', 'BR.05.2921302', 'ASCII:Milagres;ID:6324259', '12252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12252', '112', '14129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2921302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14130', '1079', '1', 'Candeias', 'BR.15.3112000', 'ASCII:Candeias;ID:6324260', '12253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12253', '112', '14130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3112000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14131', '1079', '1', 'Aurora', 'BR.26.4201901', 'ASCII:Aurora;ID:6324261', '12254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12254', '112', '14131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4201901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14132', '1079', '1', 'Alto Alegre', 'BR.23.4300554', 'ASCII:Alto Alegre;ID:6324262', '12255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12255', '112', '14132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14133', '1079', '1', 'Jardim', 'BR.11.5005004', 'ASCII:Jardim;ID:6324263', '12256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12256', '112', '14133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.11.5005004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14134', '1079', '1', 'Piranhas', 'BR.29.5217203', 'ASCII:Piranhas;ID:6324264', '12257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12257', '112', '14134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.29.5217203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14135', '1079', '1', 'Granja', 'BR.06.2304707', 'ASCII:Granja;ID:6324265', '12258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12258', '112', '14135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14136', '1079', '1', 'Itambé', 'BR.30.2607653', 'ASCII:Itambe;ID:6324266', '12259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12259', '112', '14136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2607653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14137', '1079', '1', 'Serrita', 'BR.30.2614006', 'ASCII:Serrita;ID:6324267', '12260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12260', '112', '14137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2614006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14138', '1079', '1', 'Jacaré dos Homens', 'BR.02.2703403', 'ASCII:Jacare Dos Homens;ID:6324268', '12261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12261', '112', '14138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14139', '1079', '1', 'Olho d''Água do Casado', 'BR.02.2705804', 'ASCII:Olho D''Agua Do Casado;ID:6324269', '12262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12262', '112', '14139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2705804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14140', '1079', '1', 'Hidrolândia', 'BR.06.2305209', 'ASCII:Hidrolandia;ID:6324270', '12263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12263', '112', '14140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2305209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14141', '1079', '1', 'Ocara', 'BR.06.2309458', 'ASCII:Ocara;ID:6324271', '12264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12264', '112', '14141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14142', '1079', '1', 'Belo Monte', 'BR.02.2700904', 'ASCII:Belo Monte;ID:6324272', '12265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12265', '112', '14142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2700904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14143', '1079', '1', 'Igaci', 'BR.02.2703106', 'ASCII:Igaci;ID:6324273', '12266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12266', '112', '14143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2703106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14144', '1079', '1', 'Nova Mamoré', 'BR.24.1100338', 'ASCII:Nova Mamore;ID:6324274', '12267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12267', '112', '14144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.24.1100338» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14145', '1079', '1', 'Canutama', 'BR.04.1300904', 'ASCII:Canutama;ID:6324275', '12268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12268', '112', '14145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1300904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14146', '1079', '1', 'Tapauá', 'BR.04.1304104', 'ASCII:Tapaua;ID:6324276', '12269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12269', '112', '14146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.04.1304104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14147', '1079', '1', 'Aveiro', 'BR.16.1501006', 'ASCII:Aveiro;ID:6324277', '12270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12270', '112', '14147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1501006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14148', '1079', '1', 'Inhangapi', 'BR.16.1503408', 'ASCII:Inhangapi;ID:6324278', '12271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12271', '112', '14148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1503408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14149', '1079', '1', 'Viseu', 'BR.16.1508308', 'ASCII:Viseu;ID:6324279', '12272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12272', '112', '14149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.16.1508308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14150', '1079', '1', 'Lagoa da Confusão', 'BR.31.1711902', 'ASCII:Lagoa Da Confusao;ID:6324280', '12273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12273', '112', '14150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1711902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14151', '1079', '1', 'Presidente Kennedy', 'BR.31.1718402', 'ASCII:Presidente Kennedy;ID:6324281', '12274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12274', '112', '14151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1718402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14152', '1079', '1', 'Tupiratins', 'BR.31.1721307', 'ASCII:Tupiratins;ID:6324282', '12275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12275', '112', '14152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.31.1721307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14153', '1079', '1', 'Avelino Lopes', 'BR.20.2201101', 'ASCII:Avelino Lopes;ID:6324283', '12276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12276', '112', '14153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2201101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14154', '1079', '1', 'Morro Cabeça no Tempo', 'BR.20.2206654', 'ASCII:Morro Cabeca No Tempo;ID:6324284', '12277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12277', '112', '14154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.20.2206654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14155', '1079', '1', 'Aracati', 'BR.06.2301109', 'ASCII:Aracati;ID:6324285', '12278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12278', '112', '14155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14156', '1079', '1', 'Ararendá', 'BR.06.2301257', 'ASCII:Ararenda;ID:6324286', '12279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12279', '112', '14156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14157', '1079', '1', 'Banabuiú', 'BR.06.2301851', 'ASCII:Banabuiu;ID:6324287', '12280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12280', '112', '14157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2301851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14158', '1079', '1', 'Croatá', 'BR.06.2304236', 'ASCII:Croata;ID:6324288', '12281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12281', '112', '14158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304236» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14159', '1079', '1', 'Ererê', 'BR.06.2304277', 'ASCII:Erere;ID:6324289', '12282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12282', '112', '14159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14160', '1079', '1', 'Forquilha', 'BR.06.2304350', 'ASCII:Forquilha;ID:6324290', '12283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12283', '112', '14160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14161', '1079', '1', 'Graça', 'BR.06.2304657', 'ASCII:Graca;ID:6324291', '12284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12284', '112', '14161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2304657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14162', '1079', '1', 'Irauçuba', 'BR.06.2306108', 'ASCII:Iraucuba;ID:6324292', '12285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12285', '112', '14162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14163', '1079', '1', 'Itaitinga', 'BR.06.2306256', 'ASCII:Itaitinga;ID:6324293', '12286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12286', '112', '14163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14164', '1079', '1', 'Itapiúna', 'BR.06.2306504', 'ASCII:Itapiuna;ID:6324294', '12287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12287', '112', '14164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14165', '1079', '1', 'Jaguaribara', 'BR.06.2306801', 'ASCII:Jaguaribara;ID:6324295', '12288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12288', '112', '14165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2306801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14166', '1079', '1', 'Madalena', 'BR.06.2307635', 'ASCII:Madalena;ID:6324296', '12289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12289', '112', '14166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2307635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14167', '1079', '1', 'Milhã', 'BR.06.2308351', 'ASCII:Milha;ID:6324297', '12290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12290', '112', '14167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2308351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14168', '1079', '1', 'Nova Olinda', 'BR.06.2309201', 'ASCII:Nova Olinda;ID:6324298', '12291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12291', '112', '14168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2309201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14169', '1079', '1', 'Palhano', 'BR.06.2310001', 'ASCII:Palhano;ID:6324299', '12292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12292', '112', '14169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2310001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14170', '1079', '1', 'Potiretama', 'BR.06.2311231', 'ASCII:Potiretama;ID:6324300', '12293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12293', '112', '14170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2311231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14171', '1079', '1', 'Senador Sá', 'BR.06.2312809', 'ASCII:Senador Sa;ID:6324301', '12294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12294', '112', '14171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2312809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14172', '1079', '1', 'Tabuleiro do Norte', 'BR.06.2313104', 'ASCII:Tabuleiro Do Norte;ID:6324302', '12295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12295', '112', '14172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14173', '1079', '1', 'Varjota', 'BR.06.2313955', 'ASCII:Varjota;ID:6324303', '12296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12296', '112', '14173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2313955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14174', '1079', '1', 'Piancó', 'BR.17.2511301', 'ASCII:Pianco;ID:6324304', '12297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12297', '112', '14174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.17.2511301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14175', '1079', '1', 'Ferreiros', 'BR.30.2605509', 'ASCII:Ferreiros;ID:6324305', '12298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12298', '112', '14175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.30.2605509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14176', '1079', '1', 'Cacimbinhas', 'BR.02.2701209', 'ASCII:Cacimbinhas;ID:6324306', '12299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12299', '112', '14176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14177', '1079', '1', 'Campo Grande', 'BR.02.2701506', 'ASCII:Campo Grande;ID:6324307', '12300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12300', '112', '14177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2701506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14178', '1079', '1', 'Craíbas', 'BR.02.2702355', 'ASCII:Craibas;ID:6324308', '12301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12301', '112', '14178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14179', '1079', '1', 'Estrela de Alagoas', 'BR.02.2702553', 'ASCII:Estrela De Alagoas;ID:6324309', '12302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12302', '112', '14179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14180', '1079', '1', 'Girau do Ponciano', 'BR.02.2702900', 'ASCII:Girau Do Ponciano;ID:6324310', '12303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12303', '112', '14180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2702900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14181', '1079', '1', 'Maribondo', 'BR.02.2704807', 'ASCII:Maribondo;ID:6324311', '12304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12304', '112', '14181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2704807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14182', '1079', '1', 'Poço das Trincheiras', 'BR.02.2707206', 'ASCII:Poco Das Trincheiras;ID:6324312', '12305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12305', '112', '14182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2707206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14183', '1079', '1', 'São José da Tapera', 'BR.02.2708402', 'ASCII:Sao Jose Da Tapera;ID:6324313', '12306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12306', '112', '14183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14184', '1079', '1', 'Senador Rui Palmeira', 'BR.02.2708956', 'ASCII:Senador Rui Palmeira;ID:6324314', '12307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12307', '112', '14184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.02.2708956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14185', '1079', '1', 'Feira Nova', 'BR.28.2802205', 'ASCII:Feira Nova;ID:6324315', '12308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12308', '112', '14185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2802205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14186', '1079', '1', 'Gracho Cardoso', 'BR.28.2802601', 'ASCII:Gracho Cardoso;ID:6324316', '12309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12309', '112', '14186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2802601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14187', '1079', '1', 'Japoatã', 'BR.28.2803401', 'ASCII:Japoata;ID:6324317', '12310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12310', '112', '14187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2803401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14188', '1079', '1', 'Pedra Mole', 'BR.28.2805000', 'ASCII:Pedra Mole;ID:6324318', '12311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12311', '112', '14188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2805000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14189', '1079', '1', 'São Domingos', 'BR.28.2806800', 'ASCII:Sao Domingos;ID:6324319', '12312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12312', '112', '14189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2806800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14190', '1079', '1', 'São Miguel do Aleixo', 'BR.28.2807006', 'ASCII:Sao Miguel Do Aleixo;ID:6324320', '12313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12313', '112', '14190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2807006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14191', '1079', '1', 'Aramari', 'BR.05.2902203', 'ASCII:Aramari;ID:6324321', '12314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12314', '112', '14191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2902203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14192', '1079', '1', 'Chorrochó', 'BR.05.2907707', 'ASCII:Chorrocho;ID:6324322', '12315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12315', '112', '14192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2907707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14193', '1079', '1', 'Itapicuru', 'BR.05.2916500', 'ASCII:Itapicuru;ID:6324323', '12316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12316', '112', '14193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2916500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14194', '1079', '1', 'Macururé', 'BR.05.2919900', 'ASCII:Macurure;ID:6324324', '12317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12317', '112', '14194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2919900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14195', '1079', '1', 'Paulo Afonso', 'BR.05.2924009', 'ASCII:Paulo Afonso;ID:6324325', '12318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12318', '112', '14195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2924009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14196', '1079', '1', 'Rio Real', 'BR.05.2927002', 'ASCII:Rio Real;ID:6324326', '12319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12319', '112', '14196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2927002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14197', '1079', '1', 'Rodelas', 'BR.05.2927101', 'ASCII:Rodelas;ID:6324327', '12320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12320', '112', '14197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.05.2927101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14198', '1079', '1', 'Belmiro Braga', 'BR.15.3106101', 'ASCII:Belmiro Braga;ID:6324328', '12321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12321', '112', '14198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3106101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14199', '1079', '1', 'Monte Sião', 'BR.15.3143401', 'ASCII:Monte Siao;ID:6324329', '12322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12322', '112', '14199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.15.3143401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14200', '1079', '1', 'Cantagalo', 'BR.21.3301108', 'ASCII:Cantagalo;ID:6324330', '12323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12323', '112', '14200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.21.3301108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14201', '1079', '1', 'Anhumas', 'BR.27.3502408', 'ASCII:Anhumas;ID:6324331', '12324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12324', '112', '14201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3502408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14202', '1079', '1', 'Campinas', 'BR.27.3509502', 'ASCII:Campinas;ID:6324332', '12325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12325', '112', '14202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3509502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14203', '1079', '1', 'Coroados', 'BR.27.3512506', 'ASCII:Coroados;ID:6324333', '12326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12326', '112', '14203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3512506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14204', '1079', '1', 'Corumbataí', 'BR.27.3512704', 'ASCII:Corumbatai;ID:6324334', '12327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12327', '112', '14204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3512704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14205', '1079', '1', 'Cosmorama', 'BR.27.3512902', 'ASCII:Cosmorama;ID:6324335', '12328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12328', '112', '14205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3512902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14206', '1079', '1', 'Franca', 'BR.27.3516200', 'ASCII:Franca;ID:6324336', '12329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12329', '112', '14206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14207', '1079', '1', 'Garça', 'BR.27.3516705', 'ASCII:Garca;ID:6324337', '12330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12330', '112', '14207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3516705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14208', '1079', '1', 'Itapira', 'BR.27.3522604', 'ASCII:Itapira;ID:6324338', '12331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12331', '112', '14208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3522604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14209', '1079', '1', 'Jardinópolis', 'BR.27.3525102', 'ASCII:Jardinopolis;ID:6324339', '12332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12332', '112', '14209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14210', '1079', '1', 'Jarinu', 'BR.27.3525201', 'ASCII:Jarinu;ID:6324340', '12333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12333', '112', '14210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3525201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14211', '1079', '1', 'Lucélia', 'BR.27.3527405', 'ASCII:Lucelia;ID:6324341', '12334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12334', '112', '14211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3527405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14212', '1079', '1', 'Mogi Guaçu', 'BR.27.3530706', 'ASCII:Moji-Guacu;ID:6324342', '12335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12335', '112', '14212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3530706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14213', '1079', '1', 'Nova Odessa', 'BR.27.3533403', 'ASCII:Nova Odessa;ID:6324343', '12336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12336', '112', '14213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3533403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14214', '1079', '1', 'Paulistânia', 'BR.27.3536570', 'ASCII:Paulistania;ID:6324344', '12337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12337', '112', '14214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3536570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14215', '1079', '1', 'Pedreira', 'BR.27.3537107', 'ASCII:Pedreira;ID:6324345', '12338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12338', '112', '14215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14216', '1079', '1', 'Penápolis', 'BR.27.3537305', 'ASCII:Penapolis;ID:6324346', '12339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12339', '112', '14216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3537305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14217', '1079', '1', 'Piracicaba', 'BR.27.3538709', 'ASCII:Piracicaba;ID:6324347', '12340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12340', '112', '14217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3538709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14218', '1079', '1', 'Pirapozinho', 'BR.27.3539202', 'ASCII:Pirapozinho;ID:6324348', '12341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12341', '112', '14218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3539202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14219', '1079', '1', 'Piratininga', 'BR.27.3539400', 'ASCII:Piratininga;ID:6324349', '12342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12342', '112', '14219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3539400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14220', '1079', '1', 'Pontes Gestal', 'BR.27.3540309', 'ASCII:Pontes Gestal;ID:6324350', '12343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12343', '112', '14220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3540309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14221', '1079', '1', 'Praia Grande', 'BR.27.3541000', 'ASCII:Praia Grande;ID:6324351', '12344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12344', '112', '14221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14222', '1079', '1', 'Presidente Bernardes', 'BR.27.3541208', 'ASCII:Presidente Bernardes;ID:6324352', '12345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12345', '112', '14222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14223', '1079', '1', 'Presidente Prudente', 'BR.27.3541406', 'ASCII:Presidente Prudente;ID:6324353', '12346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12346', '112', '14223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3541406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14224', '1079', '1', 'Riolândia', 'BR.27.3544202', 'ASCII:Riolandia;ID:6324354', '12347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12347', '112', '14224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3544202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14225', '1079', '1', 'Santa Cruz da Conceição', 'BR.27.3546207', 'ASCII:Santa Cruz Da Conceicao;ID:6324355', '12348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12348', '112', '14225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3546207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14226', '1079', '1', 'São Bernardo do Campo', 'BR.27.3548708', 'ASCII:Sao Bernardo Do Campo;ID:6324356', '12349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12349', '112', '14226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3548708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14227', '1079', '1', 'São João da Boa Vista', 'BR.27.3549102', 'ASCII:Sao Joao Da Boa Vista;ID:6324357', '12350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12350', '112', '14227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3549102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14228', '1079', '1', 'São Paulo', 'BR.27.3550308', 'ASCII:Sao Paulo;ID:6324358', '12351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12351', '112', '14228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3550308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14229', '1079', '1', 'Vera Cruz', 'BR.27.3556602', 'ASCII:Vera Cruz;ID:6324359', '12352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12352', '112', '14229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3556602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14230', '1079', '1', 'Votuporanga', 'BR.27.3557105', 'ASCII:Votuporanga;ID:6324360', '12353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12353', '112', '14230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.27.3557105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14231', '1079', '1', 'Tijucas', 'BR.26.4218004', 'ASCII:Tijucas;ID:6324361', '12354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12354', '112', '14231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.26.4218004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14232', '1079', '1', 'Arroio Grande', 'BR.23.4301305', 'ASCII:Arroio Grande;ID:6324362', '12355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12355', '112', '14232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4301305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14233', '1079', '1', 'Canguçu', 'BR.23.4304507', 'ASCII:Cangucu;ID:6324363', '12356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12356', '112', '14233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14234', '1079', '1', 'Carlos Barbosa', 'BR.23.4304804', 'ASCII:Carlos Barbosa;ID:6324364', '12357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12357', '112', '14234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14235', '1079', '1', 'Novo Hamburgo', 'BR.23.4313409', 'ASCII:Novo Hamburgo;ID:6324365', '12358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12358', '112', '14235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4313409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14236', '1079', '1', 'Carlinda', 'BR.14.5102793', 'ASCII:Carlinda;ID:6324366', '12359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12359', '112', '14236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5102793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14237', '1079', '1', 'Novo Mundo', 'BR.14.5106265', 'ASCII:Novo Mundo;ID:6324367', '12360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12360', '112', '14237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5106265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14238', '1079', '1', 'Santa Terezinha', 'BR.14.5107776', 'ASCII:Santa Terezinha;ID:6324368', '12361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12361', '112', '14238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.14.5107776» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14239', '1079', '1', 'Almirante Tamandaré do Sul', 'BR.23.4300471', 'ASCII:Almirante Tamandare Do Sul;ID:6324369', '12362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12362', '112', '14239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4300471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14240', '1079', '1', 'Capão Bonito do Sul', 'BR.23.4304622', 'ASCII:Capao Bonito Do Sul;ID:6324370', '12363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12363', '112', '14240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.23.4304622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14241', '1079', '1', 'São Francisco', 'BR.28.2806909', 'ASCII:Sao Francisco;ID:6324371', '12364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12364', '112', '14241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.28.2806909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14242', '1079', '1', 'Acopiara', 'BR.06.2300309', 'ASCII:Acopiara;ID:6324372', '12365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12365', '112', '14242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BR.06.2300309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14243', '1079', '1', 'Tashigang', 'BT.00.1252424', 'ASCII:Tashigang;ID:1252424', '12366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12366', '112', '14243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BT.00.1252424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14244', '1079', '1', 'Zhlobinski Rayon', 'BY.02.618803', 'ASCII:Zhlobinski Rayon;ID:618803', '12367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12367', '112', '14244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.618803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14245', '1079', '1', 'Zhytkavitski Rayon', 'BY.02.618814', 'ASCII:Zhytkavitski Rayon;ID:618814', '12368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12368', '112', '14245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.618814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14246', '1079', '1', 'Zhabinkawski Rayon', 'BY.01.618911', 'ASCII:Zhabinkawski Rayon;ID:618911', '12369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12369', '112', '14246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.618911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14247', '1079', '1', 'Zel''vyenski Rayon', 'BY.03.618930', 'ASCII:Zel''vyenski Rayon;ID:618930', '12370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12370', '112', '14247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.618930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14248', '1079', '1', 'Zavodski Rayon', 'BY.05.619008', 'ASCII:Zavodski Rayon;ID:619008', '12371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12371', '112', '14248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.05.619008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14249', '1079', '1', 'Yel''ski Rayon', 'BY.02.619597', 'ASCII:Yel''ski Rayon;ID:619597', '12372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12372', '112', '14249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.619597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14250', '1079', '1', 'Voranawski Rayon', 'BY.03.619978', 'ASCII:Voranawski Rayon;ID:619978', '12373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12373', '112', '14250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.619978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14251', '1079', '1', 'Valozhynski Rayon', 'BY.06.620025', 'ASCII:Valozhynski Rayon;ID:620025', '12374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12374', '112', '14251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.620025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14252', '1079', '1', 'Vawkavyski Rayon', 'BY.03.620067', 'ASCII:Vawkavyski Rayon;ID:620067', '12375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12375', '112', '14252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.620067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14253', '1079', '1', 'Vitsyebski Rayon', 'BY.07.620133', 'ASCII:Vitsyebski Rayon;ID:620133', '12376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12376', '112', '14253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.620133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14254', '1079', '1', 'Vilyeyski Rayon', 'BY.06.620178', 'ASCII:Vilyeyski Rayon;ID:620178', '12377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12377', '112', '14254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.620178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14255', '1079', '1', 'Vyetkawski Rayon', 'BY.02.620212', 'ASCII:Vyetkawski Rayon;ID:620212', '12378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12378', '112', '14255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.620212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14256', '1079', '1', 'Vyerkhnyadzvinski Rayon', 'BY.07.620254', 'ASCII:Vyerkhnyadzvinski Rayon;ID:620254', '12379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12379', '112', '14256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.620254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14257', '1079', '1', 'Uzdzyenski Rayon', 'BY.06.620482', 'ASCII:Uzdzyenski Rayon;ID:620482', '12380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12380', '112', '14257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.620482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14258', '1079', '1', 'Ushatski Rayon', 'BY.07.620539', 'ASCII:Ushatski Rayon;ID:620539', '12381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12381', '112', '14258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.620539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14259', '1079', '1', 'Tsentral''ny Rayon', 'BY.05.620745', 'ASCII:Tsentral''ny Rayon;ID:620745', '12382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12382', '112', '14259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.05.620745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14260', '1079', '1', 'Talachynski Rayon', 'BY.07.620831', 'ASCII:Talachynski Rayon;ID:620831', '12383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12383', '112', '14260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.620831» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14261', '1079', '1', 'Svislatski Rayon', 'BY.03.621044', 'ASCII:Svislatski Rayon;ID:621044', '12384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12384', '112', '14261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.621044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14262', '1079', '1', 'Svyetlahorski Rayon', 'BY.02.621073', 'ASCII:Svyetlahorski Rayon;ID:621073', '12385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12385', '112', '14262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.621073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14263', '1079', '1', 'Stolinski Rayon', 'BY.01.621276', 'ASCII:Stolinski Rayon;ID:621276', '12386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12386', '112', '14263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.621276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14264', '1079', '1', 'Stawbtsowski Rayon', 'BY.06.621281', 'ASCII:Stawbtsowski Rayon;ID:621281', '12387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12387', '112', '14264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.621281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14265', '1079', '1', 'Staradarozhski Rayon', 'BY.06.621460', 'ASCII:Staradarozhski Rayon;ID:621460', '12388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12388', '112', '14265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.621460» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14266', '1079', '1', 'Savyetski Rayon', 'BY.05.621599', 'ASCII:Savyetski Rayon;ID:621599', '12389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12389', '112', '14266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.05.621599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14267', '1079', '1', 'Salihorski Rayon', 'BY.06.621664', 'ASCII:Salihorski Rayon;ID:621664', '12390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12390', '112', '14267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.621664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14268', '1079', '1', 'Smarhonski Rayon', 'BY.03.621711', 'ASCII:Smarhonski Rayon;ID:621711', '12391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12391', '112', '14268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.621711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14269', '1079', '1', 'Smalyavitski Rayon', 'BY.06.621728', 'ASCII:Smalyavitski Rayon;ID:621728', '12392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12392', '112', '14269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.621728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14270', '1079', '1', 'Slutski Rayon', 'BY.06.621740', 'ASCII:Slutski Rayon;ID:621740', '12393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12393', '112', '14270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.621740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14271', '1079', '1', 'Slonimski Rayon', 'BY.03.621752', 'ASCII:Slonimski Rayon;ID:621752', '12394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12394', '112', '14271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.621752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14272', '1079', '1', 'Slawharadski Rayon', 'BY.04.621846', 'ASCII:Slawharadski Rayon;ID:621846', '12395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12395', '112', '14272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.621846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14273', '1079', '1', 'Shumilinski Rayon', 'BY.07.621985', 'ASCII:Shumilinski Rayon;ID:621985', '12396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12396', '112', '14273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.621985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14274', '1079', '1', 'Shklowski Rayon', 'BY.04.622033', 'ASCII:Shklowski Rayon;ID:622033', '12397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12397', '112', '14274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.622033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14275', '1079', '1', 'Shchuchynski Rayon', 'BY.03.622114', 'ASCII:Shchuchynski Rayon;ID:622114', '12398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12398', '112', '14275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.622114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14276', '1079', '1', 'Sharkowshchynski Rayon', 'BY.07.622178', 'ASCII:Sharkowshchynski Rayon;ID:622178', '12399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12399', '112', '14276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.622178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14277', '1079', '1', 'Syennyenski Rayon', 'BY.07.622261', 'ASCII:Syennyenski Rayon;ID:622261', '12400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12400', '112', '14277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.622261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14278', '1079', '1', 'Rasonski Rayon', 'BY.07.622691', 'ASCII:Rasonski Rayon;ID:622691', '12401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12401', '112', '14278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.622691» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14279', '1079', '1', 'Rahachowski Rayon', 'BY.02.622738', 'ASCII:Rahachowski Rayon;ID:622738', '12402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12402', '112', '14279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.622738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14280', '1079', '1', 'Rechytski Rayon', 'BY.02.622799', 'ASCII:Rechytski Rayon;ID:622799', '12403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12403', '112', '14280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.622799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14281', '1079', '1', 'Pukhavitski Rayon', 'BY.06.622968', 'ASCII:Pukhavitski Rayon;ID:622968', '12404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12404', '112', '14281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.622968» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14282', '1079', '1', 'Pruzhanski Rayon', 'BY.01.622998', 'ASCII:Pruzhanski Rayon;ID:622998', '12405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12405', '112', '14282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.622998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14283', '1079', '1', 'Pastawski Rayon', 'BY.07.623176', 'ASCII:Pastawski Rayon;ID:623176', '12406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12406', '112', '14283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.623176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14284', '1079', '1', 'Polatski Rayon', 'BY.07.623283', 'ASCII:Polatski Rayon;ID:623283', '12407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12407', '112', '14284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.623283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14285', '1079', '1', 'Pinski Rayon', 'BY.01.623548', 'ASCII:Pinski Rayon;ID:623548', '12408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12408', '112', '14285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.623548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14286', '1079', '1', 'Pyetrykawski Rayon', 'BY.02.623580', 'ASCII:Pyetrykawski Rayon;ID:623580', '12409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12409', '112', '14286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.623580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14287', '1079', '1', 'Pyershamayski Rayon', 'BY.05.623628', 'ASCII:Pyershamayski Rayon;ID:623628', '12410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12410', '112', '14287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.05.623628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14288', '1079', '1', 'Partyzanski Rayon', 'BY.05.623778', 'ASCII:Partyzanski Rayon;ID:623778', '12411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12411', '112', '14288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.05.623778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14289', '1079', '1', 'Astravyetski Rayon', 'BY.03.623940', 'ASCII:Astravyetski Rayon;ID:623940', '12412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12412', '112', '14289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.623940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14290', '1079', '1', 'Asipovitski Rayon', 'BY.04.624028', 'ASCII:Asipovitski Rayon;ID:624028', '12413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12413', '112', '14290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.624028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14291', '1079', '1', 'Ashmyanski Rayon', 'BY.03.624062', 'ASCII:Ashmyanski Rayon;ID:624062', '12414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12414', '112', '14291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.624062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14292', '1079', '1', 'Arshanski Rayon', 'BY.07.624077', 'ASCII:Arshanski Rayon;ID:624077', '12415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12415', '112', '14292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.624077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14293', '1079', '1', 'Kastrychnitski Rayon', 'BY.05.624196', 'ASCII:Kastrychnitski Rayon;ID:624196', '12416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12416', '112', '14293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.05.624196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14294', '1079', '1', 'Aktsyabrski Rayon', 'BY.02.624197', 'ASCII:Aktsyabrski Rayon;ID:624197', '12417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12417', '112', '14294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.624197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14295', '1079', '1', 'Navahrudski Rayon', 'BY.03.624498', 'ASCII:Navahrudski Rayon;ID:624498', '12418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12418', '112', '14295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.624498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14296', '1079', '1', 'Nyasvizhski Rayon', 'BY.06.624699', 'ASCII:Nyasvizhski Rayon;ID:624699', '12419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12419', '112', '14296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.624699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14297', '1079', '1', 'Narawlyanski Rayon', 'BY.02.624798', 'ASCII:Narawlyanski Rayon;ID:624798', '12420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12420', '112', '14297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.624798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14298', '1079', '1', 'Myadzyel''ski Rayon', 'BY.06.624858', 'ASCII:Myadzyel''ski Rayon;ID:624858', '12421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12421', '112', '14298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.624858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14299', '1079', '1', 'Mstsislawski Rayon', 'BY.04.624891', 'ASCII:Mstsislawski Rayon;ID:624891', '12422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12422', '112', '14299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.624891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14300', '1079', '1', 'Mazyrski Rayon', 'BY.02.624894', 'ASCII:Mazyrski Rayon;ID:624894', '12423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12423', '112', '14300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.624894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14301', '1079', '1', 'Mastowski Rayon', 'BY.03.624920', 'ASCII:Mastowski Rayon;ID:624920', '12424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12424', '112', '14301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.624920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14302', '1079', '1', 'Maskowski Rayon', 'BY.05.624936', 'ASCII:Maskowski Rayon;ID:624936', '12425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12425', '112', '14302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.05.624936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14303', '1079', '1', 'Maladzyechanski Rayon', 'BY.06.625025', 'ASCII:Maladzyechanski Rayon;ID:625025', '12426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12426', '112', '14303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.625025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14304', '1079', '1', 'Mahilyowski Rayon', 'BY.04.625072', 'ASCII:Mahilyowski Rayon;ID:625072', '12427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12427', '112', '14304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.625072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14305', '1079', '1', 'Miyorski Rayon', 'BY.07.625131', 'ASCII:Miyorski Rayon;ID:625131', '12428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12428', '112', '14305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.625131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14306', '1079', '1', 'Minski Rayon', 'BY.06.625140', 'ASCII:Minski Rayon;ID:625140', '12429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12429', '112', '14306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.625140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14307', '1079', '1', 'Malarytski Rayon', 'BY.01.625538', 'ASCII:Malarytski Rayon;ID:625538', '12430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12430', '112', '14307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.625538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14308', '1079', '1', 'Lyubanski Rayon', 'BY.06.625717', 'ASCII:Lyubanski Rayon;ID:625717', '12431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12431', '112', '14308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.625717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14309', '1079', '1', 'Lyakhavitski Rayon', 'BY.01.625765', 'ASCII:Lyakhavitski Rayon;ID:625765', '12432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12432', '112', '14309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.625765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14310', '1079', '1', 'Luninyetski Rayon', 'BY.01.625820', 'ASCII:Luninyetski Rayon;ID:625820', '12433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12433', '112', '14310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.625820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14311', '1079', '1', 'Loyewski Rayon', 'BY.02.625906', 'ASCII:Loyewski Rayon;ID:625906', '12434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12434', '112', '14311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.625906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14312', '1079', '1', 'Lahoyski Rayon', 'BY.06.625971', 'ASCII:Lahoyski Rayon;ID:625971', '12435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12435', '112', '14312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.625971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14313', '1079', '1', 'Lyëznyenski Rayon', 'BY.07.626065', 'ASCII:Lyeznyenski Rayon;ID:626065', '12436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12436', '112', '14313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.626065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14314', '1079', '1', 'Lidski Rayon', 'BY.03.626079', 'ASCII:Lidski Rayon;ID:626079', '12437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12437', '112', '14314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.626079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14315', '1079', '1', 'Lyepyel''ski Rayon', 'BY.07.626141', 'ASCII:Lyepyel''ski Rayon;ID:626141', '12438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12438', '112', '14315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.626141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14316', '1079', '1', 'Lyeninski Rayon', 'BY.05.626161', 'ASCII:Lyeninski Rayon;ID:626161', '12439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12439', '112', '14316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.05.626161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14317', '1079', '1', 'Lyel''chytski Rayon', 'BY.02.626189', 'ASCII:Lyel''chytski Rayon;ID:626189', '12440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12440', '112', '14317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.626189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14318', '1079', '1', 'Krupski Rayon', 'BY.06.626463', 'ASCII:Krupski Rayon;ID:626463', '12441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12441', '112', '14318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.626463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14319', '1079', '1', 'Kryhlyanski Rayon', 'BY.04.626490', 'ASCII:Kryhlyanski Rayon;ID:626490', '12442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12442', '112', '14319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.626490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14320', '1079', '1', 'Krychawski Rayon', 'BY.04.626545', 'ASCII:Krychawski Rayon;ID:626545', '12443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12443', '112', '14320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.626545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14321', '1079', '1', 'Krasnapol''ski Rayon', 'BY.04.626626', 'ASCII:Krasnapol''ski Rayon;ID:626626', '12444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12444', '112', '14321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.626626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14322', '1079', '1', 'Kastsyukovitski Rayon', 'BY.04.626807', 'ASCII:Kastsyukovitski Rayon;ID:626807', '12445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12445', '112', '14322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.626807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14323', '1079', '1', 'Karmyanski Rayon', 'BY.02.626914', 'ASCII:Karmyanski Rayon;ID:626914', '12446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12446', '112', '14323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.626914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14324', '1079', '1', 'Karelitski Rayon', 'BY.03.626938', 'ASCII:Karelitski Rayon;ID:626938', '12447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12447', '112', '14324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.626938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14325', '1079', '1', 'Kapyl''ski Rayon', 'BY.06.626951', 'ASCII:Kapyl''ski Rayon;ID:626951', '12448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12448', '112', '14325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.626951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14326', '1079', '1', 'Kobrynski Rayon', 'BY.01.627146', 'ASCII:Kobrynski Rayon;ID:627146', '12449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12449', '112', '14326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.627146» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14327', '1079', '1', 'Klimavitski Rayon', 'BY.04.627199', 'ASCII:Klimavitski Rayon;ID:627199', '12450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12450', '112', '14327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.627199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14328', '1079', '1', 'Klichawski Rayon', 'BY.04.627204', 'ASCII:Klichawski Rayon;ID:627204', '12451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12451', '112', '14328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.627204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14329', '1079', '1', 'Klyetski Rayon', 'BY.06.627213', 'ASCII:Klyetski Rayon;ID:627213', '12452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12452', '112', '14329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.627213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14330', '1079', '1', 'Kirawski Rayon', 'BY.04.627271', 'ASCII:Kirawski Rayon;ID:627271', '12453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12453', '112', '14330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.627271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14331', '1079', '1', 'Khoynitski Rayon', 'BY.02.627360', 'ASCII:Khoynitski Rayon;ID:627360', '12454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12454', '112', '14331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.627360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14332', '1079', '1', 'Khotsimski Rayon', 'BY.04.627380', 'ASCII:Khotsimski Rayon;ID:627380', '12455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12455', '112', '14332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.627380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14333', '1079', '1', 'Kamyanyetski Rayon', 'BY.01.627709', 'ASCII:Kamyanyetski Rayon;ID:627709', '12456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12456', '112', '14333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.627709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14334', '1079', '1', 'Kalinkavitski Rayon', 'BY.02.627748', 'ASCII:Kalinkavitski Rayon;ID:627748', '12457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12457', '112', '14334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.627748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14335', '1079', '1', 'Iwyewski Rayon', 'BY.03.627794', 'ASCII:Iwyewski Rayon;ID:627794', '12458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12458', '112', '14335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.627794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14336', '1079', '1', 'Ivatsevitski Rayon', 'BY.01.627799', 'ASCII:Ivatsevitski Rayon;ID:627799', '12459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12459', '112', '14336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.627799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14337', '1079', '1', 'Ivanawski Rayon', 'BY.01.627807', 'ASCII:Ivanawski Rayon;ID:627807', '12460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12460', '112', '14337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.627807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14338', '1079', '1', 'Hrodzyenski Rayon', 'BY.03.628034', 'ASCII:Hrodzyenski Rayon;ID:628034', '12461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12461', '112', '14338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.628034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14339', '1079', '1', 'Haradotski Rayon', 'BY.07.628152', 'ASCII:Haradotski Rayon;ID:628152', '12462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12462', '112', '14339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.628152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14340', '1079', '1', 'Horatski Rayon', 'BY.04.628237', 'ASCII:Horatski Rayon;ID:628237', '12463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12463', '112', '14340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.628237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14341', '1079', '1', 'Homyel''ski Rayon', 'BY.02.628280', 'ASCII:Homyel''ski Rayon;ID:628280', '12464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12464', '112', '14341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.628280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14342', '1079', '1', 'Hluski Rayon', 'BY.04.628386', 'ASCII:Hluski Rayon;ID:628386', '12465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12465', '112', '14342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.628386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14343', '1079', '1', 'Hlybotski Rayon', 'BY.07.628404', 'ASCII:Hlybotski Rayon;ID:628404', '12466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12466', '112', '14343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.628404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14344', '1079', '1', 'Hantsavitski Rayon', 'BY.01.628532', 'ASCII:Hantsavitski Rayon;ID:628532', '12467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12467', '112', '14344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.628532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14345', '1079', '1', 'Frunzyenski Rayon', 'BY.05.628577', 'ASCII:Frunzyenski Rayon;ID:628577', '12468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12468', '112', '14345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.05.628577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14346', '1079', '1', 'Dzyarzhynski Rayon', 'BY.06.628641', 'ASCII:Dzyarzhynski Rayon;ID:628641', '12469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12469', '112', '14346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.628641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14347', '1079', '1', 'Dzyatlawski Rayon', 'BY.03.628657', 'ASCII:Dzyatlawski Rayon;ID:628657', '12470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12470', '112', '14347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.628657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14348', '1079', '1', 'Dubrovyenski Rayon', 'BY.07.628789', 'ASCII:Dubrovyenski Rayon;ID:628789', '12471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12471', '112', '14348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.628789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14349', '1079', '1', 'Drahichynski Rayon', 'BY.01.628882', 'ASCII:Drahichynski Rayon;ID:628882', '12472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12472', '112', '14349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.628882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14350', '1079', '1', 'Dokshytski Rayon', 'BY.07.629003', 'ASCII:Dokshytski Rayon;ID:629003', '12473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12473', '112', '14350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.629003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14351', '1079', '1', 'Dobrushski Rayon', 'BY.02.629017', 'ASCII:Dobrushski Rayon;ID:629017', '12474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12474', '112', '14351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.629017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14352', '1079', '1', 'Chervyen''ski Rayon', 'BY.06.629270', 'ASCII:Chervyen''ski Rayon;ID:629270', '12475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12475', '112', '14352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.629270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14353', '1079', '1', 'Cherykawski Rayon', 'BY.04.629346', 'ASCII:Cherykawski Rayon;ID:629346', '12476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12476', '112', '14353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.629346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14354', '1079', '1', 'Chacherski Rayon', 'BY.02.629389', 'ASCII:Chacherski Rayon;ID:629389', '12477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12477', '112', '14354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.629389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14355', '1079', '1', 'Chavuski Rayon', 'BY.04.629396', 'ASCII:Chavuski Rayon;ID:629396', '12478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12478', '112', '14355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.629396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14356', '1079', '1', 'Chashnitski Rayon', 'BY.07.629398', 'ASCII:Chashnitski Rayon;ID:629398', '12479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12479', '112', '14356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.629398» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14357', '1079', '1', 'Bykhawski Rayon', 'BY.04.629443', 'ASCII:Bykhawski Rayon;ID:629443', '12480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12480', '112', '14357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.629443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14358', '1079', '1', 'Buda-Kashalyowski Rayon', 'BY.02.629562', 'ASCII:Buda-Kashalyowski Rayon;ID:629562', '12481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12481', '112', '14358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.629562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14359', '1079', '1', 'Brestski Rayon', 'BY.01.629630', 'ASCII:Brestski Rayon;ID:629630', '12482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12482', '112', '14359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.629630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14360', '1079', '1', 'Braslawski Rayon', 'BY.07.629639', 'ASCII:Braslawski Rayon;ID:629639', '12483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12483', '112', '14360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.629639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14361', '1079', '1', 'Brahinski Rayon', 'BY.02.629645', 'ASCII:Brahinski Rayon;ID:629645', '12484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12484', '112', '14361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.629645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14362', '1079', '1', 'Barysawski Rayon', 'BY.06.629799', 'ASCII:Barysawski Rayon;ID:629799', '12485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12485', '112', '14362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.629799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14363', '1079', '1', 'Babruyski Rayon', 'BY.04.630046', 'ASCII:Babruyski Rayon;ID:630046', '12486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12486', '112', '14363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.630046» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14364', '1079', '1', 'Byeshankovitski Rayon', 'BY.07.630135', 'ASCII:Byeshankovitski Rayon;ID:630135', '12487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12487', '112', '14364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.630135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14365', '1079', '1', 'Byarozawski Rayon', 'BY.01.630155', 'ASCII:Byarozawski Rayon;ID:630155', '12488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12488', '112', '14365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.630155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14366', '1079', '1', 'Byarezinski Rayon', 'BY.06.630193', 'ASCII:Byarezinski Rayon;ID:630193', '12489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12489', '112', '14366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.630193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14367', '1079', '1', 'Byerastavitski Rayon', 'BY.03.630208', 'ASCII:Byerastavitski Rayon;ID:630208', '12490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12490', '112', '14367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.630208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14368', '1079', '1', 'Byalynitski Rayon', 'BY.04.630244', 'ASCII:Byalynitski Rayon;ID:630244', '12491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12491', '112', '14368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.630244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14369', '1079', '1', 'Baranavitski Rayon', 'BY.01.630420', 'ASCII:Baranavitski Rayon;ID:630420', '12492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12492', '112', '14369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.630420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14370', '1079', '1', 'Drybinski Rayon', 'BY.04.828843', 'ASCII:Drybinski Rayon;ID:828843', '12493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12493', '112', '14370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.828843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14371', '1079', '1', 'Horad Hrodna', 'BY.03.828847', 'ASCII:Horad Hrodna;ID:828847', '12494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12494', '112', '14371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.828847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14372', '1079', '1', 'Uvarovichskiy Rayon', 'BY.02.828879', 'ASCII:Uvarovichskiy Rayon;ID:828879', '12495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12495', '112', '14372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.828879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14373', '1079', '1', 'Horad Brest', 'BY.01.828881', 'ASCII:Horad Brest;ID:828881', '12496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12496', '112', '14373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.828881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14374', '1079', '1', 'Horad Baranavichy', 'BY.01.828883', 'ASCII:Horad Baranavichy;ID:828883', '12497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12497', '112', '14374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.828883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14375', '1079', '1', 'Horad Kobryn', 'BY.01.828884', 'ASCII:Horad Kobryn;ID:828884', '12498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12498', '112', '14375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.828884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14376', '1079', '1', 'Horad Luninyets', 'BY.01.828885', 'ASCII:Horad Luninyets;ID:828885', '12499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12499', '112', '14376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.828885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14377', '1079', '1', 'Horad Pinsk', 'BY.01.828886', 'ASCII:Horad Pinsk;ID:828886', '12500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12500', '112', '14377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.01.828886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14378', '1079', '1', 'Horad Vitsyebsk', 'BY.07.828887', 'ASCII:Horad Vitsyebsk;ID:828887', '12501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12501', '112', '14378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.828887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14379', '1079', '1', 'Horad Lyepyel''', 'BY.07.828888', 'ASCII:Horad Lyepyel'';ID:828888', '12502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12502', '112', '14379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.828888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14380', '1079', '1', 'Horad Navapolatsk', 'BY.07.828889', 'ASCII:Horad Navapolatsk;ID:828889', '12503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12503', '112', '14380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.828889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14381', '1079', '1', 'Horad Orsha', 'BY.07.828890', 'ASCII:Horad Orsha;ID:828890', '12504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12504', '112', '14381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.828890» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14382', '1079', '1', 'Horad Polatsk', 'BY.07.828891', 'ASCII:Horad Polatsk;ID:828891', '12505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12505', '112', '14382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.07.828891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14383', '1079', '1', 'Horad Homyel''', 'BY.02.828892', 'ASCII:Horad Homyel'';ID:828892', '12506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12506', '112', '14383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.828892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14384', '1079', '1', 'Horad Dobrush', 'BY.02.828894', 'ASCII:Horad Dobrush;ID:828894', '12507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12507', '112', '14384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.828894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14385', '1079', '1', 'Horad Zhlobin', 'BY.02.828895', 'ASCII:Horad Zhlobin;ID:828895', '12508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12508', '112', '14385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.828895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14386', '1079', '1', 'Horad Kalinkavichy', 'BY.02.828897', 'ASCII:Horad Kalinkavichy;ID:828897', '12509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12509', '112', '14386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.828897» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14387', '1079', '1', 'Horad Mazyr', 'BY.02.828898', 'ASCII:Horad Mazyr;ID:828898', '12510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12510', '112', '14387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.828898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14388', '1079', '1', 'Horad Rechytsa', 'BY.02.828899', 'ASCII:Horad Rechytsa;ID:828899', '12511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12511', '112', '14388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.828899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14389', '1079', '1', 'Horad Rahachow', 'BY.02.828900', 'ASCII:Horad Rahachow;ID:828900', '12512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12512', '112', '14389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.828900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14390', '1079', '1', 'Horad Svyetlahorsk', 'BY.02.828901', 'ASCII:Horad Svyetlahorsk;ID:828901', '12513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12513', '112', '14390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.02.828901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14391', '1079', '1', 'Horad Vawkavysk', 'BY.03.828902', 'ASCII:Horad Vawkavysk;ID:828902', '12514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12514', '112', '14391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.828902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14392', '1079', '1', 'Horad Lida', 'BY.03.828903', 'ASCII:Horad Lida;ID:828903', '12515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12515', '112', '14392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.828903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14393', '1079', '1', 'Horad Navahrudak', 'BY.03.828904', 'ASCII:Horad Navahrudak;ID:828904', '12516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12516', '112', '14393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.828904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14394', '1079', '1', 'Horad Slonim', 'BY.03.828905', 'ASCII:Horad Slonim;ID:828905', '12517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12517', '112', '14394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.828905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14395', '1079', '1', 'Horad Smarhon''', 'BY.03.828906', 'ASCII:Horad Smarhon'';ID:828906', '12518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12518', '112', '14395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.03.828906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14396', '1079', '1', 'Horad Barysaw', 'BY.06.828907', 'ASCII:Horad Barysaw;ID:828907', '12519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12519', '112', '14396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.828907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14397', '1079', '1', 'Horad Vilyeyka', 'BY.06.828908', 'ASCII:Horad Vilyeyka;ID:828908', '12520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12520', '112', '14397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.828908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14398', '1079', '1', 'Horad Dzyarzhynsk', 'BY.06.828910', 'ASCII:Horad Dzyarzhynsk;ID:828910', '12521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12521', '112', '14398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.828910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14399', '1079', '1', 'Horad Zhodzina', 'BY.06.828912', 'ASCII:Horad Zhodzina;ID:828912', '12522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12522', '112', '14399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.828912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14400', '1079', '1', 'Horad Zaslawye', 'BY.06.828913', 'ASCII:Horad Zaslawye;ID:828913', '12523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12523', '112', '14400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.828913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14401', '1079', '1', 'Horad Maladzyechna', 'BY.06.828914', 'ASCII:Horad Maladzyechna;ID:828914', '12524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12524', '112', '14401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.828914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14402', '1079', '1', 'Horad Slutsk', 'BY.06.828915', 'ASCII:Horad Slutsk;ID:828915', '12525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12525', '112', '14402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.828915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14403', '1079', '1', 'Horad Salihorsk', 'BY.06.828916', 'ASCII:Horad Salihorsk;ID:828916', '12526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12526', '112', '14403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.06.828916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14404', '1079', '1', 'Horad Mahilyow', 'BY.04.828917', 'ASCII:Horad Mahilyow;ID:828917', '12527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12527', '112', '14404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.828917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14405', '1079', '1', 'Horad Babruysk', 'BY.04.828918', 'ASCII:Horad Babruysk;ID:828918', '12528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12528', '112', '14405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.828918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14406', '1079', '1', 'Horad Asipovichy', 'BY.04.828919', 'ASCII:Horad Asipovichy;ID:828919', '12529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12529', '112', '14406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.828919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14407', '1079', '1', 'Horad Krychaw', 'BY.04.828920', 'ASCII:Horad Krychaw;ID:828920', '12530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12530', '112', '14407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.04.828920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14408', '1079', '1', 'Molodechnenskaya Oblast''', 'BY.00.829413', 'ASCII:Molodechnenskaya Oblast'';ID:829413', '12531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12531', '112', '14408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «BY.00.829413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14409', '1079', '1', 'Abitibi-Témiscamingue', 'CA.10.08', 'ASCII:Abitibi-Temiscamingue;ID:5881941', '12532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12532', '112', '14409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14410', '1079', '1', 'Côte-Nord', 'CA.10.09', 'ASCII:Cote-Nord;ID:5928473', '12533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12533', '112', '14410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14411', '1079', '1', 'Estrie', 'CA.10.05', 'ASCII:Estrie;ID:5949621', '12534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12534', '112', '14411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14412', '1079', '1', 'Lanaudière', 'CA.10.14', 'ASCII:Lanaudiere;ID:6049141', '12535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12535', '112', '14412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.14» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14413', '1079', '1', 'Laurentides', 'CA.10.15', 'ASCII:Laurentides;ID:6050541', '12536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12536', '112', '14413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.15» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14414', '1079', '1', 'Laval', 'CA.10.13', 'ASCII:Laval;ID:6050612', '12537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12537', '112', '14414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14415', '1079', '1', 'Mauricie', 'CA.10.04', 'ASCII:Mauricie;ID:6068167', '12538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12538', '112', '14415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14416', '1079', '1', 'Milton', 'CA.08.6074377', 'ASCII:Milton;ID:6074377', '12539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12539', '112', '14416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.08.6074377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14417', '1079', '1', 'Montérégie', 'CA.10.16', 'ASCII:Monteregie;ID:6076966', '12540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12540', '112', '14417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14418', '1079', '1', 'Montréal', 'CA.10.06', 'ASCII:Montreal;ID:6077246', '12541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12541', '112', '14418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14419', '1079', '1', 'Outaouais', 'CA.10.07', 'ASCII:Outaouais;ID:6095306', '12542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12542', '112', '14419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14420', '1079', '1', 'Saguenay/Lac-Saint-Jean', 'CA.10.02', 'ASCII:Saguenay/Lac-Saint-Jean;ID:6137271', '12543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12543', '112', '14420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14421', '1079', '1', 'Bas-Saint-Laurent', 'CA.10.01', 'ASCII:Bas-Saint-Laurent;ID:6691318', '12544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12544', '112', '14421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.01» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14422', '1079', '1', 'Capitale-Nationale', 'CA.10.03', 'ASCII:Capitale-Nationale;ID:6691319', '12545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12545', '112', '14422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14423', '1079', '1', 'Nord-du-Québec', 'CA.10.10', 'ASCII:Nord-du-Quebec;ID:6691320', '12546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12546', '112', '14423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14424', '1079', '1', 'Gaspésie-Îles-de-la-Madeleine', 'CA.10.11', 'ASCII:Gaspesie-Iles-de-la-Madeleine;ID:6691321', '12547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12547', '112', '14424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14425', '1079', '1', 'Chaudière-Appalaches', 'CA.10.12', 'ASCII:Chaudiere-Appalaches;ID:6691322', '12548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12548', '112', '14425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CA.10.12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14426', '1079', '1', 'Sous-Région de la Tshuapa', 'CD.00.204697', 'ASCII:Sous-Region de la Tshuapa;ID:204697', '12549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12549', '112', '14426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.204697» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14427', '1079', '1', 'Sous-Région de la Tshopo', 'CD.00.204704', 'ASCII:Sous-Region de la Tshopo;ID:204704', '12550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12550', '112', '14427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.204704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14428', '1079', '1', 'Sous-Région du Tanganika', 'CD.00.205253', 'ASCII:Sous-Region du Tanganika;ID:205253', '12551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12551', '112', '14428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.205253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14429', '1079', '1', 'Sous-Région du Sankuru', 'CD.00.205828', 'ASCII:Sous-Region du Sankuru;ID:205828', '12552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12552', '112', '14429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.205828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14430', '1079', '1', 'Sous-Région de la Mongala', 'CD.00.208741', 'ASCII:Sous-Region de la Mongala;ID:208741', '12553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12553', '112', '14430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.208741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14431', '1079', '1', 'Ville de Mbuji-Mayi', 'CD.00.209226', 'ASCII:Ville de Mbuji-Mayi;ID:209226', '12554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12554', '112', '14431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.209226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14432', '1079', '1', 'Sous-Région de la Lulua', 'CD.00.210596', 'ASCII:Sous-Region de la Lulua;ID:210596', '12555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12555', '112', '14432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.210596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14433', '1079', '1', 'Ville de Kisangani', 'CD.00.212726', 'ASCII:Ville de Kisangani;ID:212726', '12556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12556', '112', '14433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.212726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14434', '1079', '1', 'Sous-Région du Kasai', 'CD.00.214140', 'ASCII:Sous-Region du Kasai;ID:214140', '12557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12557', '112', '14434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.214140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14435', '1079', '1', 'Ville de Kananga', 'CD.00.214476', 'ASCII:Ville de Kananga;ID:214476', '12558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12558', '112', '14435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.214476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14436', '1079', '1', 'Sous-Région du Kabinda', 'CD.00.215523', 'ASCII:Sous-Region du Kabinda;ID:215523', '12559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12559', '112', '14436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.215523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14437', '1079', '1', 'Sous-Région de l'' Ituri', 'CD.00.215709', 'ASCII:Sous-Region de l'' Ituri;ID:215709', '12560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12560', '112', '14437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.215709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14438', '1079', '1', 'Sous-Région du Haut-Uele', 'CD.00.216140', 'ASCII:Sous-Region du Haut-Uele;ID:216140', '12561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12561', '112', '14438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.216140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14439', '1079', '1', 'Sous-Région du Haut-Lomani', 'CD.05.216141', 'ASCII:Sous-Region du Haut-Lomani;ID:216141', '12562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12562', '112', '14439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.05.216141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14440', '1079', '1', 'Ville de Bukavu', 'CD.00.217830', 'ASCII:Ville de Bukavu;ID:217830', '12563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12563', '112', '14440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.217830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14441', '1079', '1', 'Sous-Région du Bas-Uele', 'CD.00.219402', 'ASCII:Sous-Region du Bas-Uele;ID:219402', '12564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12564', '112', '14441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.219402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14442', '1079', '1', 'Ville de Lubumbashi', 'CD.00.922702', 'ASCII:Ville de Lubumbashi;ID:922702', '12565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12565', '112', '14442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.922702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14443', '1079', '1', 'Sous-Région du Lualaba', 'CD.00.922727', 'ASCII:Sous-Region du Lualaba;ID:922727', '12566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12566', '112', '14443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.922727» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14444', '1079', '1', 'Ville de Likasi', 'CD.00.922740', 'ASCII:Ville de Likasi;ID:922740', '12567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12567', '112', '14444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.922740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14445', '1079', '1', 'Ville de Kolwezi', 'CD.00.922772', 'ASCII:Ville de Kolwezi;ID:922772', '12568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12568', '112', '14445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.922772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14446', '1079', '1', 'Sous-Région du Haut-Shaba', 'CD.00.923173', 'ASCII:Sous-Region du Haut-Shaba;ID:923173', '12569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12569', '112', '14446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.923173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14447', '1079', '1', 'Ville de Zongo', 'CD.00.2310762', 'ASCII:Ville de Zongo;ID:2310762', '12570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12570', '112', '14447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2310762» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14448', '1079', '1', 'Sous-Région de l'' Ubangi', 'CD.00.2311041', 'ASCII:Sous-Region de l'' Ubangi;ID:2311041', '12571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12571', '112', '14448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2311041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14449', '1079', '1', 'Ville de Mbandaka', 'CD.00.2312894', 'ASCII:Ville de Mbandaka;ID:2312894', '12572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12572', '112', '14449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2312894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14450', '1079', '1', 'Ville de Matadi', 'CD.00.2313001', 'ASCII:Ville de Matadi;ID:2313001', '12573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12573', '112', '14450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2313001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14451', '1079', '1', 'Sous-Région de Mai-Ndombe', 'CD.00.2313191', 'ASCII:Sous-Region de Mai-Ndombe;ID:2313191', '12574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12574', '112', '14451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2313191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14452', '1079', '1', 'Sous-Région du Kwilu', 'CD.00.2313847', 'ASCII:Sous-Region du Kwilu;ID:2313847', '12575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12575', '112', '14452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2313847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14453', '1079', '1', 'Sous-Région du Kwango', 'CD.00.2313860', 'ASCII:Sous-Region du Kwango;ID:2313860', '12576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12576', '112', '14453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2313860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14454', '1079', '1', 'Ville de Kikwit', 'CD.00.2314704', 'ASCII:Ville de Kikwit;ID:2314704', '12577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12577', '112', '14454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2314704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14455', '1079', '1', 'Sous-Région de l'' Équateur', 'CD.00.2315861', 'ASCII:Sous-Region de l'' Equateur;ID:2315861', '12578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12578', '112', '14455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2315861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14456', '1079', '1', 'Sous-Région des Catarates', 'CD.00.2316119', 'ASCII:Sous-Region des Catarates;ID:2316119', '12579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12579', '112', '14456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2316119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14457', '1079', '1', 'Ville de Boma', 'CD.00.2316701', 'ASCII:Ville de Boma;ID:2316701', '12580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12580', '112', '14457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2316701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14458', '1079', '1', 'Sous-Région du Bas-Fleuve', 'CD.00.2317281', 'ASCII:Sous-Region du Bas-Fleuve;ID:2317281', '12581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12581', '112', '14458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2317281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14459', '1079', '1', 'Ville de Bandundu', 'CD.00.2317395', 'ASCII:Ville de Bandundu;ID:2317395', '12582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12582', '112', '14459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CD.00.2317395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14460', '1079', '1', 'Sous-Préfecture de Carnot', 'CF.00.2387494', 'ASCII:Sous-Prefecture de Carnot;ID:2387494', '12583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12583', '112', '14460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CF.00.2387494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14461', '1079', '1', 'Sous-Préfecture de Baboua', 'CF.00.2390511', 'ASCII:Sous-Prefecture de Baboua;ID:2390511', '12584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12584', '112', '14461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CF.00.2390511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14462', '1079', '1', 'Vallemaggia', 'CH.TI.2108', 'ASCII:Vallemaggia;ID:2658196', '12585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12585', '112', '14462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TI.2108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14463', '1079', '1', 'Unterlandquart', 'CH.GR.1813', 'ASCII:Unterlandquart;ID:2658247', '12586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12586', '112', '14463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14464', '1079', '1', 'Bezirk Thierstein', 'CH.SO.1110', 'ASCII:Bezirk Thierstein;ID:2658380', '12587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12587', '112', '14464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SO.1110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14465', '1079', '1', 'Bezirk Sargans', 'CH.SG.1706', 'ASCII:Bezirk Sargans;ID:2658792', '12588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12588', '112', '14465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14466', '1079', '1', 'Bezirk Raron', 'CH.VS.2309', 'ASCII:Bezirk Raron;ID:2659097', '12589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12589', '112', '14466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14467', '1079', '1', 'Obertoggenburg', 'CH.SG.1709', 'ASCII:Obertoggenburg;ID:2659336', '12590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12590', '112', '14467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14468', '1079', '1', 'Oberlandguart', 'CH.GR.1811', 'ASCII:Oberlandguart;ID:2659369', '12591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12591', '112', '14468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14469', '1079', '1', 'Bezirk Meilen', 'CH.ZH.107', 'ASCII:Bezirk Meilen;ID:2659702', '12592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12592', '112', '14469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14470', '1079', '1', 'Martigny', 'CH.VS.2307', 'ASCII:Martigny;ID:2659752', '12593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12593', '112', '14470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14471', '1079', '1', 'Glenner', 'CH.GR.1803', 'ASCII:Glenner;ID:2660584', '12594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12594', '112', '14471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14472', '1079', '1', 'District de la Glâne', 'CH.FR.1002', 'ASCII:District de la Glane;ID:2660598', '12595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12595', '112', '14472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.FR.1002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14473', '1079', '1', 'District Cossonay', 'CH.VD.2204', 'ASCII:District Cossonay;ID:2661103', '12596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12596', '112', '14473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14474', '1079', '1', 'Bezirk Andelfingen', 'CH.ZH.102', 'ASCII:Bezirk Andelfingen;ID:2661751', '12597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12597', '112', '14474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14475', '1079', '1', 'Aarwangen', 'CH.BE.202', 'ASCII:Aarwangen;ID:2661875', '12598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12598', '112', '14475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14476', '1079', '1', 'Bezirk Steckborn', 'CH.TG.2007', 'ASCII:Bezirk Steckborn;ID:6458739', '12599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12599', '112', '14476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TG.2007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14477', '1079', '1', 'Amt Konolfingen', 'CH.BE.212', 'ASCII:Amt Konolfingen;ID:6458740', '12600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12600', '112', '14477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14478', '1079', '1', 'Bezirk Maloja', 'CH.GR.1808', 'ASCII:Bezirk Maloja;ID:6458741', '12601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12601', '112', '14478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14479', '1079', '1', 'Bezirk Gäu', 'CH.SO.1101', 'ASCII:Bezirk Gaeu;ID:6458742', '12602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12602', '112', '14479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SO.1101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14480', '1079', '1', 'Appenzell I.Rh.', 'CH.AI.1600', 'ASCII:Appenzell I.Rh.;ID:6458743', '12603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12603', '112', '14480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AI.1600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14481', '1079', '1', 'District de Delémont', 'CH.JU.2601', 'ASCII:District de Delemont;ID:6458744', '12604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12604', '112', '14481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.JU.2601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14482', '1079', '1', 'District de Sion', 'CH.VS.2312', 'ASCII:District de Sion;ID:6458745', '12605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12605', '112', '14482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14483', '1079', '1', 'Bezirk Zofingen', 'CH.AG.1910', 'ASCII:Bezirk Zofingen;ID:6458746', '12606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12606', '112', '14483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14484', '1079', '1', 'Glarus', 'CH.GL.800', 'ASCII:Glarus;ID:6458747', '12607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12607', '112', '14484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GL.800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14485', '1079', '1', 'Bezirk Waldenburg', 'CH.BL.1305', 'ASCII:Bezirk Waldenburg;ID:6458748', '12608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12608', '112', '14485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BL.1305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14486', '1079', '1', 'Bezirk See', 'CH.SG.1708', 'ASCII:Bezirk See;ID:6458749', '12609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12609', '112', '14486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14487', '1079', '1', 'Distretto di Locarno', 'CH.TI.2104', 'ASCII:Distretto di Locarno;ID:6458750', '12610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12610', '112', '14487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TI.2104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14488', '1079', '1', 'Bezirk Uster', 'CH.ZH.109', 'ASCII:Bezirk Uster;ID:6458751', '12611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12611', '112', '14488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14489', '1079', '1', 'District de Lavaux', 'CH.VD.2208', 'ASCII:District de Lavaux;ID:6458752', '12612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12612', '112', '14489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14490', '1079', '1', 'Bezirk Leuk', 'CH.VS.2306', 'ASCII:Bezirk Leuk;ID:6458753', '12613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12613', '112', '14490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14491', '1079', '1', 'District de la Broye', 'CH.FR.1001', 'ASCII:District de la Broye;ID:6458754', '12614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12614', '112', '14491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.FR.1001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14492', '1079', '1', 'District d''Avenches', 'CH.VD.2203', 'ASCII:District d''Avenches;ID:6458755', '12615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12615', '112', '14492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14493', '1079', '1', 'Distretto di Riviera', 'CH.TI.2107', 'ASCII:Distretto di Riviera;ID:6458756', '12616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12616', '112', '14493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TI.2107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14494', '1079', '1', 'District de la Neuveville', 'CH.BE.215', 'ASCII:District de la Neuveville;ID:6458757', '12617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12617', '112', '14494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14495', '1079', '1', 'District d''Oron', 'CH.VD.2213', 'ASCII:District d''Oron;ID:6458758', '12618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12618', '112', '14495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14496', '1079', '1', 'Bezirk Hinterrhein', 'CH.GR.1805', 'ASCII:Bezirk Hinterrhein;ID:6458759', '12619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12619', '112', '14496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14497', '1079', '1', 'Bezirk Dietikon', 'CH.ZH.111', 'ASCII:Bezirk Dietikon;ID:6458760', '12620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12620', '112', '14497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14498', '1079', '1', 'Amt Hochdorf', 'CH.LU.302', 'ASCII:Amt Hochdorf;ID:6458761', '12621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12621', '112', '14498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.LU.302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14499', '1079', '1', 'Nidwalden', 'CH.NW.700', 'ASCII:Nidwalden;ID:6458762', '12622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12622', '112', '14499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.NW.700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14500', '1079', '1', 'Basel-Stadt', 'CH.BS.1200', 'ASCII:Basel-Stadt;ID:6458763', '12623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12623', '112', '14500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BS.1200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14501', '1079', '1', 'Bezirk Untertoggenburg', 'CH.SG.1712', 'ASCII:Bezirk Untertoggenburg;ID:6458764', '12624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12624', '112', '14501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14502', '1079', '1', 'District d''Aubonne', 'CH.VD.2202', 'ASCII:District d''Aubonne;ID:6458765', '12625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12625', '112', '14502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14503', '1079', '1', 'Bezirk Goms', 'CH.VS.2304', 'ASCII:Bezirk Goms;ID:6458766', '12626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12626', '112', '14503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14504', '1079', '1', 'District de la Sarine', 'CH.FR.1004', 'ASCII:District de la Sarine;ID:6458767', '12627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12627', '112', '14504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.FR.1004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14505', '1079', '1', 'District d''Entremont', 'CH.VS.2303', 'ASCII:District d''Entremont;ID:6458768', '12628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12628', '112', '14505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14506', '1079', '1', 'Bezirk St. Gallen', 'CH.SG.1701', 'ASCII:Bezirk St. Gallen;ID:6458770', '12629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12629', '112', '14506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14507', '1079', '1', 'Distretto di Lugano', 'CH.TI.2105', 'ASCII:Distretto di Lugano;ID:6458771', '12630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12630', '112', '14507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TI.2105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14508', '1079', '1', 'Bezirk Kulm', 'CH.AG.1905', 'ASCII:Bezirk Kulm;ID:6458772', '12631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12631', '112', '14508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14509', '1079', '1', 'Amt Biel', 'CH.BE.204', 'ASCII:Amt Biel;ID:6458773', '12632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12632', '112', '14509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14510', '1079', '1', 'Bezirk Bremgarten', 'CH.AG.1903', 'ASCII:Bezirk Bremgarten;ID:6458774', '12633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12633', '112', '14510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14511', '1079', '1', 'Bezirk Schwyz', 'CH.SZ.506', 'ASCII:Bezirk Schwyz;ID:6458775', '12634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12634', '112', '14511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SZ.506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14512', '1079', '1', 'District de Porrentruy', 'CH.JU.2603', 'ASCII:District de Porrentruy;ID:6458776', '12635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12635', '112', '14512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.JU.2603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14513', '1079', '1', 'District de Grandson', 'CH.VD.2206', 'ASCII:District de Grandson;ID:6458777', '12636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12636', '112', '14513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14514', '1079', '1', 'Amt Oberhasli', 'CH.BE.218', 'ASCII:Amt Oberhasli;ID:6458778', '12637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12637', '112', '14514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14515', '1079', '1', 'Bezirk Solothurn', 'CH.SO.1109', 'ASCII:Bezirk Solothurn;ID:6458779', '12638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12638', '112', '14515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SO.1109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14516', '1079', '1', 'Bezirk Val Müstair', 'CH.GR.1810', 'ASCII:Bezirk Val Muestair;ID:6458780', '12639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12639', '112', '14516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14517', '1079', '1', 'Bezirk March', 'CH.SZ.505', 'ASCII:Bezirk March;ID:6458781', '12640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12640', '112', '14517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SZ.505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14518', '1079', '1', 'Amt Thun', 'CH.BE.224', 'ASCII:Amt Thun;ID:6458782', '12641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12641', '112', '14518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14519', '1079', '1', 'Genève', 'CH.GE.2500', 'ASCII:Geneve;ID:6458783', '12642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12642', '112', '14519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GE.2500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14520', '1079', '1', 'Distretto di Blenio', 'CH.TI.2102', 'ASCII:Distretto di Blenio;ID:6458784', '12643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12643', '112', '14520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TI.2102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14521', '1079', '1', 'Bezirk Kreuzlingen', 'CH.TG.2005', 'ASCII:Bezirk Kreuzlingen;ID:6458785', '12644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12644', '112', '14521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TG.2005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14522', '1079', '1', 'Bezirk Münchwilen', 'CH.TG.2006', 'ASCII:Bezirk Muenchwilen;ID:6458786', '12645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12645', '112', '14522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TG.2006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14523', '1079', '1', 'Amt Bern', 'CH.BE.203', 'ASCII:Amt Bern;ID:6458787', '12646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12646', '112', '14523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14524', '1079', '1', 'Bezirk Zurzach', 'CH.AG.1911', 'ASCII:Bezirk Zurzach;ID:6458788', '12647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12647', '112', '14524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14525', '1079', '1', 'Amt Niedersimmental', 'CH.BE.217', 'ASCII:Amt Niedersimmental;ID:6458789', '12648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12648', '112', '14525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14526', '1079', '1', 'District des Franches-Montagnes', 'CH.JU.2602', 'ASCII:District des Franches-Montagnes;ID:6458790', '12649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12649', '112', '14526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.JU.2602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14527', '1079', '1', 'District de Moutier', 'CH.BE.214', 'ASCII:District de Moutier;ID:6458791', '12650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12650', '112', '14527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14528', '1079', '1', 'Bezirk Gaster', 'CH.SG.1707', 'ASCII:Bezirk Gaster;ID:6458792', '12651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12651', '112', '14528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14529', '1079', '1', 'Amt Seftigen', 'CH.BE.222', 'ASCII:Amt Seftigen;ID:6458793', '12652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12652', '112', '14529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14530', '1079', '1', 'District de Sierre', 'CH.VS.2311', 'ASCII:District de Sierre;ID:6458795', '12653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12653', '112', '14530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14531', '1079', '1', 'District de la Gruyère', 'CH.FR.1003', 'ASCII:District de la Gruyere;ID:6458796', '12654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12654', '112', '14531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.FR.1003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14532', '1079', '1', 'Bezirk Hinwil', 'CH.ZH.105', 'ASCII:Bezirk Hinwil;ID:6458797', '12655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12655', '112', '14532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14533', '1079', '1', 'Bezirk Zürich', 'CH.ZH.112', 'ASCII:Bezirk Zuerich;ID:6458798', '12656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12656', '112', '14533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14534', '1079', '1', 'Uri', 'CH.UR.400', 'ASCII:Uri;ID:6458799', '12657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12657', '112', '14534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.UR.400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14535', '1079', '1', 'Bezirk Diessenhofen', 'CH.TG.2003', 'ASCII:Bezirk Diessenhofen;ID:6458800', '12658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12658', '112', '14535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TG.2003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14536', '1079', '1', 'Bezirk Frauenfeld', 'CH.TG.2004', 'ASCII:Bezirk Frauenfeld;ID:6458801', '12659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12659', '112', '14536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TG.2004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14537', '1079', '1', 'Bezirk Oberrheintal', 'CH.SG.1704', 'ASCII:Bezirk Oberrheintal;ID:6458802', '12660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12660', '112', '14537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14538', '1079', '1', 'Amt Büren', 'CH.BE.205', 'ASCII:Amt Bueren;ID:6458803', '12661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12661', '112', '14538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14539', '1079', '1', 'District de Moudon', 'CH.VD.2210', 'ASCII:District de Moudon;ID:6458804', '12662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12662', '112', '14539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14540', '1079', '1', 'District de Vevey', 'CH.VD.2218', 'ASCII:District de Vevey;ID:6458805', '12663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12663', '112', '14540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14541', '1079', '1', 'Bezirk Lenzburg', 'CH.AG.1907', 'ASCII:Bezirk Lenzburg;ID:6458806', '12664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12664', '112', '14541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14542', '1079', '1', 'Zug', 'CH.ZG.900', 'ASCII:Zug;ID:6458807', '12665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12665', '112', '14542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZG.900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14543', '1079', '1', 'Bezirk Winterthur', 'CH.ZH.110', 'ASCII:Bezirk Winterthur;ID:6458808', '12666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12666', '112', '14543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14544', '1079', '1', 'District du Locle', 'CH.NE.2403', 'ASCII:District du Locle;ID:6458809', '12667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12667', '112', '14544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.NE.2403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14545', '1079', '1', 'Bezirk Gersau', 'CH.SZ.502', 'ASCII:Bezirk Gersau;ID:6458810', '12668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12668', '112', '14545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SZ.502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14546', '1079', '1', 'Bezirk Vorderrhein', 'CH.GR.1814', 'ASCII:Bezirk Vorderrhein;ID:6458811', '12669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12669', '112', '14546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14547', '1079', '1', 'District du Val-de-Ruz', 'CH.NE.2405', 'ASCII:District du Val-de-Ruz;ID:6458812', '12670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12670', '112', '14547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.NE.2405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14548', '1079', '1', 'Bezirk Baden', 'CH.AG.1902', 'ASCII:Bezirk Baden;ID:6458813', '12671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12671', '112', '14548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14549', '1079', '1', 'Distretto di Moësa', 'CH.GR.1809', 'ASCII:Distretto di Moesa;ID:6458814', '12672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12672', '112', '14549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14550', '1079', '1', 'Obwalden', 'CH.OW.600', 'ASCII:Obwalden;ID:6458816', '12673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12673', '112', '14550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.OW.600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14551', '1079', '1', 'District d''Echallens', 'CH.VD.2205', 'ASCII:District d''Echallens;ID:6458817', '12674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12674', '112', '14551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14552', '1079', '1', 'Bezirk Affoltern', 'CH.ZH.101', 'ASCII:Bezirk Affoltern;ID:6458818', '12675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12675', '112', '14552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14553', '1079', '1', 'Amt Trachselwald', 'CH.BE.225', 'ASCII:Amt Trachselwald;ID:6458819', '12676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12676', '112', '14553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14554', '1079', '1', 'Bezirk See/District du Lac', 'CH.FR.1005', 'ASCII:Bezirk See/District du Lac;ID:6458820', '12677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12677', '112', '14554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.FR.1005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14555', '1079', '1', 'Bezirk Brig', 'CH.VS.2301', 'ASCII:Bezirk Brig;ID:6458821', '12678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12678', '112', '14555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14556', '1079', '1', 'Amt Wangen', 'CH.BE.226', 'ASCII:Amt Wangen;ID:6458822', '12679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12679', '112', '14556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14557', '1079', '1', 'Bezirk Sissach', 'CH.BL.1304', 'ASCII:Bezirk Sissach;ID:6458823', '12680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12680', '112', '14557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BL.1304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14558', '1079', '1', 'Bezirk Heinzenberg', 'CH.GR.1804', 'ASCII:Bezirk Heinzenberg;ID:6458824', '12681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12681', '112', '14558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14559', '1079', '1', 'District de Boudry', 'CH.NE.2401', 'ASCII:District de Boudry;ID:6458825', '12682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12682', '112', '14559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.NE.2401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14560', '1079', '1', 'Bezirk Brugg', 'CH.AG.1904', 'ASCII:Bezirk Brugg;ID:6458826', '12683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12683', '112', '14560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14561', '1079', '1', 'Bezirk Albula', 'CH.GR.1801', 'ASCII:Bezirk Albula;ID:6458827', '12684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12684', '112', '14561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14562', '1079', '1', 'Amt Willisau', 'CH.LU.305', 'ASCII:Amt Willisau;ID:6458828', '12685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12685', '112', '14562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.LU.305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14563', '1079', '1', 'Bezirk Lebern', 'CH.SO.1107', 'ASCII:Bezirk Lebern;ID:6458829', '12686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12686', '112', '14563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SO.1107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14564', '1079', '1', 'Bezirk Mittelland', 'CH.AR.1502', 'ASCII:Bezirk Mittelland;ID:6458830', '12687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12687', '112', '14564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AR.1502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14565', '1079', '1', 'District de la Chaux-de-Fonds', 'CH.NE.2402', 'ASCII:District de la Chaux-de-Fonds;ID:6458831', '12688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12688', '112', '14565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.NE.2402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14566', '1079', '1', 'District de Saint-Maurice', 'CH.VS.2310', 'ASCII:District de Saint-Maurice;ID:6458832', '12689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12689', '112', '14566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14567', '1079', '1', 'Bezirk Laufen', 'CH.BL.1302', 'ASCII:Bezirk Laufen;ID:6458833', '12690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12690', '112', '14567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BL.1302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14568', '1079', '1', 'Bezirk Gossau', 'CH.SG.1714', 'ASCII:Bezirk Gossau;ID:6458834', '12691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12691', '112', '14568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14569', '1079', '1', 'District du Val-de-Travers', 'CH.NE.2406', 'ASCII:District du Val-de-Travers;ID:6458835', '12692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12692', '112', '14569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.NE.2406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14570', '1079', '1', 'Bezirk Hinterland', 'CH.AR.1501', 'ASCII:Bezirk Hinterland;ID:6458837', '12693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12693', '112', '14570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AR.1501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14571', '1079', '1', 'Bezirk Rorschach', 'CH.SG.1702', 'ASCII:Bezirk Rorschach;ID:6458838', '12694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12694', '112', '14571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14572', '1079', '1', 'Bezirk Küssnacht', 'CH.SZ.504', 'ASCII:Bezirk Kuessnacht;ID:6458839', '12695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12695', '112', '14572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SZ.504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14573', '1079', '1', 'Bezirk Wil', 'CH.SG.1713', 'ASCII:Bezirk Wil;ID:6458840', '12696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12696', '112', '14573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14574', '1079', '1', 'Bezirk Bucheggberg', 'CH.SO.1103', 'ASCII:Bezirk Bucheggberg;ID:6458841', '12697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12697', '112', '14574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SO.1103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14575', '1079', '1', 'Amt Interlaken', 'CH.BE.211', 'ASCII:Amt Interlaken;ID:6458842', '12698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12698', '112', '14575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14576', '1079', '1', 'Bezirk Arlesheim', 'CH.BL.1301', 'ASCII:Bezirk Arlesheim;ID:6458843', '12699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12699', '112', '14576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BL.1301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14577', '1079', '1', 'Bezirk Visp', 'CH.VS.2313', 'ASCII:Bezirk Visp;ID:6458844', '12700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12700', '112', '14577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14578', '1079', '1', 'District de Monthey', 'CH.VS.2308', 'ASCII:District de Monthey;ID:6458845', '12701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12701', '112', '14578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14579', '1079', '1', 'Bezirk Aarau', 'CH.AG.1901', 'ASCII:Bezirk Aarau;ID:6458846', '12702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12702', '112', '14579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14580', '1079', '1', 'Bezirk Horgen', 'CH.ZH.106', 'ASCII:Bezirk Horgen;ID:6458847', '12703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12703', '112', '14580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14581', '1079', '1', 'Bezirk Höfe', 'CH.SZ.503', 'ASCII:Bezirk Hoefe;ID:6458848', '12704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12704', '112', '14581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SZ.503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14582', '1079', '1', 'District du Pays d''Enhaut', 'CH.VD.2215', 'ASCII:District du Pays d''Enhaut;ID:6458849', '12705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12705', '112', '14582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14583', '1079', '1', 'District de Conthey', 'CH.VS.2302', 'ASCII:District de Conthey;ID:6458850', '12706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12706', '112', '14583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14584', '1079', '1', 'Distretto di Bernina', 'CH.GR.1802', 'ASCII:Distretto di Bernina;ID:6458851', '12707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12707', '112', '14584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14585', '1079', '1', 'Bezirk Pfäffikon', 'CH.ZH.108', 'ASCII:Bezirk Pfaeffikon;ID:6458852', '12708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12708', '112', '14585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14586', '1079', '1', 'Rheinfelden', 'CH.AG.1909', 'ASCII:Rheinfelden;ID:6458853', '12709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12709', '112', '14586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14587', '1079', '1', 'Bezirk Liestal', 'CH.BL.1303', 'ASCII:Bezirk Liestal;ID:6458854', '12710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12710', '112', '14587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BL.1303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14588', '1079', '1', 'District de Morges', 'CH.VD.2209', 'ASCII:District de Morges;ID:6458855', '12711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12711', '112', '14588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14589', '1079', '1', 'Amt Fraubrunnen', 'CH.BE.209', 'ASCII:Amt Fraubrunnen;ID:6458856', '12712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12712', '112', '14589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14590', '1079', '1', 'District de Payerne', 'CH.VD.2214', 'ASCII:District de Payerne;ID:6458857', '12713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12713', '112', '14590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14591', '1079', '1', 'Bezirk Inn', 'CH.GR.1807', 'ASCII:Bezirk Inn;ID:6458858', '12714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12714', '112', '14591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14592', '1079', '1', 'District de la Vallée', 'CH.VD.2217', 'ASCII:District de la Vallee;ID:6458859', '12715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12715', '112', '14592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14593', '1079', '1', 'Bezirk Laufenburg', 'CH.AG.1906', 'ASCII:Bezirk Laufenburg;ID:6458860', '12716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12716', '112', '14593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14594', '1079', '1', 'Amt Schwarzenburg', 'CH.BE.221', 'ASCII:Amt Schwarzenburg;ID:6458861', '12717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12717', '112', '14594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14595', '1079', '1', 'District de la Veveyse', 'CH.FR.1007', 'ASCII:District de la Veveyse;ID:6458862', '12718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12718', '112', '14595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.FR.1007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14596', '1079', '1', 'Bezirk Vorderland', 'CH.AR.1503', 'ASCII:Bezirk Vorderland;ID:6458863', '12719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12719', '112', '14596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AR.1503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14597', '1079', '1', 'Bezirk Alttoggenburg', 'CH.SG.1711', 'ASCII:Bezirk Alttoggenburg;ID:6458864', '12720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12720', '112', '14597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14598', '1079', '1', 'Bezirk Dielsdorf', 'CH.ZH.104', 'ASCII:Bezirk Dielsdorf;ID:6458865', '12721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12721', '112', '14598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14599', '1079', '1', 'District de Lausanne', 'CH.VD.2207', 'ASCII:District de Lausanne;ID:6458866', '12722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12722', '112', '14599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14600', '1079', '1', 'Bezirk Bülach', 'CH.ZH.103', 'ASCII:Bezirk Buelach;ID:6458867', '12723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12723', '112', '14600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.ZH.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14601', '1079', '1', 'Bezirk Neutoggenburg', 'CH.SG.1710', 'ASCII:Bezirk Neutoggenburg;ID:6458868', '12724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12724', '112', '14601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14602', '1079', '1', 'Bezirk Thal', 'CH.SO.1102', 'ASCII:Bezirk Thal;ID:6458869', '12725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12725', '112', '14602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SO.1102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14603', '1079', '1', 'Distretto di Bellinzona', 'CH.TI.2101', 'ASCII:Distretto di Bellinzona;ID:6458870', '12726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12726', '112', '14603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TI.2101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14604', '1079', '1', 'Bezirk Bischofszell', 'CH.TG.2002', 'ASCII:Bezirk Bischofszell;ID:6458871', '12727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12727', '112', '14604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TG.2002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14605', '1079', '1', 'District d''Hérens', 'CH.VS.2305', 'ASCII:District d''Herens;ID:6458872', '12728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12728', '112', '14605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VS.2305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14606', '1079', '1', 'District de Courtelary', 'CH.BE.207', 'ASCII:District de Courtelary;ID:6458873', '12729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12729', '112', '14606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14607', '1079', '1', 'Bezirk Gösgen', 'CH.SO.1105', 'ASCII:Bezirk Goesgen;ID:6458874', '12730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12730', '112', '14607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SO.1105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14608', '1079', '1', 'District d''Orbe', 'CH.VD.2212', 'ASCII:District d''Orbe;ID:6458875', '12731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12731', '112', '14608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14609', '1079', '1', 'Amt Luzern', 'CH.LU.303', 'ASCII:Amt Luzern;ID:6458876', '12732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12732', '112', '14609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.LU.303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14610', '1079', '1', 'Amt Sursee', 'CH.LU.304', 'ASCII:Amt Sursee;ID:6458877', '12733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12733', '112', '14610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.LU.304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14611', '1079', '1', 'Bezirk Einsiedeln', 'CH.SZ.501', 'ASCII:Bezirk Einsiedeln;ID:6458878', '12734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12734', '112', '14611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SZ.501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14612', '1079', '1', 'Distict de Nyon', 'CH.VD.2211', 'ASCII:Distict de Nyon;ID:6458879', '12735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12735', '112', '14612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14613', '1079', '1', 'Bezirk Werdenberg', 'CH.SG.1705', 'ASCII:Bezirk Werdenberg;ID:6458880', '12736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12736', '112', '14613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14614', '1079', '1', 'Amt Saanen', 'CH.BE.220', 'ASCII:Amt Saanen;ID:6458882', '12737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12737', '112', '14614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.220» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14615', '1079', '1', 'Bezirk Plessur', 'CH.GR.1812', 'ASCII:Bezirk Plessur;ID:6458884', '12738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12738', '112', '14615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14616', '1079', '1', 'Bezirk Wasseramt', 'CH.SO.1106', 'ASCII:Bezirk Wasseramt;ID:6458885', '12739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12739', '112', '14616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SO.1106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14617', '1079', '1', 'District de Neuchâtel', 'CH.NE.2404', 'ASCII:District de Neuchatel;ID:6458886', '12740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12740', '112', '14617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.NE.2404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14618', '1079', '1', 'Amt Laupen', 'CH.BE.213', 'ASCII:Amt Laupen;ID:6458887', '12741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12741', '112', '14618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14619', '1079', '1', 'Bezirk Weinfelden', 'CH.TG.2008', 'ASCII:Bezirk Weinfelden;ID:6458888', '12742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12742', '112', '14619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TG.2008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14620', '1079', '1', 'District d''Yverdon', 'CH.VD.2219', 'ASCII:District d''Yverdon;ID:6458889', '12743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12743', '112', '14620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14621', '1079', '1', 'Amt Obersimmental', 'CH.BE.219', 'ASCII:Amt Obersimmental;ID:6458890', '12744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12744', '112', '14621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14622', '1079', '1', 'Bezirk Arbon', 'CH.TG.2001', 'ASCII:Bezirk Arbon;ID:6458891', '12745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12745', '112', '14622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TG.2001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14623', '1079', '1', 'Amt Burgdorf', 'CH.BE.206', 'ASCII:Amt Burgdorf;ID:6458892', '12746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12746', '112', '14623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14624', '1079', '1', 'Bezirk Olten', 'CH.SO.1108', 'ASCII:Bezirk Olten;ID:6458893', '12747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12747', '112', '14624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SO.1108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14625', '1079', '1', 'Distretto di Mendrisio', 'CH.TI.2106', 'ASCII:Distretto di Mendrisio;ID:6458894', '12748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12748', '112', '14625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TI.2106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14626', '1079', '1', 'Amt Aarberg', 'CH.BE.201', 'ASCII:Amt Aarberg;ID:6458895', '12749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12749', '112', '14626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14627', '1079', '1', 'District d''Aigle', 'CH.VD.2201', 'ASCII:District d''Aigle;ID:6458896', '12750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12750', '112', '14627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14628', '1079', '1', 'Bezirk Unterrheintal', 'CH.SG.1703', 'ASCII:Bezirk Unterrheintal;ID:6458897', '12751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12751', '112', '14628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SG.1703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14629', '1079', '1', 'Bezirk Sense', 'CH.FR.1006', 'ASCII:Bezirk Sense;ID:6458898', '12752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12752', '112', '14629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.FR.1006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14630', '1079', '1', 'Amt Entlebuch', 'CH.LU.301', 'ASCII:Amt Entlebuch;ID:6458899', '12753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12753', '112', '14630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.LU.301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14631', '1079', '1', 'District de Rolle', 'CH.VD.2216', 'ASCII:District de Rolle;ID:6458900', '12754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12754', '112', '14631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.VD.2216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14632', '1079', '1', 'Amt Nidau', 'CH.BE.216', 'ASCII:Amt Nidau;ID:6458901', '12755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12755', '112', '14632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14633', '1079', '1', 'Bezirk Muri', 'CH.AG.1908', 'ASCII:Bezirk Muri;ID:6458902', '12756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12756', '112', '14633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.AG.1908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14634', '1079', '1', 'Distretto di Leventina', 'CH.TI.2103', 'ASCII:Distretto di Leventina;ID:6458903', '12757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12757', '112', '14634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.TI.2103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14635', '1079', '1', 'Bezirk Dorneck', 'CH.SO.1104', 'ASCII:Bezirk Dorneck;ID:6458904', '12758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12758', '112', '14635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.SO.1104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14636', '1079', '1', 'Bezirk Imboden', 'CH.GR.1806', 'ASCII:Bezirk Imboden;ID:6458905', '12759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12759', '112', '14636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.GR.1806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14637', '1079', '1', 'Amt Frutigen', 'CH.BE.210', 'ASCII:Amt Frutigen;ID:6458906', '12760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12760', '112', '14637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14638', '1079', '1', 'Amt Signau', 'CH.BE.223', 'ASCII:Amt Signau;ID:6458907', '12761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12761', '112', '14638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14639', '1079', '1', 'Amt Erlach', 'CH.BE.208', 'ASCII:Amt Erlach;ID:6458908', '12762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12762', '112', '14639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CH.BE.208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14640', '1079', '1', 'Département de Zuénoula', 'CI.83.2279171', 'ASCII:Departement de Zuenoula;ID:2279171', '12763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12763', '112', '14640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.83.2279171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14641', '1079', '1', 'Département de Yamoussoukro', 'CI.81.2279754', 'ASCII:Departement de Yamoussoukro;ID:2279754', '12764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12764', '112', '14641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.81.2279754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14642', '1079', '1', 'Département de Vavoua', 'CI.80.2280044', 'ASCII:Departement de Vavoua;ID:2280044', '12765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12765', '112', '14642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.80.2280044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14643', '1079', '1', 'Département de Toumodi', 'CI.81.2280314', 'ASCII:Departement de Toumodi;ID:2280314', '12766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12766', '112', '14643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.81.2280314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14644', '1079', '1', 'Département de Touba', 'CI.75.2280373', 'ASCII:Departement de Touba;ID:2280373', '12767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12767', '112', '14644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.75.2280373» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14645', '1079', '1', 'Département de Tingréla', 'CI.87.2280588', 'ASCII:Departement de Tingrela;ID:2280588', '12768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12768', '112', '14645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.87.2280588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14646', '1079', '1', 'Département de Tiassalé', 'CI.82.2280760', 'ASCII:Departement de Tiassale;ID:2280760', '12769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12769', '112', '14646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.82.2280760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14647', '1079', '1', 'Département de Tanda', 'CI.92.2280994', 'ASCII:Departement de Tanda;ID:2280994', '12770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12770', '112', '14647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.92.2280994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14648', '1079', '1', 'Département de Tabou', 'CI.76.2281118', 'ASCII:Departement de Tabou;ID:2281118', '12771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12771', '112', '14648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.76.2281118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14649', '1079', '1', 'Département de Soubré', 'CI.76.2281288', 'ASCII:Departement de Soubre;ID:2281288', '12772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12772', '112', '14649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.76.2281288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14650', '1079', '1', 'Département de Sinfra', 'CI.83.2281605', 'ASCII:Departement de Sinfra;ID:2281605', '12773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12773', '112', '14650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.83.2281605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14651', '1079', '1', 'Sous-préfecture de Séguélon', 'CI.77.2281864', 'ASCII:Sous-prefecture de Seguelon;ID:2281864', '12774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12774', '112', '14651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.77.2281864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14652', '1079', '1', 'Département de Séguéla', 'CI.91.2281867', 'ASCII:Departement de Seguela;ID:2281867', '12775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12775', '112', '14652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.91.2281867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14653', '1079', '1', 'Département de Sassandra', 'CI.76.2281948', 'ASCII:Departement de Sassandra;ID:2281948', '12776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12776', '112', '14653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.76.2281948» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14654', '1079', '1', 'Département de San-Pédro', 'CI.76.2282004', 'ASCII:Departement de San-Pedro;ID:2282004', '12777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12777', '112', '14654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.76.2282004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14655', '1079', '1', 'Département de Sakassou', 'CI.90.2282171', 'ASCII:Departement de Sakassou;ID:2282171', '12778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12778', '112', '14655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.90.2282171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14656', '1079', '1', 'Département de Oumé', 'CI.79.2282826', 'ASCII:Departement de Oume;ID:2282826', '12779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12779', '112', '14656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.79.2282826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14657', '1079', '1', 'Département d'' Odienné', 'CI.77.2283015', 'ASCII:Departement d'' Odienne;ID:2283015', '12780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12780', '112', '14657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.77.2283015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14658', '1079', '1', 'Département de M''bahiakro', 'CI.86.2284488', 'ASCII:Departement de M''bahiakro;ID:2284488', '12781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12781', '112', '14658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.86.2284488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14659', '1079', '1', 'Département de Mankono', 'CI.91.2284587', 'ASCII:Departement de Mankono;ID:2284587', '12782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12782', '112', '14659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.91.2284587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14660', '1079', '1', 'Département de Man', 'CI.78.2284646', 'ASCII:Departement de Man;ID:2284646', '12783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12783', '112', '14660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.78.2284646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14661', '1079', '1', 'Département de Lakota', 'CI.88.2285448', 'ASCII:Departement de Lakota;ID:2285448', '12784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12784', '112', '14661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.88.2285448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14662', '1079', '1', 'Département de Korhogo', 'CI.87.2286303', 'ASCII:Departement de Korhogo;ID:2286303', '12785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12785', '112', '14662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.87.2286303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14663', '1079', '1', 'Département de Katiola', 'CI.90.2287296', 'ASCII:Departement de Katiola;ID:2287296', '12786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12786', '112', '14663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.90.2287296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14664', '1079', '1', 'Département de Issia', 'CI.80.2287789', 'ASCII:Departement de Issia;ID:2287789', '12787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12787', '112', '14664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.80.2287789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14665', '1079', '1', 'Département de Guiglo', 'CI.84.2287957', 'ASCII:Departement de Guiglo;ID:2287957', '12788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12788', '112', '14665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.84.2287957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14666', '1079', '1', 'Département de Grand-Lahou', 'CI.82.2288104', 'ASCII:Departement de Grand-Lahou;ID:2288104', '12789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12789', '112', '14666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.82.2288104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14667', '1079', '1', 'Département de Gagnoa', 'CI.79.2288828', 'ASCII:Departement de Gagnoa;ID:2288828', '12790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12790', '112', '14667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.79.2288828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14668', '1079', '1', 'Département de Ferkessédougou', 'CI.87.2289048', 'ASCII:Departement de Ferkessedougou;ID:2289048', '12791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12791', '112', '14668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.87.2289048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14669', '1079', '1', 'Département de Duékoué', 'CI.84.2289548', 'ASCII:Departement de Duekoue;ID:2289548', '12792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12792', '112', '14669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.84.2289548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14670', '1079', '1', 'Département de Divo', 'CI.88.2289886', 'ASCII:Departement de Divo;ID:2289886', '12793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12793', '112', '14670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.88.2289886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14671', '1079', '1', 'Département de Dimbokro', 'CI.86.2289981', 'ASCII:Departement de Dimbokro;ID:2289981', '12794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12794', '112', '14671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.86.2289981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14672', '1079', '1', 'Département de Daoukro', 'CI.86.2290410', 'ASCII:Departement de Daoukro;ID:2290410', '12795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12795', '112', '14672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.86.2290410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14673', '1079', '1', 'Département de Danané', 'CI.78.2290461', 'ASCII:Departement de Danane;ID:2290461', '12796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12796', '112', '14673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.78.2290461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14674', '1079', '1', 'Département de Daloa', 'CI.80.2290485', 'ASCII:Departement de Daloa;ID:2290485', '12797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12797', '112', '14674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.80.2290485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14675', '1079', '1', 'Département de Dabakala', 'CI.90.2290608', 'ASCII:Departement de Dabakala;ID:2290608', '12798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12798', '112', '14675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.90.2290608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14676', '1079', '1', 'Département de Boundiali', 'CI.87.2290835', 'ASCII:Departement de Boundiali;ID:2290835', '12799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12799', '112', '14676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.87.2290835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14677', '1079', '1', 'Département de Bouna', 'CI.92.2290847', 'ASCII:Departement de Bouna;ID:2290847', '12800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12800', '112', '14677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.92.2290847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14678', '1079', '1', 'Département de Bouaké', 'CI.90.2290954', 'ASCII:Departement de Bouake;ID:2290954', '12801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12801', '112', '14678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.90.2290954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14679', '1079', '1', 'Département de Bouaflé', 'CI.83.2290963', 'ASCII:Departement de Bouafle;ID:2290963', '12802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12802', '112', '14679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.83.2290963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14680', '1079', '1', 'Département de Bongouanou', 'CI.86.2291112', 'ASCII:Departement de Bongouanou;ID:2291112', '12803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12803', '112', '14680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.86.2291112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14681', '1079', '1', 'Département de Bondoukou', 'CI.92.2291135', 'ASCII:Departement de Bondoukou;ID:2291135', '12804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12804', '112', '14681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.92.2291135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14682', '1079', '1', 'Département de Biankouma', 'CI.78.2291665', 'ASCII:Departement de Biankouma;ID:2291665', '12805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12805', '112', '14682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.78.2291665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14683', '1079', '1', 'Département de Béoumi', 'CI.90.2291778', 'ASCII:Departement de Beoumi;ID:2291778', '12806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12806', '112', '14683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.90.2291778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14684', '1079', '1', 'Département de Bangolo', 'CI.78.2292178', 'ASCII:Departement de Bangolo;ID:2292178', '12807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12807', '112', '14684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.78.2292178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14685', '1079', '1', 'Département d'' Agnibilékrou', 'CI.85.2293259', 'ASCII:Departement d'' Agnibilekrou;ID:2293259', '12808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12808', '112', '14685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.85.2293259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14686', '1079', '1', 'Département d'' Agboville', 'CI.74.2293267', 'ASCII:Departement d'' Agboville;ID:2293267', '12809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12809', '112', '14686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.74.2293267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14687', '1079', '1', 'Département d'' Adzopé', 'CI.74.2293341', 'ASCII:Departement d'' Adzope;ID:2293341', '12810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12810', '112', '14687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.74.2293341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14688', '1079', '1', 'Département d'' Aboisso', 'CI.89.2293506', 'ASCII:Departement d'' Aboisso;ID:2293506', '12811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12811', '112', '14688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.89.2293506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14689', '1079', '1', 'Département d'' Abidjan', 'CI.82.2293537', 'ASCII:Departement d'' Abidjan;ID:2293537', '12812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12812', '112', '14689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.82.2293537» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14690', '1079', '1', 'Département d'' Abengourou', 'CI.85.2293545', 'ASCII:Departement d'' Abengourou;ID:2293545', '12813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12813', '112', '14690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.85.2293545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14691', '1079', '1', 'Département d'' Adiaké', 'CI.89.2595336', 'ASCII:Departement d'' Adiake;ID:2595336', '12814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12814', '112', '14691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.89.2595336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14692', '1079', '1', 'Département d'' Alépé', 'CI.82.2595337', 'ASCII:Departement d'' Alepe;ID:2595337', '12815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12815', '112', '14692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.82.2595337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14693', '1079', '1', 'Département de Bocanda', 'CI.86.2595338', 'ASCII:Departement de Bocanda;ID:2595338', '12816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12816', '112', '14693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.86.2595338» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14694', '1079', '1', 'Département de Dabou', 'CI.82.2595339', 'ASCII:Departement de Dabou;ID:2595339', '12817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12817', '112', '14694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.82.2595339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14695', '1079', '1', 'Département de Grand-Bassam', 'CI.89.2595340', 'ASCII:Departement de Grand-Bassam;ID:2595340', '12818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12818', '112', '14695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.89.2595340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14696', '1079', '1', 'Département de Jacqueville', 'CI.82.2595341', 'ASCII:Departement de Jacqueville;ID:2595341', '12819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12819', '112', '14696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.82.2595341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14697', '1079', '1', 'Département de Tiébissou', 'CI.81.2595342', 'ASCII:Departement de Tiebissou;ID:2595342', '12820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12820', '112', '14697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.81.2595342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14698', '1079', '1', 'Département de Toulépleu', 'CI.84.2595343', 'ASCII:Departement de Toulepleu;ID:2595343', '12821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12821', '112', '14698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CI.84.2595343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14699', '1079', '1', 'Provincia de Valparaíso', 'CL.01.3868623', 'ASCII:Provincia de Valparaiso;ID:3868623', '12822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12822', '112', '14699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.01.3868623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14700', '1079', '1', 'Provincia de Valdivia', 'CL.09.3868703', 'ASCII:Provincia de Valdivia;ID:3868703', '12823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12823', '112', '14700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.09.3868703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14701', '1079', '1', 'Provincia de Última Esperanza', 'CL.10.3868829', 'ASCII:Provincia de Ultima Esperanza;ID:3868829', '12824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12824', '112', '14701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.10.3868829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14702', '1079', '1', 'Provincia de Tocopilla', 'CL.03.3869715', 'ASCII:Provincia de Tocopilla;ID:3869715', '12825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12825', '112', '14702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.03.3869715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14703', '1079', '1', 'Provincia de Tierra del Fuego', 'CL.10.3869875', 'ASCII:Provincia de Tierra del Fuego;ID:3869875', '12826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12826', '112', '14703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.10.3869875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14704', '1079', '1', 'Provincia de Talca', 'CL.11.3870289', 'ASCII:Provincia de Talca;ID:3870289', '12827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12827', '112', '14704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.11.3870289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14705', '1079', '1', 'Departamento de Talagante', 'CL.12.3870304', 'ASCII:Departamento de Talagante;ID:3870304', '12828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12828', '112', '14705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.12.3870304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14706', '1079', '1', 'Departamento de Santiago', 'CL.12.3871332', 'ASCII:Departamento de Santiago;ID:3871332', '12829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12829', '112', '14706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.12.3871332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14707', '1079', '1', 'Provincia de San Felipe', 'CL.01.3872251', 'ASCII:Provincia de San Felipe;ID:3872251', '12830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12830', '112', '14707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.01.3872251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14708', '1079', '1', 'Departamento de San Bernardo', 'CL.12.3872345', 'ASCII:Departamento de San Bernardo;ID:3872345', '12831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12831', '112', '14708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.12.3872345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14709', '1079', '1', 'Provincia de San Antonio', 'CL.01.3872374', 'ASCII:Provincia de San Antonio;ID:3872374', '12832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12832', '112', '14709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.01.3872374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14710', '1079', '1', 'Provincia de Quillota', 'CL.01.3874118', 'ASCII:Provincia de Quillota;ID:3874118', '12833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12833', '112', '14710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.01.3874118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14711', '1079', '1', 'Departamento de Puente Alto', 'CL.12.3875022', 'ASCII:Departamento de Puente Alto;ID:3875022', '12834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12834', '112', '14711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.12.3875022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14712', '1079', '1', 'Departamento Presidente Aguirre Cerda', 'CL.12.3875192', 'ASCII:Departamento Presidente Aguirre Cerda;ID:3875192', '12835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12835', '112', '14712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.12.3875192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14713', '1079', '1', 'Provincia de Petorca', 'CL.01.3876415', 'ASCII:Provincia de Petorca;ID:3876415', '12836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12836', '112', '14713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.01.3876415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14714', '1079', '1', 'Provincia de Osorno', 'CL.09.3877946', 'ASCII:Provincia de Osorno;ID:3877946', '12837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12837', '112', '14714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.09.3877946» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14715', '1079', '1', 'Provincia de Ñuble', 'CL.06.3878472', 'ASCII:Provincia de Nuble;ID:3878472', '12838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12838', '112', '14715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.06.3878472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14716', '1079', '1', 'Departamento de Melipilla', 'CL.12.3880106', 'ASCII:Departamento de Melipilla;ID:3880106', '12839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12839', '112', '14716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.12.3880106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14717', '1079', '1', 'Provincia de Malleco', 'CL.04.3880842', 'ASCII:Provincia de Malleco;ID:3880842', '12840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12840', '112', '14717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.04.3880842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14718', '1079', '1', 'Departamento de Maipo', 'CL.12.3880987', 'ASCII:Departamento de Maipo;ID:3880987', '12841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12841', '112', '14718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.12.3880987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14719', '1079', '1', 'Provincia de Magallanes', 'CL.10.3881037', 'ASCII:Provincia de Magallanes;ID:3881037', '12842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12842', '112', '14719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.10.3881037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14720', '1079', '1', 'Provincia de Los Andes', 'CL.01.3882432', 'ASCII:Provincia de Los Andes;ID:3882432', '12843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12843', '112', '14720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.01.3882432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14721', '1079', '1', 'Departamento de Lontué', 'CL.11.3882529', 'ASCII:Departamento de Lontue;ID:3882529', '12844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12844', '112', '14721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.11.3882529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14722', '1079', '1', 'Departamento de Loncomilla', 'CL.11.3882579', 'ASCII:Departamento de Loncomilla;ID:3882579', '12845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12845', '112', '14722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.11.3882579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14723', '1079', '1', 'Provincia de Llanquihue', 'CL.09.3882955', 'ASCII:Provincia de Llanquihue;ID:3882955', '12846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12846', '112', '14723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.09.3882955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14724', '1079', '1', 'Provincia de Linares', 'CL.11.3883166', 'ASCII:Provincia de Linares;ID:3883166', '12847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12847', '112', '14724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.11.3883166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14725', '1079', '1', 'Provincia de Limarí', 'CL.07.3883200', 'ASCII:Provincia de Limari;ID:3883200', '12848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12848', '112', '14725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.07.3883200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14726', '1079', '1', 'Departamento de Lebu', 'CL.06.3883456', 'ASCII:Departamento de Lebu;ID:3883456', '12849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12849', '112', '14726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.06.3883456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14727', '1079', '1', 'Departamento de Lautaro', 'CL.04.3883611', 'ASCII:Departamento de Lautaro;ID:3883611', '12850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12850', '112', '14727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.04.3883611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14728', '1079', '1', 'Departamento de La Unión', 'CL.09.3883627', 'ASCII:Departamento de La Union;ID:3883627', '12851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12851', '112', '14728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.09.3883627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14729', '1079', '1', 'Provincia de Iquique', 'CL.13.3887125', 'ASCII:Provincia de Iquique;ID:3887125', '12852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12852', '112', '14729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.13.3887125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14730', '1079', '1', 'Provincia de Huasco', 'CL.05.3887756', 'ASCII:Provincia de Huasco;ID:3887756', '12853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12853', '112', '14730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.05.3887756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14731', '1079', '1', 'Provincia General Carrera', 'CL.02.3889024', 'ASCII:Provincia General Carrera;ID:3889024', '12854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12854', '112', '14731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.02.3889024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14732', '1079', '1', 'Provincia de Elqui', 'CL.07.3890620', 'ASCII:Provincia de Elqui;ID:3890620', '12855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12855', '112', '14732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.07.3890620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14733', '1079', '1', 'Provincia de El Loa', 'CL.03.3891149', 'ASCII:Provincia de El Loa;ID:3891149', '12856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12856', '112', '14733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.03.3891149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14734', '1079', '1', 'Provincia de Curicó', 'CL.11.3892868', 'ASCII:Provincia de Curico;ID:3892868', '12857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12857', '112', '14734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.11.3892868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14735', '1079', '1', 'Provincia de Copiapó', 'CL.05.3893653', 'ASCII:Provincia de Copiapo;ID:3893653', '12858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12858', '112', '14735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.05.3893653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14736', '1079', '1', 'Provincia de Concepción', 'CL.06.3893889', 'ASCII:Provincia de Concepcion;ID:3893889', '12859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12859', '112', '14736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.06.3893889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14737', '1079', '1', 'Provincia de Colchagua', 'CL.08.3894310', 'ASCII:Provincia de Colchagua;ID:3894310', '12860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12860', '112', '14737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.08.3894310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14738', '1079', '1', 'Provincia de Choapa', 'CL.07.3894914', 'ASCII:Provincia de Choapa;ID:3894914', '12861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12861', '112', '14738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.07.3894914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14739', '1079', '1', 'Provincia de Chiloé', 'CL.09.3895070', 'ASCII:Provincia de Chiloe;ID:3895070', '12862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12862', '112', '14739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.09.3895070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14740', '1079', '1', 'Provincia de Chañaral', 'CL.05.3895547', 'ASCII:Provincia de Chanaral;ID:3895547', '12863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12863', '112', '14740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.05.3895547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14741', '1079', '1', 'Provincia de Cautín', 'CL.04.3896095', 'ASCII:Provincia de Cautin;ID:3896095', '12864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12864', '112', '14741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.04.3896095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14742', '1079', '1', 'Provincia Capitán Prat', 'CL.02.3896832', 'ASCII:Provincia Capitan Prat;ID:3896832', '12865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12865', '112', '14742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.02.3896832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14743', '1079', '1', 'Provincia de Cachapoal', 'CL.08.3897525', 'ASCII:Provincia de Cachapoal;ID:3897525', '12866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12866', '112', '14743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.08.3897525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14744', '1079', '1', 'Provincia de Biobío', 'CL.06.3898381', 'ASCII:Provincia de Biobio;ID:3898381', '12867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12867', '112', '14744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.06.3898381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14745', '1079', '1', 'Provincia de Arica', 'CL.13.3899358', 'ASCII:Provincia de Arica;ID:3899358', '12868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12868', '112', '14745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.13.3899358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14746', '1079', '1', 'Provincia de Arauco', 'CL.06.3899459', 'ASCII:Provincia de Arauco;ID:3899459', '12869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12869', '112', '14746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.06.3899459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14747', '1079', '1', 'Provincia de Antofagasta', 'CL.03.3899538', 'ASCII:Provincia de Antofagasta;ID:3899538', '12870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12870', '112', '14747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.03.3899538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14748', '1079', '1', 'Provincia de Aisén', 'CL.02.3900336', 'ASCII:Provincia de Aisen;ID:3900336', '12871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12871', '112', '14748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.02.3900336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14749', '1079', '1', 'Provincia de Isla de Pascua', 'CL.01.4030752', 'ASCII:Provincia de Isla de Pascua;ID:4030752', '12872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12872', '112', '14749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.01.4030752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14750', '1079', '1', 'Provincia Antártica Chilena', 'CL.10.4036651', 'ASCII:Provincia Antartica Chilena;ID:4036651', '12873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12873', '112', '14750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.10.4036651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14751', '1079', '1', 'Provincia de Ranco', 'CL.09.6693564', 'ASCII:Provincia de Ranco;ID:6693564', '12874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12874', '112', '14751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CL.09.6693564» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14752', '1079', '1', 'Département du Wouri', 'CM.00.2221059', 'ASCII:Departement du Wouri;ID:2221059', '12875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12875', '112', '14752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2221059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14753', '1079', '1', 'Département de la Sanaga-Maritime', 'CM.00.2222269', 'ASCII:Departement de la Sanaga-Maritime;ID:2222269', '12876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12876', '112', '14753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2222269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14754', '1079', '1', 'Département du Nyong-et-Soo', 'CM.00.2223327', 'ASCII:Departement du Nyong-et-Soo;ID:2223327', '12877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12877', '112', '14754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2223327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14755', '1079', '1', 'Département du Nyong-et-Mfoumou', 'CM.00.2223329', 'ASCII:Departement du Nyong-et-Mfoumou;ID:2223329', '12878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12878', '112', '14755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2223329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14756', '1079', '1', 'Département du Nyong-et-Kéllé', 'CM.00.2223330', 'ASCII:Departement du Nyong-et-Kelle;ID:2223330', '12879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12879', '112', '14756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2223330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14757', '1079', '1', 'Département du Ntem', 'CM.00.2223478', 'ASCII:Departement du Ntem;ID:2223478', '12880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12880', '112', '14757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2223478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14758', '1079', '1', 'Département du Nkam', 'CM.00.2224165', 'ASCII:Departement du Nkam;ID:2224165', '12881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12881', '112', '14758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2224165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14759', '1079', '1', 'Ndian Division', 'CM.00.2225280', 'ASCII:Ndian Division;ID:2225280', '12882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12882', '112', '14759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2225280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14760', '1079', '1', 'Département du Ndé', 'CM.00.2225334', 'ASCII:Departement du Nde;ID:2225334', '12883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12883', '112', '14760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2225334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14761', '1079', '1', 'Département du Mungo', 'CM.00.2225744', 'ASCII:Departement du Mungo;ID:2225744', '12884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12884', '112', '14761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2225744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14762', '1079', '1', 'Momo Division', 'CM.00.2226140', 'ASCII:Momo Division;ID:2226140', '12885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12885', '112', '14762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2226140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14763', '1079', '1', 'Département de Mifi', 'CM.00.2226712', 'ASCII:Departement de Mifi;ID:2226712', '12886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12886', '112', '14763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2226712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14764', '1079', '1', 'Mezam Division', 'CM.00.2226830', 'ASCII:Mezam Division;ID:2226830', '12887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12887', '112', '14764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2226830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14765', '1079', '1', 'Metchum Division', 'CM.00.2226947', 'ASCII:Metchum Division;ID:2226947', '12888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12888', '112', '14765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2226947» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14766', '1079', '1', 'Département de la Ménoua', 'CM.00.2227064', 'ASCII:Departement de la Menoua;ID:2227064', '12889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12889', '112', '14766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2227064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14767', '1079', '1', 'Meme Division', 'CM.00.2227197', 'ASCII:Meme Division;ID:2227197', '12890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12890', '112', '14767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2227197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14768', '1079', '1', 'Département de la Méfou', 'CM.00.2227419', 'ASCII:Departement de la Mefou;ID:2227419', '12891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12891', '112', '14768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2227419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14769', '1079', '1', 'Département du Mbam', 'CM.00.2228070', 'ASCII:Departement du Mbam;ID:2228070', '12892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12892', '112', '14769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2228070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14770', '1079', '1', 'Département du Mayo Danaï', 'CM.00.2228217', 'ASCII:Departement du Mayo Danai;ID:2228217', '12893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12893', '112', '14770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2228217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14771', '1079', '1', 'Département du Margui-Wandala', 'CM.00.2228394', 'ASCII:Departement du Margui-Wandala;ID:2228394', '12894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12894', '112', '14771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2228394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14772', '1079', '1', 'Manyu Division', 'CM.00.2228442', 'ASCII:Manyu Division;ID:2228442', '12895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12895', '112', '14772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2228442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14773', '1079', '1', 'Département du Lom-et-Kadeï', 'CM.00.2229250', 'ASCII:Departement du Lom-et-Kadei;ID:2229250', '12896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12896', '112', '14773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2229250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14774', '1079', '1', 'Département du Lom-et-Djérem', 'CM.00.2229251', 'ASCII:Departement du Lom-et-Djerem;ID:2229251', '12897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12897', '112', '14774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2229251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14775', '1079', '1', 'Département du Logone-et-Chari', 'CM.00.2229291', 'ASCII:Departement du Logone-et-Chari;ID:2229291', '12898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12898', '112', '14775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2229291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14776', '1079', '1', 'Département de la Lékié', 'CM.00.2229546', 'ASCII:Departement de la Lekie;ID:2229546', '12899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12899', '112', '14776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2229546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14777', '1079', '1', 'Département de Kribi', 'CM.00.2229760', 'ASCII:Departement de Kribi;ID:2229760', '12900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12900', '112', '14777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2229760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14778', '1079', '1', 'Département de la Kadeï', 'CM.00.2230606', 'ASCII:Departement de la Kadei;ID:2230606', '12901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12901', '112', '14778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2230606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14779', '1079', '1', 'Departement du Haut-Nyong', 'CM.00.2230815', 'ASCII:Departement du Haut-Nyong;ID:2230815', '12902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12902', '112', '14779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2230815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14780', '1079', '1', 'Département du Haut-Nkam', 'CM.00.2230816', 'ASCII:Departement du Haut-Nkam;ID:2230816', '12903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12903', '112', '14780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2230816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14781', '1079', '1', 'Département de la Haute-Sanaga', 'CM.00.2230817', 'ASCII:Departement de la Haute-Sanaga;ID:2230817', '12904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12904', '112', '14781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2230817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14782', '1079', '1', 'Fako Division', 'CM.00.2231710', 'ASCII:Fako Division;ID:2231710', '12905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12905', '112', '14782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2231710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14783', '1079', '1', 'Donga and Mantung Division', 'CM.00.2232640', 'ASCII:Donga and Mantung Division;ID:2232640', '12906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12906', '112', '14783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2232640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14784', '1079', '1', 'Département du Dja-et-Lobo', 'CM.00.2232969', 'ASCII:Departement du Dja-et-Lobo;ID:2232969', '12907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12907', '112', '14784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2232969» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14785', '1079', '1', 'Département du Diamaré', 'CM.00.2233122', 'ASCII:Departement du Diamare;ID:2233122', '12908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12908', '112', '14785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2233122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14786', '1079', '1', 'Bui Division', 'CM.00.2233408', 'ASCII:Bui Division;ID:2233408', '12909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12909', '112', '14786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2233408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14787', '1079', '1', 'Département de la Boumba-Ngoko', 'CM.00.2233500', 'ASCII:Departement de la Boumba-Ngoko;ID:2233500', '12910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12910', '112', '14787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2233500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14788', '1079', '1', 'Département de la Bénoué', 'CM.00.2234396', 'ASCII:Departement de la Benoue;ID:2234396', '12911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12911', '112', '14788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2234396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14789', '1079', '1', 'Département de Bamoun', 'CM.00.2234948', 'ASCII:Departement de Bamoun;ID:2234948', '12912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12912', '112', '14789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2234948» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14790', '1079', '1', 'Département de Bamboutos', 'CM.00.2234988', 'ASCII:Departement de Bamboutos;ID:2234988', '12913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12913', '112', '14790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2234988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14791', '1079', '1', 'Département de l'' Adamaoua', 'CM.00.2236016', 'ASCII:Departement de l'' Adamaoua;ID:2236016', '12914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12914', '112', '14791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CM.00.2236016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14792', '1079', '1', 'Yushu Zangzu Zizhizhou', 'CN.06.1279540', 'ASCII:Yushu Zangzu Zizhizhou;ID:1279540', '12915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12915', '112', '14792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.06.1279540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14793', '1079', '1', 'Xigazê Diqu', 'CN.14.1279714', 'ASCII:Xigaze Diqu;ID:1279714', '12916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12916', '112', '14793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.14.1279714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14794', '1079', '1', 'Shannan Diqu', 'CN.14.1280019', 'ASCII:Shannan Diqu;ID:1280019', '12917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12917', '112', '14794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.14.1280019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14795', '1079', '1', 'Qamdo Diqu', 'CN.14.1280280', 'ASCII:Qamdo Diqu;ID:1280280', '12918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12918', '112', '14795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.14.1280280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14796', '1079', '1', 'Nyingchi Diqu', 'CN.14.1280390', 'ASCII:Nyingchi Diqu;ID:1280390', '12919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12919', '112', '14796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.14.1280390» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14797', '1079', '1', 'Nujiang Lisuzu Zizhizhou', 'CN.29.1280418', 'ASCII:Nujiang Lisuzu Zizhizhou;ID:1280418', '12920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12920', '112', '14797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1280418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14798', '1079', '1', 'Ngari Diqu', 'CN.14.1280456', 'ASCII:Ngari Diqu;ID:1280456', '12921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12921', '112', '14798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.14.1280456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14799', '1079', '1', 'Nagqu Diqu', 'CN.14.1280515', 'ASCII:Nagqu Diqu;ID:1280515', '12922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12922', '112', '14799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.14.1280515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14800', '1079', '1', 'Lhasa Shi', 'CN.14.1280735', 'ASCII:Lhasa Shi;ID:1280735', '12923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12923', '112', '14800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.14.1280735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14801', '1079', '1', 'Kizilsu Kirgiz Zizhizhou', 'CN.13.1280828', 'ASCII:Kizilsu Kirgiz Zizhizhou;ID:1280828', '12924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12924', '112', '14801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1280828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14802', '1079', '1', 'Kashi Diqu', 'CN.13.1280848', 'ASCII:Kashi Diqu;ID:1280848', '12925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12925', '112', '14802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1280848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14803', '1079', '1', 'Jiuquan Shi', 'CN.15.1280931', 'ASCII:Jiuquan Shi;ID:1280931', '12926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12926', '112', '14803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1280931» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14804', '1079', '1', 'Jiayuguan Shi', 'CN.15.1280956', 'ASCII:Jiayuguan Shi;ID:1280956', '12927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12927', '112', '14804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1280956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14805', '1079', '1', 'Hotan Diqu', 'CN.13.1281018', 'ASCII:Hotan Diqu;ID:1281018', '12928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12928', '112', '14805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1281018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14806', '1079', '1', 'Haixi Mongolzu Zangzu Zizhizhou', 'CN.06.1281075', 'ASCII:Haixi Mongolzu Zangzu Zizhizhou;ID:1281075', '12929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12929', '112', '14806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.06.1281075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14807', '1079', '1', 'Golog Zangzu Zizhizhou', 'CN.06.1281178', 'ASCII:Golog Zangzu Zizhizhou;ID:1281178', '12930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12930', '112', '14807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.06.1281178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14808', '1079', '1', 'Dêqên Zangzu Zizhizhou', 'CN.29.1281365', 'ASCII:Deqen Zangzu Zizhizhou;ID:1281365', '12931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12931', '112', '14808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1281365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14809', '1079', '1', 'Dehong Daizu Jingpozu Zizhizhou', 'CN.29.1281381', 'ASCII:Dehong Daizu Jingpozu Zizhizhou;ID:1281381', '12932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12932', '112', '14809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1281381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14810', '1079', '1', 'Baoshan Shi', 'CN.29.1281672', 'ASCII:Baoshan Shi;ID:1281672', '12933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12933', '112', '14810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1281672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14811', '1079', '1', 'Ürümqi Shi', 'CN.13.1529101', 'ASCII:Urumqi Shi;ID:1529101', '12934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12934', '112', '14811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14812', '1079', '1', 'Turpan Diqu', 'CN.13.1529113', 'ASCII:Turpan Diqu;ID:1529113', '12935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12935', '112', '14812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14813', '1079', '1', 'Tacheng Diqu', 'CN.13.1529166', 'ASCII:Tacheng Diqu;ID:1529166', '12936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12936', '112', '14813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14814', '1079', '1', 'Karamay Shi', 'CN.13.1529400', 'ASCII:Karamay Shi;ID:1529400', '12937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12937', '112', '14814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14815', '1079', '1', 'Ili Kazak Zizhizhou', 'CN.13.1529434', 'ASCII:Ili Kazak Zizhizhou;ID:1529434', '12938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12938', '112', '14815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529434» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14816', '1079', '1', 'Ili Diqu', 'CN.13.1529435', 'ASCII:Ili Diqu;ID:1529435', '12939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12939', '112', '14816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14817', '1079', '1', 'Hami Diqu', 'CN.13.1529483', 'ASCII:Hami Diqu;ID:1529483', '12940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12940', '112', '14817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14818', '1079', '1', 'Changji Huizu Zizhizhou', 'CN.13.1529568', 'ASCII:Changji Huizu Zizhizhou;ID:1529568', '12941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12941', '112', '14818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14819', '1079', '1', 'Bortala Mongol Zizhizhou', 'CN.13.1529581', 'ASCII:Bortala Mongol Zizhizhou;ID:1529581', '12942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12942', '112', '14819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14820', '1079', '1', 'Bayingolin Mongol Zizhizhou', 'CN.13.1529604', 'ASCII:Bayingolin Mongol Zizhizhou;ID:1529604', '12943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12943', '112', '14820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14821', '1079', '1', 'Altay Diqu', 'CN.13.1529650', 'ASCII:Altay Diqu;ID:1529650', '12944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12944', '112', '14821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14822', '1079', '1', 'Aksu Diqu', 'CN.13.1529658', 'ASCII:Aksu Diqu;ID:1529658', '12945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12945', '112', '14822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.13.1529658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14823', '1079', '1', 'Zunyi Shi', 'CN.18.1783620', 'ASCII:Zunyi Shi;ID:1783620', '12946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12946', '112', '14823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.18.1783620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14824', '1079', '1', 'Zigong Shi', 'CN.32.1783744', 'ASCII:Zigong Shi;ID:1783744', '12947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12947', '112', '14824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1783744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14825', '1079', '1', 'Zibo Shi', 'CN.25.1783751', 'ASCII:Zibo Shi;ID:1783751', '12948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12948', '112', '14825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1783751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14826', '1079', '1', 'Zhuzhou Shi', 'CN.11.1783761', 'ASCII:Zhuzhou Shi;ID:1783761', '12949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12949', '112', '14826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1783761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14827', '1079', '1', 'Zhumadian Shi', 'CN.09.1783872', 'ASCII:Zhumadian Shi;ID:1783872', '12950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12950', '112', '14827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1783872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14828', '1079', '1', 'Zhuhai Shi', 'CN.30.1783950', 'ASCII:Zhuhai Shi;ID:1783950', '12951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12951', '112', '14828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1783950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14829', '1079', '1', 'Zhoushan Shi', 'CN.02.1784107', 'ASCII:Zhoushan Shi;ID:1784107', '12952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12952', '112', '14829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1784107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14830', '1079', '1', 'Zhoukou Shi', 'CN.09.1784128', 'ASCII:Zhoukou Shi;ID:1784128', '12953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12953', '112', '14830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1784128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14831', '1079', '1', 'Zhongshan Shi', 'CN.30.1784313', 'ASCII:Zhongshan Shi;ID:1784313', '12954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12954', '112', '14831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1784313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14832', '1079', '1', 'Zhenjiang Shi', 'CN.04.1784640', 'ASCII:Zhenjiang Shi;ID:1784640', '12955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12955', '112', '14832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1784640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14833', '1079', '1', 'Zhengzhou Shi', 'CN.09.1784657', 'ASCII:Zhengzhou Shi;ID:1784657', '12956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12956', '112', '14833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1784657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14834', '1079', '1', 'Zhaotong Shi', 'CN.29.1784839', 'ASCII:Zhaotong Shi;ID:1784839', '12957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12957', '112', '14834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1784839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14835', '1079', '1', 'Zhaotong Diqu', 'CN.29.1784840', 'ASCII:Zhaotong Diqu;ID:1784840', '12958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12958', '112', '14835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1784840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14836', '1079', '1', 'Zhaoqing Shi', 'CN.30.1784852', 'ASCII:Zhaoqing Shi;ID:1784852', '12959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12959', '112', '14836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1784852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14837', '1079', '1', 'Zhanjiang Shi', 'CN.30.1784987', 'ASCII:Zhanjiang Shi;ID:1784987', '12960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12960', '112', '14837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1784987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14838', '1079', '1', 'Zhangzhou Shi', 'CN.07.1785017', 'ASCII:Zhangzhou Shi;ID:1785017', '12961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12961', '112', '14838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.07.1785017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14839', '1079', '1', 'Zhangye Shi', 'CN.15.1785035', 'ASCII:Zhangye Shi;ID:1785035', '12962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12962', '112', '14839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1785035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14840', '1079', '1', 'Zaozhuang Shi', 'CN.25.1785450', 'ASCII:Zaozhuang Shi;ID:1785450', '12963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12963', '112', '14840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1785450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14841', '1079', '1', 'Yuxi Shi', 'CN.29.1785551', 'ASCII:Yuxi Shi;ID:1785551', '12964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12964', '112', '14841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1785551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14842', '1079', '1', 'Yuxi Diqu', 'CN.29.1785559', 'ASCII:Yuxi Diqu;ID:1785559', '12965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12965', '112', '14842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1785559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14843', '1079', '1', 'Yunfu Shi', 'CN.30.1785723', 'ASCII:Yunfu Shi;ID:1785723', '12966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12966', '112', '14843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1785723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14844', '1079', '1', 'Yuncheng Shi', 'CN.24.1785736', 'ASCII:Yuncheng Shi;ID:1785736', '12967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12967', '112', '14844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.1785736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14845', '1079', '1', 'Yulin Shi', 'CN.26.1785769', 'ASCII:Yulin Shi;ID:1785769', '12968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12968', '112', '14845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.26.1785769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14846', '1079', '1', 'Yulin Diqu', 'CN.16.1785770', 'ASCII:Yulin Diqu;ID:1785770', '12969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12969', '112', '14846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1785770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14847', '1079', '1', 'Yueyang Shi', 'CN.11.1785881', 'ASCII:Yueyang Shi;ID:1785881', '12970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12970', '112', '14847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1785881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14848', '1079', '1', 'Yongzhou Shi', 'CN.11.1786216', 'ASCII:Yongzhou Shi;ID:1786216', '12971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12971', '112', '14848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1786216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14849', '1079', '1', 'Yiyang Shi', 'CN.11.1786419', 'ASCII:Yiyang Shi;ID:1786419', '12972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12972', '112', '14849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1786419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14850', '1079', '1', 'Wuzhong Shi', 'CN.21.1786512', 'ASCII:Wuzhong Shi;ID:1786512', '12973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12973', '112', '14850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.21.1786512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14851', '1079', '1', 'Yingtan Shi', 'CN.03.1786576', 'ASCII:Yingtan Shi;ID:1786576', '12974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12974', '112', '14851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1786576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14852', '1079', '1', 'Yinchuan Shi', 'CN.21.1786656', 'ASCII:Yinchuan Shi;ID:1786656', '12975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12975', '112', '14852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.21.1786656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14853', '1079', '1', 'Yichun Shi', 'CN.03.1786745', 'ASCII:Yichun Shi;ID:1786745', '12976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12976', '112', '14853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1786745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14854', '1079', '1', 'Yichang Shi', 'CN.12.1786761', 'ASCII:Yichang Shi;ID:1786761', '12977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12977', '112', '14854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1786761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14855', '1079', '1', 'Yibin Shi', 'CN.32.1786769', 'ASCII:Yibin Shi;ID:1786769', '12978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12978', '112', '14855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1786769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14856', '1079', '1', 'Yantai Shi', 'CN.25.1787083', 'ASCII:Yantai Shi;ID:1787083', '12979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12979', '112', '14856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1787083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14857', '1079', '1', 'Yangzhou Shi', 'CN.04.1787226', 'ASCII:Yangzhou Shi;ID:1787226', '12980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12980', '112', '14857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1787226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14858', '1079', '1', 'Yangquan Shi', 'CN.24.1787346', 'ASCII:Yangquan Shi;ID:1787346', '12981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12981', '112', '14858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.1787346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14859', '1079', '1', 'Yangjiang Shi', 'CN.30.1787530', 'ASCII:Yangjiang Shi;ID:1787530', '12982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12982', '112', '14859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1787530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14860', '1079', '1', 'Yancheng Shi', 'CN.04.1787743', 'ASCII:Yancheng Shi;ID:1787743', '12983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12983', '112', '14860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1787743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14861', '1079', '1', 'Yan’an Shi', 'CN.26.1787763', 'ASCII:Yan''an Shi;ID:1787763', '12984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12984', '112', '14861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.26.1787763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14862', '1079', '1', 'Ya’an Shi', 'CN.32.1787815', 'ASCII:Ya''an Shi;ID:1787815', '12985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12985', '112', '14862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1787815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14863', '1079', '1', 'Xuzhou Shi', 'CN.04.1787823', 'ASCII:Xuzhou Shi;ID:1787823', '12986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12986', '112', '14863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1787823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14864', '1079', '1', 'Xuchang Shi', 'CN.09.1788045', 'ASCII:Xuchang Shi;ID:1788045', '12987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12987', '112', '14864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1788045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14865', '1079', '1', 'Xuancheng Shi', 'CN.01.1788080', 'ASCII:Xuancheng Shi;ID:1788080', '12988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12988', '112', '14865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1788080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14866', '1079', '1', 'Xishuangbanna Daizu Zizhizhou', 'CN.29.1788323', 'ASCII:Xishuangbanna Daizu Zizhizhou;ID:1788323', '12989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12989', '112', '14866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1788323» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14867', '1079', '1', 'Xinyu Shi', 'CN.03.1788505', 'ASCII:Xinyu Shi;ID:1788505', '12990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12990', '112', '14867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1788505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14868', '1079', '1', 'Xinyang Shi', 'CN.09.1788527', 'ASCII:Xinyang Shi;ID:1788527', '12991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12991', '112', '14868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1788527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14869', '1079', '1', 'Xinyang Diqu', 'CN.09.1788532', 'ASCII:Xinyang Diqu;ID:1788532', '12992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12992', '112', '14869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1788532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14870', '1079', '1', 'Xinxiang Shi', 'CN.09.1788571', 'ASCII:Xinxiang Shi;ID:1788571', '12993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12993', '112', '14870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1788571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14871', '1079', '1', 'Xining Shi', 'CN.06.1788850', 'ASCII:Xining Shi;ID:1788850', '12994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12994', '112', '14871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.06.1788850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14872', '1079', '1', 'Xingtai Shi', 'CN.10.1788925', 'ASCII:Xingtai Shi;ID:1788925', '12995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12995', '112', '14872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1788925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14873', '1079', '1', 'Xiaogan Shi', 'CN.12.1790253', 'ASCII:Xiaogan Shi;ID:1790253', '12996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12996', '112', '14873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1790253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14874', '1079', '1', 'Xianyang Shi', 'CN.26.1790352', 'ASCII:Xianyang Shi;ID:1790352', '12997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12997', '112', '14874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.26.1790352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14875', '1079', '1', 'Xi’an Shi', 'CN.26.1790384', 'ASCII:Xi''an Shi;ID:1790384', '12998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12998', '112', '14875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.26.1790384» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14876', '1079', '1', 'Xianning Shi', 'CN.12.1790395', 'ASCII:Xianning Shi;ID:1790395', '12999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('12999', '112', '14876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1790395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14877', '1079', '1', 'Xiangxi Tujiazu Miaozu Zizhizhou', 'CN.11.1790468', 'ASCII:Xiangxi Tujiazu Miaozu Zizhizhou;ID:1790468', '13000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13000', '112', '14877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1790468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14878', '1079', '1', 'Xiangtan Shi', 'CN.11.1790484', 'ASCII:Xiangtan Shi;ID:1790484', '13001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13001', '112', '14878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1790484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14879', '1079', '1', 'Xiangfan Shi', 'CN.12.1790585', 'ASCII:Xiangfan Shi;ID:1790585', '13002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13002', '112', '14879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1790585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14880', '1079', '1', 'Xiamen Shi', 'CN.07.1790638', 'ASCII:Xiamen Shi;ID:1790638', '13003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13003', '112', '14880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.07.1790638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14881', '1079', '1', 'Wuzhou Shi', 'CN.16.1790838', 'ASCII:Wuzhou Shi;ID:1790838', '13004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13004', '112', '14881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1790838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14882', '1079', '1', 'Wuzhou Diqu', 'CN.16.1790839', 'ASCII:Wuzhou Diqu;ID:1790839', '13005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13005', '112', '14882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1790839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14883', '1079', '1', 'Wuxi Shi', 'CN.04.1790902', 'ASCII:Wuxi Shi;ID:1790902', '13006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13006', '112', '14883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1790902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14884', '1079', '1', 'Wuwei Shi', 'CN.15.1790930', 'ASCII:Wuwei Shi;ID:1790930', '13007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13007', '112', '14884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1790930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14885', '1079', '1', 'Wusong Qu', 'CN.23.1790964', 'ASCII:Wusong Qu;ID:1790964', '13008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13008', '112', '14885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.23.1790964» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14886', '1079', '1', 'Wuhu Shi', 'CN.01.1791227', 'ASCII:Wuhu Shi;ID:1791227', '13009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13009', '112', '14886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1791227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14887', '1079', '1', 'Wuhan Shi', 'CN.12.1791243', 'ASCII:Wuhan Shi;ID:1791243', '13010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13010', '112', '14887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1791243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14888', '1079', '1', 'Wuhai Shi', 'CN.20.1791248', 'ASCII:Wuhai Shi;ID:1791248', '13011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13011', '112', '14888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.1791248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14889', '1079', '1', 'Wenzhou Shi', 'CN.02.1791385', 'ASCII:Wenzhou Shi;ID:1791385', '13012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13012', '112', '14889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1791385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14890', '1079', '1', 'Wenshan Zhuangzu Miaozu Zizhizhou', 'CN.29.1791424', 'ASCII:Wenshan Zhuangzu Miaozu Zizhizhou;ID:1791424', '13013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13013', '112', '14890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1791424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14891', '1079', '1', 'Weinan Shi', 'CN.26.1791635', 'ASCII:Weinan Shi;ID:1791635', '13014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13014', '112', '14891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.26.1791635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14892', '1079', '1', 'Weihai Shi', 'CN.25.1791671', 'ASCII:Weihai Shi;ID:1791671', '13015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13015', '112', '14892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1791671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14893', '1079', '1', 'Weifang Shi', 'CN.25.1791680', 'ASCII:Weifang Shi;ID:1791680', '13016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13016', '112', '14893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1791680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14894', '1079', '1', 'Tongren Diqu', 'CN.18.1792591', 'ASCII:Tongren Diqu;ID:1792591', '13017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13017', '112', '14894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.18.1792591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14895', '1079', '1', 'Tongling Shi', 'CN.01.1792619', 'ASCII:Tongling Shi;ID:1792619', '13018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13018', '112', '14895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1792619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14896', '1079', '1', 'Tongchuan Shi', 'CN.26.1792691', 'ASCII:Tongchuan Shi;ID:1792691', '13019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13019', '112', '14896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.26.1792691» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14897', '1079', '1', 'Tianshui Shi', 'CN.15.1792891', 'ASCII:Tianshui Shi;ID:1792891', '13020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13020', '112', '14897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1792891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14898', '1079', '1', 'Tangshan Shi', 'CN.10.1793343', 'ASCII:Tangshan Shi;ID:1793343', '13021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13021', '112', '14898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1793343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14899', '1079', '1', 'Taizhou Shi', 'CN.04.1793502', 'ASCII:Taizhou Shi;ID:1793502', '13022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13022', '112', '14899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1793502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14900', '1079', '1', 'Taizhou Shi', 'CN.02.1793504', 'ASCII:Taizhou Shi;ID:1793504', '13023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13023', '112', '14900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1793504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14901', '1079', '1', 'Taiyuan Shi', 'CN.24.1793510', 'ASCII:Taiyuan Shi;ID:1793510', '13024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13024', '112', '14901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.1793510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14902', '1079', '1', 'Tai’an Shi', 'CN.25.1793722', 'ASCII:Tai''an Shi;ID:1793722', '13025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13025', '112', '14902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1793722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14903', '1079', '1', 'Suzhou Shi', 'CN.01.1793752', 'ASCII:Suzhou Shi;ID:1793752', '13026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13026', '112', '14903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1793752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14904', '1079', '1', 'Suqian Shi', 'CN.04.1793770', 'ASCII:Suqian Shi;ID:1793770', '13027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13027', '112', '14904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1793770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14905', '1079', '1', 'Suizhou Shi', 'CN.12.1793878', 'ASCII:Suizhou Shi;ID:1793878', '13028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13028', '112', '14905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1793878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14906', '1079', '1', 'Simao Shi', 'CN.29.1794208', 'ASCII:Simao Shi;ID:1794208', '13029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13029', '112', '14906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1794208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14907', '1079', '1', 'Shizuishan Shi', 'CN.21.1794805', 'ASCII:Shizuishan Shi;ID:1794805', '13030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13030', '112', '14907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.21.1794805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14908', '1079', '1', 'Shiyan Shi', 'CN.12.1794892', 'ASCII:Shiyan Shi;ID:1794892', '13031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13031', '112', '14908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1794892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14909', '1079', '1', 'Shijiazhuang Shi', 'CN.10.1795266', 'ASCII:Shijiazhuang Shi;ID:1795266', '13032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13032', '112', '14909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1795266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14910', '1079', '1', 'Shenzhen Shi', 'CN.30.1795563', 'ASCII:Shenzhen Shi;ID:1795563', '13033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13033', '112', '14910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1795563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14911', '1079', '1', 'Shaoyang Shi', 'CN.11.1795852', 'ASCII:Shaoyang Shi;ID:1795852', '13034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13034', '112', '14911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1795852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14912', '1079', '1', 'Shaoxing Shi', 'CN.02.1795854', 'ASCII:Shaoxing Shi;ID:1795854', '13035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13035', '112', '14912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1795854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14913', '1079', '1', 'Shaoguan Shi', 'CN.30.1795873', 'ASCII:Shaoguan Shi;ID:1795873', '13036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13036', '112', '14913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1795873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14914', '1079', '1', 'Shantou Shi', 'CN.30.1795932', 'ASCII:Shantou Shi;ID:1795932', '13037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13037', '112', '14914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1795932» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14915', '1079', '1', 'Shangrao Shi', 'CN.03.1796129', 'ASCII:Shangrao Shi;ID:1796129', '13038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13038', '112', '14915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1796129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14916', '1079', '1', 'Shangqiu Shi', 'CN.09.1796132', 'ASCII:Shangqiu Shi;ID:1796132', '13039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13039', '112', '14916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1796132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14917', '1079', '1', 'Shangqiu Diqu', 'CN.09.1796133', 'ASCII:Shangqiu Diqu;ID:1796133', '13040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13040', '112', '14917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1796133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14918', '1079', '1', 'Shangluo Shi', 'CN.26.1796165', 'ASCII:Shangluo Shi;ID:1796165', '13041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13041', '112', '14918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.26.1796165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14919', '1079', '1', 'Shanghai Xian', 'CN.23.1796229', 'ASCII:Shanghai Xian;ID:1796229', '13042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13042', '112', '14919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.23.1796229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14920', '1079', '1', 'Sanya Shi', 'CN.31.1796539', 'ASCII:Sanya Shi;ID:1796539', '13043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13043', '112', '14920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.31.1796539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14921', '1079', '1', 'Sanming Shi', 'CN.07.1796662', 'ASCII:Sanming Shi;ID:1796662', '13044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13044', '112', '14921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.07.1796662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14922', '1079', '1', 'Sanmenxia Shi', 'CN.09.1796667', 'ASCII:Sanmenxia Shi;ID:1796667', '13045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13045', '112', '14922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1796667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14923', '1079', '1', 'Rizhao Shi', 'CN.25.1797131', 'ASCII:Rizhao Shi;ID:1797131', '13046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13046', '112', '14923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1797131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14924', '1079', '1', 'Quzhou Shi', 'CN.02.1797262', 'ASCII:Quzhou Shi;ID:1797262', '13047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13047', '112', '14924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1797262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14925', '1079', '1', 'Qujing Shi', 'CN.29.1797315', 'ASCII:Qujing Shi;ID:1797315', '13048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13048', '112', '14925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1797315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14926', '1079', '1', 'Quanzhou Shi', 'CN.07.1797350', 'ASCII:Quanzhou Shi;ID:1797350', '13049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13049', '112', '14926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.07.1797350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14927', '1079', '1', 'Qinzhou Diqu', 'CN.16.1797550', 'ASCII:Qinzhou Diqu;ID:1797550', '13050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13050', '112', '14927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1797550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14928', '1079', '1', 'Qinhuangdao Shi', 'CN.10.1797593', 'ASCII:Qinhuangdao Shi;ID:1797593', '13051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13051', '112', '14928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1797593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14929', '1079', '1', 'Qingyuan Shi', 'CN.30.1797626', 'ASCII:Qingyuan Shi;ID:1797626', '13052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13052', '112', '14929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1797626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14930', '1079', '1', 'Qingyang Shi', 'CN.15.1797652', 'ASCII:Qingyang Shi;ID:1797652', '13053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13053', '112', '14930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1797652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14931', '1079', '1', 'Qingdao Shi', 'CN.25.1797926', 'ASCII:Qingdao Shi;ID:1797926', '13054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13054', '112', '14931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1797926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14932', '1079', '1', 'Qianxinan Bouyeizu Miaozu Zizhizhou', 'CN.18.1798226', 'ASCII:Qianxinan Bouyeizu Miaozu Zizhizhou;ID:1798226', '13055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13055', '112', '14932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.18.1798226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14933', '1079', '1', 'Qiannan Bouyeizu Miaozu Zizhizhou', 'CN.18.1798280', 'ASCII:Qiannan Bouyeizu Miaozu Zizhizhou;ID:1798280', '13056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13056', '112', '14933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.18.1798280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14934', '1079', '1', 'Qiandongnan Miaozu Dongzu Zizhizhou', 'CN.18.1798360', 'ASCII:Qiandongnan Miaozu Dongzu Zizhizhou;ID:1798360', '13057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13057', '112', '14934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.18.1798360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14935', '1079', '1', 'Putian Shi', 'CN.07.1798445', 'ASCII:Putian Shi;ID:1798445', '13058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13058', '112', '14935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.07.1798445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14936', '1079', '1', 'Pingxiang Shi', 'CN.03.1798652', 'ASCII:Pingxiang Shi;ID:1798652', '13059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13059', '112', '14936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1798652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14937', '1079', '1', 'Pingliang Shi', 'CN.15.1798759', 'ASCII:Pingliang Shi;ID:1798759', '13060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13060', '112', '14937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1798759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14938', '1079', '1', 'Pingdingshan Shi', 'CN.09.1798826', 'ASCII:Pingdingshan Shi;ID:1798826', '13061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13061', '112', '14938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1798826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14939', '1079', '1', 'Panzhihua Shi', 'CN.32.1798997', 'ASCII:Panzhihua Shi;ID:1798997', '13062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13062', '112', '14939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1798997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14940', '1079', '1', 'Ningde Shi', 'CN.07.1799392', 'ASCII:Ningde Shi;ID:1799392', '13063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13063', '112', '14940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.07.1799392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14941', '1079', '1', 'Ningbo Shi', 'CN.02.1799395', 'ASCII:Ningbo Shi;ID:1799395', '13064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13064', '112', '14941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1799395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14942', '1079', '1', 'Neijiang Shi', 'CN.32.1799490', 'ASCII:Neijiang Shi;ID:1799490', '13065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13065', '112', '14942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1799490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14943', '1079', '1', 'Nanyang Shi', 'CN.09.1799614', 'ASCII:Nanyang Shi;ID:1799614', '13066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13066', '112', '14943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1799614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14944', '1079', '1', 'Nantong Shi', 'CN.04.1799719', 'ASCII:Nantong Shi;ID:1799719', '13067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13067', '112', '14944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1799719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14945', '1079', '1', 'Nanshi Qu', 'CN.23.1799750', 'ASCII:Nanshi Qu;ID:1799750', '13068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13068', '112', '14945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.23.1799750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14946', '1079', '1', 'Nanping Shi', 'CN.07.1799838', 'ASCII:Nanping Shi;ID:1799838', '13069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13069', '112', '14946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.07.1799838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14947', '1079', '1', 'Nanning Shi', 'CN.16.1799866', 'ASCII:Nanning Shi;ID:1799866', '13070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13070', '112', '14947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1799866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14948', '1079', '1', 'Nanning Diqu', 'CN.16.1799868', 'ASCII:Nanning Diqu;ID:1799868', '13071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13071', '112', '14948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1799868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14949', '1079', '1', 'Nanjing Shi', 'CN.04.1799960', 'ASCII:Nanjing;ID:1799960', '13072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13072', '112', '14949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1799960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14950', '1079', '1', 'Nanchong Shi', 'CN.32.1800145', 'ASCII:Nanchong Shi;ID:1800145', '13073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13073', '112', '14950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1800145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14951', '1079', '1', 'Nanchang Shi', 'CN.03.1800160', 'ASCII:Nanchang Shi;ID:1800160', '13074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13074', '112', '14951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1800160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14952', '1079', '1', 'Mianyang Shi', 'CN.32.1800626', 'ASCII:Mianyang Shi;ID:1800626', '13075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13075', '112', '14952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1800626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14953', '1079', '1', 'Meizhou Shi', 'CN.30.1800794', 'ASCII:Meizhou Shi;ID:1800794', '13076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13076', '112', '14953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1800794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14954', '1079', '1', 'Maoming Shi', 'CN.30.1801179', 'ASCII:Maoming Shi;ID:1801179', '13077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13077', '112', '14954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1801179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14955', '1079', '1', 'Ma’anshan Shi', 'CN.01.1801618', 'ASCII:Ma''anshan Shi;ID:1801618', '13078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13078', '112', '14955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1801618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14956', '1079', '1', 'Luzhou Shi', 'CN.32.1801637', 'ASCII:Luzhou Shi;ID:1801637', '13079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13079', '112', '14956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1801637» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14957', '1079', '1', 'Lupanshui Shi', 'CN.18.1801764', 'ASCII:Lupanshui Shi;ID:1801764', '13080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13080', '112', '14957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.18.1801764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14958', '1079', '1', 'Luoyang Shi', 'CN.09.1801785', 'ASCII:Luoyang Shi;ID:1801785', '13081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13081', '112', '14958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1801785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14959', '1079', '1', 'Luohe Shi', 'CN.09.1801930', 'ASCII:Luohe Shi;ID:1801930', '13082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13082', '112', '14959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1801930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14960', '1079', '1', 'Lüliang Shi', 'CN.24.1802029', 'ASCII:Luliang Shi;ID:1802029', '13083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13083', '112', '14960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.1802029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14961', '1079', '1', 'Lu’an Shi', 'CN.01.1802199', 'ASCII:Lu''an Shi;ID:1802199', '13084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13084', '112', '14961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1802199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14962', '1079', '1', 'Loudi Shi', 'CN.11.1802234', 'ASCII:Loudi Shi;ID:1802234', '13085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13085', '112', '14962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1802234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14963', '1079', '1', 'Longyan Shi', 'CN.07.1802274', 'ASCII:Longyan Shi;ID:1802274', '13086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13086', '112', '14963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.07.1802274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14964', '1079', '1', 'Longnan Shi', 'CN.15.1802494', 'ASCII:Longnan Shi;ID:1802494', '13087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13087', '112', '14964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1802494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14965', '1079', '1', 'Liuzhou Shi', 'CN.16.1802851', 'ASCII:Liuzhou Shi;ID:1802851', '13088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13088', '112', '14965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1802851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14966', '1079', '1', 'Liuzhou Diqu', 'CN.16.1802852', 'ASCII:Liuzhou Diqu;ID:1802852', '13089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13089', '112', '14966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1802852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14967', '1079', '1', 'Lishui Shi', 'CN.02.1803243', 'ASCII:Lishui Shi;ID:1803243', '13090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13090', '112', '14967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1803243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14968', '1079', '1', 'Linyi Shi', 'CN.25.1803316', 'ASCII:Linyi Shi;ID:1803316', '13091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13091', '112', '14968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1803316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14969', '1079', '1', 'Linxia Huizu Zizhizhou', 'CN.15.1803330', 'ASCII:Linxia Huizu Zizhizhou;ID:1803330', '13092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13092', '112', '14969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1803330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14970', '1079', '1', 'Lingling Diqu', 'CN.11.1803495', 'ASCII:Lingling Diqu;ID:1803495', '13093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13093', '112', '14970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1803495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14971', '1079', '1', 'Linfen Shi', 'CN.24.1803566', 'ASCII:Linfen Shi;ID:1803566', '13094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13094', '112', '14971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.1803566» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14972', '1079', '1', 'Lincang Shi', 'CN.29.1803589', 'ASCII:Lincang Shi;ID:1803589', '13095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13095', '112', '14972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1803589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14973', '1079', '1', 'Lijiang Shi', 'CN.29.1803666', 'ASCII:Lijiang Shi;ID:1803666', '13096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13096', '112', '14973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1803666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14974', '1079', '1', 'Liaocheng Shi', 'CN.25.1803833', 'ASCII:Liaocheng Shi;ID:1803833', '13097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13097', '112', '14974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1803833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14975', '1079', '1', 'Lianyungang Shi', 'CN.04.1803847', 'ASCII:Lianyungang Shi;ID:1803847', '13098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13098', '112', '14975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1803847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14976', '1079', '1', 'Liangshan Yizu Zizhizhou', 'CN.32.1803984', 'ASCII:Liangshan Yizu Zizhizhou;ID:1803984', '13099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13099', '112', '14976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1803984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14977', '1079', '1', 'Leshan Shi', 'CN.32.1804151', 'ASCII:Leshan Shi;ID:1804151', '13100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13100', '112', '14977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1804151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14978', '1079', '1', 'Lanzhou Shi', 'CN.15.1804429', 'ASCII:Lanzhou Shi;ID:1804429', '13101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13101', '112', '14978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1804429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14979', '1079', '1', 'Langfang Shi', 'CN.10.1804539', 'ASCII:Langfang Shi;ID:1804539', '13102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13102', '112', '14979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1804539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14980', '1079', '1', 'Laiwu Shi', 'CN.25.1804589', 'ASCII:Laiwu Shi;ID:1804589', '13103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13103', '112', '14980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1804589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14981', '1079', '1', 'Kunming Shi', 'CN.29.1804649', 'ASCII:Kunming Shi;ID:1804649', '13104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13104', '112', '14981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1804649» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14982', '1079', '1', 'Kaifeng Shi', 'CN.09.1804878', 'ASCII:Kaifeng Shi;ID:1804878', '13105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13105', '112', '14982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1804878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14983', '1079', '1', 'Jiujiang Shi', 'CN.03.1805178', 'ASCII:Jiujiang Shi;ID:1805178', '13106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13106', '112', '14983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1805178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14984', '1079', '1', 'Jinzhong Shi', 'CN.24.1805302', 'ASCII:Jinzhong Shi;ID:1805302', '13107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13107', '112', '14984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.1805302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14985', '1079', '1', 'Jining Shi', 'CN.25.1805517', 'ASCII:Jining Shi;ID:1805517', '13108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13108', '112', '14985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1805517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14986', '1079', '1', 'Jinhua Shi', 'CN.02.1805525', 'ASCII:Jinhua Shi;ID:1805525', '13109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13109', '112', '14986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1805525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14987', '1079', '1', 'Jingzhou Shi', 'CN.12.1805539', 'ASCII:Jingzhou Shi;ID:1805539', '13110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13110', '112', '14987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1805539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14988', '1079', '1', 'Jingmen Shi', 'CN.12.1805610', 'ASCII:Jingmen Shi;ID:1805610', '13111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13111', '112', '14988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1805610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14989', '1079', '1', 'Jingdezhen Shi', 'CN.03.1805679', 'ASCII:Jingdezhen Shi;ID:1805679', '13112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13112', '112', '14989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1805679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14990', '1079', '1', 'Jincheng Shi', 'CN.24.1805739', 'ASCII:Jincheng Shi;ID:1805739', '13113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13113', '112', '14990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.1805739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14991', '1079', '1', 'Jinchang Shi', 'CN.15.1805747', 'ASCII:Jinchang Shi;ID:1805747', '13114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13114', '112', '14991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1805747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14992', '1079', '1', 'Jinan Shi', 'CN.25.1805751', 'ASCII:Jinan Shi;ID:1805751', '13115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13115', '112', '14992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1805751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14993', '1079', '1', 'Jieyang Shi', 'CN.30.1805830', 'ASCII:Jieyang Shi;ID:1805830', '13116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13116', '112', '14993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1805830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14994', '1079', '1', 'Jiaxing Shi', 'CN.02.1805952', 'ASCII:Jiaxing Shi;ID:1805952', '13117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13117', '112', '14994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1805952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14995', '1079', '1', 'Jiaozuo Shi', 'CN.09.1805986', 'ASCII:Jiaozuo Shi;ID:1805986', '13118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13118', '112', '14995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1805986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14996', '1079', '1', 'Jianyang Diqu', 'CN.07.1806121', 'ASCII:Jianyang Diqu;ID:1806121', '13119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13119', '112', '14996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.07.1806121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14997', '1079', '1', 'Jiangmen Shi', 'CN.30.1806297', 'ASCII:Jiangmen Shi;ID:1806297', '13120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13120', '112', '14997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1806297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14998', '1079', '1', 'Ji’an Shi', 'CN.03.1806430', 'ASCII:Ji''an Shi;ID:1806430', '13121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13121', '112', '14998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1806430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('14999', '1079', '1', 'Ordos Shi', 'CN.20.1806529', 'ASCII:Ordos Shi;ID:1806529', '13122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13122', '112', '14999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.1806529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15000', '1079', '1', 'Huzhou Shi', 'CN.02.1806534', 'ASCII:Huzhou Shi;ID:1806534', '13123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13123', '112', '15000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1806534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15001', '1079', '1', 'Huangshan Shi', 'CN.01.1806775', 'ASCII:Huangshan Shi;ID:1806775', '13124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13124', '112', '15001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1806775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15002', '1079', '1', 'Huizhou Shi', 'CN.30.1806783', 'ASCII:Huizhou Shi;ID:1806783', '13125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13125', '112', '15002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1806783» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15003', '1079', '1', 'Huimin Diqu', 'CN.25.1806823', 'ASCII:Huimin Diqu;ID:1806823', '13126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13126', '112', '15003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1806823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15004', '1079', '1', 'Huangshi Shi', 'CN.12.1807225', 'ASCII:Huangshi Shi;ID:1807225', '13127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13127', '112', '15004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1807225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15005', '1079', '1', 'Huangnan Zangzu Zizhizhou', 'CN.06.1807329', 'ASCII:Huangnan Zangzu Zizhizhou;ID:1807329', '13128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13128', '112', '15005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.06.1807329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15006', '1079', '1', 'Huanggang Shi', 'CN.12.1807500', 'ASCII:Huanggang Shi;ID:1807500', '13129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13129', '112', '15006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1807500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15007', '1079', '1', 'Huai’an Shi', 'CN.04.1807649', 'ASCII:Huai''an Shi;ID:1807649', '13130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13130', '112', '15007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1807649» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15008', '1079', '1', 'Huainan Shi', 'CN.01.1807680', 'ASCII:Huainan Shi;ID:1807680', '13131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13131', '112', '15008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1807680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15009', '1079', '1', 'Huaihua Shi', 'CN.11.1807688', 'ASCII:Huaihua Shi;ID:1807688', '13132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13132', '112', '15009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1807688» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15010', '1079', '1', 'Huaibei Shi', 'CN.01.1807699', 'ASCII:Huaibei Shi;ID:1807699', '13133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13133', '112', '15010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1807699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15011', '1079', '1', 'Honghe Hanizu Yizu Zizhizhou', 'CN.29.1808130', 'ASCII:Honghe Hanizu Yizu Zizhizhou;ID:1808130', '13134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13134', '112', '15011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1808130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15012', '1079', '1', 'Heze Shi', 'CN.25.1808197', 'ASCII:Heze Shi;ID:1808197', '13135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13135', '112', '15012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1808197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15013', '1079', '1', 'Heyuan Shi', 'CN.30.1808200', 'ASCII:Heyuan Shi;ID:1808200', '13136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13136', '112', '15013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1808200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15014', '1079', '1', 'Hengyang Shi', 'CN.11.1808369', 'ASCII:Hengyang Shi;ID:1808369', '13137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13137', '112', '15014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1808369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15015', '1079', '1', 'Hengshui Shi', 'CN.10.1808391', 'ASCII:Hengshui Shi;ID:1808391', '13138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13138', '112', '15015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1808391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15016', '1079', '1', 'Hefei Shi', 'CN.01.1808721', 'ASCII:Hefei Shi;ID:1808721', '13139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13139', '112', '15016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1808721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15017', '1079', '1', 'Hechi Diqu', 'CN.16.1808757', 'ASCII:Hechi Diqu;ID:1808757', '13140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13140', '112', '15017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1808757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15018', '1079', '1', 'Hebi Shi', 'CN.09.1808765', 'ASCII:Hebi Shi;ID:1808765', '13141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13141', '112', '15018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1808765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15019', '1079', '1', 'Hanzhong Shi', 'CN.26.1808856', 'ASCII:Hanzhong Shi;ID:1808856', '13142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13142', '112', '15019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.26.1808856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15020', '1079', '1', 'Hangzhou Shi', 'CN.02.1808925', 'ASCII:Hangzhou Shi;ID:1808925', '13143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13143', '112', '15020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.02.1808925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15021', '1079', '1', 'Handan Shi', 'CN.10.1808961', 'ASCII:Handan Shi;ID:1808961', '13144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13144', '112', '15021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1808961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15022', '1079', '1', 'Handan Diqu', 'CN.10.1808962', 'ASCII:Handan Diqu;ID:1808962', '13145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13145', '112', '15022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1808962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15023', '1079', '1', 'Hainan Zangzu Zizhizhou', 'CN.06.1809051', 'ASCII:Hainan Zangzu Zizhizhou;ID:1809051', '13146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13146', '112', '15023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.06.1809051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15024', '1079', '1', 'Haikou Shi', 'CN.31.1809072', 'ASCII:Haikou Shi;ID:1809072', '13147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13147', '112', '15024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.31.1809072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15025', '1079', '1', 'Haidong Diqu', 'CN.06.1809101', 'ASCII:Haidong Diqu;ID:1809101', '13148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13148', '112', '15025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.06.1809101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15026', '1079', '1', 'Haibei Zangzu Zizhizhou', 'CN.06.1809111', 'ASCII:Haibei Zangzu Zizhizhou;ID:1809111', '13149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13149', '112', '15026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.06.1809111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15027', '1079', '1', 'Guyuan Shi', 'CN.21.1809151', 'ASCII:Guyuan Shi;ID:1809151', '13150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13150', '112', '15027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.21.1809151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15028', '1079', '1', 'Guiyang Shi', 'CN.18.1809458', 'ASCII:Guiyang Shi;ID:1809458', '13151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13151', '112', '15028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.18.1809458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15029', '1079', '1', 'Guilin Shi', 'CN.16.1809492', 'ASCII:Guilin Shi;ID:1809492', '13152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13152', '112', '15029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1809492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15030', '1079', '1', 'Guilin Diqu', 'CN.16.1809495', 'ASCII:Guilin Diqu;ID:1809495', '13153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13153', '112', '15030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1809495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15031', '1079', '1', 'Guangzhou Shi', 'CN.30.1809857', 'ASCII:Guangzhou Shi;ID:1809857', '13154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13154', '112', '15031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1809857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15032', '1079', '1', 'Garzê Zangzu Zizhizhou', 'CN.32.1810269', 'ASCII:Garze Zangzu Zizhizhou;ID:1810269', '13155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13155', '112', '15032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1810269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15033', '1079', '1', 'Ganzhou Shi', 'CN.03.1810636', 'ASCII:Ganzhou Shi;ID:1810636', '13156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13156', '112', '15033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1810636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15034', '1079', '1', 'Gannan Zangzu Zizhizhou', 'CN.15.1810686', 'ASCII:Gannan Zangzu Zizhizhou;ID:1810686', '13157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13157', '112', '15034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1810686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15035', '1079', '1', 'Fuzhou Shi', 'CN.07.1810815', 'ASCII:Fuzhou Shi;ID:1810815', '13158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13158', '112', '15035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.07.1810815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15036', '1079', '1', 'Fuzhou Shi', 'CN.03.1810818', 'ASCII:Fuzhou Shi;ID:1810818', '13159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13159', '112', '15036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.03.1810818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15037', '1079', '1', 'Fuyang Shi', 'CN.01.1810843', 'ASCII:Fuyang Shi;ID:1810843', '13160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13160', '112', '15037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1810843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15038', '1079', '1', 'Foshan Shi', 'CN.30.1811102', 'ASCII:Foshan Shi;ID:1811102', '13161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13161', '112', '15038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1811102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15039', '1079', '1', 'Ezhou Shi', 'CN.12.1811618', 'ASCII:Ezhou Shi;ID:1811618', '13162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13162', '112', '15039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1811618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15040', '1079', '1', 'Enshi Tujiazu Miaozu Zizhizhou', 'CN.12.1811624', 'ASCII:Enshi Tujiazu Miaozu Zizhizhou;ID:1811624', '13163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13163', '112', '15040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.12.1811624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15041', '1079', '1', 'Dongying Shi', 'CN.25.1812099', 'ASCII:Dongying Shi;ID:1812099', '13164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13164', '112', '15041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1812099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15042', '1079', '1', 'Dongguan Shi', 'CN.30.1812532', 'ASCII:Dongguan Shi;ID:1812532', '13165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13165', '112', '15042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1812532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15043', '1079', '1', 'Dingxi Shi', 'CN.15.1812743', 'ASCII:Dingxi Shi;ID:1812743', '13166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13166', '112', '15043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1812743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15044', '1079', '1', 'Dezhou Shi', 'CN.25.1812954', 'ASCII:Dezhou Shi;ID:1812954', '13167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13167', '112', '15044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1812954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15045', '1079', '1', 'Zhangjiajie Shi', 'CN.11.1813170', 'ASCII:Zhangjiajie Shi;ID:1813170', '13168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13168', '112', '15045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1813170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15046', '1079', '1', 'Dazhou Shi', 'CN.32.1813324', 'ASCII:Dazhou Shi;ID:1813324', '13169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13169', '112', '15046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1813324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15047', '1079', '1', 'Dali Baizu Zizhizhou', 'CN.29.1814065', 'ASCII:Dali Baizu Zizhizhou;ID:1814065', '13170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13170', '112', '15047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1814065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15048', '1079', '1', 'Dalian Shi', 'CN.19.1814068', 'ASCII:Dalian Shi;ID:1814068', '13171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13171', '112', '15048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.1814068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15049', '1079', '1', 'Chuxiong Yizu Zizhizhou', 'CN.29.1814758', 'ASCII:Chuxiong Yizu Zizhizhou;ID:1814758', '13172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13172', '112', '15049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.29.1814758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15050', '1079', '1', 'Chuzhou Shi', 'CN.01.1814761', 'ASCII:Chuzhou Shi;ID:1814761', '13173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13173', '112', '15050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1814761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15051', '1079', '1', 'Chenzhou Shi', 'CN.11.1815056', 'ASCII:Chenzhou Shi;ID:1815056', '13174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13174', '112', '15051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1815056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15052', '1079', '1', 'Chengdu Shi', 'CN.32.1815285', 'ASCII:Chengdu Shi;ID:1815285', '13175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13175', '112', '15052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1815285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15053', '1079', '1', 'Chaozhou Shi', 'CN.30.1815394', 'ASCII:Chaozhou Shi;ID:1815394', '13176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13176', '112', '15053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.1815394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15054', '1079', '1', 'Chaohu Shi', 'CN.01.1815425', 'ASCII:Chaohu Shi;ID:1815425', '13177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13177', '112', '15054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1815425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15055', '1079', '1', 'Changzhou Shi', 'CN.04.1815454', 'ASCII:Changzhou Shi;ID:1815454', '13178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13178', '112', '15055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1815454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15056', '1079', '1', 'Changzhi Shi', 'CN.24.1815461', 'ASCII:Changzhi Shi;ID:1815461', '13179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13179', '112', '15056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.1815461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15057', '1079', '1', 'Changsha Shi', 'CN.11.1815551', 'ASCII:Changsha Shi;ID:1815551', '13180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13180', '112', '15057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1815551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15058', '1079', '1', 'Changde Shi', 'CN.11.1815761', 'ASCII:Changde Shi;ID:1815761', '13181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13181', '112', '15058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.11.1815761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15059', '1079', '1', 'Cangzhou Shi', 'CN.10.1816078', 'ASCII:Cangzhou Shi;ID:1816078', '13182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13182', '112', '15059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1816078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15060', '1079', '1', 'Cangzhou Diqu', 'CN.10.1816079', 'ASCII:Cangzhou Diqu;ID:1816079', '13183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13183', '112', '15060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1816079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15061', '1079', '1', 'Bose Diqu', 'CN.16.1816268', 'ASCII:Bose Diqu;ID:1816268', '13184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13184', '112', '15061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1816268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15062', '1079', '1', 'Binzhou Shi', 'CN.25.1816335', 'ASCII:Binzhou Shi;ID:1816335', '13185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13185', '112', '15062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.25.1816335» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15063', '1079', '1', 'Bijie Diqu', 'CN.18.1816372', 'ASCII:Bijie Diqu;ID:1816372', '13186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13186', '112', '15063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.18.1816372» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15064', '1079', '1', 'Bengbu Shi', 'CN.01.1816439', 'ASCII:Bengbu Shi;ID:1816439', '13187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13187', '112', '15064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1816439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15065', '1079', '1', 'Beihai Shi', 'CN.16.1816702', 'ASCII:Beihai Shi;ID:1816702', '13188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13188', '112', '15065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.16.1816702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15066', '1079', '1', 'Baoding Shi', 'CN.10.1816969', 'ASCII:Baoding Shi;ID:1816969', '13189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13189', '112', '15066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1816969» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15067', '1079', '1', 'Baoding Diqu', 'CN.10.1816970', 'ASCII:Baoding Diqu;ID:1816970', '13190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13190', '112', '15067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.1816970» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15068', '1079', '1', 'Baiyin Shi', 'CN.15.1817238', 'ASCII:Baiyin Shi;ID:1817238', '13191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13191', '112', '15068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.15.1817238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15069', '1079', '1', 'Anyang Shi', 'CN.09.1817942', 'ASCII:Anyang Shi;ID:1817942', '13192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13192', '112', '15069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1817942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15070', '1079', '1', 'Anshun Shi', 'CN.18.1817965', 'ASCII:Anshun Shi;ID:1817965', '13193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13193', '112', '15070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.18.1817965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15071', '1079', '1', 'Anqing Shi', 'CN.01.1817991', 'ASCII:Anqing Shi;ID:1817991', '13194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13194', '112', '15071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.1817991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15072', '1079', '1', 'Ankang Shi', 'CN.26.1818037', 'ASCII:Ankang Shi;ID:1818037', '13195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13195', '112', '15072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.26.1818037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15073', '1079', '1', 'Alxa Meng', 'CN.20.1818128', 'ASCII:Alxa Meng;ID:1818128', '13196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13196', '112', '15073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.1818128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15074', '1079', '1', 'Aba Zangzu Qiangzu Zizhizhou', 'CN.32.1818175', 'ASCII:Aba Zangzu Qiangzu Zizhizhou;ID:1818175', '13197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13197', '112', '15074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.1818175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15075', '1079', '1', 'Suzhou Shi', 'CN.04.1881771', 'ASCII:Suzhou Shi;ID:1881771', '13198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13198', '112', '15075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.04.1881771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15076', '1079', '1', 'Puyang Shi', 'CN.09.1941243', 'ASCII:Puyang Shi;ID:1941243', '13199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13199', '112', '15076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.09.1941243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15077', '1079', '1', 'Zhangjiakou Shi', 'CN.10.2033194', 'ASCII:Zhangjiakou Shi;ID:2033194', '13200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13200', '112', '15077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.2033194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15078', '1079', '1', 'Yingkou Shi', 'CN.19.2033369', 'ASCII:Yingkou Shi;ID:2033369', '13201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13201', '112', '15078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2033369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15079', '1079', '1', 'Yichun Shi', 'CN.08.2033412', 'ASCII:Yichun Shi;ID:2033412', '13202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13202', '112', '15079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2033412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15080', '1079', '1', 'Yanbian Chaoxianzu Zizhizhou', 'CN.05.2033525', 'ASCII:Yanbian Chaoxianzu Zizhizhou;ID:2033525', '13203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13203', '112', '15080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.05.2033525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15081', '1079', '1', 'Yanbei Diqu', 'CN.24.2033526', 'ASCII:Yanbei Diqu;ID:2033526', '13204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13204', '112', '15081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.2033526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15082', '1079', '1', 'Xilin Gol Meng', 'CN.20.2033827', 'ASCII:Xilin Gol Meng;ID:2033827', '13205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13205', '112', '15082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.2033827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15083', '1079', '1', 'Ulanqab Shi', 'CN.20.2034303', 'ASCII:Ulanqab Shi;ID:2034303', '13206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13206', '112', '15083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.2034303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15084', '1079', '1', 'Tonghua Shi', 'CN.05.2034413', 'ASCII:Tonghua Shi;ID:2034413', '13207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13207', '112', '15084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.05.2034413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15085', '1079', '1', 'Tieling Shi', 'CN.19.2034437', 'ASCII:Tieling Shi;ID:2034437', '13208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13208', '112', '15085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2034437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15086', '1079', '1', 'Suihua Shi', 'CN.08.2034654', 'ASCII:Suihua Shi;ID:2034654', '13209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13209', '112', '15086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2034654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15087', '1079', '1', 'Songhuajiang Diqu', 'CN.08.2034696', 'ASCII:Songhuajiang Diqu;ID:2034696', '13210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13210', '112', '15087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2034696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15088', '1079', '1', 'Siping Shi', 'CN.05.2034711', 'ASCII:Siping Shi;ID:2034711', '13211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13211', '112', '15088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.05.2034711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15089', '1079', '1', 'Shuangyashan Shi', 'CN.08.2034785', 'ASCII:Shuangyashan Shi;ID:2034785', '13212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13212', '112', '15089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2034785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15090', '1079', '1', 'Shenyang Shi', 'CN.19.2034935', 'ASCII:Shenyang Shi;ID:2034935', '13213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13213', '112', '15090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2034935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15091', '1079', '1', 'Qitaihe Shi', 'CN.08.2035260', 'ASCII:Qitaihe Shi;ID:2035260', '13214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13214', '112', '15091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2035260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15092', '1079', '1', 'Qiqihar Shi', 'CN.08.2035264', 'ASCII:Qiqihar Shi;ID:2035264', '13215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13215', '112', '15092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2035264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15093', '1079', '1', 'Panjin Shi', 'CN.19.2035516', 'ASCII:Panjin Shi;ID:2035516', '13216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13216', '112', '15093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2035516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15094', '1079', '1', 'Mudanjiang Shi', 'CN.08.2035713', 'ASCII:Mudanjiang Shi;ID:2035713', '13217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13217', '112', '15094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2035713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15095', '1079', '1', 'Liaoyuan Shi', 'CN.05.2036107', 'ASCII:Liaoyuan Shi;ID:2036107', '13218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13218', '112', '15095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.05.2036107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15096', '1079', '1', 'Liaoyang Shi', 'CN.19.2036112', 'ASCII:Liaoyang Shi;ID:2036112', '13219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13219', '112', '15096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2036112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15097', '1079', '1', 'Jixi Shi', 'CN.08.2036380', 'ASCII:Jixi Shi;ID:2036380', '13220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13220', '112', '15097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2036380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15098', '1079', '1', 'Tongliao Shi', 'CN.20.2036421', 'ASCII:Tongliao Shi;ID:2036421', '13221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13221', '112', '15098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.2036421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15099', '1079', '1', 'Jinzhou Shi', 'CN.19.2036425', 'ASCII:Jinzhou Shi;ID:2036425', '13222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13222', '112', '15099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2036425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15100', '1079', '1', 'Huludao Shi', 'CN.19.2036430', 'ASCII:Huludao Shi;ID:2036430', '13223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13223', '112', '15100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2036430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15101', '1079', '1', 'Jilin Shi', 'CN.05.2036499', 'ASCII:Jilin Shi;ID:2036499', '13224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13224', '112', '15101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.05.2036499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15102', '1079', '1', 'Jiamusi Shi', 'CN.08.2036580', 'ASCII:Jiamusi Shi;ID:2036580', '13225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13225', '112', '15102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2036580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15103', '1079', '1', 'Baishan Shi', 'CN.05.2036646', 'ASCII:Baishan Shi;ID:2036646', '13226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13226', '112', '15103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.05.2036646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15104', '1079', '1', 'Hulunbuir Shi', 'CN.20.2036660', 'ASCII:Hulunbuir Shi;ID:2036660', '13227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13227', '112', '15104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.2036660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15105', '1079', '1', 'Hohhot Shi', 'CN.20.2036891', 'ASCII:Hohhot Shi;ID:2036891', '13228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13228', '112', '15105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.2036891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15106', '1079', '1', 'Hinggan Meng', 'CN.20.2036898', 'ASCII:Hinggan Meng;ID:2036898', '13229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13229', '112', '15106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.2036898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15107', '1079', '1', 'Heihe Shi', 'CN.08.2036971', 'ASCII:Heihe Shi;ID:2036971', '13230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13230', '112', '15107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2036971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15108', '1079', '1', 'Hegang Shi', 'CN.08.2036985', 'ASCII:Hegang Shi;ID:2036985', '13231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13231', '112', '15108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2036985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15109', '1079', '1', 'Harbin Shi', 'CN.08.2037012', 'ASCII:Harbin Shi;ID:2037012', '13232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13232', '112', '15109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2037012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15110', '1079', '1', 'Fuxin Shi', 'CN.19.2037337', 'ASCII:Fuxin Shi;ID:2037337', '13233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13233', '112', '15110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2037337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15111', '1079', '1', 'Fushun Shi', 'CN.19.2037353', 'ASCII:Fushun Shi;ID:2037353', '13234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13234', '112', '15111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2037353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15112', '1079', '1', 'Datong Shi', 'CN.24.2037794', 'ASCII:Datong Shi;ID:2037794', '13235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13235', '112', '15112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.2037794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15113', '1079', '1', 'Daqing Shi', 'CN.08.2037847', 'ASCII:Daqing Shi;ID:2037847', '13236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13236', '112', '15113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2037847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15114', '1079', '1', 'Dandong Shi', 'CN.19.2037885', 'ASCII:Dandong Shi;ID:2037885', '13237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13237', '112', '15114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2037885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15115', '1079', '1', 'Dahingganling Diqu', 'CN.08.2037961', 'ASCII:Dahingganling Diqu;ID:2037961', '13238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13238', '112', '15115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.08.2037961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15116', '1079', '1', 'Chifeng Shi', 'CN.20.2038066', 'ASCII:Chifeng Shi;ID:2038066', '13239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13239', '112', '15116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.2038066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15117', '1079', '1', 'Chengde Shi', 'CN.10.2038085', 'ASCII:Chengde Shi;ID:2038085', '13240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13240', '112', '15117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.2038085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15118', '1079', '1', 'Chengde Diqu', 'CN.10.2038086', 'ASCII:Chengde Diqu;ID:2038086', '13241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13241', '112', '15118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.10.2038086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15119', '1079', '1', 'Chaoyang Shi', 'CN.19.2038101', 'ASCII:Chaoyang Shi;ID:2038101', '13242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13242', '112', '15119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2038101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15120', '1079', '1', 'Changchun Shi', 'CN.05.2038176', 'ASCII:Changchun Shi;ID:2038176', '13243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13243', '112', '15120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.05.2038176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15121', '1079', '1', 'Benxi Shi', 'CN.19.2038299', 'ASCII:Benxi Shi;ID:2038299', '13244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13244', '112', '15121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2038299» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15122', '1079', '1', 'Bayannur Shi', 'CN.20.2038392', 'ASCII:Bayannur Shi;ID:2038392', '13245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13245', '112', '15122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.2038392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15123', '1079', '1', 'Baotou Shi', 'CN.20.2038431', 'ASCII:Baotou Shi;ID:2038431', '13246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13246', '112', '15123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.20.2038431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15124', '1079', '1', 'Baicheng Shi', 'CN.05.2038567', 'ASCII:Baicheng Shi;ID:2038567', '13247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13247', '112', '15124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.05.2038567» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15125', '1079', '1', 'Anshan Shi', 'CN.19.2038630', 'ASCII:Anshan Shi;ID:2038630', '13248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13248', '112', '15125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.19.2038630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15126', '1079', '1', 'Shanwei Shi', 'CN.30.6571356', 'ASCII:Shanwei Shi;ID:6571356', '13249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13249', '112', '15126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.30.6571356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15127', '1079', '1', 'Songyuan Shi', 'CN.05.6587798', 'ASCII:Songyuan Shi;ID:6587798', '13250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13250', '112', '15127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.05.6587798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15128', '1079', '1', 'Chizhou Shi', 'CN.01.6640435', 'ASCII:Chizhou Shi;ID:6640435', '13251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13251', '112', '15128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.6640435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15129', '1079', '1', 'Haozhou Shi', 'CN.01.6640436', 'ASCII:Haozhou Shi;ID:6640436', '13252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13252', '112', '15129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.01.6640436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15130', '1079', '1', 'Shuozhou Shi', 'CN.24.6642609', 'ASCII:Shuozhou Shi;ID:6642609', '13253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13253', '112', '15130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.6642609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15131', '1079', '1', 'Xinzhou Shi', 'CN.24.6642630', 'ASCII:Xinzhou Shi;ID:6642630', '13254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13254', '112', '15131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.24.6642630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15132', '1079', '1', 'Deyang Shi', 'CN.32.6642946', 'ASCII:Deyang Shi;ID:6642946', '13255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13255', '112', '15132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.6642946» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15133', '1079', '1', 'Zhongwei Shi', 'CN.21.6643239', 'ASCII:Zhongwei Shi;ID:6643239', '13256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13256', '112', '15133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.21.6643239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15134', '1079', '1', 'Yinchuan Shi', 'CN.21.6643245', 'ASCII:Yinchuan Shi;ID:6643245', '13257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13257', '112', '15134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.21.6643245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15135', '1079', '1', 'Guangyuan Shi', 'CN.32.6643372', 'ASCII:Guangyuan Shi;ID:6643372', '13258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13258', '112', '15135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.6643372» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15136', '1079', '1', 'Guang''an Shi', 'CN.32.6643373', 'ASCII:Guang''an Shi;ID:6643373', '13259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13259', '112', '15136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.6643373» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15137', '1079', '1', 'Suining Shi', 'CN.32.6643374', 'ASCII:Suining Shi;ID:6643374', '13260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13260', '112', '15137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.6643374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15138', '1079', '1', 'Bazhong Shi', 'CN.32.6643375', 'ASCII:Bazhong Shi;ID:6643375', '13261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13261', '112', '15138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CN.32.6643375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15139', '1079', '1', 'Zipaquirá', 'CO.33.3665543', 'ASCII:Zipaquira;ID:3665543', '13262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13262', '112', '15139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3665543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15140', '1079', '1', 'Zipacón', 'CO.33.3665545', 'ASCII:Zipacon;ID:3665545', '13263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13263', '112', '15140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3665545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15141', '1079', '1', 'Zetaquirá', 'CO.36.3665548', 'ASCII:Zetaquira;ID:3665548', '13264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13264', '112', '15141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3665548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15142', '1079', '1', 'Zarzal', 'CO.29.3665560', 'ASCII:Zarzal;ID:3665560', '13265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13265', '112', '15142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3665560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15143', '1079', '1', 'Zaragoza', 'CO.02.3665573', 'ASCII:Zaragoza;ID:3665573', '13266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13266', '112', '15143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3665573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15144', '1079', '1', 'Zapatoca', 'CO.26.3665588', 'ASCII:Zapatoca;ID:3665588', '13267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13267', '112', '15144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3665588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15145', '1079', '1', 'Zambrano', 'CO.35.3665619', 'ASCII:Zambrano;ID:3665619', '13268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13268', '112', '15145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3665619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15146', '1079', '1', 'Yotoco', 'CO.29.3665679', 'ASCII:Yotoco;ID:3665679', '13269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13269', '112', '15146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3665679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15147', '1079', '1', 'Yopal', 'CO.32.3665690', 'ASCII:Yopal;ID:3665690', '13270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13270', '112', '15147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3665690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15148', '1079', '1', 'Yolombó', 'CO.02.3665695', 'ASCII:Yolombo;ID:3665695', '13271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13271', '112', '15148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3665695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15149', '1079', '1', 'Yarumal', 'CO.02.3665747', 'ASCII:Yarumal;ID:3665747', '13272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13272', '112', '15149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3665747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15150', '1079', '1', 'Yalí', 'CO.02.3665793', 'ASCII:Yali;ID:3665793', '13273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13273', '112', '15150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3665793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15151', '1079', '1', 'Yaguará', 'CO.16.3665804', 'ASCII:Yaguara;ID:3665804', '13274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13274', '112', '15151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3665804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15152', '1079', '1', 'Yacuanquer', 'CO.20.3665812', 'ASCII:Yacuanquer;ID:3665812', '13275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13275', '112', '15152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3665812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15153', '1079', '1', 'Yacopí', 'CO.33.3665814', 'ASCII:Yacopi;ID:3665814', '13276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13276', '112', '15153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3665814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15154', '1079', '1', 'Viterbo', 'CO.37.3665852', 'ASCII:Viterbo;ID:3665852', '13277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13277', '112', '15154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3665852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15155', '1079', '1', 'Viracachá', 'CO.36.3665880', 'ASCII:Viracacha;ID:3665880', '13278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13278', '112', '15155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3665880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15156', '1079', '1', 'Viotá', 'CO.33.3665882', 'ASCII:Viota;ID:3665882', '13279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13279', '112', '15156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3665882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15157', '1079', '1', 'Villeta', 'CO.33.3665896', 'ASCII:Villeta;ID:3665896', '13280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13280', '112', '15157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3665896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15158', '1079', '1', 'Villavieja', 'CO.16.3665899', 'ASCII:Villavieja;ID:3665899', '13281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13281', '112', '15158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3665899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15159', '1079', '1', 'Villavicencio', 'CO.19.3665901', 'ASCII:Villavicencio;ID:3665901', '13282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13282', '112', '15159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3665901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15160', '1079', '1', 'Villarrica', 'CO.28.3665912', 'ASCII:Villarrica;ID:3665912', '13283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13283', '112', '15160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3665912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15161', '1079', '1', 'Villa Del Rosario', 'CO.21.3665914', 'ASCII:Villa Del Rosario;ID:3665914', '13284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13284', '112', '15161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3665914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15162', '1079', '1', 'Villapinzón', 'CO.33.3665925', 'ASCII:Villapinzon;ID:3665925', '13285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13285', '112', '15162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3665925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15163', '1079', '1', 'Villanueva', 'CO.17.3665960', 'ASCII:Villanueva;ID:3665960', '13286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13286', '112', '15163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.17.3665960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15164', '1079', '1', 'Villanueva', 'CO.35.3665961', 'ASCII:Villanueva;ID:3665961', '13287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13287', '112', '15164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3665961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15165', '1079', '1', 'Villamaría', 'CO.37.3665975', 'ASCII:Villamaria;ID:3665975', '13288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13288', '112', '15165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3665975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15166', '1079', '1', 'Villahermosa', 'CO.28.3665989', 'ASCII:Villahermosa;ID:3665989', '13289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13289', '112', '15166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3665989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15167', '1079', '1', 'Villa Caro', 'CO.21.3666017', 'ASCII:Villa Caro;ID:3666017', '13290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13290', '112', '15167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3666017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15168', '1079', '1', 'Vijes', 'CO.29.3666026', 'ASCII:Vijes;ID:3666026', '13291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13291', '112', '15168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3666026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15169', '1079', '1', 'Victoria', 'CO.37.3666079', 'ASCII:Victoria;ID:3666079', '13292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13292', '112', '15169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3666079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15170', '1079', '1', 'Vianí', 'CO.33.3666088', 'ASCII:Viani;ID:3666088', '13293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13293', '112', '15170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3666088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15171', '1079', '1', 'Versalles', 'CO.29.3666103', 'ASCII:Versalles;ID:3666103', '13294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13294', '112', '15171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3666103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15172', '1079', '1', 'Vergara', 'CO.33.3666112', 'ASCII:Vergara;ID:3666112', '13295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13295', '112', '15172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3666112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15173', '1079', '1', 'Ventaquemada', 'CO.36.3666166', 'ASCII:Ventaquemada;ID:3666166', '13296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13296', '112', '15173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3666166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15174', '1079', '1', 'Venecia', 'CO.02.3666207', 'ASCII:Venecia;ID:3666207', '13297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13297', '112', '15174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3666207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15175', '1079', '1', 'Venadillo', 'CO.28.3666227', 'ASCII:Venadillo;ID:3666227', '13298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13298', '112', '15175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3666227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15176', '1079', '1', 'Vélez', 'CO.26.3666233', 'ASCII:Velez;ID:3666233', '13299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13299', '112', '15176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3666233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15177', '1079', '1', 'Valparaíso', 'CO.02.3666292', 'ASCII:Valparaiso;ID:3666292', '13300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13300', '112', '15177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3666292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15178', '1079', '1', 'Valle de San Juan', 'CO.28.3666310', 'ASCII:Valle de San Juan;ID:3666310', '13301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13301', '112', '15178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3666310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15179', '1079', '1', 'Valle de San José', 'CO.26.3666312', 'ASCII:Valle de San Jose;ID:3666312', '13302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13302', '112', '15179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3666312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15180', '1079', '1', 'Valencia', 'CO.12.3666330', 'ASCII:Valencia;ID:3666330', '13303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13303', '112', '15180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3666330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15181', '1079', '1', 'Valdivia', 'CO.02.3666334', 'ASCII:Valdivia;ID:3666334', '13304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13304', '112', '15181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3666334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15182', '1079', '1', 'Utica', 'CO.33.3666364', 'ASCII:Utica;ID:3666364', '13305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13305', '112', '15182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3666364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15183', '1079', '1', 'Usiacurí', 'CO.04.3666371', 'ASCII:Usiacuri;ID:3666371', '13306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13306', '112', '15183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3666371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15184', '1079', '1', 'Urrao', 'CO.02.3666396', 'ASCII:Urrao;ID:3666396', '13307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13307', '112', '15184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3666396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15185', '1079', '1', 'Uribia', 'CO.17.3666412', 'ASCII:Uribia;ID:3666412', '13308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13308', '112', '15185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.17.3666412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15186', '1079', '1', 'Une', 'CO.33.3666482', 'ASCII:Une;ID:3666482', '13309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13309', '112', '15186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3666482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15187', '1079', '1', 'Umpalá', 'CO.26.3666489', 'ASCII:Umpala;ID:3666489', '13310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13310', '112', '15187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3666489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15188', '1079', '1', 'Umbita', 'CO.33.3666494', 'ASCII:Umbita;ID:3666494', '13311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13311', '112', '15188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3666494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15189', '1079', '1', 'Ulloa', 'CO.29.3666504', 'ASCII:Ulloa;ID:3666504', '13312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13312', '112', '15189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3666504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15190', '1079', '1', 'Ubaté', 'CO.33.3666520', 'ASCII:Ubate;ID:3666520', '13313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13313', '112', '15190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3666520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15191', '1079', '1', 'Ubaque', 'CO.33.3666523', 'ASCII:Ubaque;ID:3666523', '13314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13314', '112', '15191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3666523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15192', '1079', '1', 'Ubalá', 'CO.33.3666527', 'ASCII:Ubala;ID:3666527', '13315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13315', '112', '15192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3666527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15193', '1079', '1', 'Tutazá', 'CO.36.3666545', 'ASCII:Tutaza;ID:3666545', '13316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13316', '112', '15193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3666545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15194', '1079', '1', 'Tuta', 'CO.36.3666551', 'ASCII:Tuta;ID:3666551', '13317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13317', '112', '15194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3666551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15195', '1079', '1', 'Turmequé', 'CO.36.3666563', 'ASCII:Turmeque;ID:3666563', '13318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13318', '112', '15195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3666563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15196', '1079', '1', 'Turbo', 'CO.02.3666571', 'ASCII:Turbo;ID:3666571', '13319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13319', '112', '15196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3666571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15197', '1079', '1', 'Turbaná', 'CO.35.3666576', 'ASCII:Turbana;ID:3666576', '13320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13320', '112', '15197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3666576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15198', '1079', '1', 'Turbaco', 'CO.35.3666579', 'ASCII:Turbaco;ID:3666579', '13321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13321', '112', '15198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3666579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15199', '1079', '1', 'Túquerres', 'CO.20.3666583', 'ASCII:Tuquerres;ID:3666583', '13322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13322', '112', '15199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3666583» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15200', '1079', '1', 'Tunja', 'CO.36.3666610', 'ASCII:Tunja;ID:3666610', '13323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13323', '112', '15200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3666610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15201', '1079', '1', 'Tumaco', 'CO.20.3666641', 'ASCII:Tumaco;ID:3666641', '13324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13324', '112', '15201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3666641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15202', '1079', '1', 'Tuluá', 'CO.29.3666646', 'ASCII:Tulua;ID:3666646', '13325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13325', '112', '15202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3666646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15203', '1079', '1', 'Tubará', 'CO.04.3666674', 'ASCII:Tubara;ID:3666674', '13326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13326', '112', '15203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3666674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15204', '1079', '1', 'Trujillo', 'CO.29.3666682', 'ASCII:Trujillo;ID:3666682', '13327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13327', '112', '15204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3666682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15205', '1079', '1', 'Trinidad', 'CO.32.3666722', 'ASCII:Trinidad;ID:3666722', '13328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13328', '112', '15205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3666722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15206', '1079', '1', 'Totoró', 'CO.09.3666835', 'ASCII:Totoro;ID:3666835', '13329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13329', '112', '15206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3666835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15207', '1079', '1', 'Tota', 'CO.36.3666841', 'ASCII:Tota;ID:3666841', '13330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13330', '112', '15207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3666841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15208', '1079', '1', 'Toro', 'CO.29.3666882', 'ASCII:Toro;ID:3666882', '13331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13331', '112', '15208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3666882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15209', '1079', '1', 'Toribío', 'CO.09.3666888', 'ASCII:Toribio;ID:3666888', '13332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13332', '112', '15209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3666888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15210', '1079', '1', 'Topaipí', 'CO.33.3666904', 'ASCII:Topaipi;ID:3666904', '13333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13333', '112', '15210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3666904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15211', '1079', '1', 'Tópaga', 'CO.36.3666906', 'ASCII:Topaga;ID:3666906', '13334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13334', '112', '15211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3666906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15212', '1079', '1', 'Tona', 'CO.26.3666922', 'ASCII:Tona;ID:3666922', '13335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13335', '112', '15212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3666922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15213', '1079', '1', 'Toluviejo', 'CO.27.3666937', 'ASCII:Toluviejo;ID:3666937', '13336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13336', '112', '15213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3666937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15214', '1079', '1', 'Tolú', 'CO.27.3666941', 'ASCII:Tolu;ID:3666941', '13337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13337', '112', '15214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3666941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15215', '1079', '1', 'Toledo', 'CO.21.3666961', 'ASCII:Toledo;ID:3666961', '13338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13338', '112', '15215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3666961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15216', '1079', '1', 'Toledo', 'CO.02.3666962', 'ASCII:Toledo;ID:3666962', '13339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13339', '112', '15216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3666962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15217', '1079', '1', 'Togüí', 'CO.36.3666965', 'ASCII:Togui;ID:3666965', '13340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13340', '112', '15217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3666965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15218', '1079', '1', 'Tocancipá', 'CO.33.3666998', 'ASCII:Tocancipa;ID:3666998', '13341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13341', '112', '15218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3666998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15219', '1079', '1', 'Tocaima', 'CO.33.3667004', 'ASCII:Tocaima;ID:3667004', '13342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13342', '112', '15219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15220', '1079', '1', 'Toca', 'CO.36.3667008', 'ASCII:Toca;ID:3667008', '13343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13343', '112', '15220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15221', '1079', '1', 'Titiribí', 'CO.02.3667024', 'ASCII:Titiribi;ID:3667024', '13344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13344', '112', '15221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3667024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15222', '1079', '1', 'Tinjacá', 'CO.36.3667051', 'ASCII:Tinjaca;ID:3667051', '13345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13345', '112', '15222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15223', '1079', '1', 'Timbiquí', 'CO.09.3667071', 'ASCII:Timbiqui;ID:3667071', '13346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13346', '112', '15223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3667071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15224', '1079', '1', 'Timbío', 'CO.09.3667074', 'ASCII:Timbio;ID:3667074', '13347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13347', '112', '15224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3667074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15225', '1079', '1', 'Timaná', 'CO.16.3667083', 'ASCII:Timana;ID:3667083', '13348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13348', '112', '15225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3667083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15226', '1079', '1', 'Tierralta', 'CO.12.3667159', 'ASCII:Tierralta;ID:3667159', '13349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13349', '112', '15226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3667159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15227', '1079', '1', 'Tibirita', 'CO.33.3667206', 'ASCII:Tibirita;ID:3667206', '13350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13350', '112', '15227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15228', '1079', '1', 'Tibasosa', 'CO.36.3667213', 'ASCII:Tibasosa;ID:3667213', '13351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13351', '112', '15228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15229', '1079', '1', 'Tibaná', 'CO.36.3667219', 'ASCII:Tibana;ID:3667219', '13352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13352', '112', '15229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15230', '1079', '1', 'Tibacuy', 'CO.33.3667223', 'ASCII:Tibacuy;ID:3667223', '13353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13353', '112', '15230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15231', '1079', '1', 'Tesalia', 'CO.16.3667245', 'ASCII:Tesalia;ID:3667245', '13354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13354', '112', '15231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3667245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15232', '1079', '1', 'Teruel', 'CO.16.3667248', 'ASCII:Teruel;ID:3667248', '13355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13355', '112', '15232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3667248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15233', '1079', '1', 'Teorama', 'CO.21.3667287', 'ASCII:Teorama;ID:3667287', '13356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13356', '112', '15233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3667287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15234', '1079', '1', 'Tenza', 'CO.33.3667289', 'ASCII:Tenza;ID:3667289', '13357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13357', '112', '15234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15235', '1079', '1', 'Tenjo', 'CO.33.3667292', 'ASCII:Tenjo;ID:3667292', '13358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13358', '112', '15235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15236', '1079', '1', 'Tenerife', 'CO.38.3667302', 'ASCII:Tenerife;ID:3667302', '13359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13359', '112', '15236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3667302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15237', '1079', '1', 'Tena', 'CO.33.3667311', 'ASCII:Tena;ID:3667311', '13360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13360', '112', '15237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15238', '1079', '1', 'Tello', 'CO.16.3667324', 'ASCII:Tello;ID:3667324', '13361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13361', '112', '15238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3667324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15239', '1079', '1', 'Tausa', 'CO.33.3667352', 'ASCII:Tausa;ID:3667352', '13362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13362', '112', '15239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15240', '1079', '1', 'Tasco', 'CO.36.3667374', 'ASCII:Tasco;ID:3667374', '13363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13363', '112', '15240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15241', '1079', '1', 'Tarso', 'CO.02.3667381', 'ASCII:Tarso;ID:3667381', '13364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13364', '112', '15241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3667381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15242', '1079', '1', 'Tarqui', 'CO.16.3667388', 'ASCII:Tarqui;ID:3667388', '13365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13365', '112', '15242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3667388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15243', '1079', '1', 'Tangua', 'CO.20.3667448', 'ASCII:Tangua;ID:3667448', '13366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13366', '112', '15243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3667448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15244', '1079', '1', 'Taminango', 'CO.20.3667472', 'ASCII:Taminango;ID:3667472', '13367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13367', '112', '15244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3667472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15245', '1079', '1', 'Támesis', 'CO.02.3667474', 'ASCII:Tamesis;ID:3667474', '13368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13368', '112', '15245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3667474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15246', '1079', '1', 'Tame', 'CO.03.3667480', 'ASCII:Tame;ID:3667480', '13369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13369', '112', '15246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.03.3667480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15247', '1079', '1', 'Támara', 'CO.32.3667517', 'ASCII:Tamara;ID:3667517', '13370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13370', '112', '15247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3667517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15248', '1079', '1', 'Tamalameque', 'CO.10.3667529', 'ASCII:Tamalameque;ID:3667529', '13371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13371', '112', '15248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.10.3667529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15249', '1079', '1', 'Tadó', 'CO.11.3667580', 'ASCII:Tado;ID:3667580', '13372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13372', '112', '15249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3667580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15250', '1079', '1', 'Tabio', 'CO.33.3667630', 'ASCII:Tabio;ID:3667630', '13373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13373', '112', '15250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15251', '1079', '1', 'Sutatenza', 'CO.33.3667648', 'ASCII:Sutatenza;ID:3667648', '13374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13374', '112', '15251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15252', '1079', '1', 'Sutatausa', 'CO.33.3667650', 'ASCII:Sutatausa;ID:3667650', '13375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13375', '112', '15252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15253', '1079', '1', 'Sutamarchán', 'CO.36.3667652', 'ASCII:Sutamarchan;ID:3667652', '13376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13376', '112', '15253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15254', '1079', '1', 'Susacón', 'CO.36.3667661', 'ASCII:Susacon;ID:3667661', '13377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13377', '112', '15254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15255', '1079', '1', 'Susa', 'CO.33.3667666', 'ASCII:Susa;ID:3667666', '13378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13378', '112', '15255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15256', '1079', '1', 'Suratá', 'CO.26.3667686', 'ASCII:Surata;ID:3667686', '13379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13379', '112', '15256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3667686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15257', '1079', '1', 'Supía', 'CO.37.3667698', 'ASCII:Supia;ID:3667698', '13380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13380', '112', '15257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3667698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15258', '1079', '1', 'Supatá', 'CO.33.3667702', 'ASCII:Supata;ID:3667702', '13381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13381', '112', '15258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15259', '1079', '1', 'Suesca', 'CO.33.3667718', 'ASCII:Suesca;ID:3667718', '13382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13382', '112', '15259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15260', '1079', '1', 'Sucre', 'CO.27.3667734', 'ASCII:Sucre;ID:3667734', '13383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13383', '112', '15260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3667734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15261', '1079', '1', 'Sucre', 'CO.26.3667735', 'ASCII:Sucre;ID:3667735', '13384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13384', '112', '15261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3667735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15262', '1079', '1', 'Subachoque', 'CO.33.3667761', 'ASCII:Subachoque;ID:3667761', '13385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13385', '112', '15262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15263', '1079', '1', 'Suaza', 'CO.16.3667765', 'ASCII:Suaza;ID:3667765', '13386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13386', '112', '15263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3667765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15264', '1079', '1', 'Suárez', 'CO.28.3667775', 'ASCII:Suarez;ID:3667775', '13387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13387', '112', '15264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3667775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15265', '1079', '1', 'Suan', 'CO.04.3667781', 'ASCII:Suan;ID:3667781', '13388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13388', '112', '15265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3667781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15266', '1079', '1', 'Suaita', 'CO.26.3667784', 'ASCII:Suaita;ID:3667784', '13389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13389', '112', '15266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3667784» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15267', '1079', '1', 'Sotará', 'CO.09.3667795', 'ASCII:Sotara;ID:3667795', '13390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13390', '112', '15267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3667795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15268', '1079', '1', 'Sotaquirá', 'CO.36.3667797', 'ASCII:Sotaquira;ID:3667797', '13391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13391', '112', '15268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15269', '1079', '1', 'Sopó', 'CO.33.3667808', 'ASCII:Sopo;ID:3667808', '13392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13392', '112', '15269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15270', '1079', '1', 'Soplaviento', 'CO.35.3667813', 'ASCII:Soplaviento;ID:3667813', '13393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13393', '112', '15270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3667813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15271', '1079', '1', 'Sopetrán', 'CO.02.3667817', 'ASCII:Sopetran;ID:3667817', '13394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13394', '112', '15271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3667817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15272', '1079', '1', 'Sonsón', 'CO.02.3667821', 'ASCII:Sonson;ID:3667821', '13395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13395', '112', '15272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3667821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15273', '1079', '1', 'Soledad', 'CO.04.3667859', 'ASCII:Soledad;ID:3667859', '13396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13396', '112', '15273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3667859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15274', '1079', '1', 'Bahía Solano', 'CO.11.3667869', 'ASCII:Bahia Solano;ID:3667869', '13397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13397', '112', '15274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3667869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15275', '1079', '1', 'Sogamoso', 'CO.36.3667874', 'ASCII:Sogamoso;ID:3667874', '13398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13398', '112', '15275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15276', '1079', '1', 'Socotá', 'CO.36.3667881', 'ASCII:Socota;ID:3667881', '13399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13399', '112', '15276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15277', '1079', '1', 'Socorro', 'CO.26.3667888', 'ASCII:Socorro;ID:3667888', '13400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13400', '112', '15277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3667888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15278', '1079', '1', 'Socha', 'CO.36.3667897', 'ASCII:Socha;ID:3667897', '13401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13401', '112', '15278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667897» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15279', '1079', '1', 'Soatá', 'CO.36.3667903', 'ASCII:Soata;ID:3667903', '13402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13402', '112', '15279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3667903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15280', '1079', '1', 'Soacha', 'CO.33.3667906', 'ASCII:Soacha;ID:3667906', '13403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13403', '112', '15280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3667906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15281', '1079', '1', 'Sitionuevo', 'CO.38.3667924', 'ASCII:Sitionuevo;ID:3667924', '13404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13404', '112', '15281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3667924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15282', '1079', '1', 'Sipí', 'CO.11.3667960', 'ASCII:Sipi;ID:3667960', '13405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13405', '112', '15282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3667960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15283', '1079', '1', 'Sincelejo', 'CO.27.3667985', 'ASCII:Sincelejo;ID:3667985', '13406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13406', '112', '15283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3667985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15284', '1079', '1', 'Sincé', 'CO.27.3667992', 'ASCII:Since;ID:3667992', '13407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13407', '112', '15284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3667992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15285', '1079', '1', 'Simití', 'CO.35.3668014', 'ASCII:Simiti;ID:3668014', '13408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13408', '112', '15285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3668014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15286', '1079', '1', 'Simijaca', 'CO.33.3668018', 'ASCII:Simijaca;ID:3668018', '13409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13409', '112', '15286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3668018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15287', '1079', '1', 'Simacota', 'CO.26.3668024', 'ASCII:Simacota;ID:3668024', '13410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13410', '112', '15287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3668024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15288', '1079', '1', 'Silvia', 'CO.09.3668026', 'ASCII:Silvia;ID:3668026', '13411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13411', '112', '15288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3668026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15289', '1079', '1', 'Silvania', 'CO.33.3668029', 'ASCII:Silvania;ID:3668029', '13412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13412', '112', '15289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3668029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15290', '1079', '1', 'Silos', 'CO.21.3668034', 'ASCII:Silos;ID:3668034', '13413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13413', '112', '15290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3668034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15291', '1079', '1', 'Siachoque', 'CO.36.3668097', 'ASCII:Siachoque;ID:3668097', '13414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13414', '112', '15291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3668097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15292', '1079', '1', 'Sevilla', 'CO.29.3668134', 'ASCII:Sevilla;ID:3668134', '13415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13415', '112', '15292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3668134» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15293', '1079', '1', 'Sesquilé', 'CO.33.3668139', 'ASCII:Sesquile;ID:3668139', '13416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13416', '112', '15293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3668139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15294', '1079', '1', 'Segovia', 'CO.02.3668177', 'ASCII:Segovia;ID:3668177', '13417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13417', '112', '15294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3668177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15295', '1079', '1', 'Sátivasur', 'CO.36.3668220', 'ASCII:Sativasur;ID:3668220', '13418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13418', '112', '15295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3668220» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15296', '1079', '1', 'Sátivanorte', 'CO.36.3668222', 'ASCII:Sativanorte;ID:3668222', '13419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13419', '112', '15296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3668222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15297', '1079', '1', 'Sasaima', 'CO.33.3668229', 'ASCII:Sasaima;ID:3668229', '13420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13420', '112', '15297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3668229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15298', '1079', '1', 'Sardinata', 'CO.21.3668246', 'ASCII:Sardinata;ID:3668246', '13421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13421', '112', '15298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3668246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15299', '1079', '1', 'Saravena', 'CO.03.3668259', 'ASCII:Saravena;ID:3668259', '13422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13422', '112', '15299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.03.3668259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15300', '1079', '1', 'Sapuyes', 'CO.20.3668269', 'ASCII:Sapuyes;ID:3668269', '13423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13423', '112', '15300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3668269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15301', '1079', '1', 'San Zenón', 'CO.38.3668287', 'ASCII:San Zenon;ID:3668287', '13424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13424', '112', '15301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3668287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15302', '1079', '1', 'San Vicente del Caguán', 'CO.08.3668291', 'ASCII:San Vicente del Caguan;ID:3668291', '13425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13425', '112', '15302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.08.3668291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15303', '1079', '1', 'San Vicente de Chucurí', 'CO.26.3668293', 'ASCII:San Vicente de Chucuri;ID:3668293', '13426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13426', '112', '15303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3668293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15304', '1079', '1', 'San Vicente', 'CO.02.3668318', 'ASCII:San Vicente;ID:3668318', '13427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13427', '112', '15304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3668318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15305', '1079', '1', 'Santuario', 'CO.02.3668328', 'ASCII:Santuario;ID:3668328', '13428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13428', '112', '15305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3668328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15306', '1079', '1', 'Santuario', 'CO.24.3668329', 'ASCII:Santuario;ID:3668329', '13429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13429', '112', '15306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3668329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15307', '1079', '1', 'Santo Tomás', 'CO.04.3668337', 'ASCII:Santo Tomas;ID:3668337', '13430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13430', '112', '15307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3668337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15308', '1079', '1', 'Santiago', 'CO.21.3668401', 'ASCII:Santiago;ID:3668401', '13431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13431', '112', '15308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3668401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15309', '1079', '1', 'Santa Sofía', 'CO.36.3668437', 'ASCII:Santa Sofia;ID:3668437', '13432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13432', '112', '15309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3668437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15310', '1079', '1', 'Santa Rosa de Viterbo', 'CO.36.3668448', 'ASCII:Santa Rosa de Viterbo;ID:3668448', '13433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13433', '112', '15310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3668448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15311', '1079', '1', 'Santa Rosa de Osos', 'CO.02.3668452', 'ASCII:Santa Rosa de Osos;ID:3668452', '13434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13434', '112', '15311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3668452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15312', '1079', '1', 'Santa Rosa de Cabal', 'CO.24.3668455', 'ASCII:Santa Rosa de Cabal;ID:3668455', '13435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13435', '112', '15312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3668455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15313', '1079', '1', 'Santa Rosa', 'CO.35.3668524', 'ASCII:Santa Rosa;ID:3668524', '13436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13436', '112', '15313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3668524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15314', '1079', '1', 'Santa Rosa', 'CO.09.3668525', 'ASCII:Santa Rosa;ID:3668525', '13437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13437', '112', '15314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3668525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15315', '1079', '1', 'Santander de Quilichao', 'CO.09.3668573', 'ASCII:Santander de Quilichao;ID:3668573', '13438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13438', '112', '15315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3668573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15316', '1079', '1', 'Santa Marta', 'CO.38.3668614', 'ASCII:Santa Marta;ID:3668614', '13439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13439', '112', '15316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3668614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15317', '1079', '1', 'Santa María', 'CO.16.3668643', 'ASCII:Santa Maria;ID:3668643', '13440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13440', '112', '15317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3668643» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15318', '1079', '1', 'Santa Isabel', 'CO.28.3668721', 'ASCII:Santa Isabel;ID:3668721', '13441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13441', '112', '15318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3668721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15319', '1079', '1', 'Santa Cruz', 'CO.20.3668834', 'ASCII:Santa Cruz;ID:3668834', '13442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13442', '112', '15319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3668834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15320', '1079', '1', 'Santa Catalina', 'CO.35.3668858', 'ASCII:Santa Catalina;ID:3668858', '13443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13443', '112', '15320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3668858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15321', '1079', '1', 'Santa Bárbara', 'CO.02.3668920', 'ASCII:Santa Barbara;ID:3668920', '13444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13444', '112', '15321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3668920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15322', '1079', '1', 'Santa Bárbara', 'CO.20.3668921', 'ASCII:Santa Barbara;ID:3668921', '13445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13445', '112', '15322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3668921» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15323', '1079', '1', 'Santa Ana', 'CO.38.3668928', 'ASCII:Santa Ana;ID:3668928', '13446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13446', '112', '15323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3668928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15324', '1079', '1', 'Santa Ana', 'CO.36.3668968', 'ASCII:Santa Ana;ID:3668968', '13447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13447', '112', '15324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3668968» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15325', '1079', '1', 'San Sebastián de Buenavista', 'CO.38.3668979', 'ASCII:San Sebastian de Buenavista;ID:3668979', '13448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13448', '112', '15325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3668979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15326', '1079', '1', 'San Sebastián', 'CO.09.3668992', 'ASCII:San Sebastian;ID:3668992', '13449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13449', '112', '15326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3668992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15327', '1079', '1', 'San Roque', 'CO.02.3669018', 'ASCII:San Roque;ID:3669018', '13450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13450', '112', '15327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3669018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15328', '1079', '1', 'San Rafael', 'CO.02.3669034', 'ASCII:San Rafael;ID:3669034', '13451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13451', '112', '15328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3669034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15329', '1079', '1', 'San Pelayo', 'CO.12.3669085', 'ASCII:San Pelayo;ID:3669085', '13452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13452', '112', '15329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3669085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15330', '1079', '1', 'San Pedro', 'CO.27.3669167', 'ASCII:San Pedro;ID:3669167', '13453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13453', '112', '15330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3669167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15331', '1079', '1', 'San Pedro', 'CO.02.3669168', 'ASCII:San Pedro;ID:3669168', '13454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13454', '112', '15331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3669168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15332', '1079', '1', 'San Pedro', 'CO.29.3669169', 'ASCII:San Pedro;ID:3669169', '13455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13455', '112', '15332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3669169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15333', '1079', '1', 'San Pablo de Borbur', 'CO.36.3669174', 'ASCII:San Pablo de Borbur;ID:3669174', '13456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13456', '112', '15333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3669174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15334', '1079', '1', 'San Pablo', 'CO.20.3669217', 'ASCII:San Pablo;ID:3669217', '13457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13457', '112', '15334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3669217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15335', '1079', '1', 'San Onofre', 'CO.27.3669219', 'ASCII:San Onofre;ID:3669219', '13458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13458', '112', '15335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3669219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15336', '1079', '1', 'San Miguel de Sema', 'CO.36.3669239', 'ASCII:San Miguel de Sema;ID:3669239', '13459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13459', '112', '15336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3669239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15337', '1079', '1', 'San Miguel', 'CO.26.3669294', 'ASCII:San Miguel;ID:3669294', '13460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13460', '112', '15337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3669294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15338', '1079', '1', 'San Mateo', 'CO.36.3669314', 'ASCII:San Mateo;ID:3669314', '13461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13461', '112', '15338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3669314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15339', '1079', '1', 'San Martín de Loba', 'CO.35.3669317', 'ASCII:San Martin de Loba;ID:3669317', '13462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13462', '112', '15339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3669317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15340', '1079', '1', 'San Martín', 'CO.19.3669334', 'ASCII:San Martin;ID:3669334', '13463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13463', '112', '15340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3669334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15341', '1079', '1', 'San Marcos', 'CO.27.3669350', 'ASCII:San Marcos;ID:3669350', '13464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13464', '112', '15341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3669350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15342', '1079', '1', 'San Luis de Palenque', 'CO.32.3669354', 'ASCII:San Luis de Palenque;ID:3669354', '13465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13465', '112', '15342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3669354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15343', '1079', '1', 'San Luis de Gaceno', 'CO.32.3669357', 'ASCII:San Luis de Gaceno;ID:3669357', '13466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13466', '112', '15343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3669357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15344', '1079', '1', 'San Luis', 'CO.02.3669407', 'ASCII:San Luis;ID:3669407', '13467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13467', '112', '15344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3669407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15345', '1079', '1', 'San Luis', 'CO.28.3669408', 'ASCII:San Luis;ID:3669408', '13468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13468', '112', '15345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3669408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15346', '1079', '1', 'San Lorenzo', 'CO.20.3669441', 'ASCII:San Lorenzo;ID:3669441', '13469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13469', '112', '15346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3669441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15347', '1079', '1', 'San Juan Nepomuceno', 'CO.35.3669455', 'ASCII:San Juan Nepomuceno;ID:3669455', '13470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13470', '112', '15347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3669455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15348', '1079', '1', 'San Juan de Ríoseco', 'CO.33.3669465', 'ASCII:San Juan de Rioseco;ID:3669465', '13471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13471', '112', '15348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3669465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15349', '1079', '1', 'San Juan del César', 'CO.17.3669470', 'ASCII:San Juan del Cesar;ID:3669470', '13472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13472', '112', '15349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.17.3669470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15350', '1079', '1', 'San José de Pare', 'CO.36.3669542', 'ASCII:San Jose de Pare;ID:3669542', '13473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13473', '112', '15350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3669542» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15351', '1079', '1', 'San José de Miranda', 'CO.26.3669546', 'ASCII:San Jose de Miranda;ID:3669546', '13474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13474', '112', '15351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3669546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15352', '1079', '1', 'San José del Palmar', 'CO.11.3669550', 'ASCII:San Jose del Palmar;ID:3669550', '13475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13475', '112', '15352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3669550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15353', '1079', '1', 'Isnos', 'CO.16.3669559', 'ASCII:Isnos;ID:3669559', '13476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13476', '112', '15353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3669559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15354', '1079', '1', 'San Joaquín', 'CO.26.3669709', 'ASCII:San Joaquin;ID:3669709', '13477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13477', '112', '15354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3669709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15355', '1079', '1', 'San Jerónimo', 'CO.02.3669722', 'ASCII:San Jeronimo;ID:3669722', '13478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13478', '112', '15355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3669722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15356', '1079', '1', 'San Jacinto', 'CO.35.3669739', 'ASCII:San Jacinto;ID:3669739', '13479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13479', '112', '15356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3669739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15357', '1079', '1', 'San Gil', 'CO.26.3669809', 'ASCII:San Gil;ID:3669809', '13480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13480', '112', '15357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3669809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15358', '1079', '1', 'San Francisco', 'CO.33.3669885', 'ASCII:San Francisco;ID:3669885', '13481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13481', '112', '15358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3669885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15359', '1079', '1', 'San Fernando', 'CO.35.3669903', 'ASCII:San Fernando;ID:3669903', '13482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13482', '112', '15359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3669903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15360', '1079', '1', 'San Estanislao', 'CO.35.3669930', 'ASCII:San Estanislao;ID:3669930', '13483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13483', '112', '15360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3669930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15361', '1079', '1', 'Sandoná', 'CO.20.3669939', 'ASCII:Sandona;ID:3669939', '13484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13484', '112', '15361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3669939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15362', '1079', '1', 'San Cayetano', 'CO.21.3669985', 'ASCII:San Cayetano;ID:3669985', '13485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13485', '112', '15362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3669985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15363', '1079', '1', 'San Cayetano', 'CO.33.3669986', 'ASCII:San Cayetano;ID:3669986', '13486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13486', '112', '15363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3669986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15364', '1079', '1', 'San Carlos', 'CO.12.3670009', 'ASCII:San Carlos;ID:3670009', '13487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13487', '112', '15364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3670009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15365', '1079', '1', 'San Carlos', 'CO.02.3670010', 'ASCII:San Carlos;ID:3670010', '13488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13488', '112', '15365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3670010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15366', '1079', '1', 'San Calixto', 'CO.21.3670012', 'ASCII:San Calixto;ID:3670012', '13489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13489', '112', '15366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3670012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15367', '1079', '1', 'San Bernardo del Viento', 'CO.12.3670019', 'ASCII:San Bernardo del Viento;ID:3670019', '13490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13490', '112', '15367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3670019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15368', '1079', '1', 'San Bernardo', 'CO.33.3670036', 'ASCII:San Bernardo;ID:3670036', '13491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13491', '112', '15368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3670036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15369', '1079', '1', 'San Benito Abad', 'CO.27.3670039', 'ASCII:San Benito Abad;ID:3670039', '13492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13492', '112', '15369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3670039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15370', '1079', '1', 'San Benito', 'CO.26.3670044', 'ASCII:San Benito;ID:3670044', '13493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13493', '112', '15370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3670044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15371', '1079', '1', 'San Antonio de Tena', 'CO.33.3670059', 'ASCII:San Antonio de Tena;ID:3670059', '13494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13494', '112', '15371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3670059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15372', '1079', '1', 'San Antonio', 'CO.28.3670198', 'ASCII:San Antonio;ID:3670198', '13495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13495', '112', '15372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3670198» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15373', '1079', '1', 'San Antero', 'CO.12.3670200', 'ASCII:San Antero;ID:3670200', '13496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13496', '112', '15373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3670200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15374', '1079', '1', 'San Andrés de Sotavento', 'CO.12.3670208', 'ASCII:San Andres de Sotavento;ID:3670208', '13497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13497', '112', '15374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3670208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15375', '1079', '1', 'San Andrés', 'CO.25.3670229', 'ASCII:San Andres;ID:3670229', '13498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13498', '112', '15375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.25.3670229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15376', '1079', '1', 'San Andrés', 'CO.02.3670230', 'ASCII:San Andres;ID:3670230', '13499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13499', '112', '15376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3670230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15377', '1079', '1', 'San Andrés', 'CO.26.3670231', 'ASCII:San Andres;ID:3670231', '13500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13500', '112', '15377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3670231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15378', '1079', '1', 'San Agustín', 'CO.16.3670266', 'ASCII:San Agustin;ID:3670266', '13501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13501', '112', '15378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3670266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15379', '1079', '1', 'Sampués', 'CO.27.3670282', 'ASCII:Sampues;ID:3670282', '13502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13502', '112', '15379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3670282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15380', '1079', '1', 'Samaniego', 'CO.20.3670294', 'ASCII:Samaniego;ID:3670294', '13503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13503', '112', '15380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3670294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15381', '1079', '1', 'Samaná', 'CO.37.3670301', 'ASCII:Samana;ID:3670301', '13504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13504', '112', '15381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3670301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15382', '1079', '1', 'Samacá', 'CO.36.3670304', 'ASCII:Samaca;ID:3670304', '13505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13505', '112', '15382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3670304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15383', '1079', '1', 'Salgar', 'CO.02.3670351', 'ASCII:Salgar;ID:3670351', '13506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13506', '112', '15383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3670351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15384', '1079', '1', 'Salento', 'CO.23.3670353', 'ASCII:Salento;ID:3670353', '13507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13507', '112', '15384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.23.3670353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15385', '1079', '1', 'Salazar', 'CO.21.3670361', 'ASCII:Salazar;ID:3670361', '13508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13508', '112', '15385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3670361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15386', '1079', '1', 'Salamina', 'CO.38.3670371', 'ASCII:Salamina;ID:3670371', '13509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13509', '112', '15386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3670371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15387', '1079', '1', 'Salamina', 'CO.37.3670372', 'ASCII:Salamina;ID:3670372', '13510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13510', '112', '15387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3670372» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15388', '1079', '1', 'Saladoblanco', 'CO.16.3670384', 'ASCII:Saladoblanco;ID:3670384', '13511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13511', '112', '15388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3670384» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15389', '1079', '1', 'Sahagún', 'CO.12.3670420', 'ASCII:Sahagun;ID:3670420', '13512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13512', '112', '15389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3670420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15390', '1079', '1', 'Sáchica', 'CO.36.3670432', 'ASCII:Sachica;ID:3670432', '13513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13513', '112', '15390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3670432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15391', '1079', '1', 'Sácama', 'CO.32.3670444', 'ASCII:Sacama;ID:3670444', '13514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13514', '112', '15391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3670444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15392', '1079', '1', 'Saboyá', 'CO.36.3670448', 'ASCII:Saboya;ID:3670448', '13515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13515', '112', '15392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3670448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15393', '1079', '1', 'Sabanalarga', 'CO.04.3670507', 'ASCII:Sabanalarga;ID:3670507', '13516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13516', '112', '15393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3670507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15394', '1079', '1', 'Sabanalarga', 'CO.02.3670508', 'ASCII:Sabanalarga;ID:3670508', '13517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13517', '112', '15394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3670508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15395', '1079', '1', 'Sabanagrande', 'CO.04.3670519', 'ASCII:Sabanagrande;ID:3670519', '13518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13518', '112', '15395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3670519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15396', '1079', '1', 'Rovira', 'CO.28.3670588', 'ASCII:Rovira;ID:3670588', '13519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13519', '112', '15396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3670588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15397', '1079', '1', 'Rosas', 'CO.09.3670596', 'ASCII:Rosas;ID:3670596', '13520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13520', '112', '15397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3670596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15398', '1079', '1', 'Rondón', 'CO.36.3670627', 'ASCII:Rondon;ID:3670627', '13521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13521', '112', '15398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3670627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15399', '1079', '1', 'Roncesvalles', 'CO.28.3670630', 'ASCII:Roncesvalles;ID:3670630', '13522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13522', '112', '15399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3670630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15400', '1079', '1', 'Roldanillo', 'CO.29.3670645', 'ASCII:Roldanillo;ID:3670645', '13523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13523', '112', '15400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3670645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15401', '1079', '1', 'Robles', 'CO.10.3670672', 'ASCII:Robles;ID:3670672', '13524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13524', '112', '15401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.10.3670672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15402', '1079', '1', 'La paz', 'CO.10.3670673', 'ASCII:La paz;ID:3670673', '13525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13525', '112', '15402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.10.3670673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15403', '1079', '1', 'Roberto Payán', 'CO.20.3670681', 'ASCII:Roberto Payan;ID:3670681', '13526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13526', '112', '15403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3670681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15404', '1079', '1', 'Rivera', 'CO.16.3670693', 'ASCII:Rivera;ID:3670693', '13527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13527', '112', '15404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3670693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15405', '1079', '1', 'Risaralda', 'CO.37.3670701', 'ASCII:Risaralda;ID:3670701', '13528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13528', '112', '15405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3670701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15406', '1079', '1', 'Ríosucio', 'CO.11.3670720', 'ASCII:Riosucio;ID:3670720', '13529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13529', '112', '15406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3670720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15407', '1079', '1', 'Ríosucio', 'CO.37.3670721', 'ASCII:Riosucio;ID:3670721', '13530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13530', '112', '15407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3670721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15408', '1079', '1', 'Ríonegro', 'CO.26.3670735', 'ASCII:Rionegro;ID:3670735', '13531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13531', '112', '15408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3670735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15409', '1079', '1', 'Ríonegro', 'CO.02.3670736', 'ASCII:Rionegro;ID:3670736', '13532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13532', '112', '15409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3670736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15410', '1079', '1', 'Ríohacha', 'CO.17.3670747', 'ASCII:Riohacha;ID:3670747', '13533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13533', '112', '15410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.17.3670747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15411', '1079', '1', 'Ríofrío', 'CO.29.3670755', 'ASCII:Riofrio;ID:3670755', '13534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13534', '112', '15411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3670755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15412', '1079', '1', 'Río de Oro', 'CO.10.3670757', 'ASCII:Rio de Oro;ID:3670757', '13535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13535', '112', '15412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.10.3670757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15413', '1079', '1', 'Ríoblanco', 'CO.28.3670766', 'ASCII:Rioblanco;ID:3670766', '13536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13536', '112', '15413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3670766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15414', '1079', '1', 'Chalán', 'CO.27.3670818', 'ASCII:Chalan;ID:3670818', '13537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13537', '112', '15414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3670818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15415', '1079', '1', 'Ricaurte', 'CO.20.3670819', 'ASCII:Ricaurte;ID:3670819', '13538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13538', '112', '15415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3670819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15416', '1079', '1', 'Retiro', 'CO.02.3670853', 'ASCII:Retiro;ID:3670853', '13539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13539', '112', '15416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3670853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15417', '1079', '1', 'Restrepo', 'CO.19.3670859', 'ASCII:Restrepo;ID:3670859', '13540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13540', '112', '15417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3670859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15418', '1079', '1', 'Restrepo', 'CO.29.3670860', 'ASCII:Restrepo;ID:3670860', '13541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13541', '112', '15418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3670860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15419', '1079', '1', 'Repelón', 'CO.04.3670876', 'ASCII:Repelon;ID:3670876', '13542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13542', '112', '15419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3670876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15420', '1079', '1', 'Remolino', 'CO.38.3670898', 'ASCII:Remolino;ID:3670898', '13543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13543', '112', '15420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3670898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15421', '1079', '1', 'Remedios', 'CO.02.3670900', 'ASCII:Remedios;ID:3670900', '13544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13544', '112', '15421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3670900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15422', '1079', '1', 'Recetor', 'CO.32.3670935', 'ASCII:Recetor;ID:3670935', '13545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13545', '112', '15422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3670935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15423', '1079', '1', 'Ráquira', 'CO.36.3670967', 'ASCII:Raquira;ID:3670967', '13546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13546', '112', '15423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3670967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15424', '1079', '1', 'Ramiriquí', 'CO.36.3671003', 'ASCII:Ramiriqui;ID:3671003', '13547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13547', '112', '15424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3671003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15425', '1079', '1', 'Ragonvalia', 'CO.21.3671019', 'ASCII:Ragonvalia;ID:3671019', '13548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13548', '112', '15425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3671019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15426', '1079', '1', 'Apulo', 'CO.33.3671021', 'ASCII:Apulo;ID:3671021', '13549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13549', '112', '15426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3671021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15427', '1079', '1', 'Quipile', 'CO.33.3671073', 'ASCII:Quipile;ID:3671073', '13550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13550', '112', '15427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3671073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15428', '1079', '1', 'Quinchía', 'CO.24.3671092', 'ASCII:Quinchia;ID:3671092', '13551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13551', '112', '15428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3671092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15429', '1079', '1', 'Quimbaya', 'CO.23.3671099', 'ASCII:Quimbaya;ID:3671099', '13552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13552', '112', '15429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.23.3671099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15430', '1079', '1', 'Quibdó', 'CO.11.3671117', 'ASCII:Quibdo;ID:3671117', '13553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13553', '112', '15430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3671117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15431', '1079', '1', 'Quetame', 'CO.33.3671120', 'ASCII:Quetame;ID:3671120', '13554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13554', '112', '15431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3671120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15432', '1079', '1', 'Quebradanegra', 'CO.33.3671164', 'ASCII:Quebradanegra;ID:3671164', '13555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13555', '112', '15432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3671164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15433', '1079', '1', 'Purísima', 'CO.12.3671204', 'ASCII:Purisima;ID:3671204', '13556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13556', '112', '15433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3671204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15434', '1079', '1', 'Purificación', 'CO.28.3671209', 'ASCII:Purificacion;ID:3671209', '13557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13557', '112', '15434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3671209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15435', '1079', '1', 'Puracé', 'CO.09.3671223', 'ASCII:Purace;ID:3671223', '13558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13558', '112', '15435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3671223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15436', '1079', '1', 'Pupiales', 'CO.20.3671229', 'ASCII:Pupiales;ID:3671229', '13559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13559', '112', '15436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3671229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15437', '1079', '1', 'Pulí', 'CO.33.3671280', 'ASCII:Puli;ID:3671280', '13560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13560', '112', '15437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3671280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15438', '1079', '1', 'Puerto Wilches', 'CO.26.3671289', 'ASCII:Puerto Wilches;ID:3671289', '13561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13561', '112', '15438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3671289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15439', '1079', '1', 'Puerto Tejada', 'CO.09.3671316', 'ASCII:Puerto Tejada;ID:3671316', '13562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13562', '112', '15439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3671316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15440', '1079', '1', 'Puerto Salgar', 'CO.33.3671331', 'ASCII:Puerto Salgar;ID:3671331', '13563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13563', '112', '15440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3671331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15441', '1079', '1', 'Puerto López', 'CO.19.3671422', 'ASCII:Puerto Lopez;ID:3671422', '13564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13564', '112', '15441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3671422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15442', '1079', '1', 'Puerto Lleras', 'CO.19.3671425', 'ASCII:Puerto Lleras;ID:3671425', '13565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13565', '112', '15442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3671425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15443', '1079', '1', 'Puerto Leguízamo', 'CO.22.3671438', 'ASCII:Puerto Leguizamo;ID:3671438', '13566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13566', '112', '15443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.22.3671438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15444', '1079', '1', 'Puerto Escondido', 'CO.12.3671471', 'ASCII:Puerto Escondido;ID:3671471', '13567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13567', '112', '15444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3671471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15445', '1079', '1', 'Puerto Colombia', 'CO.04.3671506', 'ASCII:Puerto Colombia;ID:3671506', '13568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13568', '112', '15445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3671506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15446', '1079', '1', 'Puerto Boyacá', 'CO.36.3671533', 'ASCII:Puerto Boyaca;ID:3671533', '13569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13569', '112', '15446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3671533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15447', '1079', '1', 'Puerto Berrío', 'CO.02.3671541', 'ASCII:Puerto Berrio;ID:3671541', '13570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13570', '112', '15447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3671541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15448', '1079', '1', 'Puerres', 'CO.20.3671578', 'ASCII:Puerres;ID:3671578', '13571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13571', '112', '15448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3671578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15449', '1079', '1', 'Puente Nacional', 'CO.26.3671592', 'ASCII:Puente Nacional;ID:3671592', '13572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13572', '112', '15449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3671592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15450', '1079', '1', 'Pueblo Viejo', 'CO.38.3671628', 'ASCII:Pueblo Viejo;ID:3671628', '13573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13573', '112', '15450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3671628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15451', '1079', '1', 'Pueblorrico', 'CO.02.3671632', 'ASCII:Pueblorrico;ID:3671632', '13574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13574', '112', '15451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3671632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15452', '1079', '1', 'Pueblo Rico', 'CO.24.3671635', 'ASCII:Pueblo Rico;ID:3671635', '13575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13575', '112', '15452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3671635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15453', '1079', '1', 'Pueblo Neuvo', 'CO.12.3671664', 'ASCII:Pueblo Neuvo;ID:3671664', '13576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13576', '112', '15453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3671664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15454', '1079', '1', 'Providencia Y Santa Catalina', 'CO.25.3671718', 'ASCII:Providencia Y Santa Catalina;ID:3671718', '13577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13577', '112', '15454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.25.3671718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15455', '1079', '1', 'Prado', 'CO.28.3671766', 'ASCII:Prado;ID:3671766', '13578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13578', '112', '15455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3671766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15456', '1079', '1', 'Pradera', 'CO.29.3671773', 'ASCII:Pradera;ID:3671773', '13579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13579', '112', '15456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3671773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15457', '1079', '1', 'Potosí', 'CO.20.3671849', 'ASCII:Potosi;ID:3671849', '13580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13580', '112', '15457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3671849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15458', '1079', '1', 'Pore', 'CO.32.3671904', 'ASCII:Pore;ID:3671904', '13581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13581', '112', '15458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3671904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15459', '1079', '1', 'Popayán', 'CO.09.3671917', 'ASCII:Popayan;ID:3671917', '13582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13582', '112', '15459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3671917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15460', '1079', '1', 'Polonuevo', 'CO.04.3671951', 'ASCII:Polonuevo;ID:3671951', '13583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13583', '112', '15460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3671951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15461', '1079', '1', 'Plato', 'CO.38.3672032', 'ASCII:Plato;ID:3672032', '13584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13584', '112', '15461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3672032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15462', '1079', '1', 'Planeta Rica', 'CO.12.3672069', 'ASCII:Planeta Rica;ID:3672069', '13585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13585', '112', '15462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3672069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15463', '1079', '1', 'Planadas', 'CO.28.3672078', 'ASCII:Planadas;ID:3672078', '13586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13586', '112', '15463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3672078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15464', '1079', '1', 'Pivijay', 'CO.38.3672094', 'ASCII:Pivijay;ID:3672094', '13587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13587', '112', '15464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3672094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15465', '1079', '1', 'Pitalito', 'CO.16.3672111', 'ASCII:Pitalito;ID:3672111', '13588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13588', '112', '15465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3672111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15466', '1079', '1', 'Pital', 'CO.16.3672124', 'ASCII:Pital;ID:3672124', '13589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13589', '112', '15466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3672124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15467', '1079', '1', 'Pisba', 'CO.36.3672144', 'ASCII:Pisba;ID:3672144', '13590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13590', '112', '15467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3672144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15468', '1079', '1', 'Piojó', 'CO.04.3672177', 'ASCII:Piojo;ID:3672177', '13591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13591', '112', '15468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3672177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15469', '1079', '1', 'Pinchote', 'CO.26.3672205', 'ASCII:Pinchote;ID:3672205', '13592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13592', '112', '15469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3672205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15470', '1079', '1', 'Pijao', 'CO.23.3672256', 'ASCII:Pijao;ID:3672256', '13593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13593', '112', '15470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.23.3672256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15471', '1079', '1', 'Piendamó', 'CO.09.3672262', 'ASCII:Piendamo;ID:3672262', '13594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13594', '112', '15471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3672262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15472', '1079', '1', 'Piedras', 'CO.28.3672292', 'ASCII:Piedras;ID:3672292', '13595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13595', '112', '15472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3672292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15473', '1079', '1', 'Piedecuesta', 'CO.26.3672331', 'ASCII:Piedecuesta;ID:3672331', '13596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13596', '112', '15473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3672331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15474', '1079', '1', 'Pesca', 'CO.36.3672430', 'ASCII:Pesca;ID:3672430', '13597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13597', '112', '15474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3672430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15475', '1079', '1', 'Pereira', 'CO.24.3672487', 'ASCII:Pereira;ID:3672487', '13598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13598', '112', '15475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3672487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15476', '1079', '1', 'Peque', 'CO.02.3672513', 'ASCII:Peque;ID:3672513', '13599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13599', '112', '15476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3672513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15477', '1079', '1', 'Pensilvania', 'CO.37.3672524', 'ASCII:Pensilvania;ID:3672524', '13600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13600', '112', '15477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3672524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15478', '1079', '1', 'Peñol', 'CO.02.3672541', 'ASCII:Penol;ID:3672541', '13601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13601', '112', '15478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3672541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15479', '1079', '1', 'Pedraza', 'CO.38.3672634', 'ASCII:Pedraza;ID:3672634', '13602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13602', '112', '15479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3672634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15480', '1079', '1', 'Paz de Río', 'CO.36.3672652', 'ASCII:Paz de Rio;ID:3672652', '13603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13603', '112', '15480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3672652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15481', '1079', '1', 'Paz de Ariporo', 'CO.32.3672655', 'ASCII:Paz de Ariporo;ID:3672655', '13604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13604', '112', '15481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3672655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15482', '1079', '1', 'Magui', 'CO.20.3672667', 'ASCII:Magui;ID:3672667', '13605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13605', '112', '15482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3672667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15483', '1079', '1', 'Payá', 'CO.36.3672670', 'ASCII:Paya;ID:3672670', '13606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13606', '112', '15483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3672670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15484', '1079', '1', 'Pauna', 'CO.36.3672699', 'ASCII:Pauna;ID:3672699', '13607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13607', '112', '15484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3672699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15485', '1079', '1', 'Patía', 'CO.09.3672762', 'ASCII:Patia;ID:3672762', '13608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13608', '112', '15485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3672762» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15486', '1079', '1', 'Pasca', 'CO.33.3672814', 'ASCII:Pasca;ID:3672814', '13609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13609', '112', '15486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3672814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15487', '1079', '1', 'Páramo', 'CO.26.3672900', 'ASCII:Paramo;ID:3672900', '13610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13610', '112', '15487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3672900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15488', '1079', '1', 'Panqueba', 'CO.36.3672982', 'ASCII:Panqueba;ID:3672982', '13611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13611', '112', '15488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3672982» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15489', '1079', '1', 'Pandi', 'CO.33.3672998', 'ASCII:Pandi;ID:3672998', '13612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13612', '112', '15489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3672998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15490', '1079', '1', 'Pamplonita', 'CO.21.3673042', 'ASCII:Pamplonita;ID:3673042', '13613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13613', '112', '15490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3673042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15491', '1079', '1', 'Pamplona', 'CO.21.3673046', 'ASCII:Pamplona;ID:3673046', '13614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13614', '112', '15491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3673046» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15492', '1079', '1', 'Pinillos', 'CO.35.3673097', 'ASCII:Pinillos;ID:3673097', '13615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13615', '112', '15492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3673097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15493', '1079', '1', 'Palmito', 'CO.27.3673144', 'ASCII:Palmito;ID:3673144', '13616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13616', '112', '15493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3673144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15494', '1079', '1', 'Palmira', 'CO.29.3673165', 'ASCII:Palmira;ID:3673165', '13617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13617', '112', '15494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3673165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15495', '1079', '1', 'Palmas del Socorro', 'CO.26.3673191', 'ASCII:Palmas del Socorro;ID:3673191', '13618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13618', '112', '15495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3673191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15496', '1079', '1', 'Palmar de Varela', 'CO.04.3673221', 'ASCII:Palmar de Varela;ID:3673221', '13619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13619', '112', '15496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3673221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15497', '1079', '1', 'Palmar', 'CO.26.3673242', 'ASCII:Palmar;ID:3673242', '13620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13620', '112', '15497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3673242» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15498', '1079', '1', 'Palestina', 'CO.37.3673276', 'ASCII:Palestina;ID:3673276', '13621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13621', '112', '15498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3673276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15499', '1079', '1', 'Palermo', 'CO.16.3673290', 'ASCII:Palermo;ID:3673290', '13622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13622', '112', '15499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3673290» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15500', '1079', '1', 'Pajarito', 'CO.36.3673353', 'ASCII:Pajarito;ID:3673353', '13623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13623', '112', '15500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3673353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15501', '1079', '1', 'Paipa', 'CO.36.3673371', 'ASCII:Paipa;ID:3673371', '13624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13624', '112', '15501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3673371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15502', '1079', '1', 'Paime', 'CO.33.3673373', 'ASCII:Paime;ID:3673373', '13625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13625', '112', '15502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3673373» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15503', '1079', '1', 'Paicol', 'CO.16.3673387', 'ASCII:Paicol;ID:3673387', '13626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13626', '112', '15503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3673387» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15504', '1079', '1', 'Páez', 'CO.09.3673399', 'ASCII:Paez;ID:3673399', '13627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13627', '112', '15504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3673399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15505', '1079', '1', 'Padilla', 'CO.09.3673408', 'ASCII:Padilla;ID:3673408', '13628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13628', '112', '15505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3673408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15506', '1079', '1', 'Pácora', 'CO.37.3673414', 'ASCII:Pacora;ID:3673414', '13629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13629', '112', '15506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3673414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15507', '1079', '1', 'Pacho', 'CO.33.3673425', 'ASCII:Pacho;ID:3673425', '13630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13630', '112', '15507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3673425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15508', '1079', '1', 'Pachavita', 'CO.33.3673432', 'ASCII:Pachavita;ID:3673432', '13631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13631', '112', '15508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3673432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15509', '1079', '1', 'Ovejas', 'CO.27.3673457', 'ASCII:Ovejas;ID:3673457', '13632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13632', '112', '15509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3673457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15510', '1079', '1', 'Otanche', 'CO.36.3673476', 'ASCII:Otanche;ID:3673476', '13633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13633', '112', '15510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3673476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15511', '1079', '1', 'Ospina Pérez', 'CO.33.3673481', 'ASCII:Ospina Perez;ID:3673481', '13634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13634', '112', '15511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3673481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15512', '1079', '1', 'Ospina', 'CO.20.3673483', 'ASCII:Ospina;ID:3673483', '13635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13635', '112', '15512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3673483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15513', '1079', '1', 'Ortega', 'CO.28.3673514', 'ASCII:Ortega;ID:3673514', '13636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13636', '112', '15513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3673514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15514', '1079', '1', 'Orocué', 'CO.32.3673538', 'ASCII:Orocue;ID:3673538', '13637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13637', '112', '15514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3673538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15515', '1079', '1', 'Oporapa', 'CO.16.3673579', 'ASCII:Oporapa;ID:3673579', '13638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13638', '112', '15515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3673579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15516', '1079', '1', 'Onzaga', 'CO.26.3673591', 'ASCII:Onzaga;ID:3673591', '13639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13639', '112', '15516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3673591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15517', '1079', '1', 'Olaya', 'CO.02.3673617', 'ASCII:Olaya;ID:3673617', '13640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13640', '112', '15517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3673617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15518', '1079', '1', 'Oiba', 'CO.26.3673638', 'ASCII:Oiba;ID:3673638', '13641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13641', '112', '15518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3673638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15519', '1079', '1', 'Ocaña', 'CO.21.3673663', 'ASCII:Ocana;ID:3673663', '13642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13642', '112', '15519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3673663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15520', '1079', '1', 'Ocamonte', 'CO.26.3673665', 'ASCII:Ocamonte;ID:3673665', '13643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13643', '112', '15520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3673665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15521', '1079', '1', 'Obando', 'CO.29.3673678', 'ASCII:Obando;ID:3673678', '13644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13644', '112', '15521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3673678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15522', '1079', '1', 'Nuquí', 'CO.11.3673691', 'ASCII:Nuqui;ID:3673691', '13645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13645', '112', '15522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3673691» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15523', '1079', '1', 'Nunchía', 'CO.32.3673697', 'ASCII:Nunchia;ID:3673697', '13646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13646', '112', '15523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3673697» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15524', '1079', '1', 'Nuevo Colón', 'CO.36.3673731', 'ASCII:Nuevo Colon;ID:3673731', '13647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13647', '112', '15524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3673731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15525', '1079', '1', 'Nóvita', 'CO.11.3673784', 'ASCII:Novita;ID:3673784', '13648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13648', '112', '15525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3673784» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15526', '1079', '1', 'Nocaima', 'CO.33.3673827', 'ASCII:Nocaima;ID:3673827', '13649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13649', '112', '15526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3673827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15527', '1079', '1', 'Nobsa', 'CO.36.3673830', 'ASCII:Nobsa;ID:3673830', '13650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13650', '112', '15527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3673830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15528', '1079', '1', 'Nimaima', 'CO.33.3673846', 'ASCII:Nimaima;ID:3673846', '13651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13651', '112', '15528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3673846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15529', '1079', '1', 'Nilo', 'CO.33.3673850', 'ASCII:Nilo;ID:3673850', '13652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13652', '112', '15529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3673850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15530', '1079', '1', 'Nemocón', 'CO.33.3673888', 'ASCII:Nemocon;ID:3673888', '13653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13653', '112', '15530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3673888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15531', '1079', '1', 'Neiva', 'CO.16.3673900', 'ASCII:Neiva;ID:3673900', '13654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13654', '112', '15531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3673900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15532', '1079', '1', 'Neira', 'CO.37.3673904', 'ASCII:Neira;ID:3673904', '13655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13655', '112', '15532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3673904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15533', '1079', '1', 'Natagaima', 'CO.28.3674011', 'ASCII:Natagaima;ID:3674011', '13656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13656', '112', '15533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3674011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15534', '1079', '1', 'Nátaga', 'CO.16.3674013', 'ASCII:Nataga;ID:3674013', '13657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13657', '112', '15534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3674013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15535', '1079', '1', 'Nariño', 'CO.02.3674032', 'ASCII:Narino;ID:3674032', '13658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13658', '112', '15535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3674032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15536', '1079', '1', 'Nariño', 'CO.33.3674033', 'ASCII:Narino;ID:3674033', '13659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13659', '112', '15536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3674033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15537', '1079', '1', 'Muzo', 'CO.36.3674122', 'ASCII:Muzo;ID:3674122', '13660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13660', '112', '15537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3674122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15538', '1079', '1', 'Mutiscua', 'CO.21.3674126', 'ASCII:Mutiscua;ID:3674126', '13661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13661', '112', '15538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3674126» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15539', '1079', '1', 'Mutatá', 'CO.02.3674131', 'ASCII:Mutata;ID:3674131', '13662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13662', '112', '15539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3674131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15540', '1079', '1', 'Murindó', 'CO.02.3674162', 'ASCII:Murindo;ID:3674162', '13663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13663', '112', '15540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3674162» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15541', '1079', '1', 'Mosquera', 'CO.33.3674295', 'ASCII:Mosquera;ID:3674295', '13664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13664', '112', '15541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3674295» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15542', '1079', '1', 'Mosquera', 'CO.20.3674296', 'ASCII:Mosquera;ID:3674296', '13665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13665', '112', '15542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3674296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15543', '1079', '1', 'Morroa', 'CO.27.3674338', 'ASCII:Morroa;ID:3674338', '13666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13666', '112', '15543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3674338» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15544', '1079', '1', 'Morales', 'CO.35.3674414', 'ASCII:Morales;ID:3674414', '13667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13667', '112', '15544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3674414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15545', '1079', '1', 'Morales', 'CO.09.3674415', 'ASCII:Morales;ID:3674415', '13668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13668', '112', '15545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3674415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15546', '1079', '1', 'Monterrey', 'CO.32.3674446', 'ASCII:Monterrey;ID:3674446', '13669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13669', '112', '15546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3674446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15547', '1079', '1', 'Montería', 'CO.12.3674454', 'ASCII:Monteria;ID:3674454', '13670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13670', '112', '15547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3674454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15548', '1079', '1', 'Montenegro', 'CO.23.3674464', 'ASCII:Montenegro;ID:3674464', '13671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13671', '112', '15548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.23.3674464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15549', '1079', '1', 'Montelíbano', 'CO.12.3674471', 'ASCII:Montelibano;ID:3674471', '13672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13672', '112', '15549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3674471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15550', '1079', '1', 'Montebello', 'CO.02.3674520', 'ASCII:Montebello;ID:3674520', '13673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13673', '112', '15550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3674520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15551', '1079', '1', 'La Montañita', 'CO.08.3674528', 'ASCII:La Montanita;ID:3674528', '13674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13674', '112', '15551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.08.3674528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15552', '1079', '1', 'Moniquirá', 'CO.36.3674574', 'ASCII:Moniquira;ID:3674574', '13675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13675', '112', '15552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3674574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15553', '1079', '1', 'Monguí', 'CO.36.3674578', 'ASCII:Mongui;ID:3674578', '13676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13676', '112', '15553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3674578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15554', '1079', '1', 'Mongua', 'CO.36.3674581', 'ASCII:Mongua;ID:3674581', '13677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13677', '112', '15554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3674581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15555', '1079', '1', 'Mompós', 'CO.35.3674600', 'ASCII:Mompos;ID:3674600', '13678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13678', '112', '15555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3674600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15556', '1079', '1', 'Molagavita', 'CO.26.3674619', 'ASCII:Molagavita;ID:3674619', '13679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13679', '112', '15556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3674619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15557', '1079', '1', 'Mogotes', 'CO.26.3674641', 'ASCII:Mogotes;ID:3674641', '13680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13680', '112', '15557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3674641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15558', '1079', '1', 'Mocoa', 'CO.22.3674655', 'ASCII:Mocoa;ID:3674655', '13681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13681', '112', '15558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.22.3674655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15559', '1079', '1', 'Mistrató', 'CO.24.3674679', 'ASCII:Mistrato;ID:3674679', '13682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13682', '112', '15559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3674679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15560', '1079', '1', 'Miranda', 'CO.09.3674703', 'ASCII:Miranda;ID:3674703', '13683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13683', '112', '15560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3674703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15561', '1079', '1', 'Miraflores', 'CO.36.3674743', 'ASCII:Miraflores;ID:3674743', '13684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13684', '112', '15561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3674743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15562', '1079', '1', 'Mercaderes', 'CO.09.3674852', 'ASCII:Mercaderes;ID:3674852', '13685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13685', '112', '15562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3674852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15563', '1079', '1', 'Melgar', 'CO.28.3674886', 'ASCII:Melgar;ID:3674886', '13686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13686', '112', '15563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3674886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15564', '1079', '1', 'Medina', 'CO.33.3674933', 'ASCII:Medina;ID:3674933', '13687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13687', '112', '15564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3674933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15565', '1079', '1', 'Medellín', 'CO.02.3674954', 'ASCII:Medellin;ID:3674954', '13688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13688', '112', '15565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3674954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15566', '1079', '1', 'Matanza', 'CO.26.3675119', 'ASCII:Matanza;ID:3675119', '13689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13689', '112', '15566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3675119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15567', '1079', '1', 'Marulanda', 'CO.37.3675192', 'ASCII:Marulanda;ID:3675192', '13690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13690', '112', '15567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3675192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15568', '1079', '1', 'Marsella', 'CO.24.3675214', 'ASCII:Marsella;ID:3675214', '13691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13691', '112', '15568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3675214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15569', '1079', '1', 'Marquetalia', 'CO.37.3675235', 'ASCII:Marquetalia;ID:3675235', '13692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13692', '112', '15569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3675235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15570', '1079', '1', 'Marmato', 'CO.37.3675245', 'ASCII:Marmato;ID:3675245', '13693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13693', '112', '15570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3675245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15571', '1079', '1', 'Mariquita', 'CO.28.3675253', 'ASCII:Mariquita;ID:3675253', '13694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13694', '112', '15571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3675253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15572', '1079', '1', 'Maripí', 'CO.36.3675256', 'ASCII:Maripi;ID:3675256', '13695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13695', '112', '15572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3675256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15573', '1079', '1', 'Marinilla', 'CO.02.3675265', 'ASCII:Marinilla;ID:3675265', '13696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13696', '112', '15573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3675265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15574', '1079', '1', 'María La Baja', 'CO.35.3675288', 'ASCII:Maria La Baja;ID:3675288', '13697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13697', '112', '15574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3675288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15575', '1079', '1', 'Margarita', 'CO.35.3675307', 'ASCII:Margarita;ID:3675307', '13698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13698', '112', '15575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3675307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15576', '1079', '1', 'Manzanares', 'CO.37.3675412', 'ASCII:Manzanares;ID:3675412', '13699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13699', '112', '15576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3675412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15577', '1079', '1', 'Manta', 'CO.33.3675433', 'ASCII:Manta;ID:3675433', '13700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13700', '112', '15577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3675433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15578', '1079', '1', 'Manizales', 'CO.37.3675444', 'ASCII:Manizales;ID:3675444', '13701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13701', '112', '15578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3675444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15579', '1079', '1', 'Maní', 'CO.32.3675454', 'ASCII:Mani;ID:3675454', '13702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13702', '112', '15579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3675454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15580', '1079', '1', 'Manatí', 'CO.04.3675514', 'ASCII:Manati;ID:3675514', '13703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13703', '112', '15580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3675514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15581', '1079', '1', 'Mallama', 'CO.20.3675578', 'ASCII:Mallama;ID:3675578', '13704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13704', '112', '15581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3675578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15582', '1079', '1', 'Malambo', 'CO.04.3675597', 'ASCII:Malambo;ID:3675597', '13705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13705', '112', '15582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3675597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15583', '1079', '1', 'Málaga', 'CO.26.3675606', 'ASCII:Malaga;ID:3675606', '13706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13706', '112', '15583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3675606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15584', '1079', '1', 'Majagual', 'CO.27.3675640', 'ASCII:Majagual;ID:3675640', '13707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13707', '112', '15584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3675640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15585', '1079', '1', 'Maicao', 'CO.17.3675659', 'ASCII:Maicao;ID:3675659', '13708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13708', '112', '15585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.17.3675659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15586', '1079', '1', 'Mahates', 'CO.35.3675666', 'ASCII:Mahates;ID:3675666', '13709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13709', '112', '15586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3675666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15587', '1079', '1', 'Magangué', 'CO.35.3675695', 'ASCII:Magangue;ID:3675695', '13710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13710', '112', '15587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3675695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15588', '1079', '1', 'Madrid', 'CO.33.3675708', 'ASCII:Madrid;ID:3675708', '13711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13711', '112', '15588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3675708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15589', '1079', '1', 'Machetá', 'CO.33.3675758', 'ASCII:Macheta;ID:3675758', '13712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13712', '112', '15589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3675758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15590', '1079', '1', 'Maceo', 'CO.02.3675769', 'ASCII:Maceo;ID:3675769', '13713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13713', '112', '15590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3675769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15591', '1079', '1', 'Macaravita', 'CO.26.3675781', 'ASCII:Macaravita;ID:3675781', '13714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13714', '112', '15591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3675781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15592', '1079', '1', 'Macanal', 'CO.36.3675793', 'ASCII:Macanal;ID:3675793', '13715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13715', '112', '15592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3675793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15593', '1079', '1', 'Luruaco', 'CO.04.3675827', 'ASCII:Luruaco;ID:3675827', '13716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13716', '112', '15593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3675827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15594', '1079', '1', 'Lourdes', 'CO.21.3675858', 'ASCII:Lourdes;ID:3675858', '13717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13717', '112', '15594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3675858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15595', '1079', '1', 'Los Santos', 'CO.26.3675909', 'ASCII:Los Santos;ID:3675909', '13718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13718', '112', '15595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3675909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15596', '1079', '1', 'Los Andes', 'CO.20.3676357', 'ASCII:Los Andes;ID:3676357', '13719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13719', '112', '15596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3676357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15597', '1079', '1', 'Lorica', 'CO.12.3676400', 'ASCII:Lorica;ID:3676400', '13720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13720', '112', '15597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3676400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15598', '1079', '1', 'López', 'CO.09.3676418', 'ASCII:Lopez;ID:3676418', '13721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13721', '112', '15598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3676418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15599', '1079', '1', 'Lloró', 'CO.11.3676478', 'ASCII:Lloro;ID:3676478', '13722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13722', '112', '15599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3676478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15600', '1079', '1', 'Linares', 'CO.20.3676541', 'ASCII:Linares;ID:3676541', '13723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13723', '112', '15600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3676541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15601', '1079', '1', 'Liborina', 'CO.02.3676592', 'ASCII:Liborina;ID:3676592', '13724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13724', '112', '15601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3676592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15602', '1079', '1', 'Líbano', 'CO.28.3676606', 'ASCII:Libano;ID:3676606', '13725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13725', '112', '15602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3676606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15603', '1079', '1', 'Lérida', 'CO.28.3676628', 'ASCII:Lerida;ID:3676628', '13726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13726', '112', '15603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3676628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15604', '1079', '1', 'Lenguazaque', 'CO.33.3676645', 'ASCII:Lenguazaque;ID:3676645', '13727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13727', '112', '15604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3676645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15605', '1079', '1', 'Villa De Leyva', 'CO.36.3676662', 'ASCII:Villa De Leyva;ID:3676662', '13728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13728', '112', '15605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3676662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15606', '1079', '1', 'Lebrija', 'CO.26.3676675', 'ASCII:Lebrija;ID:3676675', '13729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13729', '112', '15606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3676675» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15607', '1079', '1', 'La Virginia', 'CO.24.3676723', 'ASCII:La Virginia;ID:3676723', '13730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13730', '112', '15607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3676723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15608', '1079', '1', 'La Vega', 'CO.33.3676870', 'ASCII:La Vega;ID:3676870', '13731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13731', '112', '15608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3676870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15609', '1079', '1', 'La Vega', 'CO.09.3676871', 'ASCII:La Vega;ID:3676871', '13732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13732', '112', '15609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3676871» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15610', '1079', '1', 'La Uvita', 'CO.36.3676885', 'ASCII:La Uvita;ID:3676885', '13733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13733', '112', '15610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3676885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15611', '1079', '1', 'La Unión', 'CO.02.3676936', 'ASCII:La Union;ID:3676936', '13734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13734', '112', '15611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3676936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15612', '1079', '1', 'La Unión', 'CO.29.3676937', 'ASCII:La Union;ID:3676937', '13735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13735', '112', '15612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3676937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15613', '1079', '1', 'La Unión', 'CO.20.3676938', 'ASCII:La Union;ID:3676938', '13736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13736', '112', '15613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3676938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15614', '1079', '1', 'La Tebaida', 'CO.23.3677011', 'ASCII:La Tebaida;ID:3677011', '13737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13737', '112', '15614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.23.3677011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15615', '1079', '1', 'La Sierra', 'CO.09.3677458', 'ASCII:La Sierra;ID:3677458', '13738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13738', '112', '15615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3677458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15616', '1079', '1', 'La Salina', 'CO.36.3677769', 'ASCII:La Salina;ID:3677769', '13739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13739', '112', '15616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3677769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15617', '1079', '1', 'La Playa', 'CO.21.3678089', 'ASCII:La Playa;ID:3678089', '13740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13740', '112', '15617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3678089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15618', '1079', '1', 'La Plata', 'CO.16.3678098', 'ASCII:La Plata;ID:3678098', '13741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13741', '112', '15618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3678098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15619', '1079', '1', 'La Peña', 'CO.33.3678169', 'ASCII:La Pena;ID:3678169', '13742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13742', '112', '15619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3678169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15620', '1079', '1', 'La Paz', 'CO.26.3678194', 'ASCII:La Paz;ID:3678194', '13743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13743', '112', '15620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3678194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15621', '1079', '1', 'La Palma', 'CO.33.3678287', 'ASCII:La Palma;ID:3678287', '13744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13744', '112', '15621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3678287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15622', '1079', '1', 'La Mesa', 'CO.33.3678411', 'ASCII:La Mesa;ID:3678411', '13745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13745', '112', '15622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3678411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15623', '1079', '1', 'La Gloria', 'CO.10.3678913', 'ASCII:La Gloria;ID:3678913', '13746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13746', '112', '15623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.10.3678913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15624', '1079', '1', 'La Florida', 'CO.20.3679009', 'ASCII:La Florida;ID:3679009', '13747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13747', '112', '15624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3679009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15625', '1079', '1', 'La Estrella', 'CO.02.3679071', 'ASCII:La Estrella;ID:3679071', '13748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13748', '112', '15625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3679071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15626', '1079', '1', 'La Dorada', 'CO.37.3679279', 'ASCII:La Dorada;ID:3679279', '13749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13749', '112', '15626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3679279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15627', '1079', '1', 'La Cumbre', 'CO.29.3679319', 'ASCII:La Cumbre;ID:3679319', '13750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13750', '112', '15627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3679319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15628', '1079', '1', 'La Cruz', 'CO.20.3679381', 'ASCII:La Cruz;ID:3679381', '13751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13751', '112', '15628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3679381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15629', '1079', '1', 'La Celia', 'CO.24.3679543', 'ASCII:La Celia;ID:3679543', '13752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13752', '112', '15629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3679543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15630', '1079', '1', 'La Ceja', 'CO.02.3679555', 'ASCII:La Ceja;ID:3679555', '13753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13753', '112', '15630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3679555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15631', '1079', '1', 'La Capilla', 'CO.36.3679629', 'ASCII:La Capilla;ID:3679629', '13754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13754', '112', '15631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3679629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15632', '1079', '1', 'La Calera', 'CO.33.3679663', 'ASCII:La Calera;ID:3679663', '13755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13755', '112', '15632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3679663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15633', '1079', '1', 'Labranzagrande', 'CO.36.3679717', 'ASCII:Labranzagrande;ID:3679717', '13756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13756', '112', '15633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3679717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15634', '1079', '1', 'Labateca', 'CO.21.3679781', 'ASCII:Labateca;ID:3679781', '13757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13757', '112', '15634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3679781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15635', '1079', '1', 'La Argentina', 'CO.16.3679855', 'ASCII:La Argentina;ID:3679855', '13758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13758', '112', '15635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3679855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15636', '1079', '1', 'Aguada', 'CO.26.3679928', 'ASCII:Aguada;ID:3679928', '13759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13759', '112', '15636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3679928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15637', '1079', '1', 'Juradó', 'CO.11.3680091', 'ASCII:Jurado;ID:3680091', '13760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13760', '112', '15637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3680091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15638', '1079', '1', 'Junín', 'CO.33.3680116', 'ASCII:Junin;ID:3680116', '13761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13761', '112', '15638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3680116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15639', '1079', '1', 'Juan de Acosta', 'CO.04.3680177', 'ASCII:Juan de Acosta;ID:3680177', '13762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13762', '112', '15639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3680177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15640', '1079', '1', 'Jordán', 'CO.26.3680237', 'ASCII:Jordan;ID:3680237', '13763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13763', '112', '15640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3680237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15641', '1079', '1', 'Jesús María', 'CO.26.3680298', 'ASCII:Jesus Maria;ID:3680298', '13764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13764', '112', '15641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3680298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15642', '1079', '1', 'Jerusalén', 'CO.33.3680310', 'ASCII:Jerusalen;ID:3680310', '13765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13765', '112', '15642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3680310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15643', '1079', '1', 'Jericó', 'CO.36.3680319', 'ASCII:Jerico;ID:3680319', '13766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13766', '112', '15643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3680319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15644', '1079', '1', 'Jericó', 'CO.02.3680320', 'ASCII:Jerico;ID:3680320', '13767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13767', '112', '15644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3680320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15645', '1079', '1', 'Jenesano', 'CO.36.3680336', 'ASCII:Jenesano;ID:3680336', '13768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13768', '112', '15645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3680336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15646', '1079', '1', 'Jardín', 'CO.02.3680367', 'ASCII:Jardin;ID:3680367', '13769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13769', '112', '15646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3680367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15647', '1079', '1', 'Jamundí', 'CO.29.3680388', 'ASCII:Jamundi;ID:3680388', '13770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13770', '112', '15647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3680388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15648', '1079', '1', 'Jambaló', 'CO.09.3680394', 'ASCII:Jambalo;ID:3680394', '13771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13771', '112', '15648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3680394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15649', '1079', '1', 'Iza', 'CO.36.3680427', 'ASCII:Iza;ID:3680427', '13772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13772', '112', '15649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3680427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15650', '1079', '1', 'Ituango', 'CO.02.3680435', 'ASCII:Ituango;ID:3680435', '13773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13773', '112', '15650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3680435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15651', '1079', '1', 'Itagüí', 'CO.02.3680451', 'ASCII:Itagui;ID:3680451', '13774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13774', '112', '15651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3680451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15652', '1079', '1', 'Istmina', 'CO.11.3680454', 'ASCII:Istmina;ID:3680454', '13775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13775', '112', '15652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3680454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15653', '1079', '1', 'Iquira', 'CO.16.3680532', 'ASCII:Iquira;ID:3680532', '13776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13776', '112', '15653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3680532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15654', '1079', '1', 'Ipiales', 'CO.20.3680540', 'ASCII:Ipiales;ID:3680540', '13777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13777', '112', '15654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3680540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15655', '1079', '1', 'Inzá', 'CO.09.3680555', 'ASCII:Inza;ID:3680555', '13778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13778', '112', '15655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3680555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15656', '1079', '1', 'Imués', 'CO.20.3680602', 'ASCII:Imues;ID:3680602', '13779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13779', '112', '15656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3680602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15657', '1079', '1', 'Iles', 'CO.20.3680617', 'ASCII:Iles;ID:3680617', '13780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13780', '112', '15657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3680617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15658', '1079', '1', 'Icononzo', 'CO.28.3680642', 'ASCII:Icononzo;ID:3680642', '13781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13781', '112', '15658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3680642» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15659', '1079', '1', 'Ibagué', 'CO.28.3680657', 'ASCII:Ibague;ID:3680657', '13782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13782', '112', '15659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3680657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15660', '1079', '1', 'Honda', 'CO.28.3680841', 'ASCII:Honda;ID:3680841', '13783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13783', '112', '15660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3680841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15661', '1079', '1', 'Hobo', 'CO.16.3680855', 'ASCII:Hobo;ID:3680855', '13784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13784', '112', '15661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3680855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15662', '1079', '1', 'Herrán', 'CO.21.3680887', 'ASCII:Herran;ID:3680887', '13785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13785', '112', '15662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3680887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15663', '1079', '1', 'Heliconia', 'CO.02.3680903', 'ASCII:Heliconia;ID:3680903', '13786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13786', '112', '15663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3680903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15664', '1079', '1', 'Hato Corozal', 'CO.32.3681010', 'ASCII:Hato Corozal;ID:3681010', '13787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13787', '112', '15664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3681010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15665', '1079', '1', 'Hato', 'CO.26.3681027', 'ASCII:Hato;ID:3681027', '13788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13788', '112', '15665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3681027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15666', '1079', '1', 'Hacarí', 'CO.21.3681169', 'ASCII:Hacari;ID:3681169', '13789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13789', '112', '15666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3681169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15667', '1079', '1', 'Gutiérrez', 'CO.33.3681177', 'ASCII:Gutierrez;ID:3681177', '13790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13790', '112', '15667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3681177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15668', '1079', '1', 'Güicán', 'CO.36.3681223', 'ASCII:Guican;ID:3681223', '13791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13791', '112', '15668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3681223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15669', '1079', '1', 'Güepsa', 'CO.26.3681235', 'ASCII:Guepsa;ID:3681235', '13792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13792', '112', '15669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3681235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15670', '1079', '1', 'Guayatá', 'CO.36.3681256', 'ASCII:Guayata;ID:3681256', '13793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13793', '112', '15670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3681256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15671', '1079', '1', 'Guayabal de Síquima', 'CO.33.3681307', 'ASCII:Guayabal de Siquima;ID:3681307', '13794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13794', '112', '15671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3681307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15672', '1079', '1', 'Guavatá', 'CO.26.3681347', 'ASCII:Guavata;ID:3681347', '13795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13795', '112', '15672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3681347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15673', '1079', '1', 'Guática', 'CO.24.3681354', 'ASCII:Guatica;ID:3681354', '13796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13796', '112', '15673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3681354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15674', '1079', '1', 'Guateque', 'CO.36.3681357', 'ASCII:Guateque;ID:3681357', '13797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13797', '112', '15674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3681357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15675', '1079', '1', 'Guatavita', 'CO.33.3681361', 'ASCII:Guatavita;ID:3681361', '13798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13798', '112', '15675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3681361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15676', '1079', '1', 'Guataquí', 'CO.33.3681365', 'ASCII:Guataqui;ID:3681365', '13799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13799', '112', '15676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3681365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15677', '1079', '1', 'Guatapé', 'CO.02.3681369', 'ASCII:Guatape;ID:3681369', '13800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13800', '112', '15677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3681369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15678', '1079', '1', 'Guasca', 'CO.33.3681405', 'ASCII:Guasca;ID:3681405', '13801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13801', '112', '15678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3681405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15679', '1079', '1', 'Guarne', 'CO.02.3681430', 'ASCII:Guarne;ID:3681430', '13802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13802', '112', '15679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3681430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15680', '1079', '1', 'Guapotá', 'CO.26.3681492', 'ASCII:Guapota;ID:3681492', '13803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13803', '112', '15680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3681492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15681', '1079', '1', 'Guapí', 'CO.09.3681506', 'ASCII:Guapi;ID:3681506', '13804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13804', '112', '15681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3681506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15682', '1079', '1', 'Guamo', 'CO.28.3681564', 'ASCII:Guamo;ID:3681564', '13805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13805', '112', '15682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3681564» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15683', '1079', '1', 'Guamal', 'CO.38.3681606', 'ASCII:Guamal;ID:3681606', '13806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13806', '112', '15683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3681606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15684', '1079', '1', 'Guamal', 'CO.19.3681607', 'ASCII:Guamal;ID:3681607', '13807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13807', '112', '15684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3681607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15685', '1079', '1', 'Gualmatán', 'CO.20.3681620', 'ASCII:Gualmatan;ID:3681620', '13808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13808', '112', '15685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3681620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15686', '1079', '1', 'Guaitarilla', 'CO.20.3681645', 'ASCII:Guaitarilla;ID:3681645', '13809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13809', '112', '15686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3681645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15687', '1079', '1', 'Guaduas', 'CO.33.3681703', 'ASCII:Guaduas;ID:3681703', '13810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13810', '112', '15687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3681703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15688', '1079', '1', 'Guadalupe', 'CO.26.3681734', 'ASCII:Guadalupe;ID:3681734', '13811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13811', '112', '15688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3681734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15689', '1079', '1', 'Guadalupe', 'CO.16.3681735', 'ASCII:Guadalupe;ID:3681735', '13812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13812', '112', '15689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3681735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15690', '1079', '1', 'Guachucal', 'CO.20.3681757', 'ASCII:Guachucal;ID:3681757', '13813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13813', '112', '15690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3681757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15691', '1079', '1', 'Guachetá', 'CO.33.3681768', 'ASCII:Guacheta;ID:3681768', '13814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13814', '112', '15691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3681768» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15692', '1079', '1', 'Guacarí', 'CO.29.3681798', 'ASCII:Guacari;ID:3681798', '13815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13815', '112', '15692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3681798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15693', '1079', '1', 'Guacamayas', 'CO.36.3681815', 'ASCII:Guacamayas;ID:3681815', '13816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13816', '112', '15693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3681815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15694', '1079', '1', 'Guaca', 'CO.26.3681833', 'ASCII:Guaca;ID:3681833', '13817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13817', '112', '15694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3681833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15695', '1079', '1', 'Granada', 'CO.02.3681960', 'ASCII:Granada;ID:3681960', '13818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13818', '112', '15695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3681960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15696', '1079', '1', 'Granada', 'CO.19.3681961', 'ASCII:Granada;ID:3681961', '13819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13819', '112', '15696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3681961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15697', '1079', '1', 'Gramalote', 'CO.21.3681968', 'ASCII:Gramalote;ID:3681968', '13820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13820', '112', '15697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3681968» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15698', '1079', '1', 'González', 'CO.10.3681991', 'ASCII:Gonzalez;ID:3681991', '13821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13821', '112', '15698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.10.3681991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15699', '1079', '1', 'Gómez Plata', 'CO.02.3681998', 'ASCII:Gomez Plata;ID:3681998', '13822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13822', '112', '15699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3681998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15700', '1079', '1', 'Girón', 'CO.26.3682019', 'ASCII:Giron;ID:3682019', '13823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13823', '112', '15700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3682019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15701', '1079', '1', 'Girardota', 'CO.02.3682023', 'ASCII:Girardota;ID:3682023', '13824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13824', '112', '15701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3682023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15702', '1079', '1', 'Girardot', 'CO.33.3682029', 'ASCII:Girardot;ID:3682029', '13825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13825', '112', '15702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15703', '1079', '1', 'Giraldo', 'CO.02.3682031', 'ASCII:Giraldo;ID:3682031', '13826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13826', '112', '15703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3682031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15704', '1079', '1', 'Ginebra', 'CO.29.3682040', 'ASCII:Ginebra;ID:3682040', '13827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13827', '112', '15704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3682040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15705', '1079', '1', 'Gigante', 'CO.16.3682048', 'ASCII:Gigante;ID:3682048', '13828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13828', '112', '15705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3682048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15706', '1079', '1', 'Génova', 'CO.23.3682071', 'ASCII:Genova;ID:3682071', '13829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13829', '112', '15706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.23.3682071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15707', '1079', '1', 'Garzón', 'CO.16.3682109', 'ASCII:Garzon;ID:3682109', '13830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13830', '112', '15707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3682109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15708', '1079', '1', 'Garagoa', 'CO.36.3682161', 'ASCII:Garagoa;ID:3682161', '13831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13831', '112', '15708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3682161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15709', '1079', '1', 'Gámeza', 'CO.36.3682173', 'ASCII:Gameza;ID:3682173', '13832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13832', '112', '15709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3682173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15710', '1079', '1', 'Gámbita', 'CO.26.3682179', 'ASCII:Gambita;ID:3682179', '13833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13833', '112', '15710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3682179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15711', '1079', '1', 'Gamarra', 'CO.10.3682184', 'ASCII:Gamarra;ID:3682184', '13834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13834', '112', '15711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.10.3682184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15712', '1079', '1', 'Gama', 'CO.33.3682186', 'ASCII:Gama;ID:3682186', '13835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13835', '112', '15712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15713', '1079', '1', 'Galapa', 'CO.04.3682239', 'ASCII:Galapa;ID:3682239', '13836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13836', '112', '15713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3682239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15714', '1079', '1', 'Galán', 'CO.26.3682244', 'ASCII:Galan;ID:3682244', '13837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13837', '112', '15714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3682244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15715', '1079', '1', 'Gachetá', 'CO.33.3682259', 'ASCII:Gacheta;ID:3682259', '13838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13838', '112', '15715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15716', '1079', '1', 'Gachantivá', 'CO.36.3682261', 'ASCII:Gachantiva;ID:3682261', '13839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13839', '112', '15716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3682261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15717', '1079', '1', 'Gachancipá', 'CO.33.3682263', 'ASCII:Gachancipa;ID:3682263', '13840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13840', '112', '15717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15718', '1079', '1', 'Gachalá', 'CO.33.3682267', 'ASCII:Gachala;ID:3682267', '13841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13841', '112', '15718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15719', '1079', '1', 'Fusagasugá', 'CO.33.3682275', 'ASCII:Fusagasuga;ID:3682275', '13842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13842', '112', '15719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15720', '1079', '1', 'Fúquene', 'CO.33.3682280', 'ASCII:Fuquene;ID:3682280', '13843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13843', '112', '15720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15721', '1079', '1', 'Funza', 'CO.33.3682282', 'ASCII:Funza;ID:3682282', '13844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13844', '112', '15721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15722', '1079', '1', 'Funes', 'CO.20.3682284', 'ASCII:Funes;ID:3682284', '13845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13845', '112', '15722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3682284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15723', '1079', '1', 'Fundación', 'CO.38.3682289', 'ASCII:Fundacion;ID:3682289', '13846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13846', '112', '15723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3682289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15724', '1079', '1', 'Frontino', 'CO.02.3682314', 'ASCII:Frontino;ID:3682314', '13847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13847', '112', '15724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3682314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15725', '1079', '1', 'Fresno', 'CO.28.3682331', 'ASCII:Fresno;ID:3682331', '13848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13848', '112', '15725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3682331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15726', '1079', '1', 'Fredonia', 'CO.02.3682333', 'ASCII:Fredonia;ID:3682333', '13849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13849', '112', '15726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3682333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15727', '1079', '1', 'Fosca', 'CO.33.3682359', 'ASCII:Fosca;ID:3682359', '13850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13850', '112', '15727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15728', '1079', '1', 'Fonseca', 'CO.17.3682376', 'ASCII:Fonseca;ID:3682376', '13851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13851', '112', '15728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.17.3682376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15729', '1079', '1', 'Fómeque', 'CO.33.3682381', 'ASCII:Fomeque;ID:3682381', '13852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13852', '112', '15729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15730', '1079', '1', 'Floridablanca', 'CO.26.3682386', 'ASCII:Floridablanca;ID:3682386', '13853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13853', '112', '15730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3682386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15731', '1079', '1', 'Florida', 'CO.29.3682394', 'ASCII:Florida;ID:3682394', '13854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13854', '112', '15731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3682394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15732', '1079', '1', 'Floresta', 'CO.36.3682401', 'ASCII:Floresta;ID:3682401', '13855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13855', '112', '15732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3682401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15733', '1079', '1', 'Florencia', 'CO.08.3682428', 'ASCII:Florencia;ID:3682428', '13856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13856', '112', '15733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.08.3682428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15734', '1079', '1', 'Flandes', 'CO.28.3682459', 'ASCII:Flandes;ID:3682459', '13857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13857', '112', '15734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3682459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15735', '1079', '1', 'Firavitoba', 'CO.36.3682466', 'ASCII:Firavitoba;ID:3682466', '13858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13858', '112', '15735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3682466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15736', '1079', '1', 'Filandia', 'CO.23.3682475', 'ASCII:Filandia;ID:3682475', '13859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13859', '112', '15736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.23.3682475» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15737', '1079', '1', 'Filadelfia', 'CO.37.3682482', 'ASCII:Filadelfia;ID:3682482', '13860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13860', '112', '15737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3682482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15738', '1079', '1', 'Falan', 'CO.28.3682511', 'ASCII:Falan;ID:3682511', '13861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13861', '112', '15738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3682511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15739', '1079', '1', 'Facatativá', 'CO.33.3682517', 'ASCII:Facatativa;ID:3682517', '13862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13862', '112', '15739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3682517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15740', '1079', '1', 'Espinal', 'CO.28.3682574', 'ASCII:Espinal;ID:3682574', '13863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13863', '112', '15740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3682574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15741', '1079', '1', 'Envigado', 'CO.02.3682632', 'ASCII:Envigado;ID:3682632', '13864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13864', '112', '15741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3682632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15742', '1079', '1', 'Entrerríos', 'CO.02.3682634', 'ASCII:Entrerrios;ID:3682634', '13865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13865', '112', '15742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3682634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15743', '1079', '1', 'Enciso', 'CO.26.3682655', 'ASCII:Enciso;ID:3682655', '13866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13866', '112', '15743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3682655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15744', '1079', '1', 'Encino', 'CO.26.3682657', 'ASCII:Encino;ID:3682657', '13867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13867', '112', '15744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3682657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15745', '1079', '1', 'El Zulia', 'CO.21.3682683', 'ASCII:El Zulia;ID:3682683', '13868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13868', '112', '15745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3682683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15746', '1079', '1', 'El Tambo', 'CO.09.3682966', 'ASCII:El Tambo;ID:3682966', '13869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13869', '112', '15746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3682966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15747', '1079', '1', 'El Tambo', 'CO.20.3682967', 'ASCII:El Tambo;ID:3682967', '13870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13870', '112', '15747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3682967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15748', '1079', '1', 'El Tablón', 'CO.20.3682983', 'ASCII:El Tablon;ID:3682983', '13871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13871', '112', '15748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3682983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15749', '1079', '1', 'El Rosario', 'CO.20.3683153', 'ASCII:El Rosario;ID:3683153', '13872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13872', '112', '15749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3683153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15750', '1079', '1', 'El Piñón', 'CO.38.3683465', 'ASCII:El Pinon;ID:3683465', '13873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13873', '112', '15750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3683465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15751', '1079', '1', 'El Peñón', 'CO.33.3683506', 'ASCII:El Penon;ID:3683506', '13874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13874', '112', '15751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3683506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15752', '1079', '1', 'Elías', 'CO.16.3684030', 'ASCII:Elias;ID:3684030', '13875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13875', '112', '15752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3684030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15753', '1079', '1', 'El Guamo', 'CO.35.3684120', 'ASCII:El Guamo;ID:3684120', '13876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13876', '112', '15753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3684120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15754', '1079', '1', 'El Guacamayo', 'CO.26.3684133', 'ASCII:El Guacamayo;ID:3684133', '13877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13877', '112', '15754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3684133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15755', '1079', '1', 'El Espino', 'CO.36.3684192', 'ASCII:El Espino;ID:3684192', '13878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13878', '112', '15755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3684192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15756', '1079', '1', 'El Dovio', 'CO.29.3684267', 'ASCII:El Dovio;ID:3684267', '13879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13879', '112', '15756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3684267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15757', '1079', '1', 'El Colegio', 'CO.33.3684506', 'ASCII:El Colegio;ID:3684506', '13880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13880', '112', '15757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3684506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15758', '1079', '1', 'El Cocuy', 'CO.36.3684511', 'ASCII:El Cocuy;ID:3684511', '13881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13881', '112', '15758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3684511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15759', '1079', '1', 'El Charco', 'CO.20.3684581', 'ASCII:El Charco;ID:3684581', '13882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13882', '112', '15759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3684581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15760', '1079', '1', 'El Cerrito', 'CO.29.3684616', 'ASCII:El Cerrito;ID:3684616', '13883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13883', '112', '15760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3684616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15761', '1079', '1', 'El Carmen de Bolívar', 'CO.35.3684667', 'ASCII:El Carmen de Bolivar;ID:3684667', '13884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13884', '112', '15761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3684667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15762', '1079', '1', 'El Carmen', 'CO.21.3684711', 'ASCII:El Carmen;ID:3684711', '13885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13885', '112', '15762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3684711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15763', '1079', '1', 'El Carmen De Atrato', 'CO.11.3684712', 'ASCII:El Carmen De Atrato;ID:3684712', '13886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13886', '112', '15763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3684712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15764', '1079', '1', 'El Calvario', 'CO.19.3684771', 'ASCII:El Calvario;ID:3684771', '13887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13887', '112', '15764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3684771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15765', '1079', '1', 'El Cairo', 'CO.29.3684790', 'ASCII:El Cairo;ID:3684790', '13888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13888', '112', '15765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3684790» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15766', '1079', '1', 'El Banco', 'CO.35.3684928', 'ASCII:El Banco;ID:3684928', '13889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13889', '112', '15766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3684928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15767', '1079', '1', 'El Águila', 'CO.29.3685028', 'ASCII:El Aguila;ID:3685028', '13890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13890', '112', '15767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3685028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15768', '1079', '1', 'Ebéjico', 'CO.02.3685059', 'ASCII:Ebejico;ID:3685059', '13891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13891', '112', '15768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3685059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15769', '1079', '1', 'Durania', 'CO.21.3685071', 'ASCII:Durania;ID:3685071', '13892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13892', '112', '15769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3685071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15770', '1079', '1', 'Duitama', 'CO.36.3685085', 'ASCII:Duitama;ID:3685085', '13893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13893', '112', '15770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3685085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15771', '1079', '1', 'Don Matías', 'CO.02.3685127', 'ASCII:Don Matias;ID:3685127', '13894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13894', '112', '15771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3685127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15772', '1079', '1', 'Dolores', 'CO.28.3685179', 'ASCII:Dolores;ID:3685179', '13895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13895', '112', '15772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3685179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15773', '1079', '1', 'Dagua', 'CO.29.3685293', 'ASCII:Dagua;ID:3685293', '13896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13896', '112', '15773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3685293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15774', '1079', '1', 'Dabeiba', 'CO.02.3685297', 'ASCII:Dabeiba;ID:3685297', '13897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13897', '112', '15774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3685297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15775', '1079', '1', 'Curití', 'CO.26.3685346', 'ASCII:Curiti;ID:3685346', '13898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13898', '112', '15775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3685346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15776', '1079', '1', 'Cunday', 'CO.28.3685419', 'ASCII:Cunday;ID:3685419', '13899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13899', '112', '15776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3685419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15777', '1079', '1', 'Cumbal', 'CO.20.3685433', 'ASCII:Cumbal;ID:3685433', '13900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13900', '112', '15777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3685433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15778', '1079', '1', 'Cumaral', 'CO.19.3685446', 'ASCII:Cumaral;ID:3685446', '13901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13901', '112', '15778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3685446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15779', '1079', '1', 'Cuítiva', 'CO.36.3685483', 'ASCII:Cuitiva;ID:3685483', '13902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13902', '112', '15779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3685483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15780', '1079', '1', 'Cucutilla', 'CO.21.3685530', 'ASCII:Cucutilla;ID:3685530', '13903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13903', '112', '15780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3685530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15781', '1079', '1', 'Cúcuta', 'CO.21.3685534', 'ASCII:Cucuta;ID:3685534', '13904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13904', '112', '15781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3685534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15782', '1079', '1', 'Cucunubá', 'CO.33.3685541', 'ASCII:Cucunuba;ID:3685541', '13905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13905', '112', '15782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3685541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15783', '1079', '1', 'Cubará', 'CO.36.3685572', 'ASCII:Cubara;ID:3685572', '13906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13906', '112', '15783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3685572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15784', '1079', '1', 'Cuaspud', 'CO.20.3685615', 'ASCII:Cuaspud;ID:3685615', '13907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13907', '112', '15784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3685615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15785', '1079', '1', 'Coyaima', 'CO.28.3685709', 'ASCII:Coyaima;ID:3685709', '13908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13908', '112', '15785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3685709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15786', '1079', '1', 'Covarachía', 'CO.36.3685715', 'ASCII:Covarachia;ID:3685715', '13909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13909', '112', '15786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3685715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15787', '1079', '1', 'Cota', 'CO.33.3685734', 'ASCII:Cota;ID:3685734', '13910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13910', '112', '15787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3685734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15788', '1079', '1', 'Corrales', 'CO.36.3685795', 'ASCII:Corrales;ID:3685795', '13911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13911', '112', '15788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3685795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15789', '1079', '1', 'Corozal', 'CO.27.3685831', 'ASCII:Corozal;ID:3685831', '13912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13912', '112', '15789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3685831» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15790', '1079', '1', 'Coromoro', 'CO.26.3685841', 'ASCII:Coromoro;ID:3685841', '13913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13913', '112', '15790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3685841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15791', '1079', '1', 'Corinto', 'CO.09.3685873', 'ASCII:Corinto;ID:3685873', '13914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13914', '112', '15791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3685873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15792', '1079', '1', 'Córdoba', 'CO.35.3685904', 'ASCII:Cordoba;ID:3685904', '13915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13915', '112', '15792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3685904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15793', '1079', '1', 'Córdoba', 'CO.20.3685905', 'ASCII:Cordoba;ID:3685905', '13916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13916', '112', '15793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3685905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15794', '1079', '1', 'Coper', 'CO.36.3685944', 'ASCII:Coper;ID:3685944', '13917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13917', '112', '15794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3685944» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15795', '1079', '1', 'Copacabana', 'CO.02.3685950', 'ASCII:Copacabana;ID:3685950', '13918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13918', '112', '15795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3685950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15796', '1079', '1', 'Convención', 'CO.21.3685957', 'ASCII:Convencion;ID:3685957', '13919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13919', '112', '15796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3685957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15797', '1079', '1', 'Contratación', 'CO.26.3685962', 'ASCII:Contratacion;ID:3685962', '13920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13920', '112', '15797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3685962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15798', '1079', '1', 'Contadero', 'CO.20.3685975', 'ASCII:Contadero;ID:3685975', '13921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13921', '112', '15798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3685975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15799', '1079', '1', 'Consacá', 'CO.20.3685985', 'ASCII:Consaca;ID:3685985', '13922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13922', '112', '15799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3685985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15800', '1079', '1', 'Confines', 'CO.26.3685996', 'ASCII:Confines;ID:3685996', '13923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13923', '112', '15800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3685996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15801', '1079', '1', 'Condoto', 'CO.11.3686003', 'ASCII:Condoto;ID:3686003', '13924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13924', '112', '15801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3686003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15802', '1079', '1', 'Concordia', 'CO.02.3686016', 'ASCII:Concordia;ID:3686016', '13925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13925', '112', '15802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3686016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15803', '1079', '1', 'Concepción', 'CO.26.3686033', 'ASCII:Concepcion;ID:3686033', '13926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13926', '112', '15803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3686033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15804', '1079', '1', 'Concepción', 'CO.02.3686034', 'ASCII:Concepcion;ID:3686034', '13927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13927', '112', '15804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3686034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15805', '1079', '1', 'Cómbita', 'CO.36.3686053', 'ASCII:Combita;ID:3686053', '13928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13928', '112', '15805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3686053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15806', '1079', '1', 'Colón', 'CO.20.3686108', 'ASCII:Colon;ID:3686108', '13929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13929', '112', '15806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3686108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15807', '1079', '1', 'Colombia', 'CO.16.3686121', 'ASCII:Colombia;ID:3686121', '13930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13930', '112', '15807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3686121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15808', '1079', '1', 'Cogua', 'CO.33.3686135', 'ASCII:Cogua;ID:3686135', '13931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13931', '112', '15808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3686135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15809', '1079', '1', 'Coello', 'CO.28.3686143', 'ASCII:Coello;ID:3686143', '13932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13932', '112', '15809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3686143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15810', '1079', '1', 'Cocorná', 'CO.02.3686159', 'ASCII:Cocorna;ID:3686159', '13933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13933', '112', '15810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3686159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15811', '1079', '1', 'Cisneros', 'CO.02.3686229', 'ASCII:Cisneros;ID:3686229', '13934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13934', '112', '15811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3686229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15812', '1079', '1', 'Circasia', 'CO.23.3686234', 'ASCII:Circasia;ID:3686234', '13935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13935', '112', '15812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.23.3686234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15813', '1079', '1', 'Ciénaga de Oro', 'CO.12.3686273', 'ASCII:Cienaga de Oro;ID:3686273', '13936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13936', '112', '15813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3686273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15814', '1079', '1', 'Ciénaga', 'CO.38.3686276', 'ASCII:Cienaga;ID:3686276', '13937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13937', '112', '15814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3686276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15815', '1079', '1', 'Ciénaga', 'CO.36.3686280', 'ASCII:Cienaga;ID:3686280', '13938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13938', '112', '15815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3686280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15816', '1079', '1', 'Caicedonia', 'CO.29.3686294', 'ASCII:Caicedonia;ID:3686294', '13939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13939', '112', '15816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3686294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15817', '1079', '1', 'Chocontá', 'CO.33.3686423', 'ASCII:Choconta;ID:3686423', '13940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13940', '112', '15817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3686423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15818', '1079', '1', 'Choachí', 'CO.33.3686442', 'ASCII:Choachi;ID:3686442', '13941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13941', '112', '15818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3686442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15819', '1079', '1', 'Chitaraque', 'CO.36.3686455', 'ASCII:Chitaraque;ID:3686455', '13942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13942', '112', '15819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3686455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15820', '1079', '1', 'Chitagá', 'CO.21.3686461', 'ASCII:Chitaga;ID:3686461', '13943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13943', '112', '15820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3686461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15821', '1079', '1', 'Chita', 'CO.36.3686466', 'ASCII:Chita;ID:3686466', '13944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13944', '112', '15821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3686466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15822', '1079', '1', 'Chiscas', 'CO.36.3686472', 'ASCII:Chiscas;ID:3686472', '13945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13945', '112', '15822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3686472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15823', '1079', '1', 'Chiriguaná', 'CO.10.3686481', 'ASCII:Chiriguana;ID:3686481', '13946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13946', '112', '15823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.10.3686481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15824', '1079', '1', 'Chiquinquirá', 'CO.36.3686515', 'ASCII:Chiquinquira;ID:3686515', '13947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13947', '112', '15824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3686515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15825', '1079', '1', 'Chipatá', 'CO.26.3686531', 'ASCII:Chipata;ID:3686531', '13948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13948', '112', '15825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3686531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15826', '1079', '1', 'Chipaque', 'CO.33.3686533', 'ASCII:Chipaque;ID:3686533', '13949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13949', '112', '15826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3686533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15827', '1079', '1', 'Chinú', 'CO.12.3686541', 'ASCII:Chinu;ID:3686541', '13950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13950', '112', '15827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3686541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15828', '1079', '1', 'Chinchiná', 'CO.37.3686562', 'ASCII:Chinchina;ID:3686562', '13951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13951', '112', '15828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3686562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15829', '1079', '1', 'Chinavita', 'CO.36.3686571', 'ASCII:Chinavita;ID:3686571', '13952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13952', '112', '15829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3686571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15830', '1079', '1', 'Chinácota', 'CO.21.3686575', 'ASCII:Chinacota;ID:3686575', '13953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13953', '112', '15830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3686575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15831', '1079', '1', 'Chimichagua', 'CO.38.3686586', 'ASCII:Chimichagua;ID:3686586', '13954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13954', '112', '15831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3686586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15832', '1079', '1', 'Chimá', 'CO.12.3686607', 'ASCII:Chima;ID:3686607', '13955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13955', '112', '15832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3686607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15833', '1079', '1', 'Chima', 'CO.26.3686608', 'ASCII:Chima;ID:3686608', '13956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13956', '112', '15833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3686608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15834', '1079', '1', 'Chigorodó', 'CO.02.3686637', 'ASCII:Chigorodo;ID:3686637', '13957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13957', '112', '15834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3686637» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15835', '1079', '1', 'Chía', 'CO.33.3686677', 'ASCII:Chia;ID:3686677', '13958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13958', '112', '15835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3686677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15836', '1079', '1', 'Charta', 'CO.26.3686713', 'ASCII:Charta;ID:3686713', '13959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13959', '112', '15836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3686713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15837', '1079', '1', 'Charalá', 'CO.26.3686738', 'ASCII:Charala;ID:3686738', '13960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13960', '112', '15837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3686738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15838', '1079', '1', 'Chaparral', 'CO.28.3686794', 'ASCII:Chaparral;ID:3686794', '13961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13961', '112', '15838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3686794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15839', '1079', '1', 'Chámeza', 'CO.32.3686820', 'ASCII:Chameza;ID:3686820', '13962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13962', '112', '15839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3686820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15840', '1079', '1', 'Chaguaní', 'CO.33.3686852', 'ASCII:Chaguani;ID:3686852', '13963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13963', '112', '15840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3686852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15841', '1079', '1', 'Cerro de San Antonio', 'CO.38.3686895', 'ASCII:Cerro de San Antonio;ID:3686895', '13964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13964', '112', '15841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3686895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15842', '1079', '1', 'Cerrito', 'CO.26.3686909', 'ASCII:Cerrito;ID:3686909', '13965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13965', '112', '15842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3686909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15843', '1079', '1', 'Cerinza', 'CO.36.3686919', 'ASCII:Cerinza;ID:3686919', '13966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13966', '112', '15843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3686919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15844', '1079', '1', 'Cereté', 'CO.12.3686923', 'ASCII:Cerete;ID:3686923', '13967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13967', '112', '15844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3686923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15845', '1079', '1', 'Cepitá', 'CO.26.3686926', 'ASCII:Cepita;ID:3686926', '13968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13968', '112', '15845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3686926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15846', '1079', '1', 'Caucasia', 'CO.02.3687026', 'ASCII:Caucasia;ID:3687026', '13969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13969', '112', '15846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3687026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15847', '1079', '1', 'Castilla La Nueva', 'CO.19.3687085', 'ASCII:Castilla La Nueva;ID:3687085', '13970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13970', '112', '15847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3687085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15848', '1079', '1', 'Casabianca', 'CO.28.3687214', 'ASCII:Casabianca;ID:3687214', '13971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13971', '112', '15848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3687214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15849', '1079', '1', 'Cartago', 'CO.29.3687232', 'ASCII:Cartago;ID:3687232', '13972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13972', '112', '15849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3687232» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15850', '1079', '1', 'Cartagena', 'CO.35.3687247', 'ASCII:Cartagena;ID:3687247', '13973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13973', '112', '15850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3687247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15851', '1079', '1', 'Carolina', 'CO.02.3687311', 'ASCII:Carolina;ID:3687311', '13974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13974', '112', '15851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3687311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15852', '1079', '1', 'Carmen de Viboral', 'CO.02.3687319', 'ASCII:Carmen de Viboral;ID:3687319', '13975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13975', '112', '15852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3687319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15853', '1079', '1', 'Carmen de Carupa', 'CO.33.3687322', 'ASCII:Carmen de Carupa;ID:3687322', '13976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13976', '112', '15853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3687322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15854', '1079', '1', 'Carmen de Apicalá', 'CO.28.3687325', 'ASCII:Carmen de Apicala;ID:3687325', '13977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13977', '112', '15854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3687325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15855', '1079', '1', 'Carcasí', 'CO.26.3687395', 'ASCII:Carcasi;ID:3687395', '13978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13978', '112', '15855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3687395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15856', '1079', '1', 'Caramanta', 'CO.02.3687428', 'ASCII:Caramanta;ID:3687428', '13979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13979', '112', '15856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3687428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15857', '1079', '1', 'Cáqueza', 'CO.33.3687477', 'ASCII:Caqueza;ID:3687477', '13980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13980', '112', '15857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3687477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15858', '1079', '1', 'Capitanejo', 'CO.26.3687491', 'ASCII:Capitanejo;ID:3687491', '13981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13981', '112', '15858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3687491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15859', '1079', '1', 'Caparrapí', 'CO.33.3687506', 'ASCII:Caparrapi;ID:3687506', '13982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13982', '112', '15859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3687506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15860', '1079', '1', 'Candelaria', 'CO.04.3687646', 'ASCII:Candelaria;ID:3687646', '13983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13983', '112', '15860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3687646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15861', '1079', '1', 'Candelaria', 'CO.29.3687647', 'ASCII:Candelaria;ID:3687647', '13984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13984', '112', '15861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3687647» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15862', '1079', '1', 'Cañasgordas', 'CO.02.3687679', 'ASCII:Canasgordas;ID:3687679', '13985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13985', '112', '15862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3687679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15863', '1079', '1', 'Campohermoso', 'CO.36.3687753', 'ASCII:Campohermoso;ID:3687753', '13986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13986', '112', '15863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3687753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15864', '1079', '1', 'Campo de la Cruz', 'CO.04.3687759', 'ASCII:Campo de la Cruz;ID:3687759', '13987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13987', '112', '15864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3687759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15865', '1079', '1', 'Campoalegre', 'CO.16.3687808', 'ASCII:Campoalegre;ID:3687808', '13988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13988', '112', '15865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3687808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15866', '1079', '1', 'Campamento', 'CO.02.3687840', 'ASCII:Campamento;ID:3687840', '13989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13989', '112', '15866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3687840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15867', '1079', '1', 'Caloto', 'CO.09.3687881', 'ASCII:Caloto;ID:3687881', '13990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13990', '112', '15867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3687881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15868', '1079', '1', 'Calima', 'CO.29.3687908', 'ASCII:Calima;ID:3687908', '13991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13991', '112', '15868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3687908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15869', '1079', '1', 'California', 'CO.26.3687919', 'ASCII:California;ID:3687919', '13992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13992', '112', '15869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3687919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15870', '1079', '1', 'Cali', 'CO.29.3687926', 'ASCII:Cali;ID:3687926', '13993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13993', '112', '15870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3687926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15871', '1079', '1', 'Caldono', 'CO.09.3687934', 'ASCII:Caldono;ID:3687934', '13994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13994', '112', '15871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3687934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15872', '1079', '1', 'Caldas', 'CO.02.3687954', 'ASCII:Caldas;ID:3687954', '13995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13995', '112', '15872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3687954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15873', '1079', '1', 'Caldas', 'CO.36.3687955', 'ASCII:Caldas;ID:3687955', '13996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13996', '112', '15873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3687955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15874', '1079', '1', 'Calarcá', 'CO.23.3687965', 'ASCII:Calarca;ID:3687965', '13997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13997', '112', '15874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.23.3687965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15875', '1079', '1', 'Calamar', 'CO.35.3687977', 'ASCII:Calamar;ID:3687977', '13998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13998', '112', '15875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3687977» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15876', '1079', '1', 'Cajicá', 'CO.33.3688007', 'ASCII:Cajica;ID:3688007', '13999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('13999', '112', '15876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3688007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15877', '1079', '1', 'Cajibío', 'CO.09.3688010', 'ASCII:Cajibio;ID:3688010', '14000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14000', '112', '15877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3688010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15878', '1079', '1', 'Cajamarca', 'CO.28.3688022', 'ASCII:Cajamarca;ID:3688022', '14001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14001', '112', '15878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3688022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15879', '1079', '1', 'Caimito', 'CO.27.3688031', 'ASCII:Caimito;ID:3688031', '14002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14002', '112', '15879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.27.3688031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15880', '1079', '1', 'Caicedo', 'CO.02.3688073', 'ASCII:Caicedo;ID:3688073', '14003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14003', '112', '15880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3688073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15881', '1079', '1', 'Cácota', 'CO.21.3688088', 'ASCII:Cacota;ID:3688088', '14004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14004', '112', '15881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3688088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15882', '1079', '1', 'Cáchira', 'CO.21.3688108', 'ASCII:Cachira;ID:3688108', '14005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14005', '112', '15882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3688108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15883', '1079', '1', 'Cáceres', 'CO.02.3688130', 'ASCII:Caceres;ID:3688130', '14006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14006', '112', '15883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3688130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15884', '1079', '1', 'Cabrera', 'CO.26.3688173', 'ASCII:Cabrera;ID:3688173', '14007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14007', '112', '15884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3688173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15885', '1079', '1', 'Busbanzá', 'CO.36.3688215', 'ASCII:Busbanza;ID:3688215', '14008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14008', '112', '15885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3688215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15886', '1079', '1', 'Buriticá', 'CO.02.3688226', 'ASCII:Buritica;ID:3688226', '14009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14009', '112', '15886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3688226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15887', '1079', '1', 'Bugalagrande', 'CO.29.3688255', 'ASCII:Bugalagrande;ID:3688255', '14010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14010', '112', '15887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3688255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15888', '1079', '1', 'Buga', 'CO.29.3688258', 'ASCII:Buga;ID:3688258', '14011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14011', '112', '15888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3688258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15889', '1079', '1', 'Buesaco', 'CO.20.3688267', 'ASCII:Buesaco;ID:3688267', '14012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14012', '112', '15889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3688267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15890', '1079', '1', 'Buenos Aires', 'CO.09.3688360', 'ASCII:Buenos Aires;ID:3688360', '14013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14013', '112', '15890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3688360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15891', '1079', '1', 'Buenavista', 'CO.36.3688364', 'ASCII:Buenavista;ID:3688364', '14014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14014', '112', '15891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3688364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15892', '1079', '1', 'Bucarasica', 'CO.21.3688463', 'ASCII:Bucarasica;ID:3688463', '14015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14015', '112', '15892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3688463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15893', '1079', '1', 'Bucaramanga', 'CO.26.3688467', 'ASCII:Bucaramanga;ID:3688467', '14016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14016', '112', '15893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3688467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15894', '1079', '1', 'Briceño', 'CO.36.3688505', 'ASCII:Briceno;ID:3688505', '14017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14017', '112', '15894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3688505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15895', '1079', '1', 'Boyacá', 'CO.36.3688543', 'ASCII:Boyaca;ID:3688543', '14018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14018', '112', '15895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3688543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15896', '1079', '1', 'Bolívar', 'CO.26.3688666', 'ASCII:Bolivar;ID:3688666', '14019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14019', '112', '15896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3688666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15897', '1079', '1', 'Bolívar', 'CO.02.3688667', 'ASCII:Bolivar;ID:3688667', '14020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14020', '112', '15897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3688667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15898', '1079', '1', 'Bolívar', 'CO.29.3688668', 'ASCII:Bolivar;ID:3688668', '14021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14021', '112', '15898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3688668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15899', '1079', '1', 'Bolívar', 'CO.09.3688669', 'ASCII:Bolivar;ID:3688669', '14022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14022', '112', '15899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3688669» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15900', '1079', '1', 'Bojayá', 'CO.11.3688672', 'ASCII:Bojaya;ID:3688672', '14023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14023', '112', '15900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3688672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15901', '1079', '1', 'Bojacá', 'CO.33.3688674', 'ASCII:Bojaca;ID:3688674', '14024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14024', '112', '15901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3688674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15902', '1079', '1', 'Bochalema', 'CO.21.3688707', 'ASCII:Bochalema;ID:3688707', '14025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14025', '112', '15902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3688707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15903', '1079', '1', 'Boavita', 'CO.36.3688776', 'ASCII:Boavita;ID:3688776', '14026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14026', '112', '15903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3688776» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15904', '1079', '1', 'Bituima', 'CO.33.3688812', 'ASCII:Bituima;ID:3688812', '14027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14027', '112', '15904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3688812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15905', '1079', '1', 'Betulia', 'CO.26.3688842', 'ASCII:Betulia;ID:3688842', '14028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14028', '112', '15905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3688842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15906', '1079', '1', 'Betulia', 'CO.02.3688843', 'ASCII:Betulia;ID:3688843', '14029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14029', '112', '15906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3688843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15907', '1079', '1', 'Betéitiva', 'CO.36.3688847', 'ASCII:Beteitiva;ID:3688847', '14030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14030', '112', '15907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3688847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15908', '1079', '1', 'Betania', 'CO.02.3688865', 'ASCII:Betania;ID:3688865', '14031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14031', '112', '15908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3688865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15909', '1079', '1', 'Berbeo', 'CO.36.3688910', 'ASCII:Berbeo;ID:3688910', '14032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14032', '112', '15909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3688910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15910', '1079', '1', 'Beltrán', 'CO.33.3688919', 'ASCII:Beltran;ID:3688919', '14033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14033', '112', '15910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3688919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15911', '1079', '1', 'Belmira', 'CO.02.3688924', 'ASCII:Belmira;ID:3688924', '14034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14034', '112', '15911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3688924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15912', '1079', '1', 'Bello', 'CO.02.3688929', 'ASCII:Bello;ID:3688929', '14035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14035', '112', '15912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3688929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15913', '1079', '1', 'Belén de Umbría', 'CO.24.3688990', 'ASCII:Belen de Umbria;ID:3688990', '14036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14036', '112', '15913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3688990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15914', '1079', '1', 'Belén de los Andaquíes', 'CO.08.3688992', 'ASCII:Belen de los Andaquies;ID:3688992', '14037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14037', '112', '15914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.08.3688992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15915', '1079', '1', 'Belén', 'CO.36.3689007', 'ASCII:Belen;ID:3689007', '14038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14038', '112', '15915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3689007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15916', '1079', '1', 'Belalcázar', 'CO.37.3689013', 'ASCII:Belalcazar;ID:3689013', '14039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14039', '112', '15916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3689013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15917', '1079', '1', 'Barranquilla', 'CO.04.3689152', 'ASCII:Barranquilla;ID:3689152', '14040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14040', '112', '15917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3689152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15918', '1079', '1', 'Barranco de Loba', 'CO.35.3689158', 'ASCII:Barranco de Loba;ID:3689158', '14041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14041', '112', '15918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3689158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15919', '1079', '1', 'Barrancas', 'CO.17.3689165', 'ASCII:Barrancas;ID:3689165', '14042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14042', '112', '15919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.17.3689165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15920', '1079', '1', 'Barrancabermeja', 'CO.26.3689170', 'ASCII:Barrancabermeja;ID:3689170', '14043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14043', '112', '15920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3689170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15921', '1079', '1', 'Barichara', 'CO.26.3689188', 'ASCII:Barichara;ID:3689188', '14044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14044', '112', '15921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3689188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15922', '1079', '1', 'Barbosa', 'CO.02.3689207', 'ASCII:Barbosa;ID:3689207', '14045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14045', '112', '15922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3689207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15923', '1079', '1', 'Barbosa', 'CO.26.3689208', 'ASCII:Barbosa;ID:3689208', '14046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14046', '112', '15923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3689208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15924', '1079', '1', 'Barbacoas', 'CO.20.3689229', 'ASCII:Barbacoas;ID:3689229', '14047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14047', '112', '15924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3689229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15925', '1079', '1', 'Baraya', 'CO.16.3689234', 'ASCII:Baraya;ID:3689234', '14048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14048', '112', '15925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3689234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15926', '1079', '1', 'Baranoa', 'CO.04.3689237', 'ASCII:Baranoa;ID:3689237', '14049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14049', '112', '15926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.04.3689237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15927', '1079', '1', 'Balboa', 'CO.24.3689293', 'ASCII:Balboa;ID:3689293', '14050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14050', '112', '15927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3689293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15928', '1079', '1', 'Balboa', 'CO.09.3689294', 'ASCII:Balboa;ID:3689294', '14051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14051', '112', '15928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3689294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15929', '1079', '1', 'Bajo Baudó', 'CO.11.3689318', 'ASCII:Bajo Baudo;ID:3689318', '14052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14052', '112', '15929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3689318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15930', '1079', '1', 'Bagadó', 'CO.11.3689337', 'ASCII:Bagado;ID:3689337', '14053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14053', '112', '15930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3689337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15931', '1079', '1', 'Ayapel', 'CO.12.3689382', 'ASCII:Ayapel;ID:3689382', '14054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14054', '112', '15931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.12.3689382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15932', '1079', '1', 'Ataco', 'CO.28.3689451', 'ASCII:Ataco;ID:3689451', '14055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14055', '112', '15932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3689451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15933', '1079', '1', 'Armero', 'CO.28.3689552', 'ASCII:Armero;ID:3689552', '14056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14056', '112', '15933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3689552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15934', '1079', '1', 'Armenia', 'CO.02.3689562', 'ASCII:Armenia;ID:3689562', '14057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14057', '112', '15934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3689562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15935', '1079', '1', 'Armenia', 'CO.23.3689563', 'ASCII:Armenia;ID:3689563', '14058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14058', '112', '15935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.23.3689563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15936', '1079', '1', 'Arjona', 'CO.35.3689572', 'ASCII:Arjona;ID:3689572', '14059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14059', '112', '15936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3689572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15937', '1079', '1', 'Argelia', 'CO.29.3689618', 'ASCII:Argelia;ID:3689618', '14060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14060', '112', '15937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3689618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15938', '1079', '1', 'Argelia', 'CO.09.3689619', 'ASCII:Argelia;ID:3689619', '14061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14061', '112', '15938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3689619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15939', '1079', '1', 'Arcabuco', 'CO.36.3689690', 'ASCII:Arcabuco;ID:3689690', '14062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14062', '112', '15939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3689690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15940', '1079', '1', 'Arboletes', 'CO.02.3689694', 'ASCII:Arboletes;ID:3689694', '14063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14063', '112', '15940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3689694» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15941', '1079', '1', 'Arboledas', 'CO.21.3689698', 'ASCII:Arboledas;ID:3689698', '14064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14064', '112', '15941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3689698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15942', '1079', '1', 'Arboleda', 'CO.20.3689706', 'ASCII:Arboleda;ID:3689706', '14065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14065', '112', '15942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3689706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15943', '1079', '1', 'Arbeláez', 'CO.33.3689710', 'ASCII:Arbelaez;ID:3689710', '14066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14066', '112', '15943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3689710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15944', '1079', '1', 'Arauca', 'CO.03.3689720', 'ASCII:Arauca;ID:3689720', '14067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14067', '112', '15944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.03.3689720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15945', '1079', '1', 'Aratoca', 'CO.26.3689724', 'ASCII:Aratoca;ID:3689724', '14068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14068', '112', '15945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3689724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15946', '1079', '1', 'Aranzazu', 'CO.37.3689741', 'ASCII:Aranzazu;ID:3689741', '14069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14069', '112', '15946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3689741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15947', '1079', '1', 'Aracataca', 'CO.38.3689761', 'ASCII:Aracataca;ID:3689761', '14070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14070', '112', '15947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.38.3689761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15948', '1079', '1', 'Aquitania', 'CO.36.3689772', 'ASCII:Aquitania;ID:3689772', '14071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14071', '112', '15948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3689772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15949', '1079', '1', 'Apía', 'CO.24.3689794', 'ASCII:Apia;ID:3689794', '14072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14072', '112', '15949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.24.3689794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15950', '1079', '1', 'Anzoátegui', 'CO.28.3689803', 'ASCII:Anzoategui;ID:3689803', '14073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14073', '112', '15950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3689803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15951', '1079', '1', 'Anzá', 'CO.02.3689805', 'ASCII:Anza;ID:3689805', '14074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14074', '112', '15951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3689805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15952', '1079', '1', 'Santafé De Antioquia', 'CO.02.3689819', 'ASCII:Santafe De Antioquia;ID:3689819', '14075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14075', '112', '15952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3689819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15953', '1079', '1', 'Ansermanuevo', 'CO.29.3689832', 'ASCII:Ansermanuevo;ID:3689832', '14076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14076', '112', '15953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3689832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15954', '1079', '1', 'Anserma', 'CO.37.3689834', 'ASCII:Anserma;ID:3689834', '14077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14077', '112', '15954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3689834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15955', '1079', '1', 'Anorí', 'CO.02.3689839', 'ASCII:Anori;ID:3689839', '14078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14078', '112', '15955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3689839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15956', '1079', '1', 'Anolaima', 'CO.33.3689842', 'ASCII:Anolaima;ID:3689842', '14079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14079', '112', '15956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3689842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15957', '1079', '1', 'Angostura', 'CO.02.3689875', 'ASCII:Angostura;ID:3689875', '14080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14080', '112', '15957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3689875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15958', '1079', '1', 'Angelópolis', 'CO.02.3689878', 'ASCII:Angelopolis;ID:3689878', '14081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14081', '112', '15958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3689878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15959', '1079', '1', 'Andes', 'CO.02.3689900', 'ASCII:Andes;ID:3689900', '14082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14082', '112', '15959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3689900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15960', '1079', '1', 'Andalucía', 'CO.29.3689907', 'ASCII:Andalucia;ID:3689907', '14083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14083', '112', '15960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3689907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15961', '1079', '1', 'Ancuyá', 'CO.20.3689916', 'ASCII:Ancuya;ID:3689916', '14084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14084', '112', '15961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3689916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15962', '1079', '1', 'Anapoima', 'CO.33.3689942', 'ASCII:Anapoima;ID:3689942', '14085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14085', '112', '15962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3689942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15963', '1079', '1', 'Ambalema', 'CO.28.3689980', 'ASCII:Ambalema;ID:3689980', '14086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14086', '112', '15963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3689980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15964', '1079', '1', 'Amalfi', 'CO.02.3690011', 'ASCII:Amalfi;ID:3690011', '14087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14087', '112', '15964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3690011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15965', '1079', '1', 'Amagá', 'CO.02.3690020', 'ASCII:Amaga;ID:3690020', '14088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14088', '112', '15965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3690020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15966', '1079', '1', 'Alvarado', 'CO.28.3690031', 'ASCII:Alvarado;ID:3690031', '14089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14089', '112', '15966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3690031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15967', '1079', '1', 'Alto Baudó', 'CO.11.3690070', 'ASCII:Alto Baudo;ID:3690070', '14090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14090', '112', '15967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3690070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15968', '1079', '1', 'Altamira', 'CO.16.3690104', 'ASCII:Altamira;ID:3690104', '14091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14091', '112', '15968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3690104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15969', '1079', '1', 'Alpujarra', 'CO.28.3690125', 'ASCII:Alpujarra;ID:3690125', '14092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14092', '112', '15969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.28.3690125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15970', '1079', '1', 'Almeida', 'CO.36.3690135', 'ASCII:Almeida;ID:3690135', '14093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14093', '112', '15970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.3690135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15971', '1079', '1', 'Almaguer', 'CO.09.3690137', 'ASCII:Almaguer;ID:3690137', '14094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14094', '112', '15971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.09.3690137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15972', '1079', '1', 'Algeciras', 'CO.16.3690161', 'ASCII:Algeciras;ID:3690161', '14095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14095', '112', '15972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3690161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15973', '1079', '1', 'Alejandría', 'CO.02.3690217', 'ASCII:Alejandria;ID:3690217', '14096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14096', '112', '15973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3690217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15974', '1079', '1', 'Aldana', 'CO.20.3690227', 'ASCII:Aldana;ID:3690227', '14097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14097', '112', '15974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3690227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15975', '1079', '1', 'Alcalá', 'CO.29.3690238', 'ASCII:Alcala;ID:3690238', '14098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14098', '112', '15975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.29.3690238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15976', '1079', '1', 'Albania', 'CO.26.3690263', 'ASCII:Albania;ID:3690263', '14099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14099', '112', '15976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.26.3690263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15977', '1079', '1', 'Albán', 'CO.33.3690267', 'ASCII:Alban;ID:3690267', '14100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14100', '112', '15977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3690267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15978', '1079', '1', 'Albán', 'CO.20.3690268', 'ASCII:Alban;ID:3690268', '14101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14101', '112', '15978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.20.3690268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15979', '1079', '1', 'Aipe', 'CO.16.3690288', 'ASCII:Aipe;ID:3690288', '14102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14102', '112', '15979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3690288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15980', '1079', '1', 'Agustín Codazzi', 'CO.10.3690298', 'ASCII:Agustin Codazzi;ID:3690298', '14103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14103', '112', '15980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.10.3690298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15981', '1079', '1', 'Aguazul', 'CO.32.3690317', 'ASCII:Aguazul;ID:3690317', '14104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14104', '112', '15981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.3690317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15982', '1079', '1', 'Agua de Dios', 'CO.33.3690430', 'ASCII:Agua de Dios;ID:3690430', '14105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14105', '112', '15982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.33.3690430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15983', '1079', '1', 'Aguadas', 'CO.37.3690432', 'ASCII:Aguadas;ID:3690432', '14106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14106', '112', '15983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.37.3690432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15984', '1079', '1', 'Aguachica', 'CO.10.3690466', 'ASCII:Aguachica;ID:3690466', '14107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14107', '112', '15984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.10.3690466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15985', '1079', '1', 'Agrado', 'CO.16.3690521', 'ASCII:Agrado;ID:3690521', '14108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14108', '112', '15985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3690521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15986', '1079', '1', 'Achí', 'CO.35.3690550', 'ASCII:Achi;ID:3690550', '14109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14109', '112', '15986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.35.3690550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15987', '1079', '1', 'Acevedo', 'CO.16.3690553', 'ASCII:Acevedo;ID:3690553', '14110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14110', '112', '15987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.16.3690553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15988', '1079', '1', 'Acandí', 'CO.11.3690573', 'ASCII:Acandi;ID:3690573', '14111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14111', '112', '15988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.11.3690573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15989', '1079', '1', 'Acacías', 'CO.19.3690578', 'ASCII:Acacias;ID:3690578', '14112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14112', '112', '15989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.3690578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15990', '1079', '1', 'Abriaquí', 'CO.02.3690583', 'ASCII:Abriaqui;ID:3690583', '14113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14113', '112', '15990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3690583» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15991', '1079', '1', 'Ábrego', 'CO.21.3690586', 'ASCII:Abrego;ID:3690586', '14114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14114', '112', '15991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.21.3690586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15992', '1079', '1', 'Abejorral', 'CO.02.3690593', 'ASCII:Abejorral;ID:3690593', '14115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14115', '112', '15992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.02.3690593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15993', '1079', '1', 'Arauquita', 'CO.03.6194448', 'ASCII:Arauquita;ID:6194448', '14116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14116', '112', '15993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.03.6194448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15994', '1079', '1', 'Fortul', 'CO.03.6194449', 'ASCII:Fortul;ID:6194449', '14117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14117', '112', '15994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.03.6194449» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15995', '1079', '1', 'Puerto Rondón', 'CO.03.6194450', 'ASCII:Puerto Rondon;ID:6194450', '14118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14118', '112', '15995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.03.6194450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15996', '1079', '1', 'Cravo Norte', 'CO.03.6195938', 'ASCII:Cravo Norte;ID:6195938', '14119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14119', '112', '15996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.03.6195938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15997', '1079', '1', 'Güicán', 'CO.36.6196087', 'ASCII:Gueican;ID:6196087', '14120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14120', '112', '15997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.36.6196087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15998', '1079', '1', 'La Salina', 'CO.32.6198139', 'ASCII:La Salina;ID:6198139', '14121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14121', '112', '15998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.6198139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('15999', '1079', '1', 'Sacama', 'CO.32.6198140', 'ASCII:Sacama;ID:6198140', '14122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14122', '112', '15999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.32.6198140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16000', '1079', '1', 'Municipio de Puerto Guzmán', 'CO.08.6791991', 'ASCII:Municipio de Puerto Guzman;ID:6791991', '14123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14123', '112', '16000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.08.6791991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16001', '1079', '1', 'Municipio de Solita', 'CO.08.6792005', 'ASCII:Municipio de Solita;ID:6792005', '14124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14124', '112', '16001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.08.6792005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16002', '1079', '1', 'Municipio de Calamar', 'CO.14.6798554', 'ASCII:Municipio de Calamar;ID:6798554', '14125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14125', '112', '16002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.14.6798554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16003', '1079', '1', 'Municipio de La Macarena', 'CO.19.6826880', 'ASCII:Municipio de La Macarena;ID:6826880', '14126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14126', '112', '16003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.19.6826880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16004', '1079', '1', 'Municipio de San Vicente de Caguán', 'CO.08.6826899', 'ASCII:Municipio de San Vicente de Caguan;ID:6826899', '14127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14127', '112', '16004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.08.6826899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16005', '1079', '1', 'Municipio San José del Guaviare', 'CO.14.6851384', 'ASCII:Municipio San Jose del Guaviare;ID:6851384', '14128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14128', '112', '16005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CO.14.6851384» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16006', '1079', '1', 'Cantón Vázquez de Coronado', 'CR.08.3621119', 'ASCII:Canton Vazquez de Coronado;ID:3621119', '14129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14129', '112', '16006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3621119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16007', '1079', '1', 'Cantón de Valverde Vega', 'CR.01.3621127', 'ASCII:Canton de Valverde Vega;ID:3621127', '14130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14130', '112', '16007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3621127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16008', '1079', '1', 'Cantón de Upala', 'CR.01.3621152', 'ASCII:Canton de Upala;ID:3621152', '14131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14131', '112', '16008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3621152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16009', '1079', '1', 'Cantón de Turrubares', 'CR.08.3621177', 'ASCII:Canton de Turrubares;ID:3621177', '14132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14132', '112', '16009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3621177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16010', '1079', '1', 'Cantón de Turrialba', 'CR.02.3621183', 'ASCII:Canton de Turrialba;ID:3621183', '14133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14133', '112', '16010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.02.3621183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16011', '1079', '1', 'Cantón de Tilarán', 'CR.03.3621277', 'ASCII:Canton de Tilaran;ID:3621277', '14134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14134', '112', '16011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3621277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16012', '1079', '1', 'Cantón de Tibás', 'CR.08.3621308', 'ASCII:Canton de Tibas;ID:3621308', '14135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14135', '112', '16012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3621308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16013', '1079', '1', 'Cantón de Tarrazú', 'CR.08.3621342', 'ASCII:Canton de Tarrazu;ID:3621342', '14136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14136', '112', '16013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3621342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16014', '1079', '1', 'Cantón de Talamanca', 'CR.06.3621369', 'ASCII:Canton de Talamanca;ID:3621369', '14137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14137', '112', '16014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.06.3621369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16015', '1079', '1', 'Cantón de Siquirres', 'CR.06.3621439', 'ASCII:Canton de Siquirres;ID:3621439', '14138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14138', '112', '16015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.06.3621439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16016', '1079', '1', 'Cantón de Sarapiquí', 'CR.04.3621497', 'ASCII:Canton de Sarapiqui;ID:3621497', '14139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14139', '112', '16016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.04.3621497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16017', '1079', '1', 'Cantón de Santo Domingo', 'CR.04.3621512', 'ASCII:Canton de Santo Domingo;ID:3621512', '14140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14140', '112', '16017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.04.3621512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16018', '1079', '1', 'Cantón de Santa Cruz', 'CR.03.3621604', 'ASCII:Canton de Santa Cruz;ID:3621604', '14141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14141', '112', '16018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3621604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16019', '1079', '1', 'Cantón de Santa Bárbara', 'CR.04.3621622', 'ASCII:Canton de Santa Barbara;ID:3621622', '14142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14142', '112', '16019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.04.3621622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16020', '1079', '1', 'Cantón de Santa Ana', 'CR.08.3621626', 'ASCII:Canton de Santa Ana;ID:3621626', '14143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14143', '112', '16020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3621626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16021', '1079', '1', 'Cantón de San Ramón', 'CR.01.3621642', 'ASCII:Canton de San Ramon;ID:3621642', '14144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14144', '112', '16021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3621642» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16022', '1079', '1', 'Cantón de San Rafael', 'CR.04.3621668', 'ASCII:Canton de San Rafael;ID:3621668', '14145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14145', '112', '16022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.04.3621668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16023', '1079', '1', 'Cantón de San Pablo', 'CR.04.3621727', 'ASCII:Canton de San Pablo;ID:3621727', '14146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14146', '112', '16023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.04.3621727» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16024', '1079', '1', 'Cantón de San Mateo', 'CR.01.3621757', 'ASCII:Canton de San Mateo;ID:3621757', '14147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14147', '112', '16024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3621757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16025', '1079', '1', 'Cantón Central de San José', 'CR.08.3621840', 'ASCII:Canton Central de San Jose;ID:3621840', '14148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14148', '112', '16025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3621840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16026', '1079', '1', 'Cantón de San Isidro', 'CR.04.3621871', 'ASCII:Canton de San Isidro;ID:3621871', '14149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14149', '112', '16026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.04.3621871» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16027', '1079', '1', 'Cantón de San Carlos', 'CR.01.3621940', 'ASCII:Canton de San Carlos;ID:3621940', '14150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14150', '112', '16027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3621940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16028', '1079', '1', 'Cantón de Puriscal', 'CR.08.3622220', 'ASCII:Canton de Puriscal;ID:3622220', '14151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14151', '112', '16028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3622220» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16029', '1079', '1', 'Cantón Central de Puntarenas', 'CR.07.3622227', 'ASCII:Canton Central de Puntarenas;ID:3622227', '14152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14152', '112', '16029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.07.3622227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16030', '1079', '1', 'Cantón de Pococí', 'CR.06.3622326', 'ASCII:Canton de Pococi;ID:3622326', '14153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14153', '112', '16030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.06.3622326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16031', '1079', '1', 'Cantón de Poás', 'CR.01.3622341', 'ASCII:Canton de Poas;ID:3622341', '14154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14154', '112', '16031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3622341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16032', '1079', '1', 'Cantón de Pérez Zeledón', 'CR.08.3622439', 'ASCII:Canton de Perez Zeledon;ID:3622439', '14155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14155', '112', '16032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3622439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16033', '1079', '1', 'Cantón de Parrita', 'CR.07.3622535', 'ASCII:Canton de Parrita;ID:3622535', '14156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14156', '112', '16033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.07.3622535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16034', '1079', '1', 'Cantón de Paraíso', 'CR.02.3622543', 'ASCII:Canton de Paraiso;ID:3622543', '14157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14157', '112', '16034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.02.3622543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16035', '1079', '1', 'Cantón de Palmares', 'CR.01.3622608', 'ASCII:Canton de Palmares;ID:3622608', '14158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14158', '112', '16035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3622608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16036', '1079', '1', 'Cantón de Osa', 'CR.07.3622657', 'ASCII:Canton de Osa;ID:3622657', '14159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14159', '112', '16036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.07.3622657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16037', '1079', '1', 'Cantón de Orotina', 'CR.01.3622659', 'ASCII:Canton de Orotina;ID:3622659', '14160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14160', '112', '16037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3622659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16038', '1079', '1', 'Cantón de Oreamuno', 'CR.02.3622669', 'ASCII:Canton de Oreamuno;ID:3622669', '14161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14161', '112', '16038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.02.3622669» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16039', '1079', '1', 'Cantón de Nicoya', 'CR.03.3622715', 'ASCII:Canton de Nicoya;ID:3622715', '14162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14162', '112', '16039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3622715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16040', '1079', '1', 'Cantón de Naranjo', 'CR.01.3622749', 'ASCII:Canton de Naranjo;ID:3622749', '14163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14163', '112', '16040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3622749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16041', '1079', '1', 'Cantón de Nandayure', 'CR.03.3622764', 'ASCII:Canton de Nandayure;ID:3622764', '14164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14164', '112', '16041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3622764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16042', '1079', '1', 'Cantón de Moravia', 'CR.08.3622800', 'ASCII:Canton de Moravia;ID:3622800', '14165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14165', '112', '16042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3622800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16043', '1079', '1', 'Cantón de Mora', 'CR.08.3622808', 'ASCII:Canton de Mora;ID:3622808', '14166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14166', '112', '16043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3622808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16044', '1079', '1', 'Cantón de Montes de Oro', 'CR.07.3622813', 'ASCII:Canton de Montes de Oro;ID:3622813', '14167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14167', '112', '16044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.07.3622813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16045', '1079', '1', 'Cantón de Montes de Oca', 'CR.08.3622814', 'ASCII:Canton de Montes de Oca;ID:3622814', '14168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14168', '112', '16045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3622814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16046', '1079', '1', 'Cantón de Matina', 'CR.06.3622893', 'ASCII:Canton de Matina;ID:3622893', '14169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14169', '112', '16046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.06.3622893» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16047', '1079', '1', 'Cantón de Los Chiles', 'CR.01.3623007', 'ASCII:Canton de Los Chiles;ID:3623007', '14170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14170', '112', '16047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3623007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16048', '1079', '1', 'Cantón Central de Limón', 'CR.06.3623065', 'ASCII:Canton Central de Limon;ID:3623065', '14171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14171', '112', '16048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.06.3623065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16049', '1079', '1', 'Cantón Central de Liberia', 'CR.03.3623075', 'ASCII:Canton Central de Liberia;ID:3623075', '14172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14172', '112', '16049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3623075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16050', '1079', '1', 'Cantón de León Cortés', 'CR.08.3623082', 'ASCII:Canton de Leon Cortes;ID:3623082', '14173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14173', '112', '16050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3623082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16051', '1079', '1', 'Cantón de La Unión', 'CR.02.3623105', 'ASCII:Canton de La Union;ID:3623105', '14174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14174', '112', '16051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.02.3623105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16052', '1079', '1', 'Cantón de La Cruz', 'CR.03.3623257', 'ASCII:Canton de La Cruz;ID:3623257', '14175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14175', '112', '16052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3623257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16053', '1079', '1', 'Cantón de Jiménez', 'CR.02.3623341', 'ASCII:Canton de Jimenez;ID:3623341', '14176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14176', '112', '16053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.02.3623341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16054', '1079', '1', 'Cantón de Hojancha', 'CR.03.3623453', 'ASCII:Canton de Hojancha;ID:3623453', '14177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14177', '112', '16054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3623453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16055', '1079', '1', 'Cantón Central de Heredia', 'CR.04.3623485', 'ASCII:Canton Central de Heredia;ID:3623485', '14178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14178', '112', '16055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.04.3623485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16056', '1079', '1', 'Cantón de Guatuso', 'CR.01.3623553', 'ASCII:Canton de Guatuso;ID:3623553', '14179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14179', '112', '16056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3623553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16057', '1079', '1', 'Cantón de Guácimo', 'CR.06.3623600', 'ASCII:Canton de Guacimo;ID:3623600', '14180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14180', '112', '16057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.06.3623600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16058', '1079', '1', 'Cantón de Grecia', 'CR.01.3623619', 'ASCII:Canton de Grecia;ID:3623619', '14181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14181', '112', '16058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3623619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16059', '1079', '1', 'Cantón de Golfito', 'CR.07.3623655', 'ASCII:Canton de Golfito;ID:3623655', '14182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14182', '112', '16059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.07.3623655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16060', '1079', '1', 'Cantón de Goicoechea', 'CR.08.3623659', 'ASCII:Canton de Goicoechea;ID:3623659', '14183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14183', '112', '16060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3623659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16061', '1079', '1', 'Cantón de Flores', 'CR.04.3623725', 'ASCII:Canton de Flores;ID:3623725', '14184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14184', '112', '16061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.04.3623725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16062', '1079', '1', 'Cantón de Esparza', 'CR.07.3623780', 'ASCII:Canton de Esparza;ID:3623780', '14185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14185', '112', '16062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.07.3623780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16063', '1079', '1', 'Cantón de Escazú', 'CR.08.3623786', 'ASCII:Canton de Escazu;ID:3623786', '14186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14186', '112', '16063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3623786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16064', '1079', '1', 'Cantón de El Guarco', 'CR.02.3623834', 'ASCII:Canton de El Guarco;ID:3623834', '14187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14187', '112', '16064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.02.3623834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16065', '1079', '1', 'Cantón de Dota', 'CR.08.3623892', 'ASCII:Canton de Dota;ID:3623892', '14188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14188', '112', '16065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3623892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16066', '1079', '1', 'Cantón de Desamparados', 'CR.08.3623933', 'ASCII:Canton de Desamparados;ID:3623933', '14189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14189', '112', '16066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3623933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16067', '1079', '1', 'Cantón de Curridabat', 'CR.08.3623976', 'ASCII:Canton de Curridabat;ID:3623976', '14190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14190', '112', '16067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3623976» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16068', '1079', '1', 'Cantón de Coto Brus', 'CR.07.3624051', 'ASCII:Canton de Coto Brus;ID:3624051', '14191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14191', '112', '16068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.07.3624051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16069', '1079', '1', 'Cantón de Corredores', 'CR.07.3624064', 'ASCII:Canton de Corredores;ID:3624064', '14192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14192', '112', '16069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.07.3624064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16070', '1079', '1', 'Cantón Central de Cartago', 'CR.02.3624369', 'ASCII:Canton Central de Cartago;ID:3624369', '14193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14193', '112', '16070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.02.3624369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16071', '1079', '1', 'Cantón de Carrillo', 'CR.03.3624381', 'ASCII:Canton de Carrillo;ID:3624381', '14194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14194', '112', '16071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3624381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16072', '1079', '1', 'Cantón de Cañas', 'CR.03.3624467', 'ASCII:Canton de Canas;ID:3624467', '14195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14195', '112', '16072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3624467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16073', '1079', '1', 'Cantón de Buenos Aires', 'CR.07.3624586', 'ASCII:Canton de Buenos Aires;ID:3624586', '14196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14196', '112', '16073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.07.3624586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16074', '1079', '1', 'Cantón de Belén', 'CR.04.3624717', 'ASCII:Canton de Belen;ID:3624717', '14197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14197', '112', '16074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.04.3624717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16075', '1079', '1', 'Cantón de Barva', 'CR.04.3624732', 'ASCII:Canton de Barva;ID:3624732', '14198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14198', '112', '16075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.04.3624732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16076', '1079', '1', 'Cantón de Bagaces', 'CR.03.3624821', 'ASCII:Canton de Bagaces;ID:3624821', '14199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14199', '112', '16076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3624821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16077', '1079', '1', 'Cantón de Atenas', 'CR.01.3624841', 'ASCII:Canton de Atenas;ID:3624841', '14200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14200', '112', '16077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3624841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16078', '1079', '1', 'Cantón de Aserrí', 'CR.08.3624847', 'ASCII:Canton de Aserri;ID:3624847', '14201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14201', '112', '16078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3624847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16079', '1079', '1', 'Cantón de Alvarado', 'CR.02.3624924', 'ASCII:Canton de Alvarado;ID:3624924', '14202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14202', '112', '16079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.02.3624924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16080', '1079', '1', 'Cantón de Alfaro Ruiz', 'CR.01.3624942', 'ASCII:Canton de Alfaro Ruiz;ID:3624942', '14203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14203', '112', '16080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3624942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16081', '1079', '1', 'Cantón de Alajuelita', 'CR.08.3624950', 'ASCII:Canton de Alajuelita;ID:3624950', '14204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14204', '112', '16081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3624950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16082', '1079', '1', 'Cantón Central de Alajuela', 'CR.01.3624954', 'ASCII:Canton Central de Alajuela;ID:3624954', '14205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14205', '112', '16082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.01.3624954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16083', '1079', '1', 'Cantón de Aguirre', 'CR.07.3624970', 'ASCII:Canton de Aguirre;ID:3624970', '14206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14206', '112', '16083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.07.3624970» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16084', '1079', '1', 'Cantón de Acosta', 'CR.08.3625011', 'ASCII:Canton de Acosta;ID:3625011', '14207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14207', '112', '16084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.08.3625011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16085', '1079', '1', 'Cantón de Abangares', 'CR.03.3625024', 'ASCII:Canton de Abangares;ID:3625024', '14208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14208', '112', '16085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CR.03.3625024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16086', '1079', '1', 'Municipio de Zulueta', 'CU.16.3533524', 'ASCII:Municipio de Zulueta;ID:3533524', '14209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14209', '112', '16086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3533524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16087', '1079', '1', 'Municipio de Yateras', 'CU.10.3533721', 'ASCII:Municipio de Yateras;ID:3533721', '14210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14210', '112', '16087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.10.3533721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16088', '1079', '1', 'Municipio de Yaguajay', 'CU.14.3533822', 'ASCII:Municipio de Yaguajay;ID:3533822', '14211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14211', '112', '16088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.14.3533822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16089', '1079', '1', 'Municipio de Viñales', 'CU.01.3534093', 'ASCII:Municipio de Vinales;ID:3534093', '14212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14212', '112', '16089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.01.3534093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16090', '1079', '1', 'Municipio de Unión de Reyes', 'CU.03.3534760', 'ASCII:Municipio de Union de Reyes;ID:3534760', '14213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14213', '112', '16090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3534760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16091', '1079', '1', 'Municipio de Trinidad', 'CU.14.3534905', 'ASCII:Municipio de Trinidad;ID:3534905', '14214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14214', '112', '16091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.14.3534905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16092', '1079', '1', 'Municipio de Santo Domingo', 'CU.16.3536629', 'ASCII:Municipio de Santo Domingo;ID:3536629', '14215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14215', '112', '16092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3536629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16093', '1079', '1', 'Municipio de Santiago de las Vegas', 'CU.02.3536723', 'ASCII:Municipio de Santiago de las Vegas;ID:3536723', '14216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14216', '112', '16093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.02.3536723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16094', '1079', '1', 'Municipio de Santiago de Cuba', 'CU.15.3536726', 'ASCII:Municipio de Santiago de Cuba;ID:3536726', '14217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14217', '112', '16094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.15.3536726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16095', '1079', '1', 'Municipio de Santa María del Rosario', 'CU.02.3537298', 'ASCII:Municipio de Santa Maria del Rosario;ID:3537298', '14218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14218', '112', '16095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.02.3537298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16096', '1079', '1', 'Municipio de Santa Isabel de las Lajas', 'CU.08.3537524', 'ASCII:Municipio de Santa Isabel de las Lajas;ID:3537524', '14219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14219', '112', '16096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.08.3537524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16097', '1079', '1', 'Municipio de Santa Cruz del Sur', 'CU.05.3537839', 'ASCII:Municipio de Santa Cruz del Sur;ID:3537839', '14220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14220', '112', '16097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.05.3537839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16098', '1079', '1', 'Municipio de Santa Cruz del Norte', 'CU.11.3537843', 'ASCII:Municipio de Santa Cruz del Norte;ID:3537843', '14221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14221', '112', '16098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3537843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16099', '1079', '1', 'Municipio de Santa Clara', 'CU.16.3537891', 'ASCII:Municipio de Santa Clara;ID:3537891', '14222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14222', '112', '16099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3537891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16100', '1079', '1', 'Municipio de Santa Ana', 'CU.03.3538080', 'ASCII:Municipio de Santa Ana;ID:3538080', '14223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14223', '112', '16100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3538080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16101', '1079', '1', 'Municipio de San Nicolás', 'CU.11.3538748', 'ASCII:Municipio de San Nicolas;ID:3538748', '14224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14224', '112', '16101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3538748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16102', '1079', '1', 'Municipio de San Luis', 'CU.01.3539072', 'ASCII:Municipio de San Luis;ID:3539072', '14225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14225', '112', '16102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.01.3539072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16103', '1079', '1', 'Municipio de San Luis', 'CU.15.3539073', 'ASCII:Municipio de San Luis;ID:3539073', '14226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14226', '112', '16103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.15.3539073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16104', '1079', '1', 'Municipio de San Juan y Martínez', 'CU.01.3539257', 'ASCII:Municipio de San Juan y Martinez;ID:3539257', '14227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14227', '112', '16104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.01.3539257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16105', '1079', '1', 'Municipio de San Juan de los Yeras', 'CU.16.3539282', 'ASCII:Municipio de San Juan de los Yeras;ID:3539282', '14228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14228', '112', '16105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3539282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16106', '1079', '1', 'Municipio de San Juan de los Remedios', 'CU.16.3539285', 'ASCII:Municipio de San Juan de los Remedios;ID:3539285', '14229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14229', '112', '16106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3539285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16107', '1079', '1', 'Municipio de San José de los Ramos', 'CU.03.3539542', 'ASCII:Municipio de San Jose de los Ramos;ID:3539542', '14230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14230', '112', '16107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3539542» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16108', '1079', '1', 'Municipio de San José de las Lajas', 'CU.11.3539559', 'ASCII:Municipio de San Jose de las Lajas;ID:3539559', '14231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14231', '112', '16108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3539559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16109', '1079', '1', 'Municipio de San Fernando de Camarones', 'CU.08.3540450', 'ASCII:Municipio de San Fernando de Camarones;ID:3540450', '14232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14232', '112', '16109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.08.3540450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16110', '1079', '1', 'Municipio de San Diego del Valle', 'CU.16.3540616', 'ASCII:Municipio de San Diego del Valle;ID:3540616', '14233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14233', '112', '16110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3540616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16111', '1079', '1', 'Municipio de Sancti Spíritus', 'CU.14.3540666', 'ASCII:Municipio de Sancti Spiritus;ID:3540666', '14234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14234', '112', '16111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.14.3540666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16112', '1079', '1', 'Municipio de San Cristóbal', 'CU.01.3540673', 'ASCII:Municipio de San Cristobal;ID:3540673', '14235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14235', '112', '16112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.01.3540673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16113', '1079', '1', 'Municipio de San Antonio de los Baños', 'CU.11.3540884', 'ASCII:Municipio de San Antonio de los Banos;ID:3540884', '14236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14236', '112', '16113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3540884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16114', '1079', '1', 'Municipio de San Antonio de las Vueltas', 'CU.16.3540887', 'ASCII:Municipio de San Antonio de las Vueltas;ID:3540887', '14237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14237', '112', '16114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3540887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16115', '1079', '1', 'Municipio de San Antonio de las Vegas', 'CU.11.3540889', 'ASCII:Municipio de San Antonio de las Vegas;ID:3540889', '14238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14238', '112', '16115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3540889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16116', '1079', '1', 'Municipio de San Antonio de Cabezas', 'CU.11.3540900', 'ASCII:Municipio de San Antonio de Cabezas;ID:3540900', '14239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14239', '112', '16116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3540900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16117', '1079', '1', 'Municipio de Sagua la Grande', 'CU.16.3541437', 'ASCII:Municipio de Sagua la Grande;ID:3541437', '14240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14240', '112', '16117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3541437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16118', '1079', '1', 'Municipio de Sagua de Tánamo', 'CU.13.3541444', 'ASCII:Municipio de Sagua de Tanamo;ID:3541444', '14241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14241', '112', '16118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.13.3541444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16119', '1079', '1', 'Municipio de Rodas', 'CU.08.3541997', 'ASCII:Municipio de Rodas;ID:3541997', '14242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14242', '112', '16119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.08.3541997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16120', '1079', '1', 'Municipio de Regla', 'CU.02.3542500', 'ASCII:Municipio de Regla;ID:3542500', '14243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14243', '112', '16120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.02.3542500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16121', '1079', '1', 'Municipio de Ranchuelo', 'CU.16.3542741', 'ASCII:Municipio de Ranchuelo;ID:3542741', '14244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14244', '112', '16121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3542741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16122', '1079', '1', 'Municipio de Rancho Veloz', 'CU.16.3542752', 'ASCII:Municipio de Rancho Veloz;ID:3542752', '14245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14245', '112', '16122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3542752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16123', '1079', '1', 'Municipio de Quivicán', 'CU.11.3542963', 'ASCII:Municipio de Quivican;ID:3542963', '14246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14246', '112', '16123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3542963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16124', '1079', '1', 'Municipio de Quemado de Güines', 'CU.16.3543076', 'ASCII:Municipio de Quemado de Guines;ID:3543076', '14247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14247', '112', '16124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3543076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16125', '1079', '1', 'Municipio de Puerto Padre', 'CU.13.3543297', 'ASCII:Municipio de Puerto Padre;ID:3543297', '14248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14248', '112', '16125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.13.3543297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16126', '1079', '1', 'Municipio de Placetas', 'CU.16.3543960', 'ASCII:Municipio de Placetas;ID:3543960', '14249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14249', '112', '16126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3543960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16127', '1079', '1', 'Municipio de Pinar del Río', 'CU.01.3544089', 'ASCII:Municipio de Pinar del Rio;ID:3544089', '14250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14250', '112', '16127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.01.3544089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16128', '1079', '1', 'Municipio de Perico', 'CU.03.3544391', 'ASCII:Municipio de Perico;ID:3544391', '14251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14251', '112', '16128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3544391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16129', '1079', '1', 'Municipio de Pedro Betancourt', 'CU.03.3544606', 'ASCII:Municipio de Pedro Betancourt;ID:3544606', '14252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14252', '112', '16129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3544606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16130', '1079', '1', 'Municipio de Palmira', 'CU.08.3545037', 'ASCII:Municipio de Palmira;ID:3545037', '14253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14253', '112', '16130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.08.3545037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16131', '1079', '1', 'Municipio de Palma Soriano', 'CU.15.3545062', 'ASCII:Municipio de Palma Soriano;ID:3545062', '14254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14254', '112', '16131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.15.3545062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16132', '1079', '1', 'Municipio de Nuevitas', 'CU.05.3545838', 'ASCII:Municipio de Nuevitas;ID:3545838', '14255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14255', '112', '16132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.05.3545838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16133', '1079', '1', 'Municipio de Nueva Paz', 'CU.11.3545853', 'ASCII:Municipio de Nueva Paz;ID:3545853', '14256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14256', '112', '16133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3545853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16134', '1079', '1', 'Municipio de Niquero', 'CU.09.3545978', 'ASCII:Municipio de Niquero;ID:3545978', '14257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14257', '112', '16134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.09.3545978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16135', '1079', '1', 'Municipio de Morón', 'CU.07.3546433', 'ASCII:Municipio de Moron;ID:3546433', '14258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14258', '112', '16135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.07.3546433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16136', '1079', '1', 'Municipio de Melena del Sur', 'CU.11.3547180', 'ASCII:Municipio de Melena del Sur;ID:3547180', '14259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14259', '112', '16136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3547180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16137', '1079', '1', 'Municipio de Mayarí', 'CU.12.3547315', 'ASCII:Municipio de Mayari;ID:3547315', '14260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14260', '112', '16137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.12.3547315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16138', '1079', '1', 'Municipio de Máximo Gómez', 'CU.03.3547342', 'ASCII:Municipio de Maximo Gomez;ID:3547342', '14261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14261', '112', '16138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3547342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16139', '1079', '1', 'Municipio de Matanzas', 'CU.03.3547395', 'ASCII:Municipio de Matanzas;ID:3547395', '14262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14262', '112', '16139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3547395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16140', '1079', '1', 'Municipio de Martí', 'CU.03.3547517', 'ASCII:Municipio de Marti;ID:3547517', '14263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14263', '112', '16140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3547517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16141', '1079', '1', 'Municipio de Mariel', 'CU.11.3547597', 'ASCII:Municipio de Mariel;ID:3547597', '14264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14264', '112', '16141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3547597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16142', '1079', '1', 'Municipio de Marianao', 'CU.02.3547639', 'ASCII:Municipio de Marianao;ID:3547639', '14265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14265', '112', '16142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.02.3547639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16143', '1079', '1', 'Municipio de Manzanillo', 'CU.09.3547864', 'ASCII:Municipio de Manzanillo;ID:3547864', '14266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14266', '112', '16143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.09.3547864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16144', '1079', '1', 'Municipio de Mantua', 'CU.01.3547929', 'ASCII:Municipio de Mantua;ID:3547929', '14267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14267', '112', '16144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.01.3547929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16145', '1079', '1', 'Municipio de Manguito', 'CU.03.3547990', 'ASCII:Municipio de Manguito;ID:3547990', '14268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14268', '112', '16145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3547990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16146', '1079', '1', 'Municipio de Madruga', 'CU.11.3548528', 'ASCII:Municipio de Madruga;ID:3548528', '14269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14269', '112', '16146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3548528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16147', '1079', '1', 'Municipio de Los Palacios', 'CU.01.3548992', 'ASCII:Municipio de Los Palacios;ID:3548992', '14270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14270', '112', '16147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.01.3548992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16148', '1079', '1', 'Municipio de Los Arabos', 'CU.03.3549462', 'ASCII:Municipio de Los Arabos;ID:3549462', '14271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14271', '112', '16148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3549462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16149', '1079', '1', 'Limonar', 'CU.03.3549839', 'ASCII:Limonar;ID:3549839', '14272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14272', '112', '16149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3549839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16150', '1079', '1', 'Municipio de Las Tunas', 'CU.13.3550596', 'ASCII:Municipio de Las Tunas;ID:3550596', '14273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14273', '112', '16150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.13.3550596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16151', '1079', '1', 'Municipio de La Salud', 'CU.11.3551606', 'ASCII:Municipio de La Salud;ID:3551606', '14274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14274', '112', '16151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3551606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16152', '1079', '1', 'Municipio de La Palma', 'CU.01.3552311', 'ASCII:Municipio de La Palma;ID:3552311', '14275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14275', '112', '16152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.01.3552311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16153', '1079', '1', 'Municipio de La Esperanza', 'CU.16.3554062', 'ASCII:Municipio de La Esperanza;ID:3554062', '14276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14276', '112', '16153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3554062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16154', '1079', '1', 'Municipio de Juan Gualberto Gómez', 'CU.03.3555835', 'ASCII:Municipio de Juan Gualberto Gomez;ID:3555835', '14277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14277', '112', '16154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3555835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16155', '1079', '1', 'Municipio de Jovellanos', 'CU.03.3555906', 'ASCII:Municipio de Jovellanos;ID:3555906', '14278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14278', '112', '16155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3555906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16156', '1079', '1', 'Municipio de Jiguaní', 'CU.09.3556166', 'ASCII:Municipio de Jiguani;ID:3556166', '14279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14279', '112', '16156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.09.3556166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16157', '1079', '1', 'Municipio de Jatibonico', 'CU.14.3556333', 'ASCII:Municipio de Jatibonico;ID:3556333', '14280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14280', '112', '16157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.14.3556333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16158', '1079', '1', 'Municipio de Jaruco', 'CU.11.3556347', 'ASCII:Municipio de Jaruco;ID:3556347', '14281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14281', '112', '16158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3556347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16159', '1079', '1', 'Municipio de Jagüey Grande', 'CU.03.3556436', 'ASCII:Municipio de Jaguey Grande;ID:3556436', '14282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14282', '112', '16159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3556436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16160', '1079', '1', 'Municipio de Holguín', 'CU.12.3556966', 'ASCII:Municipio de Holguin;ID:3556966', '14283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14283', '112', '16160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.12.3556966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16161', '1079', '1', 'Municipio de Güira de Melena', 'CU.11.3557346', 'ASCII:Municipio de Guira de Melena;ID:3557346', '14284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14284', '112', '16161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3557346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16162', '1079', '1', 'Municipio de Güines', 'CU.11.3557376', 'ASCII:Municipio de Guines;ID:3557376', '14285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14285', '112', '16162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3557376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16163', '1079', '1', 'Municipio de Guantánamo', 'CU.10.3557686', 'ASCII:Municipio de Guantanamo;ID:3557686', '14286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14286', '112', '16163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.10.3557686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16164', '1079', '1', 'Municipio de Guane', 'CU.01.3557756', 'ASCII:Municipio de Guane;ID:3557756', '14287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14287', '112', '16164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.01.3557756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16165', '1079', '1', 'Municipio de Guanajay', 'CU.11.3557800', 'ASCII:Municipio de Guanajay;ID:3557800', '14288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14288', '112', '16165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3557800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16166', '1079', '1', 'Municipio de Guanabacoa', 'CU.02.3557845', 'ASCII:Municipio de Guanabacoa;ID:3557845', '14289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14289', '112', '16166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.02.3557845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16167', '1079', '1', 'Municipio de Guamacaro', 'CU.03.3557868', 'ASCII:Municipio de Guamacaro;ID:3557868', '14290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14290', '112', '16167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3557868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16168', '1079', '1', 'Municipio de Guáimaro', 'CU.05.3557921', 'ASCII:Municipio de Guaimaro;ID:3557921', '14291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14291', '112', '16168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.05.3557921» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16169', '1079', '1', 'Municipio de Gibara', 'CU.12.3558314', 'ASCII:Municipio de Gibara;ID:3558314', '14292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14292', '112', '16169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.12.3558314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16170', '1079', '1', 'Municipio de Fomento', 'CU.14.3558742', 'ASCII:Municipio de Fomento;ID:3558742', '14293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14293', '112', '16170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.14.3558742» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16171', '1079', '1', 'Municipio de Florida', 'CU.05.3558766', 'ASCII:Municipio de Florida;ID:3558766', '14294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14294', '112', '16171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.05.3558766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16172', '1079', '1', 'Municipio de Esmeralda', 'CU.05.3559316', 'ASCII:Municipio de Esmeralda;ID:3559316', '14295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14295', '112', '16172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.05.3559316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16173', '1079', '1', 'Municipio de Encrucijada', 'CU.16.3559414', 'ASCII:Municipio de Encrucijada;ID:3559414', '14296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14296', '112', '16173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3559414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16174', '1079', '1', 'Municipio de El Cobre', 'CU.15.3561407', 'ASCII:Municipio de El Cobre;ID:3561407', '14297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14297', '112', '16174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.15.3561407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16175', '1079', '1', 'Municipio de El Caney', 'CU.15.3561666', 'ASCII:Municipio de El Caney;ID:3561666', '14298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14298', '112', '16175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.15.3561666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16176', '1079', '1', 'Municipio de Cruces', 'CU.08.3563143', 'ASCII:Municipio de Cruces;ID:3563143', '14299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14299', '112', '16176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.08.3563143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16177', '1079', '1', 'Municipio de Corralillo', 'CU.03.3563312', 'ASCII:Municipio de Corralillo;ID:3563312', '14300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14300', '112', '16177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3563312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16178', '1079', '1', 'Municipio de Consolación del Sur', 'CU.01.3563558', 'ASCII:Municipio de Consolacion del Sur;ID:3563558', '14301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14301', '112', '16178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.01.3563558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16179', '1079', '1', 'Municipio de Colón', 'CU.03.3563841', 'ASCII:Municipio de Colon;ID:3563841', '14302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14302', '112', '16179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3563841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16180', '1079', '1', 'Municipio de Cifuentes', 'CU.16.3564113', 'ASCII:Municipio de Cifuentes;ID:3564113', '14303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14303', '112', '16180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3564113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16181', '1079', '1', 'Municipio de Cienfuegos', 'CU.08.3564121', 'ASCII:Municipio de Cienfuegos;ID:3564121', '14304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14304', '112', '16181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.08.3564121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16182', '1079', '1', 'Municipio de Ciego de Ávila', 'CU.07.3564176', 'ASCII:Municipio de Ciego de Avila;ID:3564176', '14305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14305', '112', '16182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.07.3564176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16183', '1079', '1', 'Municipio de Carlos Rojas', 'CU.03.3565316', 'ASCII:Municipio de Carlos Rojas;ID:3565316', '14306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14306', '112', '16183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3565316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16184', '1079', '1', 'Municipio de Cárdenas', 'CU.03.3565430', 'ASCII:Municipio de Cardenas;ID:3565430', '14307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14307', '112', '16184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3565430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16185', '1079', '1', 'Municipio de Candelaria', 'CU.04.3565758', 'ASCII:Municipio de Candelaria;ID:3565758', '14308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14308', '112', '16185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.04.3565758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16186', '1079', '1', 'Municipio de Campechuela', 'CU.09.3565950', 'ASCII:Municipio de Campechuela;ID:3565950', '14309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14309', '112', '16186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.09.3565950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16187', '1079', '1', 'Municipio de Camajuaní', 'CU.16.3566053', 'ASCII:Municipio de Camajuani;ID:3566053', '14310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14310', '112', '16187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3566053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16188', '1079', '1', 'Municipio de Camagüey', 'CU.05.3566063', 'ASCII:Municipio de Camaguey;ID:3566063', '14311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14311', '112', '16188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.05.3566063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16189', '1079', '1', 'Municipio de Calabazar de Sagua', 'CU.16.3566234', 'ASCII:Municipio de Calabazar de Sagua;ID:3566234', '14312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14312', '112', '16189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3566234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16190', '1079', '1', 'Municipio de Caimito del Guayabal', 'CU.11.3566283', 'ASCII:Municipio de Caimito del Guayabal;ID:3566283', '14313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14313', '112', '16190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3566283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16191', '1079', '1', 'Municipio de Caibarién', 'CU.16.3566354', 'ASCII:Municipio de Caibarien;ID:3566354', '14314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14314', '112', '16191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.16.3566354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16192', '1079', '1', 'Municipio de Cabañas', 'CU.11.3566569', 'ASCII:Municipio de Cabanas;ID:3566569', '14315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14315', '112', '16192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3566569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16193', '1079', '1', 'Municipio de Cabaiguán', 'CU.14.3566602', 'ASCII:Municipio de Cabaiguan;ID:3566602', '14316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14316', '112', '16193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.14.3566602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16194', '1079', '1', 'Municipio de Bolondrón', 'CU.03.3567080', 'ASCII:Municipio de Bolondron;ID:3567080', '14317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14317', '112', '16194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3567080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16195', '1079', '1', 'Municipio de Bejucal', 'CU.02.3567544', 'ASCII:Municipio de Bejucal;ID:3567544', '14318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14318', '112', '16195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.02.3567544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16196', '1079', '1', 'Municipio de Bayamo', 'CU.09.3567595', 'ASCII:Municipio de Bayamo;ID:3567595', '14319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14319', '112', '16196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.09.3567595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16197', '1079', '1', 'Municipio de Bauta', 'CU.11.3567611', 'ASCII:Municipio de Bauta;ID:3567611', '14320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14320', '112', '16197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3567611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16198', '1079', '1', 'Municipio de Batabanó', 'CU.11.3567653', 'ASCII:Municipio de Batabano;ID:3567653', '14321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14321', '112', '16198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3567653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16199', '1079', '1', 'Municipio de Baracoa', 'CU.10.3567831', 'ASCII:Municipio de Baracoa;ID:3567831', '14322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14322', '112', '16199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.10.3567831» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16200', '1079', '1', 'Municipio de Banes', 'CU.12.3567863', 'ASCII:Municipio de Banes;ID:3567863', '14323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14323', '112', '16200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.12.3567863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16201', '1079', '1', 'Municipio de Artemisa', 'CU.11.3568311', 'ASCII:Municipio de Artemisa;ID:3568311', '14324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14324', '112', '16201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3568311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16202', '1079', '1', 'Municipio de Arcos de Canasí', 'CU.11.3568590', 'ASCII:Municipio de Arcos de Canasi;ID:3568590', '14325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14325', '112', '16202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3568590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16203', '1079', '1', 'Municipio de Antilla', 'CU.12.3568725', 'ASCII:Municipio de Antilla;ID:3568725', '14326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14326', '112', '16203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.12.3568725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16204', '1079', '1', 'Municipio de Alto Songo', 'CU.15.3569067', 'ASCII:Municipio de Alto Songo;ID:3569067', '14327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14327', '112', '16204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.15.3569067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16205', '1079', '1', 'Municipio de Alquízar', 'CU.11.3569135', 'ASCII:Municipio de Alquizar;ID:3569135', '14328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14328', '112', '16205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3569135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16206', '1079', '1', 'Municipio de Alacranes', 'CU.03.3569376', 'ASCII:Municipio de Alacranes;ID:3569376', '14329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14329', '112', '16206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3569376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16207', '1079', '1', 'Municipio de Aguada de Pasajeros', 'CU.08.3569544', 'ASCII:Municipio de Aguada de Pasajeros;ID:3569544', '14330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14330', '112', '16207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.08.3569544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16208', '1079', '1', 'Municipio de Aguacate', 'CU.11.3569579', 'ASCII:Municipio de Aguacate;ID:3569579', '14331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14331', '112', '16208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.11.3569579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16209', '1079', '1', 'Municipio de Agramonte', 'CU.03.3569644', 'ASCII:Municipio de Agramonte;ID:3569644', '14332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14332', '112', '16209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.03.3569644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16210', '1079', '1', 'Municipio de Abreus', 'CU.08.3569740', 'ASCII:Municipio de Abreus;ID:3569740', '14333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14333', '112', '16210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CU.08.3569740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16211', '1079', '1', 'Okres Znojmo', 'CZ.78.0627', 'ASCII:Okres Znojmo;ID:3061343', '14334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14334', '112', '16211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.78.0627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16212', '1079', '1', 'Okres Žďár nad Sázavou', 'CZ.80.0615', 'ASCII:Okres Zd''ar nad Sazavou;ID:3061694', '14335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14335', '112', '16212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.80.0615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16213', '1079', '1', 'Okres Vyškov', 'CZ.78.0626', 'ASCII:Okres Vyskov;ID:3062280', '14336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14336', '112', '16213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.78.0626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16214', '1079', '1', 'Okres Vsetín', 'CZ.90.0723', 'ASCII:Okres Vsetin;ID:3062338', '14337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14337', '112', '16214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.90.0723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16215', '1079', '1', 'Okres Ústí nad Orlicí', 'CZ.86.0534', 'ASCII:Okres Usti nad Orlici;ID:3063545', '14338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14338', '112', '16215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.86.0534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16216', '1079', '1', 'Okres Ústí nad Labem', 'CZ.89.0427', 'ASCII:Okres Usti nad Labem;ID:3063547', '14339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14339', '112', '16216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.89.0427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16217', '1079', '1', 'Okres Uherské Hradiště', 'CZ.90.0722', 'ASCII:Okres Uherske Hradiste;ID:3063738', '14340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14340', '112', '16217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.90.0722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16218', '1079', '1', 'Okres Trutnov', 'CZ.82.0525', 'ASCII:Okres Trutnov;ID:3063906', '14341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14341', '112', '16218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.82.0525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16219', '1079', '1', 'Okres Třebíč', 'CZ.80.0614', 'ASCII:Okres Trebic;ID:3064103', '14342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14342', '112', '16219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.80.0614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16220', '1079', '1', 'Okres Teplice', 'CZ.89.0426', 'ASCII:Okres Teplice;ID:3064287', '14343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14343', '112', '16220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.89.0426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16221', '1079', '1', 'Okres Tachov', 'CZ.87.0327', 'ASCII:Okres Tachov;ID:3064370', '14344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14344', '112', '16221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.87.0327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16222', '1079', '1', 'Okres Tábor', 'CZ.79.0317', 'ASCII:Okres Tabor;ID:3064377', '14345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14345', '112', '16222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.79.0317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16223', '1079', '1', 'Okres Svitavy', 'CZ.86.0533', 'ASCII:Okres Svitavy;ID:3064453', '14346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14346', '112', '16223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.86.0533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16224', '1079', '1', 'Okres Šumperk', 'CZ.84.0715', 'ASCII:Okres Sumperk;ID:3064672', '14347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14347', '112', '16224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.84.0715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16225', '1079', '1', 'Okres Strakonice', 'CZ.79.0316', 'ASCII:Okres Strakonice;ID:3065066', '14348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14348', '112', '16225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.79.0316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16226', '1079', '1', 'Okres Sokolov', 'CZ.81.0413', 'ASCII:Okres Sokolov;ID:3065616', '14349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14349', '112', '16226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.81.0413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16227', '1079', '1', 'Okres Semily', 'CZ.83.0514', 'ASCII:Okres Semily;ID:3066219', '14350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14350', '112', '16227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.83.0514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16228', '1079', '1', 'Okres Rychnov nad Kněžnou', 'CZ.82.0524', 'ASCII:Okres Rychnov nad Kneznou;ID:3066502', '14351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14351', '112', '16228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.82.0524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16229', '1079', '1', 'Okres Rokycany', 'CZ.87.0326', 'ASCII:Okres Rokycany;ID:3066793', '14352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14352', '112', '16229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.87.0326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16230', '1079', '1', 'Okres Rakovník', 'CZ.88.020C', 'ASCII:Okres Rakovnik;ID:3067050', '14353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14353', '112', '16230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.020C» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16231', '1079', '1', 'Okres Prostějov', 'CZ.84.0713', 'ASCII:Okres Prostejov;ID:3067420', '14354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14354', '112', '16231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.84.0713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16232', '1079', '1', 'Okres Příbram', 'CZ.88.020B', 'ASCII:Okres Pribram;ID:3067540', '14355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14355', '112', '16232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.020B» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16233', '1079', '1', 'Okres Přerov', 'CZ.84.0714', 'ASCII:Okres Prerov;ID:3067578', '14356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14356', '112', '16233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.84.0714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16234', '1079', '1', 'Okres Praha-Západ', 'CZ.88.020A', 'ASCII:Okres Praha-Zapad;ID:3067692', '14357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14357', '112', '16234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.020A» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16235', '1079', '1', 'Okres Praha-Východ', 'CZ.88.0209', 'ASCII:Okres Praha-Vychod;ID:3067693', '14358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14358', '112', '16235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.0209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16236', '1079', '1', 'Okres Prachatice', 'CZ.79.0315', 'ASCII:Okres Prachatice;ID:3067712', '14359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14359', '112', '16236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.79.0315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16237', '1079', '1', 'Okres Plzeň-Sever', 'CZ.87.0325', 'ASCII:Okres Plzen-Sever;ID:3068157', '14360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14360', '112', '16237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.87.0325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16238', '1079', '1', 'Okres Plzeň-Město', 'CZ.87.0323', 'ASCII:Okres Plzen-Mesto;ID:3068158', '14361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14361', '112', '16238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.87.0323» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16239', '1079', '1', 'Okres Plzeň-Jih', 'CZ.87.0324', 'ASCII:Okres Plzen-Jih;ID:3068159', '14362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14362', '112', '16239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.87.0324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16240', '1079', '1', 'Okres Písek', 'CZ.79.0314', 'ASCII:Okres Pisek;ID:3068289', '14363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14363', '112', '16240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.79.0314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16241', '1079', '1', 'Okres Pelhřimov', 'CZ.80.0613', 'ASCII:Okres Pelhrimov;ID:3068444', '14364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14364', '112', '16241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.80.0613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16242', '1079', '1', 'Okres Pardubice', 'CZ.86.0532', 'ASCII:Okres Pardubice;ID:3068581', '14365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14365', '112', '16242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.86.0532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16243', '1079', '1', 'Okres Ostrava-Město', 'CZ.85.0806', 'ASCII:Okres Ostrava-Mesto;ID:3068798', '14366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14366', '112', '16243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.85.0806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16244', '1079', '1', 'Okres Opava', 'CZ.85.0805', 'ASCII:Okres Opava;ID:3068925', '14367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14367', '112', '16244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.85.0805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16245', '1079', '1', 'Okres Olomouc', 'CZ.84.0712', 'ASCII:Okres Olomouc;ID:3069010', '14368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14368', '112', '16245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.84.0712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16246', '1079', '1', 'Okres Nymburk', 'CZ.88.0208', 'ASCII:Okres Nymburk;ID:3069235', '14369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14369', '112', '16246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.0208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16247', '1079', '1', 'Okres Nový Jičín', 'CZ.85.0804', 'ASCII:Okres Novy Jicin;ID:3069304', '14370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14370', '112', '16247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.85.0804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16248', '1079', '1', 'Okres Náchod', 'CZ.82.0523', 'ASCII:Okres Nachod;ID:3070121', '14371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14371', '112', '16248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.82.0523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16249', '1079', '1', 'Okres Most', 'CZ.89.0425', 'ASCII:Okres Most;ID:3070290', '14372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14372', '112', '16249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.89.0425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16250', '1079', '1', 'Okres Mladá Boleslav', 'CZ.88.0207', 'ASCII:Okres Mlada Boleslav;ID:3070543', '14373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14373', '112', '16250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.0207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16251', '1079', '1', 'Okres Mělník', 'CZ.88.0206', 'ASCII:Okres Melnik;ID:3070861', '14374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14374', '112', '16251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.0206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16252', '1079', '1', 'Okres Louny', 'CZ.89.0424', 'ASCII:Okres Louny;ID:3071506', '14375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14375', '112', '16252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.89.0424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16253', '1079', '1', 'Okres Litoměřice', 'CZ.89.0423', 'ASCII:Okres Litomerice;ID:3071676', '14376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14376', '112', '16253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.89.0423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16254', '1079', '1', 'Okres Liberec', 'CZ.83.0513', 'ASCII:Okres Liberec;ID:3071960', '14377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14377', '112', '16254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.83.0513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16255', '1079', '1', 'Okres Kutná Hora', 'CZ.88.0205', 'ASCII:Okres Kutna Hora;ID:3072462', '14378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14378', '112', '16255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.0205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16256', '1079', '1', 'Okres Kroměříž', 'CZ.90.0721', 'ASCII:Okres Kromeriz;ID:3072648', '14379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14379', '112', '16256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.90.0721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16257', '1079', '1', 'Okres Kolín', 'CZ.88.0204', 'ASCII:Okres Kolin;ID:3073370', '14380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14380', '112', '16257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.0204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16258', '1079', '1', 'Okres Klatovy', 'CZ.87.0322', 'ASCII:Okres Klatovy;ID:3073659', '14381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14381', '112', '16258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.87.0322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16259', '1079', '1', 'Okres Kladno', 'CZ.88.0203', 'ASCII:Okres Kladno;ID:3073698', '14382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14382', '112', '16259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.0203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16260', '1079', '1', 'Okres Karviná', 'CZ.85.0803', 'ASCII:Okres Karvina;ID:3073790', '14383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14383', '112', '16260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.85.0803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16261', '1079', '1', 'Okres Karlovy Vary', 'CZ.81.0412', 'ASCII:Okres Karlovy Vary;ID:3073802', '14384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14384', '112', '16261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.81.0412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16262', '1079', '1', 'Okres Jindřichův Hradec', 'CZ.79.0313', 'ASCII:Okres Jindrichuv Hradec;ID:3074148', '14385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14385', '112', '16262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.79.0313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16263', '1079', '1', 'Okres Jihlava', 'CZ.80.0612', 'ASCII:Okres Jihlava;ID:3074197', '14386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14386', '112', '16263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.80.0612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16264', '1079', '1', 'Okres Jičín', 'CZ.82.0522', 'ASCII:Okres Jicin;ID:3074205', '14387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14387', '112', '16264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.82.0522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16265', '1079', '1', 'Okres Jablonec nad Nisou', 'CZ.83.0512', 'ASCII:Okres Jablonec nad Nisou;ID:3074602', '14388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14388', '112', '16265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.83.0512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16266', '1079', '1', 'Okres Hradec Králové', 'CZ.82.0521', 'ASCII:Okres Hradec Kralove;ID:3074966', '14389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14389', '112', '16266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.82.0521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16267', '1079', '1', 'Okres Hodonín', 'CZ.78.0625', 'ASCII:Okres Hodonin;ID:3075651', '14390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14390', '112', '16267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.78.0625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16268', '1079', '1', 'Okres Havlíčkův Brod', 'CZ.80.0611', 'ASCII:Okres Havlickuv Brod;ID:3075918', '14391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14391', '112', '16268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.80.0611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16269', '1079', '1', 'Okres Zlín', 'CZ.90.0724', 'ASCII:Okres Zlin;ID:3076093', '14392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14392', '112', '16269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.90.0724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16270', '1079', '1', 'Okres Frýdek-Místek', 'CZ.85.0802', 'ASCII:Okres Frydek-Mistek;ID:3076125', '14393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14393', '112', '16270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.85.0802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16271', '1079', '1', 'Okres Domažlice', 'CZ.87.0321', 'ASCII:Okres Domazlice;ID:3076586', '14394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14394', '112', '16271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.87.0321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16272', '1079', '1', 'Okres Děčín', 'CZ.89.0421', 'ASCII:Okres Decin;ID:3077243', '14395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14395', '112', '16272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.89.0421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16273', '1079', '1', 'Okres Chrudim', 'CZ.86.0531', 'ASCII:Okres Chrudim;ID:3077538', '14396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14396', '112', '16273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.86.0531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16274', '1079', '1', 'Okres Chomutov', 'CZ.89.0422', 'ASCII:Okres Chomutov;ID:3077684', '14397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14397', '112', '16274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.89.0422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16275', '1079', '1', 'Okres Cheb', 'CZ.81.0411', 'ASCII:Okres Cheb;ID:3077834', '14398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14398', '112', '16275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.81.0411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16276', '1079', '1', 'Okres Český Krumlov', 'CZ.79.0312', 'ASCII:Okres Cesky Krumlov;ID:3077888', '14399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14399', '112', '16276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.79.0312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16277', '1079', '1', 'Okres České Budějovice', 'CZ.79.0311', 'ASCII:Okres Ceske Budejovice;ID:3077915', '14400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14400', '112', '16277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.79.0311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16278', '1079', '1', 'Okres Česká Lípa', 'CZ.83.0511', 'ASCII:Okres Ceska Lipa;ID:3077928', '14401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14401', '112', '16278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.83.0511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16279', '1079', '1', 'Okres Bruntál', 'CZ.85.0801', 'ASCII:Okres Bruntal;ID:3078544', '14402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14402', '112', '16279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.85.0801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16280', '1079', '1', 'Okres Brno-Venkov', 'CZ.78.0623', 'ASCII:Okres Brno-Venkov;ID:3078607', '14403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14403', '112', '16280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.78.0623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16281', '1079', '1', 'Město Brno', 'CZ.78.0622', 'ASCII:Mesto Brno;ID:3078609', '14404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14404', '112', '16281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.78.0622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16282', '1079', '1', 'Okres Břeclav', 'CZ.78.0624', 'ASCII:Okres Breclav;ID:3078772', '14405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14405', '112', '16282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.78.0624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16283', '1079', '1', 'Okres Blansko', 'CZ.78.0621', 'ASCII:Okres Blansko;ID:3079270', '14406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14406', '112', '16283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.78.0621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16284', '1079', '1', 'Okres Beroun', 'CZ.88.0202', 'ASCII:Okres Beroun;ID:3079466', '14407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14407', '112', '16284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.0202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16285', '1079', '1', 'Okres Benešov', 'CZ.88.0201', 'ASCII:Okres Benesov;ID:3079506', '14408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14408', '112', '16285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.88.0201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16286', '1079', '1', 'Okres Jeseník', 'CZ.84.0711', 'ASCII:Okres Jesenik;ID:3337501', '14409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14409', '112', '16286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.84.0711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16287', '1079', '1', 'Okres Praha', 'CZ.52.0100', 'ASCII:Okres Praha;ID:6533385', '14410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14410', '112', '16287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «CZ.52.0100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16288', '1079', '1', 'Regierungsbezirk Unterfranken', 'DE.02.2819564', 'ASCII:Lower Franconia;ID:2819564', '14411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14411', '112', '16288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.02.2819564» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16289', '1079', '1', 'Regierungsbezirk Schwaben', 'DE.02.2835521', 'ASCII:Regierungsbezirk Schwaben;ID:2835521', '14412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14412', '112', '16289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.02.2835521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16290', '1079', '1', 'Regierungsbezirk Oberpfalz', 'DE.02.2859444', 'ASCII:Upper Palatinate;ID:2859444', '14413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14413', '112', '16290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.02.2859444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16291', '1079', '1', 'Regierungsbezirk Oberfranken', 'DE.02.2860681', 'ASCII:Regierungsbezirk Oberfranken;ID:2860681', '14414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14414', '112', '16291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.02.2860681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16292', '1079', '1', 'Regierungsbezirk Oberbayern', 'DE.02.2861322', 'ASCII:Regierungsbezirk Oberbayern;ID:2861322', '14415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14415', '112', '16292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.02.2861322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16293', '1079', '1', 'Regierungsbezirk Niederbayern', 'DE.02.2863622', 'ASCII:Regierungsbezirk Niederbayern;ID:2863622', '14416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14416', '112', '16293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.02.2863622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16294', '1079', '1', 'Regierungsbezirk Münster', 'DE.07.2867539', 'ASCII:Regierungsbezirk Munster;ID:2867539', '14417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14417', '112', '16294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.07.2867539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16295', '1079', '1', 'Regierungsbezirk Mittelfranken', 'DE.02.2870736', 'ASCII:Middle Franconia;ID:2870736', '14418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14418', '112', '16295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.02.2870736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16296', '1079', '1', 'Regierungsbezirk Köln', 'DE.07.2886241', 'ASCII:Regierungsbezirk Koln;ID:2886241', '14419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14419', '112', '16296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.07.2886241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16297', '1079', '1', 'Regierungsbezirk Kassel', 'DE.05.2892513', 'ASCII:Regierungsbezirk Kassel;ID:2892513', '14420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14420', '112', '16297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.05.2892513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16298', '1079', '1', 'Regierungsbezirk Freiburg', 'DE.01.2925180', 'ASCII:Regierungsbezirk Freiburg;ID:2925180', '14421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14421', '112', '16298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.01.2925180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16299', '1079', '1', 'Regierungsbezirk Düsseldorf', 'DE.07.2934245', 'ASCII:Regierungsbezirk Dusseldorf;ID:2934245', '14422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14422', '112', '16299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.07.2934245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16300', '1079', '1', 'Regierungsbezirk Detmold', 'DE.07.2937935', 'ASCII:Regierungsbezirk Detmold;ID:2937935', '14423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14423', '112', '16300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.07.2937935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16301', '1079', '1', 'Regierungsbezirk Darmstadt', 'DE.05.2938912', 'ASCII:Regierungsbezirk Darmstadt;ID:2938912', '14424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14424', '112', '16301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.05.2938912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16302', '1079', '1', 'Regierungsbezirk Arnsberg', 'DE.07.2955470', 'ASCII:Regierungsbezirk Arnsberg;ID:2955470', '14425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14425', '112', '16302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.07.2955470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16303', '1079', '1', 'Regierungsbezirk Karlsruhe', 'DE.01.3214104', 'ASCII:Regierungsbezirk Karlsruhe;ID:3214104', '14426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14426', '112', '16303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.01.3214104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16304', '1079', '1', 'Regierungsbezirk Stuttgart', 'DE.01.3214105', 'ASCII:Regierungsbezirk Stuttgart;ID:3214105', '14427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14427', '112', '16304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.01.3214105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16305', '1079', '1', 'Regierungsbezirk Tübingen', 'DE.01.3214106', 'ASCII:Regierungsbezirk Tubingen;ID:3214106', '14428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14428', '112', '16305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.01.3214106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16306', '1079', '1', 'Regierungsbezirk Gießen', 'DE.05.3220941', 'ASCII:Regierungsbezirk Giessen;ID:3220941', '14429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14429', '112', '16306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.05.3220941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16307', '1079', '1', 'Regierungsbezirk Dresden', 'DE.13.3305799', 'ASCII:Regierungsbezirk Dresden;ID:3305799', '14430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14430', '112', '16307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.13.3305799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16308', '1079', '1', 'Regierungsbezirk Leipzig', 'DE.13.3305800', 'ASCII:Regierungsbezirk Leipzig;ID:3305800', '14431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14431', '112', '16308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.13.3305800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16309', '1079', '1', 'Regierungsbezirk Chemnitz', 'DE.13.3305801', 'ASCII:Regierungsbezirk Chemnitz;ID:3305801', '14432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14432', '112', '16309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.13.3305801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16310', '1079', '1', 'Kreis Nordfriesland', 'DE.10.DE.SH.SH', 'ASCII:Kreis Nordfriesland;ID:6620353', '14433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14433', '112', '16310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DE.10.DE.SH.SH» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16311', '1079', '1', 'Vordingborg Kommune', 'DK.20.390', 'ASCII:Vordingborg Kommune;ID:2610019', '14434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14434', '112', '16311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.390» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16312', '1079', '1', 'Viborg Kommune', 'DK.18.791', 'ASCII:Viborg Kommune;ID:2610315', '14435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14435', '112', '16312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.791» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16313', '1079', '1', 'Vejle Kommune', 'DK.21.630', 'ASCII:Vejle Kommune;ID:2610601', '14436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14436', '112', '16313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16314', '1079', '1', 'Vejen Kommune', 'DK.21.575', 'ASCII:Vejen Kommune;ID:2610631', '14437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14437', '112', '16314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16315', '1079', '1', 'Vallensbæk Kommune', 'DK.17.187', 'ASCII:Vallensbaek Kommune;ID:2610788', '14438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14438', '112', '16315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16316', '1079', '1', 'Tønder Kommune', 'DK.21.550', 'ASCII:Tonder Kommune;ID:2611516', '14439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14439', '112', '16316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16317', '1079', '1', 'Thisted Kommune', 'DK.19.787', 'ASCII:Thisted Kommune;ID:2611753', '14440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14440', '112', '16317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.787» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16318', '1079', '1', 'Tårnby Kommune', 'DK.17.185', 'ASCII:Tarnby Kommune;ID:2611861', '14441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14441', '112', '16318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16319', '1079', '1', 'Svendborg Kommune', 'DK.21.479', 'ASCII:Svendborg Kommune;ID:2612044', '14442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14442', '112', '16319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16320', '1079', '1', 'Struer Kommune', 'DK.18.671', 'ASCII:Struer Kommune;ID:2612202', '14443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14443', '112', '16320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16321', '1079', '1', 'Stevns Kommune', 'DK.20.336', 'ASCII:Stevns Kommune;ID:2612565', '14444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14444', '112', '16321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16322', '1079', '1', 'Sorø Kommune', 'DK.20.340', 'ASCII:Soro Kommune;ID:2612863', '14445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14445', '112', '16322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16323', '1079', '1', 'Sønderborg Kommune', 'DK.21.540', 'ASCII:Sonderborg Kommune;ID:2613221', '14446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14446', '112', '16323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16324', '1079', '1', 'Solrød Kommune', 'DK.20.269', 'ASCII:Solrod Kommune;ID:2613235', '14447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14447', '112', '16324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16325', '1079', '1', 'Slagelse Kommune', 'DK.20.330', 'ASCII:Slagelse Kommune;ID:2613459', '14448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14448', '112', '16325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16326', '1079', '1', 'Skive Kommune', 'DK.18.779', 'ASCII:Skive Kommune;ID:2613729', '14449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14449', '112', '16326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16327', '1079', '1', 'Skanderborg Kommune', 'DK.18.746', 'ASCII:Skanderborg Kommune;ID:2613886', '14450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14450', '112', '16327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.746» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16328', '1079', '1', 'Silkeborg Kommune', 'DK.18.740', 'ASCII:Silkeborg Kommune;ID:2614029', '14451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14451', '112', '16328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16329', '1079', '1', 'Samsø Kommune', 'DK.18.741', 'ASCII:Samso Kommune;ID:2614281', '14452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14452', '112', '16329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16330', '1079', '1', 'Roskilde Kommune', 'DK.20.265', 'ASCII:Roskilde Kommune;ID:2614478', '14453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14453', '112', '16330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16331', '1079', '1', 'Rødovre Kommune', 'DK.17.175', 'ASCII:Rodovre Kommune;ID:2614677', '14454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14454', '112', '16331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16332', '1079', '1', 'Ringsted Kommune', 'DK.20.329', 'ASCII:Ringsted Kommune;ID:2614761', '14455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14455', '112', '16332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16333', '1079', '1', 'Randers Kommune', 'DK.18.730', 'ASCII:Randers Kommune;ID:2615003', '14456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14456', '112', '16333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16334', '1079', '1', 'Odense Kommune', 'DK.21.461', 'ASCII:Odense Kommune;ID:2615872', '14457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14457', '112', '16334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16335', '1079', '1', 'Odder Kommune', 'DK.18.727', 'ASCII:Odder Kommune;ID:2615884', '14458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14458', '112', '16335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.727» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16336', '1079', '1', 'Nyborg Kommune', 'DK.21.450', 'ASCII:Nyborg Kommune;ID:2616011', '14459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14459', '112', '16336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16337', '1079', '1', 'Næstved Kommune', 'DK.20.370', 'ASCII:Naestved Kommune;ID:2616037', '14460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14460', '112', '16337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16338', '1079', '1', 'Morsø Kommune', 'DK.19.773', 'ASCII:Morso Kommune;ID:2616755', '14461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14461', '112', '16338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16339', '1079', '1', 'Middelfart Kommune', 'DK.21.410', 'ASCII:Middelfart Kommune;ID:2616932', '14462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14462', '112', '16339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16340', '1079', '1', 'Lyngby-Tårbæk Kommune', 'DK.17.173', 'ASCII:Lyngby-Tarbaek Kommune;ID:2617227', '14463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14463', '112', '16340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16341', '1079', '1', 'Læso Kommune', 'DK.19.825', 'ASCII:Laeso Kommune;ID:2617382', '14464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14464', '112', '16341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16342', '1079', '1', 'Lemvig Kommune', 'DK.18.665', 'ASCII:Lemvig Kommune;ID:2617811', '14465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14465', '112', '16342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16343', '1079', '1', 'Lejre Kommune', 'DK.20.350', 'ASCII:Lejre Kommune;ID:2617831', '14466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14466', '112', '16343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16344', '1079', '1', 'Københavns Kommune', 'DK.17.101', 'ASCII:Copenhagen municipality;ID:2618424', '14467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14467', '112', '16344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16345', '1079', '1', 'Kolding Kommune', 'DK.21.621', 'ASCII:Kolding Kommune;ID:2618525', '14468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14468', '112', '16345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16346', '1079', '1', 'Køge Kommune', 'DK.20.259', 'ASCII:Koge Kommune;ID:2618557', '14469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14469', '112', '16346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16347', '1079', '1', 'Kerteminde Kommune', 'DK.21.440', 'ASCII:Kerteminde Kommune;ID:2618941', '14470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14470', '112', '16347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16348', '1079', '1', 'Kalundborg Kommune', 'DK.20.326', 'ASCII:Kalundborg Kommune;ID:2619152', '14471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14471', '112', '16348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16349', '1079', '1', 'Ishøj Kommune', 'DK.17.183', 'ASCII:Ishoj Kommune;ID:2619378', '14472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14472', '112', '16349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16350', '1079', '1', 'Hvidovre Kommune', 'DK.17.167', 'ASCII:Hvidovre Kommune;ID:2619527', '14473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14473', '112', '16350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16351', '1079', '1', 'Hørsholm Kommune', 'DK.17.223', 'ASCII:Horsholm Kommune;ID:2619762', '14474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14474', '112', '16351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16352', '1079', '1', 'Horsens Kommune', 'DK.18.615', 'ASCII:Horsens Kommune;ID:2619767', '14475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14475', '112', '16352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16353', '1079', '1', 'Holstebro Kommune', 'DK.18.661', 'ASCII:Holstebro Kommune;ID:2620045', '14476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14476', '112', '16353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16354', '1079', '1', 'Holbæk Kommune', 'DK.20.316', 'ASCII:Holbaek Kommune;ID:2620141', '14477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14477', '112', '16354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16355', '1079', '1', 'Hjørring Kommune', 'DK.19.860', 'ASCII:Hjorring Kommune;ID:2620209', '14478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14478', '112', '16355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16356', '1079', '1', 'Hillerød Kommune', 'DK.17.219', 'ASCII:Hillerod Kommune;ID:2620321', '14479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14479', '112', '16356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16357', '1079', '1', 'Herning Kommune', 'DK.18.657', 'ASCII:Herning Kommune;ID:2620423', '14480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14480', '112', '16357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16358', '1079', '1', 'Herlev Kommune', 'DK.17.163', 'ASCII:Herlev Kommune;ID:2620430', '14481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14481', '112', '16358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16359', '1079', '1', 'Helsingør Kommune', 'DK.17.217', 'ASCII:Helsingor Kommune;ID:2620469', '14482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14482', '112', '16359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16360', '1079', '1', 'Hedensted Kommune', 'DK.18.766', 'ASCII:Hedensted Kommune;ID:2620581', '14483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14483', '112', '16360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16361', '1079', '1', 'Haderslev Kommune', 'DK.21.510', 'ASCII:Haderslev Kommune;ID:2620961', '14484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14484', '112', '16361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16362', '1079', '1', 'Greve Kommune', 'DK.20.253', 'ASCII:Greve Kommune;ID:2621218', '14485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14485', '112', '16362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16363', '1079', '1', 'Glostrup Kommune', 'DK.17.161', 'ASCII:Glostrup Kommune;ID:2621354', '14486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14486', '112', '16363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16364', '1079', '1', 'Gladsakse Kommune', 'DK.17.159', 'ASCII:Gladsakse Kommune;ID:2621394', '14487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14487', '112', '16364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16365', '1079', '1', 'Gentofte Kommune', 'DK.17.157', 'ASCII:Gentofte Kommune;ID:2621514', '14488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14488', '112', '16365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16366', '1079', '1', 'Frederikssund Kommune', 'DK.17.250', 'ASCII:Frederikssund Kommune;ID:2621911', '14489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14489', '112', '16366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16367', '1079', '1', 'Frederikshavn Kommune', 'DK.19.813', 'ASCII:Frederikshavn Kommune;ID:2621926', '14490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14490', '112', '16367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16368', '1079', '1', 'Frederiksberg Kommune', 'DK.17.147', 'ASCII:Frederiksberg Kommune;ID:2621941', '14491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14491', '112', '16368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16369', '1079', '1', 'Fredericia Kommune', 'DK.21.607', 'ASCII:Fredericia Kommune;ID:2621950', '14492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14492', '112', '16369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16370', '1079', '1', 'Fanø Kommune', 'DK.21.563', 'ASCII:Fano Kommune;ID:2622341', '14493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14493', '112', '16370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16371', '1079', '1', 'Varde Kommune', 'DK.21.573', 'ASCII:Varde Kommune;ID:2622446', '14494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14494', '112', '16371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16372', '1079', '1', 'Dragør Kommune', 'DK.17.155', 'ASCII:Dragor Kommune;ID:2622935', '14495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14495', '112', '16372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16373', '1079', '1', 'Brønderslev Kommune', 'DK.19.810', 'ASCII:Bronderslev Kommune;ID:2623351', '14496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14496', '112', '16373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16374', '1079', '1', 'Brøndby Kommune', 'DK.17.153', 'ASCII:Brondby Kommune;ID:2623352', '14497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14497', '112', '16374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16375', '1079', '1', 'Bornholm Kommune', 'DK.17.400', 'ASCII:Bornholm Kommune;ID:2623665', '14498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14498', '112', '16375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16376', '1079', '1', 'Billund Kommune', 'DK.21.530', 'ASCII:Billund Kommune;ID:2624143', '14499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14499', '112', '16376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16377', '1079', '1', 'Ballerup Kommune', 'DK.17.151', 'ASCII:Ballerup Kommune;ID:2624340', '14500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14500', '112', '16377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16378', '1079', '1', 'Assens Kommune', 'DK.21.420', 'ASCII:Assens Kommune;ID:2624500', '14501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14501', '112', '16378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16379', '1079', '1', 'Århus Kommune', 'DK.18.751', 'ASCII:Arhus Kommune;ID:2624647', '14502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14502', '112', '16379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16380', '1079', '1', 'Allerød Kommune', 'DK.17.201', 'ASCII:Allerod Kommune;ID:2624844', '14503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14503', '112', '16380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16381', '1079', '1', 'Albertslund Kommune', 'DK.17.165', 'ASCII:Albertslund Kommune;ID:2624905', '14504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14504', '112', '16381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16382', '1079', '1', 'Åbenrå Kommune', 'DK.21.580', 'ASCII:Abenra Kommune;ID:2625068', '14505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14505', '112', '16382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16383', '1079', '1', 'Jammerbugt Kommune', 'DK.19.849', 'ASCII:Jammerbugt Kommune;ID:6543926', '14506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14506', '112', '16383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16384', '1079', '1', 'Furesø Kommune', 'DK.17.190', 'ASCII:Fureso Kommune;ID:6543927', '14507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14507', '112', '16384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16385', '1079', '1', 'Odsherred Kommune', 'DK.20.306', 'ASCII:Odsherred Kommune;ID:6543928', '14508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14508', '112', '16385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16386', '1079', '1', 'Nordfyns Kommune', 'DK.21.480', 'ASCII:Nordfyns Kommune;ID:6543929', '14509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14509', '112', '16386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16387', '1079', '1', 'Mariagerfjord Kommune', 'DK.19.846', 'ASCII:Mariagerfjord Kommune;ID:6543930', '14510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14510', '112', '16387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16388', '1079', '1', 'Faxe Kommune', 'DK.20.320', 'ASCII:Faxe Kommune;ID:6543931', '14511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14511', '112', '16388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16389', '1079', '1', 'Ringkøbing-Skjern Kommune', 'DK.18.760', 'ASCII:Ringkobing-Skjern Kommune;ID:6543932', '14512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14512', '112', '16389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16390', '1079', '1', 'Norddjurs Kommune', 'DK.18.707', 'ASCII:Norddjurs Kommune;ID:6543933', '14513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14513', '112', '16390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16391', '1079', '1', 'Ålborg Kommune', 'DK.19.851', 'ASCII:Alborg Kommune;ID:6543934', '14514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14514', '112', '16391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16392', '1079', '1', 'Ærø Kommune', 'DK.21.492', 'ASCII:AEro Kommune;ID:6543935', '14515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14515', '112', '16392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16393', '1079', '1', 'Faaborg-Midtfyn Kommune', 'DK.21.430', 'ASCII:Faaborg-Midtfyn Kommune;ID:6543936', '14516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14516', '112', '16393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16394', '1079', '1', 'Rebild Kommune', 'DK.19.840', 'ASCII:Rebild Kommune;ID:6543937', '14517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14517', '112', '16394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16395', '1079', '1', 'Høje-Taastrup Kommune', 'DK.17.169', 'ASCII:Hoje-Taastrup Kommune;ID:6543938', '14518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14518', '112', '16395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16396', '1079', '1', 'Vesthimmerland Kommune', 'DK.19.820', 'ASCII:Vesthimmerland Kommune;ID:6543939', '14519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14519', '112', '16396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.19.820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16397', '1079', '1', 'Fredensborg Kommune', 'DK.17.210', 'ASCII:Fredensborg Kommune;ID:6543940', '14520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14520', '112', '16397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16398', '1079', '1', 'Frederiksværk-Hundested Kommune', 'DK.17.260', 'ASCII:Frederiksvaerk-Hundested Kommune;ID:6543941', '14521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14521', '112', '16398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16399', '1079', '1', 'Langeland Kommune', 'DK.21.482', 'ASCII:Langeland Kommune;ID:6543942', '14522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14522', '112', '16399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.21.482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16400', '1079', '1', 'Rudersdal Kommune', 'DK.17.230', 'ASCII:Rudersdal Kommune;ID:6543943', '14523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14523', '112', '16400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16401', '1079', '1', 'Ikast-Brande Kommune', 'DK.18.756', 'ASCII:Ikast-Brande Kommune;ID:6543944', '14524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14524', '112', '16401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16402', '1079', '1', 'Gribskov Kommune', 'DK.17.270', 'ASCII:Gribskov Kommune;ID:6543945', '14525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14525', '112', '16402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16403', '1079', '1', 'Favrskov Kommune', 'DK.18.710', 'ASCII:Favrskov Kommune;ID:6543946', '14526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14526', '112', '16403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16404', '1079', '1', 'Syddjurs Kommune', 'DK.18.706', 'ASCII:Syddjurs Kommune;ID:6543947', '14527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14527', '112', '16404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.18.706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16405', '1079', '1', 'Egedal Kommune', 'DK.17.240', 'ASCII:Egedal Kommune;ID:6543948', '14528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14528', '112', '16405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.17.240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16406', '1079', '1', 'Guldborgsund Kommune', 'DK.20.376', 'ASCII:Guldborgsund Kommune;ID:6543949', '14529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14529', '112', '16406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16407', '1079', '1', 'Lolland Kommune', 'DK.20.360', 'ASCII:Lolland Kommune;ID:6543950', '14530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14530', '112', '16407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DK.20.360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16408', '1079', '1', 'Yamasá', 'DO.32.3491797', 'ASCII:Yamasa;ID:3491797', '14531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14531', '112', '16408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.32.3491797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16409', '1079', '1', 'Yaguate', 'DO.33.3491808', 'ASCII:Yaguate;ID:3491808', '14532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14532', '112', '16409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.33.3491808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16410', '1079', '1', 'Villa Vásquez', 'DO.15.3491906', 'ASCII:Villa Vasquez;ID:3491906', '14533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14533', '112', '16410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.15.3491906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16411', '1079', '1', 'Villa Tapia', 'DO.19.3491909', 'ASCII:Villa Tapia;ID:3491909', '14534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14534', '112', '16411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.19.3491909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16412', '1079', '1', 'Villa Riva', 'DO.06.3491917', 'ASCII:Villa Riva;ID:3491917', '14535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14535', '112', '16412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.06.3491917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16413', '1079', '1', 'Villa Jaragua', 'DO.02.3491928', 'ASCII:Villa Jaragua;ID:3491928', '14536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14536', '112', '16413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.02.3491928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16414', '1079', '1', 'Villa Isabela', 'DO.18.3491930', 'ASCII:Villa Isabela;ID:3491930', '14537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14537', '112', '16414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.18.3491930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16415', '1079', '1', 'Villa Altagracia', 'DO.33.3491953', 'ASCII:Villa Altagracia;ID:3491953', '14538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14538', '112', '16415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.33.3491953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16416', '1079', '1', 'Vicente Noble', 'DO.03.3492031', 'ASCII:Vicente Noble;ID:3492031', '14539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14539', '112', '16416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.03.3492031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16417', '1079', '1', 'Vallejuelo', 'DO.23.3492124', 'ASCII:Vallejuelo;ID:3492124', '14540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14540', '112', '16417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.23.3492124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16418', '1079', '1', 'Tenares', 'DO.19.3492478', 'ASCII:Tenares;ID:3492478', '14541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14541', '112', '16418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.19.3492478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16419', '1079', '1', 'Tamboril', 'DO.25.3492518', 'ASCII:Tamboril;ID:3492518', '14542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14542', '112', '16419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.25.3492518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16420', '1079', '1', 'Tamayo', 'DO.02.3492521', 'ASCII:Tamayo;ID:3492521', '14543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14543', '112', '16420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.02.3492521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16421', '1079', '1', 'Sosúa', 'DO.18.3492630', 'ASCII:Sosua;ID:3492630', '14544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14544', '112', '16421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.18.3492630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16422', '1079', '1', 'Santo Domingo', 'DO.34.3492909', 'ASCII:Santo Domingo;ID:3492909', '14545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14545', '112', '16422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.34.3492909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16423', '1079', '1', 'Santiago de los Caballeros', 'DO.25.3492915', 'ASCII:Santiago de los Caballeros;ID:3492915', '14546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14546', '112', '16423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.25.3492915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16424', '1079', '1', 'San Rafael del Yuma', 'DO.10.3493023', 'ASCII:San Rafael del Yuma;ID:3493023', '14547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14547', '112', '16424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.10.3493023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16425', '1079', '1', 'San Pedro de Macorís', 'DO.24.3493033', 'ASCII:San Pedro de Macoris;ID:3493033', '14548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14548', '112', '16425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.24.3493033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16426', '1079', '1', 'San Juan de la Maguana', 'DO.23.3493083', 'ASCII:San Juan de la Maguana;ID:3493083', '14549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14549', '112', '16426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.23.3493083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16427', '1079', '1', 'San José de Ocoa', 'DO.35.3493101', 'ASCII:San Jose de Ocoa;ID:3493101', '14550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14550', '112', '16427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.35.3493101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16428', '1079', '1', 'San José de Las Matas', 'DO.25.3493104', 'ASCII:San Jose de Las Matas;ID:3493104', '14551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14551', '112', '16428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.25.3493104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16429', '1079', '1', 'San Francisco de Macorís', 'DO.06.3493147', 'ASCII:San Francisco de Macoris;ID:3493147', '14552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14552', '112', '16429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.06.3493147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16430', '1079', '1', 'San Cristóbal', 'DO.33.3493190', 'ASCII:San Cristobal;ID:3493190', '14553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14553', '112', '16430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.33.3493190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16431', '1079', '1', 'Sánchez', 'DO.20.3493201', 'ASCII:Sanchez;ID:3493201', '14554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14554', '112', '16431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.20.3493201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16432', '1079', '1', 'Samaná', 'DO.20.3493236', 'ASCII:Samana;ID:3493236', '14555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14555', '112', '16432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.20.3493236» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16433', '1079', '1', 'Salcedo', 'DO.19.3493284', 'ASCII:Salcedo;ID:3493284', '14556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14556', '112', '16433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.19.3493284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16434', '1079', '1', 'Sabaneta', 'DO.26.3493405', 'ASCII:Sabaneta;ID:3493405', '14557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14557', '112', '16434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.26.3493405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16435', '1079', '1', 'Sabana Grande de Boyá', 'DO.32.3493483', 'ASCII:Sabana Grande de Boya;ID:3493483', '14558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14558', '112', '16435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.32.3493483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16436', '1079', '1', 'Sabana de La Mar', 'DO.29.3493569', 'ASCII:Sabana de La Mar;ID:3493569', '14559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14559', '112', '16436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.29.3493569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16437', '1079', '1', 'Río San Juan', 'DO.14.3493745', 'ASCII:Rio San Juan;ID:3493745', '14560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14560', '112', '16437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.14.3493745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16438', '1079', '1', 'Restauración', 'DO.04.3493888', 'ASCII:Restauracion;ID:3493888', '14561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14561', '112', '16438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.04.3493888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16439', '1079', '1', 'Ramón Santana', 'DO.24.3494065', 'ASCII:Ramon Santana;ID:3494065', '14562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14562', '112', '16439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.24.3494065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16440', '1079', '1', 'Puerto Plata', 'DO.18.3494269', 'ASCII:Puerto Plata;ID:3494269', '14563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14563', '112', '16440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.18.3494269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16441', '1079', '1', 'Postrer Río', 'DO.09.3494510', 'ASCII:Postrer Rio;ID:3494510', '14564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14564', '112', '16441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.09.3494510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16442', '1079', '1', 'Pimentel', 'DO.06.3494769', 'ASCII:Pimentel;ID:3494769', '14565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14565', '112', '16442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.06.3494769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16443', '1079', '1', 'Peralta', 'DO.01.3495021', 'ASCII:Peralta;ID:3495021', '14566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14566', '112', '16443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.01.3495021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16444', '1079', '1', 'Pepillo Salcedo', 'DO.15.3495025', 'ASCII:Pepillo Salcedo;ID:3495025', '14567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14567', '112', '16444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.15.3495025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16445', '1079', '1', 'Pedro Santana', 'DO.11.3495099', 'ASCII:Pedro Santana;ID:3495099', '14568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14568', '112', '16445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.11.3495099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16446', '1079', '1', 'Pedernales', 'DO.16.3495139', 'ASCII:Pedernales;ID:3495139', '14569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14569', '112', '16446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.16.3495139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16447', '1079', '1', 'Paraíso', 'DO.03.3495273', 'ASCII:Paraiso;ID:3495273', '14570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14570', '112', '16447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.03.3495273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16448', '1079', '1', 'Padre Las Casas', 'DO.01.3495665', 'ASCII:Padre Las Casas;ID:3495665', '14571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14571', '112', '16448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.01.3495665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16449', '1079', '1', 'Oviedo', 'DO.16.3495685', 'ASCII:Oviedo;ID:3495685', '14572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14572', '112', '16449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.16.3495685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16450', '1079', '1', 'Nizao', 'DO.35.3495812', 'ASCII:Nizao;ID:3495812', '14573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14573', '112', '16450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.35.3495812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16451', '1079', '1', 'Neiba', 'DO.02.3495858', 'ASCII:Neiba;ID:3495858', '14574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14574', '112', '16451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.02.3495858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16452', '1079', '1', 'Nagua', 'DO.14.3496022', 'ASCII:Nagua;ID:3496022', '14575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14575', '112', '16452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.14.3496022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16453', '1079', '1', 'Monte Plata', 'DO.32.3496135', 'ASCII:Monte Plata;ID:3496135', '14576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14576', '112', '16453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.32.3496135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16454', '1079', '1', 'Monte Cristi', 'DO.15.3496204', 'ASCII:Monte Cristi;ID:3496204', '14577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14577', '112', '16454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.15.3496204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16455', '1079', '1', 'Monción', 'DO.26.3496285', 'ASCII:Moncion;ID:3496285', '14578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14578', '112', '16455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.26.3496285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16456', '1079', '1', 'Moca', 'DO.08.3496332', 'ASCII:Moca;ID:3496332', '14579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14579', '112', '16456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.08.3496332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16457', '1079', '1', 'Miches', 'DO.28.3496397', 'ASCII:Miches;ID:3496397', '14580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14580', '112', '16457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.28.3496397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16458', '1079', '1', 'Mao', 'DO.27.3496832', 'ASCII:Mao;ID:3496832', '14581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14581', '112', '16458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.27.3496832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16459', '1079', '1', 'Maimón', 'DO.31.3497224', 'ASCII:Maimon;ID:3497224', '14582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14582', '112', '16459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.31.3497224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16460', '1079', '1', 'Luperón', 'DO.18.3497351', 'ASCII:Luperon;ID:3497351', '14583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14583', '112', '16460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.18.3497351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16461', '1079', '1', 'Los Llanos', 'DO.24.3498193', 'ASCII:Los Llanos;ID:3498193', '14584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14584', '112', '16461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.24.3498193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16462', '1079', '1', 'Los Hidalgos', 'DO.18.3498419', 'ASCII:Los Hidalgos;ID:3498419', '14585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14585', '112', '16462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.18.3498419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16463', '1079', '1', 'Loma de Cabrera', 'DO.04.3499604', 'ASCII:Loma de Cabrera;ID:3499604', '14586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14586', '112', '16463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.04.3499604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16464', '1079', '1', 'Licey al Medio', 'DO.25.3499750', 'ASCII:Licey al Medio;ID:3499750', '14587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14587', '112', '16464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.25.3499750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16465', '1079', '1', 'La Vega', 'DO.30.3499980', 'ASCII:La Vega;ID:3499980', '14588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14588', '112', '16465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.30.3499980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16466', '1079', '1', 'Las Matas de Santa Cruz', 'DO.15.3500369', 'ASCII:Las Matas de Santa Cruz;ID:3500369', '14589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14589', '112', '16466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.15.3500369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16467', '1079', '1', 'Las Matas de Farfán', 'DO.23.3500371', 'ASCII:Las Matas de Farfan;ID:3500371', '14590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14590', '112', '16467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.23.3500371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16468', '1079', '1', 'La Romana', 'DO.12.3500959', 'ASCII:La Romana;ID:3500959', '14591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14591', '112', '16468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.12.3500959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16469', '1079', '1', 'Laguna Salada', 'DO.27.3502374', 'ASCII:Laguna Salada;ID:3502374', '14592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14592', '112', '16469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.27.3502374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16470', '1079', '1', 'La Descubierta', 'DO.09.3502787', 'ASCII:La Descubierta;ID:3502787', '14593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14593', '112', '16470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.09.3502787» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16471', '1079', '1', 'Jimaní', 'DO.09.3504078', 'ASCII:Jimani;ID:3504078', '14594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14594', '112', '16471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.09.3504078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16472', '1079', '1', 'Jarabacoa', 'DO.30.3504159', 'ASCII:Jarabacoa;ID:3504159', '14595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14595', '112', '16472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.30.3504159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16473', '1079', '1', 'Jánico', 'DO.25.3504164', 'ASCII:Janico;ID:3504164', '14596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14596', '112', '16473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.25.3504164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16474', '1079', '1', 'Imbert', 'DO.18.3504333', 'ASCII:Imbert;ID:3504333', '14597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14597', '112', '16474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.18.3504333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16475', '1079', '1', 'Hondo Valle', 'DO.11.3504468', 'ASCII:Hondo Valle;ID:3504468', '14598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14598', '112', '16475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.11.3504468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16476', '1079', '1', 'Higüey', 'DO.10.3504569', 'ASCII:Higuey;ID:3504569', '14599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14599', '112', '16476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.10.3504569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16477', '1079', '1', 'Hato Mayor', 'DO.29.3504769', 'ASCII:Hato Mayor;ID:3504769', '14600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14600', '112', '16477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.29.3504769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16478', '1079', '1', 'Guayubín', 'DO.15.3504946', 'ASCII:Guayubin;ID:3504946', '14601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14601', '112', '16478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.15.3504946» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16479', '1079', '1', 'Guaymate', 'DO.12.3504952', 'ASCII:Guaymate;ID:3504952', '14602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14602', '112', '16479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.12.3504952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16480', '1079', '1', 'Gaspar Hernández', 'DO.08.3505489', 'ASCII:Gaspar Hernandez;ID:3505489', '14603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14603', '112', '16480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.08.3505489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16481', '1079', '1', 'Fantino', 'DO.21.3505779', 'ASCII:Fantino;ID:3505779', '14604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14604', '112', '16481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.21.3505779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16482', '1079', '1', 'Esperanza', 'DO.27.3505860', 'ASCII:Esperanza;ID:3505860', '14605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14605', '112', '16482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.27.3505860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16483', '1079', '1', 'Enriquillo', 'DO.03.3505949', 'ASCII:Enriquillo;ID:3505949', '14606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14606', '112', '16483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.03.3505949» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16484', '1079', '1', 'El Valle', 'DO.29.3506042', 'ASCII:El Valle;ID:3506042', '14607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14607', '112', '16484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.29.3506042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16485', '1079', '1', 'El Seibo', 'DO.28.3506190', 'ASCII:El Seibo;ID:3506190', '14608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14608', '112', '16485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.28.3506190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16486', '1079', '1', 'El Llano', 'DO.11.3507124', 'ASCII:El Llano;ID:3507124', '14609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14609', '112', '16486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.11.3507124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16487', '1079', '1', 'El Factor', 'DO.14.3507629', 'ASCII:El Factor;ID:3507629', '14610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14610', '112', '16487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.14.3507629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16488', '1079', '1', 'El Cercado', 'DO.23.3508017', 'ASCII:El Cercado;ID:3508017', '14611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14611', '112', '16488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.23.3508017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16489', '1079', '1', 'Duvergé', 'DO.09.3508696', 'ASCII:Duverge;ID:3508696', '14612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14612', '112', '16489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.09.3508696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16490', '1079', '1', 'Dajabón', 'DO.04.3508954', 'ASCII:Dajabon;ID:3508954', '14613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14613', '112', '16490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.04.3508954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16491', '1079', '1', 'Cotuí', 'DO.21.3509208', 'ASCII:Cotui;ID:3509208', '14614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14614', '112', '16491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.21.3509208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16492', '1079', '1', 'Constanza', 'DO.30.3509366', 'ASCII:Constanza;ID:3509366', '14615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14615', '112', '16492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.30.3509366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16493', '1079', '1', 'Comendador', 'DO.11.3509387', 'ASCII:Comendador;ID:3509387', '14616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14616', '112', '16493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.11.3509387» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16494', '1079', '1', 'Cevicos', 'DO.21.3509824', 'ASCII:Cevicos;ID:3509824', '14617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14617', '112', '16494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.21.3509824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16495', '1079', '1', 'Cayetano Germosén', 'DO.08.3509990', 'ASCII:Cayetano Germosen;ID:3509990', '14618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14618', '112', '16495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.08.3509990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16496', '1079', '1', 'Castillo', 'DO.06.3510068', 'ASCII:Castillo;ID:3510068', '14619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14619', '112', '16496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.06.3510068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16497', '1079', '1', 'Castañuelas', 'DO.15.3510084', 'ASCII:Castanuelas;ID:3510084', '14620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14620', '112', '16497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.15.3510084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16498', '1079', '1', 'Cambita Garabitos', 'DO.33.3510638', 'ASCII:Cambita Garabitos;ID:3510638', '14621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14621', '112', '16498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.33.3510638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16499', '1079', '1', 'Cabrera', 'DO.14.3510875', 'ASCII:Cabrera;ID:3510875', '14622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14622', '112', '16499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.14.3510875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16500', '1079', '1', 'Cabral', 'DO.03.3510886', 'ASCII:Cabral;ID:3510886', '14623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14623', '112', '16500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.03.3510886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16501', '1079', '1', 'Bonao', 'DO.31.3511235', 'ASCII:Bonao;ID:3511235', '14624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14624', '112', '16501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.31.3511235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16502', '1079', '1', 'Bohechío', 'DO.23.3511263', 'ASCII:Bohechio;ID:3511263', '14625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14625', '112', '16502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.23.3511263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16503', '1079', '1', 'Bisonó', 'DO.25.3511462', 'ASCII:Bisono;ID:3511462', '14626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14626', '112', '16503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.25.3511462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16504', '1079', '1', 'Bayaguana', 'DO.32.3511627', 'ASCII:Bayaguana;ID:3511627', '14627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14627', '112', '16504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.32.3511627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16505', '1079', '1', 'Barahona', 'DO.03.3512046', 'ASCII:Barahona;ID:3512046', '14628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14628', '112', '16505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.03.3512046» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16506', '1079', '1', 'Bánica', 'DO.11.3512065', 'ASCII:Banica;ID:3512065', '14629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14629', '112', '16506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.11.3512065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16507', '1079', '1', 'Baní', 'DO.35.3512069', 'ASCII:Bani;ID:3512069', '14630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14630', '112', '16507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.35.3512069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16508', '1079', '1', 'Bajos de Haina', 'DO.33.3512129', 'ASCII:Bajos de Haina;ID:3512129', '14631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14631', '112', '16508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.33.3512129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16509', '1079', '1', 'Azua', 'DO.01.3512211', 'ASCII:Azua;ID:3512211', '14632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14632', '112', '16509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.01.3512211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16510', '1079', '1', 'Altamira', 'DO.18.3512798', 'ASCII:Altamira;ID:3512798', '14633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14633', '112', '16510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «DO.18.3512798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16511', '1079', '1', 'Cantón Zaruma', 'EC.08.3649913', 'ASCII:Canton Zaruma;ID:3649913', '14634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14634', '112', '16511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.08.3649913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16512', '1079', '1', 'Cantón Zamora', 'EC.20.3649958', 'ASCII:Canton Zamora;ID:3649958', '14635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14635', '112', '16512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.20.3649958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16513', '1079', '1', 'Cantón Yantzaza', 'EC.20.3650052', 'ASCII:Canton Yantzaza;ID:3650052', '14636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14636', '112', '16513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.20.3650052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16514', '1079', '1', 'Cantón Yaguachi', 'EC.10.3650124', 'ASCII:Canton Yaguachi;ID:3650124', '14637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14637', '112', '16514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3650124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16515', '1079', '1', 'Cantón Yacuambi', 'EC.20.3650141', 'ASCII:Canton Yacuambi;ID:3650141', '14638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14638', '112', '16515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.20.3650141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16516', '1079', '1', 'Cantón Vinces', 'EC.13.3650185', 'ASCII:Canton Vinces;ID:3650185', '14639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14639', '112', '16516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.13.3650185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16517', '1079', '1', 'Cantón Ventanas', 'EC.13.3650264', 'ASCII:Canton Ventanas;ID:3650264', '14640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14640', '112', '16517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.13.3650264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16518', '1079', '1', 'Cantón Veinticuatro de Mayo', 'EC.14.3650277', 'ASCII:Canton Veinticuatro de Mayo;ID:3650277', '14641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14641', '112', '16518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3650277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16519', '1079', '1', 'Cantón Urellana', 'EC.24.3650339', 'ASCII:Canton Urellana;ID:3650339', '14642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14642', '112', '16519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.24.3650339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16520', '1079', '1', 'Cantón Urdaneta', 'EC.13.3650340', 'ASCII:Canton Urdaneta;ID:3650340', '14643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14643', '112', '16520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.13.3650340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16521', '1079', '1', 'Cantón Urbina Jado', 'EC.10.3650347', 'ASCII:Canton Urbina Jado;ID:3650347', '14644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14644', '112', '16521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3650347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16522', '1079', '1', 'Cantón Tulcán', 'EC.05.3650471', 'ASCII:Canton Tulcan;ID:3650471', '14645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14645', '112', '16522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.05.3650471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16523', '1079', '1', 'Cantón Tena', 'EC.23.3650720', 'ASCII:Canton Tena;ID:3650720', '14646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14646', '112', '16523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.23.3650720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16524', '1079', '1', 'Cantón Sucumbíos', 'EC.22.3650954', 'ASCII:Canton Sucumbios;ID:3650954', '14647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14647', '112', '16524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.22.3650954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16525', '1079', '1', 'Cantón Sucúa', 'EC.15.3650955', 'ASCII:Canton Sucua;ID:3650955', '14648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14648', '112', '16525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.15.3650955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16526', '1079', '1', 'Cantón Sucre', 'EC.14.3650958', 'ASCII:Canton Sucre;ID:3650958', '14649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14649', '112', '16526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3650958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16527', '1079', '1', 'Cantón Sozoranga', 'EC.12.3650979', 'ASCII:Canton Sozoranga;ID:3650979', '14650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14650', '112', '16527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3650979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16528', '1079', '1', 'Cantón Sigsig', 'EC.02.3651065', 'ASCII:Canton Sigsig;ID:3651065', '14651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14651', '112', '16528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.02.3651065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16529', '1079', '1', 'Cantón Saraguro', 'EC.12.3651244', 'ASCII:Canton Saraguro;ID:3651244', '14652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14652', '112', '16529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3651244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16530', '1079', '1', 'Cantón Saquisilí', 'EC.07.3651250', 'ASCII:Canton Saquisili;ID:3651250', '14653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14653', '112', '16530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.07.3651250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16531', '1079', '1', 'Cantón Santo Domingo de los Colorados', 'EC.18.3651296', 'ASCII:Canton Santo Domingo de los Colorados;ID:3651296', '14654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14654', '112', '16531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.18.3651296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16532', '1079', '1', 'Cantón Santiago', 'EC.15.3651317', 'ASCII:Canton Santiago;ID:3651317', '14655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14655', '112', '16532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.15.3651317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16533', '1079', '1', 'Cantón Santa Rosa', 'EC.08.3651355', 'ASCII:Canton Santa Rosa;ID:3651355', '14656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14656', '112', '16533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.08.3651355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16534', '1079', '1', 'Cantón Santa Isabel', 'EC.02.3651417', 'ASCII:Canton Santa Isabel;ID:3651417', '14657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14657', '112', '16534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.02.3651417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16535', '1079', '1', 'Cantón Santa Elena', 'EC.10.3651436', 'ASCII:Canton Santa Elena;ID:3651436', '14658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14658', '112', '16535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3651436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16536', '1079', '1', 'Cantón Santa Cruz', 'EC.01.3651446', 'ASCII:Canton Santa Cruz;ID:3651446', '14659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14659', '112', '16536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.01.3651446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16537', '1079', '1', 'Cantón Santa Ana', 'EC.14.3651484', 'ASCII:Canton Santa Ana;ID:3651484', '14660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14660', '112', '16537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3651484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16538', '1079', '1', 'Cantón San Miguel', 'EC.03.3651621', 'ASCII:Canton San Miguel;ID:3651621', '14661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14661', '112', '16538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.03.3651621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16539', '1079', '1', 'Cantón San Lorenzo', 'EC.09.3651686', 'ASCII:Canton San Lorenzo;ID:3651686', '14662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14662', '112', '16539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.09.3651686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16540', '1079', '1', 'Cantón San Cristóbal', 'EC.01.3651947', 'ASCII:Canton San Cristobal;ID:3651947', '14663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14663', '112', '16540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.01.3651947» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16541', '1079', '1', 'Cantón Samborondón', 'EC.10.3652064', 'ASCII:Canton Samborondon;ID:3652064', '14664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14664', '112', '16541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3652064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16542', '1079', '1', 'Cantón Salinas', 'EC.10.3652097', 'ASCII:Canton Salinas;ID:3652097', '14665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14665', '112', '16542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3652097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16543', '1079', '1', 'Cantón Salcedo', 'EC.07.3652108', 'ASCII:Canton Salcedo;ID:3652108', '14666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14666', '112', '16543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.07.3652108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16544', '1079', '1', 'Cantón Rumiñahui', 'EC.18.3652228', 'ASCII:Canton Ruminahui;ID:3652228', '14667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14667', '112', '16544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.18.3652228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16545', '1079', '1', 'Cantón Rocafuerte', 'EC.14.3652312', 'ASCII:Canton Rocafuerte;ID:3652312', '14668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14668', '112', '16545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3652312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16546', '1079', '1', 'Cantón Riobamba', 'EC.06.3652349', 'ASCII:Canton Riobamba;ID:3652349', '14669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14669', '112', '16546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.06.3652349» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16547', '1079', '1', 'Cantón Quito', 'EC.18.3652461', 'ASCII:Canton Quito;ID:3652461', '14670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14670', '112', '16547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.18.3652461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16548', '1079', '1', 'Cantón Quinindé', 'EC.09.3652499', 'ASCII:Canton Quininde;ID:3652499', '14671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14671', '112', '16548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.09.3652499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16549', '1079', '1', 'Cantón Quijos', 'EC.23.3652561', 'ASCII:Canton Quijos;ID:3652561', '14672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14672', '112', '16549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.23.3652561» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16550', '1079', '1', 'Cantón Quevedo', 'EC.13.3652566', 'ASCII:Canton Quevedo;ID:3652566', '14673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14673', '112', '16550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.13.3652566» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16551', '1079', '1', 'Cantón Quero', 'EC.19.3652572', 'ASCII:Canton Quero;ID:3652572', '14674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14674', '112', '16551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.19.3652572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16552', '1079', '1', 'Cantón Puyango', 'EC.12.3652587', 'ASCII:Canton Puyango;ID:3652587', '14675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14675', '112', '16552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3652587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16553', '1079', '1', 'Cantón Putumayo', 'EC.22.3652592', 'ASCII:Canton Putumayo;ID:3652592', '14676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14676', '112', '16553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.22.3652592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16554', '1079', '1', 'Cantón Pujilí', 'EC.07.3652683', 'ASCII:Canton Pujili;ID:3652683', '14677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14677', '112', '16554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.07.3652683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16555', '1079', '1', 'Cantón Puebloviejo', 'EC.13.3652785', 'ASCII:Canton Puebloviejo;ID:3652785', '14678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14678', '112', '16555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.13.3652785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16556', '1079', '1', 'Cantón Portoviejo', 'EC.14.3652940', 'ASCII:Canton Portoviejo;ID:3652940', '14679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14679', '112', '16556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3652940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16557', '1079', '1', 'Cantón Portovelo', 'EC.08.3652942', 'ASCII:Canton Portovelo;ID:3652942', '14680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14680', '112', '16557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.08.3652942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16558', '1079', '1', 'Cantón Piñas', 'EC.08.3653129', 'ASCII:Canton Pinas;ID:3653129', '14681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14681', '112', '16558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.08.3653129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16559', '1079', '1', 'Cantón Pimampiro', 'EC.11.3653145', 'ASCII:Canton Pimampiro;ID:3653145', '14682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14682', '112', '16559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.11.3653145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16560', '1079', '1', 'Cantón Píllaro', 'EC.19.3653158', 'ASCII:Canton Pillaro;ID:3653158', '14683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14683', '112', '16560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.19.3653158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16561', '1079', '1', 'Cantón Pelileo', 'EC.19.3653286', 'ASCII:Canton Pelileo;ID:3653286', '14684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14684', '112', '16561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.19.3653286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16562', '1079', '1', 'Cantón Pedro Moncayo', 'EC.18.3653294', 'ASCII:Canton Pedro Moncayo;ID:3653294', '14685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14685', '112', '16562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.18.3653294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16563', '1079', '1', 'Cantón Paute', 'EC.02.3653330', 'ASCII:Canton Paute;ID:3653330', '14686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14686', '112', '16563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.02.3653330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16564', '1079', '1', 'Cantón Patate', 'EC.19.3653370', 'ASCII:Canton Patate;ID:3653370', '14687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14687', '112', '16564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.19.3653370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16565', '1079', '1', 'Cantón Pastaza', 'EC.17.3653394', 'ASCII:Canton Pastaza;ID:3653394', '14688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14688', '112', '16565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.17.3653394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16566', '1079', '1', 'Cantón Pasaje', 'EC.08.3653402', 'ASCII:Canton Pasaje;ID:3653402', '14689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14689', '112', '16566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.08.3653402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16567', '1079', '1', 'Cantón Pangua', 'EC.07.3653474', 'ASCII:Canton Pangua;ID:3653474', '14690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14690', '112', '16567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.07.3653474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16568', '1079', '1', 'Cantón Paltas', 'EC.12.3653515', 'ASCII:Canton Paltas;ID:3653515', '14691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14691', '112', '16568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3653515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16569', '1079', '1', 'Cantón Palora', 'EC.15.3653522', 'ASCII:Canton Palora;ID:3653522', '14692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14692', '112', '16569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.15.3653522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16570', '1079', '1', 'Cantón Paján', 'EC.14.3653608', 'ASCII:Canton Pajan;ID:3653608', '14693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14693', '112', '16570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3653608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16571', '1079', '1', 'Cantón Otavalo', 'EC.11.3653692', 'ASCII:Canton Otavalo;ID:3653692', '14694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14694', '112', '16571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.11.3653692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16572', '1079', '1', 'Cantón Naranjito', 'EC.10.3653872', 'ASCII:Canton Naranjito;ID:3653872', '14695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14695', '112', '16572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3653872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16573', '1079', '1', 'Cantón Naranjal', 'EC.10.3653880', 'ASCII:Canton Naranjal;ID:3653880', '14696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14696', '112', '16573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3653880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16574', '1079', '1', 'Cantón Muisne', 'EC.09.3653966', 'ASCII:Canton Muisne;ID:3653966', '14697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14697', '112', '16574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.09.3653966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16575', '1079', '1', 'Cantón Morona', 'EC.15.3654006', 'ASCII:Canton Morona;ID:3654006', '14698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14698', '112', '16575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.15.3654006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16576', '1079', '1', 'Cantón Montúfar', 'EC.05.3654038', 'ASCII:Canton Montufar;ID:3654038', '14699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14699', '112', '16576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.05.3654038» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16577', '1079', '1', 'Cantón Montecristi', 'EC.14.3654054', 'ASCII:Canton Montecristi;ID:3654054', '14700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14700', '112', '16577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3654054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16578', '1079', '1', 'Cantón Mira', 'EC.05.3654172', 'ASCII:Canton Mira;ID:3654172', '14701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14701', '112', '16578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.05.3654172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16579', '1079', '1', 'Cantón Milagro', 'EC.10.3654213', 'ASCII:Canton Milagro;ID:3654213', '14702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14702', '112', '16579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3654213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16580', '1079', '1', 'Cantón Mera', 'EC.17.3654246', 'ASCII:Canton Mera;ID:3654246', '14703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14703', '112', '16580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.17.3654246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16581', '1079', '1', 'Cantón Mejía', 'EC.18.3654259', 'ASCII:Canton Mejia;ID:3654259', '14704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14704', '112', '16581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.18.3654259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16582', '1079', '1', 'Cantón Manta', 'EC.14.3654408', 'ASCII:Canton Manta;ID:3654408', '14705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14705', '112', '16582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3654408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16583', '1079', '1', 'Cantón Machala', 'EC.08.3654532', 'ASCII:Canton Machala;ID:3654532', '14706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14706', '112', '16583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.08.3654532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16584', '1079', '1', 'Cantón Macará', 'EC.12.3654544', 'ASCII:Canton Macara;ID:3654544', '14707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14707', '112', '16584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3654544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16585', '1079', '1', 'Cantón Loja', 'EC.12.3654666', 'ASCII:Canton Loja;ID:3654666', '14708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14708', '112', '16585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3654666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16586', '1079', '1', 'Cantón Limón Indanza', 'EC.15.3654737', 'ASCII:Canton Limon Indanza;ID:3654737', '14709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14709', '112', '16586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.15.3654737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16587', '1079', '1', 'Cantón Latacunga', 'EC.07.3654869', 'ASCII:Canton Latacunga;ID:3654869', '14710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14710', '112', '16587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.07.3654869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16588', '1079', '1', 'Cantón Lago Agrio', 'EC.22.3655184', 'ASCII:Canton Lago Agrio;ID:3655184', '14711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14711', '112', '16588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.22.3655184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16589', '1079', '1', 'Cantón Junín', 'EC.14.3655383', 'ASCII:Canton Junin;ID:3655383', '14712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14712', '112', '16589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3655383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16590', '1079', '1', 'Cantón Jipijapa', 'EC.14.3655445', 'ASCII:Canton Jipijapa;ID:3655445', '14713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14713', '112', '16590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3655445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16591', '1079', '1', 'Cantón Isabela', 'EC.01.3655572', 'ASCII:Canton Isabela;ID:3655572', '14714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14714', '112', '16591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.01.3655572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16592', '1079', '1', 'Cantón Ibarra', 'EC.11.3655672', 'ASCII:Canton Ibarra;ID:3655672', '14715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14715', '112', '16592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.11.3655672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16593', '1079', '1', 'Cantón Huaquillas', 'EC.08.3655719', 'ASCII:Canton Huaquillas;ID:3655719', '14716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14716', '112', '16593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.08.3655719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16594', '1079', '1', 'Cantón Guayaquil', 'EC.10.3657508', 'ASCII:Canton Guayaquil;ID:3657508', '14717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14717', '112', '16594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3657508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16595', '1079', '1', 'Cantón Guaranda', 'EC.03.3657570', 'ASCII:Canton Guaranda;ID:3657570', '14718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14718', '112', '16595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.03.3657570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16596', '1079', '1', 'Cantón Guano', 'EC.06.3657593', 'ASCII:Canton Guano;ID:3657593', '14719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14719', '112', '16596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.06.3657593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16597', '1079', '1', 'Cantón Guamote', 'EC.06.3657620', 'ASCII:Canton Guamote;ID:3657620', '14720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14720', '112', '16597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.06.3657620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16598', '1079', '1', 'Cantón Gualaquiza', 'EC.15.3657660', 'ASCII:Canton Gualaquiza;ID:3657660', '14721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14721', '112', '16598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.15.3657660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16599', '1079', '1', 'Cantón Gualaceo', 'EC.02.3657669', 'ASCII:Canton Gualaceo;ID:3657669', '14722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14722', '112', '16599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.02.3657669» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16600', '1079', '1', 'Cantón Guabo', 'EC.08.3657721', 'ASCII:Canton Guabo;ID:3657721', '14723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14723', '112', '16600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.08.3657721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16601', '1079', '1', 'Cantón Gonzanamá', 'EC.12.3657777', 'ASCII:Canton Gonzanama;ID:3657777', '14724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14724', '112', '16601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3657777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16602', '1079', '1', 'Cantón Girón', 'EC.02.3657793', 'ASCII:Canton Giron;ID:3657793', '14725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14725', '112', '16602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.02.3657793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16603', '1079', '1', 'Cantón Espindola', 'EC.12.3657967', 'ASCII:Canton Espindola;ID:3657967', '14726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14726', '112', '16603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3657967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16604', '1079', '1', 'Cantón Espejo', 'EC.05.3657981', 'ASCII:Canton Espejo;ID:3657981', '14727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14727', '112', '16604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.05.3657981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16605', '1079', '1', 'Cantón Esmeraldas', 'EC.09.3657987', 'ASCII:Canton Esmeraldas;ID:3657987', '14728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14728', '112', '16605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.09.3657987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16606', '1079', '1', 'Cantón Eloy Alfaro', 'EC.09.3658191', 'ASCII:Canton Eloy Alfaro;ID:3658191', '14729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14729', '112', '16606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.09.3658191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16607', '1079', '1', 'Cantón El Empalme', 'EC.10.3658266', 'ASCII:Canton El Empalme;ID:3658266', '14730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14730', '112', '16607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3658266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16608', '1079', '1', 'Cantón El Carmen', 'EC.14.3658324', 'ASCII:Canton El Carmen;ID:3658324', '14731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14731', '112', '16608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3658324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16609', '1079', '1', 'Cantón Daule', 'EC.10.3658498', 'ASCII:Canton Daule;ID:3658498', '14732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14732', '112', '16609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3658498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16610', '1079', '1', 'Cantón Cuenca', 'EC.02.3658665', 'ASCII:Canton Cuenca;ID:3658665', '14733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14733', '112', '16610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.02.3658665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16611', '1079', '1', 'Cantón Cotacachi', 'EC.11.3658780', 'ASCII:Canton Cotacachi;ID:3658780', '14734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14734', '112', '16611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.11.3658780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16612', '1079', '1', 'Cantón Colta', 'EC.06.3658919', 'ASCII:Canton Colta;ID:3658919', '14735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14735', '112', '16612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.06.3658919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16613', '1079', '1', 'Cantón Chunchi', 'EC.06.3659071', 'ASCII:Canton Chunchi;ID:3659071', '14736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14736', '112', '16613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.06.3659071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16614', '1079', '1', 'Cantón Chone', 'EC.14.3659138', 'ASCII:Canton Chone;ID:3659138', '14737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14737', '112', '16614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3659138» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16615', '1079', '1', 'Cantón Chinchipe', 'EC.20.3659209', 'ASCII:Canton Chinchipe;ID:3659209', '14738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14738', '112', '16615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.20.3659209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16616', '1079', '1', 'Cantón Chimbo', 'EC.03.3659242', 'ASCII:Canton Chimbo;ID:3659242', '14739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14739', '112', '16616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.03.3659242» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16617', '1079', '1', 'Cantón Chillanes', 'EC.03.3659255', 'ASCII:Canton Chillanes;ID:3659255', '14740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14740', '112', '16617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.03.3659255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16618', '1079', '1', 'Cantón Celica', 'EC.12.3659543', 'ASCII:Canton Celica;ID:3659543', '14741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14741', '112', '16618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3659543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16619', '1079', '1', 'Cantón Cayambe', 'EC.18.3659576', 'ASCII:Canton Cayambe;ID:3659576', '14742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14742', '112', '16619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.18.3659576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16620', '1079', '1', 'Cantón Catamayo', 'EC.12.3659598', 'ASCII:Canton Catamayo;ID:3659598', '14743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14743', '112', '16620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3659598» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16621', '1079', '1', 'Cantón Cañar', 'EC.04.3659851', 'ASCII:Canton Canar;ID:3659851', '14744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14744', '112', '16621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.04.3659851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16622', '1079', '1', 'Cantón Calvas', 'EC.12.3659882', 'ASCII:Canton Calvas;ID:3659882', '14745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14745', '112', '16622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.12.3659882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16623', '1079', '1', 'Cantón Bolívar', 'EC.14.3660131', 'ASCII:Canton Bolivar;ID:3660131', '14746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14746', '112', '16623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.14.3660131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16624', '1079', '1', 'Cantón Biblián', 'EC.04.3660210', 'ASCII:Canton Biblian;ID:3660210', '14747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14747', '112', '16624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.04.3660210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16625', '1079', '1', 'Cantón Baños', 'EC.19.3660343', 'ASCII:Canton Banos;ID:3660343', '14748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14748', '112', '16625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.19.3660343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16626', '1079', '1', 'Cantón Balzar', 'EC.10.3660360', 'ASCII:Canton Balzar;ID:3660360', '14749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14749', '112', '16626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.10.3660360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16627', '1079', '1', 'Cantón Babahoyo', 'EC.13.3660417', 'ASCII:Canton Babahoyo;ID:3660417', '14750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14750', '112', '16627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.13.3660417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16628', '1079', '1', 'Cantón Baba', 'EC.13.3660421', 'ASCII:Canton Baba;ID:3660421', '14751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14751', '112', '16628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.13.3660421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16629', '1079', '1', 'Cantón Azogues', 'EC.04.3660433', 'ASCII:Canton Azogues;ID:3660433', '14752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14752', '112', '16629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.04.3660433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16630', '1079', '1', 'Cantón Arenillas', 'EC.08.3660558', 'ASCII:Canton Arenillas;ID:3660558', '14753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14753', '112', '16630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.08.3660558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16631', '1079', '1', 'Cantón Archidona', 'EC.23.3660572', 'ASCII:Canton Archidona;ID:3660572', '14754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14754', '112', '16631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.23.3660572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16632', '1079', '1', 'Cantón Antonio Ante', 'EC.11.3660592', 'ASCII:Canton Antonio Ante;ID:3660592', '14755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14755', '112', '16632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.11.3660592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16633', '1079', '1', 'Cantón Ambato', 'EC.19.3660688', 'ASCII:Canton Ambato;ID:3660688', '14756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14756', '112', '16633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.19.3660688» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16634', '1079', '1', 'Cantón Alausí', 'EC.06.3660797', 'ASCII:Canton Alausi;ID:3660797', '14757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14757', '112', '16634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.06.3660797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16635', '1079', '1', 'Cantón Aguarico', 'EC.24.3660839', 'ASCII:Canton Aguarico;ID:3660839', '14758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14758', '112', '16635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EC.24.3660839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16636', '1079', '1', 'El Bâgûr', 'EG.09.345955', 'ASCII:El Bagur;ID:345955', '14759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14759', '112', '16636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.09.345955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16637', '1079', '1', 'Markaz `Unaybah', 'EG.16.346518', 'ASCII:Markaz `Unaybah;ID:346518', '14760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14760', '112', '16637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.16.346518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16638', '1079', '1', 'Markaz Ţāmiyah', 'EG.04.347541', 'ASCII:Markaz Tamiyah;ID:347541', '14761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14761', '112', '16638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.04.347541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16639', '1079', '1', 'Markaz Sumusţā al Waqf', 'EG.18.347750', 'ASCII:Markaz Sumusta al Waqf;ID:347750', '14762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14762', '112', '16639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.18.347750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16640', '1079', '1', 'Markaz Sūhāj', 'EG.24.347795', 'ASCII:Markaz Suhaj;ID:347795', '14763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14763', '112', '16640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.24.347795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16641', '1079', '1', 'Markaz Sīdī Sālim', 'EG.21.348095', 'ASCII:Markaz Sidi Salim;ID:348095', '14764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14764', '112', '16641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.21.348095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16642', '1079', '1', 'Markaz Rashīd', 'EG.03.350200', 'ASCII:Markaz Rashid;ID:350200', '14765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14765', '112', '16642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.03.350200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16643', '1079', '1', 'Markaz Quwaysinā', 'EG.09.350368', 'ASCII:Markaz Quwaysina;ID:350368', '14766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14766', '112', '16643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.09.350368» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16644', '1079', '1', 'Markaz Quţūr', 'EG.05.350373', 'ASCII:Markaz Qutur;ID:350373', '14767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14767', '112', '16644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.05.350373» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16645', '1079', '1', 'Markaz Qinā', 'EG.23.350547', 'ASCII:Markaz Qina;ID:350547', '14768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14768', '112', '16645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.23.350547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16646', '1079', '1', 'Qism al Qanţarah', 'EG.07.350768', 'ASCII:Qism al Qantarah;ID:350768', '14769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14769', '112', '16646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.07.350768» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16647', '1079', '1', 'Markaz Qalyūb', 'EG.12.350787', 'ASCII:Markaz Qalyub;ID:350787', '14770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14770', '112', '16647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.12.350787» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16648', '1079', '1', 'Markaz Qallīn', 'EG.21.350795', 'ASCII:Markaz Qallin;ID:350795', '14771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14771', '112', '16648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.21.350795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16649', '1079', '1', 'Markaz Mīt Ghamr', 'EG.01.352180', 'ASCII:Markaz Mit Ghamr;ID:352180', '14772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14772', '112', '16649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.01.352180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16650', '1079', '1', 'Markaz Maţrūḩ', 'EG.22.352605', 'ASCII:Markaz Matruh;ID:352605', '14773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14773', '112', '16650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.22.352605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16651', '1079', '1', 'Markaz Maţāy', 'EG.10.352626', 'ASCII:Markaz Matay;ID:352626', '14774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14774', '112', '16651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.10.352626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16652', '1079', '1', 'Markaz Maryūţ', 'EG.06.352720', 'ASCII:Markaz Maryut;ID:352720', '14775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14775', '112', '16652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.06.352720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16653', '1079', '1', 'Markaz Mallawī', 'EG.10.352950', 'ASCII:Markaz Mallawi;ID:352950', '14776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14776', '112', '16653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.10.352950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16654', '1079', '1', 'Markaz Kafr ash Shaykh', 'EG.21.354501', 'ASCII:Markaz Kafr ash Shaykh;ID:354501', '14777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14777', '112', '16654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.21.354501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16655', '1079', '1', 'Markaz Kafr ad Dawwār', 'EG.03.354773', 'ASCII:Markaz Kafr ad Dawwar;ID:354773', '14778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14778', '112', '16655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.03.354773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16656', '1079', '1', 'Markaz Jirjā', 'EG.24.355025', 'ASCII:Markaz Jirja;ID:355025', '14779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14779', '112', '16656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.24.355025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16657', '1079', '1', 'Markaz Ityāy al Bārūd', 'EG.03.355416', 'ASCII:Markaz Ityay al Barud;ID:355416', '14780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14780', '112', '16657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.03.355416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16658', '1079', '1', 'Markaz Iţsā', 'EG.04.355419', 'ASCII:Markaz Itsa;ID:355419', '14781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14781', '112', '16658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.04.355419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16659', '1079', '1', 'Markaz Isnā', 'EG.23.355447', 'ASCII:Markaz Isna;ID:355447', '14782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14782', '112', '16659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.23.355447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16660', '1079', '1', 'Markaz Imbābah', 'EG.08.355547', 'ASCII:Markaz Imbabah;ID:355547', '14783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14783', '112', '16660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.08.355547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16661', '1079', '1', 'Markaz Ihnāsiyat al Madīnah', 'EG.18.355594', 'ASCII:Markaz Ihnasiyat al Madinah;ID:355594', '14784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14784', '112', '16661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.18.355594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16662', '1079', '1', 'Markaz Idfū', 'EG.16.355633', 'ASCII:Markaz Idfu;ID:355633', '14785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14785', '112', '16662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.16.355633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16663', '1079', '1', 'Markaz Ibshawāy', 'EG.04.355647', 'ASCII:Markaz Ibshaway;ID:355647', '14786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14786', '112', '16663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.04.355647» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16664', '1079', '1', 'Markaz Hihyā', 'EG.14.355938', 'ASCII:Markaz Hihya;ID:355938', '14787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14787', '112', '16664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.14.355938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16665', '1079', '1', 'Markaz Ḩawsh `Īsá', 'EG.03.355999', 'ASCII:Markaz Hawsh `Isa;ID:355999', '14788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14788', '112', '16665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.03.355999» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16666', '1079', '1', 'Markaz Fuwah', 'EG.21.356805', 'ASCII:Markaz Fuwah;ID:356805', '14789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14789', '112', '16666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.21.356805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16667', '1079', '1', 'Markaz Fāriskūr', 'EG.20.356943', 'ASCII:Markaz Fariskur;ID:356943', '14790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14790', '112', '16667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.20.356943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16668', '1079', '1', 'Markaz Diyarb Najm', 'EG.01.358094', 'ASCII:Markaz Diyarb Najm;ID:358094', '14791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14791', '112', '16668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.01.358094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16669', '1079', '1', 'Markaz Disūq', 'EG.21.358107', 'ASCII:Markaz Disuq;ID:358107', '14792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14792', '112', '16669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.21.358107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16670', '1079', '1', 'Markaz Dishnā', 'EG.23.358114', 'ASCII:Markaz Dishna;ID:358114', '14793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14793', '112', '16670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.23.358114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16671', '1079', '1', 'Markaz Dikirnis', 'EG.01.358171', 'ASCII:Markaz Dikirnis;ID:358171', '14794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14794', '112', '16671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.01.358171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16672', '1079', '1', 'Markaz Dayrūţ', 'EG.17.358267', 'ASCII:Markaz Dayrut;ID:358267', '14795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14795', '112', '16672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.17.358267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16673', '1079', '1', 'Markaz Dayr Mawās', 'EG.10.358273', 'ASCII:Markaz Dayr Mawas;ID:358273', '14796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14796', '112', '16673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.10.358273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16674', '1079', '1', 'Markaz Damanhūr', 'EG.03.358446', 'ASCII:Markaz Damanhur;ID:358446', '14797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14797', '112', '16674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.03.358446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16675', '1079', '1', 'Markaz Būsh', 'EG.18.358599', 'ASCII:Markaz Bush;ID:358599', '14798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14798', '112', '16675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.18.358599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16676', '1079', '1', 'Markaz Biyalā', 'EG.21.358725', 'ASCII:Markaz Biyala;ID:358725', '14799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14799', '112', '16676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.21.358725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16677', '1079', '1', 'Markaz Bilqās', 'EG.01.358824', 'ASCII:Markaz Bilqas;ID:358824', '14800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14800', '112', '16677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.01.358824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16678', '1079', '1', 'Markaz Bilbays', 'EG.14.358838', 'ASCII:Markaz Bilbays;ID:358838', '14801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14801', '112', '16678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.14.358838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16679', '1079', '1', 'Markaz Bibā', 'EG.18.358869', 'ASCII:Markaz Biba;ID:358869', '14802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14802', '112', '16679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.18.358869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16680', '1079', '1', 'Markaz Basyūn', 'EG.05.358969', 'ASCII:Markaz Basyun;ID:358969', '14803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14803', '112', '16680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.05.358969» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16681', '1079', '1', 'Markaz Banī Suwayf', 'EG.18.359172', 'ASCII:Markaz Bani Suwayf;ID:359172', '14804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14804', '112', '16681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.18.359172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16682', '1079', '1', 'Markaz Banī Mazār', 'EG.10.359211', 'ASCII:Markaz Bani Mazar;ID:359211', '14805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14805', '112', '16682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.10.359211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16683', '1079', '1', 'Markaz Banhā', 'EG.12.359279', 'ASCII:Markaz Banha;ID:359279', '14806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14806', '112', '16683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.12.359279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16684', '1079', '1', 'Markaz az Zaqāzīq', 'EG.14.359494', 'ASCII:Markaz az Zaqaziq;ID:359494', '14807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14807', '112', '16684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.14.359494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16685', '1079', '1', 'Markaz Awlād Ţawq Sharq', 'EG.24.359588', 'ASCII:Markaz Awlad Tawq Sharq;ID:359588', '14808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14808', '112', '16685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.24.359588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16686', '1079', '1', 'Markaz Asyūţ', 'EG.17.359782', 'ASCII:Markaz Asyut;ID:359782', '14809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14809', '112', '16686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.17.359782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16687', '1079', '1', 'Markaz Aswān', 'EG.16.359788', 'ASCII:Markaz Aswan;ID:359788', '14810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14810', '112', '16687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.16.359788» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16688', '1079', '1', 'Markaz as Sanţah', 'EG.05.359850', 'ASCII:Markaz as Santah;ID:359850', '14811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14811', '112', '16688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.05.359850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16689', '1079', '1', 'Markaz aş Şaff', 'EG.08.359901', 'ASCII:Markaz as Saff;ID:359901', '14812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14812', '112', '16689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.08.359901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16690', '1079', '1', 'Markaz ash Shuhadā''', 'EG.09.359954', 'ASCII:Markaz ash Shuhada'';ID:359954', '14813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14813', '112', '16690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.09.359954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16691', '1079', '1', 'Markaz Ashmūn', 'EG.09.360047', 'ASCII:Markaz Ashmun;ID:360047', '14814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14814', '112', '16691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.09.360047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16692', '1079', '1', 'Markaz Armant', 'EG.23.360166', 'ASCII:Markaz Armant;ID:360166', '14815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14815', '112', '16692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.23.360166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16693', '1079', '1', 'Markaz al Wāsiţah', 'EG.18.360466', 'ASCII:Markaz al Wasitah;ID:360466', '14816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14816', '112', '16693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.18.360466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16694', '1079', '1', 'Markaz al Wāḩāt al Khārijah', 'EG.13.360478', 'ASCII:Markaz al Wahat al Kharijah;ID:360478', '14817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14817', '112', '16694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.13.360478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16695', '1079', '1', 'Markaz al Wāḩāt al Baḩrīyah', 'EG.08.360479', 'ASCII:Markaz al Wahat al Bahriyah;ID:360479', '14818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14818', '112', '16695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.08.360479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16696', '1079', '1', 'Markaz al Wāḩāt ad Dākhilah', 'EG.13.360480', 'ASCII:Markaz al Wahat ad Dakhilah;ID:360480', '14819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14819', '112', '16696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.13.360480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16697', '1079', '1', 'Markaz al Uqşur', 'EG.23.360503', 'ASCII:Markaz al Uqsur;ID:360503', '14820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14820', '112', '16697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.23.360503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16698', '1079', '1', 'Markaz al Qūşīyah', 'EG.17.360527', 'ASCII:Markaz al Qusiyah;ID:360527', '14821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14821', '112', '16698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.17.360527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16699', '1079', '1', 'Markaz al Minyā', 'EG.10.360687', 'ASCII:Markaz al Minya;ID:360687', '14822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14822', '112', '16699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.10.360687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16700', '1079', '1', 'Markaz al Minshāh', 'EG.24.360699', 'ASCII:Markaz al Minshah;ID:360699', '14823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14823', '112', '16700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.24.360699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16701', '1079', '1', 'Markaz al Marāghah', 'EG.24.360749', 'ASCII:Markaz al Maraghah;ID:360749', '14824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14824', '112', '16701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.24.360749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16702', '1079', '1', 'Markaz al Manzilah', 'EG.01.360756', 'ASCII:Markaz al Manzilah;ID:360756', '14825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14825', '112', '16702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.01.360756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16703', '1079', '1', 'Markaz al Manşūrah', 'EG.01.360763', 'ASCII:Markaz al Mansurah;ID:360763', '14826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14826', '112', '16703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.01.360763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16704', '1079', '1', 'Markaz al Maḩmūdīyah', 'EG.03.360821', 'ASCII:Markaz al Mahmudiyah;ID:360821', '14827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14827', '112', '16704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.03.360821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16705', '1079', '1', 'Markaz al Maḩallah al Kubrá', 'EG.05.360830', 'ASCII:Markaz al Mahallah al Kubra;ID:360830', '14828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14828', '112', '16705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.05.360830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16706', '1079', '1', 'Markaz al Khānkah', 'EG.12.360929', 'ASCII:Markaz al Khankah;ID:360929', '14829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14829', '112', '16706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.12.360929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16707', '1079', '1', 'Markaz al Jīzah', 'EG.08.360996', 'ASCII:Markaz al Jizah;ID:360996', '14830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14830', '112', '16707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.08.360996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16708', '1079', '1', 'Markaz al `Idwah', 'EG.10.361099', 'ASCII:Markaz al `Idwah;ID:361099', '14831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14831', '112', '16708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.10.361099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16709', '1079', '1', 'Markaz al Ḩusaynīyah', 'EG.14.361127', 'ASCII:Markaz al Husayniyah;ID:361127', '14832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14832', '112', '16709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.14.361127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16710', '1079', '1', 'Markaz al Fayyūm', 'EG.04.361322', 'ASCII:Markaz al Fayyum;ID:361322', '14833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14833', '112', '16710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.04.361322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16711', '1079', '1', 'Markaz al Fashm', 'EG.18.361330', 'ASCII:Markaz al Fashm;ID:361330', '14834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14834', '112', '16711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.18.361330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16712', '1079', '1', 'Markaz al Burullus', 'EG.21.361358', 'ASCII:Markaz al Burullus;ID:361358', '14835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14835', '112', '16712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.21.361358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16713', '1079', '1', 'Markaz al Balyanā', 'EG.24.361436', 'ASCII:Markaz al Balyana;ID:361436', '14836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14836', '112', '16713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.24.361436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16714', '1079', '1', 'Markaz al Badrashayn', 'EG.08.361474', 'ASCII:Markaz al Badrashayn;ID:361474', '14837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14837', '112', '16714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.08.361474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16715', '1079', '1', 'Markaz al Badār', 'EG.17.361479', 'ASCII:Markaz al Badar;ID:361479', '14838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14838', '112', '16715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.17.361479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16716', '1079', '1', 'Markaz al `Ayyāţ', 'EG.08.361497', 'ASCII:Markaz al `Ayyat;ID:361497', '14839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14839', '112', '16716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.08.361497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16717', '1079', '1', 'Markaz Akhmīm', 'EG.24.361660', 'ASCII:Markaz Akhmim;ID:361660', '14840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14840', '112', '16717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.24.361660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16718', '1079', '1', 'Markaz Ajā', 'EG.01.361701', 'ASCII:Markaz Aja;ID:361701', '14841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14841', '112', '16718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.01.361701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16719', '1079', '1', 'Markaz ad Dilinjāt', 'EG.03.361828', 'ASCII:Markaz ad Dilinjat;ID:361828', '14842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14842', '112', '16719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.03.361828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16720', '1079', '1', 'Markaz Abū Tisht', 'EG.23.361994', 'ASCII:Markaz Abu Tisht;ID:361994', '14843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14843', '112', '16720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.23.361994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16721', '1079', '1', 'Markaz Abū Tīj', 'EG.17.362003', 'ASCII:Markaz Abu Tij;ID:362003', '14844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14844', '112', '16721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.17.362003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16722', '1079', '1', 'Markaz Abū Qurqāş', 'EG.10.362276', 'ASCII:Markaz Abu Qurqas;ID:362276', '14845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14845', '112', '16722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.10.362276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16723', '1079', '1', 'Markaz Abū Kabīr', 'EG.14.362484', 'ASCII:Markaz Abu Kabir;ID:362484', '14846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14846', '112', '16723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.14.362484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16724', '1079', '1', 'Markaz Abū Ḩummuş', 'EG.03.362550', 'ASCII:Markaz Abu Hummus;ID:362550', '14847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14847', '112', '16724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.03.362550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16725', '1079', '1', 'Markaz Abū Ḩammād', 'EG.14.362612', 'ASCII:Markaz Abu Hammad;ID:362612', '14848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14848', '112', '16725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.14.362612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16726', '1079', '1', 'Markaz Abū al Maţāmīr', 'EG.03.362880', 'ASCII:Markaz Abu al Matamir;ID:362880', '14849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14849', '112', '16726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «EG.03.362880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16727', '1079', '1', 'Serayē Āwraja', 'ER.00.328827', 'ASCII:Seraye Awraja;ID:328827', '14850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14850', '112', '16727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ER.00.328827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16728', '1079', '1', 'Sahil Āwraja', 'ER.00.329423', 'ASCII:Sahil Awraja;ID:329423', '14851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14851', '112', '16728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ER.00.329423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16729', '1079', '1', 'Hamasēn Āwraja', 'ER.00.335174', 'ASCII:Hamasen Awraja;ID:335174', '14852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14852', '112', '16729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ER.00.335174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16730', '1079', '1', 'Ākale Guzay Āwraja', 'ER.00.344451', 'ASCII:Akale Guzay Awraja;ID:344451', '14853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14853', '112', '16730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ER.00.344451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16731', '1079', '1', 'Barka Āwraja', 'ER.00.413927', 'ASCII:Barka Awraja;ID:413927', '14854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14854', '112', '16731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ER.00.413927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16732', '1079', '1', 'Denkel Āwraja', 'ER.00.413928', 'ASCII:Denkel Awraja;ID:413928', '14855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14855', '112', '16732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ER.00.413928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16733', '1079', '1', 'Semhar Āwraja', 'ER.00.413929', 'ASCII:Semhar Awraja;ID:413929', '14856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14856', '112', '16733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ER.00.413929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16734', '1079', '1', 'Senhit Āwraja', 'ER.00.413930', 'ASCII:Senhit Awraja;ID:413930', '14857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14857', '112', '16734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ER.00.413930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16735', '1079', '1', 'Província de València', 'ES.60.V', 'ASCII:Valencia;ID:2509951', '14858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14858', '112', '16735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.60.V» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16736', '1079', '1', 'Provincia de Toledo', 'ES.54.TO', 'ASCII:Toledo;ID:2510407', '14859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14859', '112', '16736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.54.TO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16737', '1079', '1', 'Provincia de Sevilla', 'ES.51.SE', 'ASCII:Province of Seville;ID:2510910', '14860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14860', '112', '16737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.51.SE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16738', '1079', '1', 'Provincia de Santa Cruz de Tenerife', 'ES.53.TF', 'ASCII:Province of Santa Cruz de Tenerife;ID:2511173', '14861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14861', '112', '16738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.53.TF» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16739', '1079', '1', 'Provincia de Málaga', 'ES.51.MA', 'ASCII:Malaga;ID:2514254', '14862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14862', '112', '16739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.51.MA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16740', '1079', '1', 'Provincia de Las Palmas', 'ES.53.GC', 'ASCII:Province of Las Palmas;ID:2515271', '14863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14863', '112', '16740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.53.GC» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16741', '1079', '1', 'Provincia de Jaén', 'ES.51.J', 'ASCII:Jaen;ID:2516394', '14864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14864', '112', '16741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.51.J» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16742', '1079', '1', 'Provincia de Huelva', 'ES.51.H', 'ASCII:Huelva;ID:2516547', '14865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14865', '112', '16742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.51.H» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16743', '1079', '1', 'Provincia de Granada', 'ES.51.GR', 'ASCII:Province of Granada;ID:2517115', '14866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14866', '112', '16743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.51.GR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16744', '1079', '1', 'Provincia de Cuenca', 'ES.54.CU', 'ASCII:Cuenca;ID:2519034', '14867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14867', '112', '16744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.54.CU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16745', '1079', '1', 'Provincia de Córdoba', 'ES.51.CO', 'ASCII:Cordoba;ID:2519239', '14868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14868', '112', '16745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.51.CO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16746', '1079', '1', 'Provincia de Ciudad Real', 'ES.54.CR', 'ASCII:Ciudad Real;ID:2519401', '14869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14869', '112', '16746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.54.CR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16747', '1079', '1', 'Provincia de Cádiz', 'ES.51.CA', 'ASCII:Cadiz;ID:2520597', '14870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14870', '112', '16747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.51.CA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16748', '1079', '1', 'Provincia de Cáceres', 'ES.57.CC', 'ASCII:Caceres;ID:2520610', '14871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14871', '112', '16748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.57.CC» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16749', '1079', '1', 'Provincia de Badajoz', 'ES.57.BA', 'ASCII:Badajoz;ID:2521419', '14872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14872', '112', '16749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.57.BA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16750', '1079', '1', 'Provincia de Almería', 'ES.51.AL', 'ASCII:Almeria;ID:2521883', '14873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14873', '112', '16750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.51.AL» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16751', '1079', '1', 'Provincia de Alicante', 'ES.60.A', 'ASCII:Alicante;ID:2521976', '14874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14874', '112', '16751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.60.A» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16752', '1079', '1', 'Provincia de Albacete', 'ES.54.AB', 'ASCII:Albacete;ID:2522257', '14875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14875', '112', '16752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.54.AB» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16753', '1079', '1', 'Provincia de Zaragoza', 'ES.52.Z', 'ASCII:Prtovince of Saragossa;ID:3104323', '14876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14876', '112', '16753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.52.Z» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16754', '1079', '1', 'Provincia de Zamora', 'ES.55.ZA', 'ASCII:Zamora;ID:3104341', '14877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14877', '112', '16754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.55.ZA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16755', '1079', '1', 'Provincia de Vizcaya', 'ES.59.BI', 'ASCII:Biscay;ID:3104469', '14878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14878', '112', '16755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.59.BI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16756', '1079', '1', 'Provincia de Valladolid', 'ES.55.VA', 'ASCII:Valladolid;ID:3106671', '14879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14879', '112', '16756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.55.VA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16757', '1079', '1', 'Provincia de Teruel', 'ES.52.TE', 'ASCII:Province of Teruel;ID:3108125', '14880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14880', '112', '16757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.52.TE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16758', '1079', '1', 'Província de Tarragona', 'ES.56.T', 'ASCII:Province of Tarragona;ID:3108287', '14881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14881', '112', '16758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.56.T» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16759', '1079', '1', 'Provincia de Soria', 'ES.55.SO', 'ASCII:Soria;ID:3108680', '14882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14882', '112', '16759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.55.SO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16760', '1079', '1', 'Provincia de Segovia', 'ES.55.SG', 'ASCII:Segovia;ID:3109254', '14883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14883', '112', '16760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.55.SG» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16761', '1079', '1', 'Provincia de Cantabria', 'ES.39.S', 'ASCII:Province of Cantabria;ID:3109716', '14884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14884', '112', '16761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.39.S» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16762', '1079', '1', 'Provincia de Salamanca', 'ES.55.SA', 'ASCII:Salamanca;ID:3111107', '14885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14885', '112', '16762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.55.SA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16763', '1079', '1', 'Provincia de Pontevedra', 'ES.58.PO', 'ASCII:Pontevedra;ID:3113208', '14886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14886', '112', '16763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.58.PO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16764', '1079', '1', 'Provincia de Palencia', 'ES.55.P', 'ASCII:Palencia;ID:3114530', '14887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14887', '112', '16764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.55.P» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16765', '1079', '1', 'Provincia de Ourense', 'ES.58.OR', 'ASCII:Ourense;ID:3114964', '14888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14888', '112', '16765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.58.OR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16766', '1079', '1', 'Provincia de Lugo', 'ES.58.LU', 'ASCII:Lugo;ID:3117813', '14889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14889', '112', '16766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.58.LU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16767', '1079', '1', 'Provincia de León', 'ES.55.LE', 'ASCII:Leon;ID:3118528', '14890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14890', '112', '16767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.55.LE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16768', '1079', '1', 'Provincia de A Coruña', 'ES.58.C', 'ASCII:Corunna;ID:3119840', '14891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14891', '112', '16768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.58.C» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16769', '1079', '1', 'Provincia de Huesca', 'ES.52.HU', 'ASCII:Province of Huesca;ID:3120513', '14892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14892', '112', '16769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.52.HU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16770', '1079', '1', 'Gipuzkoa', 'ES.59.SS', 'ASCII:Guipuzcoa;ID:3120935', '14893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14893', '112', '16770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.59.SS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16771', '1079', '1', 'Provincia de Guadalajara', 'ES.54.GU', 'ASCII:Guadalajara;ID:3121069', '14894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14894', '112', '16771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.54.GU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16772', '1079', '1', 'Província de Castelló', 'ES.60.CS', 'ASCII:Castellon;ID:3125881', '14895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14895', '112', '16772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.60.CS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16773', '1079', '1', 'Provincia de Burgos', 'ES.55.BU', 'ASCII:Burgos;ID:3127460', '14896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14896', '112', '16773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.55.BU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16774', '1079', '1', 'Província de Barcelona', 'ES.56.B', 'ASCII:Province of Barcelona;ID:3128759', '14897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14897', '112', '16774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.56.B» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16775', '1079', '1', 'Provincia de Ávila', 'ES.55.AV', 'ASCII:Avila;ID:3129138', '14898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14898', '112', '16775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.55.AV» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16776', '1079', '1', 'Provincia de Álava', 'ES.59.VI', 'ASCII:Alava;ID:3130717', '14899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14899', '112', '16776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.59.VI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16777', '1079', '1', 'Província de Girona', 'ES.56.GI', 'ASCII:Province of Girona;ID:6355230', '14900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14900', '112', '16777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.56.GI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16778', '1079', '1', 'Província de Lleida', 'ES.56.L', 'ASCII:Province of Lleida;ID:6355231', '14901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14901', '112', '16778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.56.L» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16779', '1079', '1', 'Provincia de La Rioja', 'ES.27.LO', 'ASCII:Province of La Rioja;ID:6355232', '14902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14902', '112', '16779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.27.LO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16780', '1079', '1', 'Provincia de Madrid', 'ES.29.M', 'ASCII:Province of Madrid;ID:6355233', '14903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14903', '112', '16780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.29.M» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16781', '1079', '1', 'Provincia de Murcia', 'ES.31.MU', 'ASCII:Province of Murcia;ID:6355234', '14904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14904', '112', '16781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.31.MU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16782', '1079', '1', 'Provincia de Navarra', 'ES.32.NA', 'ASCII:Province of Navarre;ID:6355235', '14905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14905', '112', '16782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.32.NA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16783', '1079', '1', 'Provincia de Asturias', 'ES.34.O', 'ASCII:Province of Asturias;ID:6355236', '14906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14906', '112', '16783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.34.O» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16784', '1079', '1', 'Illes Balears', 'ES.07.PM', 'ASCII:Province of Balearic Islands;ID:6424360', '14907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14907', '112', '16784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ES.07.PM» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16785', '1079', '1', 'Welayita Āwraja', 'ET.54.326423', 'ASCII:Welayita Awraja;ID:326423', '14908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14908', '112', '16785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ET.54.326423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16786', '1079', '1', 'Landskapet Åland', 'FI.01.830602', 'ASCII:Landskapet Aland;ID:830602', '14909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14909', '112', '16786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.01.830602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16787', '1079', '1', 'Lappland', 'FI.06.19', 'ASCII:Lappland;ID:830603', '14910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14910', '112', '16787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.06.19» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16788', '1079', '1', 'Kainuu', 'FI.08.18', 'ASCII:Kainuu;ID:830664', '14911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14911', '112', '16788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.08.18» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16789', '1079', '1', 'Norra Österbotten', 'FI.08.17', 'ASCII:Norra Osterbotten;ID:830667', '14912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14912', '112', '16789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.08.17» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16790', '1079', '1', 'Mellersta Österbotten', 'FI.15.16', 'ASCII:Mellersta Osterbotten;ID:830675', '14913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14913', '112', '16790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.15.16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16791', '1079', '1', 'Österbotten', 'FI.15.15', 'ASCII:Osterbotten;ID:830676', '14914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14914', '112', '16791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.15.15» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16792', '1079', '1', 'Södra Österbotten', 'FI.15.14', 'ASCII:Sodra Osterbotten;ID:830682', '14915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14915', '112', '16792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.15.14» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16793', '1079', '1', 'Mellersta Finland', 'FI.15.13', 'ASCII:Mellersta Finland;ID:830685', '14916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14916', '112', '16793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.15.13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16794', '1079', '1', 'Norra Karelen', 'FI.14.12', 'ASCII:North Karelia;ID:830686', '14917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14917', '112', '16794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.14.12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16795', '1079', '1', 'Savo', 'FI.14.11', 'ASCII:Savo;ID:830690', '14918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14918', '112', '16795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.14.11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16796', '1079', '1', 'Etelä-Savo', 'FI.14.10', 'ASCII:Etela-Savo;ID:830695', '14919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14919', '112', '16796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.14.10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16797', '1079', '1', 'Etelä-Karjala', 'FI.13.09', 'ASCII:South Karelia;ID:830699', '14920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14920', '112', '16797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.13.09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16798', '1079', '1', 'Kymenlaakso', 'FI.13.08', 'ASCII:Kymenlaakso;ID:830703', '14921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14921', '112', '16798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.13.08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16799', '1079', '1', 'Birkaland', 'FI.15.06', 'ASCII:Pirkanmaa;ID:830704', '14922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14922', '112', '16799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.15.06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16800', '1079', '1', 'Tavastland', 'FI.13.05', 'ASCII:Tavastland;ID:830705', '14923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14923', '112', '16800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.13.05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16801', '1079', '1', 'Östra Nyland', 'FI.13.03', 'ASCII:Ostra Nyland;ID:830706', '14924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14924', '112', '16801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.13.03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16802', '1079', '1', 'Varsinais-Suomi', 'FI.15.02', 'ASCII:Varsinais-Suomi;ID:830708', '14925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14925', '112', '16802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.15.02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16803', '1079', '1', 'Nyland', 'FI.13.01', 'ASCII:Uusimaa;ID:830709', '14926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14926', '112', '16803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.13.01» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16804', '1079', '1', 'Päijät-Häme', 'FI.13.07', 'ASCII:Paijat-Hame;ID:831040', '14927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14927', '112', '16804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.13.07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16805', '1079', '1', 'Satakunta', 'FI.15.04', 'ASCII:Satakunta;ID:831041', '14928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14928', '112', '16805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FI.15.04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16806', '1079', '1', 'Malem', 'FM.01.2081136', 'ASCII:Malem;ID:2081136', '14929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14929', '112', '16806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FM.01.2081136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16807', '1079', '1', 'Tuwunbey', 'FM.02.2081300', 'ASCII:Tuwunbey;ID:2081300', '14930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14930', '112', '16807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FM.02.2081300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16808', '1079', '1', 'Tafunsak', 'FM.01.2081396', 'ASCII:Tafunsak;ID:2081396', '14931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14931', '112', '16808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FM.01.2081396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16809', '1079', '1', 'Peken', 'FM.03.2081630', 'ASCII:Peken;ID:2081630', '14932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14932', '112', '16809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FM.03.2081630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16810', '1079', '1', 'Net', 'FM.02.2081777', 'ASCII:Net;ID:2081777', '14933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14933', '112', '16810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FM.02.2081777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16811', '1079', '1', 'Madolenihmw', 'FM.02.2081972', 'ASCII:Madolenihmw;ID:2081972', '14934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14934', '112', '16811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FM.02.2081972» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16812', '1079', '1', 'Kuchua', 'FM.03.2082032', 'ASCII:Kuchua;ID:2082032', '14935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14935', '112', '16812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FM.03.2082032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16813', '1079', '1', 'Kiti', 'FM.02.2082042', 'ASCII:Kiti;ID:2082042', '14936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14936', '112', '16813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FM.02.2082042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16814', '1079', '1', 'Inuk', 'FM.03.2082073', 'ASCII:Inuk;ID:2082073', '14937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14937', '112', '16814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FM.03.2082073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16815', '1079', '1', 'Enin', 'FM.03.2082234', 'ASCII:Enin;ID:2082234', '14938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14938', '112', '16815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FM.03.2082234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16816', '1079', '1', 'Département des Yvelines', 'FR.A8.78', 'ASCII:Yvelines;ID:2967196', '14939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14939', '112', '16816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A8.78» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16817', '1079', '1', 'Département de l''Yonne', 'FR.A1.89', 'ASCII:Yonne;ID:2967222', '14940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14940', '112', '16817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A1.89» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16818', '1079', '1', 'Département des Vosges', 'FR.B2.88', 'ASCII:Vosges;ID:2967681', '14941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14941', '112', '16818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B2.88» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16819', '1079', '1', 'Département de Ville-de-Paris', 'FR.A8.75', 'ASCII:Paris;ID:2968815', '14942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14942', '112', '16819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A8.75» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16820', '1079', '1', 'Département de la Vienne', 'FR.B7.86', 'ASCII:Vienne;ID:2969280', '14943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14943', '112', '16820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B7.86» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16821', '1079', '1', 'Département de la Vendée', 'FR.B5.85', 'ASCII:Vendee;ID:2970140', '14944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14944', '112', '16821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B5.85» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16822', '1079', '1', 'Département du Vaucluse', 'FR.B8.84', 'ASCII:Vaucluse;ID:2970554', '14945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14945', '112', '16822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B8.84» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16823', '1079', '1', 'Département du Var', 'FR.B8.83', 'ASCII:Var;ID:2970749', '14946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14946', '112', '16823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B8.83» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16824', '1079', '1', 'Département du Val-d''Oise', 'FR.A8.95', 'ASCII:Val d''Oise;ID:2971071', '14947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14947', '112', '16824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A8.95» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16825', '1079', '1', 'Département du Val-de-Marne', 'FR.A8.94', 'ASCII:Val-de-Marne;ID:2971090', '14948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14948', '112', '16825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A8.94» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16826', '1079', '1', 'Département du Tarn-et-Garonne', 'FR.B3.82', 'ASCII:Tarn-et-Garonne;ID:2973357', '14949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14949', '112', '16826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B3.82» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16827', '1079', '1', 'Département du Tarn', 'FR.B3.81', 'ASCII:Tarn;ID:2973362', '14950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14950', '112', '16827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B3.81» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16828', '1079', '1', 'Département de la Somme', 'FR.B6.80', 'ASCII:Somme;ID:2974304', '14951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14951', '112', '16828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B6.80» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16829', '1079', '1', 'Département de Seine-Saint-Denis', 'FR.A8.93', 'ASCII:Seine-Saint-Denis;ID:2975246', '14952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14952', '112', '16829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A8.93» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16830', '1079', '1', 'Département de la Seine-Maritime', 'FR.A7.76', 'ASCII:Seine-Maritime;ID:2975248', '14953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14953', '112', '16830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A7.76» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16831', '1079', '1', 'Département de Seine-et-Marne', 'FR.A8.77', 'ASCII:Seine-et-Marne;ID:2975249', '14954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14954', '112', '16831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A8.77» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16832', '1079', '1', 'Département de la Savoie', 'FR.B9.73', 'ASCII:Savoy;ID:2975517', '14955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14955', '112', '16832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B9.73» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16833', '1079', '1', 'Département de la Sarthe', 'FR.B5.72', 'ASCII:Sarthe;ID:2975926', '14956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14956', '112', '16833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B5.72» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16834', '1079', '1', 'Département de Saône-et-Loire', 'FR.A1.71', 'ASCII:Saone-et-Loire;ID:2976082', '14957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14957', '112', '16834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A1.71» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16835', '1079', '1', 'Département des Pyrénées-Orientales', 'FR.A9.66', 'ASCII:Pyrenees-Orientales;ID:2984885', '14958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14958', '112', '16835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A9.66» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16836', '1079', '1', 'Département des Pyrénées-Atlantiques', 'FR.97.64', 'ASCII:Pyrenees-Atlantiques;ID:2984887', '14959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14959', '112', '16836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.97.64» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16837', '1079', '1', 'Département du Puy-de-Dôme', 'FR.98.63', 'ASCII:Puy-de-Dome;ID:2984986', '14960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14960', '112', '16837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.98.63» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16838', '1079', '1', 'Département du Rhône', 'FR.B9.69', 'ASCII:Rhone;ID:2987410', '14961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14961', '112', '16838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B9.69» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16839', '1079', '1', 'Département du Pas-de-Calais', 'FR.B4.62', 'ASCII:Pas-de-Calais;ID:2988430', '14962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14962', '112', '16839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B4.62» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16840', '1079', '1', 'Département de l''Orne', 'FR.99.61', 'ASCII:Orne;ID:2989247', '14963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14963', '112', '16840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.99.61» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16841', '1079', '1', 'Département de l''Oise', 'FR.B6.60', 'ASCII:Oise;ID:2989663', '14964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14964', '112', '16841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B6.60» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16842', '1079', '1', 'Département du Nord', 'FR.B4.59', 'ASCII:North;ID:2990129', '14965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14965', '112', '16842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B4.59» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16843', '1079', '1', 'Département de la Nièvre', 'FR.A1.58', 'ASCII:Nievre;ID:2990371', '14966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14966', '112', '16843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A1.58» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16844', '1079', '1', 'Département de la Moselle', 'FR.B2.57', 'ASCII:Moselle;ID:2991627', '14967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14967', '112', '16844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B2.57» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16845', '1079', '1', 'Département du Morbihan', 'FR.A2.56', 'ASCII:Morbihan;ID:2991879', '14968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14968', '112', '16845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A2.56» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16846', '1079', '1', 'Département de la Meuse', 'FR.B2.55', 'ASCII:Meuse;ID:2994106', '14969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14969', '112', '16846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B2.55» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16847', '1079', '1', 'Département de Meurthe-et-Moselle', 'FR.B2.54', 'ASCII:Meurthe et Moselle;ID:2994111', '14970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14970', '112', '16847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B2.54» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16848', '1079', '1', 'Département de la Mayenne', 'FR.B5.53', 'ASCII:Mayenne;ID:2994932', '14971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14971', '112', '16848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B5.53» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16849', '1079', '1', 'Département de la Marne', 'FR.A4.51', 'ASCII:Marne;ID:2995603', '14972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14972', '112', '16849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A4.51» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16850', '1079', '1', 'Département de la Manche', 'FR.99.50', 'ASCII:Manche;ID:2996268', '14973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14973', '112', '16850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.99.50» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16851', '1079', '1', 'Département de Maine-et-Loire', 'FR.B5.49', 'ASCII:Maine-et-Loire;ID:2996663', '14974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14974', '112', '16851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B5.49» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16852', '1079', '1', 'Département de la Lozère', 'FR.A9.48', 'ASCII:Lozere;ID:2997288', '14975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14975', '112', '16852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A9.48» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16853', '1079', '1', 'Département du Lot-et-Garonne', 'FR.97.47', 'ASCII:Lot-et-Garonne;ID:2997523', '14976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14976', '112', '16853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.97.47» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16854', '1079', '1', 'Département du Lot', 'FR.B3.46', 'ASCII:Lot;ID:2997524', '14977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14977', '112', '16854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B3.46» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16855', '1079', '1', 'Département du Loir-et-Cher', 'FR.A3.41', 'ASCII:Loir-et-Cher;ID:2997856', '14978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14978', '112', '16855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A3.41» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16856', '1079', '1', 'Département du Loiret', 'FR.A3.45', 'ASCII:Loiret;ID:2997857', '14979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14979', '112', '16856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A3.45» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16857', '1079', '1', 'Département de la Loire-Atlantique', 'FR.B5.44', 'ASCII:Loire-Atlantique;ID:2997861', '14980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14980', '112', '16857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B5.44» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16858', '1079', '1', 'Département de la Loire', 'FR.B9.42', 'ASCII:Loire;ID:2997870', '14981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14981', '112', '16858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B9.42» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16859', '1079', '1', 'Département des Landes', 'FR.97.40', 'ASCII:Landes;ID:3007866', '14982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14982', '112', '16859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.97.40» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16860', '1079', '1', 'Département du Jura', 'FR.A6.39', 'ASCII:Jura;ID:3012051', '14983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14983', '112', '16860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A6.39» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16861', '1079', '1', 'Département de l''Isère', 'FR.B9.38', 'ASCII:Isere;ID:3012715', '14984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14984', '112', '16861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B9.38» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16862', '1079', '1', 'Département d''Indre-et-Loire', 'FR.A3.37', 'ASCII:Indre and Loire;ID:3012804', '14985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14985', '112', '16862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A3.37» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16863', '1079', '1', 'Département de l''Indre', 'FR.A3.36', 'ASCII:Indre;ID:3012805', '14986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14986', '112', '16863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A3.36» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16864', '1079', '1', 'Département d''Ille-et-Vilaine', 'FR.A2.35', 'ASCII:Ille-et-Vilaine;ID:3012849', '14987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14987', '112', '16864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A2.35» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16865', '1079', '1', 'Département de l''Hérault', 'FR.A9.34', 'ASCII:Herault;ID:3013500', '14988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14988', '112', '16865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A9.34» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16866', '1079', '1', 'Département des Hauts-de-Seine', 'FR.A8.92', 'ASCII:Hauts-de-Seine;ID:3013657', '14989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14989', '112', '16866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A8.92» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16867', '1079', '1', 'Département du Haut-Rhin', 'FR.C1.68', 'ASCII:Haut-Rhin;ID:3013663', '14990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14990', '112', '16867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.C1.68» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16868', '1079', '1', 'Département de la Haute-Vienne', 'FR.B1.87', 'ASCII:Haute-Vienne;ID:3013719', '14991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14991', '112', '16868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B1.87» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16869', '1079', '1', 'Département des Hautes-Pyrénées', 'FR.B3.65', 'ASCII:Hautes-Pyrenees;ID:3013726', '14992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14992', '112', '16869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B3.65» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16870', '1079', '1', 'Département de la Haute-Savoie', 'FR.B9.74', 'ASCII:Haute-Savoie;ID:3013736', '14993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14993', '112', '16870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B9.74» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16871', '1079', '1', 'Département de la Haute-Saône', 'FR.A6.70', 'ASCII:Haute-Saone;ID:3013737', '14994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14994', '112', '16871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A6.70» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16872', '1079', '1', 'Département des Hautes-Alpes', 'FR.B8.05', 'ASCII:Hautes-Alpes;ID:3013738', '14995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14995', '112', '16872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B8.05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16873', '1079', '1', 'Département de la Haute-Marne', 'FR.A4.52', 'ASCII:Haute-Marne;ID:3013757', '14996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14996', '112', '16873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A4.52» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16874', '1079', '1', 'Département de la Haute-Loire', 'FR.98.43', 'ASCII:Haute-Loire;ID:3013760', '14997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14997', '112', '16874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.98.43» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16875', '1079', '1', 'Département de la Haute-Garonne', 'FR.B3.31', 'ASCII:Upper Garonne;ID:3013767', '14998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14998', '112', '16875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B3.31» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16876', '1079', '1', 'Département de la Haute-Corse', 'FR.A5.2B', 'ASCII:Upper Corsica;ID:3013793', '14999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('14999', '112', '16876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A5.2B» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16877', '1079', '1', 'Département de la Gironde', 'FR.97.33', 'ASCII:Gironde;ID:3015948', '15000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15000', '112', '16877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.97.33» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16878', '1079', '1', 'Département du Gers', 'FR.B3.32', 'ASCII:Gers;ID:3016194', '15001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15001', '112', '16878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B3.32» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16879', '1079', '1', 'Département du Gard', 'FR.A9.30', 'ASCII:Gard;ID:3016670', '15002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15002', '112', '16879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A9.30» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16880', '1079', '1', 'Département du Finistère', 'FR.A2.29', 'ASCII:Finistere;ID:3018471', '15003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15003', '112', '16880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A2.29» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16881', '1079', '1', 'Département d''Eure-et-Loir', 'FR.A3.28', 'ASCII:Eure-et-Loir;ID:3019316', '15004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15004', '112', '16881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A3.28» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16882', '1079', '1', 'Département de l''Eure', 'FR.A7.27', 'ASCII:Eure;ID:3019317', '15005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15005', '112', '16882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A7.27» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16883', '1079', '1', 'Département de l''Essonne', 'FR.A8.91', 'ASCII:Essonne;ID:3019599', '15006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15006', '112', '16883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A8.91» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16884', '1079', '1', 'Département de la Drôme', 'FR.B9.26', 'ASCII:Drome;ID:3020781', '15007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15007', '112', '16884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B9.26» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16885', '1079', '1', 'Département du Doubs', 'FR.A6.25', 'ASCII:Doubs;ID:3020989', '15008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15008', '112', '16885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A6.25» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16886', '1079', '1', 'Département de la Dordogne', 'FR.97.24', 'ASCII:Dordogne;ID:3021042', '15009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15009', '112', '16886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.97.24» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16887', '1079', '1', 'Département des Deux-Sèvres', 'FR.B7.79', 'ASCII:Deux-Sevres;ID:3021501', '15010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15010', '112', '16887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B7.79» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16888', '1079', '1', 'Département de la Creuse', 'FR.B1.23', 'ASCII:Creuse;ID:3022516', '15011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15011', '112', '16888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B1.23» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16889', '1079', '1', 'Département des Côtes-d''Armor', 'FR.A2.22', 'ASCII:Cotes-d''Armor;ID:3023414', '15012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15012', '112', '16889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A2.22» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16890', '1079', '1', 'Département de la Côte-d''Or', 'FR.A1.21', 'ASCII:Cote d''Or;ID:3023423', '15013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15013', '112', '16890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A1.21» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16891', '1079', '1', 'Département de la Corse-du-Sud', 'FR.A5.2A', 'ASCII:South Corsica;ID:3023514', '15014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15014', '112', '16891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A5.2A» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16892', '1079', '1', 'Département de la Corrèze', 'FR.B1.19', 'ASCII:Correze;ID:3023532', '15015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15015', '112', '16892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B1.19» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16893', '1079', '1', 'Département du Cher', 'FR.A3.18', 'ASCII:Cher;ID:3025480', '15016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15016', '112', '16893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A3.18» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16894', '1079', '1', 'Département de la Charente-Maritime', 'FR.B7.17', 'ASCII:Charente-Maritime;ID:3026644', '15017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15017', '112', '16894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B7.17» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16895', '1079', '1', 'Département de la Charente', 'FR.B7.16', 'ASCII:Charente;ID:3026646', '15018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15018', '112', '16895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B7.16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16896', '1079', '1', 'Département du Cantal', 'FR.98.15', 'ASCII:Cantal;ID:3028791', '15019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15019', '112', '16896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.98.15» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16897', '1079', '1', 'Département du Calvados', 'FR.99.14', 'ASCII:Calvados;ID:3029094', '15020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15020', '112', '16897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.99.14» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16898', '1079', '1', 'Département des Bouches-du-Rhône', 'FR.B8.13', 'ASCII:Bouches-du-Rhone;ID:3031359', '15021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15021', '112', '16898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B8.13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16899', '1079', '1', 'Territoire de Belfort', 'FR.A6.90', 'ASCII:Territoire de Belfort;ID:3033789', '15022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15022', '112', '16899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A6.90» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16900', '1079', '1', 'Département du Bas-Rhin', 'FR.C1.67', 'ASCII:Bas-Rhin;ID:3034720', '15023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15023', '112', '16900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.C1.67» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16901', '1079', '1', 'Département de l''Aveyron', 'FR.B3.12', 'ASCII:Aveyron;ID:3035691', '15024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15024', '112', '16901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B3.12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16902', '1079', '1', 'Département de l''Aude', 'FR.A9.11', 'ASCII:Aude;ID:3036264', '15025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15025', '112', '16902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A9.11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16903', '1079', '1', 'Département de l''Aube', 'FR.A4.10', 'ASCII:Aube;ID:3036420', '15026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15026', '112', '16903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A4.10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16904', '1079', '1', 'Département de l''Ariège', 'FR.B3.09', 'ASCII:Ariege;ID:3036965', '15027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15027', '112', '16904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B3.09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16905', '1079', '1', 'Département des Ardennes', 'FR.A4.08', 'ASCII:Ardennes;ID:3037136', '15028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15028', '112', '16905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.A4.08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16906', '1079', '1', 'Département de l''Ardèche', 'FR.B9.07', 'ASCII:Ardeche;ID:3037147', '15029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15029', '112', '16906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B9.07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16907', '1079', '1', 'Département des Alpes-Maritimes', 'FR.B8.06', 'ASCII:Alpes-Maritimes;ID:3038049', '15030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15030', '112', '16907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B8.06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16908', '1079', '1', 'Département des Alpes-de-Haute-Provence', 'FR.B8.04', 'ASCII:Alpes-de-Haute-Provence;ID:3038050', '15031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15031', '112', '16908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B8.04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16909', '1079', '1', 'Département de l''Allier', 'FR.98.03', 'ASCII:Allier;ID:3038111', '15032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15032', '112', '16909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.98.03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16910', '1079', '1', 'Département de l''Aisne', 'FR.B6.02', 'ASCII:Aisne;ID:3038375', '15033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15033', '112', '16910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B6.02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16911', '1079', '1', 'Département de l''Ain', 'FR.B9.01', 'ASCII:Ain;ID:3038422', '15034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15034', '112', '16911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «FR.B9.01» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16912', '1079', '1', 'City of York', 'GB.ENG.Q5', 'ASCII:York City;ID:2633351', '15035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15035', '112', '16912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.Q5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16913', '1079', '1', 'Bwrdeistref Sirol Wrecsam', 'GB.WLS.Z4', 'ASCII:County Borough of Wrexham;ID:2633484', '15036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15036', '112', '16913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Z4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16914', '1079', '1', 'County of Worcestershire', 'GB.ENG.Q4', 'ASCII:Worcestershire;ID:2633560', '15037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15037', '112', '16914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.Q4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16915', '1079', '1', 'Royal Borough of Windsor and Maidenhead', 'GB.ENG.P9', 'ASCII:Windsor and Maidenhead;ID:2633840', '15038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15038', '112', '16915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.P9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16916', '1079', '1', 'County of Wiltshire', 'GB.ENG.P8', 'ASCII:Wiltshire;ID:2633868', '15039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15039', '112', '16916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.P8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16917', '1079', '1', 'West Yorkshire', 'GB.ENG.45', 'ASCII:West Yorkshire;ID:2634219', '15040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15040', '112', '16917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.45» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16918', '1079', '1', 'County of West Sussex', 'GB.ENG.P6', 'ASCII:West Sussex;ID:2634258', '15041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15041', '112', '16918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.P6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16919', '1079', '1', 'West Midlands', 'GB.ENG.00', 'ASCII:West Midlands;ID:2634343', '15042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15042', '112', '16919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.00» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16920', '1079', '1', 'West Lothian', 'GB.SCT.W9', 'ASCII:West Lothian;ID:2634354', '15043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15043', '112', '16920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.W9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16921', '1079', '1', 'Eilean Siar', 'GB.SCT.W8', 'ASCII:Western Isles;ID:2634428', '15044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15044', '112', '16921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.W8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16922', '1079', '1', 'County of Warwickshire', 'GB.ENG.P3', 'ASCII:Warwickshire;ID:2634723', '15045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15045', '112', '16922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.P3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16923', '1079', '1', 'Bro Morgannwg', 'GB.WLS.Z3', 'ASCII:Vale of Glamorgan;ID:2635028', '15046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15046', '112', '16923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Z3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16924', '1079', '1', 'County Tyròne', 'GB.NIR.00', 'ASCII:County Tyrone;ID:2635259', '15047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15047', '112', '16924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.00» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16925', '1079', '1', 'Tyne and Wear', 'GB.ENG.41', 'ASCII:Tyne and Wear;ID:2635274', '15048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15048', '112', '16925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.41» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16926', '1079', '1', 'London Borough of Tower Hamlets', 'GB.ENG.O5', 'ASCII:Tower Hamlets;ID:2635594', '15049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15049', '112', '16926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.O5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16927', '1079', '1', 'Borough of Thurrock', 'GB.ENG.O3', 'ASCII:Thurrock;ID:2635885', '15050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15050', '112', '16927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.O3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16928', '1079', '1', 'County of Surrey', 'GB.ENG.N7', 'ASCII:Surrey;ID:2636512', '15051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15051', '112', '16928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.N7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16929', '1079', '1', 'County of Suffolk', 'GB.ENG.N5', 'ASCII:Suffolk;ID:2636561', '15052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15052', '112', '16929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.N5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16930', '1079', '1', 'Strabane District', 'GB.NIR.T4', 'ASCII:Strabane;ID:2636745', '15053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15053', '112', '16930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.T4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16931', '1079', '1', 'Stirling', 'GB.SCT.W6', 'ASCII:Stirling;ID:2636909', '15054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15054', '112', '16931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.W6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16932', '1079', '1', 'County of Staffordshire', 'GB.ENG.M9', 'ASCII:Staffordshire;ID:2637141', '15055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15055', '112', '16932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.M9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16933', '1079', '1', 'South Yorkshire', 'GB.ENG.37', 'ASCII:South Yorkshire;ID:2637273', '15056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15056', '112', '16933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.37» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16934', '1079', '1', 'County of Somerset', 'GB.ENG.M3', 'ASCII:Somerset;ID:2637532', '15057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15057', '112', '16934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.M3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16935', '1079', '1', 'Shetland Islands', 'GB.SCT.W3', 'ASCII:Shetland;ID:2638010', '15058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15058', '112', '16935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.W3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16936', '1079', '1', 'Isles of Scilly', 'GB.ENG.IOS', 'ASCII:Isles of Scilly;ID:2638384', '15059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15059', '112', '16936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.IOS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16937', '1079', '1', 'County of Shropshire', 'GB.ENG.L6', 'ASCII:Shropshire;ID:2638655', '15060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15060', '112', '16937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.L6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16938', '1079', '1', 'District of Rutland', 'GB.ENG.L4', 'ASCII:Rutland;ID:2638918', '15061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15061', '112', '16938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.L4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16939', '1079', '1', 'Renfrewshire', 'GB.SCT.W2', 'ASCII:Renfrewshire;ID:2639494', '15062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15062', '112', '16939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.W2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16940', '1079', '1', 'Sir Powys', 'GB.WLS.Y8', 'ASCII:County of Powys;ID:2639944', '15063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15063', '112', '16940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Y8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16941', '1079', '1', 'Pembrokeshire', 'GB.WLS.Y7', 'ASCII:County of Pembrokeshire;ID:2640500', '15064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15064', '112', '16941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Y7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16942', '1079', '1', 'County of Oxfordshire', 'GB.ENG.K2', 'ASCII:Oxfordshire;ID:2640726', '15065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15065', '112', '16942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.K2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16943', '1079', '1', 'Orkney Islands', 'GB.SCT.V9', 'ASCII:Orkney;ID:2640923', '15066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15066', '112', '16943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.V9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16944', '1079', '1', 'Omagh District', 'GB.NIR.T3', 'ASCII:Omagh;ID:2640968', '15067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15067', '112', '16944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.T3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16945', '1079', '1', 'County of Nottinghamshire', 'GB.ENG.J9', 'ASCII:Nottinghamshire;ID:2641169', '15068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15068', '112', '16945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.J9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16946', '1079', '1', 'County of North Yorkshire', 'GB.ENG.J7', 'ASCII:North Yorkshire;ID:2641209', '15069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15069', '112', '16946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.J7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16947', '1079', '1', 'County of Northumberland', 'GB.ENG.J6', 'ASCII:Northumberland;ID:2641235', '15070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15070', '112', '16947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.J6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16948', '1079', '1', 'Borough of North Tyneside', 'GB.ENG.J5', 'ASCII:North Tyneside;ID:2641238', '15071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15071', '112', '16948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.J5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16949', '1079', '1', 'County of Northamptonshire', 'GB.ENG.J1', 'ASCII:Northamptonshire;ID:2641429', '15072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15072', '112', '16949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.J1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16950', '1079', '1', 'County of Norfolk', 'GB.ENG.I9', 'ASCII:Norfolk;ID:2641455', '15073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15073', '112', '16950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.I9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16951', '1079', '1', 'Newtownabbey District', 'GB.NIR.T1', 'ASCII:Newtownabbey;ID:2641521', '15074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15074', '112', '16951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.T1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16952', '1079', '1', 'Newry and Mourne District', 'GB.NIR.S9', 'ASCII:Newry and Mourne;ID:2641580', '15075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15075', '112', '16952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.S9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16953', '1079', '1', 'London Borough of Newham', 'GB.ENG.I8', 'ASCII:Newham;ID:2641639', '15076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15076', '112', '16953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.I8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16954', '1079', '1', 'Moyle District', 'GB.NIR.S8', 'ASCII:Moyle;ID:2642068', '15077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15077', '112', '16954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.S8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16955', '1079', '1', 'Moray', 'GB.SCT.V6', 'ASCII:Moray;ID:2642240', '15078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15078', '112', '16955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.V6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16956', '1079', '1', 'Midlothian', 'GB.SCT.V5', 'ASCII:Midlothian;ID:2642559', '15079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15079', '112', '16956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.V5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16957', '1079', '1', 'Magherafelt District', 'GB.NIR.S7', 'ASCII:Magherafelt;ID:2643209', '15080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15080', '112', '16957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.S7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16958', '1079', '1', 'City of Derry', 'GB.NIR.S6', 'ASCII:Londonderry;ID:2643737', '15081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15081', '112', '16958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.S6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16959', '1079', '1', 'Lisburn District', 'GB.NIR.S5', 'ASCII:Lisburn;ID:2644412', '15082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15082', '112', '16959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.S5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16960', '1079', '1', 'County of Lincolnshire', 'GB.ENG.H7', 'ASCII:Lincolnshire;ID:2644486', '15083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15083', '112', '16960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.H7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16961', '1079', '1', 'Limavady District', 'GB.NIR.S4', 'ASCII:Limavady;ID:2644502', '15084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15084', '112', '16961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.S4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16962', '1079', '1', 'County of Leicestershire', 'GB.ENG.H5', 'ASCII:Leicestershire;ID:2644667', '15085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15085', '112', '16962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.H5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16963', '1079', '1', 'Larne District', 'GB.NIR.S3', 'ASCII:Larne;ID:2644850', '15086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15086', '112', '16963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.S3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16964', '1079', '1', 'County of Lancashire', 'GB.ENG.H2', 'ASCII:Lancashire;ID:2644974', '15087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15087', '112', '16964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.H2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16965', '1079', '1', 'County of Isle of Wight', 'GB.ENG.G2', 'ASCII:Isle of Wight;ID:2646007', '15088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15088', '112', '16965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.G2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16966', '1079', '1', 'Inverclyde', 'GB.SCT.V4', 'ASCII:Inverclyde;ID:2646127', '15089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15089', '112', '16966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.V4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16967', '1079', '1', 'Highland', 'GB.SCT.V3', 'ASCII:Highland;ID:2646944', '15090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15090', '112', '16967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.V3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16968', '1079', '1', 'County of Hertfordshire', 'GB.ENG.F8', 'ASCII:Hertfordshire;ID:2647043', '15091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15091', '112', '16968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.F8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16969', '1079', '1', 'County of Herefordshire', 'GB.ENG.F7', 'ASCII:Herefordshire;ID:2647071', '15092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15092', '112', '16969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.F7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16970', '1079', '1', 'Hampshire', 'GB.ENG.F2', 'ASCII:Hampshire;ID:2647554', '15093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15093', '112', '16970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.F2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16971', '1079', '1', 'County of Hampshire', 'GB.ENG.F2', 'ASCII:Hampshire;ID:2647555', '15094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15094', '112', '16971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.F2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16972', '1079', '1', 'Borough of Halton', 'GB.ENG.E9', 'ASCII:Halton;ID:2647601', '15095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15095', '112', '16972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.E9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16973', '1079', '1', 'Gwynedd', 'GB.WLS.Y2', 'ASCII:Caernarfonshire and Merionethshire;ID:2647716', '15096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15096', '112', '16973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Y2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16974', '1079', '1', 'Greater London', 'GB.ENG.00', 'ASCII:Greater London;ID:2648110', '15097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15097', '112', '16974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.00» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16975', '1079', '1', 'County of Gloucestershire', 'GB.ENG.E6', 'ASCII:Gloucestershire;ID:2648402', '15098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15098', '112', '16975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.E6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16976', '1079', '1', 'Borough of Gateshead', 'GB.ENG.E5', 'ASCII:Gateshead;ID:2648772', '15099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15099', '112', '16976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.E5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16977', '1079', '1', 'County of Flintshire', 'GB.WLS.Y1', 'ASCII:Flintshire;ID:2649298', '15100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15100', '112', '16977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Y1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16978', '1079', '1', 'Fife', 'GB.SCT.V1', 'ASCII:Fife;ID:2649469', '15101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15101', '112', '16978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.V1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16979', '1079', '1', 'Fermanagh District', 'GB.NIR.S2', 'ASCII:Fermanagh;ID:2649533', '15102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15102', '112', '16979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.S2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16980', '1079', '1', 'County of Essex', 'GB.ENG.E4', 'ASCII:Essex;ID:2649889', '15103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15103', '112', '16980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.E4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16981', '1079', '1', 'County of East Sussex', 'GB.ENG.E2', 'ASCII:East Sussex;ID:2650328', '15104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15104', '112', '16981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.E2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16982', '1079', '1', 'District of East Riding of Yorkshire', 'GB.ENG.E1', 'ASCII:East Riding of Yorkshire;ID:2650345', '15105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15105', '112', '16982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.E1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16983', '1079', '1', 'East Lothian', 'GB.SCT.U6', 'ASCII:East Lothian;ID:2650386', '15106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15106', '112', '16983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.U6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16984', '1079', '1', 'County Durham', 'GB.ENG.D8', 'ASCII:Durham;ID:2650629', '15107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15107', '112', '16984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.D8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16985', '1079', '1', 'Dungannon District', 'GB.NIR.S1', 'ASCII:Dungannon;ID:2650730', '15108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15108', '112', '16985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.S1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16986', '1079', '1', 'Dumfries and Galloway', 'GB.SCT.U2', 'ASCII:Dumfries and Galloway;ID:2650797', '15109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15109', '112', '16986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.U2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16987', '1079', '1', 'Down District', 'GB.NIR.R9', 'ASCII:Down;ID:2651038', '15110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15110', '112', '16987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.R9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16988', '1079', '1', 'County of Dorset', 'GB.ENG.D6', 'ASCII:Dorset;ID:2651079', '15111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15111', '112', '16988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.D6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16989', '1079', '1', 'County of Devon', 'GB.ENG.D4', 'ASCII:Devon;ID:2651292', '15112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15112', '112', '16989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.D4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16990', '1079', '1', 'County of Derbyshire', 'GB.ENG.D3', 'ASCII:Derbyshire;ID:2651346', '15113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15113', '112', '16990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.D3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16991', '1079', '1', 'Denbighshire', 'GB.WLS.X9', 'ASCII:Denbighshire;ID:2651385', '15114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15114', '112', '16991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.X9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16992', '1079', '1', 'County of Cumbria', 'GB.ENG.C9', 'ASCII:Cumbria;ID:2651712', '15115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15115', '112', '16992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.C9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16993', '1079', '1', 'Craigavon District', 'GB.NIR.R8', 'ASCII:Craigavon;ID:2652151', '15116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15116', '112', '16993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.R8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16994', '1079', '1', 'County of Cornwall', 'GB.ENG.C6', 'ASCII:Cornwall;ID:2652355', '15117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15117', '112', '16994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.C6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16995', '1079', '1', 'Cookstown District', 'GB.NIR.R7', 'ASCII:Cookstown;ID:2652418', '15118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15118', '112', '16995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.R7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16996', '1079', '1', 'Coleraine District', 'GB.NIR.R6', 'ASCII:Coleraine;ID:2652587', '15119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15119', '112', '16996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.R6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16997', '1079', '1', 'Clackmannanshire', 'GB.SCT.U1', 'ASCII:Clackmannanshire;ID:2652975', '15120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15120', '112', '16997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.U1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16998', '1079', '1', 'County of Cheshire', 'GB.ENG.C5', 'ASCII:Cheshire;ID:2653234', '15121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15121', '112', '16998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.C5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('16999', '1079', '1', 'Castlereagh District', 'GB.NIR.R5', 'ASCII:Castlereagh;ID:2653559', '15122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15122', '112', '16999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.R5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17000', '1079', '1', 'Carrickfergus District', 'GB.NIR.R4', 'ASCII:Carrickfergus;ID:2653681', '15123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15123', '112', '17000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.R4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17001', '1079', '1', 'Sir Gaerfyrddin', 'GB.WLS.X7', 'ASCII:Carmarthenshire;ID:2653753', '15124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15124', '112', '17001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.X7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17002', '1079', '1', 'County of Ceredigion', 'GB.WLS.X6', 'ASCII:Cardiganshire;ID:2653814', '15125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15125', '112', '17002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.X6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17003', '1079', '1', 'County of Cambridgeshire', 'GB.ENG.C3', 'ASCII:County of Cambridgeshire;ID:2653940', '15126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15126', '112', '17003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.C3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17004', '1079', '1', 'County of Buckinghamshire', 'GB.ENG.B9', 'ASCII:County of Buckinghamshire;ID:2654408', '15127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15127', '112', '17004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.B9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17005', '1079', '1', 'The Scottish Borders', 'GB.SCT.T9', 'ASCII:The Scottish Borders;ID:2655192', '15128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15128', '112', '17005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.T9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17006', '1079', '1', 'Berkshire', 'GB.ENG.P4', 'ASCII:Berkshire;ID:2655856', '15129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15129', '112', '17006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.P4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17007', '1079', '1', 'County of Bedfordshire', 'GB.ENG.A5', 'ASCII:County of Bedfordshire;ID:2656044', '15130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15130', '112', '17007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.A5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17008', '1079', '1', 'Banbridge District', 'GB.NIR.R2', 'ASCII:Banbridge District;ID:2656408', '15131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15131', '112', '17008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.R2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17009', '1079', '1', 'Ballymoney District', 'GB.NIR.R1', 'ASCII:Ballymoney District;ID:2656489', '15132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15132', '112', '17009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.R1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17010', '1079', '1', 'Ballymena District', 'GB.NIR.Q9', 'ASCII:Ballymena District;ID:2656491', '15133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15133', '112', '17010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.Q9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17011', '1079', '1', 'Armagh District', 'GB.NIR.Q8', 'ASCII:Armagh District;ID:2657061', '15134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15134', '112', '17011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.Q8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17012', '1079', '1', 'Ards District', 'GB.NIR.Q7', 'ASCII:Ards District;ID:2657122', '15135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15135', '112', '17012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.Q7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17013', '1079', '1', 'Antrim District', 'GB.NIR.Q6', 'ASCII:Antrim District;ID:2657256', '15136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15136', '112', '17013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.Q6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17014', '1079', '1', 'Angus', 'GB.SCT.T7', 'ASCII:Angus;ID:2657306', '15137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15137', '112', '17014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.T7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17015', '1079', '1', 'Anglesey', 'GB.WLS.X1', 'ASCII:Anglesey;ID:2657311', '15138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15138', '112', '17015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.X1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17016', '1079', '1', 'Aberdeenshire', 'GB.SCT.T6', 'ASCII:Aberdeenshire;ID:2657830', '15139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15139', '112', '17016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.T6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17017', '1079', '1', 'London Borough of Barking and Dagenham', 'GB.ENG.A1', 'ASCII:London Borough of Barking and Dagenham;ID:3333120', '15140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15140', '112', '17017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.A1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17018', '1079', '1', 'London Borough of Barnet', 'GB.ENG.A2', 'ASCII:London Borough of Barnet;ID:3333121', '15141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15141', '112', '17018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.A2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17019', '1079', '1', 'Borough of Barnsley', 'GB.ENG.A3', 'ASCII:Borough of Barnsley;ID:3333122', '15142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15142', '112', '17019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.A3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17020', '1079', '1', 'London Borough of Bexley', 'GB.ENG.A6', 'ASCII:London Borough of Bexley;ID:3333124', '15143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15143', '112', '17020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.A6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17021', '1079', '1', 'Borough of Blackburn with Darwen', 'GB.ENG.A8', 'ASCII:Borough of Blackburn with Darwen;ID:3333126', '15144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15144', '112', '17021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.A8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17022', '1079', '1', 'Borough of Blackpool', 'GB.ENG.A9', 'ASCII:Borough of Blackpool;ID:3333127', '15145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15145', '112', '17022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.A9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17023', '1079', '1', 'Borough of Bolton', 'GB.ENG.B1', 'ASCII:Borough of Bolton;ID:3333128', '15146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15146', '112', '17023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.B1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17024', '1079', '1', 'Borough of Bournemouth', 'GB.ENG.B2', 'ASCII:Borough of Bournemouth;ID:3333129', '15147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15147', '112', '17024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.B2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17025', '1079', '1', 'Borough of Bracknell Forest', 'GB.ENG.B3', 'ASCII:Borough of Bracknell Forest;ID:3333130', '15148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15148', '112', '17025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.B3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17026', '1079', '1', 'City and Borough of Bradford', 'GB.ENG.B4', 'ASCII:City and Borough of Bradford;ID:3333131', '15149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15149', '112', '17026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.B4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17027', '1079', '1', 'London Borough of Brent', 'GB.ENG.B5', 'ASCII:London Borough of Brent;ID:3333132', '15150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15150', '112', '17027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.B5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17028', '1079', '1', 'Borough of Brighton and Hove', 'GB.ENG.B6', 'ASCII:Borough of Brighton and Hove;ID:3333133', '15151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15151', '112', '17028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.B6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17029', '1079', '1', 'City of Bristol', 'GB.ENG.B7', 'ASCII:City of Bristol;ID:3333134', '15152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15152', '112', '17029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.B7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17030', '1079', '1', 'London Borough of Bromley', 'GB.ENG.B8', 'ASCII:London Borough of Bromley;ID:3333135', '15153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15153', '112', '17030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.B8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17031', '1079', '1', 'Borough of Bury', 'GB.ENG.C1', 'ASCII:Borough of Bury;ID:3333136', '15154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15154', '112', '17031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.C1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17032', '1079', '1', 'Borough of Calderdale', 'GB.ENG.C2', 'ASCII:Borough of Calderdale;ID:3333137', '15155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15155', '112', '17032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.C2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17033', '1079', '1', 'London Borough of Camden', 'GB.ENG.C4', 'ASCII:London Borough of Camden;ID:3333138', '15156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15156', '112', '17033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.C4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17034', '1079', '1', 'City and Borough of Coventry', 'GB.ENG.C7', 'ASCII:City and Borough of Coventry;ID:3333139', '15157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15157', '112', '17034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.C7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17035', '1079', '1', 'London Borough of Croydon', 'GB.ENG.C8', 'ASCII:London Borough of Croydon;ID:3333140', '15158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15158', '112', '17035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.C8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17036', '1079', '1', 'Borough of Darlington', 'GB.ENG.D1', 'ASCII:Borough of Darlington;ID:3333141', '15159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15159', '112', '17036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.D1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17037', '1079', '1', 'City of Derby', 'GB.ENG.D2', 'ASCII:City of Derby;ID:3333142', '15160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15160', '112', '17037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.D2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17038', '1079', '1', 'Borough of Doncaster', 'GB.ENG.D5', 'ASCII:Borough of Doncaster;ID:3333143', '15161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15161', '112', '17038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.D5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17039', '1079', '1', 'Borough of Dudley', 'GB.ENG.D7', 'ASCII:Borough of Dudley;ID:3333144', '15162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15162', '112', '17039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.D7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17040', '1079', '1', 'London Borough of Ealing', 'GB.ENG.D9', 'ASCII:London Borough of Ealing;ID:3333145', '15163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15163', '112', '17040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.D9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17041', '1079', '1', 'London Borough of Enfield', 'GB.ENG.E3', 'ASCII:London Borough of Enfield;ID:3333146', '15164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15164', '112', '17041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.E3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17042', '1079', '1', 'London Borough of Greenwich', 'GB.ENG.E7', 'ASCII:London Borough of Greenwich;ID:3333147', '15165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15165', '112', '17042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.E7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17043', '1079', '1', 'London Borough of Hackney', 'GB.ENG.E8', 'ASCII:London Borough of Hackney;ID:3333148', '15166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15166', '112', '17043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.E8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17044', '1079', '1', 'London Borough of Hammersmith and Fulham', 'GB.ENG.F1', 'ASCII:London Borough of Hammersmith and Fulham;ID:3333149', '15167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15167', '112', '17044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.F1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17045', '1079', '1', 'London Borough of Haringey', 'GB.ENG.F3', 'ASCII:London Borough of Haringey;ID:3333150', '15168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15168', '112', '17045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.F3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17046', '1079', '1', 'London Borough of Harrow', 'GB.ENG.F4', 'ASCII:London Borough of Harrow;ID:3333151', '15169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15169', '112', '17046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.F4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17047', '1079', '1', 'Borough of Hartlepool', 'GB.ENG.F5', 'ASCII:Borough of Hartlepool;ID:3333152', '15170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15170', '112', '17047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.F5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17048', '1079', '1', 'London Borough of Havering', 'GB.ENG.F6', 'ASCII:London Borough of Havering;ID:3333153', '15171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15171', '112', '17048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.F6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17049', '1079', '1', 'London Borough of Hillingdon', 'GB.ENG.F9', 'ASCII:London Borough of Hillingdon;ID:3333154', '15172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15172', '112', '17049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.F9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17050', '1079', '1', 'London Borough of Hounslow', 'GB.ENG.G1', 'ASCII:London Borough of Hounslow;ID:3333155', '15173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15173', '112', '17050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.G1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17051', '1079', '1', 'London Borough of Islington', 'GB.ENG.G3', 'ASCII:London Borough of Islington;ID:3333156', '15174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15174', '112', '17051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.G3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17052', '1079', '1', 'Royal London Borough of Kensington and Chelsea', 'GB.ENG.G4', 'ASCII:Royal London Borough of Kensington and Chelsea;ID:3333157', '15175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15175', '112', '17052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.G4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17053', '1079', '1', 'County of Kent', 'GB.ENG.G5', 'ASCII:County of Kent;ID:3333158', '15176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15176', '112', '17053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.G5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17054', '1079', '1', 'City of Kingston upon Hull', 'GB.ENG.G6', 'ASCII:City of Kingston upon Hull;ID:3333159', '15177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15177', '112', '17054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.G6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17055', '1079', '1', 'Royal London Borough of Kingston upon Thames', 'GB.ENG.G7', 'ASCII:Royal London Borough of Kingston upon Thames;ID:3333160', '15178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15178', '112', '17055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.G7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17056', '1079', '1', 'Borough of Kirklees', 'GB.ENG.G8', 'ASCII:Borough of Kirklees;ID:3333161', '15179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15179', '112', '17056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.G8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17057', '1079', '1', 'Borough of Knowsley', 'GB.ENG.G9', 'ASCII:Borough of Knowsley;ID:3333162', '15180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15180', '112', '17057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.G9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17058', '1079', '1', 'London Borough of Lambeth', 'GB.ENG.H1', 'ASCII:London Borough of Lambeth;ID:3333163', '15181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15181', '112', '17058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.H1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17059', '1079', '1', 'City and Borough of Leeds', 'GB.ENG.H3', 'ASCII:City and Borough of Leeds;ID:3333164', '15182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15182', '112', '17059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.H3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17060', '1079', '1', 'City of Leicester', 'GB.ENG.H4', 'ASCII:Leicester;ID:3333165', '15183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15183', '112', '17060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.H4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17061', '1079', '1', 'London Borough of Lewisham', 'GB.ENG.H6', 'ASCII:London Borough of Lewisham;ID:3333166', '15184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15184', '112', '17061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.H6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17062', '1079', '1', 'City and Borough of Liverpool', 'GB.ENG.H8', 'ASCII:City and Borough of Liverpool;ID:3333167', '15185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15185', '112', '17062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.H8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17063', '1079', '1', 'Borough of Luton', 'GB.ENG.I1', 'ASCII:Borough of Luton;ID:3333168', '15186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15186', '112', '17063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.I1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17064', '1079', '1', 'City and Borough of Manchester', 'GB.ENG.I2', 'ASCII:City and Borough of Manchester;ID:3333169', '15187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15187', '112', '17064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.I2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17065', '1079', '1', 'Borough of Medway', 'GB.ENG.I3', 'ASCII:Borough of Medway;ID:3333170', '15188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15188', '112', '17065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.I3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17066', '1079', '1', 'London Borough of Merton', 'GB.ENG.I4', 'ASCII:London Borough of Merton;ID:3333171', '15189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15189', '112', '17066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.I4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17067', '1079', '1', 'Borough of Middlesbrough', 'GB.ENG.I5', 'ASCII:Borough of Middlesbrough;ID:3333172', '15190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15190', '112', '17067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.I5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17068', '1079', '1', 'Borough of Milton Keynes', 'GB.ENG.I6', 'ASCII:Borough of Milton Keynes;ID:3333173', '15191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15191', '112', '17068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.I6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17069', '1079', '1', 'City and Borough of Newcastle upon Tyne', 'GB.ENG.I7', 'ASCII:City and Borough of Newcastle upon Tyne;ID:3333174', '15192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15192', '112', '17069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.I7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17070', '1079', '1', 'City of Nottingham', 'GB.ENG.J8', 'ASCII:City of Nottingham;ID:3333178', '15193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15193', '112', '17070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.J8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17071', '1079', '1', 'Borough of Oldham', 'GB.ENG.K1', 'ASCII:Borough of Oldham;ID:3333179', '15194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15194', '112', '17071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.K1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17072', '1079', '1', 'City of Peterborough', 'GB.ENG.K3', 'ASCII:City of Peterborough;ID:3333180', '15195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15195', '112', '17072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.K3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17073', '1079', '1', 'City of Plymouth', 'GB.ENG.K4', 'ASCII:City of Plymouth;ID:3333181', '15196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15196', '112', '17073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.K4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17074', '1079', '1', 'Borough of Poole', 'GB.ENG.K5', 'ASCII:Borough of Poole;ID:3333182', '15197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15197', '112', '17074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.K5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17075', '1079', '1', 'City of Portsmouth', 'GB.ENG.K6', 'ASCII:City of Portsmouth;ID:3333183', '15198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15198', '112', '17075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.K6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17076', '1079', '1', 'Borough of Reading', 'GB.ENG.K7', 'ASCII:Borough of Reading;ID:3333184', '15199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15199', '112', '17076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.K7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17077', '1079', '1', 'London Borough of Redbridge', 'GB.ENG.K8', 'ASCII:London Borough of Redbridge;ID:3333185', '15200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15200', '112', '17077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.K8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17078', '1079', '1', 'Borough of Redcar and Cleveland', 'GB.ENG.K9', 'ASCII:Borough of Redcar and Cleveland;ID:3333186', '15201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15201', '112', '17078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.K9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17079', '1079', '1', 'London Borough of Richmond upon Thames', 'GB.ENG.L1', 'ASCII:London Borough of Richmond upon Thames;ID:3333187', '15202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15202', '112', '17079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.L1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17080', '1079', '1', 'Borough of Rochdale', 'GB.ENG.L2', 'ASCII:Borough of Rochdale;ID:3333188', '15203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15203', '112', '17080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.L2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17081', '1079', '1', 'Borough of Rotherham', 'GB.ENG.L3', 'ASCII:Borough of Rotherham;ID:3333189', '15204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15204', '112', '17081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.L3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17082', '1079', '1', 'City and Borough of Salford', 'GB.ENG.L5', 'ASCII:City and Borough of Salford;ID:3333190', '15205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15205', '112', '17082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.L5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17083', '1079', '1', 'Borough of Sandwell', 'GB.ENG.L7', 'ASCII:Borough of Sandwell;ID:3333191', '15206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15206', '112', '17083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.L7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17084', '1079', '1', 'Borough of Sefton', 'GB.ENG.L8', 'ASCII:Borough of Sefton;ID:3333192', '15207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15207', '112', '17084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.L8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17085', '1079', '1', 'City and Borough of Sheffield', 'GB.ENG.L9', 'ASCII:City and Borough of Sheffield;ID:3333193', '15208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15208', '112', '17085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.L9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17086', '1079', '1', 'Borough of Solihull', 'GB.ENG.M2', 'ASCII:Borough of Solihull;ID:3333195', '15209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15209', '112', '17086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.M2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17087', '1079', '1', 'City of Southampton', 'GB.ENG.M4', 'ASCII:City of Southampton;ID:3333196', '15210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15210', '112', '17087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.M4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17088', '1079', '1', 'Borough of Southend-on-Sea', 'GB.ENG.M5', 'ASCII:Borough of Southend-on-Sea;ID:3333197', '15211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15211', '112', '17088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.M5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17089', '1079', '1', 'Borough of South Tyneside', 'GB.ENG.M7', 'ASCII:Borough of South Tyneside;ID:3333199', '15212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15212', '112', '17089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.M7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17090', '1079', '1', 'London Borough of Southwark', 'GB.ENG.M8', 'ASCII:London Borough of Southwark;ID:3333200', '15213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15213', '112', '17090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.M8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17091', '1079', '1', 'Borough of St. Helens', 'GB.ENG.N1', 'ASCII:Borough of St. Helens;ID:3333201', '15214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15214', '112', '17091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.N1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17092', '1079', '1', 'Borough of Stockport', 'GB.ENG.N2', 'ASCII:Borough of Stockport;ID:3333202', '15215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15215', '112', '17092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.N2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17093', '1079', '1', 'Borough of Stockton-on-Tees', 'GB.ENG.N3', 'ASCII:Borough of Stockton-on-Tees;ID:3333203', '15216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15216', '112', '17093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.N3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17094', '1079', '1', 'City of Stoke-on-Trent', 'GB.ENG.N4', 'ASCII:City of Stoke-on-Trent;ID:3333204', '15217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15217', '112', '17094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.N4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17095', '1079', '1', 'City and Borough of Sunderland', 'GB.ENG.N6', 'ASCII:City and Borough of Sunderland;ID:3333205', '15218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15218', '112', '17095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.N6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17096', '1079', '1', 'London Borough of Sutton', 'GB.ENG.N8', 'ASCII:London Borough of Sutton;ID:3333206', '15219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15219', '112', '17096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.N8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17097', '1079', '1', 'Borough of Swindon', 'GB.ENG.N9', 'ASCII:Borough of Swindon;ID:3333207', '15220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15220', '112', '17097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.N9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17098', '1079', '1', 'Borough of Tameside', 'GB.ENG.O1', 'ASCII:Borough of Tameside;ID:3333208', '15221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15221', '112', '17098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.O1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17099', '1079', '1', 'District of Telford and Wrekin', 'GB.ENG.O2', 'ASCII:District of Telford and Wrekin;ID:3333209', '15222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15222', '112', '17099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.O2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17100', '1079', '1', 'Borough of Torbay', 'GB.ENG.O4', 'ASCII:Borough of Torbay;ID:3333210', '15223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15223', '112', '17100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.O4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17101', '1079', '1', 'Borough of Trafford', 'GB.ENG.O6', 'ASCII:Borough of Trafford;ID:3333211', '15224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15224', '112', '17101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.O6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17102', '1079', '1', 'City and Borough of Wakefield', 'GB.ENG.O7', 'ASCII:City and Borough of Wakefield;ID:3333212', '15225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15225', '112', '17102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.O7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17103', '1079', '1', 'Borough of Walsall', 'GB.ENG.O8', 'ASCII:Borough of Walsall;ID:3333213', '15226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15226', '112', '17103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.O8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17104', '1079', '1', 'London Borough of Waltham Forest', 'GB.ENG.O9', 'ASCII:London Borough of Waltham Forest;ID:3333214', '15227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15227', '112', '17104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.O9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17105', '1079', '1', 'London Borough of Wandsworth', 'GB.ENG.P1', 'ASCII:London Borough of Wandsworth;ID:3333215', '15228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15228', '112', '17105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.P1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17106', '1079', '1', 'Borough of Warrington', 'GB.ENG.P2', 'ASCII:Borough of Warrington;ID:3333216', '15229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15229', '112', '17106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.P2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17107', '1079', '1', 'City and London Borough of Westminster', 'GB.ENG.P5', 'ASCII:City and London Borough of Westminster;ID:3333218', '15230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15230', '112', '17107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.P5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17108', '1079', '1', 'Borough of Wigan', 'GB.ENG.P7', 'ASCII:Borough of Wigan;ID:3333219', '15231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15231', '112', '17108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.P7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17109', '1079', '1', 'Borough of Wirral', 'GB.ENG.Q1', 'ASCII:Borough of Wirral;ID:3333220', '15232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15232', '112', '17109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.Q1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17110', '1079', '1', 'District of Wokingham', 'GB.ENG.Q2', 'ASCII:District of Wokingham;ID:3333221', '15233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15233', '112', '17110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.Q2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17111', '1079', '1', 'Borough of Wolverhampton', 'GB.ENG.Q3', 'ASCII:Borough of Wolverhampton;ID:3333222', '15234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15234', '112', '17111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.ENG.Q3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17112', '1079', '1', 'City of Belfast', 'GB.NIR.R3', 'ASCII:City of Belfast;ID:3333223', '15235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15235', '112', '17112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.NIR.R3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17113', '1079', '1', 'Aberdeen City', 'GB.SCT.T5', 'ASCII:Aberdeen City;ID:3333224', '15236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15236', '112', '17113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.T5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17114', '1079', '1', 'Dundee City', 'GB.SCT.U3', 'ASCII:Dundee City;ID:3333225', '15237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15237', '112', '17114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.U3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17115', '1079', '1', 'East Ayrshire', 'GB.SCT.U4', 'ASCII:East Ayrshire;ID:3333226', '15238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15238', '112', '17115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.U4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17116', '1079', '1', 'East Dunbartonshire', 'GB.SCT.U5', 'ASCII:East Dunbartonshire;ID:3333227', '15239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15239', '112', '17116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.U5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17117', '1079', '1', 'East Renfrewshire', 'GB.SCT.U7', 'ASCII:East Renfrewshire;ID:3333228', '15240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15240', '112', '17117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.U7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17118', '1079', '1', 'City of Edinburgh', 'GB.SCT.U8', 'ASCII:City of Edinburgh;ID:3333229', '15241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15241', '112', '17118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.U8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17119', '1079', '1', 'Falkirk', 'GB.SCT.U9', 'ASCII:Falkirk;ID:3333230', '15242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15242', '112', '17119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.U9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17120', '1079', '1', 'Glasgow City', 'GB.SCT.V2', 'ASCII:Glasgow City;ID:3333231', '15243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15243', '112', '17120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.V2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17121', '1079', '1', 'North Ayrshire', 'GB.SCT.V7', 'ASCII:North Ayrshire;ID:3333232', '15244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15244', '112', '17121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.V7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17122', '1079', '1', 'North Lanarkshire', 'GB.SCT.V8', 'ASCII:North Lanarkshire;ID:3333233', '15245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15245', '112', '17122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.V8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17123', '1079', '1', 'Perth and Kinross', 'GB.SCT.W1', 'ASCII:Perth and Kinross;ID:3333234', '15246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15246', '112', '17123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.W1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17124', '1079', '1', 'South Ayrshire', 'GB.SCT.W4', 'ASCII:South Ayrshire;ID:3333235', '15247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15247', '112', '17124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.W4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17125', '1079', '1', 'South Lanarkshire', 'GB.SCT.W5', 'ASCII:South Lanarkshire;ID:3333236', '15248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15248', '112', '17125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.W5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17126', '1079', '1', 'West Dunbartonshire', 'GB.SCT.W7', 'ASCII:West Dunbartonshire;ID:3333237', '15249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15249', '112', '17126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.W7» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17127', '1079', '1', 'Blaenau Gwent', 'GB.WLS.X2', 'ASCII:County Borough of Blaenau Gwent;ID:3333238', '15250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15250', '112', '17127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.X2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17128', '1079', '1', 'Bridgend county borough', 'GB.WLS.X3', 'ASCII:County Borough of Bridgend;ID:3333239', '15251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15251', '112', '17128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.X3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17129', '1079', '1', 'County Borough of Caerphilly', 'GB.WLS.X4', 'ASCII:County Borough of Caerphilly;ID:3333240', '15252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15252', '112', '17129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.X4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17130', '1079', '1', 'City and County of Cardiff', 'GB.WLS.X5', 'ASCII:City and County of Cardiff;ID:3333241', '15253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15253', '112', '17130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.X5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17131', '1079', '1', 'Conwy', 'GB.WLS.X8', 'ASCII:County Borough of Conwy;ID:3333242', '15254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15254', '112', '17131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.X8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17132', '1079', '1', 'County Borough of Merthyr Tydfil', 'GB.WLS.Y3', 'ASCII:County Borough of Merthyr Tydfil;ID:3333243', '15255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15255', '112', '17132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Y3» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17133', '1079', '1', 'Monmouthshire', 'GB.WLS.Y4', 'ASCII:Monmouthshire principal area;ID:3333244', '15256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15256', '112', '17133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Y4» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17134', '1079', '1', 'Neath Port Talbot', 'GB.WLS.Y5', 'ASCII:Neath and Port Talbot;ID:3333245', '15257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15257', '112', '17134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Y5» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17135', '1079', '1', 'City of Newport', 'GB.WLS.Y6', 'ASCII:City of Newport;ID:3333246', '15258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15258', '112', '17135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Y6» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17136', '1079', '1', 'Rhondda Cynon Taff', 'GB.WLS.Y9', 'ASCII:County Borough of Rhondda Cynon Taff;ID:3333247', '15259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15259', '112', '17136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Y9» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17137', '1079', '1', 'City and County of Swansea', 'GB.WLS.Z1', 'ASCII:City and County of Swansea;ID:3333248', '15260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15260', '112', '17137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Z1» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17138', '1079', '1', 'County Borough of Torfaen', 'GB.WLS.Z2', 'ASCII:County Borough of Torfaen;ID:3333249', '15261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15261', '112', '17138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.WLS.Z2» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17139', '1079', '1', 'Argyll and Bute', 'GB.SCT.T8', 'ASCII:Argyll and Bute;ID:6457407', '15262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15262', '112', '17139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GB.SCT.T8» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17140', '1079', '1', 'Zestap’onis Raioni', 'GE.61.610865', 'ASCII:Zestap''onis Raioni;ID:610865', '15263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15263', '112', '17140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.61.610865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17141', '1079', '1', 'Zavodskoy Rayon', 'GE.00.611068', 'ASCII:Zavodskoy Rayon;ID:611068', '15264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15264', '112', '17141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.611068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17142', '1079', '1', 'Vanis Raioni', 'GE.00.611214', 'ASCII:Vanis Raioni;ID:611214', '15265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15265', '112', '17142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.611214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17143', '1079', '1', 'Dedop’listsqaros Raioni', 'GE.17.611448', 'ASCII:Dedop''listsqaros Raioni;ID:611448', '15266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15266', '112', '17143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.17.611448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17144', '1079', '1', 'Tsalkis Raioni', 'GE.00.611547', 'ASCII:Tsalkis Raioni;ID:611547', '15267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15267', '112', '17144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.611547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17145', '1079', '1', 'Tsalenjikhis Raioni', 'GE.00.611552', 'ASCII:Tsalenjikhis Raioni;ID:611552', '15268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15268', '112', '17145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.611552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17146', '1079', '1', 'Ts’ageris Raioni', 'GE.00.611565', 'ASCII:Ts''ageris Raioni;ID:611565', '15269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15269', '112', '17146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.611565» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17147', '1079', '1', 'T’ianet’is Raioni', 'GE.00.611668', 'ASCII:T''ianet''is Raioni;ID:611668', '15270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15270', '112', '17147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.611668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17148', '1079', '1', 'T’et’ritsqaros Raioni', 'GE.00.611676', 'ASCII:T''et''ritsqaros Raioni;ID:611676', '15271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15271', '112', '17148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.611676» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17149', '1079', '1', 'T’erjolis Raioni', 'GE.00.611681', 'ASCII:T''erjolis Raioni;ID:611681', '15272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15272', '112', '17149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.611681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17150', '1079', '1', 'T’elavis Raioni', 'GE.51.611692', 'ASCII:T''elavis Raioni;ID:611692', '15273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15273', '112', '17150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.51.611692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17151', '1079', '1', 'Sokhumis Raioni', 'GE.02.611818', 'ASCII:Sokhumis Raioni;ID:611818', '15274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15274', '112', '17151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.02.611818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17152', '1079', '1', 'Sighnaghis Raioni', 'GE.00.611901', 'ASCII:Sighnaghis Raioni;ID:611901', '15275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15275', '112', '17152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.611901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17153', '1079', '1', 'Senakis Raioni', 'GE.00.612051', 'ASCII:Senakis Raioni;ID:612051', '15276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15276', '112', '17153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.612051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17154', '1079', '1', 'Samtrediis Raioni', 'GE.00.612124', 'ASCII:Samtrediis Raioni;ID:612124', '15277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15277', '112', '17154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.612124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17155', '1079', '1', 'Sagarejos Raioni', 'GE.00.612231', 'ASCII:Sagarejos Raioni;ID:612231', '15278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15278', '112', '17155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.612231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17156', '1079', '1', 'Sach’kheris Raioni', 'GE.45.612255', 'ASCII:Sach''kheris Raioni;ID:612255', '15279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15279', '112', '17156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.45.612255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17157', '1079', '1', 'Pervomayskiy Rayon', 'GE.00.612422', 'ASCII:Pervomayskiy Rayon;ID:612422', '15280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15280', '112', '17157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.612422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17158', '1079', '1', 'Ozurget’is Raioni', 'GE.00.612535', 'ASCII:Ozurget''is Raioni;ID:612535', '15281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15281', '112', '17158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.612535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17159', '1079', '1', 'Ordzhonikidzevskiy Rayon', 'GE.00.612571', 'ASCII:Ordzhonikidzevskiy Rayon;ID:612571', '15282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15282', '112', '17159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.612571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17160', '1079', '1', 'Onis Raioni', 'GE.39.612590', 'ASCII:Onis Raioni;ID:612590', '15283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15283', '112', '17160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.39.612590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17161', '1079', '1', 'Oktyabr''skiy Rayon', 'GE.00.612612', 'ASCII:Oktyabr''skiy Rayon;ID:612612', '15284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15284', '112', '17161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.612612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17162', '1079', '1', 'Mts’khet’is Raioni', 'GE.00.612889', 'ASCII:Mts''khet''is Raioni;ID:612889', '15285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15285', '112', '17162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.612889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17163', '1079', '1', 'Mestiis Raioni', 'GE.00.612985', 'ASCII:Mestiis Raioni;ID:612985', '15286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15286', '112', '17163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.612985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17164', '1079', '1', 'Baghdat’is Raioni', 'GE.00.613054', 'ASCII:Baghdat''is Raioni;ID:613054', '15287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15287', '112', '17164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.613054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17165', '1079', '1', 'Marneulis Raioni', 'GE.00.613073', 'ASCII:Marneulis Raioni;ID:613073', '15288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15288', '112', '17165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.613073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17166', '1079', '1', 'Lentekhis Raioni', 'GE.00.613225', 'ASCII:Lentekhis Raioni;ID:613225', '15289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15289', '112', '17166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.613225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17167', '1079', '1', 'Leninskiy Rayon', 'GE.00.613228', 'ASCII:Leninskiy Rayon;ID:613228', '15290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15290', '112', '17167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.613228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17168', '1079', '1', 'Akhalgoris Raioni', 'GE.00.613233', 'ASCII:Akhalgoris Raioni;ID:613233', '15291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15291', '112', '17168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.613233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17169', '1079', '1', 'Lanch’khut’is Raioni', 'GE.00.613310', 'ASCII:Lanch''khut''is Raioni;ID:613310', '15292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15292', '112', '17169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.613310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17170', '1079', '1', 'Lagodekhis Raioni', 'GE.31.613341', 'ASCII:Lagodekhis Raioni;ID:613341', '15293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15293', '112', '17170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.31.613341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17171', '1079', '1', 'Qvarlis Raioni', 'GE.43.613582', 'ASCII:Qvarlis Raioni;ID:613582', '15294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15294', '112', '17171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.43.613582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17172', '1079', '1', 'Kirovskiy Rayon', 'GE.00.613811', 'ASCII:Kirovskiy Rayon;ID:613811', '15295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15295', '112', '17172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.613811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17173', '1079', '1', 'Khonis Raioni', 'GE.00.613900', 'ASCII:Khonis Raioni;ID:613900', '15296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15296', '112', '17173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.613900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17174', '1079', '1', 'Khobis Raioni', 'GE.00.613915', 'ASCII:Khobis Raioni;ID:613915', '15297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15297', '112', '17174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.613915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17175', '1079', '1', 'Khashuris Raioni', 'GE.28.613987', 'ASCII:Khashuris Raioni;ID:613987', '15298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15298', '112', '17175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.28.613987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17176', '1079', '1', 'Kharagaulis Raioni', 'GE.27.614003', 'ASCII:Kharagaulis Raioni;ID:614003', '15299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15299', '112', '17176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.27.614003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17177', '1079', '1', 'Qazbegis Raioni', 'GE.00.614086', 'ASCII:Qazbegis Raioni;ID:614086', '15300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15300', '112', '17177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17178', '1079', '1', 'Kaspis Raioni', 'GE.00.614103', 'ASCII:Kaspis Raioni;ID:614103', '15301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15301', '112', '17178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17179', '1079', '1', 'K’arelis Raioni', 'GE.25.614130', 'ASCII:K''arelis Raioni;ID:614130', '15302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15302', '112', '17179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.25.614130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17180', '1079', '1', 'Kalininskiy Rayon', 'GE.00.614171', 'ASCII:Kalininskiy Rayon;ID:614171', '15303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15303', '112', '17180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17181', '1079', '1', 'Imeni Dvadtsati Shesti Komissarov Rayon', 'GE.00.614278', 'ASCII:Imeni Dvadtsati Shesti Komissarov Rayon;ID:614278', '15304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15304', '112', '17181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17182', '1079', '1', 'Gurjaanis Raioni', 'GE.00.614356', 'ASCII:Gurjaanis Raioni;ID:614356', '15305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15305', '112', '17182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17183', '1079', '1', 'Goris Raioni', 'GE.00.614450', 'ASCII:Goris Raioni;ID:614450', '15306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15306', '112', '17183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17184', '1079', '1', 'Gldanskiy Rayon', 'GE.00.614519', 'ASCII:Gldanskiy Rayon;ID:614519', '15307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15307', '112', '17184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17185', '1079', '1', 'Gardabanis Raioni', 'GE.00.614573', 'ASCII:Gardabanis Raioni;ID:614573', '15308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15308', '112', '17185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17186', '1079', '1', 'Javis Raioni', 'GE.00.614792', 'ASCII:Javis Raioni;ID:614792', '15309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15309', '112', '17186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17187', '1079', '1', 'Dushet’is Raioni', 'GE.00.614841', 'ASCII:Dushet''is Raioni;ID:614841', '15310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15310', '112', '17187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17188', '1079', '1', 'Dmanisis Raioni', 'GE.00.614889', 'ASCII:Dmanisis Raioni;ID:614889', '15311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15311', '112', '17188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.614889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17189', '1079', '1', 'Ch’okhatauris Raioni', 'GE.00.615117', 'ASCII:Ch''okhatauris Raioni;ID:615117', '15312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15312', '112', '17189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.615117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17190', '1079', '1', 'Borjomis Raioni', 'GE.13.615400', 'ASCII:Borjomis Raioni;ID:615400', '15313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15313', '112', '17190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.13.615400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17191', '1079', '1', 'Bolnisis Raioni', 'GE.00.615418', 'ASCII:Bolnisis Raioni;ID:615418', '15314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15314', '112', '17191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.615418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17192', '1079', '1', 'Ninotsmindis Raioni', 'GE.38.615428', 'ASCII:Ninotsmindis Raioni;ID:615428', '15315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15315', '112', '17192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.38.615428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17193', '1079', '1', 'K’alak’i Tsqaltubo', 'GE.00.615631', 'ASCII:K''alak''i Tsqaltubo;ID:615631', '15316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15316', '112', '17193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.615631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17194', '1079', '1', 'Aspindzis Raioni', 'GE.10.615659', 'ASCII:Aspindzis Raioni;ID:615659', '15317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15317', '112', '17194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.10.615659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17195', '1079', '1', 'Ambrolauris Raioni', 'GE.09.615775', 'ASCII:Ambrolauris Raioni;ID:615775', '15318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15318', '112', '17195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.09.615775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17196', '1079', '1', 'Akhmetis Raioni', 'GE.08.615843', 'ASCII:Akhmetis Raioni;ID:615843', '15319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15319', '112', '17196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.08.615843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17197', '1079', '1', 'Akhalts’ikhis Raioni', 'GE.07.615856', 'ASCII:Akhalts''ikhis Raioni;ID:615856', '15320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15320', '112', '17197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.07.615856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17198', '1079', '1', 'Akhalk’alak’is Raioni', 'GE.06.615891', 'ASCII:Akhalk''alak''is Raioni;ID:615891', '15321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15321', '112', '17198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.06.615891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17199', '1079', '1', 'Adigenis Raioni', 'GE.00.615972', 'ASCII:Adigenis Raioni;ID:615972', '15322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15322', '112', '17199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.615972» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17200', '1079', '1', 'Abashis Raioni', 'GE.00.616020', 'ASCII:Abashis Raioni;ID:616020', '15323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15323', '112', '17200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.616020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17201', '1079', '1', 'K’alak’i Chiat’ura', 'GE.14.828308', 'ASCII:K''alak''i Chiat''ura;ID:828308', '15324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15324', '112', '17201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.14.828308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17202', '1079', '1', 'K’alak’i Gori', 'GE.00.828309', 'ASCII:K''alak''i Gori;ID:828309', '15325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15325', '112', '17202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.828309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17203', '1079', '1', 'K’alak’i K’ut’aisi', 'GE.00.828310', 'ASCII:K''alak''i K''ut''aisi;ID:828310', '15326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15326', '112', '17203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.828310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17204', '1079', '1', 'K’alak’i P’ot’i', 'GE.00.828311', 'ASCII:K''alak''i P''ot''i;ID:828311', '15327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15327', '112', '17204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.828311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17205', '1079', '1', 'K’alak’i Rust’avi', 'GE.00.828312', 'ASCII:K''alak''i Rust''avi;ID:828312', '15328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15328', '112', '17205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.828312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17206', '1079', '1', 'K’alak’i Tqibuli', 'GE.00.828313', 'ASCII:K''alak''i Tqibuli;ID:828313', '15329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15329', '112', '17206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.828313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17207', '1079', '1', 'K’alak’i Zugdidi', 'GE.00.828314', 'ASCII:K''alak''i Zugdidi;ID:828314', '15330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15330', '112', '17207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GE.00.828314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17208', '1079', '1', 'Département de la Guyane', 'GF.GF.973', 'ASCII:Departement de la Guyane;ID:6690606', '15331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15331', '112', '17208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GF.GF.973» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17209', '1079', '1', 'Somanya District', 'GH.00.2295235', 'ASCII:Somanya District;ID:2295235', '15332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15332', '112', '17209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GH.00.2295235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17210', '1079', '1', 'Keta', 'GH.00.2299646', 'ASCII:Keta;ID:2299646', '15333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15333', '112', '17210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GH.00.2299646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17211', '1079', '1', 'Dagomba', 'GH.00.2302058', 'ASCII:Dagomba;ID:2302058', '15334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15334', '112', '17211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GH.00.2302058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17212', '1079', '1', 'Tunu', 'GL.02.3419152', 'ASCII:East Greenland;ID:3419152', '15335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15335', '112', '17212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GL.02.3419152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17213', '1079', '1', 'Vestgrønland', 'GL.03.3422392', 'ASCII:West Greenland;ID:3422392', '15336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15336', '112', '17213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GL.03.3422392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17214', '1079', '1', 'Nordgrønland', 'GL.01.3424366', 'ASCII:North Greenland;ID:3424366', '15337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15337', '112', '17214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GL.01.3424366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17215', '1079', '1', 'Wuli', 'GM.00.2411671', 'ASCII:Wuli;ID:2411671', '15338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15338', '112', '17215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2411671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17216', '1079', '1', 'Upper Saloum', 'GM.00.2411710', 'ASCII:Upper Saloum;ID:2411710', '15339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15339', '112', '17216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2411710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17217', '1079', '1', 'Upper Niumi District', 'GM.00.2411712', 'ASCII:Upper Niumi District;ID:2411712', '15340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15340', '112', '17217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2411712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17218', '1079', '1', 'Upper Baddibu', 'GM.00.2411714', 'ASCII:Upper Baddibu;ID:2411714', '15341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15341', '112', '17218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2411714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17219', '1079', '1', 'Sandu', 'GM.00.2412176', 'ASCII:Sandu;ID:2412176', '15342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15342', '112', '17219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17220', '1079', '1', 'Sami', 'GM.00.2412201', 'ASCII:Sami;ID:2412201', '15343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15343', '112', '17220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17221', '1079', '1', 'Nianija', 'GM.00.2412420', 'ASCII:Nianija;ID:2412420', '15344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15344', '112', '17221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17222', '1079', '1', 'Niani', 'GM.00.2412421', 'ASCII:Niani;ID:2412421', '15345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15345', '112', '17222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17223', '1079', '1', 'Niamina West', 'GM.00.2412422', 'ASCII:Niamina West;ID:2412422', '15346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15346', '112', '17223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17224', '1079', '1', 'Niamina East', 'GM.00.2412423', 'ASCII:Niamina East;ID:2412423', '15347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15347', '112', '17224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17225', '1079', '1', 'Niamina Dankunku', 'GM.00.2412424', 'ASCII:Niamina Dankunku;ID:2412424', '15348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15348', '112', '17225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17226', '1079', '1', 'Lower Saloum', 'GM.00.2412715', 'ASCII:Lower Saloum;ID:2412715', '15349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15349', '112', '17226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17227', '1079', '1', 'Lower Niumi District', 'GM.07.2412717', 'ASCII:Lower Niumi District;ID:2412717', '15350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15350', '112', '17227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.07.2412717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17228', '1079', '1', 'Lower Baddibu District', 'GM.00.2412718', 'ASCII:Lower Baddibu District;ID:2412718', '15351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15351', '112', '17228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17229', '1079', '1', 'Kombo South District', 'GM.05.2412849', 'ASCII:Kombo South District;ID:2412849', '15352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15352', '112', '17229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.05.2412849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17230', '1079', '1', 'Kombo North District', 'GM.05.2412850', 'ASCII:Kombo North District;ID:2412850', '15353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15353', '112', '17230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.05.2412850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17231', '1079', '1', 'Kombo East', 'GM.00.2412851', 'ASCII:Kombo East;ID:2412851', '15354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15354', '112', '17231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17232', '1079', '1', 'Kombo Central District', 'GM.05.2412852', 'ASCII:Kombo Central District;ID:2412852', '15355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15355', '112', '17232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.05.2412852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17233', '1079', '1', 'Kiang West', 'GM.00.2412885', 'ASCII:Kiang West;ID:2412885', '15356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15356', '112', '17233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17234', '1079', '1', 'Kiang East', 'GM.00.2412886', 'ASCII:Kiang East;ID:2412886', '15357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15357', '112', '17234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17235', '1079', '1', 'Kiang Central', 'GM.00.2412887', 'ASCII:Kiang Central;ID:2412887', '15358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15358', '112', '17235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2412887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17236', '1079', '1', 'Kantora', 'GM.00.2413088', 'ASCII:Kantora;ID:2413088', '15359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15359', '112', '17236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17237', '1079', '1', 'Jokadu', 'GM.00.2413213', 'ASCII:Jokadu;ID:2413213', '15360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15360', '112', '17237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17238', '1079', '1', 'Jarra West', 'GM.00.2413266', 'ASCII:Jarra West;ID:2413266', '15361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15361', '112', '17238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17239', '1079', '1', 'Jarra East', 'GM.00.2413267', 'ASCII:Jarra East;ID:2413267', '15362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15362', '112', '17239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17240', '1079', '1', 'Jarra Central', 'GM.00.2413268', 'ASCII:Jarra Central;ID:2413268', '15363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15363', '112', '17240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17241', '1079', '1', 'Fulladu West', 'GM.00.2413461', 'ASCII:Fulladu West;ID:2413461', '15364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15364', '112', '17241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17242', '1079', '1', 'Fulladu East', 'GM.00.2413462', 'ASCII:Fulladu East;ID:2413462', '15365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15365', '112', '17242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17243', '1079', '1', 'Foni Kansala', 'GM.00.2413477', 'ASCII:Foni Kansala;ID:2413477', '15366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15366', '112', '17243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17244', '1079', '1', 'Foni Jarrol', 'GM.00.2413478', 'ASCII:Foni Jarrol;ID:2413478', '15367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15367', '112', '17244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17245', '1079', '1', 'Foni Brefet', 'GM.00.2413479', 'ASCII:Foni Brefet;ID:2413479', '15368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15368', '112', '17245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17246', '1079', '1', 'Foni Bondali', 'GM.00.2413480', 'ASCII:Foni Bondali;ID:2413480', '15369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15369', '112', '17246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17247', '1079', '1', 'Foni Bintang-Karenai', 'GM.00.2413481', 'ASCII:Foni Bintang-Karenai;ID:2413481', '15370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15370', '112', '17247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17248', '1079', '1', 'Dappo', 'GM.00.2413640', 'ASCII:Dappo;ID:2413640', '15371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15371', '112', '17248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17249', '1079', '1', 'Dappo', 'GM.00.2413641', 'ASCII:Dappo;ID:2413641', '15372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15372', '112', '17249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17250', '1079', '1', 'Central Baddibu', 'GM.00.2413686', 'ASCII:Central Baddibu;ID:2413686', '15373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15373', '112', '17250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.00.2413686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17251', '1079', '1', 'Kombo Saint Mary District', 'GM.05.2593772', 'ASCII:Kombo Saint Mary District;ID:2593772', '15374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15374', '112', '17251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GM.05.2593772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17252', '1079', '1', 'Département de la Guadeloupe', 'GP.GP.971', 'ASCII:Departement de la Guadeloupe;ID:6690364', '15375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15375', '112', '17252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GP.GP.971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17253', '1079', '1', 'Nomós Zakýnthou', 'GR.ESYE22.28', 'ASCII:Nomos Zakynthou;ID:251276', '15376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15376', '112', '17253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE22.28» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17254', '1079', '1', 'Nomós Voiotías', 'GR.ESYE24.33', 'ASCII:Nomos Voiotias;ID:251851', '15377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15377', '112', '17254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE24.33» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17255', '1079', '1', 'Trikala', 'GR.ESYE14.22', 'ASCII:Trikala;ID:252661', '15378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15378', '112', '17255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE14.22» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17256', '1079', '1', 'Nomós Thesprotías', 'GR.ESYE21.18', 'ASCII:Thesprotia;ID:252941', '15379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15379', '112', '17256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE21.18» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17257', '1079', '1', 'Nomós Sámou', 'GR.ESYE41.48', 'ASCII:Nomos Samou;ID:254112', '15380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15380', '112', '17257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE41.48» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17258', '1079', '1', 'Nomós Rethýmnis', 'GR.ESYE43.44', 'ASCII:Nomos Rethymnis;ID:254353', '15381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15381', '112', '17258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE43.44» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17259', '1079', '1', 'Nomós Prevézis', 'GR.ESYE21.19', 'ASCII:Nomos Prevezis;ID:254695', '15382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15382', '112', '17259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE21.19» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17260', '1079', '1', 'Nomós Messinías', 'GR.ESYE25.40', 'ASCII:Messenia;ID:257149', '15383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15383', '112', '17260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE25.40» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17261', '1079', '1', 'Nomós Magnisías', 'GR.ESYE14.24', 'ASCII:Nomos Magnisias;ID:258013', '15384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15384', '112', '17261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE14.24» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17262', '1079', '1', 'Nomós Lefkádas', 'GR.ESYE22.26', 'ASCII:Nomos Lefkadas;ID:258445', '15385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15385', '112', '17262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE22.26» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17263', '1079', '1', 'Nomós Lésvou', 'GR.ESYE41.51', 'ASCII:Nomos Lesvou;ID:258465', '15386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15386', '112', '17263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE41.51» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17264', '1079', '1', 'Nomós Lasithíou', 'GR.ESYE43.46', 'ASCII:Nomos Lasithiou;ID:258569', '15387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15387', '112', '17264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE43.46» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17265', '1079', '1', 'Nomós Larísis', 'GR.ESYE14.21', 'ASCII:Nomos Larisis;ID:258575', '15388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15388', '112', '17265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE14.21» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17266', '1079', '1', 'Nomós Lakonías', 'GR.ESYE25.42', 'ASCII:Laconia;ID:258657', '15389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15389', '112', '17266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE25.42» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17267', '1079', '1', 'Nomós Korinthías', 'GR.ESYE25.37', 'ASCII:Nomos Korinthias;ID:259290', '15390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15390', '112', '17267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE25.37» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17268', '1079', '1', 'Nomós Kykládon', 'GR.ESYE42.49', 'ASCII:Nomos Kykladon;ID:259819', '15391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15391', '112', '17268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE42.49» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17269', '1079', '1', 'Nomós Chíou', 'GR.ESYE41.50', 'ASCII:Nomos Chiou;ID:259970', '15392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15392', '112', '17269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE41.50» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17270', '1079', '1', 'Nomós Chaniás', 'GR.ESYE43.43', 'ASCII:Nomos Chanias;ID:260096', '15393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15393', '112', '17270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE43.43» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17271', '1079', '1', 'Nomós Kefallinías', 'GR.ESYE22.27', 'ASCII:Nomos Kefallinias;ID:260310', '15394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15394', '112', '17271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE22.27» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17272', '1079', '1', 'Nomós Kardhítsas', 'GR.ESYE14.23', 'ASCII:Nomos Kardhitsas;ID:260988', '15395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15395', '112', '17272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE14.23» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17273', '1079', '1', 'Nomós Irakleíou', 'GR.ESYE43.45', 'ASCII:Nomos Irakleiou;ID:261741', '15396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15396', '112', '17273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE43.45» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17274', '1079', '1', 'Nomós Ioannínon', 'GR.ESYE21.17', 'ASCII:Nomos Ioanninon;ID:261777', '15397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15397', '112', '17274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE21.17» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17275', '1079', '1', 'Nomós Ileías', 'GR.ESYE23.39', 'ASCII:Nomos Ileias;ID:261797', '15398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15398', '112', '17275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE23.39» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17276', '1079', '1', 'Nomós Fthiótidos', 'GR.ESYE24.29', 'ASCII:Phthiotis;ID:262187', '15399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15399', '112', '17276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE24.29» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17277', '1079', '1', 'Nomós Fokídos', 'GR.ESYE24.32', 'ASCII:Phocis;ID:262322', '15400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15400', '112', '17277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE24.32» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17278', '1079', '1', 'Nomós Evvoías', 'GR.ESYE24.34', 'ASCII:Nomos Evvoias;ID:262564', '15401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15401', '112', '17278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE24.34» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17279', '1079', '1', 'Nomós Evrytanías', 'GR.ESYE24.30', 'ASCII:Nomos Evrytanias;ID:262572', '15402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15402', '112', '17279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE24.30» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17280', '1079', '1', 'Nomós Dodekanísou', 'GR.ESYE42.47', 'ASCII:Nomos Dodekanisou;ID:263021', '15403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15403', '112', '17280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE42.47» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17281', '1079', '1', 'Nomós Attikís', 'GR.ESYE31.35', 'ASCII:Nomos Attikis;ID:264353', '15404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15404', '112', '17281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE31.35» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17282', '1079', '1', 'Nomós Ártas', 'GR.ESYE21.20', 'ASCII:Nomos Artas;ID:264545', '15405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15405', '112', '17282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE21.20» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17283', '1079', '1', 'Nomós Arkadías', 'GR.ESYE25.41', 'ASCII:Arcadia;ID:264644', '15406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15406', '112', '17283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE25.41» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17284', '1079', '1', 'Nomós Argolídos', 'GR.ESYE25.36', 'ASCII:Nomos Argolidos;ID:264673', '15407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15407', '112', '17284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE25.36» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17285', '1079', '1', 'Nomós Achaḯas', 'GR.ESYE23.38', 'ASCII:null;ID:265491', '15408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15408', '112', '17285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE23.38» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17286', '1079', '1', 'Nomós Aitolías kai Akarnanías', 'GR.ESYE23.31', 'ASCII:Nomos Aitolias kai Akarnanias;ID:265508', '15409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15409', '112', '17286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE23.31» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17287', '1079', '1', 'Nomós Piraiós', 'GR.ESYE31.406101', 'ASCII:Nomos Piraios;ID:406101', '15410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15410', '112', '17287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE31.406101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17288', '1079', '1', 'Nomarchía Anatolikís Attikís', 'GR.ESYE31.445406', 'ASCII:Nomarchia Anatolikis Attikis;ID:445406', '15411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15411', '112', '17288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE31.445406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17289', '1079', '1', 'Nomarchía Dytikís Attikís', 'GR.ESYE31.445407', 'ASCII:Nomarchia Dytikis Attikis;ID:445407', '15412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15412', '112', '17289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE31.445407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17290', '1079', '1', 'Nomarchía Athínas', 'GR.ESYE31.445408', 'ASCII:Nomarchia Athinas;ID:445408', '15413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15413', '112', '17290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE31.445408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17291', '1079', '1', 'Nomós Xánthis', 'GR.ESYE11.03', 'ASCII:Nomos Xanthis;ID:733839', '15414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15414', '112', '17291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE11.03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17292', '1079', '1', 'Nomós Thessaloníkis', 'GR.ESYE12.13', 'ASCII:Nomos Thessalonikis;ID:734075', '15415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15415', '112', '17292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE12.13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17293', '1079', '1', 'Nomós Serrón', 'GR.ESYE12.05', 'ASCII:Nomos Serron;ID:734329', '15416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15416', '112', '17293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE12.05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17294', '1079', '1', 'Nomós Rodópis', 'GR.ESYE11.02', 'ASCII:Nomos Rodopis;ID:734375', '15417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15417', '112', '17294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE11.02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17295', '1079', '1', 'Nomós Pierías', 'GR.ESYE12.16', 'ASCII:Nomos Pierias;ID:734649', '15418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15418', '112', '17295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE12.16» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17296', '1079', '1', 'Nomós Péllis', 'GR.ESYE12.07', 'ASCII:Nomos Pellis;ID:734725', '15419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15419', '112', '17296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE12.07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17297', '1079', '1', 'Nomós Kozánis', 'GR.ESYE13.11', 'ASCII:Nomos Kozanis;ID:735562', '15420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15420', '112', '17297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE13.11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17298', '1079', '1', 'Nomós Kilkís', 'GR.ESYE12.06', 'ASCII:Nomos Kilkis;ID:735735', '15421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15421', '112', '17298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE12.06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17299', '1079', '1', 'Nomós Chalkidikís', 'GR.ESYE12.15', 'ASCII:Chalcidice;ID:735804', '15422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15422', '112', '17299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE12.15» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17300', '1079', '1', 'Nomós Kaválas', 'GR.ESYE11.14', 'ASCII:Nomos Kavalas;ID:735857', '15423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15423', '112', '17300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE11.14» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17301', '1079', '1', 'Nomós Kastoriás', 'GR.ESYE13.09', 'ASCII:Nomos Kastorias;ID:735925', '15424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15424', '112', '17301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE13.09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17302', '1079', '1', 'Nomós Imathías', 'GR.ESYE12.12', 'ASCII:Nomos Imathias;ID:736120', '15425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15425', '112', '17302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE12.12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17303', '1079', '1', 'Nomós Grevenón', 'GR.ESYE13.10', 'ASCII:Nomos Grevenon;ID:736149', '15426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15426', '112', '17303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE13.10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17304', '1079', '1', 'Nomós Florínis', 'GR.ESYE13.08', 'ASCII:Nomos Florinis;ID:736228', '15427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15427', '112', '17304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE13.08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17305', '1079', '1', 'Nomós Évrou', 'GR.ESYE11.01', 'ASCII:Nomos Evrou;ID:736287', '15428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15428', '112', '17305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE11.01» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17306', '1079', '1', 'Nomós Drámas', 'GR.ESYE11.04', 'ASCII:Nomos Dramas;ID:736363', '15429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15429', '112', '17306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE11.04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17307', '1079', '1', 'Nomós Kerkýras', 'GR.ESYE22.25', 'ASCII:Nomos Kerkyras;ID:2463676', '15430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15430', '112', '17307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GR.ESYE22.25» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17308', '1079', '1', 'Municipio de Zunilito', 'GT.20.3587505', 'ASCII:Municipio de Zunilito;ID:3587505', '15431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15431', '112', '17308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3587505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17309', '1079', '1', 'Municipio de Zunil', 'GT.13.3587508', 'ASCII:Municipio de Zunil;ID:3587508', '15432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15432', '112', '17309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3587508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17310', '1079', '1', 'Municipio de Zaragoza', 'GT.03.3587541', 'ASCII:Municipio de Zaragoza;ID:3587541', '15433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15433', '112', '17310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3587541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17311', '1079', '1', 'Municipio de Zapotitlán', 'GT.11.3587545', 'ASCII:Municipio de Zapotitlan;ID:3587545', '15434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15434', '112', '17311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3587545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17312', '1079', '1', 'Municipio de Zacapa', 'GT.22.3587585', 'ASCII:Municipio de Zacapa;ID:3587585', '15435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15435', '112', '17312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.22.3587585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17313', '1079', '1', 'Municipio de Yupiltepeque', 'GT.11.3587591', 'ASCII:Municipio de Yupiltepeque;ID:3587591', '15436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15436', '112', '17313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3587591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17314', '1079', '1', 'Municipio de Yepocapa', 'GT.03.3587635', 'ASCII:Municipio de Yepocapa;ID:3587635', '15437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15437', '112', '17314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3587635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17315', '1079', '1', 'Municipio de Villa Nueva', 'GT.07.3587901', 'ASCII:Municipio de Villa Nueva;ID:3587901', '15438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15438', '112', '17315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3587901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17316', '1079', '1', 'Municipio de Villa Canales', 'GT.07.3587922', 'ASCII:Municipio de Villa Canales;ID:3587922', '15439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15439', '112', '17316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3587922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17317', '1079', '1', 'Municipio de Usumatlán', 'GT.22.3588039', 'ASCII:Municipio de Usumatlan;ID:3588039', '15440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15440', '112', '17317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.22.3588039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17318', '1079', '1', 'Municipio de Uspantán', 'GT.14.3588042', 'ASCII:Municipio de Uspantan;ID:3588042', '15441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15441', '112', '17318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3588042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17319', '1079', '1', 'Municipio de Tucurú', 'GT.01.3588205', 'ASCII:Municipio de Tucuru;ID:3588205', '15442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15442', '112', '17319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3588205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17320', '1079', '1', 'Municipio de Totonicapán', 'GT.21.3588255', 'ASCII:Municipio de Totonicapan;ID:3588255', '15443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15443', '112', '17320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.21.3588255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17321', '1079', '1', 'Municipio de Todos Santos Cuchumatán', 'GT.08.3588307', 'ASCII:Municipio de Todos Santos Cuchumatan;ID:3588307', '15444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15444', '112', '17321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3588307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17322', '1079', '1', 'Municipio de Tiquisate', 'GT.06.3588341', 'ASCII:Municipio de Tiquisate;ID:3588341', '15445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15445', '112', '17322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3588341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17323', '1079', '1', 'Municipio de Tejutla', 'GT.17.3588459', 'ASCII:Municipio de Tejutla;ID:3588459', '15446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15446', '112', '17323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3588459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17324', '1079', '1', 'Muncipio de Teculután', 'GT.22.3588468', 'ASCII:Muncipio de Teculutan;ID:3588468', '15447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15447', '112', '17324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.22.3588468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17325', '1079', '1', 'Municipio de Tectitán', 'GT.08.3588473', 'ASCII:Municipio de Tectitan;ID:3588473', '15448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15448', '112', '17325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3588473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17326', '1079', '1', 'Municipio de Tecpán Guatemala', 'GT.03.3588475', 'ASCII:Municipio de Tecpan Guatemala;ID:3588475', '15449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15449', '112', '17326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3588475» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17327', '1079', '1', 'Municipio de Taxisco', 'GT.18.3588490', 'ASCII:Municipio de Taxisco;ID:3588490', '15450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15450', '112', '17327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3588490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17328', '1079', '1', 'Municipio de Tamahú', 'GT.01.3588553', 'ASCII:Municipio de Tamahu;ID:3588553', '15451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15451', '112', '17328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3588553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17329', '1079', '1', 'Municipio de Tajumulco', 'GT.17.3588587', 'ASCII:Municipio de Tajumulco;ID:3588587', '15452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15452', '112', '17329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3588587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17330', '1079', '1', 'Municipio de Tactic', 'GT.01.3588602', 'ASCII:Municipio de Tactic;ID:3588602', '15453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15453', '112', '17330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3588602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17331', '1079', '1', 'Municipio de Tacaná', 'GT.17.3588609', 'ASCII:Municipio de Tacana;ID:3588609', '15454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15454', '112', '17331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3588609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17332', '1079', '1', 'Municipio de Sumpango', 'GT.16.3588652', 'ASCII:Municipio de Sumpango;ID:3588652', '15455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15455', '112', '17332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3588652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17333', '1079', '1', 'Municipio de Soloma', 'GT.08.3588693', 'ASCII:Municipio de Soloma;ID:3588693', '15456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15456', '112', '17333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3588693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17334', '1079', '1', 'Municipio de Sololá', 'GT.19.3588695', 'ASCII:Municipio de Solola;ID:3588695', '15457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15457', '112', '17334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3588695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17335', '1079', '1', 'Municipio de Siquinalá', 'GT.06.3588719', 'ASCII:Municipio de Siquinala;ID:3588719', '15458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15458', '112', '17335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3588719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17336', '1079', '1', 'Municipio de Sipacapa', 'GT.17.3588725', 'ASCII:Municipio de Sipacapa;ID:3588725', '15459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15459', '112', '17336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3588725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17337', '1079', '1', 'Municipio de Sibinal', 'GT.17.3588759', 'ASCII:Municipio de Sibinal;ID:3588759', '15460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15460', '112', '17337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3588759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17338', '1079', '1', 'Municipio de Sibilia', 'GT.13.3588761', 'ASCII:Municipio de Sibilia;ID:3588761', '15461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15461', '112', '17338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3588761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17339', '1079', '1', 'Municipio de Senahú', 'GT.01.3588857', 'ASCII:Municipio de Senahu;ID:3588857', '15462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15462', '112', '17339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3588857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17340', '1079', '1', 'Municipio de Sayaxché', 'GT.12.3588983', 'ASCII:Municipio de Sayaxche;ID:3588983', '15463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15463', '112', '17340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3588983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17341', '1079', '1', 'Municipio de San Vicente Pacaya', 'GT.06.3589034', 'ASCII:Municipio de San Vicente Pacaya;ID:3589034', '15464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15464', '112', '17341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3589034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17342', '1079', '1', 'Municipio de Santo Tomás La Unión', 'GT.20.3589061', 'ASCII:Municipio de Santo Tomas La Union;ID:3589061', '15465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15465', '112', '17342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3589061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17343', '1079', '1', 'Municipio de Santo Domingo Xenacoj', 'GT.16.3589071', 'ASCII:Municipio de Santo Domingo Xenacoj;ID:3589071', '15466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15466', '112', '17343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3589071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17344', '1079', '1', 'Municipio de Santo Domingo Suchitepéquez', 'GT.20.3589073', 'ASCII:Municipio de Santo Domingo Suchitepequez;ID:3589073', '15467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15467', '112', '17344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3589073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17345', '1079', '1', 'Municipio de Santiago Sacatepéquez', 'GT.16.3589100', 'ASCII:Municipio de Santiago Sacatepequez;ID:3589100', '15468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15468', '112', '17345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3589100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17346', '1079', '1', 'Municipio de Santiago Chimaltenango', 'GT.08.3589102', 'ASCII:Municipio de Santiago Chimaltenango;ID:3589102', '15469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15469', '112', '17346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17347', '1079', '1', 'Municipio de Santiago Atitlán', 'GT.19.3589104', 'ASCII:Municipio de Santiago Atitlan;ID:3589104', '15470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15470', '112', '17347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17348', '1079', '1', 'Municipio de Santa Rosa de Lima', 'GT.18.3589158', 'ASCII:Municipio de Santa Rosa de Lima;ID:3589158', '15471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15471', '112', '17348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3589158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17349', '1079', '1', 'Municipio de Santa María Visitación', 'GT.19.3589246', 'ASCII:Municipio de Santa Maria Visitacion;ID:3589246', '15472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15472', '112', '17349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17350', '1079', '1', 'Municipio de Santa María Ixhuatán', 'GT.18.3589248', 'ASCII:Municipio de Santa Maria Ixhuatan;ID:3589248', '15473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15473', '112', '17350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3589248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17351', '1079', '1', 'Municipio de Santa María de Jesús', 'GT.16.3589251', 'ASCII:Municipio de Santa Maria de Jesus;ID:3589251', '15474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15474', '112', '17351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3589251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17352', '1079', '1', 'Municipio de Santa María Chiquimula', 'GT.21.3589255', 'ASCII:Municipio de Santa Maria Chiquimula;ID:3589255', '15475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15475', '112', '17352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.21.3589255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17353', '1079', '1', 'Municipio de Santa Lucía Utatlán', 'GT.19.3589281', 'ASCII:Municipio de Santa Lucia Utatlan;ID:3589281', '15476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15476', '112', '17353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17354', '1079', '1', 'Municipio de Santa Lucía Milpas Altas', 'GT.16.3589284', 'ASCII:Municipio de Santa Lucia Milpas Altas;ID:3589284', '15477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15477', '112', '17354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3589284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17355', '1079', '1', 'Municipio de Santa Lucía La Reforma', 'GT.21.3589286', 'ASCII:Municipio de Santa Lucia La Reforma;ID:3589286', '15478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15478', '112', '17355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.21.3589286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17356', '1079', '1', 'Municipio de Santa Lucía Cotzumalguapa', 'GT.06.3589288', 'ASCII:Municipio de Santa Lucia Cotzumalguapa;ID:3589288', '15479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15479', '112', '17356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3589288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17357', '1079', '1', 'Municipio de Santa Eulalia', 'GT.08.3589354', 'ASCII:Municipio de Santa Eulalia;ID:3589354', '15480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15480', '112', '17357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17358', '1079', '1', 'Municipio de Santa Cruz Verapaz', 'GT.01.3589394', 'ASCII:Municipio de Santa Cruz Verapaz;ID:3589394', '15481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15481', '112', '17358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3589394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17359', '1079', '1', 'Municipio de Santa Cruz Naranjo', 'GT.18.3589397', 'ASCII:Municipio de Santa Cruz Naranjo;ID:3589397', '15482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15482', '112', '17359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3589397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17360', '1079', '1', 'Municipio de Santa Cruz Muluá', 'GT.15.3589399', 'ASCII:Municipio de Santa Cruz Mulua;ID:3589399', '15483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15483', '112', '17360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.15.3589399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17361', '1079', '1', 'Municipio de Santa Cruz La Laguna', 'GT.19.3589401', 'ASCII:Municipio de Santa Cruz La Laguna;ID:3589401', '15484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15484', '112', '17361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17362', '1079', '1', 'Municipio de Santa Cruz del Quiché', 'GT.14.3589403', 'ASCII:Municipio de Santa Cruz del Quiche;ID:3589403', '15485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15485', '112', '17362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3589403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17363', '1079', '1', 'Municipio de Santa Cruz Balanyá', 'GT.03.3589407', 'ASCII:Municipio de Santa Cruz Balanya;ID:3589407', '15486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15486', '112', '17363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3589407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17364', '1079', '1', 'Municipio de Santa Clara La Laguna', 'GT.19.3589432', 'ASCII:Municipio de Santa Clara La Laguna;ID:3589432', '15487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15487', '112', '17364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17365', '1079', '1', 'Municipio de Santa Catarina Pinula', 'GT.07.3589451', 'ASCII:Municipio de Santa Catarina Pinula;ID:3589451', '15488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15488', '112', '17365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3589451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17366', '1079', '1', 'Municipio de Santa Catarina Palopó', 'GT.19.3589453', 'ASCII:Municipio de Santa Catarina Palopo;ID:3589453', '15489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15489', '112', '17366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17367', '1079', '1', 'Municipio de Santa Catarina Mita', 'GT.11.3589455', 'ASCII:Municipio de Santa Catarina Mita;ID:3589455', '15490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15490', '112', '17367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3589455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17368', '1079', '1', 'Municipio de Santa Catarina Ixtahuacán', 'GT.19.3589457', 'ASCII:Municipio de Santa Catarina Ixtahuacan;ID:3589457', '15491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15491', '112', '17368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17369', '1079', '1', 'Municipio de Santa Catarina Barahona', 'GT.16.3589459', 'ASCII:Municipio de Santa Catarina Barahona;ID:3589459', '15492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15492', '112', '17369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3589459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17370', '1079', '1', 'Municipio de Santa Bárbara', 'GT.08.3589464', 'ASCII:Municipio de Santa Barbara;ID:3589464', '15493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15493', '112', '17370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17371', '1079', '1', 'Municipio de Santa Bárbara', 'GT.20.3589465', 'ASCII:Municipio de Santa Barbara;ID:3589465', '15494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15494', '112', '17371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3589465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17372', '1079', '1', 'Municipio de Santa Apolonia', 'GT.03.3589479', 'ASCII:Municipio de Santa Apolonia;ID:3589479', '15495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15495', '112', '17372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3589479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17373', '1079', '1', 'Municipio de Santa Ana Huista', 'GT.08.3589497', 'ASCII:Municipio de Santa Ana Huista;ID:3589497', '15496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15496', '112', '17373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17374', '1079', '1', 'Municipio de Santa Ana', 'GT.12.3589501', 'ASCII:Municipio de Santa Ana;ID:3589501', '15497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15497', '112', '17374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3589501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17375', '1079', '1', 'Municipio de San Sebastián Huehuetenango', 'GT.08.3589540', 'ASCII:Municipio de San Sebastian Huehuetenango;ID:3589540', '15498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15498', '112', '17375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17376', '1079', '1', 'Municipio de San Sebastián Coatán', 'GT.08.3589542', 'ASCII:Municipio de San Sebastian Coatan;ID:3589542', '15499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15499', '112', '17376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589542» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17377', '1079', '1', 'Municipio de San Sebastián', 'GT.15.3589545', 'ASCII:Municipio de San Sebastian;ID:3589545', '15500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15500', '112', '17377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.15.3589545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17378', '1079', '1', 'Municipio de Sansare', 'GT.05.3589553', 'ASCII:Municipio de Sansare;ID:3589553', '15501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15501', '112', '17378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.05.3589553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17379', '1079', '1', 'Municipio de San Raimundo', 'GT.07.3589568', 'ASCII:Municipio de San Raimundo;ID:3589568', '15502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15502', '112', '17379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3589568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17380', '1079', '1', 'Municipio de San Rafael Pie de La Cuesta', 'GT.17.3589576', 'ASCII:Municipio de San Rafael Pie de La Cuesta;ID:3589576', '15503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15503', '112', '17380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3589576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17381', '1079', '1', 'Municipio de San Rafael Petzal', 'GT.08.3589578', 'ASCII:Municipio de San Rafael Petzal;ID:3589578', '15504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15504', '112', '17381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17382', '1079', '1', 'Municipio de San Rafael Las Flores', 'GT.18.3589588', 'ASCII:Municipio de San Rafael Las Flores;ID:3589588', '15505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15505', '112', '17382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3589588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17383', '1079', '1', 'Municipio de San Rafael La Independencia', 'GT.08.3589594', 'ASCII:Municipio de San Rafael La Independencia;ID:3589594', '15506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15506', '112', '17383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17384', '1079', '1', 'Municipio de San Pedro Sacatepéquez', 'GT.17.3589624', 'ASCII:Municipio de San Pedro Sacatepequez;ID:3589624', '15507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15507', '112', '17384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3589624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17385', '1079', '1', 'Municipio de San Pedro Sacatepéquez', 'GT.07.3589625', 'ASCII:Municipio de San Pedro Sacatepequez;ID:3589625', '15508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15508', '112', '17385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3589625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17386', '1079', '1', 'Municipio de San Pedro Pinula', 'GT.10.3589628', 'ASCII:Municipio de San Pedro Pinula;ID:3589628', '15509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15509', '112', '17386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.10.3589628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17387', '1079', '1', 'Municipio de San Pedro Necta', 'GT.08.3589631', 'ASCII:Municipio de San Pedro Necta;ID:3589631', '15510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15510', '112', '17387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17388', '1079', '1', 'Municipio de San Pedro La Laguna', 'GT.19.3589636', 'ASCII:Municipio de San Pedro La Laguna;ID:3589636', '15511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15511', '112', '17388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17389', '1079', '1', 'Municipio de San Pedro Jocopilas', 'GT.14.3589639', 'ASCII:Municipio de San Pedro Jocopilas;ID:3589639', '15512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15512', '112', '17389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3589639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17390', '1079', '1', 'Municipio de San Pedro Carchá', 'GT.01.3589642', 'ASCII:Municipio de San Pedro Carcha;ID:3589642', '15513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15513', '112', '17390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3589642» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17391', '1079', '1', 'Municipio de San Pedro Ayampuc', 'GT.07.3589645', 'ASCII:Municipio de San Pedro Ayampuc;ID:3589645', '15514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15514', '112', '17391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3589645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17392', '1079', '1', 'Municipio de San Pablo La Laguna', 'GT.19.3589668', 'ASCII:Municipio de San Pablo La Laguna;ID:3589668', '15515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15515', '112', '17392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17393', '1079', '1', 'Municipio de San Pablo Jocopilas', 'GT.20.3589670', 'ASCII:Municipio de San Pablo Jocopilas;ID:3589670', '15516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15516', '112', '17393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3589670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17394', '1079', '1', 'Municipio de San Pablo', 'GT.17.3589673', 'ASCII:Municipio de San Pablo;ID:3589673', '15517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15517', '112', '17394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3589673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17395', '1079', '1', 'Municipio de San Miguel Sigüilá', 'GT.13.3589705', 'ASCII:Municipio de San Miguel Siguila;ID:3589705', '15518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15518', '112', '17395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3589705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17396', '1079', '1', 'Municipio de San Miguel Panán', 'GT.20.3589708', 'ASCII:Municipio de San Miguel Panan;ID:3589708', '15519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15519', '112', '17396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3589708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17397', '1079', '1', 'Municipio de San Miguel Ixtahuacán', 'GT.17.3589719', 'ASCII:Municipio de San Miguel Ixtahuacan;ID:3589719', '15520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15520', '112', '17397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3589719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17398', '1079', '1', 'Municipio de San Miguel Dueñas', 'GT.16.3589726', 'ASCII:Municipio de San Miguel Duenas;ID:3589726', '15521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15521', '112', '17398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3589726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17399', '1079', '1', 'Municipio de San Miguel Chicaj', 'GT.02.3589729', 'ASCII:Municipio de San Miguel Chicaj;ID:3589729', '15522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15522', '112', '17399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.02.3589729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17400', '1079', '1', 'Municipio de San Miguel Acatán', 'GT.08.3589733', 'ASCII:Municipio de San Miguel Acatan;ID:3589733', '15523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15523', '112', '17400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17401', '1079', '1', 'Municipio de San Mateo Ixtatán', 'GT.08.3589769', 'ASCII:Municipio de San Mateo Ixtatan;ID:3589769', '15524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15524', '112', '17401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17402', '1079', '1', 'Municipio de San Mateo', 'GT.13.3589772', 'ASCII:Municipio de San Mateo;ID:3589772', '15525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15525', '112', '17402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3589772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17403', '1079', '1', 'Municipio de San Martín Zapotitlán', 'GT.15.3589775', 'ASCII:Municipio de San Martin Zapotitlan;ID:3589775', '15526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15526', '112', '17403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.15.3589775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17404', '1079', '1', 'Municipio de San Martín Sacatepéquez', 'GT.13.3589777', 'ASCII:Municipio de San Martin Sacatepequez;ID:3589777', '15527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15527', '112', '17404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3589777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17405', '1079', '1', 'Municipio de San Martín Jilotepeque', 'GT.03.3589779', 'ASCII:Municipio de San Martin Jilotepeque;ID:3589779', '15528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15528', '112', '17405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3589779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17406', '1079', '1', 'Municipio de San Marcos La Laguna', 'GT.19.3589794', 'ASCII:Municipio de San Marcos La Laguna;ID:3589794', '15529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15529', '112', '17406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17407', '1079', '1', 'Municipio de San Marcos', 'GT.17.3589799', 'ASCII:Municipio de San Marcos;ID:3589799', '15530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15530', '112', '17407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3589799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17408', '1079', '1', 'Municipio de San Manuel Chaparrón', 'GT.10.3589811', 'ASCII:Municipio de San Manuel Chaparron;ID:3589811', '15531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15531', '112', '17408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.10.3589811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17409', '1079', '1', 'Muncipio de San Luis Jilotepeque', 'GT.10.3589821', 'ASCII:Muncipio de San Luis Jilotepeque;ID:3589821', '15532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15532', '112', '17409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.10.3589821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17410', '1079', '1', 'Municipio de San Luis', 'GT.12.3589835', 'ASCII:Municipio de San Luis;ID:3589835', '15533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15533', '112', '17410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3589835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17411', '1079', '1', 'Municipio de San Lucas Tolimán', 'GT.19.3589849', 'ASCII:Municipio de San Lucas Toliman;ID:3589849', '15534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15534', '112', '17411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17412', '1079', '1', 'Municipio de San Lucas Sacatepéquez', 'GT.16.3589851', 'ASCII:Municipio de San Lucas Sacatepequez;ID:3589851', '15535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15535', '112', '17412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3589851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17413', '1079', '1', 'Municipio de San Lorenzo', 'GT.17.3589860', 'ASCII:Municipio de San Lorenzo;ID:3589860', '15536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15536', '112', '17413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3589860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17414', '1079', '1', 'Municipio de San Lorenzo', 'GT.20.3589861', 'ASCII:Municipio de San Lorenzo;ID:3589861', '15537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15537', '112', '17414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3589861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17415', '1079', '1', 'Municipio de San Juan Tecuaco', 'GT.18.3589879', 'ASCII:Municipio de San Juan Tecuaco;ID:3589879', '15538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15538', '112', '17415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3589879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17416', '1079', '1', 'Municipio de San Juan Sacatepéquez', 'GT.07.3589884', 'ASCII:Municipio de San Juan Sacatepequez;ID:3589884', '15539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15539', '112', '17416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3589884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17417', '1079', '1', 'Municipio de San Juan La Laguna', 'GT.19.3589895', 'ASCII:Municipio de San Juan La Laguna;ID:3589895', '15540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15540', '112', '17417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3589895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17418', '1079', '1', 'Municipio de San Juan Ixcoy', 'GT.08.3589899', 'ASCII:Municipio de San Juan Ixcoy;ID:3589899', '15541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15541', '112', '17418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17419', '1079', '1', 'Municipio de San Juan Ermita', 'GT.04.3589902', 'ASCII:Municipio de San Juan Ermita;ID:3589902', '15542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15542', '112', '17419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3589902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17420', '1079', '1', 'Municipio de San Juan Cotzal', 'GT.14.3589912', 'ASCII:Municipio de San Juan Cotzal;ID:3589912', '15543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15543', '112', '17420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3589912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17421', '1079', '1', 'Municipio de San Juan Chamelco', 'GT.01.3589916', 'ASCII:Municipio de San Juan Chamelco;ID:3589916', '15544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15544', '112', '17421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3589916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17422', '1079', '1', 'Municipio de San Juan Bautista', 'GT.20.3589920', 'ASCII:Municipio de San Juan Bautista;ID:3589920', '15545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15545', '112', '17422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3589920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17423', '1079', '1', 'Municipio de San Juan Atitán', 'GT.08.3589924', 'ASCII:Municipio de San Juan Atitan;ID:3589924', '15546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15546', '112', '17423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3589924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17424', '1079', '1', 'Municipio de San José Poaquil', 'GT.03.3589974', 'ASCII:Municipio de San Jose Poaquil;ID:3589974', '15547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15547', '112', '17424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3589974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17425', '1079', '1', 'Municipio de San José Pinula', 'GT.07.3589976', 'ASCII:Municipio de San Jose Pinula;ID:3589976', '15548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15548', '112', '17425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3589976» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17426', '1079', '1', 'Municipio de San José Ojetenam', 'GT.17.3589984', 'ASCII:Municipio de San Jose Ojetenam;ID:3589984', '15549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15549', '112', '17426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3589984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17427', '1079', '1', 'Municipio de San José La Arada', 'GT.04.3590016', 'ASCII:Municipio de San Jose La Arada;ID:3590016', '15550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15550', '112', '17427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3590016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17428', '1079', '1', 'Municipio de San José El Ídolo', 'GT.20.3590028', 'ASCII:Municipio de San Jose El Idolo;ID:3590028', '15551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15551', '112', '17428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3590028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17429', '1079', '1', 'Municipio de San José del Golfo', 'GT.07.3590033', 'ASCII:Municipio de San Jose del Golfo;ID:3590033', '15552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15552', '112', '17429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3590033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17430', '1079', '1', 'Municipio de San José Chacayá', 'GT.19.3590040', 'ASCII:Municipio de San Jose Chacaya;ID:3590040', '15553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15553', '112', '17430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3590040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17431', '1079', '1', 'Municipio de San José Acatempa', 'GT.11.3590052', 'ASCII:Municipio de San Jose Acatempa;ID:3590052', '15554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15554', '112', '17431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3590052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17432', '1079', '1', 'Municipio de San José', 'GT.12.3590058', 'ASCII:Municipio de San Jose;ID:3590058', '15555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15555', '112', '17432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3590058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17433', '1079', '1', 'Municipio de San José', 'GT.06.3590059', 'ASCII:Municipio de San Jose;ID:3590059', '15556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15556', '112', '17433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3590059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17434', '1079', '1', 'Municipio de San Jerónimo', 'GT.02.3590106', 'ASCII:Municipio de San Jeronimo;ID:3590106', '15557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15557', '112', '17434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.02.3590106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17435', '1079', '1', 'Municipio de San Jacinto', 'GT.04.3590124', 'ASCII:Municipio de San Jacinto;ID:3590124', '15558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15558', '112', '17435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3590124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17436', '1079', '1', 'Municipio de San Gaspar Ixchil', 'GT.08.3590187', 'ASCII:Municipio de San Gaspar Ixchil;ID:3590187', '15559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15559', '112', '17436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3590187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17437', '1079', '1', 'Municipio de San Gabriel', 'GT.20.3590192', 'ASCII:Municipio de San Gabriel;ID:3590192', '15560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15560', '112', '17437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3590192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17438', '1079', '1', 'Municipio de San Francisco Zapotitlán', 'GT.20.3590196', 'ASCII:Municipio de San Francisco Zapotitlan;ID:3590196', '15561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15561', '112', '17438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3590196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17439', '1079', '1', 'Municipio de San Francisco La Unión', 'GT.13.3590210', 'ASCII:Municipio de San Francisco La Union;ID:3590210', '15562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15562', '112', '17439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3590210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17440', '1079', '1', 'Municipio de San Francisco El Alto', 'GT.21.3590218', 'ASCII:Municipio de San Francisco El Alto;ID:3590218', '15563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15563', '112', '17440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.21.3590218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17441', '1079', '1', 'Municipio de San Francisco', 'GT.12.3590233', 'ASCII:Municipio de San Francisco;ID:3590233', '15564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15564', '112', '17441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3590233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17442', '1079', '1', 'Municipio de San Felipe', 'GT.15.3590281', 'ASCII:Municipio de San Felipe;ID:3590281', '15565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15565', '112', '17442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.15.3590281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17443', '1079', '1', 'Municipio de San Diego', 'GT.22.3590305', 'ASCII:Municipio de San Diego;ID:3590305', '15566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15566', '112', '17443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.22.3590305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17444', '1079', '1', 'Municipio de San Cristóbal Verapaz', 'GT.01.3590315', 'ASCII:Municipio de San Cristobal Verapaz;ID:3590315', '15567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15567', '112', '17444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3590315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17445', '1079', '1', 'Municipio de San Cristóbal Totonicapán', 'GT.21.3590317', 'ASCII:Municipio de San Cristobal Totonicapan;ID:3590317', '15568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15568', '112', '17445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.21.3590317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17446', '1079', '1', 'Municipio de San Cristóbal Cucho', 'GT.17.3590322', 'ASCII:Municipio de San Cristobal Cucho;ID:3590322', '15569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15569', '112', '17446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3590322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17447', '1079', '1', 'Municipio de San Cristóbal Acasaguastlán', 'GT.05.3590324', 'ASCII:Municipio de San Cristobal Acasaguastlan;ID:3590324', '15570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15570', '112', '17447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.05.3590324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17448', '1079', '1', 'Municipio de San Carlos Sija', 'GT.13.3590346', 'ASCII:Municipio de San Carlos Sija;ID:3590346', '15571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15571', '112', '17448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3590346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17449', '1079', '1', 'Municipio de San Carlos Alzatate', 'GT.10.3590354', 'ASCII:Municipio de San Carlos Alzatate;ID:3590354', '15572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15572', '112', '17449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.10.3590354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17450', '1079', '1', 'Municipio de San Bernardino', 'GT.20.3590382', 'ASCII:Municipio de San Bernardino;ID:3590382', '15573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15573', '112', '17450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3590382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17451', '1079', '1', 'Municipio de San Benito', 'GT.12.3590386', 'ASCII:Municipio de San Benito;ID:3590386', '15574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15574', '112', '17451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3590386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17452', '1079', '1', 'Municipio de San Bartolomé Milpas Altas', 'GT.16.3590392', 'ASCII:Municipio de San Bartolome Milpas Altas;ID:3590392', '15575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15575', '112', '17452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3590392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17453', '1079', '1', 'Municipio de San Bartolomé Jocotenango', 'GT.14.3590394', 'ASCII:Municipio de San Bartolome Jocotenango;ID:3590394', '15576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15576', '112', '17453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3590394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17454', '1079', '1', 'Municipio de San Bartolo', 'GT.21.3590397', 'ASCII:Municipio de San Bartolo;ID:3590397', '15577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15577', '112', '17454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.21.3590397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17455', '1079', '1', 'Municipio de Sanarate', 'GT.05.3590405', 'ASCII:Municipio de Sanarate;ID:3590405', '15578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15578', '112', '17455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.05.3590405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17456', '1079', '1', 'Municipio de San Antonio Suchitepéquez', 'GT.20.3590411', 'ASCII:Municipio de San Antonio Suchitepequez;ID:3590411', '15579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15579', '112', '17456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3590411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17457', '1079', '1', 'Municipio de San Antonio Sacatepéquez', 'GT.17.3590418', 'ASCII:Municipio de San Antonio Sacatepequez;ID:3590418', '15580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15580', '112', '17457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3590418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17458', '1079', '1', 'Municipio de San Antonio Palopó', 'GT.19.3590423', 'ASCII:Municipio de San Antonio Palopo;ID:3590423', '15581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15581', '112', '17458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3590423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17459', '1079', '1', 'Municipio de San Antonio La Paz', 'GT.05.3590447', 'ASCII:Municipio de San Antonio La Paz;ID:3590447', '15582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15582', '112', '17459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.05.3590447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17460', '1079', '1', 'Municipio de San Antonio Ilotenango', 'GT.14.3590455', 'ASCII:Municipio de San Antonio Ilotenango;ID:3590455', '15583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15583', '112', '17460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3590455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17461', '1079', '1', 'Municipio de San Antonio Huista', 'GT.08.3590457', 'ASCII:Municipio de San Antonio Huista;ID:3590457', '15584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15584', '112', '17461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3590457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17462', '1079', '1', 'Municipio de San Antonio Aguas Calientes', 'GT.16.3590474', 'ASCII:Municipio de San Antonio Aguas Calientes;ID:3590474', '15585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15585', '112', '17462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3590474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17463', '1079', '1', 'Municipio de San Andrés Xecul', 'GT.21.3590519', 'ASCII:Municipio de San Andres Xecul;ID:3590519', '15586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15586', '112', '17463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.21.3590519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17464', '1079', '1', 'Municipio de San Andrés Villa Seca', 'GT.15.3590521', 'ASCII:Municipio de San Andres Villa Seca;ID:3590521', '15587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15587', '112', '17464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.15.3590521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17465', '1079', '1', 'Municipio de San Andrés Semetabaj', 'GT.19.3590523', 'ASCII:Municipio de San Andres Semetabaj;ID:3590523', '15588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15588', '112', '17465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3590523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17466', '1079', '1', 'Municipio de San Andrés Sajcabajá', 'GT.14.3590525', 'ASCII:Municipio de San Andres Sajcabaja;ID:3590525', '15589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15589', '112', '17466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3590525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17467', '1079', '1', 'Municipio de San Andrés Itzapa', 'GT.03.3590528', 'ASCII:Municipio de San Andres Itzapa;ID:3590528', '15590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15590', '112', '17467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3590528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17468', '1079', '1', 'Municipio de San Andrés', 'GT.12.3590534', 'ASCII:Municipio de San Andres;ID:3590534', '15591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15591', '112', '17468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3590534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17469', '1079', '1', 'Municipio de San Agustín Acasaguastlán', 'GT.05.3590546', 'ASCII:Municipio de San Agustin Acasaguastlan;ID:3590546', '15592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15592', '112', '17469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.05.3590546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17470', '1079', '1', 'Municipio de Samayac', 'GT.20.3590566', 'ASCII:Municipio de Samayac;ID:3590566', '15593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15593', '112', '17470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3590566» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17471', '1079', '1', 'Municipio de Salcajá', 'GT.13.3590604', 'ASCII:Municipio de Salcaja;ID:3590604', '15594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15594', '112', '17471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3590604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17472', '1079', '1', 'Municipio de Salamá', 'GT.02.3590615', 'ASCII:Municipio de Salama;ID:3590615', '15595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15595', '112', '17472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.02.3590615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17473', '1079', '1', 'Municipio de Sacapulas', 'GT.14.3590689', 'ASCII:Municipio de Sacapulas;ID:3590689', '15596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15596', '112', '17473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3590689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17474', '1079', '1', 'Municipio de Río Hondo', 'GT.22.3590786', 'ASCII:Municipio de Rio Hondo;ID:3590786', '15597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15597', '112', '17474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.22.3590786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17475', '1079', '1', 'Municipio de Río Bravo', 'GT.20.3590802', 'ASCII:Municipio de Rio Bravo;ID:3590802', '15598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15598', '112', '17475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3590802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17476', '1079', '1', 'Municipio de Río Blanco', 'GT.17.3590807', 'ASCII:Municipio de Rio Blanco;ID:3590807', '15599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15599', '112', '17476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3590807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17477', '1079', '1', 'Municipio de Retalhuleu', 'GT.15.3590856', 'ASCII:Municipio de Retalhuleu;ID:3590856', '15600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15600', '112', '17477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.15.3590856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17478', '1079', '1', 'Municipio de Rabinal', 'GT.02.3590923', 'ASCII:Municipio de Rabinal;ID:3590923', '15601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15601', '112', '17478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.02.3590923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17479', '1079', '1', 'Municipio de Quezaltepeque', 'GT.04.3590972', 'ASCII:Municipio de Quezaltepeque;ID:3590972', '15602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15602', '112', '17479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3590972» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17480', '1079', '1', 'Municipio de Quetzaltenango', 'GT.13.3590977', 'ASCII:Municipio de Quetzaltenango;ID:3590977', '15603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15603', '112', '17480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3590977» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17481', '1079', '1', 'Municipio de Quesada', 'GT.11.3590986', 'ASCII:Municipio de Quesada;ID:3590986', '15604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15604', '112', '17481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3590986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17482', '1079', '1', 'Municipio de Purulhá', 'GT.02.3591027', 'ASCII:Municipio de Purulha;ID:3591027', '15605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15605', '112', '17482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.02.3591027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17483', '1079', '1', 'Municipio de Puerto Barrios', 'GT.09.3591061', 'ASCII:Municipio de Puerto Barrios;ID:3591061', '15606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15606', '112', '17483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.09.3591061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17484', '1079', '1', 'Municipio de Pueblo Nuevo Viñas', 'GT.18.3591091', 'ASCII:Municipio de Pueblo Nuevo Vinas;ID:3591091', '15607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15607', '112', '17484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3591091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17485', '1079', '1', 'Municipio de Pueblo Nuevo', 'GT.20.3591096', 'ASCII:Municipio de Pueblo Nuevo;ID:3591096', '15608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15608', '112', '17485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3591096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17486', '1079', '1', 'Municipio de Poptún', 'GT.12.3591180', 'ASCII:Municipio de Poptun;ID:3591180', '15609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15609', '112', '17486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3591180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17487', '1079', '1', 'Municipio de Pochuta', 'GT.03.3591209', 'ASCII:Municipio de Pochuta;ID:3591209', '15610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15610', '112', '17487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3591209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17488', '1079', '1', 'Municipio de Petapa', 'GT.07.3591414', 'ASCII:Municipio de Petapa;ID:3591414', '15611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15611', '112', '17488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3591414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17489', '1079', '1', 'Municipio de Patzún', 'GT.03.3591511', 'ASCII:Municipio de Patzun;ID:3591511', '15612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15612', '112', '17489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3591511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17490', '1079', '1', 'Municipio de Patzité', 'GT.14.3591516', 'ASCII:Municipio de Patzite;ID:3591516', '15613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15613', '112', '17490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3591516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17491', '1079', '1', 'Municipio de Patzicía', 'GT.03.3591521', 'ASCII:Municipio de Patzicia;ID:3591521', '15614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15614', '112', '17491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3591521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17492', '1079', '1', 'Municipio de Patulul', 'GT.20.3591540', 'ASCII:Municipio de Patulul;ID:3591540', '15615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15615', '112', '17492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3591540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17493', '1079', '1', 'Municipio de Pastores', 'GT.16.3591573', 'ASCII:Municipio de Pastores;ID:3591573', '15616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15616', '112', '17493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3591573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17494', '1079', '1', 'Municipio de Pasaco', 'GT.11.3591617', 'ASCII:Municipio de Pasaco;ID:3591617', '15617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15617', '112', '17494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3591617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17495', '1079', '1', 'Municipio de Parramos', 'GT.03.3591628', 'ASCII:Municipio de Parramos;ID:3591628', '15618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15618', '112', '17495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3591628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17496', '1079', '1', 'Municipio de Panzós', 'GT.01.3591675', 'ASCII:Municipio de Panzos;ID:3591675', '15619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15619', '112', '17496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3591675» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17497', '1079', '1', 'Municipio de Panajachel', 'GT.19.3591748', 'ASCII:Municipio de Panajachel;ID:3591748', '15620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15620', '112', '17497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3591748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17498', '1079', '1', 'Municipio de Palín', 'GT.06.3591830', 'ASCII:Municipio de Palin;ID:3591830', '15621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15621', '112', '17498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3591830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17499', '1079', '1', 'Municipio de Palestina de los Altos', 'GT.13.3591840', 'ASCII:Municipio de Palestina de los Altos;ID:3591840', '15622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15622', '112', '17499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3591840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17500', '1079', '1', 'Municipio de Palencia', 'GT.07.3591849', 'ASCII:Municipio de Palencia;ID:3591849', '15623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15623', '112', '17500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3591849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17501', '1079', '1', 'Municipio de Pajapita', 'GT.17.3591884', 'ASCII:Municipio de Pajapita;ID:3591884', '15624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15624', '112', '17501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3591884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17502', '1079', '1', 'Municipio de Ostuncalco', 'GT.13.3591996', 'ASCII:Municipio de Ostuncalco;ID:3591996', '15625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15625', '112', '17502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3591996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17503', '1079', '1', 'Municipio de Oratorio', 'GT.18.3592017', 'ASCII:Municipio de Oratorio;ID:3592017', '15626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15626', '112', '17503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3592017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17504', '1079', '1', 'Municipio de Olopa', 'GT.04.3592034', 'ASCII:Municipio de Olopa;ID:3592034', '15627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15627', '112', '17504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3592034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17505', '1079', '1', 'Municipio de Olintepeque', 'GT.13.3592040', 'ASCII:Municipio de Olintepeque;ID:3592040', '15628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15628', '112', '17505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3592040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17506', '1079', '1', 'Municipio de Ocós', 'GT.17.3592084', 'ASCII:Municipio de Ocos;ID:3592084', '15629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15629', '112', '17506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3592084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17507', '1079', '1', 'Municipio de Nuevo San Carlos', 'GT.15.3592104', 'ASCII:Municipio de Nuevo San Carlos;ID:3592104', '15630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15630', '112', '17507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.15.3592104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17508', '1079', '1', 'Municipio de Nuevo Progreso', 'GT.17.3592107', 'ASCII:Municipio de Nuevo Progreso;ID:3592107', '15631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15631', '112', '17508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3592107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17509', '1079', '1', 'Municipio de Nueva Santa Rosa', 'GT.18.3592125', 'ASCII:Municipio de Nueva Santa Rosa;ID:3592125', '15632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15632', '112', '17509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3592125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17510', '1079', '1', 'Municipio de Nueva Concepción', 'GT.06.3592142', 'ASCII:Municipio de Nueva Concepcion;ID:3592142', '15633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15633', '112', '17510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3592142» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17511', '1079', '1', 'Municipio de Nentón', 'GT.08.3592216', 'ASCII:Municipio de Nenton;ID:3592216', '15634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15634', '112', '17511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3592216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17512', '1079', '1', 'Municipio de Nebaj', 'GT.14.3592236', 'ASCII:Municipio de Nebaj;ID:3592236', '15635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15635', '112', '17512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3592236» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17513', '1079', '1', 'Municipio de Nahualá', 'GT.19.3592285', 'ASCII:Municipio de Nahuala;ID:3592285', '15636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15636', '112', '17513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3592285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17514', '1079', '1', 'Municipio de Moyuta', 'GT.11.3592320', 'ASCII:Municipio de Moyuta;ID:3592320', '15637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15637', '112', '17514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3592320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17515', '1079', '1', 'Municipio de Morazán', 'GT.05.3592348', 'ASCII:Municipio de Morazan;ID:3592348', '15638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15638', '112', '17515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.05.3592348» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17516', '1079', '1', 'Municipio de Morales', 'GT.09.3592361', 'ASCII:Municipio de Morales;ID:3592361', '15639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15639', '112', '17516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.09.3592361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17517', '1079', '1', 'Municipio de Monjas', 'GT.10.3592476', 'ASCII:Municipio de Monjas;ID:3592476', '15640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15640', '112', '17517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.10.3592476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17518', '1079', '1', 'Municipio de Momostenango', 'GT.21.3592482', 'ASCII:Municipio de Momostenango;ID:3592482', '15641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15641', '112', '17518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.21.3592482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17519', '1079', '1', 'Municipio de Mixco', 'GT.07.3592517', 'ASCII:Municipio de Mixco;ID:3592517', '15642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15642', '112', '17519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3592517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17520', '1079', '1', 'Municipio de Melchor de Mencos', 'GT.12.3592595', 'ASCII:Municipio de Melchor de Mencos;ID:3592595', '15643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15643', '112', '17520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3592595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17521', '1079', '1', 'Municipio de Mazatenango', 'GT.20.3592608', 'ASCII:Municipio de Mazatenango;ID:3592608', '15644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15644', '112', '17521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3592608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17522', '1079', '1', 'Municipio de Mataquescuintla', 'GT.10.3592634', 'ASCII:Municipio de Mataquescuintla;ID:3592634', '15645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15645', '112', '17522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.10.3592634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17523', '1079', '1', 'Municipio de Masagua', 'GT.06.3592641', 'ASCII:Municipio de Masagua;ID:3592641', '15646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15646', '112', '17523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3592641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17524', '1079', '1', 'Municipio de Malacatancito', 'GT.08.3592750', 'ASCII:Municipio de Malacatancito;ID:3592750', '15647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15647', '112', '17524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3592750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17525', '1079', '1', 'Municipio de Malacatán', 'GT.17.3592752', 'ASCII:Municipio de Malacatan;ID:3592752', '15648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15648', '112', '17525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3592752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17526', '1079', '1', 'Municipio de Magdalena Milpas Altas', 'GT.16.3592769', 'ASCII:Municipio de Magdalena Milpas Altas;ID:3592769', '15649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15649', '112', '17526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3592769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17527', '1079', '1', 'Municipio de Los Amates', 'GT.09.3593233', 'ASCII:Municipio de Los Amates;ID:3593233', '15650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15650', '112', '17527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.09.3593233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17528', '1079', '1', 'Municipio de Lívingston', 'GT.09.3593375', 'ASCII:Municipio de Livingston;ID:3593375', '15651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15651', '112', '17528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.09.3593375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17529', '1079', '1', 'Municipio de La Unión', 'GT.22.3593488', 'ASCII:Municipio de La Union;ID:3593488', '15652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15652', '112', '17529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.22.3593488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17530', '1079', '1', 'Municipio de La Reforma', 'GT.17.3594137', 'ASCII:Municipio de La Reforma;ID:3594137', '15653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15653', '112', '17530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3594137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17531', '1079', '1', 'Municipio de Lanquín', 'GT.01.3594314', 'ASCII:Municipio de Lanquin;ID:3594314', '15654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15654', '112', '17531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3594314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17532', '1079', '1', 'Municipio de La Libertad', 'GT.12.3594418', 'ASCII:Municipio de La Libertad;ID:3594418', '15655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15655', '112', '17532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3594418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17533', '1079', '1', 'Municipio de La Libertad', 'GT.08.3594419', 'ASCII:Municipio de La Libertad;ID:3594419', '15656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15656', '112', '17533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3594419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17534', '1079', '1', 'Municipio de La Gomera', 'GT.06.3594574', 'ASCII:Municipio de La Gomera;ID:3594574', '15657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15657', '112', '17534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3594574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17535', '1079', '1', 'Municipio de La Esperanza', 'GT.13.3594666', 'ASCII:Municipio de La Esperanza;ID:3594666', '15658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15658', '112', '17535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3594666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17536', '1079', '1', 'Municipio de La Democracia', 'GT.08.3594749', 'ASCII:Municipio de La Democracia;ID:3594749', '15659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15659', '112', '17536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3594749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17537', '1079', '1', 'Municipio de La Democracia', 'GT.06.3594750', 'ASCII:Municipio de La Democracia;ID:3594750', '15660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15660', '112', '17537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3594750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17538', '1079', '1', 'Municipio de Jutiapa', 'GT.11.3595065', 'ASCII:Municipio de Jutiapa;ID:3595065', '15661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15661', '112', '17538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3595065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17539', '1079', '1', 'Municipio de Joyabaj', 'GT.14.3595147', 'ASCII:Municipio de Joyabaj;ID:3595147', '15662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15662', '112', '17539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3595147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17540', '1079', '1', 'Municipio de Jocotenango', 'GT.16.3595170', 'ASCII:Municipio de Jocotenango;ID:3595170', '15663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15663', '112', '17540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3595170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17541', '1079', '1', 'Municipio de Jocotán', 'GT.04.3595180', 'ASCII:Municipio de Jocotan;ID:3595180', '15664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15664', '112', '17541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3595180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17542', '1079', '1', 'Municipio de Jerez', 'GT.11.3595222', 'ASCII:Municipio de Jerez;ID:3595222', '15665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15665', '112', '17542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3595222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17543', '1079', '1', 'Municipio de Jalpatagua', 'GT.11.3595231', 'ASCII:Municipio de Jalpatagua;ID:3595231', '15666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15666', '112', '17543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3595231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17544', '1079', '1', 'Municipio de Jalapa', 'GT.10.3595235', 'ASCII:Municipio de Jalapa;ID:3595235', '15667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15667', '112', '17544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.10.3595235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17545', '1079', '1', 'Municipio de Jacaltenango', 'GT.08.3595247', 'ASCII:Municipio de Jacaltenango;ID:3595247', '15668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15668', '112', '17545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3595247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17546', '1079', '1', 'Municipio de Iztapa', 'GT.06.3595254', 'ASCII:Municipio de Iztapa;ID:3595254', '15669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15669', '112', '17546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3595254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17547', '1079', '1', 'Municipio de Ixtahuacán', 'GT.08.3595281', 'ASCII:Municipio de Ixtahuacan;ID:3595281', '15670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15670', '112', '17547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3595281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17548', '1079', '1', 'Municipio de Ixchiguán', 'GT.17.3595328', 'ASCII:Municipio de Ixchiguan;ID:3595328', '15671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15671', '112', '17548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3595328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17549', '1079', '1', 'Municipio de Ipala', 'GT.04.3595363', 'ASCII:Municipio de Ipala;ID:3595363', '15672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15672', '112', '17549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3595363» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17550', '1079', '1', 'Municipio de Huité', 'GT.22.3595402', 'ASCII:Municipio de Huite;ID:3595402', '15673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15673', '112', '17550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.22.3595402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17551', '1079', '1', 'Municipio de Huitán', 'GT.13.3595404', 'ASCII:Municipio de Huitan;ID:3595404', '15674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15674', '112', '17551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3595404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17552', '1079', '1', 'Municipio de Huehuetenango', 'GT.08.3595414', 'ASCII:Municipio de Huehuetenango;ID:3595414', '15675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15675', '112', '17552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3595414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17553', '1079', '1', 'Municipio de Guazacapán', 'GT.18.3595502', 'ASCII:Municipio de Guazacapan;ID:3595502', '15676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15676', '112', '17553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3595502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17554', '1079', '1', 'Municipio de Guatemala', 'GT.07.3595529', 'ASCII:Municipio de Guatemala;ID:3595529', '15677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15677', '112', '17554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3595529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17555', '1079', '1', 'Municipio de Guanagazapa', 'GT.06.3595553', 'ASCII:Municipio de Guanagazapa;ID:3595553', '15678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15678', '112', '17555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3595553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17556', '1079', '1', 'Municipio de Gualán', 'GT.22.3595559', 'ASCII:Municipio de Gualan;ID:3595559', '15679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15679', '112', '17556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.22.3595559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17557', '1079', '1', 'Municipio de Granados', 'GT.02.3595630', 'ASCII:Municipio de Granados;ID:3595630', '15680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15680', '112', '17557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.02.3595630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17558', '1079', '1', 'Municipio de Génova', 'GT.13.3595670', 'ASCII:Municipio de Genova;ID:3595670', '15681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15681', '112', '17558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3595670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17559', '1079', '1', 'Municipio de Fraijanes', 'GT.07.3595713', 'ASCII:Municipio de Fraijanes;ID:3595713', '15682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15682', '112', '17559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3595713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17560', '1079', '1', 'Municipio de Flores Costa Cuca', 'GT.13.3595720', 'ASCII:Municipio de Flores Costa Cuca;ID:3595720', '15683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15683', '112', '17560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3595720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17561', '1079', '1', 'Municipio de Flores', 'GT.12.3595722', 'ASCII:Municipio de Flores;ID:3595722', '15684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15684', '112', '17561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3595722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17562', '1079', '1', 'Municipio de Estanzuela', 'GT.22.3595755', 'ASCII:Municipio de Estanzuela;ID:3595755', '15685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15685', '112', '17562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.22.3595755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17563', '1079', '1', 'Municipio de Esquipulas Palo Gordo', 'GT.17.3595777', 'ASCII:Municipio de Esquipulas Palo Gordo;ID:3595777', '15686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15686', '112', '17563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3595777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17564', '1079', '1', 'Municipio de Esquipulas', 'GT.04.3595780', 'ASCII:Municipio de Esquipulas;ID:3595780', '15687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15687', '112', '17564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3595780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17565', '1079', '1', 'Municipio de Escuintla', 'GT.06.3595801', 'ASCII:Municipio de Escuintla;ID:3595801', '15688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15688', '112', '17565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.06.3595801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17566', '1079', '1', 'Municipio de El Tumbador', 'GT.17.3595928', 'ASCII:Municipio de El Tumbador;ID:3595928', '15689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15689', '112', '17566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3595928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17567', '1079', '1', 'Municipio de El Tejar', 'GT.03.3596040', 'ASCII:Municipio de El Tejar;ID:3596040', '15690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15690', '112', '17567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3596040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17568', '1079', '1', 'Municipio de El Rodeo', 'GT.17.3596243', 'ASCII:Municipio de El Rodeo;ID:3596243', '15691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15691', '112', '17568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3596243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17569', '1079', '1', 'Municipio de El Quetzal', 'GT.17.3596386', 'ASCII:Municipio de El Quetzal;ID:3596386', '15692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15692', '112', '17569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3596386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17570', '1079', '1', 'Municipio de El Progreso', 'GT.05.3596410', 'ASCII:Municipio de El Progreso;ID:3596410', '15693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15693', '112', '17570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.05.3596410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17571', '1079', '1', 'Municipio de El Progreso', 'GT.11.3596411', 'ASCII:Municipio de El Progreso;ID:3596411', '15694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15694', '112', '17571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3596411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17572', '1079', '1', 'Municipio de El Palmar', 'GT.13.3596634', 'ASCII:Municipio de El Palmar;ID:3596634', '15695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15695', '112', '17572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3596634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17573', '1079', '1', 'Municipio de El Jícaro', 'GT.05.3596938', 'ASCII:Municipio de El Jicaro;ID:3596938', '15696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15696', '112', '17573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.05.3596938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17574', '1079', '1', 'Municipio de El Estor', 'GT.09.3597077', 'ASCII:Municipio de El Estor;ID:3597077', '15697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15697', '112', '17574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.09.3597077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17575', '1079', '1', 'Municipio, de El Chol', 'GT.02.3597300', 'ASCII:Municipio, de El Chol;ID:3597300', '15698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15698', '112', '17575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.02.3597300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17576', '1079', '1', 'Municipio de El Asintal', 'GT.15.3597586', 'ASCII:Municipio de El Asintal;ID:3597586', '15699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15699', '112', '17576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.15.3597586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17577', '1079', '1', 'Municipio de El Adelanto', 'GT.11.3597674', 'ASCII:Municipio de El Adelanto;ID:3597674', '15700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15700', '112', '17577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3597674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17578', '1079', '1', 'Municipio de Dolores', 'GT.12.3597716', 'ASCII:Municipio de Dolores;ID:3597716', '15701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15701', '112', '17578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.12.3597716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17579', '1079', '1', 'Municipio de Cuyotenango', 'GT.20.3597749', 'ASCII:Municipio de Cuyotenango;ID:3597749', '15702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15702', '112', '17579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3597749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17580', '1079', '1', 'Municipio de Cunén', 'GT.14.3597771', 'ASCII:Municipio de Cunen;ID:3597771', '15703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15703', '112', '17580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3597771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17581', '1079', '1', 'Municipio de Cuilco', 'GT.08.3597800', 'ASCII:Municipio de Cuilco;ID:3597800', '15704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15704', '112', '17581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3597800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17582', '1079', '1', 'Municipio de Cuilapa', 'GT.18.3597803', 'ASCII:Municipio de Cuilapa;ID:3597803', '15705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15705', '112', '17582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3597803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17583', '1079', '1', 'Municipio de Cubulco', 'GT.02.3597836', 'ASCII:Municipio de Cubulco;ID:3597836', '15706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15706', '112', '17583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.02.3597836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17584', '1079', '1', 'Municipio de Conguaco', 'GT.11.3597965', 'ASCII:Municipio de Conguaco;ID:3597965', '15707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15707', '112', '17584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3597965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17585', '1079', '1', 'Municipio de Concepción Tutuapa', 'GT.17.3597975', 'ASCII:Municipio de Concepcion Tutuapa;ID:3597975', '15708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15708', '112', '17585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3597975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17586', '1079', '1', 'Municipio de Concepción Las Minas', 'GT.04.3597984', 'ASCII:Municipio de Concepcion Las Minas;ID:3597984', '15709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15709', '112', '17586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3597984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17587', '1079', '1', 'Municipio de Concepción Chiquirichapa', 'GT.13.3597992', 'ASCII:Municipio de Concepcion Chiquirichapa;ID:3597992', '15710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15710', '112', '17587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3597992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17588', '1079', '1', 'Municipio de Concepción', 'GT.08.3598001', 'ASCII:Municipio de Concepcion;ID:3598001', '15711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15711', '112', '17588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3598001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17589', '1079', '1', 'Municipio de Concepción', 'GT.19.3598002', 'ASCII:Municipio de Concepcion;ID:3598002', '15712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15712', '112', '17589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.19.3598002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17590', '1079', '1', 'Municipio de Comitancillo', 'GT.17.3598023', 'ASCII:Municipio de Comitancillo;ID:3598023', '15713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15713', '112', '17590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3598023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17591', '1079', '1', 'Municipio de Comapa', 'GT.11.3598030', 'ASCII:Municipio de Comapa;ID:3598030', '15714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15714', '112', '17591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3598030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17592', '1079', '1', 'Municipio de Comalapa', 'GT.03.3598032', 'ASCII:Municipio de Comalapa;ID:3598032', '15715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15715', '112', '17592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3598032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17593', '1079', '1', 'Municipio de Colotenango', 'GT.08.3598040', 'ASCII:Municipio de Colotenango;ID:3598040', '15716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15716', '112', '17593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3598040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17594', '1079', '1', 'Municipio de Colomba', 'GT.13.3598072', 'ASCII:Municipio de Colomba;ID:3598072', '15717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15717', '112', '17594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3598072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17595', '1079', '1', 'Municipio de Cobán', 'GT.01.3598116', 'ASCII:Municipio de Coban;ID:3598116', '15718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15718', '112', '17595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3598116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17596', '1079', '1', 'Municipio de Coatepeque', 'GT.13.3598121', 'ASCII:Municipio de Coatepeque;ID:3598121', '15719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15719', '112', '17596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3598121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17597', '1079', '1', 'Municipio de Ciudad Vieja', 'GT.16.3598127', 'ASCII:Municipio de Ciudad Vieja;ID:3598127', '15720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15720', '112', '17597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3598127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17598', '1079', '1', 'Municipio de Chuarrancho', 'GT.07.3598276', 'ASCII:Municipio de Chuarrancho;ID:3598276', '15721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15721', '112', '17598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3598276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17599', '1079', '1', 'Municipio de Chisec', 'GT.01.3598414', 'ASCII:Municipio de Chisec;ID:3598414', '15722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15722', '112', '17599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3598414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17600', '1079', '1', 'Municipio de Chiquimulilla', 'GT.18.3598459', 'ASCII:Municipio de Chiquimulilla;ID:3598459', '15723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15723', '112', '17600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3598459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17601', '1079', '1', 'Municipio de Chiquimula', 'GT.04.3598463', 'ASCII:Municipio de Chiquimula;ID:3598463', '15724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15724', '112', '17601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3598463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17602', '1079', '1', 'Municipio de Chinique', 'GT.14.3598512', 'ASCII:Municipio de Chinique;ID:3598512', '15725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15725', '112', '17602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3598512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17603', '1079', '1', 'Municipio de Chinautla', 'GT.07.3598528', 'ASCII:Municipio de Chinautla;ID:3598528', '15726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15726', '112', '17603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3598528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17604', '1079', '1', 'Municipio de Chimaltenango', 'GT.03.3598570', 'ASCII:Municipio de Chimaltenango;ID:3598570', '15727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15727', '112', '17604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3598570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17605', '1079', '1', 'Municipio de Chichicastenango', 'GT.14.3598654', 'ASCII:Municipio de Chichicastenango;ID:3598654', '15728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15728', '112', '17605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3598654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17606', '1079', '1', 'Municipio de Chiché', 'GT.14.3598658', 'ASCII:Municipio de Chiche;ID:3598658', '15729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15729', '112', '17606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3598658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17607', '1079', '1', 'Municipio de Chicacao', 'GT.20.3598677', 'ASCII:Municipio de Chicacao;ID:3598677', '15730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15730', '112', '17607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.20.3598677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17608', '1079', '1', 'Municipio de Chiantla', 'GT.08.3598691', 'ASCII:Municipio de Chiantla;ID:3598691', '15731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15731', '112', '17608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3598691» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17609', '1079', '1', 'Municipio de Champerico', 'GT.15.3598786', 'ASCII:Municipio de Champerico;ID:3598786', '15732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15732', '112', '17609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.15.3598786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17610', '1079', '1', 'Municipio de Chajul', 'GT.14.3598803', 'ASCII:Municipio de Chajul;ID:3598803', '15733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15733', '112', '17610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3598803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17611', '1079', '1', 'Municipio de Chahal', 'GT.01.3598824', 'ASCII:Municipio de Chahal;ID:3598824', '15734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15734', '112', '17611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3598824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17612', '1079', '1', 'Municipio de Catarina', 'GT.17.3598956', 'ASCII:Municipio de Catarina;ID:3598956', '15735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15735', '112', '17612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3598956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17613', '1079', '1', 'Municipio de Casillas', 'GT.18.3598967', 'ASCII:Municipio de Casillas;ID:3598967', '15736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15736', '112', '17613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3598967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17614', '1079', '1', 'Municipio de Cantel', 'GT.13.3599066', 'ASCII:Municipio de Cantel;ID:3599066', '15737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15737', '112', '17614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3599066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17615', '1079', '1', 'Municipio de Canillá', 'GT.14.3599093', 'ASCII:Municipio de Canilla;ID:3599093', '15738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15738', '112', '17615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.14.3599093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17616', '1079', '1', 'Municipio de Camotán', 'GT.04.3599180', 'ASCII:Municipio de Camotan;ID:3599180', '15739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15739', '112', '17616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.04.3599180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17617', '1079', '1', 'Municipio de Cajolá', 'GT.13.3599252', 'ASCII:Municipio de Cajola;ID:3599252', '15740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15740', '112', '17617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3599252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17618', '1079', '1', 'Municipio de Cahabón', 'GT.01.3599264', 'ASCII:Municipio de Cahabon;ID:3599264', '15741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15741', '112', '17618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.01.3599264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17619', '1079', '1', 'Municipio de Cabricán', 'GT.13.3599286', 'ASCII:Municipio de Cabrican;ID:3599286', '15742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15742', '112', '17619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3599286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17620', '1079', '1', 'Municipio de Cabañas', 'GT.22.3599294', 'ASCII:Municipio de Cabanas;ID:3599294', '15743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15743', '112', '17620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.22.3599294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17621', '1079', '1', 'Municipio de Barillas', 'GT.08.3599574', 'ASCII:Municipio de Barillas;ID:3599574', '15744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15744', '112', '17621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3599574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17622', '1079', '1', 'Municipio de Barberena', 'GT.18.3599580', 'ASCII:Municipio de Barberena;ID:3599580', '15745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15745', '112', '17622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.18.3599580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17623', '1079', '1', 'Municipio de Ayutla', 'GT.17.3599614', 'ASCII:Municipio de Ayutla;ID:3599614', '15746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15746', '112', '17623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.17.3599614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17624', '1079', '1', 'Municipio de Atescatempa', 'GT.11.3599631', 'ASCII:Municipio de Atescatempa;ID:3599631', '15747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15747', '112', '17624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3599631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17625', '1079', '1', 'Municipio de Asunción Mita', 'GT.11.3599638', 'ASCII:Municipio de Asuncion Mita;ID:3599638', '15748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15748', '112', '17625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3599638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17626', '1079', '1', 'Municipio de Antigua Guatemala', 'GT.16.3599698', 'ASCII:Municipio de Antigua Guatemala;ID:3599698', '15749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15749', '112', '17626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3599698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17627', '1079', '1', 'Municipio de Amatitlán', 'GT.07.3599732', 'ASCII:Municipio de Amatitlan;ID:3599732', '15750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15750', '112', '17627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.07.3599732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17628', '1079', '1', 'Municipio de Alotenango', 'GT.16.3599786', 'ASCII:Municipio de Alotenango;ID:3599786', '15751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15751', '112', '17628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.16.3599786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17629', '1079', '1', 'Municipio de Almolonga', 'GT.13.3599791', 'ASCII:Municipio de Almolonga;ID:3599791', '15752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15752', '112', '17629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.13.3599791» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17630', '1079', '1', 'Municipio de Aguacatán', 'GT.08.3599911', 'ASCII:Municipio de Aguacatan;ID:3599911', '15753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15753', '112', '17630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.08.3599911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17631', '1079', '1', 'Municipio de Agua Blanca', 'GT.11.3599963', 'ASCII:Municipio de Agua Blanca;ID:3599963', '15754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15754', '112', '17631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.11.3599963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17632', '1079', '1', 'Municipio de Acatenango', 'GT.03.3600007', 'ASCII:Municipio de Acatenango;ID:3600007', '15755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15755', '112', '17632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «GT.03.3600007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17633', '1079', '1', 'Yuscarán', 'HN.07.3600166', 'ASCII:Yuscaran;ID:3600166', '15756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15756', '112', '17633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3600166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17634', '1079', '1', 'Yoro', 'HN.18.3600197', 'ASCII:Yoro;ID:3600197', '15757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15757', '112', '17634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3600197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17635', '1079', '1', 'Yorito', 'HN.18.3600200', 'ASCII:Yorito;ID:3600200', '15758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15758', '112', '17635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3600200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17636', '1079', '1', 'Yocón', 'HN.15.3600213', 'ASCII:Yocon;ID:3600213', '15759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15759', '112', '17636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3600213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17637', '1079', '1', 'Yauyupe', 'HN.07.3600223', 'ASCII:Yauyupe;ID:3600223', '15760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15760', '112', '17637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3600223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17638', '1079', '1', 'Yarula', 'HN.12.3600234', 'ASCII:Yarula;ID:3600234', '15761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15761', '112', '17638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3600234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17639', '1079', '1', 'Yamaranguila', 'HN.10.3600255', 'ASCII:Yamaranguila;ID:3600255', '15762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15762', '112', '17639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3600255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17640', '1079', '1', 'Virginia', 'HN.13.3600316', 'ASCII:Virginia;ID:3600316', '15763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15763', '112', '17640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3600316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17641', '1079', '1', 'Villanueva', 'HN.06.3600329', 'ASCII:Villanueva;ID:3600329', '15764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15764', '112', '17641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.06.3600329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17642', '1079', '1', 'Villa de San Francisco', 'HN.08.3600339', 'ASCII:Villa de San Francisco;ID:3600339', '15765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15765', '112', '17642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3600339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17643', '1079', '1', 'Villa de San Antonio', 'HN.04.3600341', 'ASCII:Villa de San Antonio;ID:3600341', '15766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15766', '112', '17643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3600341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17644', '1079', '1', 'Victoria', 'HN.18.3600360', 'ASCII:Victoria;ID:3600360', '15767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15767', '112', '17644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3600360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17645', '1079', '1', 'Veracruz', 'HN.05.3600387', 'ASCII:Veracruz;ID:3600387', '15768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15768', '112', '17645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3600387» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17646', '1079', '1', 'Valle de Ángeles', 'HN.08.3600424', 'ASCII:Valle de Angeles;ID:3600424', '15769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15769', '112', '17646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3600424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17647', '1079', '1', 'Valladolid', 'HN.13.3600459', 'ASCII:Valladolid;ID:3600459', '15770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15770', '112', '17647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3600459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17648', '1079', '1', 'Vado Ancho', 'HN.07.3600470', 'ASCII:Vado Ancho;ID:3600470', '15771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15771', '112', '17648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3600470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17649', '1079', '1', 'Utila', 'HN.11.3600485', 'ASCII:Utila;ID:3600485', '15772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15772', '112', '17649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.11.3600485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17650', '1079', '1', 'Trujillo', 'HN.03.3600592', 'ASCII:Trujillo;ID:3600592', '15773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15773', '112', '17650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.03.3600592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17651', '1079', '1', 'Trinidad de Copán', 'HN.05.3600606', 'ASCII:Trinidad de Copan;ID:3600606', '15774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15774', '112', '17651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3600606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17652', '1079', '1', 'Trinidad', 'HN.16.3600610', 'ASCII:Trinidad;ID:3600610', '15775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15775', '112', '17652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3600610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17653', '1079', '1', 'Tomalá', 'HN.13.3600687', 'ASCII:Tomala;ID:3600687', '15776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15776', '112', '17653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3600687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17654', '1079', '1', 'Tocoa', 'HN.03.3600705', 'ASCII:Tocoa;ID:3600705', '15777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15777', '112', '17654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.03.3600705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17655', '1079', '1', 'Texíguat', 'HN.07.3600839', 'ASCII:Texiguat;ID:3600839', '15778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15778', '112', '17655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3600839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17656', '1079', '1', 'Teupasenti', 'HN.07.3600842', 'ASCII:Teupasenti;ID:3600842', '15779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15779', '112', '17656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3600842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17657', '1079', '1', 'Tela', 'HN.01.3600932', 'ASCII:Tela;ID:3600932', '15780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15780', '112', '17657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.01.3600932» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17658', '1079', '1', 'Tatumbla', 'HN.08.3600972', 'ASCII:Tatumbla;ID:3600972', '15781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15781', '112', '17658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3600972» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17659', '1079', '1', 'Tambla', 'HN.13.3601031', 'ASCII:Tambla;ID:3601031', '15782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15782', '112', '17659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3601031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17660', '1079', '1', 'Talgua', 'HN.13.3601064', 'ASCII:Talgua;ID:3601064', '15783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15783', '112', '17660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3601064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17661', '1079', '1', 'Talanga', 'HN.08.3601073', 'ASCII:Talanga;ID:3601073', '15784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15784', '112', '17661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3601073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17662', '1079', '1', 'Sulaco', 'HN.18.3601160', 'ASCII:Sulaco;ID:3601160', '15785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15785', '112', '17662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3601160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17663', '1079', '1', 'Sonaguera', 'HN.03.3601212', 'ASCII:Sonaguera;ID:3601212', '15786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15786', '112', '17663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.03.3601212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17664', '1079', '1', 'Soledad', 'HN.07.3601239', 'ASCII:Soledad;ID:3601239', '15787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15787', '112', '17664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3601239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17665', '1079', '1', 'Sinuapa', 'HN.14.3601283', 'ASCII:Sinuapa;ID:3601283', '15788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15788', '112', '17665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3601283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17666', '1079', '1', 'Silca', 'HN.15.3601303', 'ASCII:Silca;ID:3601303', '15789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15789', '112', '17666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3601303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17667', '1079', '1', 'Siguatepeque', 'HN.04.3601312', 'ASCII:Siguatepeque;ID:3601312', '15790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15790', '112', '17667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3601312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17668', '1079', '1', 'Sensenti', 'HN.14.3601368', 'ASCII:Sensenti;ID:3601368', '15791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15791', '112', '17668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3601368» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17669', '1079', '1', 'Savá', 'HN.03.3601404', 'ASCII:Sava;ID:3601404', '15792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15792', '112', '17669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.03.3601404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17670', '1079', '1', 'San Vicente Centenario', 'HN.16.3601437', 'ASCII:San Vicente Centenario;ID:3601437', '15793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15793', '112', '17670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3601437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17671', '1079', '1', 'Santiago Puringla', 'HN.12.3601463', 'ASCII:Santiago Puringla;ID:3601463', '15794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15794', '112', '17671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3601463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17672', '1079', '1', 'Santa Rosa de Copán', 'HN.05.3601495', 'ASCII:Santa Rosa de Copan;ID:3601495', '15795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15795', '112', '17672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3601495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17673', '1079', '1', 'Santa Rosa de Aguán', 'HN.03.3601497', 'ASCII:Santa Rosa de Aguan;ID:3601497', '15796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15796', '112', '17673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.03.3601497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17674', '1079', '1', 'Santa Rita', 'HN.18.3601530', 'ASCII:Santa Rita;ID:3601530', '15797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15797', '112', '17674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3601530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17675', '1079', '1', 'Santa Rita', 'HN.05.3601531', 'ASCII:Santa Rita;ID:3601531', '15798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15798', '112', '17675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3601531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17676', '1079', '1', 'Santa Rita', 'HN.16.3601532', 'ASCII:Santa Rita;ID:3601532', '15799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15799', '112', '17676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3601532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17677', '1079', '1', 'Santa María del Real', 'HN.15.3601544', 'ASCII:Santa Maria del Real;ID:3601544', '15800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15800', '112', '17677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3601544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17678', '1079', '1', 'Santa María', 'HN.12.3601557', 'ASCII:Santa Maria;ID:3601557', '15801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15801', '112', '17678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3601557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17679', '1079', '1', 'Santa Lucía', 'HN.08.3601571', 'ASCII:Santa Lucia;ID:3601571', '15802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15802', '112', '17679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3601571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17680', '1079', '1', 'Santa Lucía', 'HN.10.3601572', 'ASCII:Santa Lucia;ID:3601572', '15803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15803', '112', '17680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3601572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17681', '1079', '1', 'Santa Fe', 'HN.03.3601601', 'ASCII:Santa Fe;ID:3601601', '15804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15804', '112', '17681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.03.3601601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17682', '1079', '1', 'Santa Fe', 'HN.14.3601602', 'ASCII:Santa Fe;ID:3601602', '15805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15805', '112', '17682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3601602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17683', '1079', '1', 'Santa Elena', 'HN.12.3601624', 'ASCII:Santa Elena;ID:3601624', '15806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15806', '112', '17683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3601624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17684', '1079', '1', 'Santa Cruz de Yojoa', 'HN.06.3601628', 'ASCII:Santa Cruz de Yojoa;ID:3601628', '15807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15807', '112', '17684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.06.3601628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17685', '1079', '1', 'Santa Cruz', 'HN.13.3601674', 'ASCII:Santa Cruz;ID:3601674', '15808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15808', '112', '17685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3601674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17686', '1079', '1', 'Santa Bárbara', 'HN.16.3601695', 'ASCII:Santa Barbara;ID:3601695', '15809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15809', '112', '17686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3601695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17687', '1079', '1', 'Santa Ana de Yusguare', 'HN.02.3601703', 'ASCII:Santa Ana de Yusguare;ID:3601703', '15810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15810', '112', '17687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3601703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17688', '1079', '1', 'Santa Ana', 'HN.12.3601724', 'ASCII:Santa Ana;ID:3601724', '15811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15811', '112', '17688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3601724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17689', '1079', '1', 'Santa Ana', 'HN.08.3601725', 'ASCII:Santa Ana;ID:3601725', '15812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15812', '112', '17689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3601725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17690', '1079', '1', 'San Sebastián', 'HN.13.3601741', 'ASCII:San Sebastian;ID:3601741', '15813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15813', '112', '17690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3601741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17691', '1079', '1', 'San Sebastián', 'HN.04.3601742', 'ASCII:San Sebastian;ID:3601742', '15814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15814', '112', '17691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3601742» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17692', '1079', '1', 'San Rafael', 'HN.13.3601778', 'ASCII:San Rafael;ID:3601778', '15815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15815', '112', '17692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3601778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17693', '1079', '1', 'San Pedro Zacapa', 'HN.16.3601781', 'ASCII:San Pedro Zacapa;ID:3601781', '15816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15816', '112', '17693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3601781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17694', '1079', '1', 'San Pedro Sula', 'HN.06.3601783', 'ASCII:San Pedro Sula;ID:3601783', '15817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15817', '112', '17694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.06.3601783» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17695', '1079', '1', 'San Pedro de Tutule', 'HN.12.3601785', 'ASCII:San Pedro de Tutule;ID:3601785', '15818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15818', '112', '17695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3601785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17696', '1079', '1', 'San Pedro', 'HN.05.3601815', 'ASCII:San Pedro;ID:3601815', '15819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15819', '112', '17696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3601815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17697', '1079', '1', 'San Nicolás', 'HN.05.3601846', 'ASCII:San Nicolas;ID:3601846', '15820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15820', '112', '17697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3601846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17698', '1079', '1', 'San Nicolás', 'HN.16.3601847', 'ASCII:San Nicolas;ID:3601847', '15821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15821', '112', '17698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3601847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17699', '1079', '1', 'San Miguelito', 'HN.10.3601857', 'ASCII:San Miguelito;ID:3601857', '15822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15822', '112', '17699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3601857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17700', '1079', '1', 'San Miguelito', 'HN.08.3601858', 'ASCII:San Miguelito;ID:3601858', '15823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15823', '112', '17700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3601858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17701', '1079', '1', 'San Matías', 'HN.07.3601876', 'ASCII:San Matias;ID:3601876', '15824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15824', '112', '17701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3601876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17702', '1079', '1', 'San Marcos de Sierra', 'HN.10.3601886', 'ASCII:San Marcos de Sierra;ID:3601886', '15825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15825', '112', '17702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3601886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17703', '1079', '1', 'San Marcos de Colón', 'HN.02.3601889', 'ASCII:San Marcos de Colon;ID:3601889', '15826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15826', '112', '17703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3601889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17704', '1079', '1', 'San Marcos', 'HN.16.3601916', 'ASCII:San Marcos;ID:3601916', '15827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15827', '112', '17704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3601916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17705', '1079', '1', 'San Marcos', 'HN.14.3601917', 'ASCII:San Marcos;ID:3601917', '15828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15828', '112', '17705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3601917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17706', '1079', '1', 'San Manuel de Colohete', 'HN.13.3601920', 'ASCII:San Manuel de Colohete;ID:3601920', '15829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15829', '112', '17706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3601920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17707', '1079', '1', 'San Manuel', 'HN.06.3601923', 'ASCII:San Manuel;ID:3601923', '15830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15830', '112', '17707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.06.3601923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17708', '1079', '1', 'San Luis', 'HN.16.3601942', 'ASCII:San Luis;ID:3601942', '15831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15831', '112', '17708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3601942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17709', '1079', '1', 'San Luis', 'HN.04.3601943', 'ASCII:San Luis;ID:3601943', '15832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15832', '112', '17709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3601943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17710', '1079', '1', 'San Lucas', 'HN.07.3601952', 'ASCII:San Lucas;ID:3601952', '15833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15833', '112', '17710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3601952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17711', '1079', '1', 'San Lorenzo', 'HN.17.3601978', 'ASCII:San Lorenzo;ID:3601978', '15834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15834', '112', '17711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.17.3601978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17712', '1079', '1', 'San Juan Guarita', 'HN.13.3601990', 'ASCII:San Juan Guarita;ID:3601990', '15835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15835', '112', '17712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3601990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17713', '1079', '1', 'San Juan de Opoa', 'HN.05.3601994', 'ASCII:San Juan de Opoa;ID:3601994', '15836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15836', '112', '17713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3601994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17714', '1079', '1', 'San Juan de Flores', 'HN.08.3602000', 'ASCII:San Juan de Flores;ID:3602000', '15837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15837', '112', '17714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3602000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17715', '1079', '1', 'San Juan', 'HN.10.3602062', 'ASCII:San Juan;ID:3602062', '15838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15838', '112', '17715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3602062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17716', '1079', '1', 'San Juan', 'HN.12.3602063', 'ASCII:San Juan;ID:3602063', '15839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15839', '112', '17716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3602063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17717', '1079', '1', 'San José del Potrero', 'HN.04.3602072', 'ASCII:San Jose del Potrero;ID:3602072', '15840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15840', '112', '17717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3602072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17718', '1079', '1', 'San José de Copán', 'HN.05.3602093', 'ASCII:San Jose de Copan;ID:3602093', '15841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15841', '112', '17718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3602093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17719', '1079', '1', 'San José de Comayagua', 'HN.04.3602095', 'ASCII:San Jose de Comayagua;ID:3602095', '15842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15842', '112', '17719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3602095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17720', '1079', '1', 'San José de Colinas', 'HN.16.3602098', 'ASCII:San Jose de Colinas;ID:3602098', '15843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15843', '112', '17720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3602098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17721', '1079', '1', 'San José', 'HN.12.3602160', 'ASCII:San Jose;ID:3602160', '15844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15844', '112', '17721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3602160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17722', '1079', '1', 'San José', 'HN.02.3602161', 'ASCII:San Jose;ID:3602161', '15845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15845', '112', '17722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3602161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17723', '1079', '1', 'San Jorge', 'HN.14.3602165', 'ASCII:San Jorge;ID:3602165', '15846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15846', '112', '17723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3602165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17724', '1079', '1', 'San Jerónimo', 'HN.05.3602207', 'ASCII:San Jeronimo;ID:3602207', '15847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15847', '112', '17724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3602207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17725', '1079', '1', 'San Jerónimo', 'HN.04.3602208', 'ASCII:San Jeronimo;ID:3602208', '15848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15848', '112', '17725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3602208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17726', '1079', '1', 'San Isidro', 'HN.10.3602249', 'ASCII:San Isidro;ID:3602249', '15849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15849', '112', '17726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3602249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17727', '1079', '1', 'San Isidro', 'HN.02.3602250', 'ASCII:San Isidro;ID:3602250', '15850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15850', '112', '17727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3602250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17728', '1079', '1', 'San Ignacio', 'HN.08.3602259', 'ASCII:San Ignacio;ID:3602259', '15851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15851', '112', '17728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3602259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17729', '1079', '1', 'San Francisco de Yojoa', 'HN.06.3602273', 'ASCII:San Francisco de Yojoa;ID:3602273', '15852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15852', '112', '17729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.06.3602273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17730', '1079', '1', 'San Francisco de Ojuera', 'HN.16.3602276', 'ASCII:San Francisco de Ojuera;ID:3602276', '15853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15853', '112', '17730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3602276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17731', '1079', '1', 'San Francisco del Valle', 'HN.14.3602278', 'ASCII:San Francisco del Valle;ID:3602278', '15854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15854', '112', '17731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3602278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17732', '1079', '1', 'San Francisco de la Paz', 'HN.15.3602282', 'ASCII:San Francisco de la Paz;ID:3602282', '15855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15855', '112', '17732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3602282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17733', '1079', '1', 'San Francisco de Coray', 'HN.17.3602285', 'ASCII:San Francisco de Coray;ID:3602285', '15856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15856', '112', '17733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.17.3602285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17734', '1079', '1', 'San Francisco de Becerra', 'HN.15.3602288', 'ASCII:San Francisco de Becerra;ID:3602288', '15857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15857', '112', '17734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3602288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17735', '1079', '1', 'San Francisco', 'HN.01.3602332', 'ASCII:San Francisco;ID:3602332', '15858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15858', '112', '17735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.01.3602332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17736', '1079', '1', 'San Francisco', 'HN.13.3602333', 'ASCII:San Francisco;ID:3602333', '15859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15859', '112', '17736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3602333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17737', '1079', '1', 'San Fernando', 'HN.14.3602340', 'ASCII:San Fernando;ID:3602340', '15860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15860', '112', '17737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3602340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17738', '1079', '1', 'San Esteban', 'HN.15.3602357', 'ASCII:San Esteban;ID:3602357', '15861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15861', '112', '17738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3602357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17739', '1079', '1', 'San Buenaventura', 'HN.08.3602398', 'ASCII:San Buenaventura;ID:3602398', '15862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15862', '112', '17739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3602398» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17740', '1079', '1', 'San Antonio de Oriente', 'HN.08.3602424', 'ASCII:San Antonio de Oriente;ID:3602424', '15863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15863', '112', '17740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3602424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17741', '1079', '1', 'San Antonio del Norte', 'HN.12.3602429', 'ASCII:San Antonio del Norte;ID:3602429', '15864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15864', '112', '17741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3602429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17742', '1079', '1', 'San Antonio de Flores', 'HN.07.3602441', 'ASCII:San Antonio de Flores;ID:3602441', '15865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15865', '112', '17742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3602441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17743', '1079', '1', 'San Antonio de Flores', 'HN.02.3602442', 'ASCII:San Antonio de Flores;ID:3602442', '15866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15866', '112', '17743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3602442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17744', '1079', '1', 'San Antonio de Cortés', 'HN.06.3602445', 'ASCII:San Antonio de Cortes;ID:3602445', '15867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15867', '112', '17744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.06.3602445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17745', '1079', '1', 'San Antonio', 'HN.05.3602522', 'ASCII:San Antonio;ID:3602522', '15868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15868', '112', '17745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3602522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17746', '1079', '1', 'San Antonio', 'HN.10.3602523', 'ASCII:San Antonio;ID:3602523', '15869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15869', '112', '17746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3602523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17747', '1079', '1', 'San Andrés', 'HN.13.3602538', 'ASCII:San Andres;ID:3602538', '15870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15870', '112', '17747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3602538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17748', '1079', '1', 'San Agustín', 'HN.05.3602550', 'ASCII:San Agustin;ID:3602550', '15871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15871', '112', '17748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3602550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17749', '1079', '1', 'Salamá', 'HN.15.3602604', 'ASCII:Salama;ID:3602604', '15872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15872', '112', '17749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3602604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17750', '1079', '1', 'Sabanagrande', 'HN.08.3602682', 'ASCII:Sabanagrande;ID:3602682', '15873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15873', '112', '17750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3602682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17751', '1079', '1', 'Roatán', 'HN.11.3602737', 'ASCII:Roatan;ID:3602737', '15874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15874', '112', '17751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.11.3602737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17752', '1079', '1', 'Reitoca', 'HN.08.3602853', 'ASCII:Reitoca;ID:3602853', '15875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15875', '112', '17752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3602853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17753', '1079', '1', 'Quimistán', 'HN.16.3602953', 'ASCII:Quimistan;ID:3602953', '15876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15876', '112', '17753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3602953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17754', '1079', '1', 'Puerto Lempira', 'HN.09.3603158', 'ASCII:Puerto Lempira;ID:3603158', '15877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15877', '112', '17754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.09.3603158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17755', '1079', '1', 'Protección', 'HN.16.3603258', 'ASCII:Proteccion;ID:3603258', '15878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15878', '112', '17755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3603258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17756', '1079', '1', 'Potrerillos', 'HN.06.3603366', 'ASCII:Potrerillos;ID:3603366', '15879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15879', '112', '17756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.06.3603366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17757', '1079', '1', 'Potrerillos', 'HN.07.3603367', 'ASCII:Potrerillos;ID:3603367', '15880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15880', '112', '17757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3603367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17758', '1079', '1', 'Piraera', 'HN.13.3603605', 'ASCII:Piraera;ID:3603605', '15881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15881', '112', '17758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3603605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17759', '1079', '1', 'Pimienta', 'HN.06.3603657', 'ASCII:Pimienta;ID:3603657', '15882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15882', '112', '17759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.06.3603657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17760', '1079', '1', 'Petoa', 'HN.16.3603800', 'ASCII:Petoa;ID:3603800', '15883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15883', '112', '17760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3603800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17761', '1079', '1', 'Pespire', 'HN.02.3603806', 'ASCII:Pespire;ID:3603806', '15884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15884', '112', '17761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3603806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17762', '1079', '1', 'Oropolí', 'HN.07.3604182', 'ASCII:Oropoli;ID:3604182', '15885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15885', '112', '17762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3604182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17763', '1079', '1', 'Orocuina', 'HN.02.3604190', 'ASCII:Orocuina;ID:3604190', '15886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15886', '112', '17763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3604190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17764', '1079', '1', 'Orica', 'HN.08.3604204', 'ASCII:Orica;ID:3604204', '15887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15887', '112', '17764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3604204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17765', '1079', '1', 'Opatoro', 'HN.12.3604214', 'ASCII:Opatoro;ID:3604214', '15888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15888', '112', '17765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3604214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17766', '1079', '1', 'Omoa', 'HN.06.3604231', 'ASCII:Omoa;ID:3604231', '15889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15889', '112', '17766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.06.3604231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17767', '1079', '1', 'Olanchito', 'HN.18.3604253', 'ASCII:Olanchito;ID:3604253', '15890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15890', '112', '17767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3604253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17768', '1079', '1', 'Ojos de Agua', 'HN.04.3604269', 'ASCII:Ojos de Agua;ID:3604269', '15891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15891', '112', '17768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3604269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17769', '1079', '1', 'Ojojona', 'HN.08.3604271', 'ASCII:Ojojona;ID:3604271', '15892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15892', '112', '17769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3604271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17770', '1079', '1', 'Nuevo Celilac', 'HN.16.3604377', 'ASCII:Nuevo Celilac;ID:3604377', '15893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15893', '112', '17770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3604377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17771', '1079', '1', 'Nueva Ocotepeque', 'HN.14.3604385', 'ASCII:Nueva Ocotepeque;ID:3604385', '15894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15894', '112', '17771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3604385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17772', '1079', '1', 'Nueva Armenia', 'HN.08.3604398', 'ASCII:Nueva Armenia;ID:3604398', '15895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15895', '112', '17772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3604398» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17773', '1079', '1', 'Nueva Arcadia', 'HN.05.3604400', 'ASCII:Nueva Arcadia;ID:3604400', '15896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15896', '112', '17773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3604400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17774', '1079', '1', 'Naranjito', 'HN.16.3604480', 'ASCII:Naranjito;ID:3604480', '15897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15897', '112', '17774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3604480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17775', '1079', '1', 'Namasigüe', 'HN.02.3604504', 'ASCII:Namasigue;ID:3604504', '15898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15898', '112', '17775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3604504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17776', '1079', '1', 'Nacaome', 'HN.17.3604523', 'ASCII:Nacaome;ID:3604523', '15899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15899', '112', '17776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.17.3604523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17777', '1079', '1', 'Morolica', 'HN.02.3604577', 'ASCII:Morolica;ID:3604577', '15900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15900', '112', '17777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3604577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17778', '1079', '1', 'Morocelí', 'HN.07.3604580', 'ASCII:Moroceli;ID:3604580', '15901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15901', '112', '17778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3604580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17779', '1079', '1', 'Morazán', 'HN.18.3604586', 'ASCII:Morazan;ID:3604586', '15902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15902', '112', '17779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3604586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17780', '1079', '1', 'Minas de Oro', 'HN.04.3604796', 'ASCII:Minas de Oro;ID:3604796', '15903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15903', '112', '17780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3604796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17781', '1079', '1', 'Mercedes de Oriente', 'HN.12.3604853', 'ASCII:Mercedes de Oriente;ID:3604853', '15904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15904', '112', '17781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3604853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17782', '1079', '1', 'Mercedes', 'HN.14.3604857', 'ASCII:Mercedes;ID:3604857', '15905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15905', '112', '17782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3604857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17783', '1079', '1', 'Meámbar', 'HN.04.3604895', 'ASCII:Meambar;ID:3604895', '15906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15906', '112', '17783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3604895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17784', '1079', '1', 'Masaguara', 'HN.10.3604977', 'ASCII:Masaguara;ID:3604977', '15907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15907', '112', '17784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3604977» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17785', '1079', '1', 'Marcovia', 'HN.02.3605001', 'ASCII:Marcovia;ID:3605001', '15908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15908', '112', '17785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3605001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17786', '1079', '1', 'Marcala', 'HN.12.3605006', 'ASCII:Marcala;ID:3605006', '15909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15909', '112', '17786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3605006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17787', '1079', '1', 'Marale', 'HN.08.3605019', 'ASCII:Marale;ID:3605019', '15910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15910', '112', '17787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3605019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17788', '1079', '1', 'Maraita', 'HN.08.3605022', 'ASCII:Maraita;ID:3605022', '15911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15911', '112', '17788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3605022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17789', '1079', '1', 'Mapulaca', 'HN.13.3605032', 'ASCII:Mapulaca;ID:3605032', '15912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15912', '112', '17789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3605032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17790', '1079', '1', 'Manto', 'HN.15.3605043', 'ASCII:Manto;ID:3605043', '15913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15913', '112', '17790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3605043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17791', '1079', '1', 'Mangulile', 'HN.15.3605054', 'ASCII:Mangulile;ID:3605054', '15914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15914', '112', '17791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3605054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17792', '1079', '1', 'Magdalena', 'HN.10.3605180', 'ASCII:Magdalena;ID:3605180', '15915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15915', '112', '17792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3605180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17793', '1079', '1', 'Macuelizo', 'HN.16.3605192', 'ASCII:Macuelizo;ID:3605192', '15916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15916', '112', '17793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3605192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17794', '1079', '1', 'Lucerna', 'HN.14.3605223', 'ASCII:Lucerna;ID:3605223', '15917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15917', '112', '17794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3605223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17795', '1079', '1', 'Liure', 'HN.07.3605951', 'ASCII:Liure;ID:3605951', '15918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15918', '112', '17795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3605951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17796', '1079', '1', 'Limón', 'HN.03.3606014', 'ASCII:Limon;ID:3606014', '15919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15919', '112', '17796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.03.3606014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17797', '1079', '1', 'Lepaterique', 'HN.08.3606036', 'ASCII:Lepaterique;ID:3606036', '15920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15920', '112', '17797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3606036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17798', '1079', '1', 'Lepaera', 'HN.13.3606049', 'ASCII:Lepaera;ID:3606049', '15921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15921', '112', '17798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3606049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17799', '1079', '1', 'Lejamaní', 'HN.04.3606070', 'ASCII:Lejamani;ID:3606070', '15922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15922', '112', '17799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3606070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17800', '1079', '1', 'La Virtud', 'HN.13.3606098', 'ASCII:La Virtud;ID:3606098', '15923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15923', '112', '17800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3606098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17801', '1079', '1', 'La Venta', 'HN.08.3606124', 'ASCII:La Venta;ID:3606124', '15924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15924', '112', '17801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3606124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17802', '1079', '1', 'Lauterique', 'HN.12.3606156', 'ASCII:Lauterique;ID:3606156', '15925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15925', '112', '17802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3606156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17803', '1079', '1', 'La Unión', 'HN.15.3606177', 'ASCII:La Union;ID:3606177', '15926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15926', '112', '17803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3606177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17804', '1079', '1', 'La Unión', 'HN.13.3606178', 'ASCII:La Union;ID:3606178', '15927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15927', '112', '17804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3606178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17805', '1079', '1', 'La Unión', 'HN.05.3606179', 'ASCII:La Union;ID:3606179', '15928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15928', '112', '17805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3606179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17806', '1079', '1', 'La Trinidad', 'HN.04.3606192', 'ASCII:La Trinidad;ID:3606192', '15929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15929', '112', '17806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3606192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17807', '1079', '1', 'Las Flores', 'HN.13.3606787', 'ASCII:Las Flores;ID:3606787', '15930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15930', '112', '17807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3606787» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17808', '1079', '1', 'La Paz', 'HN.12.3607256', 'ASCII:La Paz;ID:3607256', '15931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15931', '112', '17808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3607256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17809', '1079', '1', 'Langue', 'HN.17.3607295', 'ASCII:Langue;ID:3607295', '15932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15932', '112', '17809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.17.3607295» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17810', '1079', '1', 'La Masica', 'HN.01.3607421', 'ASCII:La Masica;ID:3607421', '15933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15933', '112', '17810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.01.3607421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17811', '1079', '1', 'Lamaní', 'HN.04.3607437', 'ASCII:Lamani;ID:3607437', '15934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15934', '112', '17811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3607437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17812', '1079', '1', 'La Libertad', 'HN.04.3607545', 'ASCII:La Libertad;ID:3607545', '15935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15935', '112', '17812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3607545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17813', '1079', '1', 'La Libertad', 'HN.08.3607546', 'ASCII:La Libertad;ID:3607546', '15936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15936', '112', '17813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3607546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17814', '1079', '1', 'La Labor', 'HN.14.3607645', 'ASCII:La Labor;ID:3607645', '15937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15937', '112', '17814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3607645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17815', '1079', '1', 'La Jigua', 'HN.05.3607680', 'ASCII:La Jigua;ID:3607680', '15938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15938', '112', '17815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3607680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17816', '1079', '1', 'La Iguala', 'HN.13.3607729', 'ASCII:La Iguala;ID:3607729', '15939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15939', '112', '17816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3607729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17817', '1079', '1', 'La Guata', 'HN.15.3607831', 'ASCII:La Guata;ID:3607831', '15940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15940', '112', '17817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3607831» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17818', '1079', '1', 'La Esperanza', 'HN.10.3607973', 'ASCII:La Esperanza;ID:3607973', '15941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15941', '112', '17818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3607973» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17819', '1079', '1', 'La Encarnación', 'HN.14.3607994', 'ASCII:La Encarnacion;ID:3607994', '15942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15942', '112', '17819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3607994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17820', '1079', '1', 'La Ceiba', 'HN.01.3608268', 'ASCII:La Ceiba;ID:3608268', '15943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15943', '112', '17820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.01.3608268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17821', '1079', '1', 'La Campa', 'HN.13.3608337', 'ASCII:La Campa;ID:3608337', '15944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15944', '112', '17821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3608337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17822', '1079', '1', 'Juticalpa', 'HN.15.3608504', 'ASCII:Juticalpa;ID:3608504', '15945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15945', '112', '17822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3608504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17823', '1079', '1', 'Jutiapa', 'HN.01.3608523', 'ASCII:Jutiapa;ID:3608523', '15946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15946', '112', '17823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.01.3608523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17824', '1079', '1', 'José Santos Guardiola', 'HN.11.3608605', 'ASCII:Jose Santos Guardiola;ID:3608605', '15947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15947', '112', '17824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.11.3608605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17825', '1079', '1', 'Jocón', 'HN.18.3608636', 'ASCII:Jocon;ID:3608636', '15948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15948', '112', '17825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3608636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17826', '1079', '1', 'Jesús de Otoro', 'HN.10.3608716', 'ASCII:Jesus de Otoro;ID:3608716', '15949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15949', '112', '17826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3608716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17827', '1079', '1', 'Jano', 'HN.15.3608736', 'ASCII:Jano;ID:3608736', '15950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15950', '112', '17827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3608736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17828', '1079', '1', 'Jacaleapa', 'HN.07.3608799', 'ASCII:Jacaleapa;ID:3608799', '15951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15951', '112', '17828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3608799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17829', '1079', '1', 'Iriona', 'HN.03.3608823', 'ASCII:Iriona;ID:3608823', '15952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15952', '112', '17829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.03.3608823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17830', '1079', '1', 'Intibucá', 'HN.10.3608835', 'ASCII:Intibuca;ID:3608835', '15953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15953', '112', '17830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3608835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17831', '1079', '1', 'Ilama', 'HN.16.3608861', 'ASCII:Ilama;ID:3608861', '15954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15954', '112', '17831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3608861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17832', '1079', '1', 'Humuya', 'HN.04.3608880', 'ASCII:Humuya;ID:3608880', '15955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15955', '112', '17832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3608880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17833', '1079', '1', 'Güinope', 'HN.07.3609113', 'ASCII:Guinope;ID:3609113', '15956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15956', '112', '17833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3609113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17834', '1079', '1', 'Guayape', 'HN.15.3609153', 'ASCII:Guayape;ID:3609153', '15957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15957', '112', '17834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3609153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17835', '1079', '1', 'Guarizama', 'HN.15.3609232', 'ASCII:Guarizama;ID:3609232', '15958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15958', '112', '17835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3609232» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17836', '1079', '1', 'Guarita', 'HN.13.3609234', 'ASCII:Guarita;ID:3609234', '15959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15959', '112', '17836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3609234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17837', '1079', '1', 'Guanaja', 'HN.11.3609294', 'ASCII:Guanaja;ID:3609294', '15960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15960', '112', '17837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.11.3609294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17838', '1079', '1', 'Gualcince', 'HN.13.3609371', 'ASCII:Gualcince;ID:3609371', '15961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15961', '112', '17838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3609371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17839', '1079', '1', 'Gualala', 'HN.16.3609387', 'ASCII:Gualala;ID:3609387', '15962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15962', '112', '17839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3609387» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17840', '1079', '1', 'Gualaco', 'HN.15.3609390', 'ASCII:Gualaco;ID:3609390', '15963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15963', '112', '17840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3609390» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17841', '1079', '1', 'Guajiquiro', 'HN.12.3609396', 'ASCII:Guajiquiro;ID:3609396', '15964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15964', '112', '17841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3609396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17842', '1079', '1', 'Guaimaca', 'HN.08.3609419', 'ASCII:Guaimaca;ID:3609419', '15965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15965', '112', '17842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3609419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17843', '1079', '1', 'Gracias', 'HN.13.3609587', 'ASCII:Gracias;ID:3609587', '15966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15966', '112', '17843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3609587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17844', '1079', '1', 'Goascorán', 'HN.17.3609609', 'ASCII:Goascoran;ID:3609609', '15967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15967', '112', '17844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.17.3609609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17845', '1079', '1', 'Fraternidad', 'HN.14.3609671', 'ASCII:Fraternidad;ID:3609671', '15968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15968', '112', '17845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3609671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17846', '1079', '1', 'Florida', 'HN.05.3609683', 'ASCII:Florida;ID:3609683', '15969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15969', '112', '17846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3609683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17847', '1079', '1', 'Esquipulas del Norte', 'HN.15.3609735', 'ASCII:Esquipulas del Norte;ID:3609735', '15970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15970', '112', '17847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3609735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17848', '1079', '1', 'Esquías', 'HN.04.3609743', 'ASCII:Esquias;ID:3609743', '15971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15971', '112', '17848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3609743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17849', '1079', '1', 'Esparta', 'HN.01.3609754', 'ASCII:Esparta;ID:3609754', '15972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15972', '112', '17849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.01.3609754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17850', '1079', '1', 'Erandique', 'HN.13.3609776', 'ASCII:Erandique;ID:3609776', '15973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15973', '112', '17850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3609776» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17851', '1079', '1', 'El Triunfo', 'HN.02.3610061', 'ASCII:El Triunfo;ID:3610061', '15974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15974', '112', '17851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3610061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17852', '1079', '1', 'El Rosario', 'HN.15.3610388', 'ASCII:El Rosario;ID:3610388', '15975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15975', '112', '17852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3610388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17853', '1079', '1', 'El Rosario', 'HN.04.3610389', 'ASCII:El Rosario;ID:3610389', '15976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15976', '112', '17853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3610389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17854', '1079', '1', 'El Progreso', 'HN.18.3610615', 'ASCII:El Progreso;ID:3610615', '15977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15977', '112', '17854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3610615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17855', '1079', '1', 'El Porvenir', 'HN.01.3610697', 'ASCII:El Porvenir;ID:3610697', '15978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15978', '112', '17855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.01.3610697» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17856', '1079', '1', 'El Porvenir', 'HN.08.3610698', 'ASCII:El Porvenir;ID:3610698', '15979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15979', '112', '17856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3610698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17857', '1079', '1', 'El Paraíso', 'HN.05.3610966', 'ASCII:El Paraiso;ID:3610966', '15980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15980', '112', '17857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3610966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17858', '1079', '1', 'El Paraíso', 'HN.07.3610967', 'ASCII:El Paraiso;ID:3610967', '15981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15981', '112', '17858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3610967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17859', '1079', '1', 'El Níspero', 'HN.16.3611147', 'ASCII:El Nispero;ID:3611147', '15982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15982', '112', '17859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3611147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17860', '1079', '1', 'El Negrito', 'HN.18.3611153', 'ASCII:El Negrito;ID:3611153', '15983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15983', '112', '17860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3611153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17861', '1079', '1', 'El Corpus', 'HN.02.3611988', 'ASCII:El Corpus;ID:3611988', '15984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15984', '112', '17861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3611988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17862', '1079', '1', 'Duyure', 'HN.02.3612802', 'ASCII:Duyure;ID:3612802', '15985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15985', '112', '17862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3612802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17863', '1079', '1', 'Dulce Nombre de Culmí', 'HN.15.3612811', 'ASCII:Dulce Nombre de Culmi;ID:3612811', '15986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15986', '112', '17863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3612811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17864', '1079', '1', 'Dulce Nombre', 'HN.05.3612816', 'ASCII:Dulce Nombre;ID:3612816', '15987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15987', '112', '17864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3612816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17865', '1079', '1', 'Dolores Merendón', 'HN.14.3612833', 'ASCII:Dolores Merendon;ID:3612833', '15988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15988', '112', '17865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3612833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17866', '1079', '1', 'Dolores', 'HN.05.3612844', 'ASCII:Dolores;ID:3612844', '15989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15989', '112', '17866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3612844» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17867', '1079', '1', 'Dolores', 'HN.10.3612845', 'ASCII:Dolores;ID:3612845', '15990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15990', '112', '17867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3612845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17868', '1079', '1', 'Danlí', 'HN.07.3612908', 'ASCII:Danli;ID:3612908', '15991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15991', '112', '17868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3612908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17869', '1079', '1', 'Curarén', 'HN.08.3612967', 'ASCII:Curaren;ID:3612967', '15992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15992', '112', '17869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3612967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17870', '1079', '1', 'Cucuyagua', 'HN.05.3613016', 'ASCII:Cucuyagua;ID:3613016', '15993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15993', '112', '17870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3613016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17871', '1079', '1', 'Corquín', 'HN.05.3613172', 'ASCII:Corquin;ID:3613172', '15994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15994', '112', '17871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3613172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17872', '1079', '1', 'Copán Ruinas', 'HN.05.3613227', 'ASCII:Copan Ruinas;ID:3613227', '15995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15995', '112', '17872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3613227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17873', '1079', '1', 'Concordia', 'HN.15.3613265', 'ASCII:Concordia;ID:3613265', '15996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15996', '112', '17873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3613265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17874', '1079', '1', 'Concepción de María', 'HN.02.3613280', 'ASCII:Concepcion de Maria;ID:3613280', '15997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15997', '112', '17874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3613280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17875', '1079', '1', 'Concepción del Sur', 'HN.16.3613282', 'ASCII:Concepcion del Sur;ID:3613282', '15998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15998', '112', '17875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3613282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17876', '1079', '1', 'Concepción del Norte', 'HN.16.3613284', 'ASCII:Concepcion del Norte;ID:3613284', '15999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('15999', '112', '17876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3613284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17877', '1079', '1', 'Concepción', 'HN.05.3613299', 'ASCII:Concepcion;ID:3613299', '16000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16000', '112', '17877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3613299» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17878', '1079', '1', 'Concepción', 'HN.14.3613300', 'ASCII:Concepcion;ID:3613300', '16001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16001', '112', '17878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3613300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17879', '1079', '1', 'Concepción', 'HN.10.3613301', 'ASCII:Concepcion;ID:3613301', '16002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16002', '112', '17879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3613301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17880', '1079', '1', 'Comayagua', 'HN.04.3613322', 'ASCII:Comayagua;ID:3613322', '16003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16003', '112', '17880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3613322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17881', '1079', '1', 'Colomoncagua', 'HN.10.3613362', 'ASCII:Colomoncagua;ID:3613362', '16004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16004', '112', '17881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3613362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17882', '1079', '1', 'Cololaca', 'HN.13.3613372', 'ASCII:Cololaca;ID:3613372', '16005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16005', '112', '17882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3613372» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17883', '1079', '1', 'Choluteca', 'HN.02.3613529', 'ASCII:Choluteca;ID:3613529', '16006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16006', '112', '17883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3613529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17884', '1079', '1', 'Choloma', 'HN.06.3613536', 'ASCII:Choloma;ID:3613536', '16007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16007', '112', '17884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.06.3613536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17885', '1079', '1', 'Chinda', 'HN.16.3613602', 'ASCII:Chinda;ID:3613602', '16008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16008', '112', '17885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3613602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17886', '1079', '1', 'Chinacla', 'HN.12.3613613', 'ASCII:Chinacla;ID:3613613', '16009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16009', '112', '17886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3613613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17887', '1079', '1', 'Distrito Central', 'HN.08.3613870', 'ASCII:Distrito Central;ID:3613870', '16010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16010', '112', '17887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3613870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17888', '1079', '1', 'Ceguaca', 'HN.16.3613901', 'ASCII:Ceguaca;ID:3613901', '16011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16011', '112', '17888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3613901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17889', '1079', '1', 'Cedros', 'HN.08.3613909', 'ASCII:Cedros;ID:3613909', '16012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16012', '112', '17889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3613909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17890', '1079', '1', 'Catacamas', 'HN.15.3613975', 'ASCII:Catacamas;ID:3613975', '16013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16013', '112', '17890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3613975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17891', '1079', '1', 'Caridad', 'HN.17.3614096', 'ASCII:Caridad;ID:3614096', '16014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16014', '112', '17891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.17.3614096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17892', '1079', '1', 'Cane', 'HN.12.3614219', 'ASCII:Cane;ID:3614219', '16015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16015', '112', '17892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3614219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17893', '1079', '1', 'Candelaria', 'HN.13.3614239', 'ASCII:Candelaria;ID:3614239', '16016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16016', '112', '17893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3614239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17894', '1079', '1', 'Campamento', 'HN.15.3614321', 'ASCII:Campamento;ID:3614321', '16017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16017', '112', '17894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.15.3614321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17895', '1079', '1', 'Camasca', 'HN.10.3614329', 'ASCII:Camasca;ID:3614329', '16018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16018', '112', '17895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.10.3614329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17896', '1079', '1', 'Cabañas', 'HN.05.3614539', 'ASCII:Cabanas;ID:3614539', '16019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16019', '112', '17896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.05.3614539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17897', '1079', '1', 'Cabañas', 'HN.12.3614540', 'ASCII:Cabanas;ID:3614540', '16020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16020', '112', '17897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3614540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17898', '1079', '1', 'Brus Laguna', 'HN.09.3614664', 'ASCII:Brus Laguna;ID:3614664', '16021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16021', '112', '17898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.09.3614664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17899', '1079', '1', 'Belén Gualcho', 'HN.14.3614798', 'ASCII:Belen Gualcho;ID:3614798', '16022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16022', '112', '17899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.14.3614798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17900', '1079', '1', 'Belén', 'HN.13.3614802', 'ASCII:Belen;ID:3614802', '16023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16023', '112', '17900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.13.3614802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17901', '1079', '1', 'Balfate', 'HN.03.3614905', 'ASCII:Balfate;ID:3614905', '16024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16024', '112', '17901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.03.3614905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17902', '1079', '1', 'Azacualpa', 'HN.16.3614991', 'ASCII:Azacualpa;ID:3614991', '16025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16025', '112', '17902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3614991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17903', '1079', '1', 'Atima', 'HN.16.3615029', 'ASCII:Atima;ID:3615029', '16026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16026', '112', '17903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3615029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17904', '1079', '1', 'Arenal', 'HN.18.3615092', 'ASCII:Arenal;ID:3615092', '16027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16027', '112', '17904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.18.3615092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17905', '1079', '1', 'Aramecina', 'HN.17.3615116', 'ASCII:Aramecina;ID:3615116', '16028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16028', '112', '17905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.17.3615116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17906', '1079', '1', 'Arada', 'HN.16.3615127', 'ASCII:Arada;ID:3615127', '16029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16029', '112', '17906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.16.3615127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17907', '1079', '1', 'Apacilagua', 'HN.02.3615162', 'ASCII:Apacilagua;ID:3615162', '16030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16030', '112', '17907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.02.3615162» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17908', '1079', '1', 'Amapala', 'HN.17.3615214', 'ASCII:Amapala;ID:3615214', '16031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16031', '112', '17908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.17.3615214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17909', '1079', '1', 'Alubarén', 'HN.08.3615227', 'ASCII:Alubaren;ID:3615227', '16032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16032', '112', '17909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.08.3615227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17910', '1079', '1', 'Alianza', 'HN.17.3615252', 'ASCII:Alianza;ID:3615252', '16033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16033', '112', '17910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.17.3615252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17911', '1079', '1', 'Alauca', 'HN.07.3615267', 'ASCII:Alauca;ID:3615267', '16034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16034', '112', '17911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.07.3615267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17912', '1079', '1', 'Ajuterique', 'HN.04.3615280', 'ASCII:Ajuterique;ID:3615280', '16035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16035', '112', '17912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.04.3615280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17913', '1079', '1', 'Aguanqueterique', 'HN.12.3615353', 'ASCII:Aguanqueterique;ID:3615353', '16036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16036', '112', '17913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HN.12.3615353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17914', '1079', '1', 'Zupanja Opština', 'HR.18.3186293', 'ASCII:Zupanja Opstina;ID:3186293', '16037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16037', '112', '17914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.18.3186293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17915', '1079', '1', 'Zlatar-Bistrica Opština', 'HR.07.3186405', 'ASCII:Zlatar-Bistrica Opstina;ID:3186405', '16038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16038', '112', '17915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.07.3186405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17916', '1079', '1', 'Zelina Opština', 'HR.20.3186602', 'ASCII:Zelina Opstina;ID:3186602', '16039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16039', '112', '17916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.20.3186602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17917', '1079', '1', 'Zaprešic Opština', 'HR.20.3186780', 'ASCII:Zapresic Opstina;ID:3186780', '16040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16040', '112', '17917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.20.3186780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17918', '1079', '1', 'Zagreb Opština', 'HR.21.3186885', 'ASCII:Zagreb Opstina;ID:3186885', '16041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16041', '112', '17918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.21.3186885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17919', '1079', '1', 'Zabok Opština', 'HR.07.3186983', 'ASCII:Zabok Opstina;ID:3186983', '16042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16042', '112', '17919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.07.3186983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17920', '1079', '1', 'Vukovar Opština', 'HR.18.3187046', 'ASCII:Vukovar Opstina;ID:3187046', '16043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16043', '112', '17920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.18.3187046» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17921', '1079', '1', 'Vrgorac Opština', 'HR.15.3187229', 'ASCII:Vrgorac Opstina;ID:3187229', '16044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16044', '112', '17921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.15.3187229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17922', '1079', '1', 'Vrginmost Opština', 'HR.14.3187231', 'ASCII:Vrginmost Opstina;ID:3187231', '16045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16045', '112', '17922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.14.3187231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17923', '1079', '1', 'Vrbovsko Opština', 'HR.12.3187256', 'ASCII:Vrbovsko Opstina;ID:3187256', '16046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16046', '112', '17923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.12.3187256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17924', '1079', '1', 'Vrbovec Općina', 'HR.20.3187264', 'ASCII:Vrbovec Opcina;ID:3187264', '16047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16047', '112', '17924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.20.3187264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17925', '1079', '1', 'Vojnic Opština', 'HR.05.3187450', 'ASCII:Vojnic Opstina;ID:3187450', '16048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16048', '112', '17925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.05.3187450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17926', '1079', '1', 'Vis Opština', 'HR.15.3187684', 'ASCII:Vis Opstina;ID:3187684', '16049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16049', '112', '17926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.15.3187684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17927', '1079', '1', 'Virovitica Opština', 'HR.17.3187693', 'ASCII:Virovitica Opstina;ID:3187693', '16050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16050', '112', '17927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.17.3187693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17928', '1079', '1', 'Vinkovci Opština', 'HR.18.3187718', 'ASCII:Vinkovci Opstina;ID:3187718', '16051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16051', '112', '17928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.18.3187718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17929', '1079', '1', 'Velika Gorica Opština', 'HR.20.3188243', 'ASCII:Velika Gorica Opstina;ID:3188243', '16052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16052', '112', '17929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.20.3188243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17930', '1079', '1', 'Varaždin Opština', 'HR.16.3188382', 'ASCII:Varazdin Opstina;ID:3188382', '16053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16053', '112', '17930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.16.3188382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17931', '1079', '1', 'Valpovo Opština', 'HR.10.3188394', 'ASCII:Valpovo Opstina;ID:3188394', '16054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16054', '112', '17931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.10.3188394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17932', '1079', '1', 'Trogir Opština', 'HR.15.3188762', 'ASCII:Trogir Opstina;ID:3188762', '16055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16055', '112', '17932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.15.3188762» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17933', '1079', '1', 'Split Opcina', 'HR.15.3190259', 'ASCII:Split Opcina;ID:3190259', '16056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16056', '112', '17933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.15.3190259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17934', '1079', '1', 'Slunj Opština', 'HR.05.3190522', 'ASCII:Slunj Opstina;ID:3190522', '16057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16057', '112', '17934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.05.3190522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17935', '1079', '1', 'Slavonski Brod Opština', 'HR.02.3190585', 'ASCII:Slavonski Brod Opstina;ID:3190585', '16058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16058', '112', '17935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.02.3190585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17936', '1079', '1', 'Slavonska Požega Opština', 'HR.11.3190588', 'ASCII:Slavonska Pozega Opstina;ID:3190588', '16059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16059', '112', '17936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.11.3190588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17937', '1079', '1', 'Sisak Opština', 'HR.14.3190812', 'ASCII:Sisak Opstina;ID:3190812', '16060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16060', '112', '17937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.14.3190812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17938', '1079', '1', 'Sinj Opština', 'HR.15.3190864', 'ASCII:Sinj Opstina;ID:3190864', '16061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16061', '112', '17938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.15.3190864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17939', '1079', '1', 'Šibenik Opština', 'HR.13.3190938', 'ASCII:Sibenik Opstina;ID:3190938', '16062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16062', '112', '17939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.13.3190938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17940', '1079', '1', 'Sesvete Opština', 'HR.21.3190965', 'ASCII:Sesvete Opstina;ID:3190965', '16063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16063', '112', '17940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.21.3190965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17941', '1079', '1', 'Samobor Opština', 'HR.20.3191315', 'ASCII:Samobor Opstina;ID:3191315', '16064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16064', '112', '17941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.20.3191315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17942', '1079', '1', 'Rovinj Opština', 'HR.04.3191516', 'ASCII:Rovinj Opstina;ID:3191516', '16065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16065', '112', '17942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.04.3191516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17943', '1079', '1', 'Rijeka Opština', 'HR.12.3191647', 'ASCII:Rijeka Opstina;ID:3191647', '16066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16066', '112', '17943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.12.3191647» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17944', '1079', '1', 'Pula Opština', 'HR.04.3192222', 'ASCII:Pula Opstina;ID:3192222', '16067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16067', '112', '17944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.04.3192222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17945', '1079', '1', 'Porec Opština', 'HR.04.3192696', 'ASCII:Porec Opstina;ID:3192696', '16068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16068', '112', '17945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.04.3192696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17946', '1079', '1', 'Podravska Slatina Opština', 'HR.17.3192931', 'ASCII:Podravska Slatina Opstina;ID:3192931', '16069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16069', '112', '17946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.17.3192931» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17947', '1079', '1', 'Ploce Opcina', 'HR.03.3193146', 'ASCII:Ploce Opcina;ID:3193146', '16070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16070', '112', '17947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.03.3193146» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17948', '1079', '1', 'Petrinja Opština', 'HR.14.3193419', 'ASCII:Petrinja Opstina;ID:3193419', '16071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16071', '112', '17948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.14.3193419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17949', '1079', '1', 'Pazin Opština', 'HR.04.3193560', 'ASCII:Pazin Opstina;ID:3193560', '16072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16072', '112', '17949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.04.3193560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17950', '1079', '1', 'Pakrac Opština', 'HR.11.3193705', 'ASCII:Pakrac Opstina;ID:3193705', '16073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16073', '112', '17950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.11.3193705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17951', '1079', '1', 'Ozalj Opština', 'HR.05.3193753', 'ASCII:Ozalj Opstina;ID:3193753', '16074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16074', '112', '17951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.05.3193753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17952', '1079', '1', 'Osijek Općiina', 'HR.10.3193934', 'ASCII:Osijek Opciina;ID:3193934', '16075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16075', '112', '17952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.10.3193934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17953', '1079', '1', 'Orahovica Opština', 'HR.17.3194063', 'ASCII:Orahovica Opstina;ID:3194063', '16076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16076', '112', '17953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.17.3194063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17954', '1079', '1', 'Opatija Opština', 'HR.12.3194097', 'ASCII:Opatija Opstina;ID:3194097', '16077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16077', '112', '17954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.12.3194097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17955', '1079', '1', 'Omiš Opština', 'HR.15.3194113', 'ASCII:Omis Opstina;ID:3194113', '16078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16078', '112', '17955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.15.3194113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17956', '1079', '1', 'Ogulin Opština', 'HR.05.3194182', 'ASCII:Ogulin Opstina;ID:3194182', '16079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16079', '112', '17956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.05.3194182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17957', '1079', '1', 'Novska Opština', 'HR.14.3194318', 'ASCII:Novska Opstina;ID:3194318', '16080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16080', '112', '17957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.14.3194318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17958', '1079', '1', 'Novi Marof Opština', 'HR.16.3194366', 'ASCII:Novi Marof Opstina;ID:3194366', '16081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16081', '112', '17958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.16.3194366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17959', '1079', '1', 'Nova Gradiška Opština', 'HR.02.3194448', 'ASCII:Nova Gradiska Opstina;ID:3194448', '16082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16082', '112', '17959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.02.3194448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17960', '1079', '1', 'Našice Opština', 'HR.10.3194580', 'ASCII:Nasice Opstina;ID:3194580', '16083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16083', '112', '17960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.10.3194580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17961', '1079', '1', 'Makarska Opština', 'HR.15.3195888', 'ASCII:Makarska Opstina;ID:3195888', '16084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16084', '112', '17961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.15.3195888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17962', '1079', '1', 'Ludbreg Opština', 'HR.16.3196119', 'ASCII:Ludbreg Opstina;ID:3196119', '16085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16085', '112', '17962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.16.3196119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17963', '1079', '1', 'Lastovo Opština', 'HR.03.3196753', 'ASCII:Lastovo Opstina;ID:3196753', '16086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16086', '112', '17963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.03.3196753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17964', '1079', '1', 'Labin Opština', 'HR.04.3196833', 'ASCII:Labin Opstina;ID:3196833', '16087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16087', '112', '17964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.04.3196833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17965', '1079', '1', 'Kutina Opština', 'HR.14.3196862', 'ASCII:Kutina Opstina;ID:3196862', '16088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16088', '112', '17965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.14.3196862» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17966', '1079', '1', 'Krk Opština', 'HR.12.3197207', 'ASCII:Krk Opstina;ID:3197207', '16089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16089', '112', '17966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.12.3197207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17967', '1079', '1', 'Križevci Opština', 'HR.06.3197228', 'ASCII:Krizevci Opstina;ID:3197228', '16090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16090', '112', '17967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.06.3197228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17968', '1079', '1', 'Krapina Opština', 'HR.07.3197366', 'ASCII:Krapina Opstina;ID:3197366', '16091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16091', '112', '17968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.07.3197366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17969', '1079', '1', 'Kostajnica Opština', 'HR.14.3197593', 'ASCII:Kostajnica Opstina;ID:3197593', '16092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16092', '112', '17969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.14.3197593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17970', '1079', '1', 'Korcula Opština', 'HR.03.3197709', 'ASCII:Korcula Opstina;ID:3197709', '16093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16093', '112', '17970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.03.3197709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17971', '1079', '1', 'Koprivnica Opština', 'HR.06.3197726', 'ASCII:Koprivnica Opstina;ID:3197726', '16094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16094', '112', '17971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.06.3197726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17972', '1079', '1', 'Klanjec Opština', 'HR.07.3198102', 'ASCII:Klanjec Opstina;ID:3198102', '16095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16095', '112', '17972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.07.3198102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17973', '1079', '1', 'Karlovac Opština', 'HR.05.3198257', 'ASCII:Karlovac Opstina;ID:3198257', '16096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16096', '112', '17973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.05.3198257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17974', '1079', '1', 'Jastrebarsko Opština', 'HR.20.3198798', 'ASCII:Jastrebarsko Opstina;ID:3198798', '16097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16097', '112', '17974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.20.3198798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17975', '1079', '1', 'Ivanic-Grad Opština', 'HR.20.3199068', 'ASCII:Ivanic-Grad Opstina;ID:3199068', '16098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16098', '112', '17975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.20.3199068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17976', '1079', '1', 'Ivanec Opština', 'HR.16.3199075', 'ASCII:Ivanec Opstina;ID:3199075', '16099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16099', '112', '17976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.16.3199075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17977', '1079', '1', 'Imotski Opština', 'HR.15.3199110', 'ASCII:Imotski Opstina;ID:3199110', '16100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16100', '112', '17977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.15.3199110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17978', '1079', '1', 'Hvar Opština', 'HR.15.3199178', 'ASCII:Hvar Opstina;ID:3199178', '16101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16101', '112', '17978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.15.3199178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17979', '1079', '1', 'Grubišno Polje Opština', 'HR.01.3199514', 'ASCII:Grubisno Polje Opstina;ID:3199514', '16102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16102', '112', '17979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.01.3199514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17980', '1079', '1', 'Glina Opština', 'HR.14.3200597', 'ASCII:Glina Opstina;ID:3200597', '16103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16103', '112', '17980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.14.3200597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17981', '1079', '1', 'Garešnica Opština', 'HR.01.3200709', 'ASCII:Garesnica Opstina;ID:3200709', '16104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16104', '112', '17981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.01.3200709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17982', '1079', '1', 'Općina Dvor', 'HR.14.3200915', 'ASCII:Opcina Dvor;ID:3200915', '16105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16105', '112', '17982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.14.3200915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17983', '1079', '1', 'Ðurdevac Opština', 'HR.06.3200960', 'ASCII:Durdevac Opstina;ID:3200960', '16106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16106', '112', '17983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.06.3200960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17984', '1079', '1', 'Dugo Selo Opština', 'HR.20.3201007', 'ASCII:Dugo Selo Opstina;ID:3201007', '16107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16107', '112', '17984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.20.3201007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17985', '1079', '1', 'Duga Resa Opština', 'HR.05.3201029', 'ASCII:Duga Resa Opstina;ID:3201029', '16108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16108', '112', '17985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.05.3201029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17986', '1079', '1', 'Drniš Opština', 'HR.13.3201161', 'ASCII:Drnis Opstina;ID:3201161', '16109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16109', '112', '17986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.13.3201161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17987', '1079', '1', 'Donji Miholjac Opština', 'HR.10.3201431', 'ASCII:Donji Miholjac Opstina;ID:3201431', '16110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16110', '112', '17987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.10.3201431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17988', '1079', '1', 'Donja Stubica Opština', 'HR.07.3201620', 'ASCII:Donja Stubica Opstina;ID:3201620', '16111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16111', '112', '17988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.07.3201620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17989', '1079', '1', 'Općina Delnice', 'HR.12.3202102', 'ASCII:Opcina Delnice;ID:3202102', '16112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16112', '112', '17989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.12.3202102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17990', '1079', '1', 'Daruvar Opština', 'HR.01.3202183', 'ASCII:Daruvar Opstina;ID:3202183', '16113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16113', '112', '17990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.01.3202183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17991', '1079', '1', 'Ðakovo Opština', 'HR.10.3202219', 'ASCII:Dakovo Opstina;ID:3202219', '16114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16114', '112', '17991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.10.3202219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17992', '1079', '1', 'Općina Crikvenica', 'HR.12.3202506', 'ASCII:Opcina Crikvenica;ID:3202506', '16115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16115', '112', '17992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.12.3202506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17993', '1079', '1', 'Cazma Opština', 'HR.01.3202819', 'ASCII:Cazma Opstina;ID:3202819', '16116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16116', '112', '17993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.01.3202819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17994', '1079', '1', 'Cakovec Opština', 'HR.09.3202887', 'ASCII:Cakovec Opstina;ID:3202887', '16117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16117', '112', '17994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.09.3202887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17995', '1079', '1', 'Cabar Opština', 'HR.12.3202931', 'ASCII:Cabar Opstina;ID:3202931', '16118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16118', '112', '17995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.12.3202931» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17996', '1079', '1', 'Buzet Opština', 'HR.04.3202941', 'ASCII:Buzet Opstina;ID:3202941', '16119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16119', '112', '17996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.04.3202941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17997', '1079', '1', 'Buje Opština', 'HR.04.3203088', 'ASCII:Buje Opstina;ID:3203088', '16120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16120', '112', '17997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.04.3203088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17998', '1079', '1', 'Brac Opština', 'HR.15.3203595', 'ASCII:Brac Opstina;ID:3203595', '16121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16121', '112', '17998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.15.3203595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('17999', '1079', '1', 'Bjelovar Opština', 'HR.01.3203981', 'ASCII:Bjelovar Opstina;ID:3203981', '16122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16122', '112', '17999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.01.3203981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18000', '1079', '1', 'Biograd Opština', 'HR.19.3204122', 'ASCII:Biograd Opstina;ID:3204122', '16123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16123', '112', '18000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.19.3204122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18001', '1079', '1', 'Beli Manastir Opština', 'HR.10.3204319', 'ASCII:Beli Manastir Opstina;ID:3204319', '16124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16124', '112', '18001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HR.10.3204319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18002', '1079', '1', 'Arrondissement de Vallières', 'HT.10.3716114', 'ASCII:Arrondissement de Vallieres;ID:3716114', '16125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16125', '112', '18002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.10.3716114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18003', '1079', '1', 'Arrondissement du Trou du Nord', 'HT.10.3716223', 'ASCII:Arrondissement du Trou du Nord;ID:3716223', '16126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16126', '112', '18003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.10.3716223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18004', '1079', '1', 'Arrondissement de Saint-Raphaël', 'HT.09.3717545', 'ASCII:Arrondissement de Saint-Raphael;ID:3717545', '16127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16127', '112', '18004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.09.3717545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18005', '1079', '1', 'Arrondissement de Saint-Michel', 'HT.06.3717563', 'ASCII:Arrondissement de Saint-Michel;ID:3717563', '16128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16128', '112', '18005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.06.3717563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18006', '1079', '1', 'Arrondissement de Saint-Marc', 'HT.06.3717587', 'ASCII:Arrondissement de Saint-Marc;ID:3717587', '16129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16129', '112', '18006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.06.3717587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18007', '1079', '1', 'Arrondissement de Saint-Louis du Nord', 'HT.03.3717599', 'ASCII:Arrondissement de Saint-Louis du Nord;ID:3717599', '16130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16130', '112', '18007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.03.3717599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18008', '1079', '1', 'Arrondissement de Port-Salut', 'HT.12.3718404', 'ASCII:Arrondissement de Port-Salut;ID:3718404', '16131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16131', '112', '18008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.12.3718404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18009', '1079', '1', 'Arrondissement de Port-de-Paix', 'HT.03.3718419', 'ASCII:Arrondissement de Port-de-Paix;ID:3718419', '16132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16132', '112', '18009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.03.3718419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18010', '1079', '1', 'Arrondissement de Port-au-Prince', 'HT.11.3718425', 'ASCII:Arrondissement de Port-au-Prince;ID:3718425', '16133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16133', '112', '18010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.11.3718425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18011', '1079', '1', 'Arrondissement de Plaisance', 'HT.09.3718665', 'ASCII:Arrondissement de Plaisance;ID:3718665', '16134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16134', '112', '18011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.09.3718665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18012', '1079', '1', 'Arrondissement d'' Ouanaminthe', 'HT.10.3719435', 'ASCII:Arrondissement d'' Ouanaminthe;ID:3719435', '16135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16135', '112', '18012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.10.3719435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18013', '1079', '1', 'Arrondissement du Môle Saint-Nicolas', 'HT.03.3720764', 'ASCII:Arrondissement du Mole Saint-Nicolas;ID:3720764', '16136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16136', '112', '18013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.03.3720764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18014', '1079', '1', 'Arrondissement de Mirebalais', 'HT.07.3720809', 'ASCII:Arrondissement de Mirebalais;ID:3720809', '16137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16137', '112', '18014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.07.3720809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18015', '1079', '1', 'Arrondissement de Miragoâne', 'HT.14.3720823', 'ASCII:Arrondissement de Miragoane;ID:3720823', '16138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16138', '112', '18015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.14.3720823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18016', '1079', '1', 'Arrondissement du Limbé', 'HT.09.3722122', 'ASCII:Arrondissement du Limbe;ID:3722122', '16139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16139', '112', '18016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.09.3722122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18017', '1079', '1', 'Arrondissement de Léogâne', 'HT.11.3722285', 'ASCII:Arrondissement de Leogane;ID:3722285', '16140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16140', '112', '18017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.11.3722285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18018', '1079', '1', 'Arrondissement de Lascahobas', 'HT.07.3722578', 'ASCII:Arrondissement de Lascahobas;ID:3722578', '16141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16141', '112', '18018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.07.3722578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18019', '1079', '1', 'Arrondissement de La Gonâve', 'HT.11.3723019', 'ASCII:Arrondissement de La Gonave;ID:3723019', '16142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16142', '112', '18019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.11.3723019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18020', '1079', '1', 'Arrondissement du Jérémie', 'HT.14.3723592', 'ASCII:Arrondissement du Jeremie;ID:3723592', '16143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16143', '112', '18020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.14.3723592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18021', '1079', '1', 'Arrondissement de Jacmel', 'HT.13.3723778', 'ASCII:Arrondissement de Jacmel;ID:3723778', '16144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16144', '112', '18021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.13.3723778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18022', '1079', '1', 'Arrondissement de Hinche', 'HT.07.3723840', 'ASCII:Arrondissement de Hinche;ID:3723840', '16145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16145', '112', '18022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.07.3723840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18023', '1079', '1', 'Arrondissement de Gros Morne', 'HT.06.3724144', 'ASCII:Arrondissement de Gros Morne;ID:3724144', '16146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16146', '112', '18023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.06.3724144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18024', '1079', '1', 'Arrondissement de la Grande Rivière du Nord', 'HT.09.3724438', 'ASCII:Arrondissement de la Grande Riviere du Nord;ID:3724438', '16147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16147', '112', '18024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.09.3724438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18025', '1079', '1', 'Arrondissement des Gonaïves', 'HT.06.3724695', 'ASCII:Arrondissement des Gonaives;ID:3724695', '16148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16148', '112', '18025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.06.3724695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18026', '1079', '1', 'Arrondissement de Fort Liberté', 'HT.10.3725169', 'ASCII:Arrondissement de Fort Liberte;ID:3725169', '16149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16149', '112', '18026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.10.3725169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18027', '1079', '1', 'Arrondissement de Dessalines', 'HT.06.3726539', 'ASCII:Arrondissement de Dessalines;ID:3726539', '16150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16150', '112', '18027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.06.3726539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18028', '1079', '1', 'Arrondissement de Croix des Bouquets', 'HT.11.3727134', 'ASCII:Arrondissement de Croix des Bouquets;ID:3727134', '16151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16151', '112', '18028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.11.3727134» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18029', '1079', '1', 'Arrondissement des Coteaux', 'HT.12.3727295', 'ASCII:Arrondissement des Coteaux;ID:3727295', '16152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16152', '112', '18029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.12.3727295» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18030', '1079', '1', 'Arrondissement de Corail', 'HT.14.3727381', 'ASCII:Arrondissement de Corail;ID:3727381', '16153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16153', '112', '18030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.14.3727381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18031', '1079', '1', 'Arrondissement des Chardonnières', 'HT.12.3727900', 'ASCII:Arrondissement des Chardonnieres;ID:3727900', '16154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16154', '112', '18031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.12.3727900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18032', '1079', '1', 'Arrondissement de Cerca La Source', 'HT.07.3728053', 'ASCII:Arrondissement de Cerca La Source;ID:3728053', '16155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16155', '112', '18032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.07.3728053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18033', '1079', '1', 'Arrondissement des Cayes', 'HT.12.3728096', 'ASCII:Arrondissement des Cayes;ID:3728096', '16156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16156', '112', '18033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.12.3728096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18034', '1079', '1', 'Arrondissement du Cap-Haïtien', 'HT.09.3728473', 'ASCII:Arrondissement du Cap-Haitien;ID:3728473', '16157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16157', '112', '18034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.09.3728473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18035', '1079', '1', 'Arrondissement du Borgne', 'HT.09.3729454', 'ASCII:Arrondissement du Borgne;ID:3729454', '16158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16158', '112', '18035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.09.3729454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18036', '1079', '1', 'Arrondissement de Belle-Anse', 'HT.13.3730361', 'ASCII:Arrondissement de Belle-Anse;ID:3730361', '16159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16159', '112', '18036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.13.3730361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18037', '1079', '1', 'Arrondissement de Bainet', 'HT.13.3730910', 'ASCII:Arrondissement de Bainet;ID:3730910', '16160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16160', '112', '18037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.13.3730910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18038', '1079', '1', 'Arrondissement d'' Arcahaie', 'HT.11.3731086', 'ASCII:Arrondissement d'' Arcahaie;ID:3731086', '16161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16161', '112', '18038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.11.3731086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18039', '1079', '1', 'Arrondissement d'' Aquin', 'HT.12.3731094', 'ASCII:Arrondissement d'' Aquin;ID:3731094', '16162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16162', '112', '18039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.12.3731094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18040', '1079', '1', 'Arrondissement de l'' Anse d''Hainault', 'HT.14.3731116', 'ASCII:Arrondissement de l'' Anse d''Hainault;ID:3731116', '16163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16163', '112', '18040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.14.3731116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18041', '1079', '1', 'Arrondissement de l'' Anse-à-Veau', 'HT.14.3731122', 'ASCII:Arrondissement de l'' Anse-a-Veau;ID:3731122', '16164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16164', '112', '18041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.14.3731122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18042', '1079', '1', 'Arrondissement de l'' Acul du Nord', 'HT.09.3731232', 'ASCII:Arrondissement de l'' Acul du Nord;ID:3731232', '16165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16165', '112', '18042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «HT.09.3731232» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18043', '1079', '1', 'Kota Tebingtinggi', 'ID.26.1213498', 'ASCII:Kota Tebingtinggi;ID:1213498', '16166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16166', '112', '18043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.1213498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18044', '1079', '1', 'Kabupaten Tapanuli Tengah', 'ID.26.1213518', 'ASCII:Kabupaten Tapanuli Tengah;ID:1213518', '16167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16167', '112', '18044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.1213518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18045', '1079', '1', 'Kabupaten Tapanuli Selatan', 'ID.00.1213519', 'ASCII:Kabupaten Tapanuli Selatan;ID:1213519', '16168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16168', '112', '18045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1213519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18046', '1079', '1', 'Kabupaten Simalungun', 'ID.26.1213765', 'ASCII:Kabupaten Simalungun;ID:1213765', '16169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16169', '112', '18046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.1213765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18047', '1079', '1', 'Kota Sibolga', 'ID.26.1213854', 'ASCII:Kota Sibolga;ID:1213854', '16170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16170', '112', '18047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.1213854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18048', '1079', '1', 'Kotamadya Sabang', 'ID.01.1214025', 'ASCII:Kotamadya Sabang;ID:1214025', '16171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16171', '112', '18048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.1214025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18049', '1079', '1', 'Kotamadya Pematangsiantar', 'ID.26.1214203', 'ASCII:Kotamadya Pematangsiantar;ID:1214203', '16172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16172', '112', '18049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.1214203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18050', '1079', '1', 'Kabupaten Nias Selatan', 'ID.26.1214405', 'ASCII:Kabupaten Nias Selatan;ID:1214405', '16173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16173', '112', '18050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.1214405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18051', '1079', '1', 'Kota Medan', 'ID.26.1214519', 'ASCII:Kota Medan;ID:1214519', '16174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16174', '112', '18051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.1214519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18052', '1079', '1', 'Kabupaten Langkat', 'ID.01.1214728', 'ASCII:Kabupaten Langkat;ID:1214728', '16175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16175', '112', '18052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.1214728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18053', '1079', '1', 'Kabupaten Karo', 'ID.26.1214929', 'ASCII:Kabupaten Karo;ID:1214929', '16176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16176', '112', '18053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.1214929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18054', '1079', '1', 'Kabupaten Deli Serdang', 'ID.26.1215200', 'ASCII:Kabupaten Deli Serdang;ID:1215200', '16177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16177', '112', '18054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.1215200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18055', '1079', '1', 'Banda Aceh', 'ID.01.1215501', 'ASCII:Banda Aceh;ID:1215501', '16178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16178', '112', '18055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.1215501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18056', '1079', '1', 'Kabupaten Asahan', 'ID.01.1215554', 'ASCII:Kabupaten Asahan;ID:1215554', '16179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16179', '112', '18056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.1215554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18057', '1079', '1', 'Kabupaten Aceh Utara', 'ID.00.1215630', 'ASCII:Kabupaten Aceh Utara;ID:1215630', '16180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16180', '112', '18057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1215630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18058', '1079', '1', 'Kabupaten Aceh Timur', 'ID.01.1215631', 'ASCII:Kabupaten Aceh Timur;ID:1215631', '16181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16181', '112', '18058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.1215631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18059', '1079', '1', 'Kabupaten Aceh Tenggara', 'ID.01.1215632', 'ASCII:Kabupaten Aceh Tenggara;ID:1215632', '16182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16182', '112', '18059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.1215632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18060', '1079', '1', 'Kabupaten Aceh Tengah', 'ID.00.1215633', 'ASCII:Kabupaten Aceh Tengah;ID:1215633', '16183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16183', '112', '18060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1215633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18061', '1079', '1', 'Kabupaten Aceh Selatan', 'ID.01.1215634', 'ASCII:Kabupaten Aceh Selatan;ID:1215634', '16184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16184', '112', '18061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.1215634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18062', '1079', '1', 'Kabupaten Aceh Besar', 'ID.01.1215635', 'ASCII:Kabupaten Aceh Besar;ID:1215635', '16185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16185', '112', '18062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.1215635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18063', '1079', '1', 'Kabupaten Aceh Barat', 'ID.01.1215636', 'ASCII:Kabupaten Aceh Barat;ID:1215636', '16186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16186', '112', '18063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.1215636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18064', '1079', '1', 'Kotamadya Yogyakarta', 'ID.10.1621175', 'ASCII:Kotamadya Yogyakarta;ID:1621175', '16187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16187', '112', '18064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.10.1621175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18065', '1079', '1', 'Kabupaten Yapen Waropen', 'ID.00.1621238', 'ASCII:Kabupaten Yapen Waropen;ID:1621238', '16188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16188', '112', '18065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1621238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18066', '1079', '1', 'Kabupaten Wonosobo', 'ID.07.1621394', 'ASCII:Kabupaten Wonosobo;ID:1621394', '16189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16189', '112', '18066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1621394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18067', '1079', '1', 'Kabupaten Wonogiri', 'ID.07.1621430', 'ASCII:Kabupaten Wonogiri;ID:1621430', '16190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16190', '112', '18067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1621430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18068', '1079', '1', 'Kabupaten Wajo', 'ID.00.1622267', 'ASCII:Kabupaten Wajo;ID:1622267', '16191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16191', '112', '18068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1622267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18069', '1079', '1', 'Kotamadya Makassar', 'ID.38.1622785', 'ASCII:Kotamadya Makassar;ID:1622785', '16192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16192', '112', '18069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1622785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18070', '1079', '1', 'Kabupaten Tulungagung', 'ID.00.1623079', 'ASCII:Kabupaten Tulungagung;ID:1623079', '16193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16193', '112', '18070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1623079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18071', '1079', '1', 'Kabupaten Tuban', 'ID.00.1623178', 'ASCII:Kabupaten Tuban;ID:1623178', '16194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16194', '112', '18071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1623178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18072', '1079', '1', 'Kabupaten Trenggalek', 'ID.00.1623250', 'ASCII:Kabupaten Trenggalek;ID:1623250', '16195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16195', '112', '18072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1623250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18073', '1079', '1', 'Kabupaten Timor Tengah Utara', 'ID.18.1623839', 'ASCII:Kabupaten Timor Tengah Utara;ID:1623839', '16196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16196', '112', '18073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.18.1623839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18074', '1079', '1', 'Kabupaten Timor Tengah Selatan', 'ID.18.1623840', 'ASCII:Kabupaten Timor Tengah Selatan;ID:1623840', '16197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16197', '112', '18074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.18.1623840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18075', '1079', '1', 'Kabupaten Temanggung', 'ID.07.1624237', 'ASCII:Kabupaten Temanggung;ID:1624237', '16198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16198', '112', '18075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1624237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18076', '1079', '1', 'Kabupaten Teluk Cenderawasih', 'ID.00.1624316', 'ASCII:Kabupaten Teluk Cenderawasih;ID:1624316', '16199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16199', '112', '18076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1624316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18077', '1079', '1', 'Kabupaten Tegal', 'ID.07.1624493', 'ASCII:Kabupaten Tegal;ID:1624493', '16200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16200', '112', '18077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1624493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18078', '1079', '1', 'Kota Administratip Tasikmalaya', 'ID.00.1624645', 'ASCII:Kota Administratip Tasikmalaya;ID:1624645', '16201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16201', '112', '18078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1624645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18079', '1079', '1', 'Kabupaten Tasikmalaya', 'ID.00.1624646', 'ASCII:Kabupaten Tasikmalaya;ID:1624646', '16202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16202', '112', '18079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1624646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18080', '1079', '1', 'Kabupaten Tapin', 'ID.00.1624750', 'ASCII:Kabupaten Tapin;ID:1624750', '16203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16203', '112', '18080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1624750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18081', '1079', '1', 'Kotamadya Tanjungkarang-Telukbetung', 'ID.00.1624916', 'ASCII:Kotamadya Tanjungkarang-Telukbetung;ID:1624916', '16204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16204', '112', '18081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1624916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18082', '1079', '1', 'Kabupaten Tanjung Jabung', 'ID.00.1624924', 'ASCII:Kabupaten Tanjung Jabung;ID:1624924', '16205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16205', '112', '18082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1624924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18083', '1079', '1', 'Kabupaten Tana Toraja', 'ID.00.1625123', 'ASCII:Kabupaten Tana Toraja;ID:1625123', '16206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16206', '112', '18083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1625123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18084', '1079', '1', 'Kabupaten Tanah Laut', 'ID.00.1625166', 'ASCII:Kabupaten Tanah Laut;ID:1625166', '16207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16207', '112', '18084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1625166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18085', '1079', '1', 'Kabupaten Takalar', 'ID.38.1625545', 'ASCII:Kabupaten Takalar;ID:1625545', '16208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16208', '112', '18085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1625545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18086', '1079', '1', 'Kabupaten Tabalong', 'ID.00.1625714', 'ASCII:Kabupaten Tabalong;ID:1625714', '16209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16209', '112', '18086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1625714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18087', '1079', '1', 'Kotamadya Surakarta', 'ID.07.1625811', 'ASCII:Kotamadya Surakarta;ID:1625811', '16210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16210', '112', '18087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1625811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18088', '1079', '1', 'Kotamadya Surabaya', 'ID.08.1625820', 'ASCII:Kotamadya Surabaya;ID:1625820', '16211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16211', '112', '18088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1625820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18089', '1079', '1', 'Kabupaten Surabaya', 'ID.00.1625821', 'ASCII:Kabupaten Surabaya;ID:1625821', '16212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16212', '112', '18089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1625821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18090', '1079', '1', 'Kabupaten Sumedang', 'ID.30.1626102', 'ASCII:Kabupaten Sumedang;ID:1626102', '16213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16213', '112', '18090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1626102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18091', '1079', '1', 'Kabupaten Sumba Timur', 'ID.00.1626190', 'ASCII:Kabupaten Sumba Timur;ID:1626190', '16214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16214', '112', '18091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1626190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18092', '1079', '1', 'Kabupaten Sukoharjo', 'ID.07.1626271', 'ASCII:Kabupaten Sukoharjo;ID:1626271', '16215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16215', '112', '18092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1626271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18093', '1079', '1', 'Kotamadya Sukabumi', 'ID.30.1626379', 'ASCII:Kotamadya Sukabumi;ID:1626379', '16216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16216', '112', '18093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1626379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18094', '1079', '1', 'Kabupaten Sukabumi', 'ID.30.1626380', 'ASCII:Kabupaten Sukabumi;ID:1626380', '16217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16217', '112', '18094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1626380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18095', '1079', '1', 'Kabupaten Subang', 'ID.00.1626440', 'ASCII:Kabupaten Subang;ID:1626440', '16218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16218', '112', '18095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1626440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18096', '1079', '1', 'Kabupaten Sragen', 'ID.07.1626497', 'ASCII:Kabupaten Sragen;ID:1626497', '16219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16219', '112', '18096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1626497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18097', '1079', '1', 'Kabupaten Sorong', 'ID.00.1626541', 'ASCII:Kabupaten Sorong;ID:1626541', '16220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16220', '112', '18097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1626541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18098', '1079', '1', 'Kabupaten Sopeng', 'ID.00.1626581', 'ASCII:Kabupaten Sopeng;ID:1626581', '16221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16221', '112', '18098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1626581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18099', '1079', '1', 'Kabupaten Sinjai', 'ID.38.1626894', 'ASCII:Kabupaten Sinjai;ID:1626894', '16222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16222', '112', '18099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1626894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18100', '1079', '1', 'Kabupaten Sika', 'ID.00.1627182', 'ASCII:Kabupaten Sika;ID:1627182', '16223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16223', '112', '18100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1627182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18101', '1079', '1', 'Kabupaten Sidoarjo', 'ID.08.1627252', 'ASCII:Kabupaten Sidoarjo;ID:1627252', '16224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16224', '112', '18101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1627252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18102', '1079', '1', 'Kabupaten Sidenreng-Rapang', 'ID.00.1627258', 'ASCII:Kabupaten Sidenreng-Rapang;ID:1627258', '16225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16225', '112', '18102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1627258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18103', '1079', '1', 'Kabupaten Seruyan', 'ID.00.1627443', 'ASCII:Kabupaten Seruyan;ID:1627443', '16226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16226', '112', '18103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1627443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18104', '1079', '1', 'Kabupaten Serang', 'ID.33.1627545', 'ASCII:Kabupaten Serang;ID:1627545', '16227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16227', '112', '18104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.33.1627545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18105', '1079', '1', 'Kabupaten Selayar', 'ID.38.1628015', 'ASCII:Kabupaten Selayar;ID:1628015', '16228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16228', '112', '18105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1628015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18106', '1079', '1', 'Kabupaten Sarolangun', 'ID.00.1628580', 'ASCII:Kabupaten Sarolangun;ID:1628580', '16229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16229', '112', '18106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1628580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18107', '1079', '1', 'Kepulauan Sangihe dan Talaud', 'ID.31.1628775', 'ASCII:Kepulauan Sangihe dan Talaud;ID:1628775', '16230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16230', '112', '18107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.31.1628775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18108', '1079', '1', 'Kabupaten Sampang', 'ID.08.1628896', 'ASCII:Kabupaten Sampang;ID:1628896', '16231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16231', '112', '18108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1628896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18109', '1079', '1', 'Kabupaten Rejang Lebong', 'ID.00.1629764', 'ASCII:Kabupaten Rejang Lebong;ID:1629764', '16232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16232', '112', '18109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1629764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18110', '1079', '1', 'Kabupaten Purworejo', 'ID.07.1630324', 'ASCII:Kabupaten Purworejo;ID:1630324', '16233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16233', '112', '18110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1630324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18111', '1079', '1', 'Kabupaten Purwakarta', 'ID.30.1630340', 'ASCII:Kabupaten Purwakarta;ID:1630340', '16234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16234', '112', '18111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1630340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18112', '1079', '1', 'Kabupaten Probolinggo', 'ID.08.1630633', 'ASCII:Kabupaten Probolinggo;ID:1630633', '16235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16235', '112', '18112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1630633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18113', '1079', '1', 'Kabupaten Poso', 'ID.21.1630720', 'ASCII:Kabupaten Poso;ID:1630720', '16236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16236', '112', '18113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.21.1630720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18114', '1079', '1', 'Kabupaten Ponorogo', 'ID.08.1630797', 'ASCII:Kabupaten Ponorogo;ID:1630797', '16237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16237', '112', '18114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1630797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18115', '1079', '1', 'Kabupaten Pesisir Selatan', 'ID.00.1631300', 'ASCII:Kabupaten Pesisir Selatan;ID:1631300', '16238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16238', '112', '18115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1631300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18116', '1079', '1', 'Kabupaten Pemalang', 'ID.07.1631647', 'ASCII:Kabupaten Pemalang;ID:1631647', '16239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16239', '112', '18116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1631647» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18117', '1079', '1', 'Kota Pekanbaru', 'ID.37.1631760', 'ASCII:Kota Pekanbaru;ID:1631760', '16240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16240', '112', '18117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.37.1631760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18118', '1079', '1', 'Kotamadya Pekalongan', 'ID.07.1631763', 'ASCII:Kotamadya Pekalongan;ID:1631763', '16241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16241', '112', '18118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1631763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18119', '1079', '1', 'Kabupaten Pegunungan Jayawijaya', 'ID.00.1631789', 'ASCII:Kabupaten Pegunungan Jayawijaya;ID:1631789', '16242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16242', '112', '18119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1631789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18120', '1079', '1', 'Kotamadya Payakumbuh', 'ID.00.1631904', 'ASCII:Kotamadya Payakumbuh;ID:1631904', '16243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16243', '112', '18120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1631904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18121', '1079', '1', 'Kabupaten Pati', 'ID.07.1631990', 'ASCII:Kabupaten Pati;ID:1631990', '16244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16244', '112', '18121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1631990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18122', '1079', '1', 'Kotamadya Pasuruan', 'ID.08.1632031', 'ASCII:Kotamadya Pasuruan;ID:1632031', '16245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16245', '112', '18122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1632031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18123', '1079', '1', 'Kabupaten Pasuruan', 'ID.08.1632032', 'ASCII:Kabupaten Pasuruan;ID:1632032', '16246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16246', '112', '18123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1632032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18124', '1079', '1', 'Kabupaten Paniai', 'ID.00.1632622', 'ASCII:Kabupaten Paniai;ID:1632622', '16247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16247', '112', '18124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1632622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18125', '1079', '1', 'Kotamadya Pangkalpinang', 'ID.00.1632653', 'ASCII:Kotamadya Pangkalpinang;ID:1632653', '16248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16248', '112', '18125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1632653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18126', '1079', '1', 'Kabupaten Pangkajene dan Kepulauan', 'ID.38.1632723', 'ASCII:Kabupaten Pangkajene dan Kepulauan;ID:1632723', '16249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16249', '112', '18126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1632723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18127', '1079', '1', 'Kabupaten Pandegelang', 'ID.00.1632822', 'ASCII:Kabupaten Pandegelang;ID:1632822', '16250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16250', '112', '18127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1632822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18128', '1079', '1', 'Kabupaten Situbondo', 'ID.08.1632902', 'ASCII:Kabupaten Situbondo;ID:1632902', '16251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16251', '112', '18128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1632902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18129', '1079', '1', 'Kota administratip Palu', 'ID.00.1633033', 'ASCII:Kota administratip Palu;ID:1633033', '16252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16252', '112', '18129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1633033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18130', '1079', '1', 'Kotamadya Palangkaraya', 'ID.00.1633117', 'ASCII:Kotamadya Palangkaraya;ID:1633117', '16253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16253', '112', '18130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1633117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18131', '1079', '1', 'Kotamadya Padangpanjang', 'ID.00.1633374', 'ASCII:Kotamadya Padangpanjang;ID:1633374', '16254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16254', '112', '18131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1633374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18132', '1079', '1', 'Kabupaten Pacitan', 'ID.08.1633438', 'ASCII:Kabupaten Pacitan;ID:1633438', '16255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16255', '112', '18132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1633438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18133', '1079', '1', 'Kabupaten Nganjuk', 'ID.08.1634130', 'ASCII:Kabupaten Nganjuk;ID:1634130', '16256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16256', '112', '18133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1634130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18134', '1079', '1', 'Kabupaten Musi Hulu Rawas', 'ID.00.1634643', 'ASCII:Kabupaten Musi Hulu Rawas;ID:1634643', '16257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16257', '112', '18134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1634643» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18135', '1079', '1', 'Kabupaten Musibanyuasin', 'ID.00.1634644', 'ASCII:Kabupaten Musibanyuasin;ID:1634644', '16258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16258', '112', '18135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1634644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18136', '1079', '1', 'Kabupaten Murung Raya', 'ID.00.1634654', 'ASCII:Kabupaten Murung Raya;ID:1634654', '16259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16259', '112', '18136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1634654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18137', '1079', '1', 'Kabupaten Muaraenim', 'ID.00.1634890', 'ASCII:Kabupaten Muaraenim;ID:1634890', '16260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16260', '112', '18137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1634890» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18138', '1079', '1', 'Kotamadya Mojokerto', 'ID.08.1635109', 'ASCII:Kotamadya Mojokerto;ID:1635109', '16261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16261', '112', '18138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1635109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18139', '1079', '1', 'Kabupaten Mojokerto', 'ID.08.1635110', 'ASCII:Kabupaten Mojokerto;ID:1635110', '16262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16262', '112', '18139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1635110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18140', '1079', '1', 'Kabupaten Merangin', 'ID.00.1635409', 'ASCII:Kabupaten Merangin;ID:1635409', '16263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16263', '112', '18140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1635409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18141', '1079', '1', 'Kota Administratip Mataram', 'ID.00.1635881', 'ASCII:Kota Administratip Mataram;ID:1635881', '16264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16264', '112', '18141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1635881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18142', '1079', '1', 'Kabupaten Maros', 'ID.38.1636028', 'ASCII:Kabupaten Maros;ID:1636028', '16265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16265', '112', '18142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1636028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18143', '1079', '1', 'Kotamadya Manado', 'ID.31.1636543', 'ASCII:Kotamadya Manado;ID:1636543', '16266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16266', '112', '18143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.31.1636543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18144', '1079', '1', 'Kabupaten Mamuju', 'ID.00.1636555', 'ASCII:Kabupaten Mamuju;ID:1636555', '16267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16267', '112', '18144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1636555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18145', '1079', '1', 'Kabupaten Maluku Utara', 'ID.29.1636624', 'ASCII:Kabupaten Maluku Utara;ID:1636624', '16268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16268', '112', '18145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.29.1636624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18146', '1079', '1', 'Kotamadya Malang', 'ID.08.1636712', 'ASCII:Kotamadya Malang;ID:1636712', '16269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16269', '112', '18146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1636712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18147', '1079', '1', 'Kabupaten Malang', 'ID.00.1636713', 'ASCII:Kabupaten Malang;ID:1636713', '16270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16270', '112', '18147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1636713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18148', '1079', '1', 'Kabupaten Majene', 'ID.00.1636805', 'ASCII:Kabupaten Majene;ID:1636805', '16271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16271', '112', '18148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1636805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18149', '1079', '1', 'Kabupaten Majalengka', 'ID.30.1636815', 'ASCII:Kabupaten Majalengka;ID:1636815', '16272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16272', '112', '18149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1636815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18150', '1079', '1', 'Kotamadya Magelang', 'ID.07.1636882', 'ASCII:Kotamadya Magelang;ID:1636882', '16273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16273', '112', '18150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1636882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18151', '1079', '1', 'Kotamadya Madiun', 'ID.08.1636927', 'ASCII:Kotamadya Madiun;ID:1636927', '16274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16274', '112', '18151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1636927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18152', '1079', '1', 'Kabupaten Madiun', 'ID.08.1636929', 'ASCII:Kabupaten Madiun;ID:1636929', '16275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16275', '112', '18152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1636929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18153', '1079', '1', 'Kabupaten Lumajang', 'ID.00.1637089', 'ASCII:Kabupaten Lumajang;ID:1637089', '16276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16276', '112', '18153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1637089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18154', '1079', '1', 'Kabupaten Kuningan', 'ID.30.1639093', 'ASCII:Kabupaten Kuningan;ID:1639093', '16277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16277', '112', '18154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1639093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18155', '1079', '1', 'Kabupaten Kudus', 'ID.07.1639214', 'ASCII:Kabupaten Kudus;ID:1639214', '16278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16278', '112', '18155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1639214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18156', '1079', '1', 'Kabupaten Klungkung', 'ID.00.1639849', 'ASCII:Kabupaten Klungkung;ID:1639849', '16279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16279', '112', '18156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1639849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18157', '1079', '1', 'Kabupaten Klaten', 'ID.07.1639899', 'ASCII:Kabupaten Klaten;ID:1639899', '16280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16280', '112', '18157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1639899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18158', '1079', '1', 'Kabupaten Kerinci', 'ID.00.1640224', 'ASCII:Kabupaten Kerinci;ID:1640224', '16281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16281', '112', '18158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1640224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18159', '1079', '1', 'Kabupaten Kepulauan Riau', 'ID.00.1640272', 'ASCII:Kabupaten Kepulauan Riau;ID:1640272', '16282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16282', '112', '18159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1640272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18160', '1079', '1', 'Kota Administratip Kendari', 'ID.00.1640342', 'ASCII:Kota Administratip Kendari;ID:1640342', '16283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16283', '112', '18160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1640342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18161', '1079', '1', 'Kabupaten Katingan', 'ID.00.1640948', 'ASCII:Kabupaten Katingan;ID:1640948', '16284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16284', '112', '18161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1640948» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18162', '1079', '1', 'Kabupaten Karawang', 'ID.30.1641133', 'ASCII:Kabupaten Karawang;ID:1641133', '16285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16285', '112', '18162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1641133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18163', '1079', '1', 'Kabupaten Jombang', 'ID.08.1642413', 'ASCII:Kabupaten Jombang;ID:1642413', '16286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16286', '112', '18163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1642413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18164', '1079', '1', 'Kabupaten Jepara', 'ID.00.1642545', 'ASCII:Kabupaten Jepara;ID:1642545', '16287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16287', '112', '18164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1642545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18165', '1079', '1', 'Kabupaten Jeneponto', 'ID.38.1642569', 'ASCII:Kabupaten Jeneponto;ID:1642569', '16288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16288', '112', '18165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1642569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18166', '1079', '1', 'Kabupaten Jembrana', 'ID.00.1642584', 'ASCII:Kabupaten Jembrana;ID:1642584', '16289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16289', '112', '18166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1642584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18167', '1079', '1', 'Kota Administratip Jember', 'ID.00.1642586', 'ASCII:Kota Administratip Jember;ID:1642586', '16290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16290', '112', '18167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1642586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18168', '1079', '1', 'Kabupaten Jember', 'ID.00.1642587', 'ASCII:Kabupaten Jember;ID:1642587', '16291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16291', '112', '18168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1642587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18169', '1079', '1', 'Kabupaten Jayapura', 'ID.00.1642655', 'ASCII:Kabupaten Jayapura;ID:1642655', '16292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16292', '112', '18169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1642655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18170', '1079', '1', 'Kotamadya Jambi', 'ID.00.1642857', 'ASCII:Kotamadya Jambi;ID:1642857', '16293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16293', '112', '18170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1642857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18171', '1079', '1', 'Kotamadya Jakarta Utara', 'ID.04.1642903', 'ASCII:Kotamadya Jakarta Utara;ID:1642903', '16294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16294', '112', '18171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.04.1642903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18172', '1079', '1', 'Kotamadya Jakarta Timur', 'ID.04.1642904', 'ASCII:Kotamadya Jakarta Timur;ID:1642904', '16295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16295', '112', '18172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.04.1642904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18173', '1079', '1', 'Kotamadya Jakarta Selatan', 'ID.04.1642905', 'ASCII:Kotamadya Jakarta Selatan;ID:1642905', '16296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16296', '112', '18173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.04.1642905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18174', '1079', '1', 'Kotamadya Jakarta Pusat', 'ID.04.1642908', 'ASCII:Kotamadya Jakarta Pusat;ID:1642908', '16297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16297', '112', '18174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.04.1642908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18175', '1079', '1', 'Kotamadya Jakarta Barat', 'ID.04.1642909', 'ASCII:Kotamadya Jakarta Barat;ID:1642909', '16298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16298', '112', '18175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.04.1642909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18176', '1079', '1', 'Kabupaten Indramayu', 'ID.30.1643077', 'ASCII:Kabupaten Indramayu;ID:1643077', '16299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16299', '112', '18176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1643077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18177', '1079', '1', 'Kabupaten Indragiri Hulu', 'ID.00.1643081', 'ASCII:Kabupaten Indragiri Hulu;ID:1643081', '16300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16300', '112', '18177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1643081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18178', '1079', '1', 'Kabupaten Indragiri Hilir', 'ID.00.1643082', 'ASCII:Kabupaten Indragiri Hilir;ID:1643082', '16301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16301', '112', '18178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1643082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18179', '1079', '1', 'Kabupaten Halmahera Tengah', 'ID.00.1643475', 'ASCII:Kabupaten Halmahera Tengah;ID:1643475', '16302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16302', '112', '18179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1643475» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18180', '1079', '1', 'Kabupaten Gunung Mas', 'ID.00.1643597', 'ASCII:Kabupaten Gunung Mas;ID:1643597', '16303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16303', '112', '18180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1643597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18181', '1079', '1', 'Kabupaten Gunung Kidul', 'ID.00.1643604', 'ASCII:Kabupaten Gunung Kidul;ID:1643604', '16304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16304', '112', '18181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1643604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18182', '1079', '1', 'Kabupaten Grobogan', 'ID.07.1643768', 'ASCII:Kabupaten Grobogan;ID:1643768', '16305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16305', '112', '18182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1643768» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18183', '1079', '1', 'Kabupaten Gowa', 'ID.38.1643807', 'ASCII:Kabupaten Gowa;ID:1643807', '16306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16306', '112', '18183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1643807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18184', '1079', '1', 'Kotamadya Gorontalo', 'ID.00.1643836', 'ASCII:Kotamadya Gorontalo;ID:1643836', '16307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16307', '112', '18184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1643836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18185', '1079', '1', 'Kabupaten Gianyar', 'ID.00.1644098', 'ASCII:Kabupaten Gianyar;ID:1644098', '16308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16308', '112', '18185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1644098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18186', '1079', '1', 'Kabupaten Donggala', 'ID.21.1645322', 'ASCII:Kabupaten Donggala;ID:1645322', '16309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16309', '112', '18186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.21.1645322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18187', '1079', '1', 'Kota Administratip Denpasar', 'ID.00.1645527', 'ASCII:Kota Administratip Denpasar;ID:1645527', '16310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16310', '112', '18187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1645527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18188', '1079', '1', 'Kabupaten Demak', 'ID.07.1645558', 'ASCII:Kabupaten Demak;ID:1645558', '16311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16311', '112', '18188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1645558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18189', '1079', '1', 'Kotamadya Cirebon', 'ID.30.1646168', 'ASCII:Kotamadya Cirebon;ID:1646168', '16312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16312', '112', '18189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1646168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18190', '1079', '1', 'Kabupaten Cirebon', 'ID.30.1646169', 'ASCII:Kabupaten Cirebon;ID:1646169', '16313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16313', '112', '18190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1646169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18191', '1079', '1', 'Kota Administratip Cimahi', 'ID.00.1646446', 'ASCII:Kota Administratip Cimahi;ID:1646446', '16314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16314', '112', '18191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1646446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18192', '1079', '1', 'Kabupaten Buton', 'ID.00.1647498', 'ASCII:Kabupaten Buton;ID:1647498', '16315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16315', '112', '18192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1647498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18193', '1079', '1', 'Kabupaten Buol Tolitoli', 'ID.00.1647571', 'ASCII:Kabupaten Buol Tolitoli;ID:1647571', '16316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16316', '112', '18193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1647571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18194', '1079', '1', 'Kabupaten Bulukumba', 'ID.38.1647738', 'ASCII:Kabupaten Bulukumba;ID:1647738', '16317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16317', '112', '18194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1647738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18195', '1079', '1', 'Kabupaten Brebes', 'ID.07.1648064', 'ASCII:Kabupaten Brebes;ID:1648064', '16318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16318', '112', '18195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1648064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18196', '1079', '1', 'Kabupaten Boyolali', 'ID.00.1648083', 'ASCII:Kabupaten Boyolali;ID:1648083', '16319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16319', '112', '18196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1648083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18197', '1079', '1', 'Kabupaten Bolaangmongondow', 'ID.00.1648339', 'ASCII:Kabupaten Bolaangmongondow;ID:1648339', '16320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16320', '112', '18197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1648339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18198', '1079', '1', 'Kabupaten Bojonegoro', 'ID.08.1648450', 'ASCII:Kabupaten Bojonegoro;ID:1648450', '16321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16321', '112', '18198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1648450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18199', '1079', '1', 'Kodya Bogor', 'ID.30.1648470', 'ASCII:Kodya Bogor;ID:1648470', '16322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16322', '112', '18199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1648470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18200', '1079', '1', 'Kabupaten Bogor', 'ID.30.1648471', 'ASCII:Kabupaten Bogor;ID:1648471', '16323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16323', '112', '18200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1648471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18201', '1079', '1', 'Kotamadya Bitung', 'ID.31.1648633', 'ASCII:Kotamadya Bitung;ID:1648633', '16324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16324', '112', '18201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.31.1648633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18202', '1079', '1', 'Kotamadya Binjai', 'ID.00.1648725', 'ASCII:Kotamadya Binjai;ID:1648725', '16325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16325', '112', '18202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1648725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18203', '1079', '1', 'Daerah Berbahaya', 'ID.00.1649030', 'ASCII:Daerah Berbahaya;ID:1649030', '16326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16326', '112', '18203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1649030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18204', '1079', '1', 'Kabupaten Belu', 'ID.18.1649264', 'ASCII:Kabupaten Belu;ID:1649264', '16327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16327', '112', '18204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.18.1649264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18205', '1079', '1', 'Kabupaten Bekasi', 'ID.30.1649377', 'ASCII:Kabupaten Bekasi;ID:1649377', '16328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16328', '112', '18205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1649377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18206', '1079', '1', 'Kabupaten Batang', 'ID.00.1649879', 'ASCII:Kabupaten Batang;ID:1649879', '16329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16329', '112', '18206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1649879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18207', '1079', '1', 'Kabupaten Barru', 'ID.38.1649975', 'ASCII:Kabupaten Barru;ID:1649975', '16330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16330', '112', '18207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1649975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18208', '1079', '1', 'Kabupaten Barito Utara', 'ID.00.1649989', 'ASCII:Kabupaten Barito Utara;ID:1649989', '16331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16331', '112', '18208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1649989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18209', '1079', '1', 'Kabupaten Barito Timur', 'ID.00.1649990', 'ASCII:Kabupaten Barito Timur;ID:1649990', '16332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16332', '112', '18209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1649990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18210', '1079', '1', 'Kabupaten Barito Selatan', 'ID.00.1649991', 'ASCII:Kabupaten Barito Selatan;ID:1649991', '16333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16333', '112', '18210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1649991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18211', '1079', '1', 'Kabupaten Barito Kuala', 'ID.00.1649992', 'ASCII:Kabupaten Barito Kuala;ID:1649992', '16334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16334', '112', '18211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1649992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18212', '1079', '1', 'Kabupaten Banyuwangi', 'ID.00.1650076', 'ASCII:Kabupaten Banyuwangi;ID:1650076', '16335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16335', '112', '18212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1650076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18213', '1079', '1', 'Kabupaten Banyumas', 'ID.07.1650094', 'ASCII:Kabupaten Banyumas;ID:1650094', '16336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16336', '112', '18213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.1650094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18214', '1079', '1', 'Kabupaten Bantul', 'ID.10.1650117', 'ASCII:Kabupaten Bantul;ID:1650117', '16337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16337', '112', '18214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.10.1650117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18215', '1079', '1', 'Kabupaten Bantaeng', 'ID.38.1650183', 'ASCII:Kabupaten Bantaeng;ID:1650183', '16338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16338', '112', '18215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.38.1650183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18216', '1079', '1', 'Kabupaten Banjarnegara', 'ID.00.1650209', 'ASCII:Kabupaten Banjarnegara;ID:1650209', '16339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16339', '112', '18216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1650209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18217', '1079', '1', 'Kotamadya Banjarmasin', 'ID.00.1650211', 'ASCII:Kotamadya Banjarmasin;ID:1650211', '16340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16340', '112', '18217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1650211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18218', '1079', '1', 'Kota Administratip Banjarbaru', 'ID.00.1650216', 'ASCII:Kota Administratip Banjarbaru;ID:1650216', '16341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16341', '112', '18218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1650216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18219', '1079', '1', 'Kabupaten Banjar', 'ID.00.1650231', 'ASCII:Kabupaten Banjar;ID:1650231', '16342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16342', '112', '18219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1650231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18220', '1079', '1', 'Kabupaten Bangkalan', 'ID.08.1650297', 'ASCII:Kabupaten Bangkalan;ID:1650297', '16343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16343', '112', '18220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.1650297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18221', '1079', '1', 'Kabupaten Bandung', 'ID.30.1650352', 'ASCII:Kabupaten Bandung;ID:1650352', '16344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16344', '112', '18221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.1650352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18222', '1079', '1', 'Kabupaten Badung', 'ID.00.1650818', 'ASCII:Kabupaten Badung;ID:1650818', '16345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16345', '112', '18222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1650818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18223', '1079', '1', 'Kotamadya Ambon', 'ID.00.1651530', 'ASCII:Kotamadya Ambon;ID:1651530', '16346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16346', '112', '18223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.1651530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18224', '1079', '1', 'Kabupaten Alor', 'ID.18.1651608', 'ASCII:Kabupaten Alor;ID:1651608', '16347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16347', '112', '18224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.18.1651608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18225', '1079', '1', 'Kota Administratip Klaten', 'ID.00.2007277', 'ASCII:Kota Administratip Klaten;ID:2007277', '16348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16348', '112', '18225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.00.2007277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18226', '1079', '1', 'Kota Administratip Kupang', 'ID.18.2057084', 'ASCII:Kota Administratip Kupang;ID:2057084', '16349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16349', '112', '18226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.18.2057084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18227', '1079', '1', 'Kabupaten Kupang', 'ID.18.2057086', 'ASCII:Kabupaten Kupang;ID:2057086', '16350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16350', '112', '18227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.18.2057086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18228', '1079', '1', 'Kabupaten Magelang', 'ID.07.6199035', 'ASCII:Kabupaten Magelang;ID:6199035', '16351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16351', '112', '18228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6199035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18229', '1079', '1', 'Kabupaten Semarang', 'ID.07.6257264', 'ASCII:Kabupaten Semarang;ID:6257264', '16352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16352', '112', '18229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6257264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18230', '1079', '1', 'Kotamadya Salatiga', 'ID.07.6257933', 'ASCII:Kotamadya Salatiga;ID:6257933', '16353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16353', '112', '18230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6257933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18231', '1079', '1', 'Kabupaten Sleman', 'ID.07.6258231', 'ASCII:Kabupaten Sleman;ID:6258231', '16354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16354', '112', '18231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6258231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18232', '1079', '1', 'Kabupaten Kulonprogo', 'ID.10.6264410', 'ASCII:Kabupaten Kulonprogo;ID:6264410', '16355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16355', '112', '18232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.10.6264410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18233', '1079', '1', 'Kabupaten Sragen', 'ID.07.6266177', 'ASCII:Kabupaten Sragen;ID:6266177', '16356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16356', '112', '18233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6266177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18234', '1079', '1', 'Kabupaten Kebumen', 'ID.07.6376498', 'ASCII:Kabupaten Kebumen;ID:6376498', '16357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16357', '112', '18234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6376498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18235', '1079', '1', 'Kabupaten Banjarnegara', 'ID.07.6380795', 'ASCII:Kabupaten Banjarnegara;ID:6380795', '16358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16358', '112', '18235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6380795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18236', '1079', '1', 'Kabupaten Cilacap', 'ID.07.6384572', 'ASCII:Kabupaten Cilacap;ID:6384572', '16359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16359', '112', '18236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6384572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18237', '1079', '1', 'Kotip Purwokerto', 'ID.07.6389072', 'ASCII:Kotip Purwokerto;ID:6389072', '16360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16360', '112', '18237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6389072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18238', '1079', '1', 'Kabupaten Purbalingga', 'ID.07.6390578', 'ASCII:Kabupaten Purbalingga;ID:6390578', '16361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16361', '112', '18238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6390578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18239', '1079', '1', 'Kabupaten Wonosobo', 'ID.07.6405140', 'ASCII:Kabupaten Wonosobo;ID:6405140', '16362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16362', '112', '18239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6405140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18240', '1079', '1', 'Kabupaten Magetan', 'ID.08.6409167', 'ASCII:Kabupaten Magetan;ID:6409167', '16363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16363', '112', '18240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.6409167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18241', '1079', '1', 'Kabupaten Ngawi', 'ID.08.6410477', 'ASCII:Kabupaten Ngawi;ID:6410477', '16364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16364', '112', '18241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.6410477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18242', '1079', '1', 'Kabupaten Semarang', 'ID.07.6410701', 'ASCII:Kabupaten Semarang;ID:6410701', '16365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16365', '112', '18242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6410701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18243', '1079', '1', 'Kotamadya Bandung', 'ID.30.6559695', 'ASCII:Kotamadya Bandung;ID:6559695', '16366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16366', '112', '18243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.6559695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18244', '1079', '1', 'Kabupaten Karanganyar', 'ID.07.6560140', 'ASCII:Kabupaten Karanganyar;ID:6560140', '16367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16367', '112', '18244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6560140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18245', '1079', '1', 'Kabupaten Subang', 'ID.30.6581948', 'ASCII:Kabupaten Subang;ID:6581948', '16368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16368', '112', '18245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.6581948» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18246', '1079', '1', 'Kabupaten Cianjur', 'ID.30.6588980', 'ASCII:Kabupaten Cianjur;ID:6588980', '16369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16369', '112', '18246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.6588980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18247', '1079', '1', 'Kotamadya Bekasi', 'ID.30.6599302', 'ASCII:Kotamadya Bekasi;ID:6599302', '16370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16370', '112', '18247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.6599302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18248', '1079', '1', 'Kabupaten Karawang', 'ID.30.6606769', 'ASCII:Kabupaten Karawang;ID:6606769', '16371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16371', '112', '18248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.6606769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18249', '1079', '1', 'Kantor Bupati Minahasa Selatan', 'ID.23.6698251', 'ASCII:Kantor Bupati Minahasa Selatan;ID:6698251', '16372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16372', '112', '18249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.23.6698251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18250', '1079', '1', 'Amurang', 'ID.23.6698267', 'ASCII:Amurang;ID:6698267', '16373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16373', '112', '18250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.23.6698267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18251', '1079', '1', 'Kabupaten Aceh Tamiang', 'ID.01.6701575', 'ASCII:Kabupaten Aceh Tamiang;ID:6701575', '16374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16374', '112', '18251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6701575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18252', '1079', '1', 'Kabupaten Aceh Barat Daya', 'ID.01.6701674', 'ASCII:Kabupaten Aceh Barat Daya;ID:6701674', '16375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16375', '112', '18252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6701674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18253', '1079', '1', 'Kabupaten Aceh Tengah', 'ID.01.6702502', 'ASCII:Kabupaten Aceh Tengah;ID:6702502', '16376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16376', '112', '18253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6702502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18254', '1079', '1', 'Kabupaten Nagan Rayan', 'ID.01.6703019', 'ASCII:Kabupaten Nagan Rayan;ID:6703019', '16377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16377', '112', '18254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6703019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18255', '1079', '1', 'Kabupaten Simeulue', 'ID.01.6704825', 'ASCII:Kabupaten Simeulue;ID:6704825', '16378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16378', '112', '18255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6704825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18256', '1079', '1', 'Kabupaten Ache Jaya', 'ID.01.6705241', 'ASCII:Kabupaten Ache Jaya;ID:6705241', '16379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16379', '112', '18256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6705241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18257', '1079', '1', 'Kota Banda Aceh', 'ID.01.6709426', 'ASCII:Kota Banda Aceh;ID:6709426', '16380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16380', '112', '18257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6709426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18258', '1079', '1', 'Kabupaten Bener Meriah', 'ID.01.6712486', 'ASCII:Kabupaten Bener Meriah;ID:6712486', '16381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16381', '112', '18258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6712486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18259', '1079', '1', 'Kabupaten Aceh Singkil', 'ID.01.6713333', 'ASCII:Kabupaten Aceh Singkil;ID:6713333', '16382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16382', '112', '18259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6713333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18260', '1079', '1', 'Kabupaten Serdang Bedagai', 'ID.26.6715130', 'ASCII:Kabupaten Serdang Bedagai;ID:6715130', '16383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16383', '112', '18260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.6715130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18261', '1079', '1', 'Kota Lhokseumawe', 'ID.01.6719204', 'ASCII:Kota Lhokseumawe;ID:6719204', '16384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16384', '112', '18261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6719204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18262', '1079', '1', 'Rokan Hulu', 'ID.37.6722476', 'ASCII:Rokan Hulu;ID:6722476', '16385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16385', '112', '18262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.37.6722476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18263', '1079', '1', 'Kampar', 'ID.37.6724202', 'ASCII:Kampar;ID:6724202', '16386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16386', '112', '18263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.37.6724202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18264', '1079', '1', 'Kabupaten Pakpak Bharat', 'ID.26.6725176', 'ASCII:Kabupaten Pakpak Bharat;ID:6725176', '16387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16387', '112', '18264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.6725176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18265', '1079', '1', 'Kabupaten Tapanuli Utara', 'ID.26.6726149', 'ASCII:Kabupaten Tapanuli Utara;ID:6726149', '16388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16388', '112', '18265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.26.6726149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18266', '1079', '1', 'Kabupaten Bireuen', 'ID.01.6729814', 'ASCII:Kabupaten Bireuen;ID:6729814', '16389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16389', '112', '18266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.01.6729814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18267', '1079', '1', 'Kabupaten Demak', 'ID.07.6739766', 'ASCII:Kabupaten Demak;ID:6739766', '16390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16390', '112', '18267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6739766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18268', '1079', '1', 'Kabupaten Kendal', 'ID.07.6745680', 'ASCII:Kabupaten Kendal;ID:6745680', '16391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16391', '112', '18268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6745680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18269', '1079', '1', 'Kabupaten Kudos', 'ID.07.6748239', 'ASCII:Kabupaten Kudos;ID:6748239', '16392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16392', '112', '18269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6748239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18270', '1079', '1', 'Kotamadya Depok', 'ID.30.6751097', 'ASCII:Kotamadya Depok;ID:6751097', '16393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16393', '112', '18270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.6751097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18271', '1079', '1', 'Kabupaten Minahasa', 'ID.31.6755517', 'ASCII:Kabupaten Minahasa;ID:6755517', '16394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16394', '112', '18271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.31.6755517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18272', '1079', '1', 'Kotamadya Cilegon', 'ID.33.6758625', 'ASCII:Kotamadya Cilegon;ID:6758625', '16395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16395', '112', '18272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.33.6758625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18273', '1079', '1', 'Kotamadya Tegal', 'ID.07.6769512', 'ASCII:Kotamadya Tegal;ID:6769512', '16396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16396', '112', '18273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6769512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18274', '1079', '1', 'Kabupaten Gresik', 'ID.08.6775904', 'ASCII:Kabupaten Gresik;ID:6775904', '16397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16397', '112', '18274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.08.6775904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18275', '1079', '1', 'Kabupaten Pekalongan', 'ID.07.6792336', 'ASCII:Kabupaten Pekalongan;ID:6792336', '16398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16398', '112', '18275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.07.6792336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18276', '1079', '1', 'Kabupaten Bondowoso', 'ID.30.6829652', 'ASCII:Kabupaten Bondowoso;ID:6829652', '16399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16399', '112', '18276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.30.6829652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18277', '1079', '1', 'Kabupaten Mamuju', 'ID.24.6907478', 'ASCII:Kabupaten Mamuju;ID:6907478', '16400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16400', '112', '18277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.24.6907478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18278', '1079', '1', 'Kabupaten Minahasa', 'ID.31.6910934', 'ASCII:Kabupaten Minahasa;ID:6910934', '16401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16401', '112', '18278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ID.31.6910934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18279', '1079', '1', 'Nefat H̱efa', 'IL.04.294798', 'ASCII:Nefat Hefa;ID:294798', '16402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16402', '112', '18279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IL.04.294798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18280', '1079', '1', 'Nefat Ashqelon', 'IL.01.295618', 'ASCII:Nefat Ashqelon;ID:295618', '16403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16403', '112', '18280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IL.01.295618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18281', '1079', '1', 'Nefat `Akko', 'IL.03.295719', 'ASCII:Nefat `Akko;ID:295719', '16404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16404', '112', '18281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IL.03.295719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18282', '1079', '1', 'Zunheboto', 'IN.20.1252654', 'ASCII:Zunheboto;ID:1252654', '16405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16405', '112', '18282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.20.1252654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18283', '1079', '1', 'Yavatmāl', 'IN.16.1252771', 'ASCII:Yavatmal;ID:1252771', '16406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16406', '112', '18283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1252771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18284', '1079', '1', 'Yanam', 'IN.00.1252796', 'ASCII:Yanam;ID:1252796', '16407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16407', '112', '18284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.00.1252796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18285', '1079', '1', 'Wokha', 'IN.20.1252841', 'ASCII:Wokha;ID:1252841', '16408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16408', '112', '18285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.20.1252841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18286', '1079', '1', 'West Tripura', 'IN.26.1252864', 'ASCII:West Tripura;ID:1252864', '16409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16409', '112', '18286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.26.1252864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18287', '1079', '1', 'West Siang', 'IN.30.1252865', 'ASCII:West Siang;ID:1252865', '16410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16410', '112', '18287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.30.1252865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18288', '1079', '1', 'West Nimār', 'IN.35.1252866', 'ASCII:West Nimar;ID:1252866', '16411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16411', '112', '18288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1252866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18289', '1079', '1', 'West Kameng', 'IN.30.1252869', 'ASCII:West Kameng;ID:1252869', '16412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16412', '112', '18289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.30.1252869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18290', '1079', '1', 'West Godāvari', 'IN.02.1252873', 'ASCII:West Godavari;ID:1252873', '16413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16413', '112', '18290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1252873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18291', '1079', '1', 'West District', 'IN.00.1252877', 'ASCII:West District;ID:1252877', '16414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16414', '112', '18291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.00.1252877» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18292', '1079', '1', 'West Dinājpur', 'IN.28.1252878', 'ASCII:West Dinajpur;ID:1252878', '16415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16415', '112', '18292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1252878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18293', '1079', '1', 'Wardha', 'IN.16.1252944', 'ASCII:Wardha;ID:1252944', '16416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16416', '112', '18293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1252944» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18294', '1079', '1', 'Warangal', 'IN.02.1252949', 'ASCII:Warangal;ID:1252949', '16417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16417', '112', '18294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1252949» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18295', '1079', '1', 'Vishākhapatnam', 'IN.02.1253103', 'ASCII:Vishakhapatnam;ID:1253103', '16418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16418', '112', '18295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1253103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18296', '1079', '1', 'Vidisha', 'IN.35.1253201', 'ASCII:Vidisha;ID:1253201', '16419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16419', '112', '18296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1253201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18297', '1079', '1', 'Vārānasi', 'IN.36.1253407', 'ASCII:Varanasi;ID:1253407', '16420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16420', '112', '18297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1253407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18298', '1079', '1', 'Valsād', 'IN.09.1253469', 'ASCII:Valsad;ID:1253469', '16421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16421', '112', '18298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1253469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18299', '1079', '1', 'Vaishāli', 'IN.34.1253533', 'ASCII:Vaishali;ID:1253533', '16422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16422', '112', '18299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1253533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18300', '1079', '1', 'Vadodara', 'IN.09.1253574', 'ASCII:Vadodara;ID:1253574', '16423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16423', '112', '18300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1253574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18301', '1079', '1', 'Uttarkāshi', 'IN.39.1253629', 'ASCII:Uttarkashi;ID:1253629', '16424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16424', '112', '18301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.39.1253629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18302', '1079', '1', 'Uttar Kannad', 'IN.19.1253630', 'ASCII:Uttar Kannad;ID:1253630', '16425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16425', '112', '18302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1253630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18303', '1079', '1', 'Upper Subansiri', 'IN.30.1253720', 'ASCII:Upper Subansiri;ID:1253720', '16426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16426', '112', '18303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.30.1253720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18304', '1079', '1', 'Unnāo', 'IN.36.1253748', 'ASCII:Unnao;ID:1253748', '16427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16427', '112', '18304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1253748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18305', '1079', '1', 'Ujjain', 'IN.35.1253915', 'ASCII:Ujjain;ID:1253915', '16428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16428', '112', '18305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1253915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18306', '1079', '1', 'Udhampur', 'IN.12.1253957', 'ASCII:Udhampur;ID:1253957', '16429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16429', '112', '18306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.12.1253957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18307', '1079', '1', 'Udaipur', 'IN.24.1253989', 'ASCII:Udaipur;ID:1253989', '16430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16430', '112', '18307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1253989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18308', '1079', '1', 'Twenty-four Parganas', 'IN.28.1254014', 'ASCII:Twenty-four Parganas;ID:1254014', '16431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16431', '112', '18308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1254014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18309', '1079', '1', 'Tumakūru', 'IN.19.1254090', 'ASCII:Tumkur;ID:1254090', '16432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16432', '112', '18309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1254090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18310', '1079', '1', 'Tuensang District', 'IN.20.1254132', 'ASCII:Tuensang District;ID:1254132', '16433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16433', '112', '18310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.20.1254132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18311', '1079', '1', 'Trivandrum', 'IN.13.1254164', 'ASCII:Trivandrum;ID:1254164', '16434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16434', '112', '18311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1254164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18312', '1079', '1', 'Trichūr', 'IN.13.1254188', 'ASCII:Trichur;ID:1254188', '16435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16435', '112', '18312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1254188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18313', '1079', '1', 'Tonk', 'IN.24.1254242', 'ASCII:Tonk;ID:1254242', '16436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16436', '112', '18313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1254242» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18314', '1079', '1', 'Tirunelveli', 'IN.25.1254362', 'ASCII:Tirunelveli;ID:1254362', '16437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16437', '112', '18314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1254362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18315', '1079', '1', 'Tiruchchirāppalli', 'IN.25.1254389', 'ASCII:Tiruchchirappalli;ID:1254389', '16438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16438', '112', '18315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1254389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18316', '1079', '1', 'Tirāp', 'IN.30.1254418', 'ASCII:Tirap;ID:1254418', '16439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16439', '112', '18316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.30.1254418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18317', '1079', '1', 'Tīkamgarh', 'IN.35.1254535', 'ASCII:Tikamgarh;ID:1254535', '16440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16440', '112', '18317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1254535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18318', '1079', '1', 'The Dāngs', 'IN.09.1254616', 'ASCII:The Dangs;ID:1254616', '16441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16441', '112', '18318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1254616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18319', '1079', '1', 'Thanjāvūr', 'IN.25.1254650', 'ASCII:Thanjavur;ID:1254650', '16442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16442', '112', '18319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1254650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18320', '1079', '1', 'Thāne', 'IN.16.1254662', 'ASCII:Thane;ID:1254662', '16443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16443', '112', '18320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1254662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18321', '1079', '1', 'Tehri-Garhwāl', 'IN.39.1254807', 'ASCII:Tehri-Garhwal;ID:1254807', '16444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16444', '112', '18321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.39.1254807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18322', '1079', '1', 'Surguja', 'IN.37.1255347', 'ASCII:Surguja;ID:1255347', '16445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16445', '112', '18322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.37.1255347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18323', '1079', '1', 'Surendranagar', 'IN.09.1255350', 'ASCII:Surendranagar;ID:1255350', '16446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16446', '112', '18323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1255350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18324', '1079', '1', 'Sūrat', 'IN.09.1255365', 'ASCII:Surat;ID:1255365', '16447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16447', '112', '18324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1255365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18325', '1079', '1', 'Sundargarh', 'IN.21.1255438', 'ASCII:Sundargarh;ID:1255438', '16448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16448', '112', '18325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1255438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18326', '1079', '1', 'Sultānpur', 'IN.36.1255497', 'ASCII:Sultanpur;ID:1255497', '16449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16449', '112', '18326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1255497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18327', '1079', '1', 'Srīnagar', 'IN.12.1255639', 'ASCII:Srinagar;ID:1255639', '16450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16450', '112', '18327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.12.1255639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18328', '1079', '1', 'Srīkākulam', 'IN.02.1255649', 'ASCII:Srikakulam;ID:1255649', '16451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16451', '112', '18328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1255649» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18329', '1079', '1', 'South Tripura', 'IN.26.1255671', 'ASCII:South Tripura;ID:1255671', '16452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16452', '112', '18329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.26.1255671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18330', '1079', '1', 'South District', 'IN.00.1255681', 'ASCII:South District;ID:1255681', '16453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16453', '112', '18330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.00.1255681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18331', '1079', '1', 'South Arcot', 'IN.25.1255690', 'ASCII:South Arcot;ID:1255690', '16454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16454', '112', '18331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1255690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18332', '1079', '1', 'Sonīpat', 'IN.10.1255745', 'ASCII:Sonipat;ID:1255745', '16455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16455', '112', '18332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1255745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18333', '1079', '1', 'Solāpur', 'IN.16.1255847', 'ASCII:Solapur;ID:1255847', '16456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16456', '112', '18333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1255847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18334', '1079', '1', 'Solan', 'IN.11.1255851', 'ASCII:Solan;ID:1255851', '16457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16457', '112', '18334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1255851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18335', '1079', '1', 'Siwān', 'IN.34.1255930', 'ASCII:Siwan;ID:1255930', '16458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16458', '112', '18335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1255930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18336', '1079', '1', 'Sītāpur', 'IN.36.1255971', 'ASCII:Sitapur;ID:1255971', '16459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16459', '112', '18336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1255971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18337', '1079', '1', 'Sītāmarhi', 'IN.34.1255984', 'ASCII:Sitamarhi;ID:1255984', '16460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16460', '112', '18337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1255984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18338', '1079', '1', 'Sirsa', 'IN.10.1256056', 'ASCII:Sirsa;ID:1256056', '16461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16461', '112', '18338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1256056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18339', '1079', '1', 'Sirohi', 'IN.24.1256068', 'ASCII:Sirohi;ID:1256068', '16462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16462', '112', '18339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1256068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18340', '1079', '1', 'Sirmaur', 'IN.11.1256073', 'ASCII:Sirmaur;ID:1256073', '16463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16463', '112', '18340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1256073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18341', '1079', '1', 'Singhbhūm', 'IN.38.1256163', 'ASCII:Singhbhum;ID:1256163', '16464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16464', '112', '18341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.38.1256163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18342', '1079', '1', 'Shimla', 'IN.11.1256238', 'ASCII:Shimla;ID:1256238', '16465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16465', '112', '18342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1256238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18343', '1079', '1', 'Sīkar', 'IN.24.1256321', 'ASCII:Sikar;ID:1256321', '16466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16466', '112', '18343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1256321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18344', '1079', '1', 'Sidhi', 'IN.35.1256370', 'ASCII:Sidhi;ID:1256370', '16467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16467', '112', '18344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1256370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18345', '1079', '1', 'Sibsāgar', 'IN.03.1256389', 'ASCII:Sibsagar;ID:1256389', '16468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16468', '112', '18345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.03.1256389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18346', '1079', '1', 'Shivpurī', 'IN.35.1256452', 'ASCII:Shivpuri;ID:1256452', '16469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16469', '112', '18346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1256452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18347', '1079', '1', 'Shimoga', 'IN.19.1256516', 'ASCII:Shimoga;ID:1256516', '16470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16470', '112', '18347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1256516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18348', '1079', '1', 'Shājāpur', 'IN.35.1256694', 'ASCII:Shajapur;ID:1256694', '16471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16471', '112', '18348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1256694» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18349', '1079', '1', 'Shāhjahānpur', 'IN.36.1256729', 'ASCII:Shahjahanpur;ID:1256729', '16472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16472', '112', '18349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1256729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18350', '1079', '1', 'Shahdol', 'IN.35.1256740', 'ASCII:Shahdol;ID:1256740', '16473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16473', '112', '18350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1256740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18351', '1079', '1', 'Seonī', 'IN.35.1256827', 'ASCII:Seoni;ID:1256827', '16474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16474', '112', '18351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1256827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18352', '1079', '1', 'Sehore', 'IN.35.1256914', 'ASCII:Sehore;ID:1256914', '16475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16475', '112', '18352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1256914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18353', '1079', '1', 'Sawāi Mādhopur', 'IN.24.1256950', 'ASCII:Sawai Madhopur;ID:1256950', '16476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16476', '112', '18353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1256950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18354', '1079', '1', 'Satna', 'IN.35.1257023', 'ASCII:Satna;ID:1257023', '16477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16477', '112', '18354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1257023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18355', '1079', '1', 'Sātāra', 'IN.16.1257056', 'ASCII:Satara;ID:1257056', '16478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16478', '112', '18355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1257056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18356', '1079', '1', 'Sāran', 'IN.34.1257248', 'ASCII:Saran;ID:1257248', '16479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16479', '112', '18356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1257248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18357', '1079', '1', 'Santhāl Pargana', 'IN.38.1257331', 'ASCII:Santhal Pargana;ID:1257331', '16480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16480', '112', '18357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.38.1257331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18358', '1079', '1', 'Sangrūr', 'IN.10.1257403', 'ASCII:Sangrur;ID:1257403', '16481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16481', '112', '18358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1257403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18359', '1079', '1', 'Sāngli', 'IN.16.1257417', 'ASCII:Sangli;ID:1257417', '16482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16482', '112', '18359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1257417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18360', '1079', '1', 'Sambalpur', 'IN.21.1257544', 'ASCII:Sambalpur;ID:1257544', '16483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16483', '112', '18360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1257544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18361', '1079', '1', 'Samastīpur', 'IN.34.1257552', 'ASCII:Samastipur;ID:1257552', '16484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16484', '112', '18361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1257552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18362', '1079', '1', 'Salem', 'IN.25.1257630', 'ASCII:Salem;ID:1257630', '16485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16485', '112', '18362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1257630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18363', '1079', '1', 'Saharsa', 'IN.34.1257805', 'ASCII:Saharsa;ID:1257805', '16486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16486', '112', '18363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1257805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18364', '1079', '1', 'Sahāranpur', 'IN.36.1257807', 'ASCII:Saharanpur;ID:1257807', '16487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16487', '112', '18364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1257807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18365', '1079', '1', 'Sāgar', 'IN.35.1257852', 'ASCII:Sagar;ID:1257852', '16488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16488', '112', '18365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1257852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18366', '1079', '1', 'Sabar Kāntha', 'IN.09.1257922', 'ASCII:Sabar Kantha;ID:1257922', '16489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16489', '112', '18366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1257922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18367', '1079', '1', 'Rūpnagar', 'IN.23.1257953', 'ASCII:Rupnagar;ID:1257953', '16490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16490', '112', '18367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.23.1257953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18368', '1079', '1', 'Rohtās', 'IN.34.1258074', 'ASCII:Rohtas;ID:1258074', '16491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16491', '112', '18368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1258074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18369', '1079', '1', 'Rohtak', 'IN.10.1258077', 'ASCII:Rohtak;ID:1258077', '16492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16492', '112', '18369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1258077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18370', '1079', '1', 'Rewa', 'IN.35.1258183', 'ASCII:Rewa;ID:1258183', '16493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16493', '112', '18370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1258183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18371', '1079', '1', 'Ratnāgiri', 'IN.16.1258340', 'ASCII:Ratnagiri;ID:1258340', '16494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16494', '112', '18371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1258340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18372', '1079', '1', 'Ratlām', 'IN.35.1258343', 'ASCII:Ratlam;ID:1258343', '16495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16495', '112', '18372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1258343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18373', '1079', '1', 'Rānchī', 'IN.38.1258527', 'ASCII:Ranchi;ID:1258527', '16496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16496', '112', '18373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.38.1258527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18374', '1079', '1', 'Rāmpur', 'IN.36.1258622', 'ASCII:Rampur;ID:1258622', '16497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16497', '112', '18374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1258622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18375', '1079', '1', 'Rāmanāthapuram', 'IN.25.1258741', 'ASCII:Ramanathapuram;ID:1258741', '16498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16498', '112', '18375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1258741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18376', '1079', '1', 'Rāj Nāndgaon', 'IN.37.1258832', 'ASCII:Raj Nandgaon;ID:1258832', '16499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16499', '112', '18376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.37.1258832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18377', '1079', '1', 'Rājkot', 'IN.09.1258849', 'ASCII:Rajkot;ID:1258849', '16500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16500', '112', '18377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1258849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18378', '1079', '1', 'Rājgarh', 'IN.35.1258878', 'ASCII:Rajgarh;ID:1258878', '16501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16501', '112', '18378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1258878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18379', '1079', '1', 'Rājauri', 'IN.12.1258892', 'ASCII:Rajauri;ID:1258892', '16502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16502', '112', '18379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.12.1258892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18380', '1079', '1', 'Raisen', 'IN.35.1258953', 'ASCII:Raisen;ID:1258953', '16503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16503', '112', '18380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1258953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18381', '1079', '1', 'Raipur', 'IN.37.1258984', 'ASCII:Raipur;ID:1258984', '16504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16504', '112', '18381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.37.1258984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18382', '1079', '1', 'Raigarh', 'IN.37.1259006', 'ASCII:Raigarh;ID:1259006', '16505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16505', '112', '18382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.37.1259006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18383', '1079', '1', 'Rāichūr', 'IN.19.1259013', 'ASCII:Raichur;ID:1259013', '16506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16506', '112', '18383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1259013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18384', '1079', '1', 'Rāe Bareli', 'IN.36.1259065', 'ASCII:Rae Bareli;ID:1259065', '16507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16507', '112', '18384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1259065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18385', '1079', '1', 'Quilon', 'IN.13.1259092', 'ASCII:Quilon;ID:1259092', '16508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16508', '112', '18385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1259092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18386', '1079', '1', 'Puruliya', 'IN.28.1259164', 'ASCII:Puruliya;ID:1259164', '16509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16509', '112', '18386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1259164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18387', '1079', '1', 'Purnia', 'IN.34.1259168', 'ASCII:Purnia;ID:1259168', '16510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16510', '112', '18387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1259168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18388', '1079', '1', 'Pūrba Champāran', 'IN.34.1259186', 'ASCII:Purba Champaran;ID:1259186', '16511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16511', '112', '18388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1259186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18389', '1079', '1', 'Pudukkottai', 'IN.25.1259298', 'ASCII:Pudukkottai;ID:1259298', '16512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16512', '112', '18389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1259298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18390', '1079', '1', 'Pratāpgarh', 'IN.36.1259339', 'ASCII:Pratapgarh;ID:1259339', '16513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16513', '112', '18390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1259339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18391', '1079', '1', 'Prakasam', 'IN.02.1259346', 'ASCII:Prakasam;ID:1259346', '16514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16514', '112', '18391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1259346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18392', '1079', '1', 'Puducherry', 'IN.22.1259426', 'ASCII:Pondicherry;ID:1259426', '16515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16515', '112', '18392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.22.1259426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18393', '1079', '1', 'Pithorāgarh', 'IN.39.1259504', 'ASCII:Pithoragarh;ID:1259504', '16516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16516', '112', '18393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.39.1259504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18394', '1079', '1', 'Pīlībhīt', 'IN.36.1259687', 'ASCII:Pilibhit;ID:1259687', '16517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16517', '112', '18394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1259687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18395', '1079', '1', 'Phulabāni', 'IN.21.1259757', 'ASCII:Phulabani;ID:1259757', '16518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16518', '112', '18395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1259757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18396', '1079', '1', 'Phek', 'IN.20.1259785', 'ASCII:Phek;ID:1259785', '16519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16519', '112', '18396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.20.1259785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18397', '1079', '1', 'Patna', 'IN.34.1260091', 'ASCII:Patna;ID:1260091', '16520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16520', '112', '18397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1260091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18398', '1079', '1', 'Patiāla', 'IN.23.1260108', 'ASCII:Patiala;ID:1260108', '16521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16521', '112', '18398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.23.1260108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18399', '1079', '1', 'Pashchim Champāran', 'IN.34.1260208', 'ASCII:Pashchim Champaran;ID:1260208', '16522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16522', '112', '18399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1260208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18400', '1079', '1', 'Parbhani', 'IN.16.1260342', 'ASCII:Parbhani;ID:1260342', '16523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16523', '112', '18400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1260342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18401', '1079', '1', 'Panna', 'IN.35.1260455', 'ASCII:Panna;ID:1260455', '16524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16524', '112', '18401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1260455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18402', '1079', '1', 'Pāli', 'IN.24.1260724', 'ASCII:Pali;ID:1260724', '16525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16525', '112', '18402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1260724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18403', '1079', '1', 'Pālghāt', 'IN.13.1260729', 'ASCII:Palghat;ID:1260729', '16526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16526', '112', '18403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1260729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18404', '1079', '1', 'Palāmu', 'IN.38.1260783', 'ASCII:Palamu;ID:1260783', '16527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16527', '112', '18404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.38.1260783» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18405', '1079', '1', 'Osmānābād', 'IN.16.1261013', 'ASCII:Osmanabad;ID:1261013', '16528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16528', '112', '18405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1261013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18406', '1079', '1', 'Nowgong', 'IN.03.1261165', 'ASCII:Nowgong;ID:1261165', '16529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16529', '112', '18406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.03.1261165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18407', '1079', '1', 'North Tripura', 'IN.26.1261174', 'ASCII:North Tripura;ID:1261174', '16530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16530', '112', '18407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.26.1261174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18408', '1079', '1', 'North District', 'IN.00.1261190', 'ASCII:North District;ID:1261190', '16531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16531', '112', '18408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.00.1261190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18409', '1079', '1', 'North Cāchār Hills', 'IN.03.1261192', 'ASCII:North Cachar Hills;ID:1261192', '16532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16532', '112', '18409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.03.1261192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18410', '1079', '1', 'North Arcot', 'IN.25.1261197', 'ASCII:North Arcot;ID:1261197', '16533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16533', '112', '18410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1261197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18411', '1079', '1', 'Nizāmābād', 'IN.02.1261260', 'ASCII:Nizamabad;ID:1261260', '16534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16534', '112', '18411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1261260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18412', '1079', '1', 'Nīlgiri', 'IN.25.1261391', 'ASCII:Nilgiri;ID:1261391', '16535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16535', '112', '18412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1261391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18413', '1079', '1', 'Nicobar', 'IN.01.1261448', 'ASCII:Nicobar;ID:1261448', '16536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16536', '112', '18413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.01.1261448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18414', '1079', '1', 'Nellore', 'IN.02.1261530', 'ASCII:Nellore;ID:1261530', '16537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16537', '112', '18414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1261530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18415', '1079', '1', 'Nawāda', 'IN.34.1261632', 'ASCII:Nawada;ID:1261632', '16538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16538', '112', '18415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1261632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18416', '1079', '1', 'Nāsik', 'IN.16.1261732', 'ASCII:Nasik;ID:1261732', '16539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16539', '112', '18416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1261732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18417', '1079', '1', 'Narsimhapur', 'IN.35.1261755', 'ASCII:Narsimhapur;ID:1261755', '16540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16540', '112', '18417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1261755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18418', '1079', '1', 'Nānded', 'IN.16.1261978', 'ASCII:Nanded;ID:1261978', '16541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16541', '112', '18418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1261978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18419', '1079', '1', 'Nalgonda', 'IN.02.1262068', 'ASCII:Nalgonda;ID:1262068', '16542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16542', '112', '18419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1262068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18420', '1079', '1', 'Nālanda', 'IN.34.1262081', 'ASCII:Nalanda;ID:1262081', '16543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16543', '112', '18420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1262081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18421', '1079', '1', 'Naini Tāl', 'IN.39.1262118', 'ASCII:Naini Tal;ID:1262118', '16544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16544', '112', '18421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.39.1262118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18422', '1079', '1', 'Nāgpur', 'IN.16.1262182', 'ASCII:Nagpur;ID:1262182', '16545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16545', '112', '18422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1262182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18423', '1079', '1', 'Nāgaur', 'IN.24.1262217', 'ASCII:Nagaur;ID:1262217', '16546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16546', '112', '18423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1262217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18424', '1079', '1', 'Nadia', 'IN.28.1262293', 'ASCII:Nadia;ID:1262293', '16547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16547', '112', '18424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1262293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18425', '1079', '1', 'Mysore', 'IN.19.1262322', 'ASCII:Mysore;ID:1262322', '16548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16548', '112', '18425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1262322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18426', '1079', '1', 'Muzaffarpur', 'IN.34.1262331', 'ASCII:Muzaffarpur;ID:1262331', '16549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16549', '112', '18426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1262331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18427', '1079', '1', 'Muzaffarnagar', 'IN.36.1262333', 'ASCII:Muzaffarnagar;ID:1262333', '16550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16550', '112', '18427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1262333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18428', '1079', '1', 'Murshidābād', 'IN.35.1262413', 'ASCII:Murshidabad;ID:1262413', '16551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16551', '112', '18428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1262413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18429', '1079', '1', 'Munger', 'IN.34.1262483', 'ASCII:Munger;ID:1262483', '16552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16552', '112', '18429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1262483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18430', '1079', '1', 'Morena', 'IN.35.1262772', 'ASCII:Morena;ID:1262772', '16553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16553', '112', '18430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1262772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18431', '1079', '1', 'Morādābād', 'IN.36.1262802', 'ASCII:Moradabad;ID:1262802', '16554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16554', '112', '18431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1262802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18432', '1079', '1', 'Mon', 'IN.20.1262825', 'ASCII:Mon;ID:1262825', '16555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16555', '112', '18432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.20.1262825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18433', '1079', '1', 'Mon', 'IN.20.1262826', 'ASCII:Mon;ID:1262826', '16556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16556', '112', '18433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.20.1262826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18434', '1079', '1', 'Mokokchūng', 'IN.20.1262844', 'ASCII:Mokokchung;ID:1262844', '16557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16557', '112', '18434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.20.1262844» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18435', '1079', '1', 'Mirzāpur', 'IN.36.1262997', 'ASCII:Mirzapur;ID:1262997', '16558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16558', '112', '18435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1262997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18436', '1079', '1', 'Meerut', 'IN.36.1263215', 'ASCII:Meerut;ID:1263215', '16559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16559', '112', '18436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1263215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18437', '1079', '1', 'Medinīpur', 'IN.28.1263221', 'ASCII:Medinipur;ID:1263221', '16560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16560', '112', '18437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1263221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18438', '1079', '1', 'Medak', 'IN.02.1263231', 'ASCII:Medak;ID:1263231', '16561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16561', '112', '18438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1263231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18439', '1079', '1', 'Mayūrbhanj', 'IN.21.1263245', 'ASCII:Mayurbhanj;ID:1263245', '16562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16562', '112', '18439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1263245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18440', '1079', '1', 'Mathura', 'IN.36.1263366', 'ASCII:Mathura;ID:1263366', '16563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16563', '112', '18440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1263366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18441', '1079', '1', 'Manipur West', 'IN.17.1263700', 'ASCII:Manipur West;ID:1263700', '16564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16564', '112', '18441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.17.1263700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18442', '1079', '1', 'Manipur South', 'IN.17.1263701', 'ASCII:Manipur South;ID:1263701', '16565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16565', '112', '18442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.17.1263701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18443', '1079', '1', 'Manipur North', 'IN.17.1263703', 'ASCII:Manipur North;ID:1263703', '16566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16566', '112', '18443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.17.1263703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18444', '1079', '1', 'Manipur East', 'IN.17.1263704', 'ASCII:Manipur East;ID:1263704', '16567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16567', '112', '18444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.17.1263704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18445', '1079', '1', 'Manipur Central', 'IN.17.1263705', 'ASCII:Manipur Central;ID:1263705', '16568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16568', '112', '18445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.17.1263705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18446', '1079', '1', 'Mandya', 'IN.19.1263815', 'ASCII:Mandya;ID:1263815', '16569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16569', '112', '18446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1263815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18447', '1079', '1', 'Mandsaur', 'IN.35.1263835', 'ASCII:Mandsaur;ID:1263835', '16570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16570', '112', '18447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1263835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18448', '1079', '1', 'Mandla', 'IN.35.1263853', 'ASCII:Mandla;ID:1263853', '16571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16571', '112', '18448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1263853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18449', '1079', '1', 'Mandi', 'IN.11.1263863', 'ASCII:Mandi;ID:1263863', '16572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16572', '112', '18449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1263863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18450', '1079', '1', 'Māldah', 'IN.28.1264122', 'ASCII:Maldah;ID:1264122', '16573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16573', '112', '18450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1264122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18451', '1079', '1', 'Malappuram', 'IN.13.1264155', 'ASCII:Malappuram;ID:1264155', '16574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16574', '112', '18451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1264155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18452', '1079', '1', 'Mainpuri', 'IN.36.1264293', 'ASCII:Mainpuri;ID:1264293', '16575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16575', '112', '18452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1264293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18453', '1079', '1', 'Mahesāna', 'IN.09.1264390', 'ASCII:Mahesana;ID:1264390', '16576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16576', '112', '18453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1264390» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18454', '1079', '1', 'Mahendragarh', 'IN.10.1264396', 'ASCII:Mahendragarh;ID:1264396', '16577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16577', '112', '18454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1264396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18455', '1079', '1', 'Mahe', 'IN.13.1264404', 'ASCII:Mahe;ID:1264404', '16578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16578', '112', '18455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1264404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18456', '1079', '1', 'Mahbūbnagar', 'IN.02.1264408', 'ASCII:Mahbubnagar;ID:1264408', '16579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16579', '112', '18456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1264408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18457', '1079', '1', 'Madurai', 'IN.25.1264522', 'ASCII:Madurai;ID:1264522', '16580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16580', '112', '18457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1264522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18458', '1079', '1', 'Madras', 'IN.25.1264528', 'ASCII:Madras;ID:1264528', '16581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16581', '112', '18458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1264528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18459', '1079', '1', 'Madhubani', 'IN.34.1264556', 'ASCII:Madhubani;ID:1264556', '16582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16582', '112', '18459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1264556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18460', '1079', '1', 'Ludhiāna', 'IN.23.1264729', 'ASCII:Ludhiana;ID:1264729', '16583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16583', '112', '18460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.23.1264729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18461', '1079', '1', 'Lucknow District', 'IN.36.1264734', 'ASCII:Lucknow District;ID:1264734', '16584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16584', '112', '18461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1264734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18462', '1079', '1', 'Lower Subansiri', 'IN.30.1264739', 'ASCII:Lower Subansiri;ID:1264739', '16585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16585', '112', '18462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.30.1264739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18463', '1079', '1', 'Lohit District', 'IN.30.1264818', 'ASCII:Lohit District;ID:1264818', '16586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16586', '112', '18463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.30.1264818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18464', '1079', '1', 'Lalitpur', 'IN.36.1265158', 'ASCII:Lalitpur;ID:1265158', '16587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16587', '112', '18464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1265158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18465', '1079', '1', 'Lakhimpur', 'IN.03.1265243', 'ASCII:Lakhimpur;ID:1265243', '16588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16588', '112', '18465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.03.1265243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18466', '1079', '1', 'Lāhul and Spiti', 'IN.11.1265292', 'ASCII:Lahul and Spiti;ID:1265292', '16589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16589', '112', '18466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1265292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18467', '1079', '1', 'Ladākh', 'IN.12.1265343', 'ASCII:Ladakh;ID:1265343', '16590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16590', '112', '18467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.12.1265343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18468', '1079', '1', 'Kurukshetra', 'IN.10.1265468', 'ASCII:Kurukshetra;ID:1265468', '16591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16591', '112', '18468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1265468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18469', '1079', '1', 'Kurnool', 'IN.02.1265492', 'ASCII:Kurnool;ID:1265492', '16592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16592', '112', '18469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1265492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18470', '1079', '1', 'Kulu', 'IN.11.1265710', 'ASCII:Kulu;ID:1265710', '16593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16593', '112', '18470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1265710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18471', '1079', '1', 'Kulāba', 'IN.16.1265749', 'ASCII:Kulaba;ID:1265749', '16594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16594', '112', '18471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1265749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18472', '1079', '1', 'Krishna', 'IN.02.1265869', 'ASCII:Krishna;ID:1265869', '16595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16595', '112', '18472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1265869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18473', '1079', '1', 'Kozhikode', 'IN.13.1265874', 'ASCII:Kozhikode;ID:1265874', '16596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16596', '112', '18473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1265874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18474', '1079', '1', 'Kottayam', 'IN.13.1265912', 'ASCII:Kottayam;ID:1265912', '16597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16597', '112', '18474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1265912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18475', '1079', '1', 'Kota', 'IN.24.1266054', 'ASCII:Kota;ID:1266054', '16598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16598', '112', '18475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1266054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18476', '1079', '1', 'Koraput', 'IN.21.1266129', 'ASCII:Koraput;ID:1266129', '16599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16599', '112', '18476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1266129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18477', '1079', '1', 'Kolhāpur', 'IN.16.1266287', 'ASCII:Kolhapur;ID:1266287', '16600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16600', '112', '18477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1266287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18478', '1079', '1', 'Kolār', 'IN.19.1266306', 'ASCII:Kolar;ID:1266306', '16601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16601', '112', '18478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1266306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18479', '1079', '1', 'Kohīma', 'IN.20.1266367', 'ASCII:Kohima;ID:1266367', '16602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16602', '112', '18479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.20.1266367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18480', '1079', '1', 'Kodagu', 'IN.19.1266426', 'ASCII:Kodagu;ID:1266426', '16603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16603', '112', '18480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1266426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18481', '1079', '1', 'Koch Bihār', 'IN.28.1266437', 'ASCII:Koch Bihar;ID:1266437', '16604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16604', '112', '18481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1266437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18482', '1079', '1', 'Kinnaur', 'IN.11.1266519', 'ASCII:Kinnaur;ID:1266519', '16605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16605', '112', '18482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1266519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18483', '1079', '1', 'Kheri', 'IN.36.1266768', 'ASCII:Kheri;ID:1266768', '16606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16606', '112', '18483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1266768» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18484', '1079', '1', 'Kheda', 'IN.09.1266810', 'ASCII:Kheda;ID:1266810', '16607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16607', '112', '18484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1266810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18485', '1079', '1', 'Khāsi Hills', 'IN.18.1266857', 'ASCII:Khasi Hills;ID:1266857', '16608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16608', '112', '18485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.18.1266857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18486', '1079', '1', 'Khammam', 'IN.02.1267077', 'ASCII:Khammam;ID:1267077', '16609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16609', '112', '18486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1267077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18487', '1079', '1', 'Keonjhar', 'IN.21.1267268', 'ASCII:Keonjhar;ID:1267268', '16610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16610', '112', '18487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1267268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18488', '1079', '1', 'Kathua', 'IN.12.1267487', 'ASCII:Kathua;ID:1267487', '16611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16611', '112', '18488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.12.1267487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18489', '1079', '1', 'Kathihār', 'IN.34.1267499', 'ASCII:Kathihar;ID:1267499', '16612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16612', '112', '18489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1267499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18490', '1079', '1', 'Karnāl', 'IN.10.1267709', 'ASCII:Karnal;ID:1267709', '16613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16613', '112', '18490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1267709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18491', '1079', '1', 'Karīmnagar', 'IN.02.1267756', 'ASCII:Karimnagar;ID:1267756', '16614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16614', '112', '18491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1267756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18492', '1079', '1', 'Kārbi Ānglong', 'IN.03.1267812', 'ASCII:Karbi Anglong;ID:1267812', '16615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16615', '112', '18492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.03.1267812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18493', '1079', '1', 'Kāraikāl', 'IN.22.1267888', 'ASCII:Karaikal;ID:1267888', '16616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16616', '112', '18493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.22.1267888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18494', '1079', '1', 'Kapūrthala', 'IN.23.1267912', 'ASCII:Kapurthala;ID:1267912', '16617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16617', '112', '18494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.23.1267912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18495', '1079', '1', 'Kānpur', 'IN.36.1267997', 'ASCII:Kanpur;ID:1267997', '16618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16618', '112', '18495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1267997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18496', '1079', '1', 'Kanniyākumāri', 'IN.25.1268009', 'ASCII:Kanniyakumari;ID:1268009', '16619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16619', '112', '18496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1268009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18497', '1079', '1', 'Kāngra', 'IN.11.1268085', 'ASCII:Kangra;ID:1268085', '16620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16620', '112', '18497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1268085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18498', '1079', '1', 'Kāmrūp', 'IN.03.1268209', 'ASCII:Kamrup;ID:1268209', '16621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16621', '112', '18498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.03.1268209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18499', '1079', '1', 'Kālāhandi', 'IN.21.1268508', 'ASCII:Kalahandi;ID:1268508', '16622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16622', '112', '18499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1268508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18500', '1079', '1', 'Kachchh', 'IN.09.1268731', 'ASCII:Kachchh;ID:1268731', '16623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16623', '112', '18500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1268731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18501', '1079', '1', 'Jūnāgadh', 'IN.09.1268774', 'ASCII:Junagadh;ID:1268774', '16624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16624', '112', '18501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1268774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18502', '1079', '1', 'Jullundur', 'IN.23.1268783', 'ASCII:Jullundur;ID:1268783', '16625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16625', '112', '18502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.23.1268783» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18503', '1079', '1', 'Jodhpur', 'IN.24.1268867', 'ASCII:Jodhpur;ID:1268867', '16626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16626', '112', '18503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1268867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18504', '1079', '1', 'Jīnd', 'IN.10.1268908', 'ASCII:Jind;ID:1268908', '16627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16627', '112', '18504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1268908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18505', '1079', '1', 'Jhunjhunūn', 'IN.24.1268937', 'ASCII:Jhunjhunun;ID:1268937', '16628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16628', '112', '18505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1268937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18506', '1079', '1', 'Jhānsi', 'IN.35.1269007', 'ASCII:Jhansi;ID:1269007', '16629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16629', '112', '18506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1269007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18507', '1079', '1', 'Jhālāwār', 'IN.24.1269028', 'ASCII:Jhalawar;ID:1269028', '16630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16630', '112', '18507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1269028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18508', '1079', '1', 'Jhābua', 'IN.35.1269054', 'ASCII:Jhabua;ID:1269054', '16631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16631', '112', '18508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1269054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18509', '1079', '1', 'Jaunpur', 'IN.36.1269136', 'ASCII:Jaunpur;ID:1269136', '16632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16632', '112', '18509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1269136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18510', '1079', '1', 'Jāmnagar', 'IN.09.1269318', 'ASCII:Jamnagar;ID:1269318', '16633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16633', '112', '18510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1269318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18511', '1079', '1', 'Jammu', 'IN.12.1269322', 'ASCII:Jammu;ID:1269322', '16634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16634', '112', '18511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.12.1269322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18512', '1079', '1', 'Jalpāiguri', 'IN.00.1269389', 'ASCII:Jalpaiguri;ID:1269389', '16635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16635', '112', '18512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.00.1269389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18513', '1079', '1', 'Jālor', 'IN.24.1269393', 'ASCII:Jalor;ID:1269393', '16636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16636', '112', '18513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1269393» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18514', '1079', '1', 'Jālgaon', 'IN.16.1269411', 'ASCII:Jalgaon;ID:1269411', '16637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16637', '112', '18514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1269411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18515', '1079', '1', 'Jālaun', 'IN.36.1269423', 'ASCII:Jalaun;ID:1269423', '16638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16638', '112', '18515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1269423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18516', '1079', '1', 'Jaisalmer', 'IN.24.1269508', 'ASCII:Jaisalmer;ID:1269508', '16639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16639', '112', '18516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1269508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18517', '1079', '1', 'Jaipur', 'IN.24.1269519', 'ASCII:Jaipur;ID:1269519', '16640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16640', '112', '18517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1269519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18518', '1079', '1', 'Jaintia Hills', 'IN.18.1269523', 'ASCII:Jaintia Hills;ID:1269523', '16641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16641', '112', '18518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.18.1269523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18519', '1079', '1', 'Jabalpur', 'IN.35.1269634', 'ASCII:Jabalpur;ID:1269634', '16642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16642', '112', '18519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1269634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18520', '1079', '1', 'Indore', 'IN.35.1269744', 'ASCII:Indore;ID:1269744', '16643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16643', '112', '18520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1269744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18521', '1079', '1', 'Idukki', 'IN.13.1269812', 'ASCII:Idukki;ID:1269812', '16644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16644', '112', '18521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1269812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18522', '1079', '1', 'Hyderābād', 'IN.02.1269844', 'ASCII:Hyderabad;ID:1269844', '16645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16645', '112', '18522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1269844» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18523', '1079', '1', 'Hugli', 'IN.28.1269911', 'ASCII:Hugli;ID:1269911', '16646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16646', '112', '18523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1269911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18524', '1079', '1', 'Hoshiārpur', 'IN.23.1269938', 'ASCII:Hoshiarpur;ID:1269938', '16647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16647', '112', '18524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.23.1269938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18525', '1079', '1', 'Hoshangābād', 'IN.35.1269940', 'ASCII:Hoshangabad;ID:1269940', '16648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16648', '112', '18525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1269940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18526', '1079', '1', 'Hisār', 'IN.10.1270023', 'ASCII:Hisar;ID:1270023', '16649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16649', '112', '18526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1270023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18527', '1079', '1', 'Hazārībāg', 'IN.38.1270165', 'ASCII:Hazaribag;ID:1270165', '16650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16650', '112', '18527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.38.1270165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18528', '1079', '1', 'Hassan', 'IN.19.1270240', 'ASCII:Hassan;ID:1270240', '16651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16651', '112', '18528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1270240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18529', '1079', '1', 'Hardoi', 'IN.36.1270371', 'ASCII:Hardoi;ID:1270371', '16652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16652', '112', '18529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1270371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18530', '1079', '1', 'Hāora', 'IN.28.1270397', 'ASCII:Haora;ID:1270397', '16653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16653', '112', '18530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1270397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18531', '1079', '1', 'Hamīrpur', 'IN.11.1270456', 'ASCII:Hamirpur;ID:1270456', '16654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16654', '112', '18531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1270456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18532', '1079', '1', 'Hamīrpur', 'IN.36.1270457', 'ASCII:Hamirpur;ID:1270457', '16655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16655', '112', '18532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1270457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18533', '1079', '1', 'Gwalior', 'IN.35.1270585', 'ASCII:Gwalior;ID:1270585', '16656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16656', '112', '18533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1270585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18534', '1079', '1', 'Gurgaon', 'IN.10.1270644', 'ASCII:Gurgaon;ID:1270644', '16657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16657', '112', '18534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1270644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18535', '1079', '1', 'Gurdāspur', 'IN.00.1270648', 'ASCII:Gurdaspur;ID:1270648', '16658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16658', '112', '18535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.00.1270648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18536', '1079', '1', 'Guntūr', 'IN.02.1270669', 'ASCII:Guntur;ID:1270669', '16659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16659', '112', '18536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1270669» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18537', '1079', '1', 'Guna', 'IN.35.1270712', 'ASCII:Guna;ID:1270712', '16660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16660', '112', '18537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1270712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18538', '1079', '1', 'Gulbarga', 'IN.19.1270753', 'ASCII:Gulbarga;ID:1270753', '16661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16661', '112', '18538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1270753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18539', '1079', '1', 'Greater Bombay', 'IN.16.1270836', 'ASCII:Greater Bombay;ID:1270836', '16662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16662', '112', '18539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1270836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18540', '1079', '1', 'Gorakhpur', 'IN.36.1270930', 'ASCII:Gorakhpur;ID:1270930', '16663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16663', '112', '18540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1270930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18541', '1079', '1', 'Gopālganj', 'IN.34.1270967', 'ASCII:Gopalganj;ID:1270967', '16664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16664', '112', '18541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1270967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18542', '1079', '1', 'Gonda', 'IN.36.1270997', 'ASCII:Gonda;ID:1270997', '16665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16665', '112', '18542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1270997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18543', '1079', '1', 'Goālpāra', 'IN.03.1271152', 'ASCII:Goalpara;ID:1271152', '16666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16666', '112', '18543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.03.1271152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18544', '1079', '1', 'Girīdīh', 'IN.38.1271176', 'ASCII:Giridih;ID:1271176', '16667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16667', '112', '18544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.38.1271176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18545', '1079', '1', 'Ghāzīpur', 'IN.36.1271307', 'ASCII:Ghazipur;ID:1271307', '16668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16668', '112', '18545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1271307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18546', '1079', '1', 'Ghāziābād', 'IN.36.1271310', 'ASCII:Ghaziabad;ID:1271310', '16669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16669', '112', '18546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1271310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18547', '1079', '1', 'Gayā', 'IN.34.1271440', 'ASCII:Gaya;ID:1271440', '16670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16670', '112', '18547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1271440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18548', '1079', '1', 'Gāro Hills', 'IN.18.1271512', 'ASCII:Garo Hills;ID:1271512', '16671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16671', '112', '18548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.18.1271512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18549', '1079', '1', 'Garhwāl', 'IN.39.1271535', 'ASCII:Garhwal;ID:1271535', '16672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16672', '112', '18549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.39.1271535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18550', '1079', '1', 'Ganjām', 'IN.21.1271622', 'ASCII:Ganjam;ID:1271622', '16673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16673', '112', '18550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1271622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18551', '1079', '1', 'Gangānagar', 'IN.24.1271686', 'ASCII:Ganganagar;ID:1271686', '16674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16674', '112', '18551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1271686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18552', '1079', '1', 'Gāndhīnagar', 'IN.09.1271716', 'ASCII:Gandhinagar;ID:1271716', '16675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16675', '112', '18552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1271716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18553', '1079', '1', 'Fīrozpur', 'IN.23.1271884', 'ASCII:Firozpur;ID:1271884', '16676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16676', '112', '18553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.23.1271884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18554', '1079', '1', 'Fatehpur', 'IN.36.1271920', 'ASCII:Fatehpur;ID:1271920', '16677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16677', '112', '18554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1271920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18555', '1079', '1', 'Farrukhābād', 'IN.36.1271943', 'ASCII:Farrukhabad;ID:1271943', '16678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16678', '112', '18555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1271943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18556', '1079', '1', 'Farīdkot', 'IN.23.1271950', 'ASCII:Faridkot;ID:1271950', '16679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16679', '112', '18556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.23.1271950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18557', '1079', '1', 'Faizābād', 'IN.36.1271977', 'ASCII:Faizabad;ID:1271977', '16680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16680', '112', '18557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1271977» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18558', '1079', '1', 'Etāwah', 'IN.36.1271989', 'ASCII:Etawah;ID:1271989', '16681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16681', '112', '18558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1271989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18559', '1079', '1', 'Etah', 'IN.36.1271993', 'ASCII:Etah;ID:1271993', '16682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16682', '112', '18559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1271993» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18560', '1079', '1', 'Ernākulam', 'IN.13.1272019', 'ASCII:Ernakulam;ID:1272019', '16683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16683', '112', '18560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1272019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18561', '1079', '1', 'East Siang', 'IN.30.1272115', 'ASCII:East Siang;ID:1272115', '16684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16684', '112', '18561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.30.1272115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18562', '1079', '1', 'East Nimār', 'IN.35.1272117', 'ASCII:East Nimar;ID:1272117', '16685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16685', '112', '18562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1272117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18563', '1079', '1', 'East Kameng', 'IN.30.1272120', 'ASCII:East Kameng;ID:1272120', '16686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16686', '112', '18563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.30.1272120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18564', '1079', '1', 'East Godāvari', 'IN.02.1272123', 'ASCII:East Godavari;ID:1272123', '16687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16687', '112', '18564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1272123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18565', '1079', '1', 'East District', 'IN.00.1272129', 'ASCII:East District;ID:1272129', '16688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16688', '112', '18565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.00.1272129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18566', '1079', '1', 'Durg', 'IN.37.1272182', 'ASCII:Durg;ID:1272182', '16689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16689', '112', '18566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.37.1272182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18567', '1079', '1', 'Dūngarpur', 'IN.24.1272203', 'ASCII:Dungarpur;ID:1272203', '16690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16690', '112', '18567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1272203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18568', '1079', '1', 'Diu', 'IN.09.1272504', 'ASCII:Diu;ID:1272504', '16691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16691', '112', '18568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1272504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18569', '1079', '1', 'Dibrugarh', 'IN.03.1272649', 'ASCII:Dibrugarh;ID:1272649', '16692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16692', '112', '18569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.03.1272649» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18570', '1079', '1', 'Dibāng Valley', 'IN.30.1272651', 'ASCII:Dibang Valley;ID:1272651', '16693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16693', '112', '18570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.30.1272651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18571', '1079', '1', 'Dhule', 'IN.16.1272692', 'ASCII:Dhule;ID:1272692', '16694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16694', '112', '18571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1272692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18572', '1079', '1', 'Dhenkānāl', 'IN.21.1272781', 'ASCII:Dhenkanal;ID:1272781', '16695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16695', '112', '18572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1272781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18573', '1079', '1', 'Dhāwād', 'IN.19.1272797', 'ASCII:Dhawad;ID:1272797', '16696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16696', '112', '18573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1272797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18574', '1079', '1', 'Dharmapuri', 'IN.25.1272848', 'ASCII:Dharmapuri;ID:1272848', '16697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16697', '112', '18574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1272848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18575', '1079', '1', 'Dhār', 'IN.35.1272895', 'ASCII:Dhar;ID:1272895', '16698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16698', '112', '18575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1272895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18576', '1079', '1', 'Dhānbād', 'IN.38.1272980', 'ASCII:Dhanbad;ID:1272980', '16699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16699', '112', '18576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.38.1272980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18577', '1079', '1', 'Dewās', 'IN.35.1273067', 'ASCII:Dewas;ID:1273067', '16700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16700', '112', '18577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1273067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18578', '1079', '1', 'Deoria', 'IN.36.1273196', 'ASCII:Deoria;ID:1273196', '16701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16701', '112', '18578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1273196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18579', '1079', '1', 'Dehra Dūn', 'IN.39.1273314', 'ASCII:Dehra Dun;ID:1273314', '16702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16702', '112', '18579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.39.1273314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18580', '1079', '1', 'Datia', 'IN.35.1273404', 'ASCII:Datia;ID:1273404', '16703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16703', '112', '18580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1273404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18581', '1079', '1', 'Darrang', 'IN.03.1273451', 'ASCII:Darrang;ID:1273451', '16704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16704', '112', '18581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.03.1273451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18582', '1079', '1', 'Darjiling', 'IN.28.1273468', 'ASCII:Darjiling;ID:1273468', '16705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16705', '112', '18582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1273468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18583', '1079', '1', 'Darbhanga', 'IN.34.1273492', 'ASCII:Darbhanga;ID:1273492', '16706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16706', '112', '18583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1273492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18584', '1079', '1', 'Damoh', 'IN.35.1273589', 'ASCII:Damoh;ID:1273589', '16707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16707', '112', '18584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1273589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18585', '1079', '1', 'Damān District', 'IN.32.1273616', 'ASCII:Daman District;ID:1273616', '16708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16708', '112', '18585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.32.1273616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18586', '1079', '1', 'Dakshin Kannad', 'IN.19.1273664', 'ASCII:Dakshin Kannad;ID:1273664', '16709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16709', '112', '18586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1273664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18587', '1079', '1', 'Cuttack', 'IN.21.1273781', 'ASCII:Cuttack;ID:1273781', '16710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16710', '112', '18587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1273781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18588', '1079', '1', 'Cuddapah', 'IN.02.1273801', 'ASCII:Cuddapah;ID:1273801', '16711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16711', '112', '18588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1273801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18589', '1079', '1', 'Coimbatore', 'IN.25.1273866', 'ASCII:Coimbatore;ID:1273866', '16712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16712', '112', '18589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1273866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18590', '1079', '1', 'Chūru', 'IN.24.1273894', 'ASCII:Churu;ID:1273894', '16713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16713', '112', '18590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1273894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18591', '1079', '1', 'Chittoor', 'IN.02.1274034', 'ASCII:Chittoor;ID:1274034', '16714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16714', '112', '18591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1274034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18592', '1079', '1', 'Chittaurgarh', 'IN.24.1274041', 'ASCII:Chittaurgarh;ID:1274041', '16715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16715', '112', '18592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1274041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18593', '1079', '1', 'Chitradurga', 'IN.19.1274057', 'ASCII:Chitradurga;ID:1274057', '16716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16716', '112', '18593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1274057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18594', '1079', '1', 'Chikmagalūr', 'IN.19.1274221', 'ASCII:Chikmagalur;ID:1274221', '16717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16717', '112', '18594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1274221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18595', '1079', '1', 'Chhindwāra', 'IN.35.1274305', 'ASCII:Chhindwara;ID:1274305', '16718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16718', '112', '18595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1274305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18596', '1079', '1', 'Chhatarpur', 'IN.35.1274339', 'ASCII:Chhatarpur;ID:1274339', '16719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16719', '112', '18596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1274339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18597', '1079', '1', 'Chengalpattu', 'IN.25.1274431', 'ASCII:Chengalpattu;ID:1274431', '16720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16720', '112', '18597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1274431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18598', '1079', '1', 'Chandrapur', 'IN.16.1274695', 'ASCII:Chandrapur;ID:1274695', '16721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16721', '112', '18598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1274695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18599', '1079', '1', 'Chamoli', 'IN.39.1274839', 'ASCII:Chamoli;ID:1274839', '16722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16722', '112', '18599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.39.1274839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18600', '1079', '1', 'Chamba', 'IN.11.1274849', 'ASCII:Chamba;ID:1274849', '16723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16723', '112', '18600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1274849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18601', '1079', '1', 'Kannur', 'IN.13.1274988', 'ASCII:Kannur;ID:1274988', '16724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16724', '112', '18601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1274988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18602', '1079', '1', 'Calcutta', 'IN.28.1275005', 'ASCII:Calcutta;ID:1275005', '16725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16725', '112', '18602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1275005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18603', '1079', '1', 'Cāchār', 'IN.03.1275009', 'ASCII:Cachar;ID:1275009', '16726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16726', '112', '18603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.03.1275009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18604', '1079', '1', 'Būndi', 'IN.24.1275104', 'ASCII:Bundi;ID:1275104', '16727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16727', '112', '18604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1275104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18605', '1079', '1', 'Buldāna', 'IN.16.1275118', 'ASCII:Buldana;ID:1275118', '16728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16728', '112', '18605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1275118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18606', '1079', '1', 'Bulandshahr', 'IN.36.1275121', 'ASCII:Bulandshahr;ID:1275121', '16729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16729', '112', '18606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1275121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18607', '1079', '1', 'Budaun', 'IN.36.1275164', 'ASCII:Budaun;ID:1275164', '16730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16730', '112', '18607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1275164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18608', '1079', '1', 'Bīrbhūm', 'IN.28.1275525', 'ASCII:Birbhum;ID:1275525', '16731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16731', '112', '18608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1275525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18609', '1079', '1', 'Bīr', 'IN.16.1275540', 'ASCII:Bir;ID:1275540', '16732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16732', '112', '18609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1275540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18610', '1079', '1', 'Bilāspur', 'IN.11.1275638', 'ASCII:Bilaspur;ID:1275638', '16733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16733', '112', '18610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.11.1275638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18611', '1079', '1', 'Bilāspur', 'IN.37.1275639', 'ASCII:Bilaspur;ID:1275639', '16734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16734', '112', '18611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.37.1275639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18612', '1079', '1', 'Bīkāner', 'IN.24.1275666', 'ASCII:Bikaner;ID:1275666', '16735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16735', '112', '18612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1275666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18613', '1079', '1', 'Bijnor', 'IN.36.1275680', 'ASCII:Bijnor;ID:1275680', '16736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16736', '112', '18613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1275680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18614', '1079', '1', 'Bijāpur', 'IN.19.1275702', 'ASCII:Bijapur;ID:1275702', '16737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16737', '112', '18614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1275702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18615', '1079', '1', 'Bīdar', 'IN.19.1275739', 'ASCII:Bidar;ID:1275739', '16738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16738', '112', '18615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1275739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18616', '1079', '1', 'Bhopāl', 'IN.35.1275842', 'ASCII:Bhopal;ID:1275842', '16739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16739', '112', '18616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1275842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18617', '1079', '1', 'Bhojpur', 'IN.34.1275871', 'ASCII:Bhojpur;ID:1275871', '16740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16740', '112', '18617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1275871» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18618', '1079', '1', 'Bhiwani', 'IN.10.1275900', 'ASCII:Bhiwani;ID:1275900', '16741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16741', '112', '18618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1275900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18619', '1079', '1', 'Bhind', 'IN.35.1275927', 'ASCII:Bhind;ID:1275927', '16742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16742', '112', '18619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1275927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18620', '1079', '1', 'Bhīlwāra', 'IN.24.1275961', 'ASCII:Bhilwara;ID:1275961', '16743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16743', '112', '18620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1275961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18621', '1079', '1', 'Bhāvnagar', 'IN.09.1276033', 'ASCII:Bhavnagar;ID:1276033', '16744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16744', '112', '18621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1276033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18622', '1079', '1', 'Bhatinda', 'IN.23.1276071', 'ASCII:Bhatinda;ID:1276071', '16745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16745', '112', '18622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.23.1276071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18623', '1079', '1', 'Bharūch', 'IN.09.1276101', 'ASCII:Bharuch;ID:1276101', '16746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16746', '112', '18623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1276101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18624', '1079', '1', 'Bharatpur', 'IN.24.1276130', 'ASCII:Bharatpur;ID:1276130', '16747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16747', '112', '18624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1276130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18625', '1079', '1', 'Bhandāra', 'IN.16.1276192', 'ASCII:Bhandara;ID:1276192', '16748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16748', '112', '18625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1276192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18626', '1079', '1', 'Bhāgalpur', 'IN.34.1276301', 'ASCII:Bhagalpur;ID:1276301', '16749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16749', '112', '18626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1276301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18627', '1079', '1', 'Betūl', 'IN.35.1276391', 'ASCII:Betul;ID:1276391', '16750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16750', '112', '18627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1276391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18628', '1079', '1', 'Bellary', 'IN.19.1276510', 'ASCII:Bellary;ID:1276510', '16751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16751', '112', '18628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1276510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18629', '1079', '1', 'Belgaum', 'IN.19.1276534', 'ASCII:Belgaum;ID:1276534', '16752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16752', '112', '18629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1276534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18630', '1079', '1', 'Begusarāi', 'IN.34.1276610', 'ASCII:Begusarai;ID:1276610', '16753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16753', '112', '18630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1276610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18631', '1079', '1', 'Basti', 'IN.36.1276737', 'ASCII:Basti;ID:1276737', '16754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16754', '112', '18631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1276737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18632', '1079', '1', 'Bastar', 'IN.37.1276739', 'ASCII:Bastar;ID:1276739', '16755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16755', '112', '18632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.37.1276739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18633', '1079', '1', 'Bārmer', 'IN.24.1276902', 'ASCII:Barmer;ID:1276902', '16756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16756', '112', '18633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1276902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18634', '1079', '1', 'Bareilly', 'IN.36.1277014', 'ASCII:Bareilly;ID:1277014', '16757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16757', '112', '18634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1277014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18635', '1079', '1', 'Barddhamān', 'IN.28.1277030', 'ASCII:Barddhaman;ID:1277030', '16758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16758', '112', '18635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1277030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18636', '1079', '1', 'Bāramūla', 'IN.12.1277086', 'ASCII:Baramula;ID:1277086', '16759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16759', '112', '18636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.12.1277086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18637', '1079', '1', 'Bāra Banki', 'IN.36.1277159', 'ASCII:Bara Banki;ID:1277159', '16760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16760', '112', '18637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1277159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18638', '1079', '1', 'Bānswāra', 'IN.24.1277215', 'ASCII:Banswara;ID:1277215', '16761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16761', '112', '18638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1277215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18639', '1079', '1', 'Bānkurā', 'IN.28.1277265', 'ASCII:Bankura;ID:1277265', '16762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16762', '112', '18639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.28.1277265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18640', '1079', '1', 'Bangalore Urban', 'IN.19.1277331', 'ASCII:Bangalore Urban;ID:1277331', '16763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16763', '112', '18640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1277331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18641', '1079', '1', 'Bangalore Rural', 'IN.19.1277332', 'ASCII:Bangalore Rural;ID:1277332', '16764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16764', '112', '18641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.19.1277332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18642', '1079', '1', 'Bānda', 'IN.36.1277400', 'ASCII:Banda;ID:1277400', '16765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16765', '112', '18642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1277400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18643', '1079', '1', 'Banās Kāntha', 'IN.09.1277417', 'ASCII:Banas Kantha;ID:1277417', '16766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16766', '112', '18643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1277417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18644', '1079', '1', 'Ballia', 'IN.34.1277553', 'ASCII:Ballia;ID:1277553', '16767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16767', '112', '18644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1277553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18645', '1079', '1', 'Bāleshwar', 'IN.21.1277600', 'ASCII:Baleshwar;ID:1277600', '16768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16768', '112', '18645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1277600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18646', '1079', '1', 'Balāngīr', 'IN.21.1277644', 'ASCII:Balangir;ID:1277644', '16769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16769', '112', '18646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.21.1277644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18647', '1079', '1', 'Bālāghāt', 'IN.35.1277662', 'ASCII:Balaghat;ID:1277662', '16770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16770', '112', '18647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.35.1277662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18648', '1079', '1', 'Bahraich', 'IN.36.1277800', 'ASCII:Bahraich;ID:1277800', '16771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16771', '112', '18648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1277800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18649', '1079', '1', 'Āzamgarh', 'IN.36.1278084', 'ASCII:Azamgarh;ID:1278084', '16772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16772', '112', '18649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1278084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18650', '1079', '1', 'Aurangābād', 'IN.34.1278150', 'ASCII:Aurangabad;ID:1278150', '16773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16773', '112', '18650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.34.1278150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18651', '1079', '1', 'Aurangābād', 'IN.16.1278151', 'ASCII:Aurangabad;ID:1278151', '16774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16774', '112', '18651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1278151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18652', '1079', '1', 'Anna', 'IN.25.1278547', 'ASCII:Anna;ID:1278547', '16775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16775', '112', '18652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.1278547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18653', '1079', '1', 'Andaman', 'IN.01.1278648', 'ASCII:Andaman;ID:1278648', '16776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16776', '112', '18653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.01.1278648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18654', '1079', '1', 'Anantnāg', 'IN.12.1278668', 'ASCII:Anantnag;ID:1278668', '16777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16777', '112', '18654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.12.1278668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18655', '1079', '1', 'Anantapur', 'IN.02.1278673', 'ASCII:Anantapur;ID:1278673', '16778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16778', '112', '18655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1278673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18656', '1079', '1', 'Amritsar', 'IN.23.1278711', 'ASCII:Amritsar;ID:1278711', '16779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16779', '112', '18656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.23.1278711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18657', '1079', '1', 'Amreli', 'IN.32.1278716', 'ASCII:Amreli;ID:1278716', '16780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16780', '112', '18657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.32.1278716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18658', '1079', '1', 'Amrāvati', 'IN.16.1278719', 'ASCII:Amravati;ID:1278719', '16781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16781', '112', '18658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1278719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18659', '1079', '1', 'Ambāla', 'IN.10.1278861', 'ASCII:Ambala;ID:1278861', '16782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16782', '112', '18659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.10.1278861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18660', '1079', '1', 'Alwar', 'IN.24.1278947', 'ASCII:Alwar;ID:1278947', '16783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16783', '112', '18660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1278947» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18661', '1079', '1', 'Almora', 'IN.39.1278975', 'ASCII:Almora;ID:1278975', '16784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16784', '112', '18661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.39.1278975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18662', '1079', '1', 'Alappuzha', 'IN.13.1278986', 'ASCII:Alappuzha;ID:1278986', '16785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16785', '112', '18662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.13.1278986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18663', '1079', '1', 'Allahābād', 'IN.36.1278995', 'ASCII:Allahabad;ID:1278995', '16786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16786', '112', '18663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1278995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18664', '1079', '1', 'Alīgarh', 'IN.36.1279020', 'ASCII:Aligarh;ID:1279020', '16787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16787', '112', '18664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1279020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18665', '1079', '1', 'Akola', 'IN.16.1279109', 'ASCII:Akola;ID:1279109', '16788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16788', '112', '18665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1279109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18666', '1079', '1', 'Ajmer', 'IN.24.1279160', 'ASCII:Ajmer;ID:1279160', '16789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16789', '112', '18666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.24.1279160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18667', '1079', '1', 'Ahmadnagar', 'IN.16.1279229', 'ASCII:Ahmadnagar;ID:1279229', '16790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16790', '112', '18667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.16.1279229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18668', '1079', '1', 'Ahmadābād', 'IN.09.1279234', 'ASCII:Ahmadabad;ID:1279234', '16791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16791', '112', '18668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.09.1279234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18669', '1079', '1', 'Āgra', 'IN.36.1279262', 'ASCII:Agra;ID:1279262', '16792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16792', '112', '18669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.36.1279262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18670', '1079', '1', 'Ādilābād', 'IN.02.1279345', 'ASCII:Adilabad;ID:1279345', '16793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16793', '112', '18670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.02.1279345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18671', '1079', '1', 'Nāmakkal', 'IN.25.6640313', 'ASCII:Namakkal;ID:6640313', '16794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16794', '112', '18671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IN.25.6640313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18672', '1079', '1', 'Qaḑā'' Zakho', 'IQ.08.89569', 'ASCII:Qada'' Zakho;ID:89569', '16795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16795', '112', '18672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.08.89569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18673', '1079', '1', 'Qaḑā'' Tikrīt', 'IQ.18.90148', 'ASCII:Qada'' Tikrit;ID:90148', '16796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16796', '112', '18673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.18.90148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18674', '1079', '1', 'Qaḑā'' Tall `Afar', 'IQ.15.90392', 'ASCII:Qada'' Tall `Afar;ID:90392', '16797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16797', '112', '18674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.15.90392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18675', '1079', '1', 'Qaḑā'' Sūq ash Shuyūkh', 'IQ.09.90509', 'ASCII:Qada'' Suq ash Shuyukh;ID:90509', '16798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16798', '112', '18675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.09.90509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18676', '1079', '1', 'Qaḑā'' Shahrbāzār', 'IQ.05.91176', 'ASCII:Qada'' Shahrbazar;ID:91176', '16799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16799', '112', '18676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.05.91176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18677', '1079', '1', 'Qaḑā'' Sāmarrā''', 'IQ.18.91594', 'ASCII:Qada'' Samarra'';ID:91594', '16800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16800', '112', '18677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.18.91594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18678', '1079', '1', 'Qaḑā'' Rāniyah', 'IQ.05.92051', 'ASCII:Qada'' Raniyah;ID:92051', '16801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16801', '112', '18678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.05.92051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18679', '1079', '1', 'Qaḑā'' Qal`at Şāliḩ', 'IQ.14.92536', 'ASCII:Qada'' Qal`at Salih;ID:92536', '16802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16802', '112', '18679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.14.92536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18680', '1079', '1', 'Qaḑā'' Pishdar', 'IQ.00.92743', 'ASCII:Qada'' Pishdar;ID:92743', '16803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16803', '112', '18680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.00.92743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18681', '1079', '1', 'Qaḑā'' Mandalī', 'IQ.10.93708', 'ASCII:Qada'' Mandali;ID:93708', '16804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16804', '112', '18681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.10.93708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18682', '1079', '1', 'Qaḑā'' Makhmūr', 'IQ.11.93817', 'ASCII:Qada'' Makhmur;ID:93817', '16805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16805', '112', '18682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.11.93817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18683', '1079', '1', 'Qaḑā'' Kifrī', 'IQ.05.94296', 'ASCII:Qada'' Kifri;ID:94296', '16806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16806', '112', '18683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.05.94296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18684', '1079', '1', 'Qaḑā'' Khānaqīn', 'IQ.10.94590', 'ASCII:Qada'' Khanaqin;ID:94590', '16807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16807', '112', '18684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.10.94590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18685', '1079', '1', 'Qaḑā'' Karkūk', 'IQ.13.94786', 'ASCII:Qada'' Karkuk;ID:94786', '16808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16808', '112', '18685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.13.94786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18686', '1079', '1', 'Qaḑā Karbalā''', 'IQ.12.94822', 'ASCII:Qada Karbala'';ID:94822', '16809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16809', '112', '18686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.12.94822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18687', '1079', '1', 'Qaḑā'' Arbīl', 'IQ.11.95444', 'ASCII:Qada'' Arbil;ID:95444', '16810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16810', '112', '18687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.11.95444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18688', '1079', '1', 'Qaḑā'' Ḩalabjah', 'IQ.05.96204', 'ASCII:Qada'' Halabjah;ID:96204', '16811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16811', '112', '18688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.05.96204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18689', '1079', '1', 'Qaḑā'' Dahūk', 'IQ.08.97269', 'ASCII:Qada'' Dahuk;ID:97269', '16812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16812', '112', '18689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.08.97269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18690', '1079', '1', 'Qaḑā'' Chamchamal', 'IQ.05.97416', 'ASCII:Qada'' Chamchamal;ID:97416', '16813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16813', '112', '18690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.05.97416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18691', '1079', '1', 'Qaḑā'' Ba`qūbah', 'IQ.07.97988', 'ASCII:Qada'' Ba`qubah;ID:97988', '16814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16814', '112', '18691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.07.97988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18692', '1079', '1', 'Qaḑā'' Baghdād', 'IQ.07.98179', 'ASCII:Qada'' Baghdad;ID:98179', '16815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16815', '112', '18692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.07.98179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18693', '1079', '1', 'Qaḑā'' Badrah', 'IQ.16.98197', 'ASCII:Qada'' Badrah;ID:98197', '16816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16816', '112', '18693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.16.98197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18694', '1079', '1', 'Qaḑā'' az Zubayr', 'IQ.02.98247', 'ASCII:Qada'' az Zubayr;ID:98247', '16817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16817', '112', '18694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.02.98247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18695', '1079', '1', 'Qaḑā'' az Zībār', 'IQ.08.98253', 'ASCII:Qada'' az Zibar;ID:98253', '16818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16818', '112', '18695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.08.98253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18696', '1079', '1', 'Qaḑā'' aş Şuwayrah', 'IQ.16.98460', 'ASCII:Qada'' as Suwayrah;ID:98460', '16819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16819', '112', '18696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.16.98460» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18697', '1079', '1', 'Qaḑā'' as Sulaymānīyah', 'IQ.05.98464', 'ASCII:Qada'' as Sulaymaniyah;ID:98464', '16820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16820', '112', '18697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.05.98464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18698', '1079', '1', 'Qaḑā'' as Samāwah', 'IQ.03.98532', 'ASCII:Qada'' as Samawah;ID:98532', '16821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16821', '112', '18698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.03.98532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18699', '1079', '1', 'Qaḑā'' as Salmān', 'IQ.03.98534', 'ASCII:Qada'' as Salman;ID:98534', '16822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16822', '112', '18699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.03.98534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18700', '1079', '1', 'Qaḑā'' ash Shaykhān', 'IQ.15.98612', 'ASCII:Qada'' ash Shaykhan;ID:98612', '16823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16823', '112', '18700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.15.98612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18701', '1079', '1', 'Qaḑā'' ash Shaţrah', 'IQ.09.98623', 'ASCII:Qada'' ash Shatrah;ID:98623', '16824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16824', '112', '18701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.09.98623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18702', '1079', '1', 'Qaḑā'' ash Shāmīyah', 'IQ.04.98634', 'ASCII:Qada'' ash Shamiyah;ID:98634', '16825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16825', '112', '18702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.04.98634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18703', '1079', '1', 'Qaḑā'' ar Ruţbah', 'IQ.01.98678', 'ASCII:Qada'' ar Rutbah;ID:98678', '16826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16826', '112', '18703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.01.98678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18704', '1079', '1', 'Qaḑā'' ar Rifā`', 'IQ.09.98700', 'ASCII:Qada'' ar Rifa`;ID:98700', '16827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16827', '112', '18704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.09.98700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18705', '1079', '1', 'Qaḑā'' ar Ramād', 'IQ.01.98718', 'ASCII:Qada'' ar Ramad;ID:98718', '16828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16828', '112', '18705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.01.98718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18706', '1079', '1', 'Qaḑā'' an Nāşirīyah', 'IQ.09.98855', 'ASCII:Qada'' an Nasiriyah;ID:98855', '16829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16829', '112', '18706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.09.98855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18707', '1079', '1', 'Qaḑā'' an Najaf', 'IQ.17.98861', 'ASCII:Qada'' an Najaf;ID:98861', '16830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16830', '112', '18707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.17.98861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18708', '1079', '1', 'Qaḑā'' `Ānah', 'IQ.01.98884', 'ASCII:Qada'' `Anah;ID:98884', '16831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16831', '112', '18708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.01.98884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18709', '1079', '1', 'Qaḑā'' al Qurnah', 'IQ.02.98994', 'ASCII:Qada'' al Qurnah;ID:98994', '16832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16832', '112', '18709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.02.98994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18710', '1079', '1', 'Qaḑā'' al Musayyib', 'IQ.06.99040', 'ASCII:Qada'' al Musayyib;ID:99040', '16833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16833', '112', '18710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.06.99040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18711', '1079', '1', 'Qaḑā’ al Miqdādīyah', 'IQ.10.99063', 'ASCII:Qada'' al Miqdadiyah;ID:99063', '16834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16834', '112', '18711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.10.99063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18712', '1079', '1', 'Qaḑā'' al Maḩmūdīyah', 'IQ.06.99101', 'ASCII:Qada'' al Mahmudiyah;ID:99101', '16835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16835', '112', '18712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.06.99101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18713', '1079', '1', 'Qaḑā'' al Kūt', 'IQ.16.99132', 'ASCII:Qada'' al Kut;ID:99132', '16836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16836', '112', '18713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.16.99132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18714', '1079', '1', 'Qaḑā'' al Khāliş', 'IQ.10.99170', 'ASCII:Qada'' al Khalis;ID:99170', '16837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16837', '112', '18714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.10.99170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18715', '1079', '1', 'Qaḑā'' al Kāz̧imīyah', 'IQ.07.99173', 'ASCII:Qada'' al Kazimiyah;ID:99173', '16838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16838', '112', '18715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.07.99173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18716', '1079', '1', 'Qaḑā'' al Chabaish', 'IQ.09.99185', 'ASCII:Qada'' al Chabaish;ID:99185', '16839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16839', '112', '18716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.09.99185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18717', '1079', '1', 'Qaḑā'' `Alī al Gharbī', 'IQ.14.99305', 'ASCII:Qada'' `Ali al Gharbi;ID:99305', '16840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16840', '112', '18717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.14.99305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18718', '1079', '1', 'Qaḑā’ al Hindīyah', 'IQ.06.99345', 'ASCII:Qada'' al Hindiyah;ID:99345', '16841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16841', '112', '18718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.06.99345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18719', '1079', '1', 'Qaḑā'' al Ḩillah', 'IQ.06.99348', 'ASCII:Qada'' al Hillah;ID:99348', '16842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16842', '112', '18719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.06.99348» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18720', '1079', '1', 'Qaḑā'' al Ḩayy', 'IQ.16.99351', 'ASCII:Qada'' al Hayy;ID:99351', '16843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16843', '112', '18720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.16.99351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18721', '1079', '1', 'Qaḑā'' al Hāshimīyah', 'IQ.06.99358', 'ASCII:Qada'' al Hashimiyah;ID:99358', '16844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16844', '112', '18721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.06.99358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18722', '1079', '1', 'Qaḑā'' al Ḩaḑr', 'IQ.15.99414', 'ASCII:Qada'' al Hadr;ID:99414', '16845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16845', '112', '18722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.15.99414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18723', '1079', '1', 'Qaḑā'' al Fallūjah', 'IQ.01.99455', 'ASCII:Qada'' al Fallujah;ID:99455', '16846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16846', '112', '18723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.01.99455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18724', '1079', '1', 'Qaḑā'' al Başrah', 'IQ.02.99534', 'ASCII:Qada'' al Basrah;ID:99534', '16847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16847', '112', '18724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.02.99534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18725', '1079', '1', 'Qaḑā al `Amārah', 'IQ.14.99610', 'ASCII:Qada al `Amarah;ID:99610', '16848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16848', '112', '18725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.14.99610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18726', '1079', '1', 'Qaḑā'' al `Amādīyah', 'IQ.08.99612', 'ASCII:Qada'' al `Amadiyah;ID:99612', '16849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16849', '112', '18726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.08.99612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18727', '1079', '1', 'Qaḑā'' `Afak', 'IQ.04.99737', 'ASCII:Qada'' `Afak;ID:99737', '16850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16850', '112', '18727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.04.99737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18728', '1079', '1', 'Qaḑā'' ad Dīwānīyah', 'IQ.17.99763', 'ASCII:Qada'' ad Diwaniyah;ID:99763', '16851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16851', '112', '18728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.17.99763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18729', '1079', '1', 'Qaḑā'' Abū Şukhayr', 'IQ.17.99833', 'ASCII:Qada'' Abu Sukhayr;ID:99833', '16852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16852', '112', '18729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.17.99833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18730', '1079', '1', 'Qaḑā” Abū al Khaşīb', 'IQ.02.100049', 'ASCII:Qada" Abu al Khasib;ID:100049', '16853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16853', '112', '18730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.02.100049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18731', '1079', '1', 'Qaḑā’ aş Şuwīrah', 'IQ.16.6754638', 'ASCII:Qada'' as Suwirah;ID:6754638', '16854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16854', '112', '18731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.16.6754638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18732', '1079', '1', 'Qaḑā’ Ḩadīthah', 'IQ.01.6765480', 'ASCII:Qada'' Hadithah;ID:6765480', '16855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16855', '112', '18732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.01.6765480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18733', '1079', '1', 'Qaḑā’ al Ḩawījah', 'IQ.13.6770659', 'ASCII:Qada'' al Hawijah;ID:6770659', '16856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16856', '112', '18733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.13.6770659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18734', '1079', '1', 'Qaḑā’ al Kūfah', 'IQ.17.6781281', 'ASCII:Qada'' al Kufah;ID:6781281', '16857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16857', '112', '18734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.17.6781281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18735', '1079', '1', 'Qaḑā’ ad Dawr', 'IQ.18.6783103', 'ASCII:Qada'' ad Dawr;ID:6783103', '16858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16858', '112', '18735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.18.6783103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18736', '1079', '1', 'Qaḑā’ ash Sharqāţ', 'IQ.18.6804454', 'ASCII:Qada'' ash Sharqat;ID:6804454', '16859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16859', '112', '18736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.18.6804454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18737', '1079', '1', 'Qaḑā’ Balad', 'IQ.07.6805736', 'ASCII:Qada'' Balad;ID:6805736', '16860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16860', '112', '18737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.07.6805736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18738', '1079', '1', 'Qaḑā’ al Maḩāwīl', 'IQ.06.6818313', 'ASCII:Qada'' al Mahawil;ID:6818313', '16861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16861', '112', '18738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.06.6818313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18739', '1079', '1', 'Qaḑā’ al Ḩamzah', 'IQ.04.6850588', 'ASCII:Qada'' al Hamzah;ID:6850588', '16862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16862', '112', '18739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.04.6850588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18740', '1079', '1', 'Qaḑā’ Bayjī', 'IQ.18.6872046', 'ASCII:Qada'' Bayji;ID:6872046', '16863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16863', '112', '18740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IQ.18.6872046» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18741', '1079', '1', 'Khesht Va Kamārej', 'IR.07.44036', 'ASCII:Khesht Va Kamarej;ID:44036', '16864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16864', '112', '18741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.44036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18742', '1079', '1', 'Mo`ammareh', 'IR.15.44970', 'ASCII:Mo`ammareh;ID:44970', '16865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16865', '112', '18742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.44970» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18743', '1079', '1', 'Arvand Kenār', 'IR.15.45060', 'ASCII:Arvand Kenar;ID:45060', '16866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16866', '112', '18743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.45060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18744', '1079', '1', 'Shahrestān-e Sīrjān', 'IR.29.66575', 'ASCII:Shahrestan-e Sirjan;ID:66575', '16867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16867', '112', '18744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.66575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18745', '1079', '1', 'Shahrestān-e Fasā', 'IR.07.68471', 'ASCII:Shahrestan-e Fasa;ID:68471', '16868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16868', '112', '18745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.68471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18746', '1079', '1', 'Shahrestān-e Badreh', 'IR.10.112941', 'ASCII:Shahrestan-e Badreh;ID:112941', '16869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16869', '112', '18746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.10.112941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18747', '1079', '1', 'Shahrestān-e Naţanz', 'IR.28.122490', 'ASCII:Shahrestan-e Natanz;ID:122490', '16870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16870', '112', '18747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.122490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18748', '1079', '1', 'Mamasanī', 'IR.07.125034', 'ASCII:Mamasani;ID:125034', '16871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16871', '112', '18748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.125034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18749', '1079', '1', 'Delfān', 'IR.23.401611', 'ASCII:Delfan;ID:401611', '16872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16872', '112', '18749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.23.401611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18750', '1079', '1', 'Shahrestān-e Āz̄ar Shahr', 'IR.33.449425', 'ASCII:Shahrestan-e Azar Shahr;ID:449425', '16873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16873', '112', '18750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18751', '1079', '1', 'Shahrestān-e Eskū', 'IR.33.449426', 'ASCII:Shahrestan-e Esku;ID:449426', '16874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16874', '112', '18751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18752', '1079', '1', 'Shahrestān-e Ahar', 'IR.33.449427', 'ASCII:Shahrestan-e Ahar;ID:449427', '16875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16875', '112', '18752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18753', '1079', '1', 'Shahrestān-e Bostanābād', 'IR.33.449428', 'ASCII:Shahrestan-e Bostanabad;ID:449428', '16876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16876', '112', '18753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18754', '1079', '1', 'Shahrestān-e Bonāb', 'IR.33.449429', 'ASCII:Shahrestan-e Bonab;ID:449429', '16877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16877', '112', '18754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18755', '1079', '1', 'Shahrestān-e Tabrīz', 'IR.33.449430', 'ASCII:Shahrestan-e Tabriz;ID:449430', '16878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16878', '112', '18755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18756', '1079', '1', 'Shahrestān-e Jolfā', 'IR.33.449431', 'ASCII:Shahrestan-e Jolfa;ID:449431', '16879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16879', '112', '18756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18757', '1079', '1', 'Shahrestān-e Chārāvīmāq', 'IR.33.449432', 'ASCII:Shahrestan-e Charavimaq;ID:449432', '16880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16880', '112', '18757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18758', '1079', '1', 'Shahrestān-e Sarāb', 'IR.33.449433', 'ASCII:Shahrestan-e Sarab;ID:449433', '16881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16881', '112', '18758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18759', '1079', '1', 'Shahrestān-e Shabastar', 'IR.33.449434', 'ASCII:Shahrestan-e Shabastar;ID:449434', '16882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16882', '112', '18759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449434» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18760', '1079', '1', 'Shahrestān-e `Ajab Shīr', 'IR.33.449435', 'ASCII:Shahrestan-e `Ajab Shir;ID:449435', '16883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16883', '112', '18760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18761', '1079', '1', 'Shahrestān-e Koleybar', 'IR.33.449436', 'ASCII:Shahrestan-e Koleybar;ID:449436', '16884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16884', '112', '18761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18762', '1079', '1', 'Shahrestān-e Marāgheh', 'IR.33.449437', 'ASCII:Shahrestan-e Maragheh;ID:449437', '16885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16885', '112', '18762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18763', '1079', '1', 'Shahrestān-e Marand', 'IR.33.449438', 'ASCII:Shahrestan-e Marand;ID:449438', '16886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16886', '112', '18763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18764', '1079', '1', 'Shahrestān-e Malekān', 'IR.33.449439', 'ASCII:Shahrestan-e Malekan;ID:449439', '16887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16887', '112', '18764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18765', '1079', '1', 'Shahrestān-e Mīāneh', 'IR.33.449440', 'ASCII:Shahrestan-e Mianeh;ID:449440', '16888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16888', '112', '18765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18766', '1079', '1', 'Shahrestān-e Herīs', 'IR.33.449441', 'ASCII:Shahrestan-e Heris;ID:449441', '16889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16889', '112', '18766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18767', '1079', '1', 'Shahrestān-e Varzaqān', 'IR.33.449442', 'ASCII:Shahrestan-e Varzaqan;ID:449442', '16890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16890', '112', '18767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18768', '1079', '1', 'Shahrestān-e Hashtrūd', 'IR.33.449443', 'ASCII:Shahrestan-e Hashtrud;ID:449443', '16891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16891', '112', '18768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.33.449443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18769', '1079', '1', 'Shahrestān-e Orūmīyeh', 'IR.01.449444', 'ASCII:Shahrestan-e Orumiyeh;ID:449444', '16892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16892', '112', '18769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18770', '1079', '1', 'Shahrestān-e Oshnovīyeh', 'IR.01.449445', 'ASCII:Shahrestan-e Oshnoviyeh;ID:449445', '16893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16893', '112', '18770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18771', '1079', '1', 'Shahrestān-e Būkān', 'IR.01.449446', 'ASCII:Shahrestan-e Bukan;ID:449446', '16894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16894', '112', '18771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18772', '1079', '1', 'Shahrestān-e Pīrānshahr', 'IR.01.449447', 'ASCII:Shahrestan-e Piranshahr;ID:449447', '16895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16895', '112', '18772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18773', '1079', '1', 'Shahrestān-e Takāb', 'IR.01.449448', 'ASCII:Shahrestan-e Takab;ID:449448', '16896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16896', '112', '18773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18774', '1079', '1', 'Shahrestān-e Chāldarān', 'IR.01.449449', 'ASCII:Shahrestan-e Chaldaran;ID:449449', '16897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16897', '112', '18774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449449» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18775', '1079', '1', 'Shahrestān-e Khvoy', 'IR.01.449450', 'ASCII:Shahrestan-e Khvoy;ID:449450', '16898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16898', '112', '18775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18776', '1079', '1', 'Shahrestān-e Sardasht', 'IR.01.449451', 'ASCII:Shahrestan-e Sardasht;ID:449451', '16899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16899', '112', '18776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18777', '1079', '1', 'Shahrestān-e Salmās', 'IR.01.449452', 'ASCII:Shahrestan-e Salmas;ID:449452', '16900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16900', '112', '18777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18778', '1079', '1', 'Shahrestān-e Shāhīn Dezh', 'IR.01.449453', 'ASCII:Shahrestan-e Shahin Dezh;ID:449453', '16901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16901', '112', '18778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18779', '1079', '1', 'Shahrestān-e Mākū', 'IR.01.449454', 'ASCII:Shahrestan-e Maku;ID:449454', '16902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16902', '112', '18779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18780', '1079', '1', 'Shahrestān-e Mahābād', 'IR.01.449455', 'ASCII:Shahrestan-e Mahabad;ID:449455', '16903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16903', '112', '18780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18781', '1079', '1', 'Shahrestān-e Mīāndoāb', 'IR.01.449456', 'ASCII:Shahrestan-e Miandoab;ID:449456', '16904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16904', '112', '18781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18782', '1079', '1', 'Shahrestān-e Noqdeh', 'IR.01.449457', 'ASCII:Shahrestan-e Noqdeh;ID:449457', '16905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16905', '112', '18782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.01.449457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18783', '1079', '1', 'Shahrestān-e Ābadānān', 'IR.10.449458', 'ASCII:Shahrestan-e Abadanan;ID:449458', '16906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16906', '112', '18783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.10.449458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18784', '1079', '1', 'Shahrestān-e Īlām', 'IR.10.449459', 'ASCII:Shahrestan-e Ilam;ID:449459', '16907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16907', '112', '18784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.10.449459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18785', '1079', '1', 'Shahrestān-e Eyvān', 'IR.10.449460', 'ASCII:Shahrestan-e Eyvan;ID:449460', '16908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16908', '112', '18785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.10.449460» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18786', '1079', '1', 'Shahrestān-e Darrehshahr', 'IR.10.449461', 'ASCII:Shahrestan-e Darrehshahr;ID:449461', '16909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16909', '112', '18786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.10.449461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18787', '1079', '1', 'Shahrestān-e Dehlorān', 'IR.10.449462', 'ASCII:Shahrestan-e Dehloran;ID:449462', '16910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16910', '112', '18787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.10.449462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18788', '1079', '1', 'Shahrestān-e Shīrvān va Chardāval', 'IR.10.449463', 'ASCII:Shahrestan-e Shirvan va Chardaval;ID:449463', '16911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16911', '112', '18788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.10.449463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18789', '1079', '1', 'Shahrestān-e Mehrān', 'IR.10.449464', 'ASCII:Shahrestan-e Mehran;ID:449464', '16912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16912', '112', '18789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.10.449464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18790', '1079', '1', 'Shahrestān-e Ardabīl', 'IR.32.449465', 'ASCII:Shahrestan-e Ardabil;ID:449465', '16913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16913', '112', '18790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.32.449465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18791', '1079', '1', 'Shahrestān-e Bīleh Savār', 'IR.32.449466', 'ASCII:Shahrestan-e Bileh Savar;ID:449466', '16914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16914', '112', '18791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.32.449466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18792', '1079', '1', 'Shahrestān-e Pārsābād', 'IR.32.449467', 'ASCII:Shahrestan-e Parsabad;ID:449467', '16915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16915', '112', '18792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.32.449467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18793', '1079', '1', 'Shahrestān-e Khalkhāl', 'IR.32.449468', 'ASCII:Shahrestan-e Khalkhal;ID:449468', '16916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16916', '112', '18793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.32.449468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18794', '1079', '1', 'Shahrestān-e Kūs̄er', 'IR.32.449469', 'ASCII:Shahrestan-e Kuser;ID:449469', '16917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16917', '112', '18794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.32.449469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18795', '1079', '1', 'Shahrestān-e Garmī', 'IR.32.449470', 'ASCII:Shahrestan-e Garmi;ID:449470', '16918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16918', '112', '18795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.32.449470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18796', '1079', '1', 'Shahrestān-e Meshgīnshahr', 'IR.32.449471', 'ASCII:Shahrestan-e Meshginshahr;ID:449471', '16919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16919', '112', '18796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.32.449471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18797', '1079', '1', 'Shahrestān-e Namīn', 'IR.32.449472', 'ASCII:Shahrestan-e Namin;ID:449472', '16920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16920', '112', '18797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.32.449472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18798', '1079', '1', 'Shahrestān-e Neyr', 'IR.32.449473', 'ASCII:Shahrestan-e Neyr;ID:449473', '16921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16921', '112', '18798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.32.449473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18799', '1079', '1', 'Shahrestān-e Ārān va Bīdgol', 'IR.28.449474', 'ASCII:Shahrestan-e Aran va Bidgol;ID:449474', '16922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16922', '112', '18799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18800', '1079', '1', 'Shahrestān-e Ardestān', 'IR.28.449475', 'ASCII:Shahrestan-e Ardestan;ID:449475', '16923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16923', '112', '18800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449475» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18801', '1079', '1', 'Shahrestān-e Eşfaḩān', 'IR.28.449476', 'ASCII:Shahrestan-e Esfahan;ID:449476', '16924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16924', '112', '18801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18802', '1079', '1', 'Shahrestān-e Barkhvār va Meymeh', 'IR.28.449477', 'ASCII:Shahrestan-e Barkhvar va Meymeh;ID:449477', '16925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16925', '112', '18802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18803', '1079', '1', 'Shahrestān-e Tīrān va Kārūn', 'IR.28.449478', 'ASCII:Shahrestan-e Tiran va Karun;ID:449478', '16926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16926', '112', '18803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18804', '1079', '1', 'Shahrestān-e Chādagān', 'IR.28.449479', 'ASCII:Shahrestan-e Chadagan;ID:449479', '16927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16927', '112', '18804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18805', '1079', '1', 'Shahrestān-e Khomeynīshahr', 'IR.28.449480', 'ASCII:Shahrestan-e Khomeynishahr;ID:449480', '16928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16928', '112', '18805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18806', '1079', '1', 'Shahrestān-e Khvānsār', 'IR.28.449481', 'ASCII:Shahrestan-e Khvansar;ID:449481', '16929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16929', '112', '18806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18807', '1079', '1', 'Shahrestān-e Semīrom', 'IR.28.449482', 'ASCII:Shahrestan-e Semirom;ID:449482', '16930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16930', '112', '18807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18808', '1079', '1', 'Shahrestān-e Semīrom-e Soflá', 'IR.28.449483', 'ASCII:Shahrestan-e Semirom-e Sofla;ID:449483', '16931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16931', '112', '18808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18809', '1079', '1', 'Shahrestān-e Shahreẕā', 'IR.28.449484', 'ASCII:Shahrestan-e Shahreza;ID:449484', '16932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16932', '112', '18809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18810', '1079', '1', 'Shahrestān-e Farīdan', 'IR.28.449485', 'ASCII:Shahrestan-e Faridan;ID:449485', '16933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16933', '112', '18810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18811', '1079', '1', 'Shahrestān-e Farīdūnshahr', 'IR.28.449486', 'ASCII:Shahrestan-e Faridunshahr;ID:449486', '16934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16934', '112', '18811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18812', '1079', '1', 'Shahrestān-e Falāvarjān', 'IR.28.449487', 'ASCII:Shahrestan-e Falavarjan;ID:449487', '16935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16935', '112', '18812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18813', '1079', '1', 'Shahrestān-e Kāshān', 'IR.28.449488', 'ASCII:Shahrestan-e Kashan;ID:449488', '16936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16936', '112', '18813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18814', '1079', '1', 'Shahrestān-e Golpāyegān', 'IR.28.449489', 'ASCII:Shahrestan-e Golpayegan;ID:449489', '16937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16937', '112', '18814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18815', '1079', '1', 'Shahrestān-e Lanjān', 'IR.28.449490', 'ASCII:Shahrestan-e Lanjan;ID:449490', '16938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16938', '112', '18815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18816', '1079', '1', 'Shahrestān-e Mobārakeh', 'IR.28.449491', 'ASCII:Shahrestan-e Mobarakeh;ID:449491', '16939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16939', '112', '18816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18817', '1079', '1', 'Shahrestān-e Nā''īn', 'IR.28.449492', 'ASCII:Shahrestan-e Na''in;ID:449492', '16940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16940', '112', '18817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18818', '1079', '1', 'Shahrestān-e Najafābād', 'IR.28.449493', 'ASCII:Shahrestan-e Najafabad;ID:449493', '16941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16941', '112', '18818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18819', '1079', '1', 'Shahrestān-e Naţanz', 'IR.28.449494', 'ASCII:Shahrestan-e Natanz;ID:449494', '16942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16942', '112', '18819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.28.449494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18820', '1079', '1', 'Shahrestān-e Bandar-e Būshehr', 'IR.22.449495', 'ASCII:Shahrestan-e Bandar-e Bushehr;ID:449495', '16943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16943', '112', '18820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.22.449495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18821', '1079', '1', 'Shahrestān-e Tangestān', 'IR.22.449496', 'ASCII:Shahrestan-e Tangestan;ID:449496', '16944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16944', '112', '18821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.22.449496» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18822', '1079', '1', 'Shahrestān-e Jam', 'IR.22.449497', 'ASCII:Shahrestan-e Jam;ID:449497', '16945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16945', '112', '18822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.22.449497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18823', '1079', '1', 'Shahrestān-e Dashtestān', 'IR.22.449498', 'ASCII:Shahrestan-e Dashtestan;ID:449498', '16946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16946', '112', '18823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.22.449498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18824', '1079', '1', 'Shahrestān-e Dashtī', 'IR.22.449499', 'ASCII:Shahrestan-e Dashti;ID:449499', '16947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16947', '112', '18824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.22.449499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18825', '1079', '1', 'Shahrestān-e Deyr', 'IR.22.449500', 'ASCII:Shahrestan-e Deyr;ID:449500', '16948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16948', '112', '18825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.22.449500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18826', '1079', '1', 'Shahrestān-e Deylam', 'IR.22.449501', 'ASCII:Shahrestan-e Deylam;ID:449501', '16949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16949', '112', '18826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.22.449501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18827', '1079', '1', 'Shahrestān-e Kangān', 'IR.22.449502', 'ASCII:Shahrestan-e Kangan;ID:449502', '16950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16950', '112', '18827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.22.449502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18828', '1079', '1', 'Shahrestān-e Ganāveh', 'IR.22.449503', 'ASCII:Shahrestan-e Ganaveh;ID:449503', '16951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16951', '112', '18828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.22.449503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18829', '1079', '1', 'Shahrestān-e Pākdasht', 'IR.26.449505', 'ASCII:Shahrestan-e Pakdasht;ID:449505', '16952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16952', '112', '18829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18830', '1079', '1', 'Shahrestān-e Tehrān', 'IR.26.449506', 'ASCII:Shahrestan-e Tehran;ID:449506', '16953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16953', '112', '18830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18831', '1079', '1', 'Shahrestān-e Damāvand', 'IR.26.449507', 'ASCII:Shahrestan-e Damavand;ID:449507', '16954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16954', '112', '18831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18832', '1079', '1', 'Shahrestān-e Robāţ-e Karīm', 'IR.26.449508', 'ASCII:Shahrestan-e Robat-e Karim;ID:449508', '16955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16955', '112', '18832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18833', '1079', '1', 'Shahrestān-e Rey', 'IR.26.449509', 'ASCII:Shahrestan-e Rey;ID:449509', '16956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16956', '112', '18833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18834', '1079', '1', 'Shahrestān-e Savājbolāgh', 'IR.26.449510', 'ASCII:Shahrestan-e Savajbolagh;ID:449510', '16957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16957', '112', '18834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18835', '1079', '1', 'Shahrestān-e Shemīrānāt', 'IR.26.449511', 'ASCII:Shahrestan-e Shemiranat;ID:449511', '16958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16958', '112', '18835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18836', '1079', '1', 'Shahrestān-e Shahrīār', 'IR.26.449512', 'ASCII:Shahrestan-e Shahriar;ID:449512', '16959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16959', '112', '18836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18837', '1079', '1', 'Shahrestān-e Fīrūzkūh', 'IR.26.449513', 'ASCII:Shahrestan-e Firuzkuh;ID:449513', '16960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16960', '112', '18837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18838', '1079', '1', 'Shahrestān-e Karaj', 'IR.26.449514', 'ASCII:Shahrestan-e Karaj;ID:449514', '16961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16961', '112', '18838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18839', '1079', '1', 'Shahrestān-e Naz̧arābād', 'IR.26.449515', 'ASCII:Shahrestan-e Nazarabad;ID:449515', '16962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16962', '112', '18839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18840', '1079', '1', 'Shahrestān-e Varāmīn', 'IR.26.449516', 'ASCII:Shahrestan-e Varamin;ID:449516', '16963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16963', '112', '18840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.26.449516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18841', '1079', '1', 'Shahrestān-e Ardal', 'IR.03.449517', 'ASCII:Shahrestan-e Ardal;ID:449517', '16964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16964', '112', '18841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.03.449517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18842', '1079', '1', 'Shahrestān-e Borūjen', 'IR.03.449518', 'ASCII:Shahrestan-e Borujen;ID:449518', '16965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16965', '112', '18842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.03.449518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18843', '1079', '1', 'Shahrestān-e Shahr-e Kord', 'IR.03.449519', 'ASCII:Shahrestan-e Shahr-e Kord;ID:449519', '16966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16966', '112', '18843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.03.449519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18844', '1079', '1', 'Shahrestān-e Fāresān', 'IR.03.449520', 'ASCII:Shahrestan-e Faresan;ID:449520', '16967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16967', '112', '18844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.03.449520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18845', '1079', '1', 'Shahrestān-e Kūhrang', 'IR.03.449521', 'ASCII:Shahrestan-e Kuhrang;ID:449521', '16968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16968', '112', '18845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.03.449521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18846', '1079', '1', 'Shahrestān-e Lordegān', 'IR.03.449522', 'ASCII:Shahrestan-e Lordegan;ID:449522', '16969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16969', '112', '18846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.03.449522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18847', '1079', '1', 'Shahrestān-e Bīrjand', 'IR.41.449523', 'ASCII:Shahrestan-e Birjand;ID:449523', '16970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16970', '112', '18847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.41.449523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18848', '1079', '1', 'Shahrestān-e Sar Bīsheh', 'IR.41.449524', 'ASCII:Shahrestan-e Sar Bisheh;ID:449524', '16971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16971', '112', '18848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.41.449524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18849', '1079', '1', 'Shahrestān-e Bardeskan', 'IR.42.449525', 'ASCII:Shahrestan-e Bardeskan;ID:449525', '16972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16972', '112', '18849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18850', '1079', '1', 'Shahrestān-e Torbat-e Ḩeydarīyeh', 'IR.42.449526', 'ASCII:Shahrestan-e Torbat-e Heydariyeh;ID:449526', '16973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16973', '112', '18850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18851', '1079', '1', 'Shahrestān-e Chenārān', 'IR.42.449527', 'ASCII:Shahrestan-e Chenaran;ID:449527', '16974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16974', '112', '18851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18852', '1079', '1', 'Shahrestān-e Khalīlābād', 'IR.42.449528', 'ASCII:Shahrestan-e Khalilabad;ID:449528', '16975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16975', '112', '18852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18853', '1079', '1', 'Shahrestān-e Dargez', 'IR.42.449529', 'ASCII:Shahrestan-e Dargez;ID:449529', '16976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16976', '112', '18853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18854', '1079', '1', 'Shahrestān-e Rashtkhvār', 'IR.42.449530', 'ASCII:Shahrestan-e Rashtkhvar;ID:449530', '16977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16977', '112', '18854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18855', '1079', '1', 'Shahrestān-e Sabzevār', 'IR.42.449531', 'ASCII:Shahrestan-e Sabzevar;ID:449531', '16978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16978', '112', '18855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18856', '1079', '1', 'Shahrestān-e Ferdows', 'IR.42.449532', 'ASCII:Shahrestan-e Ferdows;ID:449532', '16979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16979', '112', '18856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18857', '1079', '1', 'Shahrestān-e Farīmān', 'IR.42.449533', 'ASCII:Shahrestan-e Fariman;ID:449533', '16980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16980', '112', '18857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18858', '1079', '1', 'Shahrestān-e Qā’enāt', 'IR.42.449534', 'ASCII:Shahrestan-e Qa''enat;ID:449534', '16981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16981', '112', '18858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18859', '1079', '1', 'Shahrestān-e Qūchān', 'IR.42.449535', 'ASCII:Shahrestan-e Quchan;ID:449535', '16982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16982', '112', '18859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18860', '1079', '1', 'Shahrestān-e Kāshmar', 'IR.42.449536', 'ASCII:Shahrestan-e Kashmar;ID:449536', '16983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16983', '112', '18860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18861', '1079', '1', 'Shahrestān-e Ganābād', 'IR.42.449537', 'ASCII:Shahrestan-e Ganabad;ID:449537', '16984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16984', '112', '18861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449537» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18862', '1079', '1', 'Shahrestān-e Mashhad', 'IR.42.449538', 'ASCII:Shahrestan-e Mashhad;ID:449538', '16985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16985', '112', '18862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18863', '1079', '1', 'Shahrestān-e Neyshābūr', 'IR.42.449539', 'ASCII:Shahrestan-e Neyshabur;ID:449539', '16986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16986', '112', '18863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.449539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18864', '1079', '1', 'Shahrestān-e Esfarāyen', 'IR.43.449540', 'ASCII:Shahrestan-e Esfarayen;ID:449540', '16987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16987', '112', '18864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.43.449540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18865', '1079', '1', 'Shahrestān-e Bojnūrd', 'IR.43.449541', 'ASCII:Shahrestan-e Bojnurd;ID:449541', '16988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16988', '112', '18865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.43.449541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18866', '1079', '1', 'Shahrestān-e Jājarm', 'IR.43.449542', 'ASCII:Shahrestan-e Jajarm;ID:449542', '16989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16989', '112', '18866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.43.449542» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18867', '1079', '1', 'Shahrestān-e Shīrvān', 'IR.43.449543', 'ASCII:Shahrestan-e Shirvan;ID:449543', '16990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16990', '112', '18867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.43.449543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18868', '1079', '1', 'Shahrestān-e Ābādān', 'IR.15.449544', 'ASCII:Shahrestan-e Abadan;ID:449544', '16991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16991', '112', '18868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18869', '1079', '1', 'Shahrestān-e Omīdīyeh', 'IR.15.449545', 'ASCII:Shahrestan-e Omidiyeh;ID:449545', '16992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16992', '112', '18869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18870', '1079', '1', 'Shahrestān-e Andīmeshk', 'IR.15.449546', 'ASCII:Shahrestan-e Andimeshk;ID:449546', '16993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16993', '112', '18870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18871', '1079', '1', 'Shahrestān-e Ahvāz', 'IR.15.449547', 'ASCII:Shahrestan-e Ahvaz;ID:449547', '16994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16994', '112', '18871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18872', '1079', '1', 'Shahrestān-e Īz̄eh', 'IR.15.449548', 'ASCII:Shahrestan-e Izeh;ID:449548', '16995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16995', '112', '18872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18873', '1079', '1', 'Shahrestān-e Bāgh-e Malek', 'IR.15.449549', 'ASCII:Shahrestan-e Bagh-e Malek;ID:449549', '16996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16996', '112', '18873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449549» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18874', '1079', '1', 'Shahrestān-e Bandar-e Māhshahr', 'IR.15.449550', 'ASCII:Shahrestan-e Bandar-e Mahshahr;ID:449550', '16997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16997', '112', '18874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18875', '1079', '1', 'Shahrestān-e Behbahān', 'IR.15.449551', 'ASCII:Shahrestan-e Behbahan;ID:449551', '16998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16998', '112', '18875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18876', '1079', '1', 'Shahrestān-e Khorramshahr', 'IR.15.449552', 'ASCII:Shahrestan-e Khorramshahr;ID:449552', '16999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('16999', '112', '18876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18877', '1079', '1', 'Shahrestān-e Dezfūl', 'IR.15.449553', 'ASCII:Shahrestan-e Dezful;ID:449553', '17000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17000', '112', '18877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18878', '1079', '1', 'Shahrestān-e Dasht-e Āzādegān', 'IR.15.449554', 'ASCII:Shahrestan-e Dasht-e Azadegan;ID:449554', '17001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17001', '112', '18878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18879', '1079', '1', 'Shahrestān-e Rāmhormoz', 'IR.15.449555', 'ASCII:Shahrestan-e Ramhormoz;ID:449555', '17002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17002', '112', '18879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18880', '1079', '1', 'Shahrestān-e Shādegān', 'IR.15.449556', 'ASCII:Shahrestan-e Shadegan;ID:449556', '17003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17003', '112', '18880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18881', '1079', '1', 'Shahrestān-e Shūsh', 'IR.15.449557', 'ASCII:Shahrestan-e Shush;ID:449557', '17004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17004', '112', '18881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18882', '1079', '1', 'Shahrestān-e Shūshtar', 'IR.15.449558', 'ASCII:Shahrestan-e Shushtar;ID:449558', '17005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17005', '112', '18882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18883', '1079', '1', 'Shahrestān-e Lālī', 'IR.15.449559', 'ASCII:Shahrestan-e Lali;ID:449559', '17006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17006', '112', '18883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18884', '1079', '1', 'Shahrestān-e Masjed-e Soleymān', 'IR.15.449560', 'ASCII:Shahrestan-e Masjed-e Soleyman;ID:449560', '17007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17007', '112', '18884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18885', '1079', '1', 'Shahrestān-e Hendījān', 'IR.15.449561', 'ASCII:Shahrestan-e Hendijan;ID:449561', '17008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17008', '112', '18885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.15.449561» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18886', '1079', '1', 'Shahrestān-e Abhar', 'IR.36.449562', 'ASCII:Shahrestan-e Abhar;ID:449562', '17009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17009', '112', '18886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.36.449562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18887', '1079', '1', 'Shahrestān-e Ījrūd', 'IR.36.449563', 'ASCII:Shahrestan-e Ijrud;ID:449563', '17010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17010', '112', '18887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.36.449563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18888', '1079', '1', 'Shahrestān-e Khodābandeh', 'IR.36.449564', 'ASCII:Shahrestan-e Khodabandeh;ID:449564', '17011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17011', '112', '18888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.36.449564» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18889', '1079', '1', 'Shahrestān-e Khorramdarreh', 'IR.36.449565', 'ASCII:Shahrestan-e Khorramdarreh;ID:449565', '17012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17012', '112', '18889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.36.449565» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18890', '1079', '1', 'Shahrestān-e Zanjān', 'IR.36.449566', 'ASCII:Shahrestan-e Zanjan;ID:449566', '17013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17013', '112', '18890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.36.449566» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18891', '1079', '1', 'Shahrestān-e Ţārem', 'IR.36.449567', 'ASCII:Shahrestan-e Tarem;ID:449567', '17014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17014', '112', '18891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.36.449567» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18892', '1079', '1', 'Shahrestān-e Māhneshān', 'IR.36.449568', 'ASCII:Shahrestan-e Mahneshan;ID:449568', '17015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17015', '112', '18892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.36.449568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18893', '1079', '1', 'Shahrestān-e Dāmghān', 'IR.25.449569', 'ASCII:Shahrestan-e Damghan;ID:449569', '17016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17016', '112', '18893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.25.449569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18894', '1079', '1', 'Shahrestān-e Semnān', 'IR.25.449570', 'ASCII:Shahrestan-e Semnan;ID:449570', '17017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17017', '112', '18894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.25.449570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18895', '1079', '1', 'Shahrestān-e Shāhrūd', 'IR.25.449571', 'ASCII:Shahrestan-e Shahrud;ID:449571', '17018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17018', '112', '18895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.25.449571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18896', '1079', '1', 'Shahrestān-e Garmsār', 'IR.25.449572', 'ASCII:Shahrestan-e Garmsar;ID:449572', '17019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17019', '112', '18896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.25.449572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18897', '1079', '1', 'Shahrestān-e Ābādeh', 'IR.07.449573', 'ASCII:Shahrestan-e Abadeh;ID:449573', '17020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17020', '112', '18897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18898', '1079', '1', 'Shahrestān-e Arsanjān', 'IR.07.449574', 'ASCII:Shahrestan-e Arsanjan;ID:449574', '17021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17021', '112', '18898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18899', '1079', '1', 'Shahrestān-e Estahbān', 'IR.07.449575', 'ASCII:Shahrestan-e Estahban;ID:449575', '17022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17022', '112', '18899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18900', '1079', '1', 'Shahrestān-e Bavānāt', 'IR.07.449577', 'ASCII:Shahrestan-e Bavanat;ID:449577', '17023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17023', '112', '18900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18901', '1079', '1', 'Shahrestān-e Jahrom', 'IR.07.449578', 'ASCII:Shahrestan-e Jahrom;ID:449578', '17024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17024', '112', '18901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18902', '1079', '1', 'Shahrestān-e Khorrambīd', 'IR.07.449579', 'ASCII:Shahrestan-e Khorrambid;ID:449579', '17025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17025', '112', '18902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18903', '1079', '1', 'Shahrestān-e Dārāb', 'IR.07.449580', 'ASCII:Shahrestan-e Darab;ID:449580', '17026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17026', '112', '18903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18904', '1079', '1', 'Shahrestān-e Zarrīndasht', 'IR.07.449581', 'ASCII:Shahrestan-e Zarrindasht;ID:449581', '17027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17027', '112', '18904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18905', '1079', '1', 'Shahrestān-e Sepīdān', 'IR.07.449582', 'ASCII:Shahrestan-e Sepidan;ID:449582', '17028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17028', '112', '18905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18906', '1079', '1', 'Shahrestān-e Shīrāz', 'IR.07.449583', 'ASCII:Shahrestan-e Shiraz;ID:449583', '17029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17029', '112', '18906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449583» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18907', '1079', '1', 'Shahrestān-e Farāshband', 'IR.07.449584', 'ASCII:Shahrestan-e Farashband;ID:449584', '17030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17030', '112', '18907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18908', '1079', '1', 'Shahrestān-e Fasā', 'IR.07.449585', 'ASCII:Shahrestan-e Fasa;ID:449585', '17031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17031', '112', '18908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18909', '1079', '1', 'Shahrestān-e Fīrūzābād', 'IR.07.449586', 'ASCII:Shahrestan-e Firuzabad;ID:449586', '17032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17032', '112', '18909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18910', '1079', '1', 'Shahrestān-e Qīr va Kārzīn', 'IR.07.449587', 'ASCII:Shahrestan-e Qir va Karzin;ID:449587', '17033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17033', '112', '18910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18911', '1079', '1', 'Shahrestān-e Kāzerūn', 'IR.07.449588', 'ASCII:Shahrestan-e Kazerun;ID:449588', '17034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17034', '112', '18911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18912', '1079', '1', 'Shahrestān-e Lārestān', 'IR.07.449589', 'ASCII:Shahrestan-e Larestan;ID:449589', '17035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17035', '112', '18912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18913', '1079', '1', 'Shahrestān-e Lāmard', 'IR.07.449590', 'ASCII:Shahrestan-e Lamard;ID:449590', '17036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17036', '112', '18913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18914', '1079', '1', 'Shahrestān-e Marvdasht', 'IR.07.449591', 'ASCII:Shahrestan-e Marvdasht;ID:449591', '17037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17037', '112', '18914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18915', '1079', '1', 'Shahrestān-e Mamasanī', 'IR.07.449592', 'ASCII:Shahrestan-e Mamasani;ID:449592', '17038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17038', '112', '18915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18916', '1079', '1', 'Shahrestān-e Mohr', 'IR.07.449593', 'ASCII:Shahrestan-e Mohr;ID:449593', '17039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17039', '112', '18916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18917', '1079', '1', 'Shahrestān-e Neyrīz', 'IR.07.449594', 'ASCII:Shahrestan-e Neyriz;ID:449594', '17040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17040', '112', '18917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.07.449594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18918', '1079', '1', 'Shahrestān-e Ābīk', 'IR.38.449595', 'ASCII:Shahrestan-e Abik;ID:449595', '17041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17041', '112', '18918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.38.449595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18919', '1079', '1', 'Shahrestān-e Bū’īn Zahrā', 'IR.38.449596', 'ASCII:Shahrestan-e Bu''in Zahra;ID:449596', '17042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17042', '112', '18919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.38.449596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18920', '1079', '1', 'Shahrestān-e Tākestān', 'IR.38.449597', 'ASCII:Shahrestan-e Takestan;ID:449597', '17043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17043', '112', '18920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.38.449597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18921', '1079', '1', 'Shahrestān-e Qazvīn', 'IR.38.449598', 'ASCII:Shahrestan-e Qazvin;ID:449598', '17044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17044', '112', '18921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.38.449598» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18922', '1079', '1', 'Shahrestān-e Qom', 'IR.39.449599', 'ASCII:Shahrestan-e Qom;ID:449599', '17045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17045', '112', '18922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.39.449599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18923', '1079', '1', 'Shahrestān-e Bāneh', 'IR.16.449600', 'ASCII:Shahrestan-e Baneh;ID:449600', '17046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17046', '112', '18923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.16.449600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18924', '1079', '1', 'Shahrestān-e Bījār', 'IR.16.449601', 'ASCII:Shahrestan-e Bijar;ID:449601', '17047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17047', '112', '18924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.16.449601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18925', '1079', '1', 'Shahrestān-e Dīvāndarreh', 'IR.16.449602', 'ASCII:Shahrestan-e Divandarreh;ID:449602', '17048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17048', '112', '18925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.16.449602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18926', '1079', '1', 'Shahrestān-e Sarvābād', 'IR.16.449603', 'ASCII:Shahrestan-e Sarvabad;ID:449603', '17049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17049', '112', '18926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.16.449603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18927', '1079', '1', 'Shahrestān-e Saqqez', 'IR.16.449604', 'ASCII:Shahrestan-e Saqqez;ID:449604', '17050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17050', '112', '18927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.16.449604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18928', '1079', '1', 'Shahrestān-e Sanandaj', 'IR.16.449605', 'ASCII:Shahrestan-e Sanandaj;ID:449605', '17051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17051', '112', '18928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.16.449605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18929', '1079', '1', 'Shahrestān-e Qorveh', 'IR.16.449606', 'ASCII:Shahrestan-e Qorveh;ID:449606', '17052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17052', '112', '18929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.16.449606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18930', '1079', '1', 'Shahrestān-e Kāmyārān', 'IR.16.449607', 'ASCII:Shahrestan-e Kamyaran;ID:449607', '17053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17053', '112', '18930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.16.449607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18931', '1079', '1', 'Shahrestān-e Marīvān', 'IR.16.449608', 'ASCII:Shahrestan-e Marivan;ID:449608', '17054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17054', '112', '18931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.16.449608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18932', '1079', '1', 'Shahrestān-e Bāft', 'IR.29.449609', 'ASCII:Shahrestan-e Baft;ID:449609', '17055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17055', '112', '18932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18933', '1079', '1', 'Shahrestān-e Bardsīr', 'IR.29.449610', 'ASCII:Shahrestan-e Bardsir;ID:449610', '17056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17056', '112', '18933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18934', '1079', '1', 'Shahrestān-e Bam', 'IR.29.449611', 'ASCII:Shahrestan-e Bam;ID:449611', '17057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17057', '112', '18934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18935', '1079', '1', 'Shahrestān-e Jīroft', 'IR.29.449612', 'ASCII:Shahrestan-e Jiroft;ID:449612', '17058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17058', '112', '18935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18936', '1079', '1', 'Shahrestān-e Rāvar', 'IR.29.449613', 'ASCII:Shahrestan-e Ravar;ID:449613', '17059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17059', '112', '18936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18937', '1079', '1', 'Shahrestān-e Rafsanjān', 'IR.29.449614', 'ASCII:Shahrestan-e Rafsanjan;ID:449614', '17060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17060', '112', '18937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18938', '1079', '1', 'Shahrestān-e Zarand', 'IR.29.449615', 'ASCII:Shahrestan-e Zarand;ID:449615', '17061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17061', '112', '18938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18939', '1079', '1', 'Shahrestān-e Sīrjān', 'IR.29.449616', 'ASCII:Shahrestan-e Sirjan;ID:449616', '17062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17062', '112', '18939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18940', '1079', '1', 'Shahrestān-e Shahr-e Bābak', 'IR.29.449617', 'ASCII:Shahrestan-e Shahr-e Babak;ID:449617', '17063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17063', '112', '18940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18941', '1079', '1', 'Shahrestān-e `Anbarābād', 'IR.29.449618', 'ASCII:Shahrestan-e `Anbarabad;ID:449618', '17064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17064', '112', '18941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18942', '1079', '1', 'Shahrestān-e Kermān', 'IR.29.449619', 'ASCII:Shahrestan-e Kerman;ID:449619', '17065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17065', '112', '18942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18943', '1079', '1', 'Shahrestān-e Kahnūj', 'IR.29.449620', 'ASCII:Shahrestan-e Kahnuj;ID:449620', '17066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17066', '112', '18943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18944', '1079', '1', 'Shahrestān-e Manūjān', 'IR.29.449621', 'ASCII:Shahrestan-e Manujan;ID:449621', '17067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17067', '112', '18944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.29.449621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18945', '1079', '1', 'Shahrestān-e Eslāmābād-e Gharb', 'IR.13.449622', 'ASCII:Shahrestan-e Eslamabad-e Gharb;ID:449622', '17068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17068', '112', '18945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18946', '1079', '1', 'Shahrestān-e Pāveh', 'IR.13.449623', 'ASCII:Shahrestan-e Paveh;ID:449623', '17069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17069', '112', '18946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18947', '1079', '1', 'Shahrestān-e S̄alās̄ Bābā Jānī', 'IR.13.449624', 'ASCII:Shahrestan-e Salas Baba Jani;ID:449624', '17070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17070', '112', '18947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18948', '1079', '1', 'Shahrestān-e Javānrūd', 'IR.13.449625', 'ASCII:Shahrestan-e Javanrud;ID:449625', '17071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17071', '112', '18948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18949', '1079', '1', 'Shahrestān-e Sar Pol-e Z̄ohāb', 'IR.13.449626', 'ASCII:Shahrestan-e Sar Pol-e Zohab;ID:449626', '17072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17072', '112', '18949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18950', '1079', '1', 'Shahrestān-e Sonqor', 'IR.13.449627', 'ASCII:Shahrestan-e Sonqor;ID:449627', '17073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17073', '112', '18950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18951', '1079', '1', 'Shahrestān-e Şaḩneh', 'IR.13.449628', 'ASCII:Shahrestan-e Sahneh;ID:449628', '17074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17074', '112', '18951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18952', '1079', '1', 'Shahrestān-e Qaşr-e Shīrīn', 'IR.13.449629', 'ASCII:Shahrestan-e Qasr-e Shirin;ID:449629', '17075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17075', '112', '18952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18953', '1079', '1', 'Shahrestān-e Kermānshāh', 'IR.13.449630', 'ASCII:Shahrestan-e Kermanshah;ID:449630', '17076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17076', '112', '18953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18954', '1079', '1', 'Shahrestān-e Kangāvar', 'IR.13.449631', 'ASCII:Shahrestan-e Kangavar;ID:449631', '17077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17077', '112', '18954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18955', '1079', '1', 'Shahrestān-e Gīlān-e Gharb', 'IR.13.449632', 'ASCII:Shahrestan-e Gilan-e Gharb;ID:449632', '17078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17078', '112', '18955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18956', '1079', '1', 'Shahrestān-e Hersīn', 'IR.13.449633', 'ASCII:Shahrestan-e Hersin;ID:449633', '17079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17079', '112', '18956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.13.449633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18957', '1079', '1', 'Shahrestān-e Būyer Aḩmad', 'IR.05.449634', 'ASCII:Shahrestan-e Buyer Ahmad;ID:449634', '17080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17080', '112', '18957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.05.449634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18958', '1079', '1', 'Shahrestān-e Danā', 'IR.05.449635', 'ASCII:Shahrestan-e Dana;ID:449635', '17081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17081', '112', '18958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.05.449635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18959', '1079', '1', 'Shahrestān-e Kohgīlūyeh', 'IR.05.449636', 'ASCII:Shahrestan-e Kohgiluyeh;ID:449636', '17082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17082', '112', '18959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.05.449636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18960', '1079', '1', 'Shahrestān-e Gachsārān', 'IR.05.449637', 'ASCII:Shahrestan-e Gachsaran;ID:449637', '17083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17083', '112', '18960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.05.449637» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18961', '1079', '1', 'Shahrestān-e Āzādshahr', 'IR.37.449638', 'ASCII:Shahrestan-e Azadshahr;ID:449638', '17084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17084', '112', '18961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18962', '1079', '1', 'Shahrestān-e Āq Qalā', 'IR.37.449639', 'ASCII:Shahrestan-e Aq Qala;ID:449639', '17085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17085', '112', '18962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18963', '1079', '1', 'Shahrestān-e Torkaman', 'IR.37.449640', 'ASCII:Shahrestan-e Torkaman;ID:449640', '17086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17086', '112', '18963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18964', '1079', '1', 'Shahrestān-e Bandar-e Gaz', 'IR.37.449641', 'ASCII:Shahrestan-e Bandar-e Gaz;ID:449641', '17087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17087', '112', '18964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18965', '1079', '1', 'Shahrestān-e Rāmīān', 'IR.37.449642', 'ASCII:Shahrestan-e Ramian;ID:449642', '17088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17088', '112', '18965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449642» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18966', '1079', '1', 'Shahrestān-e `Alīābād', 'IR.37.449643', 'ASCII:Shahrestan-e `Aliabad;ID:449643', '17089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17089', '112', '18966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449643» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18967', '1079', '1', 'Shahrestān-e Kord Kūy', 'IR.37.449644', 'ASCII:Shahrestan-e Kord Kuy;ID:449644', '17090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17090', '112', '18967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18968', '1079', '1', 'Shahrestān-e Kalāleh', 'IR.37.449645', 'ASCII:Shahrestan-e Kalaleh;ID:449645', '17091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17091', '112', '18968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18969', '1079', '1', 'Shahrestān-e Gorgān', 'IR.37.449646', 'ASCII:Shahrestan-e Gorgan;ID:449646', '17092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17092', '112', '18969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18970', '1079', '1', 'Shahrestān-e Gonbad-e Kāvūs', 'IR.37.449647', 'ASCII:Shahrestan-e Gonbad-e Kavus;ID:449647', '17093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17093', '112', '18970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449647» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18971', '1079', '1', 'Shahrestān-e Mīnūdasht', 'IR.37.449648', 'ASCII:Shahrestan-e Minudasht;ID:449648', '17094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17094', '112', '18971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.37.449648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18972', '1079', '1', 'Shahrestān-e Āstarā', 'IR.08.449649', 'ASCII:Shahrestan-e Astara;ID:449649', '17095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17095', '112', '18972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449649» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18973', '1079', '1', 'Shahrestān-e Āstāneh-ye Eshrafīyeh', 'IR.08.449650', 'ASCII:Shahrestan-e Astaneh-ye Eshrafiyeh;ID:449650', '17096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17096', '112', '18973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18974', '1079', '1', 'Shahrestān-e Amlash', 'IR.08.449651', 'ASCII:Shahrestan-e Amlash;ID:449651', '17097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17097', '112', '18974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18975', '1079', '1', 'Shahrestān-e Bandar-e Anzalī', 'IR.08.449652', 'ASCII:Shahrestan-e Bandar-e Anzali;ID:449652', '17098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17098', '112', '18975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18976', '1079', '1', 'Shahrestān-e Rasht', 'IR.08.449653', 'ASCII:Shahrestan-e Rasht;ID:449653', '17099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17099', '112', '18976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18977', '1079', '1', 'Shahrestān-e Raẕvānshahr', 'IR.08.449654', 'ASCII:Shahrestan-e Razvanshahr;ID:449654', '17100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17100', '112', '18977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18978', '1079', '1', 'Shahrestān-e Rūdbār', 'IR.08.449655', 'ASCII:Shahrestan-e Rudbar;ID:449655', '17101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17101', '112', '18978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18979', '1079', '1', 'Shahrestān-e Rūdsar', 'IR.08.449656', 'ASCII:Shahrestan-e Rudsar;ID:449656', '17102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17102', '112', '18979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18980', '1079', '1', 'Shahrestān-e Sīāhkal', 'IR.08.449657', 'ASCII:Shahrestan-e Siahkal;ID:449657', '17103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17103', '112', '18980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18981', '1079', '1', 'Shahrestān-e Shaft', 'IR.08.449658', 'ASCII:Shahrestan-e Shaft;ID:449658', '17104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17104', '112', '18981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18982', '1079', '1', 'Shahrestān-e Şowm`eh Sarā', 'IR.08.449659', 'ASCII:Shahrestan-e Sowm`eh Sara;ID:449659', '17105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17105', '112', '18982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18983', '1079', '1', 'Shahrestān-e Ţavālesh', 'IR.08.449660', 'ASCII:Shahrestan-e Tavalesh;ID:449660', '17106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17106', '112', '18983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18984', '1079', '1', 'Shahrestān-e Fūman', 'IR.08.449661', 'ASCII:Shahrestan-e Fuman;ID:449661', '17107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17107', '112', '18984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18985', '1079', '1', 'Shahrestān-e Lāhījān', 'IR.08.449662', 'ASCII:Shahrestan-e Lahijan;ID:449662', '17108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17108', '112', '18985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18986', '1079', '1', 'Shahrestān-e Langarūd', 'IR.08.449663', 'ASCII:Shahrestan-e Langarud;ID:449663', '17109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17109', '112', '18986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18987', '1079', '1', 'Shahrestān-e Māsāl', 'IR.08.449664', 'ASCII:Shahrestan-e Masal;ID:449664', '17110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17110', '112', '18987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.08.449664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18988', '1079', '1', 'Shahrestān-e Aznā', 'IR.23.449665', 'ASCII:Shahrestan-e Azna;ID:449665', '17111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17111', '112', '18988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.23.449665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18989', '1079', '1', 'Shahrestān-e Alīgūdarz', 'IR.23.449666', 'ASCII:Shahrestan-e Aligudarz;ID:449666', '17112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17112', '112', '18989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.23.449666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18990', '1079', '1', 'Shahrestān-e Borūjerd', 'IR.23.449667', 'ASCII:Shahrestan-e Borujerd;ID:449667', '17113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17113', '112', '18990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.23.449667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18991', '1079', '1', 'Shahrestān-e Pol-e Dokhtar', 'IR.23.449668', 'ASCII:Shahrestan-e Pol-e Dokhtar;ID:449668', '17114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17114', '112', '18991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.23.449668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18992', '1079', '1', 'Shahrestān-e Khorramābād', 'IR.23.449669', 'ASCII:Shahrestan-e Khorramabad;ID:449669', '17115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17115', '112', '18992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.23.449669» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18993', '1079', '1', 'Shahrestān-e Delfān', 'IR.23.449670', 'ASCII:Shahrestan-e Delfan;ID:449670', '17116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17116', '112', '18993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.23.449670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18994', '1079', '1', 'Shahrestān-e Dorūd', 'IR.23.449671', 'ASCII:Shahrestan-e Dorud;ID:449671', '17117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17117', '112', '18994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.23.449671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18995', '1079', '1', 'Shahrestān-e Selseleh', 'IR.23.449672', 'ASCII:Shahrestan-e Selseleh;ID:449672', '17118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17118', '112', '18995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.23.449672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18996', '1079', '1', 'Shahrestān-e Kūhdasht', 'IR.23.449673', 'ASCII:Shahrestan-e Kuhdasht;ID:449673', '17119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17119', '112', '18996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.23.449673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18997', '1079', '1', 'Shahrestān-e Āmol', 'IR.35.449674', 'ASCII:Shahrestan-e Amol;ID:449674', '17120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17120', '112', '18997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18998', '1079', '1', 'Shahrestān-e Bābol', 'IR.35.449675', 'ASCII:Shahrestan-e Babol;ID:449675', '17121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17121', '112', '18998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449675» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('18999', '1079', '1', 'Shahrestān-e Bābolsar', 'IR.35.449676', 'ASCII:Shahrestan-e Babolsar;ID:449676', '17122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17122', '112', '18999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449676» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19000', '1079', '1', 'Shahrestān-e Behshahr', 'IR.35.449677', 'ASCII:Shahrestan-e Behshahr;ID:449677', '17123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17123', '112', '19000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19001', '1079', '1', 'Shahrestān-e Tonekābon', 'IR.35.449678', 'ASCII:Shahrestan-e Tonekabon;ID:449678', '17124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17124', '112', '19001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19002', '1079', '1', 'Shahrestān-e Jūybār', 'IR.35.449679', 'ASCII:Shahrestan-e Juybar;ID:449679', '17125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17125', '112', '19002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19003', '1079', '1', 'Shahrestān-e Chālūs', 'IR.35.449680', 'ASCII:Shahrestan-e Chalus;ID:449680', '17126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17126', '112', '19003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19004', '1079', '1', 'Shahrestān-e Rāmsar', 'IR.35.449681', 'ASCII:Shahrestan-e Ramsar;ID:449681', '17127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17127', '112', '19004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19005', '1079', '1', 'Shahrestān-e Sārī', 'IR.35.449682', 'ASCII:Shahrestan-e Sari;ID:449682', '17128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17128', '112', '19005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19006', '1079', '1', 'Shahrestān-e Savād Kūh', 'IR.35.449683', 'ASCII:Shahrestan-e Savad Kuh;ID:449683', '17129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17129', '112', '19006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19007', '1079', '1', 'Shahrestān-e Qā’emshahr', 'IR.35.449684', 'ASCII:Shahrestan-e Qa''emshahr;ID:449684', '17130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17130', '112', '19007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19008', '1079', '1', 'Shahrestān-e Maḩmūdābād', 'IR.35.449685', 'ASCII:Shahrestan-e Mahmudabad;ID:449685', '17131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17131', '112', '19008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19009', '1079', '1', 'Shahrestān-e Nekā', 'IR.35.449686', 'ASCII:Shahrestan-e Neka;ID:449686', '17132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17132', '112', '19009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19010', '1079', '1', 'Shahrestān-e Nūr', 'IR.35.449687', 'ASCII:Shahrestan-e Nur;ID:449687', '17133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17133', '112', '19010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19011', '1079', '1', 'Shahrestān-e Nowshahr', 'IR.35.449688', 'ASCII:Shahrestan-e Nowshahr;ID:449688', '17134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17134', '112', '19011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.35.449688» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19012', '1079', '1', 'Shahrestān-e Āshtīān', 'IR.34.449689', 'ASCII:Shahrestan-e Ashtian;ID:449689', '17135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17135', '112', '19012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.34.449689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19013', '1079', '1', 'Shahrestān-e Ārāk', 'IR.34.449690', 'ASCII:Shahrestan-e Arak;ID:449690', '17136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17136', '112', '19013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.34.449690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19014', '1079', '1', 'Shahrestān-e Tafresh', 'IR.34.449691', 'ASCII:Shahrestan-e Tafresh;ID:449691', '17137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17137', '112', '19014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.34.449691» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19015', '1079', '1', 'Shahrestān-e Khomeyn', 'IR.34.449692', 'ASCII:Shahrestan-e Khomeyn;ID:449692', '17138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17138', '112', '19015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.34.449692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19016', '1079', '1', 'Shahrestān-e Delījān', 'IR.34.449693', 'ASCII:Shahrestan-e Delijan;ID:449693', '17139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17139', '112', '19016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.34.449693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19017', '1079', '1', 'Shahrestān-e Zarandīyeh', 'IR.34.449694', 'ASCII:Shahrestan-e Zarandiyeh;ID:449694', '17140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17140', '112', '19017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.34.449694» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19018', '1079', '1', 'Shahrestān-e Sāveh', 'IR.34.449695', 'ASCII:Shahrestan-e Saveh;ID:449695', '17141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17141', '112', '19018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.34.449695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19019', '1079', '1', 'Shahrestān-e Shāzand', 'IR.34.449696', 'ASCII:Shahrestan-e Shazand;ID:449696', '17142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17142', '112', '19019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.34.449696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19020', '1079', '1', 'Shahrestān-e Komījān', 'IR.34.449697', 'ASCII:Shahrestan-e Komijan;ID:449697', '17143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17143', '112', '19020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.34.449697» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19021', '1079', '1', 'Shahrestān-e Maḩallāt', 'IR.34.449698', 'ASCII:Shahrestan-e Mahallat;ID:449698', '17144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17144', '112', '19021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.34.449698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19022', '1079', '1', 'Shahrestān-e Abū Mūsá', 'IR.11.449699', 'ASCII:Shahrestan-e Abu Musa;ID:449699', '17145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17145', '112', '19022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.11.449699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19023', '1079', '1', 'Shahrestān-e Bastak', 'IR.11.449700', 'ASCII:Shahrestan-e Bastak;ID:449700', '17146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17146', '112', '19023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.11.449700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19024', '1079', '1', 'Shahrestān-e Bandar `Abbās', 'IR.11.449701', 'ASCII:Shahrestan-e Bandar `Abbas;ID:449701', '17147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17147', '112', '19024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.11.449701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19025', '1079', '1', 'Shahrestān-e Bandar-e Lengeh', 'IR.11.449702', 'ASCII:Shahrestan-e Bandar-e Lengeh;ID:449702', '17148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17148', '112', '19025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.11.449702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19026', '1079', '1', 'Shahrestān-e Jāsk', 'IR.11.449703', 'ASCII:Shahrestan-e Jask;ID:449703', '17149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17149', '112', '19026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.11.449703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19027', '1079', '1', 'Shahrestān-e Ḩājjīābād', 'IR.11.449704', 'ASCII:Shahrestan-e Hajjiabad;ID:449704', '17150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17150', '112', '19027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.11.449704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19028', '1079', '1', 'Shahrestān-e Rūdān', 'IR.11.449705', 'ASCII:Shahrestan-e Rudan;ID:449705', '17151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17151', '112', '19028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.11.449705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19029', '1079', '1', 'Shahrestān-e Qeshm', 'IR.11.449706', 'ASCII:Shahrestan-e Qeshm;ID:449706', '17152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17152', '112', '19029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.11.449706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19030', '1079', '1', 'Shahrestān-e Mīnāb', 'IR.11.449707', 'ASCII:Shahrestan-e Minab;ID:449707', '17153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17153', '112', '19030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.11.449707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19031', '1079', '1', 'Shahrestān-e Asadābād', 'IR.09.449708', 'ASCII:Shahrestan-e Asadabad;ID:449708', '17154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17154', '112', '19031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.09.449708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19032', '1079', '1', 'Shahrestān-e Bahār', 'IR.09.449709', 'ASCII:Shahrestan-e Bahar;ID:449709', '17155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17155', '112', '19032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.09.449709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19033', '1079', '1', 'Shahrestān-e Tūyserkān', 'IR.09.449710', 'ASCII:Shahrestan-e Tuyserkan;ID:449710', '17156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17156', '112', '19033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.09.449710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19034', '1079', '1', 'Shahrestān-e Razan', 'IR.09.449711', 'ASCII:Shahrestan-e Razan;ID:449711', '17157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17157', '112', '19034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.09.449711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19035', '1079', '1', 'Shahrestān-e Kabūdarāhang', 'IR.09.449712', 'ASCII:Shahrestan-e Kabudarahang;ID:449712', '17158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17158', '112', '19035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.09.449712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19036', '1079', '1', 'Shahrestān-e Malāyer', 'IR.09.449713', 'ASCII:Shahrestan-e Malayer;ID:449713', '17159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17159', '112', '19036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.09.449713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19037', '1079', '1', 'Shahrestān-e Nahāvand', 'IR.09.449714', 'ASCII:Shahrestan-e Nahavand;ID:449714', '17160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17160', '112', '19037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.09.449714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19038', '1079', '1', 'Shahrestān-e Hamadān', 'IR.09.449715', 'ASCII:Shahrestan-e Hamadan;ID:449715', '17161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17161', '112', '19038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.09.449715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19039', '1079', '1', 'Shahrestān-e Abarkūh', 'IR.40.449716', 'ASCII:Shahrestan-e Abarkuh;ID:449716', '17162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17162', '112', '19039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.40.449716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19040', '1079', '1', 'Shahrestān-e Ardakān', 'IR.40.449717', 'ASCII:Shahrestan-e Ardakan;ID:449717', '17163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17163', '112', '19040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.40.449717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19041', '1079', '1', 'Shahrestān-e Bāfq', 'IR.40.449718', 'ASCII:Shahrestan-e Bafq;ID:449718', '17164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17164', '112', '19041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.40.449718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19042', '1079', '1', 'Shahrestān-e Taft', 'IR.40.449719', 'ASCII:Shahrestan-e Taft;ID:449719', '17165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17165', '112', '19042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.40.449719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19043', '1079', '1', 'Shahrestān-e Khātem', 'IR.40.449720', 'ASCII:Shahrestan-e Khatem;ID:449720', '17166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17166', '112', '19043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.40.449720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19044', '1079', '1', 'Shahrestān-e Şadūq', 'IR.40.449721', 'ASCII:Shahrestan-e Saduq;ID:449721', '17167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17167', '112', '19044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.40.449721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19045', '1079', '1', 'Shahrestān-e Ţabas', 'IR.40.449722', 'ASCII:Shahrestan-e Tabas;ID:449722', '17168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17168', '112', '19045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.40.449722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19046', '1079', '1', 'Shahrestān-e Mehrīz', 'IR.40.449723', 'ASCII:Shahrestan-e Mehriz;ID:449723', '17169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17169', '112', '19046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.40.449723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19047', '1079', '1', 'Shahrestān-e Meybod', 'IR.40.449724', 'ASCII:Shahrestan-e Meybod;ID:449724', '17170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17170', '112', '19047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.40.449724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19048', '1079', '1', 'Shahrestān-e Yazd', 'IR.40.449725', 'ASCII:Shahrestan-e Yazd;ID:449725', '17171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17171', '112', '19048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.40.449725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19049', '1079', '1', 'Shahrestān-e Īrānshahr', 'IR.04.1158999', 'ASCII:Shahrestan-e Iranshahr;ID:1158999', '17172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17172', '112', '19049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.04.1158999» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19050', '1079', '1', 'Shahrestān-e Nahbandān', 'IR.41.1482419', 'ASCII:Shahrestan-e Nahbandan;ID:1482419', '17173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17173', '112', '19050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.41.1482419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19051', '1079', '1', 'Shahrestān-e Tāybād', 'IR.42.1482420', 'ASCII:Shahrestan-e Taybad;ID:1482420', '17174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17174', '112', '19051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.1482420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19052', '1079', '1', 'Shahrestān-e Torbat-e Jām', 'IR.42.1482421', 'ASCII:Shahrestan-e Torbat-e Jam;ID:1482421', '17175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17175', '112', '19052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.1482421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19053', '1079', '1', 'Shahrestān-e Khavāf', 'IR.42.1482426', 'ASCII:Shahrestan-e Khavaf;ID:1482426', '17176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17176', '112', '19053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.1482426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19054', '1079', '1', 'Shahrestān-e Sarakhs', 'IR.42.1482443', 'ASCII:Shahrestan-e Sarakhs;ID:1482443', '17177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17177', '112', '19054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.1482443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19055', '1079', '1', 'Shahrestān-e Kalāt', 'IR.42.1482469', 'ASCII:Shahrestan-e Kalat;ID:1482469', '17178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17178', '112', '19055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.42.1482469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19056', '1079', '1', 'Shahrestān-e Īrānshahr', 'IR.04.1482479', 'ASCII:Shahrestan-e Iranshahr;ID:1482479', '17179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17179', '112', '19056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.04.1482479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19057', '1079', '1', 'Shahrestān-e Chābahār', 'IR.04.1482480', 'ASCII:Shahrestan-e Chabahar;ID:1482480', '17180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17180', '112', '19057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.04.1482480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19058', '1079', '1', 'Shahrestān-e Khāsh', 'IR.04.1482481', 'ASCII:Shahrestan-e Khash;ID:1482481', '17181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17181', '112', '19058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.04.1482481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19059', '1079', '1', 'Shahrestān-e Zābol', 'IR.04.1482483', 'ASCII:Shahrestan-e Zabol;ID:1482483', '17182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17182', '112', '19059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.04.1482483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19060', '1079', '1', 'Shahrestān-e Zāhedān', 'IR.04.1482486', 'ASCII:Shahrestan-e Zahedan;ID:1482486', '17183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17183', '112', '19060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.04.1482486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19061', '1079', '1', 'Shahrestān-e Sarāvān', 'IR.04.1482494', 'ASCII:Shahrestan-e Saravan;ID:1482494', '17184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17184', '112', '19061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.04.1482494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19062', '1079', '1', 'Shahrestān-e Sarbāz', 'IR.04.1482499', 'ASCII:Shahrestan-e Sarbaz;ID:1482499', '17185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17185', '112', '19062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.04.1482499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19063', '1079', '1', 'Shahrestān-e Nīkshahr', 'IR.04.1482504', 'ASCII:Shahrestan-e Nikshahr;ID:1482504', '17186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17186', '112', '19063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IR.04.1482504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19064', '1079', '1', 'Rangárvallahreppur', 'IS.42.2627712', 'ASCII:Rangarvallahreppur;ID:2627712', '17187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17187', '112', '19064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IS.42.2627712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19065', '1079', '1', 'Provincia di Trapani', 'IT.15.TP', 'ASCII:Provincia di Trapani;ID:2522875', '17188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17188', '112', '19065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.15.TP» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19066', '1079', '1', 'Provincia di Siracusa', 'IT.15.SR', 'ASCII:Syracuse;ID:2523082', '17189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17189', '112', '19066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.15.SR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19067', '1079', '1', 'Provincia di Reggio di Calabria', 'IT.03.RC', 'ASCII:Provincia di Reggio di Calabria;ID:2523629', '17190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17190', '112', '19067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.03.RC» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19068', '1079', '1', 'Provincia di Ragusa', 'IT.15.RG', 'ASCII:Provincia di Ragusa;ID:2523649', '17191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17191', '112', '19068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.15.RG» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19069', '1079', '1', 'Provincia di Palermo', 'IT.15.PA', 'ASCII:Provincia di Palermo;ID:2523918', '17192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17192', '112', '19069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.15.PA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19070', '1079', '1', 'Provincia di Oristano', 'IT.14.OR', 'ASCII:Provincia di Oristano;ID:2523962', '17193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17193', '112', '19070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.14.OR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19071', '1079', '1', 'Provincia di Messina', 'IT.15.ME', 'ASCII:Provincia di Messina;ID:2524169', '17194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17194', '112', '19071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.15.ME» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19072', '1079', '1', 'Provincia di Enna', 'IT.15.EN', 'ASCII:Provincia di Enna;ID:2524818', '17195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17195', '112', '19072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.15.EN» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19073', '1079', '1', 'Provincia di Cosenza', 'IT.03.CS', 'ASCII:Provincia di Cosenza;ID:2524906', '17196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17196', '112', '19073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.03.CS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19074', '1079', '1', 'Provincia di Catanzaro', 'IT.03.CZ', 'ASCII:Provincia di Catanzaro;ID:2525058', '17197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17197', '112', '19074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.03.CZ» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19075', '1079', '1', 'Provincia di Catania', 'IT.15.CT', 'ASCII:Provincia di Catania;ID:2525065', '17198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17198', '112', '19075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.15.CT» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19076', '1079', '1', 'Provincia di Caltanissetta', 'IT.15.CL', 'ASCII:Provincia di Caltanissetta;ID:2525447', '17199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17199', '112', '19076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.15.CL» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19077', '1079', '1', 'Provincia di Cagliari', 'IT.14.CA', 'ASCII:Provincia di Cagliari;ID:2525471', '17200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17200', '112', '19077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.14.CA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19078', '1079', '1', 'Provincia di Agrigento', 'IT.15.AG', 'ASCII:Provincia di Agrigento;ID:2525763', '17201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17201', '112', '19078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.15.AG» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19079', '1079', '1', 'Provincia di Viterbo', 'IT.07.VT', 'ASCII:Provincia di Viterbo;ID:3164038', '17202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17202', '112', '19079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.07.VT» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19080', '1079', '1', 'Provincia di Vicenza', 'IT.20.VI', 'ASCII:Provincia di Vicenza;ID:3164418', '17203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17203', '112', '19080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.20.VI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19081', '1079', '1', 'Provincia di Verona', 'IT.20.VR', 'ASCII:Provincia di Verona;ID:3164526', '17204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17204', '112', '19081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.20.VR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19082', '1079', '1', 'Provincia di Vercelli', 'IT.12.VC', 'ASCII:Provincia di Vercelli;ID:3164564', '17205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17205', '112', '19082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.12.VC» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19083', '1079', '1', 'Provincia Verbano-Cusio-Ossola', 'IT.12.VB', 'ASCII:Verbania;ID:3164567', '17206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17206', '112', '19083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.12.VB» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19084', '1079', '1', 'Provincia di Venezia', 'IT.20.VE', 'ASCII:Venice;ID:3164600', '17207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17207', '112', '19084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.20.VE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19085', '1079', '1', 'Provincia di Varese', 'IT.09.VA', 'ASCII:Provincia di Varese;ID:3164697', '17208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17208', '112', '19085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.VA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19086', '1079', '1', 'Provincia di Udine', 'IT.06.UD', 'ASCII:Provincia di Udine;ID:3165071', '17209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17209', '112', '19086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.06.UD» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19087', '1079', '1', 'Provincia di Trieste', 'IT.06.TS', 'ASCII:Provincia di Trieste;ID:3165184', '17210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17210', '112', '19087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.06.TS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19088', '1079', '1', 'Provincia di Treviso', 'IT.20.TV', 'ASCII:Provincia di Treviso;ID:3165200', '17211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17211', '112', '19088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.20.TV» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19089', '1079', '1', 'Provincia di Trento', 'IT.17.TN', 'ASCII:Trento;ID:3165241', '17212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17212', '112', '19089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.17.TN» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19090', '1079', '1', 'Provincia di Torino', 'IT.12.TO', 'ASCII:Turin;ID:3165523', '17213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17213', '112', '19090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.12.TO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19091', '1079', '1', 'Provincia di Terni', 'IT.18.TR', 'ASCII:Provincia di Terni;ID:3165770', '17214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17214', '112', '19091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.18.TR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19092', '1079', '1', 'Provincia di Teramo', 'IT.01.TE', 'ASCII:Provincia di Teramo;ID:3165802', '17215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17215', '112', '19092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.01.TE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19093', '1079', '1', 'Provincia di Taranto', 'IT.13.TA', 'ASCII:Provincia di Taranto;ID:3165924', '17216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17216', '112', '19093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.13.TA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19094', '1079', '1', 'Provincia di Sondrio', 'IT.09.SO', 'ASCII:Provincia di Sondrio;ID:3166396', '17217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17217', '112', '19094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.SO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19095', '1079', '1', 'Provincia di Siena', 'IT.16.SI', 'ASCII:Provincia di Siena;ID:3166546', '17218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17218', '112', '19095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.16.SI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19096', '1079', '1', 'Provincia di Savona', 'IT.08.SV', 'ASCII:Provincia di Savona;ID:3167021', '17219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17219', '112', '19096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.08.SV» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19097', '1079', '1', 'Provincia di Sassari', 'IT.14.SS', 'ASCII:Provincia di Sassari;ID:3167094', '17220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17220', '112', '19097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.14.SS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19098', '1079', '1', 'Provincia di Salerno', 'IT.04.SA', 'ASCII:Provincia di Salerno;ID:3168670', '17221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17221', '112', '19098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.04.SA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19099', '1079', '1', 'Provincia di Rovigo', 'IT.20.RO', 'ASCII:Provincia di Rovigo;ID:3168842', '17222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17222', '112', '19099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.20.RO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19100', '1079', '1', 'Provincia di Roma', 'IT.07.RM', 'ASCII:Region of Rome;ID:3169069', '17223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17223', '112', '19100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.07.RM» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19101', '1079', '1', 'Provincia di Rieti', 'IT.07.RI', 'ASCII:Provincia di Rieti;ID:3169411', '17224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17224', '112', '19101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.07.RI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19102', '1079', '1', 'Provincia di Reggio Emilia', 'IT.05.RE', 'ASCII:Provincia di Reggio Emilia;ID:3169524', '17225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17225', '112', '19102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.05.RE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19103', '1079', '1', 'Provincia di Ravenna', 'IT.05.RA', 'ASCII:Provincia di Ravenna;ID:3169560', '17226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17226', '112', '19103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.05.RA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19104', '1079', '1', 'Provincia di Potenza', 'IT.02.PZ', 'ASCII:Provincia di Potenza;ID:3170025', '17227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17227', '112', '19104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.02.PZ» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19105', '1079', '1', 'Provincia di Pordenone', 'IT.06.PN', 'ASCII:Provincia di Pordenone;ID:3170146', '17228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17228', '112', '19105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.06.PN» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19106', '1079', '1', 'Provincia di Pistoia', 'IT.16.PT', 'ASCII:Provincia di Pistoia;ID:3170620', '17229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17229', '112', '19106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.16.PT» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19107', '1079', '1', 'Provincia di Pisa', 'IT.16.PI', 'ASCII:Provincia di Pisa;ID:3170646', '17230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17230', '112', '19107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.16.PI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19108', '1079', '1', 'Provincia di Piacenza', 'IT.05.PC', 'ASCII:Provincia di Piacenza;ID:3171057', '17231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17231', '112', '19108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.05.PC» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19109', '1079', '1', 'Provincia di Pescara', 'IT.01.PE', 'ASCII:Provincia di Pescara;ID:3171163', '17232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17232', '112', '19109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.01.PE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19110', '1079', '1', 'Provincia di Pesaro e Urbino', 'IT.10.PU', 'ASCII:Pesaro and Urbino;ID:3171172', '17233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17233', '112', '19110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.10.PU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19111', '1079', '1', 'Provincia di Perugia', 'IT.18.PG', 'ASCII:Provincia di Perugia;ID:3171179', '17234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17234', '112', '19111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.18.PG» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19112', '1079', '1', 'Provincia di Pavia', 'IT.09.PV', 'ASCII:Provincia di Pavia;ID:3171364', '17235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17235', '112', '19112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.PV» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19113', '1079', '1', 'Provincia di Parma', 'IT.05.PR', 'ASCII:Provincia di Parma;ID:3171456', '17236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17236', '112', '19113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.05.PR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19114', '1079', '1', 'Provincia di Padova', 'IT.20.PD', 'ASCII:Padua;ID:3171727', '17237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17237', '112', '19114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.20.PD» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19115', '1079', '1', 'Provincia di Nuoro', 'IT.14.NU', 'ASCII:Provincia di Nuoro;ID:3172153', '17238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17238', '112', '19115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.14.NU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19116', '1079', '1', 'Provincia di Novara', 'IT.12.NO', 'ASCII:Provincia di Novara;ID:3172188', '17239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17239', '112', '19116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.12.NO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19117', '1079', '1', 'Provincia di Napoli', 'IT.04.NA', 'ASCII:Naples;ID:3172391', '17240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17240', '112', '19117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.04.NA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19118', '1079', '1', 'Provincia di Modena', 'IT.05.MO', 'ASCII:Provincia di Modena;ID:3173330', '17241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17241', '112', '19118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.05.MO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19119', '1079', '1', 'Provincia di Milano', 'IT.09.MI', 'ASCII:Milan;ID:3173434', '17242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17242', '112', '19119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.MI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19120', '1079', '1', 'Provincia di Matera', 'IT.02.MT', 'ASCII:Provincia di Matera;ID:3173718', '17243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17243', '112', '19120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.02.MT» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19121', '1079', '1', 'Provincia di Massa-Carrara', 'IT.16.MS', 'ASCII:Provincia di Massa-Carrara;ID:3173767', '17244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17244', '112', '19121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.16.MS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19122', '1079', '1', 'Provincia di Mantova', 'IT.09.MN', 'ASCII:Provincia di Mantova;ID:3174050', '17245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17245', '112', '19122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.MN» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19123', '1079', '1', 'Provincia di Macerata', 'IT.10.MC', 'ASCII:Provincia di Macerata;ID:3174379', '17246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17246', '112', '19123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.10.MC» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19124', '1079', '1', 'Provincia di Lucca', 'IT.16.LU', 'ASCII:Provincia di Lucca;ID:3174529', '17247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17247', '112', '19124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.16.LU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19125', '1079', '1', 'Provincia di Livorno', 'IT.16.LI', 'ASCII:Provincia di Livorno;ID:3174658', '17248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17248', '112', '19125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.16.LI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19126', '1079', '1', 'Provincia di Lecce', 'IT.13.LE', 'ASCII:Provincia di Lecce;ID:3174952', '17249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17249', '112', '19126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.13.LE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19127', '1079', '1', 'Provincia di Latina', 'IT.07.LT', 'ASCII:Provincia di Latina;ID:3175057', '17250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17250', '112', '19127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.07.LT» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19128', '1079', '1', 'Provincia di La Spezia', 'IT.08.SP', 'ASCII:Provincia di La Spezia;ID:3175080', '17251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17251', '112', '19128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.08.SP» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19129', '1079', '1', 'Provincia di L''Aquila', 'IT.01.AQ', 'ASCII:Provincia di L''Aquila;ID:3175120', '17252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17252', '112', '19129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.01.AQ» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19130', '1079', '1', 'Provincia di Isernia', 'IT.11.IS', 'ASCII:Provincia di Isernia;ID:3175444', '17253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17253', '112', '19130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.11.IS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19131', '1079', '1', 'Provincia di Imperia', 'IT.08.IM', 'ASCII:Provincia di Imperia;ID:3175531', '17254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17254', '112', '19131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.08.IM» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19132', '1079', '1', 'Provincia di Grosseto', 'IT.16.GR', 'ASCII:Provincia di Grosseto;ID:3175784', '17255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17255', '112', '19132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.16.GR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19133', '1079', '1', 'Provincia di Gorizia', 'IT.06.GO', 'ASCII:Provincia di Gorizia;ID:3175985', '17256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17256', '112', '19133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.06.GO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19134', '1079', '1', 'Provincia di Genova', 'IT.08.GE', 'ASCII:Genoa;ID:3176217', '17257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17257', '112', '19134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.08.GE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19135', '1079', '1', 'Provincia di Frosinone', 'IT.07.FR', 'ASCII:Provincia di Frosinone;ID:3176513', '17258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17258', '112', '19135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.07.FR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19136', '1079', '1', 'Provincia di Forlì', 'IT.05.FC', 'ASCII:Provincia di Forli;ID:3176745', '17259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17259', '112', '19136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.05.FC» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19137', '1079', '1', 'Provincia di Foggia', 'IT.13.FG', 'ASCII:Provincia di Foggia;ID:3176884', '17260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17260', '112', '19137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.13.FG» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19138', '1079', '1', 'Provincia di Firenze', 'IT.16.FI', 'ASCII:Florence;ID:3176958', '17261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17261', '112', '19138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.16.FI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19139', '1079', '1', 'Provincia di Ferrara', 'IT.05.FE', 'ASCII:Provincia di Ferrara;ID:3177088', '17262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17262', '112', '19139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.05.FE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19140', '1079', '1', 'Provincia di Cuneo', 'IT.12.CN', 'ASCII:Provincia di Cuneo;ID:3177699', '17263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17263', '112', '19140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.12.CN» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19141', '1079', '1', 'Provincia di Cremona', 'IT.09.CR', 'ASCII:Provincia di Cremona;ID:3177837', '17264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17264', '112', '19141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.CR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19142', '1079', '1', 'Provincia di Como', 'IT.09.CO', 'ASCII:Provincia di Como;ID:3178227', '17265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17265', '112', '19142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.CO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19143', '1079', '1', 'Provincia di Chieti', 'IT.01.CH', 'ASCII:Provincia di Chieti;ID:3178795', '17266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17266', '112', '19143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.01.CH» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19144', '1079', '1', 'Provincia di Caserta ', 'IT.04.CE', 'ASCII:Provincia di Caserta ;ID:3179865', '17267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17267', '112', '19144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.04.CE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19145', '1079', '1', 'Provincia di Campobasso', 'IT.11.CB', 'ASCII:Provincia di Campobasso;ID:3180990', '17268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17268', '112', '19145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.11.CB» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19146', '1079', '1', 'Provincia di Brindisi', 'IT.13.BR', 'ASCII:Provincia di Brindisi;ID:3181526', '17269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17269', '112', '19146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.13.BR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19147', '1079', '1', 'Provincia di Brescia', 'IT.09.BS', 'ASCII:Provincia di Brescia;ID:3181553', '17270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17270', '112', '19147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.BS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19148', '1079', '1', 'Provincia di Bolzano', 'IT.17.BZ', 'ASCII:Provincia di Bolzano;ID:3181912', '17271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17271', '112', '19148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.17.BZ» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19149', '1079', '1', 'Provincia di Bologna', 'IT.05.BO', 'ASCII:Provincia di Bologna;ID:3181927', '17272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17272', '112', '19149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.05.BO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19150', '1079', '1', 'Provincia di Bergamo', 'IT.09.BG', 'ASCII:Provincia di Bergamo;ID:3182163', '17273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17273', '112', '19150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.BG» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19151', '1079', '1', 'Provincia di Benevento', 'IT.04.BN', 'ASCII:Provincia di Benevento;ID:3182178', '17274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17274', '112', '19151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.04.BN» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19152', '1079', '1', 'Provincia di Belluno', 'IT.20.BL', 'ASCII:Provincia di Belluno;ID:3182209', '17275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17275', '112', '19152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.20.BL» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19153', '1079', '1', 'Provincia di Bari', 'IT.13.BA', 'ASCII:Provincia di Bari;ID:3182350', '17276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17276', '112', '19153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.13.BA» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19154', '1079', '1', 'Provincia di Avellino', 'IT.04.AV', 'ASCII:Provincia di Avellino;ID:3182649', '17277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17277', '112', '19154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.04.AV» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19155', '1079', '1', 'Provincia di Asti', 'IT.12.AT', 'ASCII:Provincia di Asti;ID:3182712', '17278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17278', '112', '19155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.12.AT» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19156', '1079', '1', 'Provincia di Ascoli Piceno', 'IT.10.AP', 'ASCII:Provincia di Ascoli Piceno;ID:3182748', '17279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17279', '112', '19156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.10.AP» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19157', '1079', '1', 'Provincia di Arezzo', 'IT.16.AR', 'ASCII:Provincia di Arezzo;ID:3182882', '17280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17280', '112', '19157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.16.AR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19158', '1079', '1', 'Provincia di Aosta', 'IT.19.AO', 'ASCII:Provincia di Aosta;ID:3182996', '17281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17281', '112', '19158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.19.AO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19159', '1079', '1', 'Provincia di Ancona', 'IT.10.AN', 'ASCII:Provincia di Ancona;ID:3183087', '17282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17282', '112', '19159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.10.AN» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19160', '1079', '1', 'Provincia di Alessandria', 'IT.12.AL', 'ASCII:Provincia di Alessandria;ID:3183298', '17283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17283', '112', '19160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.12.AL» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19161', '1079', '1', 'Provincia di Biella', 'IT.12.BI', 'ASCII:Provincia di Biella;ID:6457397', '17284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17284', '112', '19161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.12.BI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19162', '1079', '1', 'Provincia di Carbonia-Iglesias', 'IT.14.CI', 'ASCII:Provincia di Carbonia-Iglesias;ID:6457400', '17285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17285', '112', '19162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.14.CI» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19163', '1079', '1', 'Provincia di Olbia-Tempio', 'IT.14.OT', 'ASCII:Provincia di Olbia-Tempio;ID:6457401', '17286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17286', '112', '19163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.14.OT» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19164', '1079', '1', 'Provincia di Medio Campidano', 'IT.14.VS', 'ASCII:Provincia di Medio Campidano;ID:6457402', '17287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17287', '112', '19164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.14.VS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19165', '1079', '1', 'Provincia di Ogliastra', 'IT.14.OG', 'ASCII:Provincia di Ogliastra;ID:6457403', '17288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17288', '112', '19165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.14.OG» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19166', '1079', '1', 'Provincia di Rimini', 'IT.05.RN', 'ASCII:Provincia di Rimini;ID:6457404', '17289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17289', '112', '19166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.05.RN» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19167', '1079', '1', 'Provincia di Vibo-Valentia', 'IT.03.VV', 'ASCII:Provincia di Vibo-Valentia;ID:6457405', '17290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17290', '112', '19167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.03.VV» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19168', '1079', '1', 'Provincia di Crotone', 'IT.03.KR', 'ASCII:Provincia di Crotone;ID:6458615', '17291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17291', '112', '19168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.03.KR» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19169', '1079', '1', 'Provincia di Lecco', 'IT.09.LC', 'ASCII:Provincia di Lecco;ID:6458616', '17292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17292', '112', '19169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.LC» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19170', '1079', '1', 'Provincia di Lodi', 'IT.09.LO', 'ASCII:Provincia di Lodi;ID:6458617', '17293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17293', '112', '19170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.09.LO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19171', '1079', '1', 'Provincia di Prato', 'IT.16.PO', 'ASCII:Provincia di Prato;ID:6458618', '17294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17294', '112', '19171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «IT.16.PO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19172', '1079', '1', 'Zentsūji-shi', 'JP.00.1847982', 'ASCII:Zentsuji-shi;ID:1847982', '17295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17295', '112', '19172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1847982» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19173', '1079', '1', 'Zama-shi', 'JP.00.1847999', 'ASCII:Zama-shi;ID:1847999', '17296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17296', '112', '19173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1847999» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19174', '1079', '1', 'Yukuhashi-shi', 'JP.00.1848086', 'ASCII:Yukuhashi-shi;ID:1848086', '17297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17297', '112', '19174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19175', '1079', '1', 'Yūki-shi', 'JP.00.1848088', 'ASCII:Yuki-shi;ID:1848088', '17298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17298', '112', '19175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19176', '1079', '1', 'Yūki-gun', 'JP.00.1848093', 'ASCII:Yuki-gun;ID:1848093', '17299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17299', '112', '19176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19177', '1079', '1', 'Yoshiki-gun', 'JP.00.1848185', 'ASCII:Yoshiki-gun;ID:1848185', '17300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17300', '112', '19177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19178', '1079', '1', 'Yosa-gun', 'JP.00.1848224', 'ASCII:Yosa-gun;ID:1848224', '17301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17301', '112', '19178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19179', '1079', '1', 'Yonago-shi', 'JP.00.1848276', 'ASCII:Yonago-shi;ID:1848276', '17302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17302', '112', '19179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19180', '1079', '1', 'Yokosuka-shi', 'JP.00.1848308', 'ASCII:Yokosuka-shi;ID:1848308', '17303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17303', '112', '19180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19181', '1079', '1', 'Yokohama-shi', 'JP.00.1848350', 'ASCII:Yokohama-shi;ID:1848350', '17304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17304', '112', '19181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19182', '1079', '1', 'Yokkaichi-shi', 'JP.00.1848370', 'ASCII:Yokkaichi-shi;ID:1848370', '17305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17305', '112', '19182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19183', '1079', '1', 'Yōkaichi-shi', 'JP.00.1848381', 'ASCII:Yokaichi-shi;ID:1848381', '17306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17306', '112', '19183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19184', '1079', '1', 'Yazu-gun', 'JP.00.1848416', 'ASCII:Yazu-gun;ID:1848416', '17307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17307', '112', '19184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19185', '1079', '1', 'Yatsushiro-shi', 'JP.00.1848441', 'ASCII:Yatsushiro-shi;ID:1848441', '17308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17308', '112', '19185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19186', '1079', '1', 'Yatsushiro-gun', 'JP.00.1848443', 'ASCII:Yatsushiro-gun;ID:1848443', '17309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17309', '112', '19186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19187', '1079', '1', 'Yatsuka-gun', 'JP.00.1848450', 'ASCII:Yatsuka-gun;ID:1848450', '17310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17310', '112', '19187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19188', '1079', '1', 'Yasu-gun', 'JP.00.1848481', 'ASCII:Yasu-gun;ID:1848481', '17311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17311', '112', '19188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19189', '1079', '1', 'Yashio-shi', 'JP.00.1848499', 'ASCII:Yashio-shi;ID:1848499', '17312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17312', '112', '19189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19190', '1079', '1', 'Yao-shi', 'JP.00.1848519', 'ASCII:Yao-shi;ID:1848519', '17313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17313', '112', '19190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19191', '1079', '1', 'Yanai-shi', 'JP.00.1848548', 'ASCII:Yanai-shi;ID:1848548', '17314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17314', '112', '19191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19192', '1079', '1', 'Yanagawa-shi', 'JP.00.1848572', 'ASCII:Yanagawa-shi;ID:1848572', '17315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17315', '112', '19192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19193', '1079', '1', 'Yame-shi', 'JP.00.1848578', 'ASCII:Yame-shi;ID:1848578', '17316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17316', '112', '19193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19194', '1079', '1', 'Yame-gun', 'JP.00.1848579', 'ASCII:Yame-gun;ID:1848579', '17317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17317', '112', '19194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19195', '1079', '1', 'Yamato-takada-shi', 'JP.00.1848592', 'ASCII:Yamato-takada-shi;ID:1848592', '17318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17318', '112', '19195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19196', '1079', '1', 'Yamato-shi', 'JP.00.1848595', 'ASCII:Yamato-shi;ID:1848595', '17319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17319', '112', '19196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19197', '1079', '1', 'Yamato-Kōriyama-shi', 'JP.00.1848602', 'ASCII:Yamato-Koriyama-shi;ID:1848602', '17320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17320', '112', '19197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19198', '1079', '1', 'Yamato-gun', 'JP.00.1848604', 'ASCII:Yamato-gun;ID:1848604', '17321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17321', '112', '19198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19199', '1079', '1', 'Yamanashi-shi', 'JP.00.1848648', 'ASCII:Yamanashi-shi;ID:1848648', '17322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17322', '112', '19199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19200', '1079', '1', 'Yama-gun', 'JP.00.1848677', 'ASCII:Yama-gun;ID:1848677', '17323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17323', '112', '19200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19201', '1079', '1', 'Yamaguchi-shi', 'JP.00.1848678', 'ASCII:Yamaguchi-shi;ID:1848678', '17324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17324', '112', '19201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19202', '1079', '1', 'Yamagata-gun', 'JP.00.1848699', 'ASCII:Yamagata-gun;ID:1848699', '17325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17325', '112', '19202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19203', '1079', '1', 'Yaizu-shi', 'JP.00.1848772', 'ASCII:Yaizu-shi;ID:1848772', '17326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17326', '112', '19203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19204', '1079', '1', 'Yaita-shi', 'JP.00.1848775', 'ASCII:Yaita-shi;ID:1848775', '17327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17327', '112', '19204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19205', '1079', '1', 'Yahata-ku', 'JP.07.1848787', 'ASCII:Yahata-ku;ID:1848787', '17328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17328', '112', '19205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.07.1848787» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19206', '1079', '1', 'Yaeyama-gun', 'JP.00.1848816', 'ASCII:Yaeyama-gun;ID:1848816', '17329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17329', '112', '19206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19207', '1079', '1', 'Yabu-gun', 'JP.00.1848849', 'ASCII:Yabu-gun;ID:1848849', '17330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17330', '112', '19207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19208', '1079', '1', 'Watarai-gun', 'JP.00.1848873', 'ASCII:Watarai-gun;ID:1848873', '17331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17331', '112', '19208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19209', '1079', '1', 'Wakayama-shi', 'JP.00.1848936', 'ASCII:Wakayama-shi;ID:1848936', '17332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17332', '112', '19209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19210', '1079', '1', 'Wajima-shi', 'JP.00.1848973', 'ASCII:Wajima-shi;ID:1848973', '17333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17333', '112', '19210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1848973» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19211', '1079', '1', 'Uwajima-shi', 'JP.05.1849041', 'ASCII:Uwajima;ID:1849041', '17334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17334', '112', '19211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.1849041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19212', '1079', '1', 'Utsunomiya-shi', 'JP.00.1849052', 'ASCII:Utsunomiya-shi;ID:1849052', '17335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17335', '112', '19212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19213', '1079', '1', 'Uto-shi', 'JP.00.1849062', 'ASCII:Uto-shi;ID:1849062', '17336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17336', '112', '19213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19214', '1079', '1', 'Uto-gun', 'JP.00.1849067', 'ASCII:Uto-gun;ID:1849067', '17337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17337', '112', '19214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19215', '1079', '1', 'Usuki-shi', 'JP.00.1849092', 'ASCII:Usuki-shi;ID:1849092', '17338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17338', '112', '19215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19216', '1079', '1', 'Usui-gun', 'JP.00.1849100', 'ASCII:Usui-gun;ID:1849100', '17339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17339', '112', '19216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19217', '1079', '1', 'Usa-shi', 'JP.00.1849160', 'ASCII:Usa-shi;ID:1849160', '17340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17340', '112', '19217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19218', '1079', '1', 'Usa-gun', 'JP.00.1849165', 'ASCII:Usa-gun;ID:1849165', '17341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17341', '112', '19218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19219', '1079', '1', 'Urazoe-shi', 'JP.00.1849184', 'ASCII:Urazoe-shi;ID:1849184', '17342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17342', '112', '19219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19220', '1079', '1', 'Urawa-shi', 'JP.00.1849187', 'ASCII:Urawa-shi;ID:1849187', '17343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17343', '112', '19220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19221', '1079', '1', 'Uozu-shi', 'JP.00.1849235', 'ASCII:Uozu-shi;ID:1849235', '17344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17344', '112', '19221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19222', '1079', '1', 'Uma-gun', 'JP.00.1849325', 'ASCII:Uma-gun;ID:1849325', '17345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17345', '112', '19222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19223', '1079', '1', 'Uji-shi', 'JP.00.1849362', 'ASCII:Uji-shi;ID:1849362', '17346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17346', '112', '19223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19224', '1079', '1', 'Uji-gun', 'JP.00.1849369', 'ASCII:Uji-gun;ID:1849369', '17347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17347', '112', '19224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19225', '1079', '1', 'Ueno-shi', 'JP.00.1849403', 'ASCII:Ueno-shi;ID:1849403', '17348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17348', '112', '19225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19226', '1079', '1', 'Ueda-shi', 'JP.00.1849427', 'ASCII:Ueda-shi;ID:1849427', '17349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17349', '112', '19226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19227', '1079', '1', 'Uda-gun', 'JP.00.1849448', 'ASCII:Uda-gun;ID:1849448', '17350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17350', '112', '19227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19228', '1079', '1', 'Ube-shi', 'JP.00.1849494', 'ASCII:Ube-shi;ID:1849494', '17351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17351', '112', '19228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19229', '1079', '1', 'Tsuyama-shi', 'JP.00.1849518', 'ASCII:Tsuyama-shi;ID:1849518', '17352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17352', '112', '19229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19230', '1079', '1', 'Tsushima-shi', 'JP.00.1849535', 'ASCII:Tsushima-shi;ID:1849535', '17353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17353', '112', '19230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19231', '1079', '1', 'Tsu-shi', 'JP.00.1849544', 'ASCII:Tsu-shi;ID:1849544', '17354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17354', '112', '19231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19232', '1079', '1', 'Tsuru-shi', 'JP.00.1849556', 'ASCII:Tsuru-shi;ID:1849556', '17355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17355', '112', '19232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19233', '1079', '1', 'Tsurusaki-shi', 'JP.00.1849557', 'ASCII:Tsurusaki-shi;ID:1849557', '17356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17356', '112', '19233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19234', '1079', '1', 'Tsuruoka-shi', 'JP.00.1849562', 'ASCII:Tsuruoka-shi;ID:1849562', '17357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17357', '112', '19234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19235', '1079', '1', 'Tsuruga-shi', 'JP.00.1849587', 'ASCII:Tsuruga-shi;ID:1849587', '17358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17358', '112', '19235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19236', '1079', '1', 'Tsuruga-gun', 'JP.00.1849591', 'ASCII:Tsuruga-gun;ID:1849591', '17359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17359', '112', '19236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19237', '1079', '1', 'Tsunan-machi', 'JP.00.1849630', 'ASCII:Tsunan-machi;ID:1849630', '17360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17360', '112', '19237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19238', '1079', '1', 'Tsuna-gun', 'JP.00.1849632', 'ASCII:Tsuna-gun;ID:1849632', '17361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17361', '112', '19238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19239', '1079', '1', 'Tsukui-gun', 'JP.00.1849662', 'ASCII:Tsukui-gun;ID:1849662', '17362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17362', '112', '19239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19240', '1079', '1', 'Tsukubo-gun', 'JP.00.1849672', 'ASCII:Tsukubo-gun;ID:1849672', '17363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17363', '112', '19240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19241', '1079', '1', 'Tsubame-shi', 'JP.00.1849786', 'ASCII:Tsubame-shi;ID:1849786', '17364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17364', '112', '19241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19242', '1079', '1', 'Toyoura-gun', 'JP.00.1849803', 'ASCII:Toyoura-gun;ID:1849803', '17365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17365', '112', '19242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19243', '1079', '1', 'Toyota-shi', 'JP.00.1849809', 'ASCII:Toyota-shi;ID:1849809', '17366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17366', '112', '19243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19244', '1079', '1', 'Toyotama-gun', 'JP.00.1849811', 'ASCII:Toyotama-gun;ID:1849811', '17367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17367', '112', '19244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19245', '1079', '1', 'Toyota-gun', 'JP.00.1849812', 'ASCII:Toyota-gun;ID:1849812', '17368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17368', '112', '19245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19246', '1079', '1', 'Toyosaka-shi', 'JP.00.1849824', 'ASCII:Toyosaka-shi;ID:1849824', '17369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17369', '112', '19246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19247', '1079', '1', 'Toyooka-shi', 'JP.00.1849826', 'ASCII:Toyooka-shi;ID:1849826', '17370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17370', '112', '19247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19248', '1079', '1', 'Toyono-gun', 'JP.00.1849834', 'ASCII:Toyono-gun;ID:1849834', '17371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17371', '112', '19248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19249', '1079', '1', 'Toyokawa-shi', 'JP.00.1849840', 'ASCII:Toyokawa-shi;ID:1849840', '17372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17372', '112', '19249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19250', '1079', '1', 'Toyoake-shi', 'JP.00.1849862', 'ASCII:Toyoake-shi;ID:1849862', '17373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17373', '112', '19250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849862» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19251', '1079', '1', 'Toyama-shi', 'JP.00.1849870', 'ASCII:Toyama-shi;ID:1849870', '17374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17374', '112', '19251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19252', '1079', '1', 'Tottori-shi', 'JP.00.1849887', 'ASCII:Tottori-shi;ID:1849887', '17375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17375', '112', '19252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19253', '1079', '1', 'Tosu-shi', 'JP.00.1849903', 'ASCII:Tosu-shi;ID:1849903', '17376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17376', '112', '19253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19254', '1079', '1', 'Tosa-shi', 'JP.00.1849928', 'ASCII:Tosa-shi;ID:1849928', '17377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17377', '112', '19254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19255', '1079', '1', 'Tosa-gun', 'JP.00.1849939', 'ASCII:Tosa-gun;ID:1849939', '17378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17378', '112', '19255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1849939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19256', '1079', '1', 'Tondabayashi-shi', 'JP.00.1850033', 'ASCII:Tondabayashi-shi;ID:1850033', '17379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17379', '112', '19256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19257', '1079', '1', 'Tonami-shi', 'JP.00.1850038', 'ASCII:Tonami-shi;ID:1850038', '17380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17380', '112', '19257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850038» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19258', '1079', '1', 'Tomada-gun', 'JP.00.1850139', 'ASCII:Tomada-gun;ID:1850139', '17381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17381', '112', '19258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19259', '1079', '1', 'Tokuyama-shi', 'JP.00.1850149', 'ASCII:Tokuyama-shi;ID:1850149', '17382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17382', '112', '19259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19260', '1079', '1', 'Tokushima-shi', 'JP.00.1850156', 'ASCII:Tokushima-shi;ID:1850156', '17383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17383', '112', '19260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19261', '1079', '1', 'Tokorozawa-shi', 'JP.34.1850180', 'ASCII:Tokorozawa-shi;ID:1850180', '17384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17384', '112', '19261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.34.1850180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19262', '1079', '1', 'Tokoname-shi', 'JP.00.1850183', 'ASCII:Tokoname-shi;ID:1850183', '17385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17385', '112', '19262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19263', '1079', '1', 'Toki-shi', 'JP.00.1850200', 'ASCII:Toki-shi;ID:1850200', '17386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17386', '112', '19263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19264', '1079', '1', 'Tōkai-shi', 'JP.00.1850219', 'ASCII:Tokai-shi;ID:1850219', '17387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17387', '112', '19264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19265', '1079', '1', 'Tōhaku-gun', 'JP.00.1850247', 'ASCII:Tohaku-gun;ID:1850247', '17388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17388', '112', '19265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19266', '1079', '1', 'Toda-shi', 'JP.00.1850300', 'ASCII:Toda-shi;ID:1850300', '17389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17389', '112', '19266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19267', '1079', '1', 'Tenryū-shi', 'JP.00.1850392', 'ASCII:Tenryu-shi;ID:1850392', '17390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17390', '112', '19267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19268', '1079', '1', 'Tenri-shi', 'JP.00.1850395', 'ASCII:Tenri-shi;ID:1850395', '17391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17391', '112', '19268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19269', '1079', '1', 'Tateyama-shi', 'JP.00.1850520', 'ASCII:Tateyama-shi;ID:1850520', '17392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17392', '112', '19269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19270', '1079', '1', 'Tarumizu-shi', 'JP.00.1850587', 'ASCII:Tarumizu-shi;ID:1850587', '17393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17393', '112', '19270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19271', '1079', '1', 'Tano-gun', 'JP.00.1850653', 'ASCII:Tano-gun;ID:1850653', '17394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17394', '112', '19271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19272', '1079', '1', 'Tanashi-shi', 'JP.00.1850692', 'ASCII:Tanashi-shi;ID:1850692', '17395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17395', '112', '19272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19273', '1079', '1', 'Tanabe-shi', 'JP.00.1850706', 'ASCII:Tanabe-shi;ID:1850706', '17396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17396', '112', '19273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19274', '1079', '1', 'Tama-shi', 'JP.00.1850731', 'ASCII:Tama-shi;ID:1850731', '17397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17397', '112', '19274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19275', '1079', '1', 'Tamano-shi', 'JP.00.1850741', 'ASCII:Tamano-shi;ID:1850741', '17398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17398', '112', '19275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19276', '1079', '1', 'Tamana-shi', 'JP.00.1850743', 'ASCII:Tamana-shi;ID:1850743', '17399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17399', '112', '19276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19277', '1079', '1', 'Tamana-gun', 'JP.00.1850744', 'ASCII:Tamana-gun;ID:1850744', '17400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17400', '112', '19277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19278', '1079', '1', 'Taku-shi', 'JP.00.1850771', 'ASCII:Taku-shi;ID:1850771', '17401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17401', '112', '19278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19279', '1079', '1', 'Taketa-shi', 'JP.00.1850823', 'ASCII:Taketa-shi;ID:1850823', '17402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17402', '112', '19279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19280', '1079', '1', 'Takeo-shi', 'JP.00.1850832', 'ASCII:Takeo-shi;ID:1850832', '17403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17403', '112', '19280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19281', '1079', '1', 'Takefu-shi', 'JP.00.1850871', 'ASCII:Takefu-shi;ID:1850871', '17404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17404', '112', '19281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850871» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19282', '1079', '1', 'Takayama-shi', 'JP.00.1850890', 'ASCII:Takayama-shi;ID:1850890', '17405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17405', '112', '19282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850890» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19283', '1079', '1', 'Takatsuki-shi', 'JP.00.1850907', 'ASCII:Takatsuki-shi;ID:1850907', '17406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17406', '112', '19283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19284', '1079', '1', 'Takashima-gun', 'JP.00.1850958', 'ASCII:Takashima-gun;ID:1850958', '17407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17407', '112', '19284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19285', '1079', '1', 'Takasaki-shi', 'JP.00.1850994', 'ASCII:Takasaki-shi;ID:1850994', '17408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17408', '112', '19285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1850994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19286', '1079', '1', 'Takasago-shi', 'JP.00.1851005', 'ASCII:Takasago-shi;ID:1851005', '17409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17409', '112', '19286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19287', '1079', '1', 'Takarazuka-shi', 'JP.00.1851011', 'ASCII:Takarazuka-shi;ID:1851011', '17410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17410', '112', '19287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19288', '1079', '1', 'Takaoka-shi', 'JP.00.1851028', 'ASCII:Takaoka-shi;ID:1851028', '17411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17411', '112', '19288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19289', '1079', '1', 'Takaoka-gun', 'JP.00.1851029', 'ASCII:Takaoka-gun;ID:1851029', '17412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17412', '112', '19289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19290', '1079', '1', 'Takamatsu-shi', 'JP.00.1851095', 'ASCII:Takamatsu-shi;ID:1851095', '17413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17413', '112', '19290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19291', '1079', '1', 'Takaishi-shi', 'JP.00.1851123', 'ASCII:Takaishi-shi;ID:1851123', '17414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17414', '112', '19291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19292', '1079', '1', 'Takahashi-shi', 'JP.00.1851133', 'ASCII:Takahashi-shi;ID:1851133', '17415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17415', '112', '19292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19293', '1079', '1', 'Taka-gun', 'JP.00.1851159', 'ASCII:Taka-gun;ID:1851159', '17416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17416', '112', '19293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19294', '1079', '1', 'Tajimi-shi', 'JP.00.1851192', 'ASCII:Tajimi-shi;ID:1851192', '17417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17417', '112', '19294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19295', '1079', '1', 'Tagawa-shi', 'JP.00.1851268', 'ASCII:Tagawa-shi;ID:1851268', '17418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17418', '112', '19295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19296', '1079', '1', 'Tagawa-gun', 'JP.00.1851269', 'ASCII:Tagawa-gun;ID:1851269', '17419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17419', '112', '19296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19297', '1079', '1', 'Tagata-gun', 'JP.00.1851274', 'ASCII:Tagata-gun;ID:1851274', '17420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17420', '112', '19297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19298', '1079', '1', 'Tachikawa-shi', 'JP.00.1851306', 'ASCII:Tachikawa-shi;ID:1851306', '17421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17421', '112', '19298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19299', '1079', '1', 'Suzu-shi', 'JP.00.1851337', 'ASCII:Suzu-shi;ID:1851337', '17422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17422', '112', '19299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19300', '1079', '1', 'Suzuka-shi', 'JP.00.1851345', 'ASCII:Suzuka-shi;ID:1851345', '17423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17423', '112', '19300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19301', '1079', '1', 'Suzu-gun', 'JP.00.1851349', 'ASCII:Suzu-gun;ID:1851349', '17424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17424', '112', '19301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851349» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19302', '1079', '1', 'Suwa-shi', 'JP.00.1851362', 'ASCII:Suwa-shi;ID:1851362', '17425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17425', '112', '19302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19303', '1079', '1', 'Suwa-gun', 'JP.00.1851367', 'ASCII:Suwa-gun;ID:1851367', '17426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17426', '112', '19303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19304', '1079', '1', 'Susono-shi', 'JP.00.1851376', 'ASCII:Susono-shi;ID:1851376', '17427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17427', '112', '19304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19305', '1079', '1', 'Suntō-gun', 'JP.00.1851401', 'ASCII:Sunto-gun;ID:1851401', '17428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17428', '112', '19305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19306', '1079', '1', 'Sumoto-shi', 'JP.00.1851423', 'ASCII:Sumoto-shi;ID:1851423', '17429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17429', '112', '19306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19307', '1079', '1', 'Suita-shi', 'JP.00.1851482', 'ASCII:Suita-shi;ID:1851482', '17430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17430', '112', '19307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19308', '1079', '1', 'Sōraku-gun', 'JP.00.1851574', 'ASCII:Soraku-gun;ID:1851574', '17431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17431', '112', '19308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19309', '1079', '1', 'Soo-gun', 'JP.00.1851576', 'ASCII:Soo-gun;ID:1851576', '17432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17432', '112', '19309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19310', '1079', '1', 'Shōzu-gun', 'JP.00.1851654', 'ASCII:Shozu-gun;ID:1851654', '17433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17433', '112', '19310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19311', '1079', '1', 'Shizuoka-shi', 'JP.00.1851714', 'ASCII:Shizuoka-shi;ID:1851714', '17434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17434', '112', '19311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19312', '1079', '1', 'Shioya-gun', 'JP.00.1851957', 'ASCII:Shioya-gun;ID:1851957', '17435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17435', '112', '19312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1851957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19313', '1079', '1', 'Shiojiri-shi', 'JP.00.1852001', 'ASCII:Shiojiri-shi;ID:1852001', '17436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17436', '112', '19313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19314', '1079', '1', 'Shinshiro-shi', 'JP.00.1852044', 'ASCII:Shinshiro-shi;ID:1852044', '17437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17437', '112', '19314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19315', '1079', '1', 'Shinnan''yō-shi', 'JP.00.1852063', 'ASCII:Shinnan''yo-shi;ID:1852063', '17438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17438', '112', '19315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19316', '1079', '1', 'Shingū-shi', 'JP.00.1852105', 'ASCII:Shingu-shi;ID:1852105', '17439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17439', '112', '19316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19317', '1079', '1', 'Shimotsuma-shi', 'JP.00.1852162', 'ASCII:Shimotsuma-shi;ID:1852162', '17440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17440', '112', '19317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852162» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19318', '1079', '1', 'Shimo-tsuga-gun', 'JP.00.1852170', 'ASCII:Shimo-tsuga-gun;ID:1852170', '17441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17441', '112', '19318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19319', '1079', '1', 'Shimo-takai-gun', 'JP.00.1852186', 'ASCII:Shimo-takai-gun;ID:1852186', '17442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17442', '112', '19319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19320', '1079', '1', 'Shimo-takai-gun', 'JP.00.1852187', 'ASCII:Shimo-takai-gun;ID:1852187', '17443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17443', '112', '19320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19321', '1079', '1', 'Shimonoseki-shi', 'JP.45.1852222', 'ASCII:Shimonoseki-shi;ID:1852222', '17444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17444', '112', '19321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.45.1852222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19322', '1079', '1', 'Shimo-niikawa-gun', 'JP.00.1852239', 'ASCII:Shimo-niikawa-gun;ID:1852239', '17445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17445', '112', '19322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19323', '1079', '1', 'Shimo-minochi-gun', 'JP.00.1852253', 'ASCII:Shimo-minochi-gun;ID:1852253', '17446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17446', '112', '19323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19324', '1079', '1', 'Shimo-ina-gun', 'JP.00.1852309', 'ASCII:Shimo-ina-gun;ID:1852309', '17447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17447', '112', '19324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19325', '1079', '1', 'Shimoge-gun', 'JP.00.1852332', 'ASCII:Shimoge-gun;ID:1852332', '17448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17448', '112', '19325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19326', '1079', '1', 'Shimoda-shi', 'JP.00.1852349', 'ASCII:Shimoda-shi;ID:1852349', '17449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17449', '112', '19326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852349» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19327', '1079', '1', 'Shimo-agata-gun', 'JP.00.1852373', 'ASCII:Shimo-agata-gun;ID:1852373', '17450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17450', '112', '19327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852373» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19328', '1079', '1', 'Shimminato-shi', 'JP.00.1852379', 'ASCII:Shimminato-shi;ID:1852379', '17451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17451', '112', '19328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19329', '1079', '1', 'Shimizu-shi', 'JP.00.1852401', 'ASCII:Shimizu-shi;ID:1852401', '17452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17452', '112', '19329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19330', '1079', '1', 'Shimajiri-gun', 'JP.00.1852456', 'ASCII:Shimajiri-gun;ID:1852456', '17453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17453', '112', '19330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19331', '1079', '1', 'Shima-gun', 'JP.00.1852464', 'ASCII:Shima-gun;ID:1852464', '17454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17454', '112', '19331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19332', '1079', '1', 'Shiki-gun', 'JP.00.1852501', 'ASCII:Shiki-gun;ID:1852501', '17455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17455', '112', '19332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19333', '1079', '1', 'Shijōnawate-shi', 'JP.00.1852523', 'ASCII:Shijonawate-shi;ID:1852523', '17456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17456', '112', '19333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19334', '1079', '1', 'Shiga-gun', 'JP.00.1852554', 'ASCII:Shiga-gun;ID:1852554', '17457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17457', '112', '19334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19335', '1079', '1', 'Shida-gun', 'JP.00.1852565', 'ASCII:Shida-gun;ID:1852565', '17458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17458', '112', '19335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852565» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19336', '1079', '1', 'Shibukawa-shi', 'JP.00.1852593', 'ASCII:Shibukawa-shi;ID:1852593', '17459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17459', '112', '19336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19337', '1079', '1', 'Shibata-shi', 'JP.00.1852604', 'ASCII:Shibata-shi;ID:1852604', '17460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17460', '112', '19337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19338', '1079', '1', 'Settsu-shi', 'JP.00.1852642', 'ASCII:Settsu-shi;ID:1852642', '17461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17461', '112', '19338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852642» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19339', '1079', '1', 'Seto-shi', 'JP.00.1852647', 'ASCII:Seto-shi;ID:1852647', '17462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17462', '112', '19339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852647» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19340', '1079', '1', 'Seta-gun', 'JP.00.1852674', 'ASCII:Seta-gun;ID:1852674', '17463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17463', '112', '19340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19341', '1079', '1', 'Sennan-gun', 'JP.00.1852716', 'ASCII:Sennan-gun;ID:1852716', '17464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17464', '112', '19341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19342', '1079', '1', 'Semboku-gun', 'JP.00.1852753', 'ASCII:Semboku-gun;ID:1852753', '17465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17465', '112', '19342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19343', '1079', '1', 'Seki-shi', 'JP.00.1852765', 'ASCII:Seki-shi;ID:1852765', '17466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17466', '112', '19343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19344', '1079', '1', 'Sayō-gun', 'JP.00.1852830', 'ASCII:Sayo-gun;ID:1852830', '17467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17467', '112', '19344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19345', '1079', '1', 'Sayama-shi', 'JP.00.1852833', 'ASCII:Sayama-shi;ID:1852833', '17468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17468', '112', '19345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19346', '1079', '1', 'Sawa-gun', 'JP.00.1852846', 'ASCII:Sawa-gun;ID:1852846', '17469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17469', '112', '19346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19347', '1079', '1', 'Satsuma-gun', 'JP.00.1852852', 'ASCII:Satsuma-gun;ID:1852852', '17470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17470', '112', '19347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19348', '1079', '1', 'Sashima-gun', 'JP.00.1852883', 'ASCII:Sashima-gun;ID:1852883', '17471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17471', '112', '19348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19349', '1079', '1', 'Sasebo-shi', 'JP.00.1852895', 'ASCII:Sasebo-shi;ID:1852895', '17472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17472', '112', '19349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19350', '1079', '1', 'Sarashina-gun', 'JP.00.1852937', 'ASCII:Sarashina-gun;ID:1852937', '17473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17473', '112', '19350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19351', '1079', '1', 'Santō-gun', 'JP.00.1852957', 'ASCII:Santo-gun;ID:1852957', '17474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17474', '112', '19351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19352', '1079', '1', 'Sanjō-shi', 'JP.00.1852981', 'ASCII:Sanjo-shi;ID:1852981', '17475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17475', '112', '19352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1852981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19353', '1079', '1', 'Saku-shi', 'JP.00.1853055', 'ASCII:Saku-shi;ID:1853055', '17476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17476', '112', '19353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19354', '1079', '1', 'Sakurai-shi', 'JP.00.1853062', 'ASCII:Sakurai-shi;ID:1853062', '17477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17477', '112', '19354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19355', '1079', '1', 'Sakata-shi', 'JP.00.1853136', 'ASCII:Sakata-shi;ID:1853136', '17478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17478', '112', '19355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19356', '1079', '1', 'Sakai-shi', 'JP.00.1853167', 'ASCII:Sakai-shi;ID:1853167', '17479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17479', '112', '19356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19357', '1079', '1', 'Sakaiminato-shi', 'JP.00.1853173', 'ASCII:Sakaiminato-shi;ID:1853173', '17480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17480', '112', '19357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19358', '1079', '1', 'Sakai-gun', 'JP.00.1853180', 'ASCII:Sakai-gun;ID:1853180', '17481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17481', '112', '19358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19359', '1079', '1', 'Sakaide-shi', 'JP.00.1853186', 'ASCII:Sakaide-shi;ID:1853186', '17482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17482', '112', '19359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19360', '1079', '1', 'Sakado-shi', 'JP.00.1853207', 'ASCII:Sakado-shi;ID:1853207', '17483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17483', '112', '19360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19361', '1079', '1', 'Saito-shi', 'JP.00.1853223', 'ASCII:Saito-shi;ID:1853223', '17484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17484', '112', '19361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19362', '1079', '1', 'Saiki-shi', 'JP.00.1853234', 'ASCII:Saiki-shi;ID:1853234', '17485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17485', '112', '19362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19363', '1079', '1', 'Saijō-shi', 'JP.00.1853240', 'ASCII:Saijo-shi;ID:1853240', '17486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17486', '112', '19363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19364', '1079', '1', 'Saihaku-gun', 'JP.00.1853248', 'ASCII:Saihaku-gun;ID:1853248', '17487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17487', '112', '19364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19365', '1079', '1', 'Saidaiji-shi', 'JP.00.1853258', 'ASCII:Saidaiji-shi;ID:1853258', '17488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17488', '112', '19365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19366', '1079', '1', 'Saga-shi', 'JP.00.1853274', 'ASCII:Saga-shi;ID:1853274', '17489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17489', '112', '19366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19367', '1079', '1', 'Sagamihara-shi', 'JP.00.1853293', 'ASCII:Sagamihara-shi;ID:1853293', '17490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17490', '112', '19367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19368', '1079', '1', 'Saga-gun', 'JP.00.1853300', 'ASCII:Saga-gun;ID:1853300', '17491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17491', '112', '19368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19369', '1079', '1', 'Saeki-gun', 'JP.00.1853306', 'ASCII:Saeki-gun;ID:1853306', '17492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17492', '112', '19369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19370', '1079', '1', 'Sado-gun', 'JP.00.1853313', 'ASCII:Sado-gun;ID:1853313', '17493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17493', '112', '19370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19371', '1079', '1', 'Ryōtsu-shi', 'JP.00.1853368', 'ASCII:Ryotsu-shi;ID:1853368', '17494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17494', '112', '19371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853368» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19372', '1079', '1', 'Ōzu-shi', 'JP.05.1853424', 'ASCII:Ozu;ID:1853424', '17495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17495', '112', '19372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.1853424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19373', '1079', '1', 'Oyama-shi', 'JP.00.1853473', 'ASCII:Oyama-shi;ID:1853473', '17496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17496', '112', '19373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19374', '1079', '1', 'Oyabe-shi', 'JP.00.1853505', 'ASCII:Oyabe-shi;ID:1853505', '17497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17497', '112', '19374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19375', '1079', '1', 'Owase-shi', 'JP.00.1853513', 'ASCII:Owase-shi;ID:1853513', '17498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17498', '112', '19375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19376', '1079', '1', 'Owari-Asahi-shi', 'JP.00.1853518', 'ASCII:Owari-Asahi-shi;ID:1853518', '17499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17499', '112', '19376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19377', '1079', '1', 'Ōtsu-shi', 'JP.00.1853552', 'ASCII:Otsu-shi;ID:1853552', '17500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17500', '112', '19377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19378', '1079', '1', 'Ōtsuki-shi', 'JP.00.1853562', 'ASCII:Otsuki-shi;ID:1853562', '17501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17501', '112', '19378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19379', '1079', '1', 'Ōta-shi', 'JP.00.1853626', 'ASCII:Ota-shi;ID:1853626', '17502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17502', '112', '19379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19380', '1079', '1', 'Ōtake-shi', 'JP.00.1853661', 'ASCII:Otake-shi;ID:1853661', '17503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17503', '112', '19380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19381', '1079', '1', 'Ōshima-shichō', 'JP.00.1853724', 'ASCII:Oshima-shicho;ID:1853724', '17504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17504', '112', '19381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19382', '1079', '1', 'Ōshima-gun', 'JP.00.1853738', 'ASCII:Oshima-gun;ID:1853738', '17505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17505', '112', '19382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19383', '1079', '1', 'Ōsaka-shi', 'JP.00.1853897', 'ASCII:Osaka-shi;ID:1853897', '17506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17506', '112', '19383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853897» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19384', '1079', '1', 'Ōra-gun', 'JP.00.1853946', 'ASCII:Ora-gun;ID:1853946', '17507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17507', '112', '19384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853946» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19385', '1079', '1', 'Onyū-gun', 'JP.00.1853960', 'ASCII:Onyu-gun;ID:1853960', '17508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17508', '112', '19385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19386', '1079', '1', 'Onomichi-shi', 'JP.00.1853990', 'ASCII:Onomichi-shi;ID:1853990', '17509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17509', '112', '19386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1853990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19387', '1079', '1', 'Ōnojō-shi', 'JP.00.1854000', 'ASCII:Onojo-shi;ID:1854000', '17510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17510', '112', '19387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19388', '1079', '1', 'Ōno-gun', 'JP.00.1854008', 'ASCII:Ono-gun;ID:1854008', '17511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17511', '112', '19388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19389', '1079', '1', 'Onga-gun', 'JP.07.1854055', 'ASCII:Onga-gun;ID:1854055', '17512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17512', '112', '19389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.07.1854055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19390', '1079', '1', 'Ōmuta-shi', 'JP.00.1854081', 'ASCII:Omuta-shi;ID:1854081', '17513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17513', '112', '19390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19391', '1079', '1', 'Ōmi-machi', 'JP.00.1854149', 'ASCII:Omi-machi;ID:1854149', '17514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17514', '112', '19391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19392', '1079', '1', 'Ōmi-Hachiman-shi', 'JP.00.1854152', 'ASCII:Omi-Hachiman-shi;ID:1854152', '17515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17515', '112', '19392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19393', '1079', '1', 'Ōme-shi', 'JP.40.1854160', 'ASCII:Ome-shi;ID:1854160', '17516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17516', '112', '19393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.40.1854160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19394', '1079', '1', 'Ōmachi-shi', 'JP.00.1854184', 'ASCII:Omachi-shi;ID:1854184', '17517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17517', '112', '19394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19395', '1079', '1', 'Ōkuchi-shi', 'JP.00.1854243', 'ASCII:Okuchi-shi;ID:1854243', '17518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17518', '112', '19395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19396', '1079', '1', 'Okinawa-shi', 'JP.00.1854344', 'ASCII:Okinawa-shi;ID:1854344', '17519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17519', '112', '19396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854344» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19397', '1079', '1', 'Oki-gun', 'JP.00.1854361', 'ASCII:Oki-gun;ID:1854361', '17520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17520', '112', '19397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19398', '1079', '1', 'Okegawa-shi', 'JP.00.1854369', 'ASCII:Okegawa-shi;ID:1854369', '17521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17521', '112', '19398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19399', '1079', '1', 'Okazaki-shi', 'JP.00.1854373', 'ASCII:Okazaki-shi;ID:1854373', '17522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17522', '112', '19399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854373» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19400', '1079', '1', 'Okaya-shi', 'JP.00.1854378', 'ASCII:Okaya-shi;ID:1854378', '17523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17523', '112', '19400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19401', '1079', '1', 'Okayama-shi', 'JP.00.1854380', 'ASCII:Okayama-shi;ID:1854380', '17524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17524', '112', '19401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19402', '1079', '1', 'Ōkawa-shi', 'JP.00.1854385', 'ASCII:Okawa-shi;ID:1854385', '17525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17525', '112', '19402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19403', '1079', '1', 'Ōkawa-gun', 'JP.00.1854392', 'ASCII:Okawa-gun;ID:1854392', '17526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17526', '112', '19403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19404', '1079', '1', 'Ojiya-shi', 'JP.00.1854442', 'ASCII:Ojiya-shi;ID:1854442', '17527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17527', '112', '19404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19405', '1079', '1', 'Ōita-shi', 'JP.00.1854480', 'ASCII:Oita-shi;ID:1854480', '17528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17528', '112', '19405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19406', '1079', '1', 'Ōita-gun', 'JP.00.1854485', 'ASCII:Oita-gun;ID:1854485', '17529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17529', '112', '19406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19407', '1079', '1', 'Ōi-gun', 'JP.00.1854517', 'ASCII:Oi-gun;ID:1854517', '17530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17530', '112', '19407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19408', '1079', '1', 'Ogōri-shi', 'JP.00.1854627', 'ASCII:Ogori-shi;ID:1854627', '17531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17531', '112', '19408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19409', '1079', '1', 'Ogi-gun', 'JP.00.1854650', 'ASCII:Ogi-gun;ID:1854650', '17532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17532', '112', '19409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19410', '1079', '1', 'Oga-shi', 'JP.00.1854681', 'ASCII:Oga-shi;ID:1854681', '17533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17533', '112', '19410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19411', '1079', '1', 'Ogasa-gun', 'JP.00.1854685', 'ASCII:Ogasa-gun;ID:1854685', '17534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17534', '112', '19411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19412', '1079', '1', 'Ōgaki-shi', 'JP.00.1854700', 'ASCII:Ogaki-shi;ID:1854700', '17535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17535', '112', '19412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19413', '1079', '1', 'Oe-gun', 'JP.00.1854719', 'ASCII:Oe-gun;ID:1854719', '17536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17536', '112', '19413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19414', '1079', '1', 'Odawara-shi', 'JP.00.1854744', 'ASCII:Odawara-shi;ID:1854744', '17537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17537', '112', '19414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19415', '1079', '1', 'Ōda-shi', 'JP.00.1854750', 'ASCII:Oda-shi;ID:1854750', '17538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17538', '112', '19415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19416', '1079', '1', 'Oda-gun', 'JP.00.1854770', 'ASCII:Oda-gun;ID:1854770', '17539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17539', '112', '19416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19417', '1079', '1', 'Ōchi-gun', 'JP.00.1854781', 'ASCII:Ochi-gun;ID:1854781', '17540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17540', '112', '19417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19418', '1079', '1', 'Ochi-gun', 'JP.00.1854782', 'ASCII:Ochi-gun;ID:1854782', '17541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17541', '112', '19418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19419', '1079', '1', 'Ōbu-shi', 'JP.00.1854797', 'ASCII:Obu-shi;ID:1854797', '17542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17542', '112', '19419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19420', '1079', '1', 'Obata-machi', 'JP.00.1854821', 'ASCII:Obata-machi;ID:1854821', '17543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17543', '112', '19420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19421', '1079', '1', 'Obama-shi', 'JP.00.1854843', 'ASCII:Obama-shi;ID:1854843', '17544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17544', '112', '19421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19422', '1079', '1', 'Nyū-gun', 'JP.00.1854875', 'ASCII:Nyu-gun;ID:1854875', '17545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17545', '112', '19422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19423', '1079', '1', 'Numazu-shi', 'JP.00.1854900', 'ASCII:Numazu-shi;ID:1854900', '17546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17546', '112', '19423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19424', '1079', '1', 'Numakuma-gun', 'JP.00.1854907', 'ASCII:Numakuma-gun;ID:1854907', '17547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17547', '112', '19424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19425', '1079', '1', 'Nukata-gun', 'JP.00.1854914', 'ASCII:Nukata-gun;ID:1854914', '17548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17548', '112', '19425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1854914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19426', '1079', '1', 'Nomi-gun', 'JP.00.1855000', 'ASCII:Nomi-gun;ID:1855000', '17549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17549', '112', '19426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19427', '1079', '1', 'Nogi-gun', 'JP.00.1855061', 'ASCII:Nogi-gun;ID:1855061', '17550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17550', '112', '19427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19428', '1079', '1', 'Nobeoka-shi', 'JP.00.1855094', 'ASCII:Nobeoka-shi;ID:1855094', '17551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17551', '112', '19428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19429', '1079', '1', 'Niwa-gun', 'JP.00.1855103', 'ASCII:Niwa-gun;ID:1855103', '17552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17552', '112', '19429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19430', '1079', '1', 'Nishi-yatsushiro-gun', 'JP.00.1855121', 'ASCII:Nishi-yatsushiro-gun;ID:1855121', '17553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17553', '112', '19430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19431', '1079', '1', 'Nishiwaki-shi', 'JP.00.1855132', 'ASCII:Nishiwaki-shi;ID:1855132', '17554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17554', '112', '19431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19432', '1079', '1', 'Nishiuwa-gun', 'JP.05.1855138', 'ASCII:Nishiuwa-gun;ID:1855138', '17555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17555', '112', '19432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.1855138» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19433', '1079', '1', 'Nishi-tonami-gun', 'JP.00.1855150', 'ASCII:Nishi-tonami-gun;ID:1855150', '17556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17556', '112', '19433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19434', '1079', '1', 'Nishi-tama-gun', 'JP.00.1855156', 'ASCII:Nishi-tama-gun;ID:1855156', '17557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17557', '112', '19434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19435', '1079', '1', 'Nishi-tagawa-gun', 'JP.00.1855158', 'ASCII:Nishi-tagawa-gun;ID:1855158', '17558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17558', '112', '19435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19436', '1079', '1', 'Nishi-sonogi-gun', 'JP.00.1855163', 'ASCII:Nishi-sonogi-gun;ID:1855163', '17559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17559', '112', '19436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19437', '1079', '1', 'Nishio-shi', 'JP.00.1855183', 'ASCII:Nishio-shi;ID:1855183', '17560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17560', '112', '19437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19438', '1079', '1', 'Nishi-okitama-gun', 'JP.00.1855187', 'ASCII:Nishi-okitama-gun;ID:1855187', '17561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17561', '112', '19438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19439', '1079', '1', 'Nishinomiya-shi', 'JP.00.1855204', 'ASCII:Nishinomiya-shi;ID:1855204', '17562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17562', '112', '19439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19440', '1079', '1', 'Nishi-muro-gun', 'JP.00.1855225', 'ASCII:Nishi-muro-gun;ID:1855225', '17563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17563', '112', '19440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19441', '1079', '1', 'Nishi-matsuura-gun', 'JP.00.1855238', 'ASCII:Nishi-matsuura-gun;ID:1855238', '17564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17564', '112', '19441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19442', '1079', '1', 'Nishi-kunisaki-gun', 'JP.00.1855248', 'ASCII:Nishi-kunisaki-gun;ID:1855248', '17565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17565', '112', '19442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19443', '1079', '1', 'Nishi-kubiki-gun', 'JP.00.1855253', 'ASCII:Nishi-kubiki-gun;ID:1855253', '17566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17566', '112', '19443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19444', '1079', '1', 'Nishi-kasugai-gun', 'JP.00.1855273', 'ASCII:Nishi-kasugai-gun;ID:1855273', '17567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17567', '112', '19444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19445', '1079', '1', 'Nishi-kanbara-gun', 'JP.00.1855274', 'ASCII:Nishi-kanbara-gun;ID:1855274', '17568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17568', '112', '19445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19446', '1079', '1', 'Nirasaki-shi', 'JP.00.1855362', 'ASCII:Nirasaki-shi;ID:1855362', '17569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17569', '112', '19446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19447', '1079', '1', 'Nima-gun', 'JP.00.1855386', 'ASCII:Nima-gun;ID:1855386', '17570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17570', '112', '19447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19448', '1079', '1', 'Niiza-shi', 'JP.00.1855405', 'ASCII:Niiza-shi;ID:1855405', '17571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17571', '112', '19448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19449', '1079', '1', 'Niihama-shi', 'JP.00.1855422', 'ASCII:Niihama-shi;ID:1855422', '17572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17572', '112', '19449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19450', '1079', '1', 'Niigata-shi', 'JP.00.1855427', 'ASCII:Niigata-shi;ID:1855427', '17573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17573', '112', '19450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19451', '1079', '1', 'Nichinan-shi', 'JP.00.1855473', 'ASCII:Nichinan-shi;ID:1855473', '17574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17574', '112', '19451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19452', '1079', '1', 'Neyagawa-shi', 'JP.00.1855493', 'ASCII:Neyagawa-shi;ID:1855493', '17575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17575', '112', '19452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19453', '1079', '1', 'Nei-gun', 'JP.00.1855521', 'ASCII:Nei-gun;ID:1855521', '17576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17576', '112', '19453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19454', '1079', '1', 'Naze-shi', 'JP.00.1855539', 'ASCII:Naze-shi;ID:1855539', '17577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17577', '112', '19454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19455', '1079', '1', 'Nara-shi', 'JP.28.1855604', 'ASCII:Nara-shi;ID:1855604', '17578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17578', '112', '19455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.28.1855604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19456', '1079', '1', 'Nankoku-shi', 'JP.00.1855637', 'ASCII:Nankoku-shi;ID:1855637', '17579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17579', '112', '19456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855637» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19457', '1079', '1', 'Nakatsu-shi', 'JP.00.1855742', 'ASCII:Nakatsu-shi;ID:1855742', '17580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17580', '112', '19457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855742» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19458', '1079', '1', 'Nakatsugawa-shi', 'JP.00.1855750', 'ASCII:Nakatsugawa-shi;ID:1855750', '17581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17581', '112', '19458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19459', '1079', '1', 'Nakatado-gun', 'JP.00.1855768', 'ASCII:Nakatado-gun;ID:1855768', '17582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17582', '112', '19459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855768» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19460', '1079', '1', 'Nakano-shi', 'JP.00.1855829', 'ASCII:Nakano-shi;ID:1855829', '17583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17583', '112', '19460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19461', '1079', '1', 'Naka-niikawa-gun', 'JP.00.1855873', 'ASCII:Naka-niikawa-gun;ID:1855873', '17584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17584', '112', '19461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19462', '1079', '1', 'Nakamura-shi', 'JP.00.1855878', 'ASCII:Nakamura-shi;ID:1855878', '17585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17585', '112', '19462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19463', '1079', '1', 'Nakama-shi', 'JP.00.1855902', 'ASCII:Nakama-shi;ID:1855902', '17586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17586', '112', '19463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19464', '1079', '1', 'Naka-kubiki-gun', 'JP.00.1855915', 'ASCII:Naka-kubiki-gun;ID:1855915', '17587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17587', '112', '19464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19465', '1079', '1', 'Naka-kawachi-gun', 'JP.00.1855924', 'ASCII:Naka-kawachi-gun;ID:1855924', '17588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17588', '112', '19465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19466', '1079', '1', 'Naka-gun', 'JP.00.1855965', 'ASCII:Naka-gun;ID:1855965', '17589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17589', '112', '19466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19467', '1079', '1', 'Naka-gun', 'JP.00.1855966', 'ASCII:Naka-gun;ID:1855966', '17590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17590', '112', '19467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19468', '1079', '1', 'Naka-gun', 'JP.00.1855967', 'ASCII:Naka-gun;ID:1855967', '17591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17591', '112', '19468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1855967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19469', '1079', '1', 'Nagoya-shi', 'JP.00.1856053', 'ASCII:Nagoya-shi;ID:1856053', '17592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17592', '112', '19469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19470', '1079', '1', 'Nago-shi', 'JP.00.1856061', 'ASCII:Nago-shi;ID:1856061', '17593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17593', '112', '19470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19471', '1079', '1', 'Nagato-shi', 'JP.00.1856090', 'ASCII:Nagato-shi;ID:1856090', '17594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17594', '112', '19471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19472', '1079', '1', 'Nagasaki-shi', 'JP.00.1856152', 'ASCII:Nagasaki-shi;ID:1856152', '17595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17595', '112', '19472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19473', '1079', '1', 'Nagareyama', 'JP.04.1856183', 'ASCII:Nagareyama;ID:1856183', '17596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17596', '112', '19473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.04.1856183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19474', '1079', '1', 'Nagaoka-shi', 'JP.00.1856195', 'ASCII:Nagaoka-shi;ID:1856195', '17597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17597', '112', '19474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19475', '1079', '1', 'Nagaokakyō-shi', 'JP.00.1856196', 'ASCII:Nagaokakyo-shi;ID:1856196', '17598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17598', '112', '19475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19476', '1079', '1', 'Nagaoka-gun', 'JP.00.1856197', 'ASCII:Nagaoka-gun;ID:1856197', '17599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17599', '112', '19476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19477', '1079', '1', 'Nagano-shi', 'JP.26.1856209', 'ASCII:Nagano-shi;ID:1856209', '17600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17600', '112', '19477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.26.1856209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19478', '1079', '1', 'Nagahama-shi', 'JP.00.1856237', 'ASCII:Nagahama-shi;ID:1856237', '17601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17601', '112', '19478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19479', '1079', '1', 'Naga-gun', 'JP.00.1856254', 'ASCII:Naga-gun;ID:1856254', '17602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17602', '112', '19479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19480', '1079', '1', 'Naga-gun', 'JP.00.1856255', 'ASCII:Naga-gun;ID:1856255', '17603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17603', '112', '19480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19481', '1079', '1', 'Nabari-shi', 'JP.00.1856290', 'ASCII:Nabari-shi;ID:1856290', '17604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17604', '112', '19481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856290» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19482', '1079', '1', 'Myōzai-gun', 'JP.00.1856299', 'ASCII:Myozai-gun;ID:1856299', '17605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17605', '112', '19482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856299» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19483', '1079', '1', 'Musashino-shi', 'JP.40.1856366', 'ASCII:Musashino-shi;ID:1856366', '17606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17606', '112', '19483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.40.1856366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19484', '1079', '1', 'Musashi-Murayama-shi', 'JP.00.1856368', 'ASCII:Musashi-Murayama-shi;ID:1856368', '17607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17607', '112', '19484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856368» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19485', '1079', '1', 'Muroto-shi', 'JP.00.1856389', 'ASCII:Muroto-shi;ID:1856389', '17608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17608', '112', '19485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19486', '1079', '1', 'Muko-gun', 'JP.00.1856454', 'ASCII:Muko-gun;ID:1856454', '17609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17609', '112', '19486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19487', '1079', '1', 'Motosu-gun', 'JP.00.1856506', 'ASCII:Motosu-gun;ID:1856506', '17610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17610', '112', '19487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19488', '1079', '1', 'Moriyama-shi', 'JP.00.1856568', 'ASCII:Moriyama-shi;ID:1856568', '17611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17611', '112', '19488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19489', '1079', '1', 'Mizunami-shi', 'JP.00.1856666', 'ASCII:Mizunami-shi;ID:1856666', '17612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17612', '112', '19489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19490', '1079', '1', 'Miyoshi-shi', 'JP.00.1856691', 'ASCII:Miyoshi-shi;ID:1856691', '17613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17613', '112', '19490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856691» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19491', '1079', '1', 'Miyoshi-gun', 'JP.00.1856695', 'ASCII:Miyoshi-gun;ID:1856695', '17614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17614', '112', '19491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19492', '1079', '1', 'Miyazaki-shi', 'JP.00.1856706', 'ASCII:Miyazaki-shi;ID:1856706', '17615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17615', '112', '19492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19493', '1079', '1', 'Miyakonojō-shi', 'JP.00.1856774', 'ASCII:Miyakonojo-shi;ID:1856774', '17616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17616', '112', '19493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19494', '1079', '1', 'Miyaki-gun', 'JP.00.1856784', 'ASCII:Miyaki-gun;ID:1856784', '17617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17617', '112', '19494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856784» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19495', '1079', '1', 'Miyake-shichō', 'JP.00.1856786', 'ASCII:Miyake-shicho;ID:1856786', '17618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17618', '112', '19495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19496', '1079', '1', 'Miura-shi', 'JP.00.1856849', 'ASCII:Miura-shi;ID:1856849', '17619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17619', '112', '19496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19497', '1079', '1', 'Miura-gun', 'JP.00.1856851', 'ASCII:Miura-gun;ID:1856851', '17620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17620', '112', '19497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19498', '1079', '1', 'Mitsuke-shi', 'JP.00.1856876', 'ASCII:Mitsuke-shi;ID:1856876', '17621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17621', '112', '19498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19499', '1079', '1', 'Mitsukaidō-shi', 'JP.00.1856880', 'ASCII:Mitsukaido-shi;ID:1856880', '17622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17622', '112', '19499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19500', '1079', '1', 'Mitsugi-gun', 'JP.00.1856896', 'ASCII:Mitsugi-gun;ID:1856896', '17623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17623', '112', '19500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19501', '1079', '1', 'Mitoyo-gun', 'JP.00.1856906', 'ASCII:Mitoyo-gun;ID:1856906', '17624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17624', '112', '19501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19502', '1079', '1', 'Mitaka-shi', 'JP.00.1856942', 'ASCII:Mitaka-shi;ID:1856942', '17625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17625', '112', '19502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19503', '1079', '1', 'Mishima-shi', 'JP.00.1856971', 'ASCII:Mishima-shi;ID:1856971', '17626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17626', '112', '19503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19504', '1079', '1', 'Mishima-gun', 'JP.00.1856974', 'ASCII:Mishima-gun;ID:1856974', '17627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17627', '112', '19504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19505', '1079', '1', 'Misato-shi', 'JP.00.1856987', 'ASCII:Misato-shi;ID:1856987', '17628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17628', '112', '19505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1856987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19506', '1079', '1', 'Minoo-shi', 'JP.00.1857043', 'ASCII:Minoo-shi;ID:1857043', '17629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17629', '112', '19506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19507', '1079', '1', 'Minokamo-shi', 'JP.00.1857051', 'ASCII:Minokamo-shi;ID:1857051', '17630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17630', '112', '19507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19508', '1079', '1', 'Mino-gun', 'JP.00.1857053', 'ASCII:Mino-gun;ID:1857053', '17631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17631', '112', '19508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19509', '1079', '1', 'Mine-shi', 'JP.00.1857072', 'ASCII:Mine-shi;ID:1857072', '17632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17632', '112', '19509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19510', '1079', '1', 'Mine-gun', 'JP.00.1857077', 'ASCII:Mine-gun;ID:1857077', '17633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17633', '112', '19510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19511', '1079', '1', 'Minamiuwa-gun', 'JP.05.1857121', 'ASCII:Minamiuwa;ID:1857121', '17634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17634', '112', '19511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.1857121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19512', '1079', '1', 'Minami-tama-gun', 'JP.00.1857128', 'ASCII:Minami-tama-gun;ID:1857128', '17635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17635', '112', '19512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19513', '1079', '1', 'Minami-takaki-gun', 'JP.00.1857129', 'ASCII:Minami-takaki-gun;ID:1857129', '17636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17636', '112', '19513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19514', '1079', '1', 'Minami-shidara-gun', 'JP.00.1857139', 'ASCII:Minami-shidara-gun;ID:1857139', '17637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17637', '112', '19514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19515', '1079', '1', 'Minami-saku-gun', 'JP.00.1857141', 'ASCII:Minami-saku-gun;ID:1857141', '17638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17638', '112', '19515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19516', '1079', '1', 'Minami-saitama-gun', 'JP.00.1857143', 'ASCII:Minami-saitama-gun;ID:1857143', '17639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17639', '112', '19516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19517', '1079', '1', 'Minaminaka-gun', 'JP.00.1857155', 'ASCII:Minaminaka-gun;ID:1857155', '17640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17640', '112', '19517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19518', '1079', '1', 'Minami-matsuura-gun', 'JP.00.1857159', 'ASCII:Minami-matsuura-gun;ID:1857159', '17641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17641', '112', '19518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19519', '1079', '1', 'Minami-koma-gun', 'JP.00.1857168', 'ASCII:Minami-koma-gun;ID:1857168', '17642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17642', '112', '19519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19520', '1079', '1', 'Minami-kawachi-gun', 'JP.00.1857170', 'ASCII:Minami-kawachi-gun;ID:1857170', '17643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17643', '112', '19520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19521', '1079', '1', 'Minami-azumi-gun', 'JP.00.1857196', 'ASCII:Minami-azumi-gun;ID:1857196', '17644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17644', '112', '19521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19522', '1079', '1', 'Minami-amabe-gun', 'JP.00.1857202', 'ASCII:Minami-amabe-gun;ID:1857202', '17645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17645', '112', '19522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19523', '1079', '1', 'Minami-aizu-gun', 'JP.00.1857203', 'ASCII:Minami-aizu-gun;ID:1857203', '17646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17646', '112', '19523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19524', '1079', '1', 'Minamata-shi', 'JP.00.1857206', 'ASCII:Minamata-shi;ID:1857206', '17647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17647', '112', '19524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19525', '1079', '1', 'Mihara-shi', 'JP.00.1857327', 'ASCII:Mihara-shi;ID:1857327', '17648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17648', '112', '19525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19526', '1079', '1', 'Mihara-gun', 'JP.00.1857329', 'ASCII:Mihara-gun;ID:1857329', '17649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17649', '112', '19526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19527', '1079', '1', 'Mie-gun', 'JP.00.1857355', 'ASCII:Mie-gun;ID:1857355', '17650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17650', '112', '19527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19528', '1079', '1', 'Matsuura-shi', 'JP.00.1857466', 'ASCII:Matsuura-shi;ID:1857466', '17651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17651', '112', '19528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19529', '1079', '1', 'Matsutō-shi', 'JP.00.1857468', 'ASCII:Matsuto-shi;ID:1857468', '17652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17652', '112', '19529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19530', '1079', '1', 'Matsusaka-shi', 'JP.00.1857495', 'ASCII:Matsusaka-shi;ID:1857495', '17653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17653', '112', '19530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19531', '1079', '1', 'Matsumoto-shi', 'JP.00.1857516', 'ASCII:Matsumoto-shi;ID:1857516', '17654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17654', '112', '19531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19532', '1079', '1', 'Matsue-shi', 'JP.00.1857549', 'ASCII:Matsue-shi;ID:1857549', '17655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17655', '112', '19532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857549» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19533', '1079', '1', 'Matsudo-shi', 'JP.00.1857552', 'ASCII:Matsudo-shi;ID:1857552', '17656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17656', '112', '19533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19534', '1079', '1', 'Matsubara-shi', 'JP.00.1857563', 'ASCII:Matsubara-shi;ID:1857563', '17657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17657', '112', '19534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19535', '1079', '1', 'Masuda-shi', 'JP.00.1857590', 'ASCII:Masuda-shi;ID:1857590', '17658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17658', '112', '19535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19536', '1079', '1', 'Marugame-shi', 'JP.00.1857664', 'ASCII:Marugame-shi;ID:1857664', '17659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17659', '112', '19536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19537', '1079', '1', 'Makurazaki-shi', 'JP.00.1857710', 'ASCII:Makurazaki-shi;ID:1857710', '17660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17660', '112', '19537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19538', '1079', '1', 'Maizuru-shi', 'JP.00.1857764', 'ASCII:Maizuru-shi;ID:1857764', '17661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17661', '112', '19538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19539', '1079', '1', 'Maebashi-shi', 'JP.00.1857842', 'ASCII:Maebashi-shi;ID:1857842', '17662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17662', '112', '19539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19540', '1079', '1', 'Machida-shi', 'JP.00.1857869', 'ASCII:Machida-shi;ID:1857869', '17663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17663', '112', '19540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19541', '1079', '1', 'Kyōto-shi', 'JP.00.1857906', 'ASCII:Kyoto-shi;ID:1857906', '17664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17664', '112', '19541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19542', '1079', '1', 'Kuwana-shi', 'JP.00.1857965', 'ASCII:Kuwana-shi;ID:1857965', '17665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17665', '112', '19542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19543', '1079', '1', 'Kuwana-gun', 'JP.00.1857966', 'ASCII:Kuwana-gun;ID:1857966', '17666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17666', '112', '19543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1857966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19544', '1079', '1', 'Kusu-gun', 'JP.00.1858008', 'ASCII:Kusu-gun;ID:1858008', '17667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17667', '112', '19544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19545', '1079', '1', 'Kushima-shi', 'JP.00.1858035', 'ASCII:Kushima-shi;ID:1858035', '17668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17668', '112', '19545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19546', '1079', '1', 'Kushikino-shi', 'JP.00.1858039', 'ASCII:Kushikino-shi;ID:1858039', '17669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17669', '112', '19546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19547', '1079', '1', 'Kusatsu-shi', 'JP.00.1858063', 'ASCII:Kusatsu-shi;ID:1858063', '17670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17670', '112', '19547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19548', '1079', '1', 'Kurume-shi', 'JP.00.1858087', 'ASCII:Kurume-shi;ID:1858087', '17671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17671', '112', '19548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19549', '1079', '1', 'Kurobe-shi', 'JP.00.1858253', 'ASCII:Kurobe-shi;ID:1858253', '17672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17672', '112', '19549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19550', '1079', '1', 'Kurita-gun', 'JP.00.1858265', 'ASCII:Kurita-gun;ID:1858265', '17673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17673', '112', '19550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19551', '1079', '1', 'Kure-shi', 'JP.00.1858288', 'ASCII:Kure-shi;ID:1858288', '17674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17674', '112', '19551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19552', '1079', '1', 'Kurate-gun', 'JP.00.1858305', 'ASCII:Kurate-gun;ID:1858305', '17675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17675', '112', '19552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19553', '1079', '1', 'Kurashiki-shi', 'JP.00.1858309', 'ASCII:Kurashiki-shi;ID:1858309', '17676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17676', '112', '19553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19554', '1079', '1', 'Kunitachi-shi', 'JP.00.1858346', 'ASCII:Kunitachi-shi;ID:1858346', '17677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17677', '112', '19554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19555', '1079', '1', 'Kume-gun', 'JP.00.1858395', 'ASCII:Kume-gun;ID:1858395', '17678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17678', '112', '19555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19556', '1079', '1', 'Kumano-shi', 'JP.00.1858408', 'ASCII:Kumano-shi;ID:1858408', '17679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17679', '112', '19556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19557', '1079', '1', 'Kumano-gun', 'JP.00.1858410', 'ASCII:Kumano-gun;ID:1858410', '17680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17680', '112', '19557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19558', '1079', '1', 'Kumamoto-shi', 'JP.00.1858418', 'ASCII:Kumamoto-shi;ID:1858418', '17681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17681', '112', '19558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19559', '1079', '1', 'Kumage-gun', 'JP.00.1858426', 'ASCII:Kumage-gun;ID:1858426', '17682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17682', '112', '19559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19560', '1079', '1', 'Kuga-gun', 'JP.00.1858484', 'ASCII:Kuga-gun;ID:1858484', '17683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17683', '112', '19560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19561', '1079', '1', 'Kudamatsu-shi', 'JP.00.1858497', 'ASCII:Kudamatsu-shi;ID:1858497', '17684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17684', '112', '19561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19562', '1079', '1', 'Koza-shi', 'JP.00.1858577', 'ASCII:Koza-shi;ID:1858577', '17685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17685', '112', '19562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19563', '1079', '1', 'Kōza-gun', 'JP.00.1858593', 'ASCII:Koza-gun;ID:1858593', '17686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17686', '112', '19563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19564', '1079', '1', 'Kōyu-gun', 'JP.00.1858599', 'ASCII:Koyu-gun;ID:1858599', '17687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17687', '112', '19564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19565', '1079', '1', 'Kōshoku-shi', 'JP.00.1858704', 'ASCII:Koshoku-shi;ID:1858704', '17688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17688', '112', '19565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19566', '1079', '1', 'Koshi-gun', 'JP.00.1858726', 'ASCII:Koshi-gun;ID:1858726', '17689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17689', '112', '19566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19567', '1079', '1', 'Koshigaya-shi', 'JP.00.1858728', 'ASCII:Koshigaya-shi;ID:1858728', '17690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17690', '112', '19567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19568', '1079', '1', 'Kōnu-gun', 'JP.00.1858776', 'ASCII:Konu-gun;ID:1858776', '17691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17691', '112', '19568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858776» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19569', '1079', '1', 'Kōnosu-shi', 'JP.00.1858792', 'ASCII:Konosu-shi;ID:1858792', '17692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17692', '112', '19569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19570', '1079', '1', 'Kōnan-shi', 'JP.00.1858832', 'ASCII:Konan-shi;ID:1858832', '17693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17693', '112', '19570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19571', '1079', '1', 'Komoro-shi', 'JP.00.1858856', 'ASCII:Komoro-shi;ID:1858856', '17694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17694', '112', '19571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19572', '1079', '1', 'Komatsushima-shi', 'JP.00.1858900', 'ASCII:Komatsushima-shi;ID:1858900', '17695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17695', '112', '19572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19573', '1079', '1', 'Komatsu-shi', 'JP.00.1858904', 'ASCII:Komatsu-shi;ID:1858904', '17696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17696', '112', '19573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19574', '1079', '1', 'Komaki-shi', 'JP.00.1858921', 'ASCII:Komaki-shi;ID:1858921', '17697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17697', '112', '19574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858921» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19575', '1079', '1', 'Komagane-shi', 'JP.00.1858938', 'ASCII:Komagane-shi;ID:1858938', '17698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17698', '112', '19575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19576', '1079', '1', 'Komae-shi', 'JP.00.1858941', 'ASCII:Komae-shi;ID:1858941', '17699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17699', '112', '19576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19577', '1079', '1', 'Kokubunji-shi', 'JP.00.1858962', 'ASCII:Kokubunji-shi;ID:1858962', '17700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17700', '112', '19577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19578', '1079', '1', 'Kōka-gun', 'JP.00.1858984', 'ASCII:Koka-gun;ID:1858984', '17701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17701', '112', '19578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19579', '1079', '1', 'Kojima-shi', 'JP.00.1858997', 'ASCII:Kojima-shi;ID:1858997', '17702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17702', '112', '19579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1858997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19580', '1079', '1', 'Kojima-gun', 'JP.00.1859000', 'ASCII:Kojima-gun;ID:1859000', '17703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17703', '112', '19580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19581', '1079', '1', 'Koga-shi', 'JP.00.1859082', 'ASCII:Koga-shi;ID:1859082', '17704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17704', '112', '19581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19582', '1079', '1', 'Koganei-shi', 'JP.00.1859087', 'ASCII:Koganei-shi;ID:1859087', '17705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17705', '112', '19582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19583', '1079', '1', 'Kōfu-shi', 'JP.00.1859096', 'ASCII:Kofu-shi;ID:1859096', '17706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17706', '112', '19583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19584', '1079', '1', 'Kodaira-shi', 'JP.00.1859115', 'ASCII:Kodaira-shi;ID:1859115', '17707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17707', '112', '19584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19585', '1079', '1', 'Kōchi-shi', 'JP.20.1859127', 'ASCII:Kochi-shi;ID:1859127', '17708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17708', '112', '19585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.20.1859127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19586', '1079', '1', 'Kōbe-shi', 'JP.00.1859161', 'ASCII:Kobe-shi;ID:1859161', '17709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17709', '112', '19586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19587', '1079', '1', 'Kizu', 'JP.22.1859202', 'ASCII:Kizu;ID:1859202', '17710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17710', '112', '19587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.22.1859202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19588', '1079', '1', 'Kiyose-shi', 'JP.00.1859211', 'ASCII:Kiyose-shi;ID:1859211', '17711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17711', '112', '19588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19589', '1079', '1', 'Kitsuki-shi', 'JP.00.1859233', 'ASCII:Kitsuki-shi;ID:1859233', '17712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17712', '112', '19589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19590', '1079', '1', 'Kita-uwa-gun', 'JP.00.1859256', 'ASCII:Kita-uwa-gun;ID:1859256', '17713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17713', '112', '19590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19591', '1079', '1', 'Kita-uonuma-gun', 'JP.00.1859259', 'ASCII:Kita-uonuma-gun;ID:1859259', '17714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17714', '112', '19591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19592', '1079', '1', 'Kita-tsuru-gun', 'JP.00.1859260', 'ASCII:Kita-tsuru-gun;ID:1859260', '17715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17715', '112', '19592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19593', '1079', '1', 'Kita-tama-gun', 'JP.00.1859265', 'ASCII:Kita-tama-gun;ID:1859265', '17716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17716', '112', '19593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19594', '1079', '1', 'Kita-shitara-gun', 'JP.00.1859272', 'ASCII:Kita-shitara-gun;ID:1859272', '17717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17717', '112', '19594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19595', '1079', '1', 'Kita-saku-gun', 'JP.00.1859278', 'ASCII:Kita-saku-gun;ID:1859278', '17718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17718', '112', '19595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19596', '1079', '1', 'Kita-muro-gun', 'JP.00.1859297', 'ASCII:Kita-muro-gun;ID:1859297', '17719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17719', '112', '19596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19597', '1079', '1', 'Kita-matsuura-gun', 'JP.00.1859301', 'ASCII:Kita-matsuura-gun;ID:1859301', '17720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17720', '112', '19597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19598', '1079', '1', 'Kitakyūshū-shi', 'JP.07.1859306', 'ASCII:Kitakyushu-shi;ID:1859306', '17721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17721', '112', '19598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.07.1859306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19599', '1079', '1', 'Kita-kawachi-gun', 'JP.00.1859315', 'ASCII:Kita-kawachi-gun;ID:1859315', '17722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17722', '112', '19599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19600', '1079', '1', 'Kita-katsushika-gun', 'JP.00.1859316', 'ASCII:Kita-katsushika-gun;ID:1859316', '17723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17723', '112', '19600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19601', '1079', '1', 'Kitakata-shi', 'JP.00.1859317', 'ASCII:Kitakata-shi;ID:1859317', '17724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17724', '112', '19601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19602', '1079', '1', 'Kita-kambara-gun', 'JP.00.1859323', 'ASCII:Kita-kambara-gun;ID:1859323', '17725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17725', '112', '19602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859323» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19603', '1079', '1', 'Kitahama-mura', 'JP.00.1859334', 'ASCII:Kitahama-mura;ID:1859334', '17726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17726', '112', '19603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19604', '1079', '1', 'Kita-gun', 'JP.00.1859337', 'ASCII:Kita-gun;ID:1859337', '17727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17727', '112', '19604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19605', '1079', '1', 'Kita-gun', 'JP.05.1859338', 'ASCII:Kita;ID:1859338', '17728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17728', '112', '19605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.1859338» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19606', '1079', '1', 'Kita-gumma-gun', 'JP.00.1859339', 'ASCII:Kita-gumma-gun;ID:1859339', '17729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17729', '112', '19606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19607', '1079', '1', 'Kita-azumi-gun', 'JP.00.1859364', 'ASCII:Kita-azumi-gun;ID:1859364', '17730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17730', '112', '19607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19608', '1079', '1', 'Kita-amabe-gun', 'JP.00.1859366', 'ASCII:Kita-amabe-gun;ID:1859366', '17731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17731', '112', '19608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19609', '1079', '1', 'Kita-aizu-gun', 'JP.00.1859368', 'ASCII:Kita-aizu-gun;ID:1859368', '17732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17732', '112', '19609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859368» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19610', '1079', '1', 'Kitaadachi-gun', 'JP.00.1859369', 'ASCII:Kitaadachi-gun;ID:1859369', '17733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17733', '112', '19610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19611', '1079', '1', 'Kishiwada-shi', 'JP.00.1859382', 'ASCII:Kishiwada-shi;ID:1859382', '17734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17734', '112', '19611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19612', '1079', '1', 'Kinosaki-gun', 'JP.00.1859437', 'ASCII:Kinosaki-gun;ID:1859437', '17735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17735', '112', '19612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19613', '1079', '1', 'Kimitsu-shi', 'JP.00.1859468', 'ASCII:Kimitsu-shi;ID:1859468', '17736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17736', '112', '19613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19614', '1079', '1', 'Kikuchi-shi', 'JP.00.1859488', 'ASCII:Kikuchi-shi;ID:1859488', '17737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17737', '112', '19614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19615', '1079', '1', 'Kikuchi-gun', 'JP.00.1859490', 'ASCII:Kikuchi-gun;ID:1859490', '17738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17738', '112', '19615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19616', '1079', '1', 'Kazo-shi', 'JP.00.1859584', 'ASCII:Kazo-shi;ID:1859584', '17739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17739', '112', '19616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19617', '1079', '1', 'Kawasaki-shi', 'JP.00.1859635', 'ASCII:Kawasaki-shi;ID:1859635', '17740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17740', '112', '19617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19618', '1079', '1', 'Kawanuma-gun', 'JP.00.1859662', 'ASCII:Kawanuma-gun;ID:1859662', '17741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17741', '112', '19618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19619', '1079', '1', 'Kawanishi-shi', 'JP.00.1859671', 'ASCII:Kawanishi-shi;ID:1859671', '17742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17742', '112', '19619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19620', '1079', '1', 'Kawakami-gun', 'JP.00.1859703', 'ASCII:Kawakami-gun;ID:1859703', '17743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17743', '112', '19620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19621', '1079', '1', 'Kawaguchi-shi', 'JP.00.1859726', 'ASCII:Kawaguchi-shi;ID:1859726', '17744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17744', '112', '19621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19622', '1079', '1', 'Kawagoe-shi', 'JP.00.1859739', 'ASCII:Kawagoe-shi;ID:1859739', '17745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17745', '112', '19622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19623', '1079', '1', 'Kawachi-shi', 'JP.00.1859746', 'ASCII:Kawachi-shi;ID:1859746', '17746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17746', '112', '19623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859746» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19624', '1079', '1', 'Kawachi-Nagano-shi', 'JP.00.1859747', 'ASCII:Kawachi-Nagano-shi;ID:1859747', '17747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17747', '112', '19624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19625', '1079', '1', 'Kawachi-gun', 'JP.00.1859750', 'ASCII:Kawachi-gun;ID:1859750', '17748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17748', '112', '19625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19626', '1079', '1', 'Kawabe-gun', 'JP.00.1859755', 'ASCII:Kawabe-gun;ID:1859755', '17749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17749', '112', '19626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19627', '1079', '1', 'Katsuyama-shi', 'JP.00.1859762', 'ASCII:Katsuyama-shi;ID:1859762', '17750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17750', '112', '19627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859762» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19628', '1079', '1', 'Katsuura-gun', 'JP.00.1859771', 'ASCII:Katsuura-gun;ID:1859771', '17751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17751', '112', '19628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19629', '1079', '1', 'Katsuta-gun', 'JP.00.1859776', 'ASCII:Katsuta-gun;ID:1859776', '17752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17752', '112', '19629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859776» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19630', '1079', '1', 'Katano-shi', 'JP.00.1859848', 'ASCII:Katano-shi;ID:1859848', '17753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17753', '112', '19630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19631', '1079', '1', 'Kasuya-gun', 'JP.00.1859874', 'ASCII:Kasuya-gun;ID:1859874', '17754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17754', '112', '19631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19632', '1079', '1', 'Kasuga-shi', 'JP.00.1859888', 'ASCII:Kasuga-shi;ID:1859888', '17755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17755', '112', '19632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19633', '1079', '1', 'Kasugai-shi', 'JP.01.1859890', 'ASCII:Kasugai-shi;ID:1859890', '17756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17756', '112', '19633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.01.1859890» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19634', '1079', '1', 'Kashiwazaki-shi', 'JP.00.1859907', 'ASCII:Kashiwazaki-shi;ID:1859907', '17757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17757', '112', '19634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19635', '1079', '1', 'Kashiwara-shi', 'JP.00.1859912', 'ASCII:Kashiwara-shi;ID:1859912', '17758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17758', '112', '19635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19636', '1079', '1', 'Kashima-shi', 'JP.00.1859936', 'ASCII:Kashima-shi;ID:1859936', '17759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17759', '112', '19636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19637', '1079', '1', 'Kashihara-shi', 'JP.00.1859951', 'ASCII:Kashihara-shi;ID:1859951', '17760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17760', '112', '19637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19638', '1079', '1', 'Kasaoka-shi', 'JP.00.1859989', 'ASCII:Kasaoka-shi;ID:1859989', '17761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17761', '112', '19638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1859989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19639', '1079', '1', 'Kariya-shi', 'JP.00.1860033', 'ASCII:Kariya-shi;ID:1860033', '17762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17762', '112', '19639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19640', '1079', '1', 'Kanzaki-gun', 'JP.00.1860088', 'ASCII:Kanzaki-gun;ID:1860088', '17763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17763', '112', '19640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19641', '1079', '1', 'Kanuma-shi', 'JP.00.1860097', 'ASCII:Kanuma-shi;ID:1860097', '17764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17764', '112', '19641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19642', '1079', '1', 'Kanra-gun', 'JP.00.1860108', 'ASCII:Kanra-gun;ID:1860108', '17765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17765', '112', '19642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19643', '1079', '1', 'Kanonji-shi', 'JP.00.1860119', 'ASCII:Kanonji-shi;ID:1860119', '17766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17766', '112', '19643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19644', '1079', '1', 'Kani-gun', 'JP.00.1860188', 'ASCII:Kani-gun;ID:1860188', '17767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17767', '112', '19644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19645', '1079', '1', 'Kanazawa-shi', 'JP.00.1860240', 'ASCII:Kanazawa-shi;ID:1860240', '17768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17768', '112', '19645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19646', '1079', '1', 'Kamo-shi', 'JP.00.1860308', 'ASCII:Kamo-shi;ID:1860308', '17769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17769', '112', '19646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19647', '1079', '1', 'Kamo-gun', 'JP.00.1860326', 'ASCII:Kamo-gun;ID:1860326', '17770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17770', '112', '19647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19648', '1079', '1', 'Kamo-gun', 'JP.00.1860327', 'ASCII:Kamo-gun;ID:1860327', '17771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17771', '112', '19648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19649', '1079', '1', 'Kamo-gun', 'JP.00.1860328', 'ASCII:Kamo-gun;ID:1860328', '17772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17772', '112', '19649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19650', '1079', '1', 'Kami-tsuga-gun', 'JP.00.1860399', 'ASCII:Kami-tsuga-gun;ID:1860399', '17773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17773', '112', '19650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19651', '1079', '1', 'Kami-takai-gun', 'JP.00.1860414', 'ASCII:Kami-takai-gun;ID:1860414', '17774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17774', '112', '19651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19652', '1079', '1', 'Kami-niikawa-gun', 'JP.00.1860471', 'ASCII:Kami-niikawa-gun;ID:1860471', '17775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17775', '112', '19652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19653', '1079', '1', 'Kami-ina-gun', 'JP.00.1860552', 'ASCII:Kami-ina-gun;ID:1860552', '17776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17776', '112', '19653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19654', '1079', '1', 'Kami-gun', 'JP.00.1860583', 'ASCII:Kami-gun;ID:1860583', '17777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17777', '112', '19654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860583» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19655', '1079', '1', 'Kami-fukuoka-shi', 'JP.00.1860594', 'ASCII:Kami-fukuoka-shi;ID:1860594', '17778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17778', '112', '19655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19656', '1079', '1', 'Kami-agata-gun', 'JP.00.1860621', 'ASCII:Kami-agata-gun;ID:1860621', '17779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17779', '112', '19656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19657', '1079', '1', 'Kameoka-shi', 'JP.00.1860633', 'ASCII:Kameoka-shi;ID:1860633', '17780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17780', '112', '19657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19658', '1079', '1', 'Kamakura-shi', 'JP.00.1860670', 'ASCII:Kamakura-shi;ID:1860670', '17781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17781', '112', '19658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19659', '1079', '1', 'Kako-gun', 'JP.00.1860701', 'ASCII:Kako-gun;ID:1860701', '17782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17782', '112', '19659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19660', '1079', '1', 'Kakogawa-shi', 'JP.00.1860702', 'ASCII:Kakogawa-shi;ID:1860702', '17783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17783', '112', '19660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19661', '1079', '1', 'Kakamigahara-shi', 'JP.00.1860734', 'ASCII:Kakamigahara-shi;ID:1860734', '17784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17784', '112', '19661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19662', '1079', '1', 'Kaizuka-shi', 'JP.00.1860764', 'ASCII:Kaizuka-shi;ID:1860764', '17785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17785', '112', '19662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19663', '1079', '1', 'Kaisō-gun', 'JP.00.1860774', 'ASCII:Kaiso-gun;ID:1860774', '17786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17786', '112', '19663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19664', '1079', '1', 'Kainan-shi', 'JP.00.1860782', 'ASCII:Kainan-shi;ID:1860782', '17787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17787', '112', '19664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19665', '1079', '1', 'Kaifu-gun', 'JP.00.1860803', 'ASCII:Kaifu-gun;ID:1860803', '17788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17788', '112', '19665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19666', '1079', '1', 'Kahoku-gun', 'JP.00.1860811', 'ASCII:Kahoku-gun;ID:1860811', '17789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17789', '112', '19666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19667', '1079', '1', 'Kaho-gun', 'JP.00.1860814', 'ASCII:Kaho-gun;ID:1860814', '17790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17790', '112', '19667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19668', '1079', '1', 'Kagoshima-shi', 'JP.00.1860823', 'ASCII:Kagoshima-shi;ID:1860823', '17791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17791', '112', '19668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19669', '1079', '1', 'Kagawa-gun', 'JP.00.1860835', 'ASCII:Kagawa-gun;ID:1860835', '17792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17792', '112', '19669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19670', '1079', '1', 'Kaga-shi', 'JP.00.1860845', 'ASCII:Kaga-shi;ID:1860845', '17793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17793', '112', '19670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19671', '1079', '1', 'Kadoma-shi', 'JP.00.1860870', 'ASCII:Kadoma-shi;ID:1860870', '17794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17794', '112', '19671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19672', '1079', '1', 'Jōyō-shi', 'JP.00.1860951', 'ASCII:Joyo-shi;ID:1860951', '17795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17795', '112', '19672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19673', '1079', '1', 'Jōetsu-shi', 'JP.00.1860992', 'ASCII:Joetsu-shi;ID:1860992', '17796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17796', '112', '19673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19674', '1079', '1', 'Jōdō-gun', 'JP.00.1860995', 'ASCII:Jodo-gun;ID:1860995', '17797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17797', '112', '19674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19675', '1079', '1', 'Jōbō-gun', 'JP.00.1860996', 'ASCII:Jobo-gun;ID:1860996', '17798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17798', '112', '19675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1860996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19676', '1079', '1', 'Jinseki-gun', 'JP.00.1861022', 'ASCII:Jinseki-gun;ID:1861022', '17799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17799', '112', '19676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19677', '1079', '1', 'Izumo-shi', 'JP.00.1861082', 'ASCII:Izumo-shi;ID:1861082', '17800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17800', '112', '19677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19678', '1079', '1', 'Izumi-shi', 'JP.00.1861089', 'ASCII:Izumi-shi;ID:1861089', '17801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17801', '112', '19678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19679', '1079', '1', 'Izumi-shi', 'JP.00.1861090', 'ASCII:Izumi-shi;ID:1861090', '17802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17802', '112', '19679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19680', '1079', '1', 'Izumiōtsu-shi', 'JP.00.1861094', 'ASCII:Izumiotsu-shi;ID:1861094', '17803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17803', '112', '19680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19681', '1079', '1', 'iyo mishima', 'JP.00.1861138', 'ASCII:iyo mishima;ID:1861138', '17804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17804', '112', '19681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861138» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19682', '1079', '1', 'Iyo-gun', 'JP.05.1861141', 'ASCII:Iyo;ID:1861141', '17805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17805', '112', '19682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.1861141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19683', '1079', '1', 'Iwatsuki-shi', 'JP.00.1861163', 'ASCII:Iwatsuki-shi;ID:1861163', '17806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17806', '112', '19683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19684', '1079', '1', 'Iwata-shi', 'JP.00.1861167', 'ASCII:Iwata-shi;ID:1861167', '17807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17807', '112', '19684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19685', '1079', '1', 'Iwata-gun', 'JP.00.1861169', 'ASCII:Iwata-gun;ID:1861169', '17808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17808', '112', '19685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19686', '1079', '1', 'Iwakuni-shi', 'JP.00.1861209', 'ASCII:Iwakuni-shi;ID:1861209', '17809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17809', '112', '19686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19687', '1079', '1', 'Iwai-shi', 'JP.00.1861217', 'ASCII:Iwai-shi;ID:1861217', '17810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17810', '112', '19687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19688', '1079', '1', 'Iwafune-gun', 'JP.00.1861238', 'ASCII:Iwafune-gun;ID:1861238', '17811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17811', '112', '19688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19689', '1079', '1', 'Itoshima-gun', 'JP.00.1861272', 'ASCII:Itoshima-gun;ID:1861272', '17812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17812', '112', '19689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19690', '1079', '1', 'Itoman-shi', 'JP.00.1861279', 'ASCII:Itoman-shi;ID:1861279', '17813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17813', '112', '19690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19691', '1079', '1', 'Ito-gun', 'JP.00.1861287', 'ASCII:Ito-gun;ID:1861287', '17814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17814', '112', '19691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19692', '1079', '1', 'Itano-gun', 'JP.00.1861303', 'ASCII:Itano-gun;ID:1861303', '17815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17815', '112', '19692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19693', '1079', '1', 'Itami-shi', 'JP.00.1861308', 'ASCII:Itami-shi;ID:1861308', '17816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17816', '112', '19693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19694', '1079', '1', 'Ishikawa-shi', 'JP.00.1861384', 'ASCII:Ishikawa-shi;ID:1861384', '17817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17817', '112', '19694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861384» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19695', '1079', '1', 'Ishikawa-gun', 'JP.00.1861388', 'ASCII:Ishikawa-gun;ID:1861388', '17818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17818', '112', '19695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19696', '1079', '1', 'Ishigaki-shi', 'JP.00.1861412', 'ASCII:Ishigaki-shi;ID:1861412', '17819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17819', '112', '19696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19697', '1079', '1', 'Ise-shi', 'JP.00.1861434', 'ASCII:Ise-shi;ID:1861434', '17820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17820', '112', '19697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861434» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19698', '1079', '1', 'Isesaki-shi', 'JP.00.1861435', 'ASCII:Isesaki-shi;ID:1861435', '17821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17821', '112', '19698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19699', '1079', '1', 'Isehara-shi', 'JP.00.1861448', 'ASCII:Isehara-shi;ID:1861448', '17822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17822', '112', '19699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19700', '1079', '1', 'Iruma-shi', 'JP.34.1861469', 'ASCII:Iruma-shi;ID:1861469', '17823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17823', '112', '19700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.34.1861469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19701', '1079', '1', 'Iruma-gun', 'JP.00.1861470', 'ASCII:Iruma-gun;ID:1861470', '17824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17824', '112', '19701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19702', '1079', '1', 'Innoshima-shi', 'JP.00.1861585', 'ASCII:Innoshima-shi;ID:1861585', '17825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17825', '112', '19702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19703', '1079', '1', 'Innami-gun', 'JP.00.1861588', 'ASCII:Innami-gun;ID:1861588', '17826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17826', '112', '19703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19704', '1079', '1', 'Inazawa-shi', 'JP.00.1861601', 'ASCII:Inazawa-shi;ID:1861601', '17827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17827', '112', '19704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19705', '1079', '1', 'Ina-shi', 'JP.00.1861606', 'ASCII:Ina-shi;ID:1861606', '17828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17828', '112', '19705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19706', '1079', '1', 'Inasa-gun', 'JP.00.1861609', 'ASCII:Inasa-gun;ID:1861609', '17829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17829', '112', '19706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19707', '1079', '1', 'Inagi-shi', 'JP.00.1861634', 'ASCII:Inagi-shi;ID:1861634', '17830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17830', '112', '19707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19708', '1079', '1', 'Imizu-gun', 'JP.00.1861653', 'ASCII:Imizu-gun;ID:1861653', '17831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17831', '112', '19708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19709', '1079', '1', 'Ikoma-shi', 'JP.00.1861747', 'ASCII:Ikoma-shi;ID:1861747', '17832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17832', '112', '19709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19710', '1079', '1', 'Ikoma-gun', 'JP.00.1861748', 'ASCII:Ikoma-gun;ID:1861748', '17833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17833', '112', '19710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19711', '1079', '1', 'Iki-gun', 'JP.00.1861758', 'ASCII:Iki-gun;ID:1861758', '17834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17834', '112', '19711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19712', '1079', '1', 'Ikeda-shi', 'JP.00.1861785', 'ASCII:Ikeda-shi;ID:1861785', '17835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17835', '112', '19712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19713', '1079', '1', 'Ika-gun', 'JP.00.1861823', 'ASCII:Ika-gun;ID:1861823', '17836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17836', '112', '19713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19714', '1079', '1', 'Iizuka-shi', 'JP.00.1861834', 'ASCII:Iizuka-shi;ID:1861834', '17837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17837', '112', '19714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19715', '1079', '1', 'Iiyama-shi', 'JP.00.1861837', 'ASCII:Iiyama-shi;ID:1861837', '17838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17838', '112', '19715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861837» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19716', '1079', '1', 'Iida-shi', 'JP.00.1861858', 'ASCII:Iida-shi;ID:1861858', '17839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17839', '112', '19716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19717', '1079', '1', 'Ihara-gun', 'JP.00.1861875', 'ASCII:Ihara-gun;ID:1861875', '17840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17840', '112', '19717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19718', '1079', '1', 'Ichishi-gun', 'JP.00.1861926', 'ASCII:Ichishi-gun;ID:1861926', '17841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17841', '112', '19718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19719', '1079', '1', 'Ichinomiya-shi', 'JP.00.1861940', 'ASCII:Ichinomiya-shi;ID:1861940', '17842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17842', '112', '19719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19720', '1079', '1', 'Ichikawa-shi', 'JP.00.1861964', 'ASCII:Ichikawa-shi;ID:1861964', '17843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17843', '112', '19720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1861964» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19721', '1079', '1', 'Ibusuki-shi', 'JP.00.1862007', 'ASCII:Ibusuki-shi;ID:1862007', '17844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17844', '112', '19721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19722', '1079', '1', 'Ibusuki-gun', 'JP.00.1862009', 'ASCII:Ibusuki-gun;ID:1862009', '17845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17845', '112', '19722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19723', '1079', '1', 'Ibo-gun', 'JP.00.1862022', 'ASCII:Ibo-gun;ID:1862022', '17846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17846', '112', '19723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19724', '1079', '1', 'Ibaraki-shi', 'JP.00.1862032', 'ASCII:Ibaraki-shi;ID:1862032', '17847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17847', '112', '19724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19725', '1079', '1', 'Hyūga-shi', 'JP.00.1862036', 'ASCII:Hyuga-shi;ID:1862036', '17848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17848', '112', '19725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19726', '1079', '1', 'Hōya-shi', 'JP.00.1862071', 'ASCII:Hoya-shi;ID:1862071', '17849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17849', '112', '19726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19727', '1079', '1', 'Hōtaku-gun', 'JP.00.1862094', 'ASCII:Hotaku-gun;ID:1862094', '17850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17850', '112', '19727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19728', '1079', '1', 'Honjō-shi', 'JP.00.1862192', 'ASCII:Honjo-shi;ID:1862192', '17851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17851', '112', '19728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19729', '1079', '1', 'Hondo-shi', 'JP.00.1862227', 'ASCII:Hondo-shi;ID:1862227', '17852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17852', '112', '19729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19730', '1079', '1', 'Hoi-gun', 'JP.00.1862294', 'ASCII:Hoi-gun;ID:1862294', '17853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17853', '112', '19730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19731', '1079', '1', 'Hōfu-shi', 'JP.00.1862301', 'ASCII:Hofu-shi;ID:1862301', '17854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17854', '112', '19731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19732', '1079', '1', 'Hitoyoshi-shi', 'JP.00.1862350', 'ASCII:Hitoyoshi-shi;ID:1862350', '17855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17855', '112', '19732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19733', '1079', '1', 'Hita-shi', 'JP.00.1862367', 'ASCII:Hita-shi;ID:1862367', '17856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17856', '112', '19733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19734', '1079', '1', 'Hisai-shi', 'JP.00.1862387', 'ASCII:Hisai-shi;ID:1862387', '17857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17857', '112', '19734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862387» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19735', '1079', '1', 'Hiroshima-shi', 'JP.00.1862412', 'ASCII:Hiroshima-shi;ID:1862412', '17858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17858', '112', '19735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19736', '1079', '1', 'Hiratsuka-shi', 'JP.00.1862461', 'ASCII:Hiratsuka-shi;ID:1862461', '17859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17859', '112', '19736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19737', '1079', '1', 'Hirata-shi', 'JP.00.1862463', 'ASCII:Hirata-shi;ID:1862463', '17860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17860', '112', '19737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19738', '1079', '1', 'Hirara-shi', 'JP.00.1862504', 'ASCII:Hirara-shi;ID:1862504', '17861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17861', '112', '19738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19739', '1079', '1', 'Hiraoka-shi', 'JP.00.1862508', 'ASCII:Hiraoka-shi;ID:1862508', '17862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17862', '112', '19739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19740', '1079', '1', 'Hirakata-shi', 'JP.00.1862538', 'ASCII:Hirakata-shi;ID:1862538', '17863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17863', '112', '19740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19741', '1079', '1', 'Hioki-gun', 'JP.00.1862568', 'ASCII:Hioki-gun;ID:1862568', '17864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17864', '112', '19741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19742', '1079', '1', 'Hino-shi', 'JP.00.1862576', 'ASCII:Hino-shi;ID:1862576', '17865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17865', '112', '19742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19743', '1079', '1', 'Hinokawa-gun', 'JP.00.1862585', 'ASCII:Hinokawa-gun;ID:1862585', '17866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17866', '112', '19743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19744', '1079', '1', 'Hino-gun', 'JP.00.1862590', 'ASCII:Hino-gun;ID:1862590', '17867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17867', '112', '19744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19745', '1079', '1', 'Himi-shi', 'JP.00.1862610', 'ASCII:Himi-shi;ID:1862610', '17868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17868', '112', '19745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19746', '1079', '1', 'Himeji-shi', 'JP.00.1862625', 'ASCII:Himeji-shi;ID:1862625', '17869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17869', '112', '19746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19747', '1079', '1', 'Hikone-shi', 'JP.00.1862635', 'ASCII:Hikone-shi;ID:1862635', '17870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17870', '112', '19747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19748', '1079', '1', 'Hiki-gun', 'JP.00.1862655', 'ASCII:Hiki-gun;ID:1862655', '17871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17871', '112', '19748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19749', '1079', '1', 'Hikari-shi', 'JP.00.1862667', 'ASCII:Hikari-shi;ID:1862667', '17872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17872', '112', '19749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19750', '1079', '1', 'Higashi-yatsushiro-gun', 'JP.00.1862702', 'ASCII:Higashi-yatsushiro-gun;ID:1862702', '17873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17873', '112', '19750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19751', '1079', '1', 'Higashi-yamato-shi', 'JP.00.1862703', 'ASCII:Higashi-yamato-shi;ID:1862703', '17874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17874', '112', '19751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19752', '1079', '1', 'Higashiyamanashi-gun', 'JP.00.1862705', 'ASCII:Higashiyamanashi-gun;ID:1862705', '17875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17875', '112', '19752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19753', '1079', '1', 'Higashi-usuki-gun', 'JP.00.1862717', 'ASCII:Higashi-usuki-gun;ID:1862717', '17876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17876', '112', '19753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19754', '1079', '1', 'Higashi-tonami-gun', 'JP.00.1862725', 'ASCII:Higashi-tonami-gun;ID:1862725', '17877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17877', '112', '19754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19755', '1079', '1', 'Higashi-tagawa-gun', 'JP.00.1862730', 'ASCII:Higashi-tagawa-gun;ID:1862730', '17878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17878', '112', '19755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19756', '1079', '1', 'Higashi-sonogi-gun', 'JP.00.1862734', 'ASCII:Higashi-sonogi-gun;ID:1862734', '17879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17879', '112', '19756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19757', '1079', '1', 'Higashi-ōsaka-shi', 'JP.00.1862751', 'ASCII:Higashi-osaka-shi;ID:1862751', '17880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17880', '112', '19757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19758', '1079', '1', 'Higashi-muro-gun', 'JP.00.1862767', 'ASCII:Higashi-muro-gun;ID:1862767', '17881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17881', '112', '19758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862767» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19759', '1079', '1', 'Higashi-murayama-shi', 'JP.00.1862768', 'ASCII:Higashi-murayama-shi;ID:1862768', '17882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17882', '112', '19759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862768» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19760', '1079', '1', 'Higashimatsuyama-shi', 'JP.00.1862777', 'ASCII:Higashimatsuyama-shi;ID:1862777', '17883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17883', '112', '19760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19761', '1079', '1', 'Higashi-matsuura-gun', 'JP.00.1862779', 'ASCII:Higashi-matsuura-gun;ID:1862779', '17884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17884', '112', '19761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19762', '1079', '1', 'Higashi-kurume-shi', 'JP.00.1862785', 'ASCII:Higashi-kurume-shi;ID:1862785', '17885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17885', '112', '19762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19763', '1079', '1', 'Higashi-kubiki-gun', 'JP.00.1862789', 'ASCII:Higashi-kubiki-gun;ID:1862789', '17886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17886', '112', '19763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19764', '1079', '1', 'Higashi-katsushika-gun', 'JP.00.1862797', 'ASCII:Higashi-katsushika-gun;ID:1862797', '17887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17887', '112', '19764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19765', '1079', '1', 'Higashi-kasugai-gun', 'JP.01.1862799', 'ASCII:Higashi-kasugai-gun;ID:1862799', '17888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17888', '112', '19765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.01.1862799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19766', '1079', '1', 'Higashi-kamo-gun', 'JP.00.1862803', 'ASCII:Higashi-kamo-gun;ID:1862803', '17889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17889', '112', '19766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19767', '1079', '1', 'Higashi-kambara-gun', 'JP.00.1862804', 'ASCII:Higashi-kambara-gun;ID:1862804', '17890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17890', '112', '19767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19768', '1079', '1', 'Higashi-hiroshima-shi', 'JP.00.1862821', 'ASCII:Higashi-hiroshima-shi;ID:1862821', '17891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17891', '112', '19768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19769', '1079', '1', 'Higashi-chikuma-gun', 'JP.00.1862841', 'ASCII:Higashi-chikuma-gun;ID:1862841', '17892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17892', '112', '19769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19770', '1079', '1', 'Hidaka-gun', 'JP.00.1862875', 'ASCII:Hidaka-gun;ID:1862875', '17893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17893', '112', '19770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19771', '1079', '1', 'Hiba-gun', 'JP.00.1862891', 'ASCII:Hiba-gun;ID:1862891', '17894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17894', '112', '19771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19772', '1079', '1', 'Hekinan-shi', 'JP.00.1862911', 'ASCII:Hekinan-shi;ID:1862911', '17895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17895', '112', '19772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19773', '1079', '1', 'Hekikai-gun', 'JP.00.1862913', 'ASCII:Hekikai-gun;ID:1862913', '17896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17896', '112', '19773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19774', '1079', '1', 'Hazu-gun', 'JP.00.1862948', 'ASCII:Hazu-gun;ID:1862948', '17897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17897', '112', '19774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1862948» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19775', '1079', '1', 'Hatogaya-shi', 'JP.00.1863022', 'ASCII:Hatogaya-shi;ID:1863022', '17898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17898', '112', '19775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19776', '1079', '1', 'Hata-gun', 'JP.00.1863048', 'ASCII:Hata-gun;ID:1863048', '17899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17899', '112', '19776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19777', '1079', '1', 'Hasuda-shi', 'JP.00.1863058', 'ASCII:Hasuda-shi;ID:1863058', '17900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17900', '112', '19777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19778', '1079', '1', 'Hashimoto-shi', 'JP.00.1863079', 'ASCII:Hashimoto-shi;ID:1863079', '17901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17901', '112', '19778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19779', '1079', '1', 'Hashima-shi', 'JP.00.1863084', 'ASCII:Hashima-shi;ID:1863084', '17902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17902', '112', '19779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19780', '1079', '1', 'Hashima-gun', 'JP.00.1863085', 'ASCII:Hashima-gun;ID:1863085', '17903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17903', '112', '19780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19781', '1079', '1', 'Hannō-shi', 'JP.00.1863182', 'ASCII:Hanno-shi;ID:1863182', '17904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17904', '112', '19781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19782', '1079', '1', 'Hannan-chō', 'JP.00.1863185', 'ASCII:Hannan-cho;ID:1863185', '17905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17905', '112', '19782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19783', '1079', '1', 'Hanishina-gun', 'JP.00.1863187', 'ASCII:Hanishina-gun;ID:1863187', '17906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17906', '112', '19783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19784', '1079', '1', 'Handa-shi', 'JP.00.1863204', 'ASCII:Handa-shi;ID:1863204', '17907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17907', '112', '19784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19785', '1079', '1', 'Hamana-gun', 'JP.00.1863283', 'ASCII:Hamana-gun;ID:1863283', '17908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17908', '112', '19785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19786', '1079', '1', 'Hamamatsu-shi', 'JP.00.1863288', 'ASCII:Hamamatsu-shi;ID:1863288', '17909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17909', '112', '19786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19787', '1079', '1', 'Hamakita-shi', 'JP.00.1863291', 'ASCII:Hamakita-shi;ID:1863291', '17910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17910', '112', '19787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19788', '1079', '1', 'Hamada-shi', 'JP.00.1863308', 'ASCII:Hamada-shi;ID:1863308', '17911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17911', '112', '19788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19789', '1079', '1', 'Hakui-shi', 'JP.00.1863340', 'ASCII:Hakui-shi;ID:1863340', '17912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17912', '112', '19789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19790', '1079', '1', 'Haibara-gun', 'JP.00.1863397', 'ASCII:Haibara-gun;ID:1863397', '17913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17913', '112', '19790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19791', '1079', '1', 'Haguri-gun', 'JP.00.1863407', 'ASCII:Haguri-gun;ID:1863407', '17914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17914', '112', '19791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19792', '1079', '1', 'Hagi-shi', 'JP.00.1863413', 'ASCII:Hagi-shi;ID:1863413', '17915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17915', '112', '19792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19793', '1079', '1', 'Hadano-shi', 'JP.00.1863429', 'ASCII:Hadano-shi;ID:1863429', '17916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17916', '112', '19793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19794', '1079', '1', 'Hachijō-shichō', 'JP.00.1863453', 'ASCII:Hachijo-shicho;ID:1863453', '17917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17917', '112', '19794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19795', '1079', '1', 'Habikino-shi', 'JP.00.1863476', 'ASCII:Habikino-shi;ID:1863476', '17918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17918', '112', '19795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19796', '1079', '1', 'Gyōda-shi', 'JP.00.1863481', 'ASCII:Gyoda-shi;ID:1863481', '17919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17919', '112', '19796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19797', '1079', '1', 'Gushikawa-shi', 'JP.00.1863491', 'ASCII:Gushikawa-shi;ID:1863491', '17920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17920', '112', '19797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19798', '1079', '1', 'Gumma-gun', 'JP.00.1863502', 'ASCII:Gumma-gun;ID:1863502', '17921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17921', '112', '19798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19799', '1079', '1', 'Gōtsu-shi', 'JP.00.1863519', 'ASCII:Gotsu-shi;ID:1863519', '17922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17922', '112', '19799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19800', '1079', '1', 'Gotemba-shi', 'JP.00.1863526', 'ASCII:Gotemba-shi;ID:1863526', '17923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17923', '112', '19800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19801', '1079', '1', 'Gose-shi', 'JP.00.1863538', 'ASCII:Gose-shi;ID:1863538', '17924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17924', '112', '19801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19802', '1079', '1', 'Gosen-shi', 'JP.00.1863539', 'ASCII:Gosen-shi;ID:1863539', '17925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17925', '112', '19802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19803', '1079', '1', 'Gojō-shi', 'JP.00.1863590', 'ASCII:Gojo-shi;ID:1863590', '17926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17926', '112', '19803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19804', '1079', '1', 'Ginowan-shi', 'JP.00.1863626', 'ASCII:Ginowan-shi;ID:1863626', '17927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17927', '112', '19804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19805', '1079', '1', 'Gifu-shi', 'JP.00.1863639', 'ASCII:Gifu-shi;ID:1863639', '17928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17928', '112', '19805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19806', '1079', '1', 'Gamō-gun', 'JP.00.1863686', 'ASCII:Gamo-gun;ID:1863686', '17929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17929', '112', '19806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19807', '1079', '1', 'Gamagōri-shi', 'JP.00.1863692', 'ASCII:Gamagori-shi;ID:1863692', '17930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17930', '112', '19807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19808', '1079', '1', 'Fuwa-gun', 'JP.00.1863710', 'ASCII:Fuwa-gun;ID:1863710', '17931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17931', '112', '19808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19809', '1079', '1', 'Futtsu-shi', 'JP.00.1863711', 'ASCII:Futtsu-shi;ID:1863711', '17932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17932', '112', '19809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19810', '1079', '1', 'Fussa-shi', 'JP.00.1863780', 'ASCII:Fussa-shi;ID:1863780', '17933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17933', '112', '19810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19811', '1079', '1', 'Fuse-shi', 'JP.00.1863796', 'ASCII:Fuse-shi;ID:1863796', '17934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17934', '112', '19811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19812', '1079', '1', 'Funabashi-shi', 'JP.04.1863903', 'ASCII:Funabashi-shi;ID:1863903', '17935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17935', '112', '19812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.04.1863903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19813', '1079', '1', 'Fukuyama-shi', 'JP.00.1863914', 'ASCII:Fukuyama-shi;ID:1863914', '17936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17936', '112', '19813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19814', '1079', '1', 'Fukuroi-shi', 'JP.00.1863944', 'ASCII:Fukuroi-shi;ID:1863944', '17937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17937', '112', '19814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863944» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19815', '1079', '1', 'Fukuoka-shi', 'JP.00.1863955', 'ASCII:Fukuoka-shi;ID:1863955', '17938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17938', '112', '19815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19816', '1079', '1', 'Fukui-shi', 'JP.00.1863982', 'ASCII:Fukui-shi;ID:1863982', '17939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17939', '112', '19816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863982» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19817', '1079', '1', 'Fukue-shi', 'JP.00.1863993', 'ASCII:Fukue-shi;ID:1863993', '17940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17940', '112', '19817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1863993» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19818', '1079', '1', 'Fukuchiyama-shi', 'JP.00.1864008', 'ASCII:Fukuchiyama-shi;ID:1864008', '17941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17941', '112', '19818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19819', '1079', '1', 'Fujiyoshida-shi', 'JP.00.1864076', 'ASCII:Fujiyoshida-shi;ID:1864076', '17942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17942', '112', '19819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19820', '1079', '1', 'Fuji-shi', 'JP.00.1864089', 'ASCII:Fuji-shi;ID:1864089', '17943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17943', '112', '19820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19821', '1079', '1', 'Fujisawa-shi', 'JP.00.1864091', 'ASCII:Fujisawa-shi;ID:1864091', '17944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17944', '112', '19821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19822', '1079', '1', 'Fujinomiya-shi', 'JP.00.1864104', 'ASCII:Fujinomiya-shi;ID:1864104', '17945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17945', '112', '19822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19823', '1079', '1', 'Fujimi-shi', 'JP.00.1864112', 'ASCII:Fujimi-shi;ID:1864112', '17946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17946', '112', '19823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19824', '1079', '1', 'Fujiidera-shi', 'JP.00.1864125', 'ASCII:Fujiidera-shi;ID:1864125', '17947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17947', '112', '19824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19825', '1079', '1', 'Fuji-gun', 'JP.00.1864129', 'ASCII:Fuji-gun;ID:1864129', '17948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17948', '112', '19825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19826', '1079', '1', 'Fujieda-shi', 'JP.00.1864131', 'ASCII:Fujieda-shi;ID:1864131', '17949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17949', '112', '19826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19827', '1079', '1', 'Fugeshi-gun', 'JP.00.1864136', 'ASCII:Fugeshi-gun;ID:1864136', '17950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17950', '112', '19827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19828', '1079', '1', 'Fuchū-shi', 'JP.00.1864148', 'ASCII:Fuchu-shi;ID:1864148', '17951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17951', '112', '19828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19829', '1079', '1', 'Ena-gun', 'JP.00.1864208', 'ASCII:Ena-gun;ID:1864208', '17952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17952', '112', '19829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19830', '1079', '1', 'Echi-gun', 'JP.00.1864254', 'ASCII:Echi-gun;ID:1864254', '17953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17953', '112', '19830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19831', '1079', '1', 'Ebina-shi', 'JP.00.1864314', 'ASCII:Ebina-shi;ID:1864314', '17954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17954', '112', '19831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19832', '1079', '1', 'Daitō-shi', 'JP.00.1864413', 'ASCII:Daito-shi;ID:1864413', '17955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17955', '112', '19832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19833', '1079', '1', 'Chōfu-shi', 'JP.00.1864514', 'ASCII:Chofu-shi;ID:1864514', '17956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17956', '112', '19833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19834', '1079', '1', 'Chiyoda-ku', 'JP.40.1864529', 'ASCII:Chiyoda-ku;ID:1864529', '17957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17957', '112', '19834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.40.1864529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19835', '1079', '1', 'Chita-shi', 'JP.00.1864539', 'ASCII:Chita-shi;ID:1864539', '17958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17958', '112', '19835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19836', '1079', '1', 'Chita-gun', 'JP.00.1864542', 'ASCII:Chita-gun;ID:1864542', '17959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17959', '112', '19836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864542» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19837', '1079', '1', 'Chiryū-shi', 'JP.00.1864548', 'ASCII:Chiryu-shi;ID:1864548', '17960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17960', '112', '19837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19838', '1079', '1', 'Chino-shi', 'JP.00.1864555', 'ASCII:Chino-shi;ID:1864555', '17961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17961', '112', '19838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19839', '1079', '1', 'Chikushino-shi', 'JP.00.1864572', 'ASCII:Chikushino-shi;ID:1864572', '17962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17962', '112', '19839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19840', '1079', '1', 'Chikushi-gun', 'JP.00.1864574', 'ASCII:Chikushi-gun;ID:1864574', '17963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17963', '112', '19840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19841', '1079', '1', 'Chikujō-gun', 'JP.00.1864588', 'ASCII:Chikujo-gun;ID:1864588', '17964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17964', '112', '19841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19842', '1079', '1', 'Chikugo-shi', 'JP.00.1864591', 'ASCII:Chikugo-shi;ID:1864591', '17965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17965', '112', '19842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19843', '1079', '1', 'Chiisagata-gun', 'JP.00.1864613', 'ASCII:Chiisagata-gun;ID:1864613', '17966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17966', '112', '19843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19844', '1079', '1', 'Chihaya-Akasaka-mura', 'JP.00.1864615', 'ASCII:Chihaya-Akasaka-mura;ID:1864615', '17967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17967', '112', '19844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19845', '1079', '1', 'Chigasaki-shi', 'JP.00.1864622', 'ASCII:Chigasaki-shi;ID:1864622', '17968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17968', '112', '19845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19846', '1079', '1', 'Chichibu-gun', 'JP.00.1864636', 'ASCII:Chichibu-gun;ID:1864636', '17969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17969', '112', '19846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19847', '1079', '1', 'Buzen-shi', 'JP.00.1864660', 'ASCII:Buzen-shi;ID:1864660', '17970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17970', '112', '19847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19848', '1079', '1', 'Bungo-Takada-shi', 'JP.00.1864667', 'ASCII:Bungo-Takada-shi;ID:1864667', '17971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17971', '112', '19848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19849', '1079', '1', 'Bizen-shi', 'JP.00.1864698', 'ASCII:Bizen-shi;ID:1864698', '17972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17972', '112', '19849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19850', '1079', '1', 'Bisai-shi', 'JP.00.1864720', 'ASCII:Bisai-shi;ID:1864720', '17973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17973', '112', '19850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19851', '1079', '1', 'Ayauta-chō', 'JP.00.1864863', 'ASCII:Ayauta-cho;ID:1864863', '17974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17974', '112', '19851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19852', '1079', '1', 'Ayase-shi', 'JP.00.1864864', 'ASCII:Ayase-shi;ID:1864864', '17975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17975', '112', '19852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19853', '1079', '1', 'Ayabe-shi', 'JP.00.1864872', 'ASCII:Ayabe-shi;ID:1864872', '17976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17976', '112', '19853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19854', '1079', '1', 'Awa-gun', 'JP.00.1864901', 'ASCII:Awa-gun;ID:1864901', '17977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17977', '112', '19854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19855', '1079', '1', 'Awa-gun', 'JP.00.1864902', 'ASCII:Awa-gun;ID:1864902', '17978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17978', '112', '19855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19856', '1079', '1', 'Atsumi-gun', 'JP.00.1864922', 'ASCII:Atsumi-gun;ID:1864922', '17979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17979', '112', '19856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19857', '1079', '1', 'Atsugi-shi', 'JP.00.1864928', 'ASCII:Atsugi-shi;ID:1864928', '17980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17980', '112', '19857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19858', '1079', '1', 'Atetsu-gun', 'JP.00.1864933', 'ASCII:Atetsu-gun;ID:1864933', '17981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17981', '112', '19858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19859', '1079', '1', 'Atami-shi', 'JP.00.1864943', 'ASCII:Atami-shi;ID:1864943', '17982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17982', '112', '19859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19860', '1079', '1', 'Aso-gun', 'JP.00.1864975', 'ASCII:Aso-gun;ID:1864975', '17983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17983', '112', '19860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19861', '1079', '1', 'Ashiya-shi', 'JP.00.1864981', 'ASCII:Ashiya-shi;ID:1864981', '17984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17984', '112', '19861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1864981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19862', '1079', '1', 'Ashikaga-shi', 'JP.00.1865004', 'ASCII:Ashikaga-shi;ID:1865004', '17985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17985', '112', '19862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19863', '1079', '1', 'Ashigara-shimo-gun', 'JP.00.1865009', 'ASCII:Ashigara-shimo-gun;ID:1865009', '17986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17986', '112', '19863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19864', '1079', '1', 'Ashigara-kami-gun', 'JP.00.1865011', 'ASCII:Ashigara-kami-gun;ID:1865011', '17987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17987', '112', '19864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19865', '1079', '1', 'Asashina-mura', 'JP.00.1865030', 'ASCII:Asashina-mura;ID:1865030', '17988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17988', '112', '19865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19866', '1079', '1', 'Asakuchi-gun', 'JP.00.1865049', 'ASCII:Asakuchi-gun;ID:1865049', '17989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17989', '112', '19866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19867', '1079', '1', 'Asako-gun', 'JP.00.1865050', 'ASCII:Asako-gun;ID:1865050', '17990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17990', '112', '19867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19868', '1079', '1', 'Asaka-shi', 'JP.00.1865056', 'ASCII:Asaka-shi;ID:1865056', '17991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17991', '112', '19868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19869', '1079', '1', 'Asaji-machi', 'JP.00.1865058', 'ASCII:Asaji-machi;ID:1865058', '17992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17992', '112', '19869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19870', '1079', '1', 'Asahi-mura', 'JP.00.1865070', 'ASCII:Asahi-mura;ID:1865070', '17993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17993', '112', '19870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19871', '1079', '1', 'Asahi-mura', 'JP.00.1865071', 'ASCII:Asahi-mura;ID:1865071', '17994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17994', '112', '19871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19872', '1079', '1', 'Asahi-mura', 'JP.00.1865072', 'ASCII:Asahi-mura;ID:1865072', '17995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17995', '112', '19872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19873', '1079', '1', 'Asahi-mura', 'JP.00.1865073', 'ASCII:Asahi-mura;ID:1865073', '17996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17996', '112', '19873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19874', '1079', '1', 'Asahi-mura', 'JP.00.1865074', 'ASCII:Asahi-mura;ID:1865074', '17997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17997', '112', '19874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19875', '1079', '1', 'Asahi-mura', 'JP.00.1865075', 'ASCII:Asahi-mura;ID:1865075', '17998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17998', '112', '19875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19876', '1079', '1', 'Asahi-machi', 'JP.00.1865078', 'ASCII:Asahi-machi;ID:1865078', '17999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('17999', '112', '19876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19877', '1079', '1', 'Asahi-chō', 'JP.00.1865085', 'ASCII:Asahi-cho;ID:1865085', '18000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18000', '112', '19877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19878', '1079', '1', 'Arita-machi', 'JP.00.1865101', 'ASCII:Arita-machi;ID:1865101', '18001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18001', '112', '19878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19879', '1079', '1', 'Arimatsu-chō', 'JP.00.1865109', 'ASCII:Arimatsu-cho;ID:1865109', '18002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18002', '112', '19879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19880', '1079', '1', 'Arikawa-chō', 'JP.00.1865115', 'ASCII:Arikawa-cho;ID:1865115', '18003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18003', '112', '19880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19881', '1079', '1', 'Arie-machi', 'JP.00.1865119', 'ASCII:Arie-machi;ID:1865119', '18004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18004', '112', '19881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19882', '1079', '1', 'Arida-shi', 'JP.00.1865121', 'ASCII:Arida-shi;ID:1865121', '18005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18005', '112', '19882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19883', '1079', '1', 'Arida-gun', 'JP.00.1865123', 'ASCII:Arida-gun;ID:1865123', '18006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18006', '112', '19883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19884', '1079', '1', 'Ariake-machi', 'JP.00.1865131', 'ASCII:Ariake-machi;ID:1865131', '18007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18007', '112', '19884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19885', '1079', '1', 'Ariake-chō', 'JP.00.1865132', 'ASCII:Ariake-cho;ID:1865132', '18008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18008', '112', '19885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19886', '1079', '1', 'Arao-shi', 'JP.00.1865168', 'ASCII:Arao-shi;ID:1865168', '18009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18009', '112', '19886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19887', '1079', '1', 'Arakawa-mura', 'JP.00.1865185', 'ASCII:Arakawa-mura;ID:1865185', '18010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18010', '112', '19887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19888', '1079', '1', 'Arakawa-machi', 'JP.00.1865186', 'ASCII:Arakawa-machi;ID:1865186', '18011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18011', '112', '19888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19889', '1079', '1', 'Arai-shi', 'JP.00.1865200', 'ASCII:Arai-shi;ID:1865200', '18012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18012', '112', '19889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19890', '1079', '1', 'Arai-chō', 'JP.00.1865206', 'ASCII:Arai-cho;ID:1865206', '18013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18013', '112', '19890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19891', '1079', '1', 'Arachi-mura', 'JP.00.1865222', 'ASCII:Arachi-mura;ID:1865222', '18014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18014', '112', '19891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19892', '1079', '1', 'Aoyama-chō', 'JP.00.1865229', 'ASCII:Aoyama-cho;ID:1865229', '18015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18015', '112', '19892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19893', '1079', '1', 'Aogashima-mura', 'JP.00.1865268', 'ASCII:Aogashima-mura;ID:1865268', '18016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18016', '112', '19893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19894', '1079', '1', 'Anjō-shi', 'JP.00.1865293', 'ASCII:Anjo-shi;ID:1865293', '18017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18017', '112', '19894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19895', '1079', '1', 'Ando-mura', 'JP.00.1865301', 'ASCII:Ando-mura;ID:1865301', '18018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18018', '112', '19895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19896', '1079', '1', 'Anan-shi', 'JP.00.1865306', 'ASCII:Anan-shi;ID:1865306', '18019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18019', '112', '19896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19897', '1079', '1', 'Anan-chō', 'JP.00.1865308', 'ASCII:Anan-cho;ID:1865308', '18020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18020', '112', '19897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19898', '1079', '1', 'Anamizu-machi', 'JP.00.1865310', 'ASCII:Anamizu-machi;ID:1865310', '18021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18021', '112', '19898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19899', '1079', '1', 'Anabuki-chō', 'JP.00.1865317', 'ASCII:Anabuki-cho;ID:1865317', '18022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18022', '112', '19899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19900', '1079', '1', 'Ampachi-chō', 'JP.00.1865324', 'ASCII:Ampachi-cho;ID:1865324', '18023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18023', '112', '19900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19901', '1079', '1', 'Amakusa-machi', 'JP.00.1865358', 'ASCII:Amakusa-machi;ID:1865358', '18024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18024', '112', '19901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19902', '1079', '1', 'Ama Gun', 'JP.00.1865365', 'ASCII:Ama Gun;ID:1865365', '18025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18025', '112', '19902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19903', '1079', '1', 'Amagi-chō', 'JP.00.1865374', 'ASCII:Amagi-cho;ID:1865374', '18026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18026', '112', '19903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19904', '1079', '1', 'Amagasaki-shi', 'JP.00.1865383', 'ASCII:Amagasaki-shi;ID:1865383', '18027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18027', '112', '19904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19905', '1079', '1', 'Ama-chō', 'JP.00.1865388', 'ASCII:Ama-cho;ID:1865388', '18028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18028', '112', '19905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19906', '1079', '1', 'Akune-shi', 'JP.00.1865399', 'ASCII:Akune-shi;ID:1865399', '18029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18029', '112', '19906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19907', '1079', '1', 'Akō-shi', 'JP.00.1865406', 'ASCII:Ako-shi;ID:1865406', '18030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18030', '112', '19907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19908', '1079', '1', 'Akiyama-mura', 'JP.00.1865421', 'ASCII:Akiyama-mura;ID:1865421', '18031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18031', '112', '19908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19909', '1079', '1', 'Akitsu-chō', 'JP.00.1865424', 'ASCII:Akitsu-cho;ID:1865424', '18032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18032', '112', '19909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19910', '1079', '1', 'Akishima-shi', 'JP.00.1865425', 'ASCII:Akishima-shi;ID:1865425', '18033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18033', '112', '19910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19911', '1079', '1', 'Aki-shi', 'JP.00.1865426', 'ASCII:Aki-shi;ID:1865426', '18034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18034', '112', '19911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19912', '1079', '1', 'Aki-machi', 'JP.00.1865438', 'ASCII:Aki-machi;ID:1865438', '18035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18035', '112', '19912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19913', '1079', '1', 'Aki-gun', 'JP.00.1865442', 'ASCII:Aki-gun;ID:1865442', '18036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18036', '112', '19913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19914', '1079', '1', 'Aki-gun', 'JP.00.1865443', 'ASCII:Aki-gun;ID:1865443', '18037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18037', '112', '19914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19915', '1079', '1', 'Akashi-shi', 'JP.00.1865470', 'ASCII:Akashi-shi;ID:1865470', '18038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18038', '112', '19915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19916', '1079', '1', 'Akashina-machi', 'JP.00.1865472', 'ASCII:Akashina-machi;ID:1865472', '18039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18039', '112', '19916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19917', '1079', '1', 'Akasaki-chō', 'JP.00.1865499', 'ASCII:Akasaki-cho;ID:1865499', '18040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18040', '112', '19917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19918', '1079', '1', 'Akasaka-chō', 'JP.00.1865521', 'ASCII:Akasaka-cho;ID:1865521', '18041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18041', '112', '19918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19919', '1079', '1', 'Akaiwa-gun', 'JP.00.1865558', 'ASCII:Akaiwa-gun;ID:1865558', '18042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18042', '112', '19919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19920', '1079', '1', 'Akaike-machi', 'JP.00.1865569', 'ASCII:Akaike-machi;ID:1865569', '18043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18043', '112', '19920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19921', '1079', '1', 'Akagi-mura', 'JP.00.1865588', 'ASCII:Akagi-mura;ID:1865588', '18044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18044', '112', '19921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19922', '1079', '1', 'Akagi-chō', 'JP.00.1865590', 'ASCII:Akagi-cho;ID:1865590', '18045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18045', '112', '19922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19923', '1079', '1', 'Akabori-mura', 'JP.00.1865598', 'ASCII:Akabori-mura;ID:1865598', '18046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18046', '112', '19923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865598» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19924', '1079', '1', 'Akabane-chō', 'JP.00.1865602', 'ASCII:Akabane-cho;ID:1865602', '18047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18047', '112', '19924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19925', '1079', '1', 'Ajimu-machi', 'JP.00.1865622', 'ASCII:Ajimu-machi;ID:1865622', '18048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18048', '112', '19925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19926', '1079', '1', 'Ajikata-mura', 'JP.00.1865626', 'ASCII:Ajikata-mura;ID:1865626', '18049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18049', '112', '19926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19927', '1079', '1', 'Aji-chō', 'JP.00.1865630', 'ASCII:Aji-cho;ID:1865630', '18050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18050', '112', '19927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19928', '1079', '1', 'Aizu-Wakamatsu-shi', 'JP.00.1865633', 'ASCII:Aizu-Wakamatsu-shi;ID:1865633', '18051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18051', '112', '19928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19929', '1079', '1', 'Aizu-Takada-machi', 'JP.00.1865635', 'ASCII:Aizu-Takada-machi;ID:1865635', '18052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18052', '112', '19929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19930', '1079', '1', 'Aizumi-chō', 'JP.00.1865636', 'ASCII:Aizumi-cho;ID:1865636', '18053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18053', '112', '19930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19931', '1079', '1', 'Aizu-Bange-machi', 'JP.00.1865638', 'ASCII:Aizu-Bange-machi;ID:1865638', '18054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18054', '112', '19931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19932', '1079', '1', 'Aitō-chō', 'JP.00.1865644', 'ASCII:Aito-cho;ID:1865644', '18055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18055', '112', '19932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19933', '1079', '1', 'Aira-gun', 'JP.00.1865649', 'ASCII:Aira-gun;ID:1865649', '18056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18056', '112', '19933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865649» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19934', '1079', '1', 'Aira-chō', 'JP.00.1865650', 'ASCII:Aira-cho;ID:1865650', '18057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18057', '112', '19934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19935', '1079', '1', 'Aioi-shi', 'JP.00.1865654', 'ASCII:Aioi-shi;ID:1865654', '18058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18058', '112', '19935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19936', '1079', '1', 'Aioi-chō', 'JP.00.1865660', 'ASCII:Aioi-cho;ID:1865660', '18059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18059', '112', '19936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19937', '1079', '1', 'Aino-chō', 'JP.00.1865672', 'ASCII:Aino-cho;ID:1865672', '18060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18060', '112', '19937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19938', '1079', '1', 'Aikawa-machi', 'JP.00.1865682', 'ASCII:Aikawa-machi;ID:1865682', '18061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18061', '112', '19938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19939', '1079', '1', 'Aikawa-machi', 'JP.00.1865683', 'ASCII:Aikawa-machi;ID:1865683', '18062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18062', '112', '19939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19940', '1079', '1', 'Aichi-gun', 'JP.00.1865696', 'ASCII:Aichi-gun;ID:1865696', '18063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18063', '112', '19940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19941', '1079', '1', 'Aguni-son', 'JP.00.1865705', 'ASCII:Aguni-son;ID:1865705', '18064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18064', '112', '19941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19942', '1079', '1', 'Adachi-ku', 'JP.00.1865750', 'ASCII:Adachi;ID:1865750', '18065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18065', '112', '19942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19943', '1079', '1', 'Achi-mura', 'JP.00.1865752', 'ASCII:Achi-mura;ID:1865752', '18066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18066', '112', '19943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.1865752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19944', '1079', '1', 'Yawatahama-shi', 'JP.05.1926017', 'ASCII:Yawatahama;ID:1926017', '18067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18067', '112', '19944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.1926017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19945', '1079', '1', 'Matsuyama-shi', 'JP.05.1926099', 'ASCII:Matsuyama;ID:1926099', '18068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18068', '112', '19945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.1926099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19946', '1079', '1', 'Imabari-shi', 'JP.05.1926135', 'ASCII:Imabari;ID:1926135', '18069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18069', '112', '19946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.1926135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19947', '1079', '1', 'Okushiri-gun', 'JP.12.2038726', 'ASCII:Okushiri-gun;ID:2038726', '18070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18070', '112', '19947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.12.2038726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19948', '1079', '1', 'Yuzawa-shi', 'JP.00.2110459', 'ASCII:Yuzawa-shi;ID:2110459', '18071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18071', '112', '19948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19949', '1079', '1', 'Yonezawa-shi', 'JP.00.2110496', 'ASCII:Yonezawa-shi;ID:2110496', '18072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18072', '112', '19949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110496» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19950', '1079', '1', 'Yokote-shi', 'JP.00.2110504', 'ASCII:Yokote-shi;ID:2110504', '18073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18073', '112', '19950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19951', '1079', '1', 'Yamagata-shi', 'JP.00.2110552', 'ASCII:Yamagata-shi;ID:2110552', '18074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18074', '112', '19951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19952', '1079', '1', 'Yachiyo-shi', 'JP.00.2110578', 'ASCII:Yachiyo-shi;ID:2110578', '18075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18075', '112', '19952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19953', '1079', '1', 'Waga-gun', 'JP.00.2110604', 'ASCII:Waga-gun;ID:2110604', '18076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18076', '112', '19953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19954', '1079', '1', 'Unakami-gun', 'JP.00.2110640', 'ASCII:Unakami-gun;ID:2110640', '18077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18077', '112', '19954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19955', '1079', '1', 'Tsukuba-gun', 'JP.00.2110682', 'ASCII:Tsukuba-gun;ID:2110682', '18078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18078', '112', '19955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19956', '1079', '1', 'Tsuchiura-shi', 'JP.00.2110701', 'ASCII:Tsuchiura-shi;ID:2110701', '18079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18079', '112', '19956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19957', '1079', '1', 'Toride-shi', 'JP.00.2110728', 'ASCII:Toride-shi;ID:2110728', '18080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18080', '112', '19957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19958', '1079', '1', 'Tōno-shi', 'JP.00.2110732', 'ASCII:Tono-shi;ID:2110732', '18081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18081', '112', '19958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19959', '1079', '1', 'Tome-gun', 'JP.00.2110755', 'ASCII:Tome-gun;ID:2110755', '18082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18082', '112', '19959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19960', '1079', '1', 'Tōgane-shi', 'JP.00.2110773', 'ASCII:Togane-shi;ID:2110773', '18083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18083', '112', '19960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19961', '1079', '1', 'Tamura-gun', 'JP.00.2110839', 'ASCII:Tamura-gun;ID:2110839', '18084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18084', '112', '19961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19962', '1079', '1', 'Taga-gun', 'JP.00.2110928', 'ASCII:Taga-gun;ID:2110928', '18085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18085', '112', '19962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19963', '1079', '1', 'Sukagawa-shi', 'JP.00.2110958', 'ASCII:Sukagawa-shi;ID:2110958', '18086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18086', '112', '19963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19964', '1079', '1', 'Sōma-shi', 'JP.00.2110975', 'ASCII:Soma-shi;ID:2110975', '18087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18087', '112', '19964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2110975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19965', '1079', '1', 'Shiwa-gun', 'JP.00.2111005', 'ASCII:Shiwa-gun;ID:2111005', '18088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18088', '112', '19965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19966', '1079', '1', 'Shiroishi-shi', 'JP.00.2111014', 'ASCII:Shiroishi-shi;ID:2111014', '18089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18089', '112', '19966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19967', '1079', '1', 'Shirakawa-shi', 'JP.00.2111029', 'ASCII:Shirakawa-shi;ID:2111029', '18090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18090', '112', '19967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19968', '1079', '1', 'Shiogama-shi', 'JP.00.2111045', 'ASCII:Shiogama-shi;ID:2111045', '18091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18091', '112', '19968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19969', '1079', '1', 'Shinobu-gun', 'JP.00.2111058', 'ASCII:Shinobu-gun;ID:2111058', '18092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18092', '112', '19969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19970', '1079', '1', 'Shinjō-shi', 'JP.00.2111061', 'ASCII:Shinjo-shi;ID:2111061', '18093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18093', '112', '19970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19971', '1079', '1', 'Shibata-gun', 'JP.00.2111130', 'ASCII:Shibata-gun;ID:2111130', '18094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18094', '112', '19971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19972', '1079', '1', 'Sendai-shi', 'JP.00.2111147', 'ASCII:Sendai-shi;ID:2111147', '18095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18095', '112', '19972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19973', '1079', '1', 'Semboku-gun', 'JP.00.2111153', 'ASCII:Semboku-gun;ID:2111153', '18096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18096', '112', '19973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19974', '1079', '1', 'Sawara-shi', 'JP.00.2111171', 'ASCII:Sawara-shi;ID:2111171', '18097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18097', '112', '19974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19975', '1079', '1', 'Sambu-gun', 'JP.00.2111211', 'ASCII:Sambu-gun;ID:2111211', '18098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18098', '112', '19975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19976', '1079', '1', 'Sakura-shi', 'JP.00.2111215', 'ASCII:Sakura-shi;ID:2111215', '18099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18099', '112', '19976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19977', '1079', '1', 'Sagae-shi', 'JP.00.2111245', 'ASCII:Sagae-shi;ID:2111245', '18100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18100', '112', '19977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19978', '1079', '1', 'Ryūgasaki-shi', 'JP.00.2111256', 'ASCII:Ryugasaki-shi;ID:2111256', '18101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18101', '112', '19978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19979', '1079', '1', 'Ōtawara-shi', 'JP.00.2111324', 'ASCII:Otawara-shi;ID:2111324', '18102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18102', '112', '19979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19980', '1079', '1', 'Ōmagari-shi', 'JP.00.2111434', 'ASCII:Omagari-shi;ID:2111434', '18103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18103', '112', '19980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111434» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19981', '1079', '1', 'Ogasawara-shichō', 'JP.00.2111520', 'ASCII:Ogasawara-shicho;ID:2111520', '18104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18104', '112', '19981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19982', '1079', '1', 'Ōfunato-shi', 'JP.00.2111528', 'ASCII:Ofunato-shi;ID:2111528', '18105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18105', '112', '19982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19983', '1079', '1', 'Nishi-shirakawa-gun', 'JP.00.2111613', 'ASCII:Nishi-shirakawa-gun;ID:2111613', '18106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18106', '112', '19983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19984', '1079', '1', 'Nishi-murayama-gun', 'JP.00.2111620', 'ASCII:Nishi-murayama-gun;ID:2111620', '18107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18107', '112', '19984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19985', '1079', '1', 'Niihari-gun', 'JP.00.2111648', 'ASCII:Niihari-gun;ID:2111648', '18108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18108', '112', '19985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19986', '1079', '1', 'Nihommatsu-shi', 'JP.00.2111654', 'ASCII:Nihommatsu-shi;ID:2111654', '18109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18109', '112', '19986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19987', '1079', '1', 'Nasu-gun', 'JP.00.2111674', 'ASCII:Nasu-gun;ID:2111674', '18110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18110', '112', '19987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19988', '1079', '1', 'Narita-shi', 'JP.00.2111683', 'ASCII:Narita-shi;ID:2111683', '18111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18111', '112', '19988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19989', '1079', '1', 'Narashino-shi', 'JP.00.2111686', 'ASCII:Narashino-shi;ID:2111686', '18112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18112', '112', '19989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19990', '1079', '1', 'Nanyō-shi', 'JP.00.2111692', 'ASCII:Nanyo-shi;ID:2111692', '18113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18113', '112', '19990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19991', '1079', '1', 'Nakaminato-shi', 'JP.00.2111732', 'ASCII:Nakaminato-shi;ID:2111732', '18114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18114', '112', '19991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19992', '1079', '1', 'Naka-gun', 'JP.00.2111741', 'ASCII:Naka-gun;ID:2111741', '18115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18115', '112', '19992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19993', '1079', '1', 'Naka-gun', 'JP.00.2111742', 'ASCII:Naka-gun;ID:2111742', '18116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18116', '112', '19993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111742» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19994', '1079', '1', 'Murayama-shi', 'JP.00.2111805', 'ASCII:Murayama-shi;ID:2111805', '18117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18117', '112', '19994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19995', '1079', '1', 'Motoyoshi-gun', 'JP.00.2111817', 'ASCII:Motoyoshi-gun;ID:2111817', '18118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18118', '112', '19995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19996', '1079', '1', 'Morioka-shi', 'JP.00.2111833', 'ASCII:Morioka-shi;ID:2111833', '18119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18119', '112', '19996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19997', '1079', '1', 'Mooka-shi', 'JP.00.2111835', 'ASCII:Mooka-shi;ID:2111835', '18120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18120', '112', '19997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19998', '1079', '1', 'Monō-gun', 'JP.00.2111839', 'ASCII:Mono-gun;ID:2111839', '18121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18121', '112', '19998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('19999', '1079', '1', 'Mogami-gun', 'JP.00.2111850', 'ASCII:Mogami-gun;ID:2111850', '18122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18122', '112', '19999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20000', '1079', '1', 'Mobara-shi', 'JP.00.2111854', 'ASCII:Mobara-shi;ID:2111854', '18123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18123', '112', '20000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20001', '1079', '1', 'Mizusawa-shi', 'JP.00.2111858', 'ASCII:Mizusawa-shi;ID:2111858', '18124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18124', '112', '20001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20002', '1079', '1', 'Miyako-shi', 'JP.00.2111883', 'ASCII:Miyako-shi;ID:2111883', '18125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18125', '112', '20002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20003', '1079', '1', 'Miyagi-gun', 'JP.00.2111889', 'ASCII:Miyagi-gun;ID:2111889', '18126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18126', '112', '20003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20004', '1079', '1', 'Mito-shi', 'JP.00.2111899', 'ASCII:Mito-shi;ID:2111899', '18127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18127', '112', '20004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20005', '1079', '1', 'Minami-akita-gun', 'JP.00.2111935', 'ASCII:Minami-akita-gun;ID:2111935', '18128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18128', '112', '20005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2111935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20006', '1079', '1', 'Makabe-gun', 'JP.00.2112018', 'ASCII:Makabe-gun;ID:2112018', '18129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18129', '112', '20006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20007', '1079', '1', 'Kurokawa-gun', 'JP.00.2112074', 'ASCII:Kurokawa-gun;ID:2112074', '18130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18130', '112', '20007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20008', '1079', '1', 'Kurihara-gun', 'JP.00.2112092', 'ASCII:Kurihara-gun;ID:2112092', '18131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18131', '112', '20008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20009', '1079', '1', 'Kuji-gun', 'JP.00.2112115', 'ASCII:Kuji-gun;ID:2112115', '18132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18132', '112', '20009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20010', '1079', '1', 'Kōriyama-shi', 'JP.00.2112139', 'ASCII:Koriyama-shi;ID:2112139', '18133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18133', '112', '20010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20011', '1079', '1', 'Kitakami-shi', 'JP.00.2112223', 'ASCII:Kitakami-shi;ID:2112223', '18134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18134', '112', '20011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20012', '1079', '1', 'Kitaibaraki-shi', 'JP.00.2112231', 'ASCII:Kitaibaraki-shi;ID:2112231', '18135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18135', '112', '20012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20013', '1079', '1', 'Kita-akita-gun', 'JP.00.2112235', 'ASCII:Kita-akita-gun;ID:2112235', '18136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18136', '112', '20013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20014', '1079', '1', 'Kimitsu-gun', 'JP.00.2112249', 'ASCII:Kimitsu-gun;ID:2112249', '18137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18137', '112', '20014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20015', '1079', '1', 'Kesennuma-shi', 'JP.00.2112261', 'ASCII:Kesennuma-shi;ID:2112261', '18138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18138', '112', '20015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20016', '1079', '1', 'Kesen-gun', 'JP.00.2112264', 'ASCII:Kesen-gun;ID:2112264', '18139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18139', '112', '20016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20017', '1079', '1', 'Kawabe-gun', 'JP.00.2112304', 'ASCII:Kawabe-gun;ID:2112304', '18140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18140', '112', '20017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20018', '1079', '1', 'Katta-gun', 'JP.00.2112306', 'ASCII:Katta-gun;ID:2112306', '18141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18141', '112', '20018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20019', '1079', '1', 'Katsuta-shi', 'JP.00.2112310', 'ASCII:Katsuta-shi;ID:2112310', '18142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18142', '112', '20019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20020', '1079', '1', 'Katori-gun', 'JP.00.2112318', 'ASCII:Katori-gun;ID:2112318', '18143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18143', '112', '20020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20021', '1079', '1', 'Kashiwa-shi', 'JP.00.2112330', 'ASCII:Kashiwa-shi;ID:2112330', '18144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18144', '112', '20021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20022', '1079', '1', 'Kasama-shi', 'JP.00.2112342', 'ASCII:Kasama-shi;ID:2112342', '18145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18145', '112', '20022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20023', '1079', '1', 'Kamogawa-shi', 'JP.00.2112386', 'ASCII:Kamogawa-shi;ID:2112386', '18146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18146', '112', '20023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20024', '1079', '1', 'Kaminoyama-shi', 'JP.00.2112407', 'ASCII:Kaminoyama-shi;ID:2112407', '18147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18147', '112', '20024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20025', '1079', '1', 'Kami-hei-gun', 'JP.00.2112424', 'ASCII:Kami-hei-gun;ID:2112424', '18148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18148', '112', '20025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20026', '1079', '1', 'Kamaishi-shi', 'JP.00.2112441', 'ASCII:Kamaishi-shi;ID:2112441', '18149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18149', '112', '20026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20027', '1079', '1', 'Kamagaya-shi', 'JP.00.2112445', 'ASCII:Kamagaya-shi;ID:2112445', '18150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18150', '112', '20027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20028', '1079', '1', 'Izumi-shi', 'JP.00.2112510', 'ASCII:Izumi-shi;ID:2112510', '18151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18151', '112', '20028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20029', '1079', '1', 'Iwanuma-shi', 'JP.00.2112525', 'ASCII:Iwanuma-shi;ID:2112525', '18152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18152', '112', '20029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20030', '1079', '1', 'Iwaki-shi', 'JP.00.2112535', 'ASCII:Iwaki-shi;ID:2112535', '18153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18153', '112', '20030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20031', '1079', '1', 'Isumi-gun', 'JP.00.2112557', 'ASCII:Isumi-gun;ID:2112557', '18154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18154', '112', '20031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20032', '1079', '1', 'Ishinomaki-shi', 'JP.00.2112574', 'ASCII:Ishinomaki-shi;ID:2112574', '18155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18155', '112', '20032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20033', '1079', '1', 'Ishiki-gun', 'JP.00.2112582', 'ASCII:Ishiki-gun;ID:2112582', '18156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18156', '112', '20033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20034', '1079', '1', 'Inashiki-gun', 'JP.00.2112616', 'ASCII:Inashiki-gun;ID:2112616', '18157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18157', '112', '20034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20035', '1079', '1', 'Ichihara-shi', 'JP.00.2112663', 'ASCII:Ichihara-shi;ID:2112663', '18158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18158', '112', '20035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20036', '1079', '1', 'Honjō-shi', 'JP.00.2112680', 'ASCII:Honjo-shi;ID:2112680', '18159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18159', '112', '20036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20037', '1079', '1', 'Hitachi-shi', 'JP.00.2112704', 'ASCII:Hitachi-shi;ID:2112704', '18160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18160', '112', '20037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20038', '1079', '1', 'Hitachi-Ōta-shi', 'JP.00.2112705', 'ASCII:Hitachi-Ota-shi;ID:2112705', '18161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18161', '112', '20038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20039', '1079', '1', 'Hiraka-gun', 'JP.00.2112729', 'ASCII:Hiraka-gun;ID:2112729', '18162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18162', '112', '20039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20040', '1079', '1', 'Higashi-okitama-gun', 'JP.00.2112756', 'ASCII:Higashi-okitama-gun;ID:2112756', '18163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18163', '112', '20040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20041', '1079', '1', 'Higashi-murayama-gun', 'JP.00.2112760', 'ASCII:Higashi-murayama-gun;ID:2112760', '18164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18164', '112', '20041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20042', '1079', '1', 'Higashi-iwai-gun', 'JP.00.2112765', 'ASCII:Higashi-iwai-gun;ID:2112765', '18165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18165', '112', '20042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20043', '1079', '1', 'Higashi-ibaraki-gun', 'JP.00.2112766', 'ASCII:Higashi-ibaraki-gun;ID:2112766', '18166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18166', '112', '20043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20044', '1079', '1', 'Hienuki-gun', 'JP.00.2112772', 'ASCII:Hienuki-gun;ID:2112772', '18167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18167', '112', '20044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20045', '1079', '1', 'Haramachi-shi', 'JP.00.2112807', 'ASCII:Haramachi-shi;ID:2112807', '18168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18168', '112', '20045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20046', '1079', '1', 'Hanamaki-shi', 'JP.00.2112822', 'ASCII:Hanamaki-shi;ID:2112822', '18169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18169', '112', '20046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20047', '1079', '1', 'Haga-gun', 'JP.00.2112845', 'ASCII:Haga-gun;ID:2112845', '18170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18170', '112', '20047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20048', '1079', '1', 'Furukawa-shi', 'JP.00.2112897', 'ASCII:Furukawa-shi;ID:2112897', '18171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18171', '112', '20048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112897» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20049', '1079', '1', 'Fukushima-shi', 'JP.00.2112921', 'ASCII:Fukushima-shi;ID:2112921', '18172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18172', '112', '20049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112921» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20050', '1079', '1', 'Esashi-shi', 'JP.00.2112952', 'ASCII:Esashi-shi;ID:2112952', '18173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18173', '112', '20050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20051', '1079', '1', 'Date-gun', 'JP.00.2112979', 'ASCII:Date-gun;ID:2112979', '18174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18174', '112', '20051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20052', '1079', '1', 'Chōshi-shi', 'JP.00.2112994', 'ASCII:Choshi-shi;ID:2112994', '18175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18175', '112', '20052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20053', '1079', '1', 'Chōsei-gun', 'JP.00.2112997', 'ASCII:Chosei-gun;ID:2112997', '18176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18176', '112', '20053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2112997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20054', '1079', '1', 'Chiba-shi', 'JP.00.2113012', 'ASCII:Chiba-shi;ID:2113012', '18177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18177', '112', '20054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2113012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20055', '1079', '1', 'Asahi-mura', 'JP.00.2113074', 'ASCII:Asahi-mura;ID:2113074', '18178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18178', '112', '20055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2113074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20056', '1079', '1', 'Asahi-machi', 'JP.00.2113075', 'ASCII:Asahi-machi;ID:2113075', '18179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18179', '112', '20056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2113075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20057', '1079', '1', 'Ani-machi', 'JP.00.2113105', 'ASCII:Ani-machi;ID:2113105', '18180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18180', '112', '20057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2113105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20058', '1079', '1', 'Ami-machi', 'JP.00.2113114', 'ASCII:Ami-machi;ID:2113114', '18181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18181', '112', '20058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2113114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20059', '1079', '1', 'Akita-shi', 'JP.00.2113122', 'ASCII:Akita-shi;ID:2113122', '18182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18182', '112', '20059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2113122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20060', '1079', '1', 'Akeno-machi', 'JP.00.2113129', 'ASCII:Akeno-machi;ID:2113129', '18183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18183', '112', '20060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2113129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20061', '1079', '1', 'Akai-mura', 'JP.00.2113141', 'ASCII:Akai-mura;ID:2113141', '18184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18184', '112', '20061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2113141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20062', '1079', '1', 'Akai-mura', 'JP.00.2113142', 'ASCII:Akai-mura;ID:2113142', '18185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18185', '112', '20062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2113142» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20063', '1079', '1', 'Abiko-shi', 'JP.00.2113162', 'ASCII:Abiko-shi;ID:2113162', '18186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18186', '112', '20063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2113162» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20064', '1079', '1', 'Yūbari-shi', 'JP.00.2127415', 'ASCII:Yubari-shi;ID:2127415', '18187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18187', '112', '20064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20065', '1079', '1', 'Yoichi-gun', 'JP.00.2127440', 'ASCII:Yoichi-gun;ID:2127440', '18188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18188', '112', '20065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20066', '1079', '1', 'Yamamoto-gun', 'JP.00.2127468', 'ASCII:Yamamoto-gun;ID:2127468', '18189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18189', '112', '20066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20067', '1079', '1', 'Wakkanai-shi', 'JP.00.2127513', 'ASCII:Wakkanai-shi;ID:2127513', '18190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18190', '112', '20067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20068', '1079', '1', 'Utashinai-shi', 'JP.00.2127544', 'ASCII:Utashinai-shi;ID:2127544', '18191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18191', '112', '20068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20069', '1079', '1', 'Tōya-mura', 'JP.00.2127666', 'ASCII:Toya-mura;ID:2127666', '18192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18192', '112', '20069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20070', '1079', '1', 'Towada-shi', 'JP.00.2127674', 'ASCII:Towada-shi;ID:2127674', '18193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18193', '112', '20070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20071', '1079', '1', 'Tomamae-gun', 'JP.00.2127730', 'ASCII:Tomamae-gun;ID:2127730', '18194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18194', '112', '20071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20072', '1079', '1', 'Tomakomai-shi', 'JP.00.2127732', 'ASCII:Tomakomai-shi;ID:2127732', '18195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18195', '112', '20072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20073', '1079', '1', 'Teshio-gun', 'JP.00.2127817', 'ASCII:Teshio-gun;ID:2127817', '18196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18196', '112', '20073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20074', '1079', '1', 'Takikawa-shi', 'JP.00.2127895', 'ASCII:Takikawa-shi;ID:2127895', '18197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18197', '112', '20074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20075', '1079', '1', 'Sunagawa-shi', 'JP.00.2127954', 'ASCII:Sunagawa-shi;ID:2127954', '18198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18198', '112', '20075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2127954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20076', '1079', '1', 'Shizunai-gun', 'JP.00.2128020', 'ASCII:Shizunai-gun;ID:2128020', '18199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18199', '112', '20076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20077', '1079', '1', 'Shimo-kita-gun', 'JP.00.2128134', 'ASCII:Shimo-kita-gun;ID:2128134', '18200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18200', '112', '20077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128134» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20078', '1079', '1', 'Shibetsu-shi', 'JP.00.2128201', 'ASCII:Shibetsu-shi;ID:2128201', '18201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18201', '112', '20078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20079', '1079', '1', 'Sapporo-shi', 'JP.00.2128291', 'ASCII:Sapporo-shi;ID:2128291', '18202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18202', '112', '20079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20080', '1079', '1', 'Sapporo-gun', 'JP.00.2128293', 'ASCII:Sapporo-gun;ID:2128293', '18203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18203', '112', '20080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20081', '1079', '1', 'Sannohe-gun', 'JP.00.2128302', 'ASCII:Sannohe-gun;ID:2128302', '18204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18204', '112', '20081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20082', '1079', '1', 'Rumoi-shi', 'JP.00.2128378', 'ASCII:Rumoi-shi;ID:2128378', '18205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18205', '112', '20082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20083', '1079', '1', 'Rishiri-gun', 'JP.00.2128405', 'ASCII:Rishiri-gun;ID:2128405', '18206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18206', '112', '20083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20084', '1079', '1', 'Rebun-gun', 'JP.00.2128418', 'ASCII:Rebun-gun;ID:2128418', '18207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18207', '112', '20084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20085', '1079', '1', 'Otaru-shi', 'JP.00.2128570', 'ASCII:Otaru-shi;ID:2128570', '18208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18208', '112', '20085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20086', '1079', '1', 'Ōdate-shi', 'JP.00.2128783', 'ASCII:Odate-shi;ID:2128783', '18209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18209', '112', '20086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128783» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20087', '1079', '1', 'Obihiro-shi', 'JP.00.2128812', 'ASCII:Obihiro-shi;ID:2128812', '18210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18210', '112', '20087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20088', '1079', '1', 'Noshiro-shi', 'JP.00.2128864', 'ASCII:Noshiro-shi;ID:2128864', '18211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18211', '112', '20088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20089', '1079', '1', 'Noboribetsu-shi', 'JP.00.2128892', 'ASCII:Noboribetsu-shi;ID:2128892', '18212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18212', '112', '20089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20090', '1079', '1', 'Nishi-tsugaru-gun', 'JP.00.2128908', 'ASCII:Nishi-tsugaru-gun;ID:2128908', '18213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18213', '112', '20090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20091', '1079', '1', 'Ninohe-shi', 'JP.00.2128940', 'ASCII:Ninohe-shi;ID:2128940', '18214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18214', '112', '20091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20092', '1079', '1', 'Ninohe-gun', 'JP.00.2128941', 'ASCII:Ninohe-gun;ID:2128941', '18215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18215', '112', '20092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20093', '1079', '1', 'Nemuro-gun', 'JP.00.2128974', 'ASCII:Nemuro-gun;ID:2128974', '18216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18216', '112', '20093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2128974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20094', '1079', '1', 'Mutsu-shi', 'JP.00.2129089', 'ASCII:Mutsu-shi;ID:2129089', '18217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18217', '112', '20094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20095', '1079', '1', 'Muroran-shi', 'JP.00.2129098', 'ASCII:Muroran-shi;ID:2129098', '18218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18218', '112', '20095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20096', '1079', '1', 'Minami-tsugaru-gun', 'JP.00.2129224', 'ASCII:Minami-tsugaru-gun;ID:2129224', '18219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18219', '112', '20096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20097', '1079', '1', 'Kushiro-shichō', 'JP.00.2129369', 'ASCII:Kushiro-shicho;ID:2129369', '18220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18220', '112', '20097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20098', '1079', '1', 'Kushiro-shi', 'JP.00.2129370', 'ASCII:Kushiro-shi;ID:2129370', '18221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18221', '112', '20098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20099', '1079', '1', 'Kushiro-gun', 'JP.00.2129373', 'ASCII:Kushiro-gun;ID:2129373', '18222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18222', '112', '20099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129373» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20100', '1079', '1', 'Kuroishi-shi', 'JP.00.2129393', 'ASCII:Kuroishi-shi;ID:2129393', '18223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18223', '112', '20100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129393» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20101', '1079', '1', 'Kunohe-gun', 'JP.00.2129400', 'ASCII:Kunohe-gun;ID:2129400', '18224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18224', '112', '20101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20102', '1079', '1', 'Kuji-shi', 'JP.00.2129423', 'ASCII:Kuji-shi;ID:2129423', '18225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18225', '112', '20102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20103', '1079', '1', 'Kita-tsugaru-gun', 'JP.00.2129525', 'ASCII:Kita-tsugaru-gun;ID:2129525', '18226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18226', '112', '20103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20104', '1079', '1', 'Kitami-shi', 'JP.00.2129532', 'ASCII:Kitami-shi;ID:2129532', '18227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18227', '112', '20104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20105', '1079', '1', 'Kazuno-shi', 'JP.00.2129593', 'ASCII:Kazuno-shi;ID:2129593', '18228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18228', '112', '20105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20106', '1079', '1', 'Kayabe-gun', 'JP.00.2129597', 'ASCII:Kayabe-gun;ID:2129597', '18229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18229', '112', '20106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20107', '1079', '1', 'Kami-kita-gun', 'JP.00.2129753', 'ASCII:Kami-kita-gun;ID:2129753', '18230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18230', '112', '20107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20108', '1079', '1', 'Kami-kita-gun', 'JP.00.2129754', 'ASCII:Kami-kita-gun;ID:2129754', '18231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18231', '112', '20108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20109', '1079', '1', 'Kamikawa-gun', 'JP.00.2129758', 'ASCII:Kamikawa-gun;ID:2129758', '18232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18232', '112', '20109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20110', '1079', '1', 'Kamiiso-gun', 'JP.00.2129763', 'ASCII:Kamiiso-gun;ID:2129763', '18233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18233', '112', '20110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20111', '1079', '1', 'Kameda-shi', 'JP.00.2129777', 'ASCII:Kameda-shi;ID:2129777', '18234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18234', '112', '20111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20112', '1079', '1', 'Kameda-gun', 'JP.00.2129779', 'ASCII:Kameda-gun;ID:2129779', '18235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18235', '112', '20112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20113', '1079', '1', 'Iwamizawa-shi', 'JP.00.2129869', 'ASCII:Iwamizawa-shi;ID:2129869', '18236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18236', '112', '20113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2129869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20114', '1079', '1', 'Hiyama-gun', 'JP.00.2130044', 'ASCII:Hiyama-gun;ID:2130044', '18237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18237', '112', '20114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20115', '1079', '1', 'Hirosaki-shi', 'JP.00.2130056', 'ASCII:Hirosaki-shi;ID:2130056', '18238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18238', '112', '20115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20116', '1079', '1', 'Hiroo-gun', 'JP.00.2130058', 'ASCII:Hiroo-gun;ID:2130058', '18239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18239', '112', '20116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20117', '1079', '1', 'Higashi-tsugaru-gun', 'JP.00.2130088', 'ASCII:Higashi-tsugaru-gun;ID:2130088', '18240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18240', '112', '20117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20118', '1079', '1', 'Hakodate-shi', 'JP.00.2130184', 'ASCII:Hakodate-shi;ID:2130184', '18241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18241', '112', '20118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20119', '1079', '1', 'Hachinohe-shi', 'JP.00.2130200', 'ASCII:Hachinohe-shi;ID:2130200', '18242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18242', '112', '20119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20120', '1079', '1', 'Goshogawara-shi', 'JP.00.2130225', 'ASCII:Goshogawara-shi;ID:2130225', '18243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18243', '112', '20120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20121', '1079', '1', 'Gonohe-machi', 'JP.00.2130235', 'ASCII:Gonohe-machi;ID:2130235', '18244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18244', '112', '20121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20122', '1079', '1', 'Furubira-gun', 'JP.00.2130287', 'ASCII:Furubira-gun;ID:2130287', '18245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18245', '112', '20122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20123', '1079', '1', 'Furano-shi', 'JP.00.2130304', 'ASCII:Furano-shi;ID:2130304', '18246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18246', '112', '20123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20124', '1079', '1', 'Fukagawa-shi', 'JP.00.2130331', 'ASCII:Fukagawa-shi;ID:2130331', '18247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18247', '112', '20124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20125', '1079', '1', 'Ebetsu-shi', 'JP.00.2130402', 'ASCII:Ebetsu-shi;ID:2130402', '18248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18248', '112', '20125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20126', '1079', '1', 'Date-shi', 'JP.00.2130419', 'ASCII:Date-shi;ID:2130419', '18249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18249', '112', '20126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20127', '1079', '1', 'Chitose-gun', 'JP.00.2130450', 'ASCII:Chitose-gun;ID:2130450', '18250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18250', '112', '20127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20128', '1079', '1', 'Bibai-shi', 'JP.00.2130533', 'ASCII:Bibai-shi;ID:2130533', '18251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18251', '112', '20128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20129', '1079', '1', 'Ashibetsu-shi', 'JP.00.2130609', 'ASCII:Ashibetsu-shi;ID:2130609', '18252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18252', '112', '20129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20130', '1079', '1', 'Asahikawa-shi', 'JP.00.2130628', 'ASCII:Asahikawa-shi;ID:2130628', '18253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18253', '112', '20130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20131', '1079', '1', 'Arakawa-mura', 'JP.00.2130646', 'ASCII:Arakawa-mura;ID:2130646', '18254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18254', '112', '20131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20132', '1079', '1', 'Aomori-shi', 'JP.00.2130654', 'ASCII:Aomori-shi;ID:2130654', '18255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18255', '112', '20132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20133', '1079', '1', 'Akabira-shi', 'JP.00.2130704', 'ASCII:Akabira-shi;ID:2130704', '18256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18256', '112', '20133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20134', '1079', '1', 'Ajigasawa-machi', 'JP.00.2130707', 'ASCII:Ajigasawa-machi;ID:2130707', '18257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18257', '112', '20134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20135', '1079', '1', 'Aikawa-machi', 'JP.00.2130715', 'ASCII:Aikawa-machi;ID:2130715', '18258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18258', '112', '20135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20136', '1079', '1', 'Abuta-gun', 'JP.00.2130724', 'ASCII:Abuta-gun;ID:2130724', '18259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18259', '112', '20136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20137', '1079', '1', 'Abashiri-shichō', 'JP.00.2130735', 'ASCII:Abashiri-shicho;ID:2130735', '18260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18260', '112', '20137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20138', '1079', '1', 'Abashiri-shi', 'JP.00.2130736', 'ASCII:Abashiri-shi;ID:2130736', '18261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18261', '112', '20138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.00.2130736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20139', '1079', '1', 'Seiyo-shi', 'JP.05.6691614', 'ASCII:Seiyo;ID:6691614', '18262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18262', '112', '20139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.6691614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20140', '1079', '1', 'Kitauwa-gun', 'JP.05.6691615', 'ASCII:Kitauwa;ID:6691615', '18263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18263', '112', '20140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.6691615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20141', '1079', '1', 'Tōon-shi', 'JP.05.6691620', 'ASCII:Toon;ID:6691620', '18264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18264', '112', '20141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.6691620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20142', '1079', '1', 'Kamiukena-gun', 'JP.05.6691622', 'ASCII:Kamiukena;ID:6691622', '18265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18265', '112', '20142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «JP.05.6691622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20143', '1079', '1', 'Siaya District', 'KE.07.180320', 'ASCII:Siaya District;ID:180320', '18266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18266', '112', '20143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KE.07.180320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20144', '1079', '1', 'Kisumu District', 'KE.07.191242', 'ASCII:Kisumu District;ID:191242', '18267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18267', '112', '20144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KE.07.191242» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20145', '1079', '1', 'Oshskaya Oblast''', 'KG.00.1222584', 'ASCII:Oshskaya Oblast'';ID:1222584', '18268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18268', '112', '20145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1222584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20146', '1079', '1', 'Kadamdzhayskiy Rayon', 'KG.00.1222671', 'ASCII:Kadamdzhayskiy Rayon;ID:1222671', '18269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18269', '112', '20146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1222671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20147', '1079', '1', 'Talasskiy Rayon', 'KG.00.1527296', 'ASCII:Talasskiy Rayon;ID:1527296', '18270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18270', '112', '20147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1527296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20148', '1079', '1', 'Kara-Kul''dzhinskiy Rayon', 'KG.00.1527348', 'ASCII:Kara-Kul''dzhinskiy Rayon;ID:1527348', '18271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18271', '112', '20148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1527348» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20149', '1079', '1', 'Sokulukskiy Rayon', 'KG.00.1527358', 'ASCII:Sokulukskiy Rayon;ID:1527358', '18272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18272', '112', '20149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1527358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20150', '1079', '1', 'Panfilovskiy Rayon', 'KG.00.1527509', 'ASCII:Panfilovskiy Rayon;ID:1527509', '18273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18273', '112', '20150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1527509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20151', '1079', '1', 'Oktyabr''skiy Rayon', 'KG.00.1527561', 'ASCII:Oktyabr''skiy Rayon;ID:1527561', '18274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18274', '112', '20151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1527561» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20152', '1079', '1', 'Moskovskiy Rayon', 'KG.00.1527613', 'ASCII:Moskovskiy Rayon;ID:1527613', '18275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18275', '112', '20152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1527613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20153', '1079', '1', 'Nookenskiy Rayon', 'KG.00.1527685', 'ASCII:Nookenskiy Rayon;ID:1527685', '18276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18276', '112', '20153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1527685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20154', '1079', '1', 'Bakay-Atinskiy Rayon', 'KG.00.1527687', 'ASCII:Bakay-Atinskiy Rayon;ID:1527687', '18277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18277', '112', '20154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1527687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20155', '1079', '1', 'Kara-Buurinskiy Rayon', 'KG.00.1527920', 'ASCII:Kara-Buurinskiy Rayon;ID:1527920', '18278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18278', '112', '20155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1527920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20156', '1079', '1', 'Keminskiy Rayon', 'KG.00.1527974', 'ASCII:Keminskiy Rayon;ID:1527974', '18279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18279', '112', '20156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1527974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20157', '1079', '1', 'Kantskiy Rayon', 'KG.00.1528191', 'ASCII:Kantskiy Rayon;ID:1528191', '18280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18280', '112', '20157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1528191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20158', '1079', '1', 'Issyk-Atinskiy Rayon', 'KG.00.1528261', 'ASCII:Issyk-Atinskiy Rayon;ID:1528261', '18281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18281', '112', '20158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1528261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20159', '1079', '1', 'Chuyskiy Rayon', 'KG.00.1528472', 'ASCII:Chuyskiy Rayon;ID:1528472', '18282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18282', '112', '20159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1528472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20160', '1079', '1', 'Alamedinskiy Rayon', 'KG.00.1528867', 'ASCII:Alamedinskiy Rayon;ID:1528867', '18283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18283', '112', '20160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KG.00.1528867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20161', '1079', '1', 'Srŏk Batum Sakôr', 'KH.08.1831788', 'ASCII:Srok Batum Sakor;ID:1831788', '18284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18284', '112', '20161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KH.08.1831788» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20162', '1079', '1', 'Yongch''ŏn-gun', 'KP.11.1865779', 'ASCII:Yongch''on-gun;ID:1865779', '18285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18285', '112', '20162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1865779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20163', '1079', '1', 'Tŏkch’ŏn-si', 'KP.15.1865781', 'ASCII:Tokch''on-si;ID:1865781', '18286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18286', '112', '20163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1865781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20164', '1079', '1', 'Kangsŏ-guyŏk', 'KP.14.1865786', 'ASCII:Kangso-guyok;ID:1865786', '18287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18287', '112', '20164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.14.1865786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20165', '1079', '1', 'Yŏnt’an-gun', 'KP.07.1865966', 'ASCII:Yont''an-gun;ID:1865966', '18288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18288', '112', '20165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1865966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20166', '1079', '1', 'Yŏnsan-gun', 'KP.07.1865975', 'ASCII:Yonsan-gun;ID:1865975', '18289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18289', '112', '20166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1865975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20167', '1079', '1', 'Yŏngwŏn-gun', 'KP.15.1866047', 'ASCII:Yongwon-gun;ID:1866047', '18290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18290', '112', '20167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1866047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20168', '1079', '1', 'Yongsŏng-guyŏk', 'KP.12.1866090', 'ASCII:Yongsong-guyok;ID:1866090', '18291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18291', '112', '20168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1866090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20169', '1079', '1', 'Yonggang-gun', 'KP.14.1866367', 'ASCII:Yonggang-gun;ID:1866367', '18292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18292', '112', '20169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.14.1866367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20170', '1079', '1', 'Yŏngbyŏn-gun', 'KP.11.1866454', 'ASCII:Yongbyon-gun;ID:1866454', '18293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18293', '112', '20170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1866454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20171', '1079', '1', 'Yŏnan-gun', 'KP.06.1866571', 'ASCII:Yonan-gun;ID:1866571', '18294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18294', '112', '20171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1866571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20172', '1079', '1', 'Yŏmju-gun', 'KP.11.1866590', 'ASCII:Yomju-gun;ID:1866590', '18295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18295', '112', '20172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1866590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20173', '1079', '1', 'Yŏkp’o-guyŏk', 'KP.12.1866614', 'ASCII:Yokp''o-guyok;ID:1866614', '18296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18296', '112', '20173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1866614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20174', '1079', '1', 'Yodŏk-kun', 'KP.03.1866638', 'ASCII:Yodok-kun;ID:1866638', '18297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18297', '112', '20174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.1866638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20175', '1079', '1', 'Yangdŏk-kun', 'KP.15.Yangdŏk-kun', 'ASCII:Yangdok-kun;ID:1866790', '18298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18298', '112', '20175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.Yangdok-kun» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20176', '1079', '1', 'Wŏnsan-si', 'KP.09.1866905', 'ASCII:Wonsan-si;ID:1866905', '18299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18299', '112', '20176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1866905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20177', '1079', '1', 'ŏnp’a-gun', 'KP.07.1867256', 'ASCII:onp''a-gun;ID:1867256', '18300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18300', '112', '20177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1867256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20178', '1079', '1', 'Unjŏn-gun', 'KP.11.1867275', 'ASCII:Unjon-gun;ID:1867275', '18301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18301', '112', '20178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1867275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20179', '1079', '1', 'Ŏnch’ŏn-gun', 'KP.06.1867379', 'ASCII:Onch''on-gun;ID:1867379', '18302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18302', '112', '20179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1867379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20180', '1079', '1', 'Ŭllyul-gun', 'KP.06.1867428', 'ASCII:Ullyul-gun;ID:1867428', '18303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18303', '112', '20180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1867428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20181', '1079', '1', 'T’osan-gun', 'KP.07.1867627', 'ASCII:T''osan-gun;ID:1867627', '18304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18304', '112', '20181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1867627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20182', '1079', '1', 'Tongnim-gun', 'KP.11.1867778', 'ASCII:Tongnim-gun;ID:1867778', '18305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18305', '112', '20182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1867778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20183', '1079', '1', 'Tongdaewŏn-guyŏk', 'KP.12.1867918', 'ASCII:Tongdaewon-guyok;ID:1867918', '18306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18306', '112', '20183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1867918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20184', '1079', '1', 'T’ongch’ŏn-gun', 'KP.09.1867930', 'ASCII:T''ongch''on-gun;ID:1867930', '18307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18307', '112', '20184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1867930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20185', '1079', '1', 'T’aet’an-gun', 'KP.06.1868579', 'ASCII:T''aet''an-gun;ID:1868579', '18308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18308', '112', '20185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1868579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20186', '1079', '1', 'Taesŏng-guyŏk', 'KP.12.1868593', 'ASCII:Taesong-guyok;ID:1868593', '18309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18309', '112', '20186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1868593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20187', '1079', '1', 'Taedong-gun', 'KP.15.1868812', 'ASCII:Taedong-gun;ID:1868812', '18310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18310', '112', '20187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1868812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20188', '1079', '1', 'Taedonggang-guyŏk', 'KP.12.1868813', 'ASCII:Taedonggang-guyok;ID:1868813', '18311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18311', '112', '20188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1868813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20189', '1079', '1', 'T’aech’ŏn-gun', 'KP.11.1868849', 'ASCII:T''aech''on-gun;ID:1868849', '18312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18312', '112', '20189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1868849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20190', '1079', '1', 'Sŭngho-guyŏk', 'KP.12.1868997', 'ASCII:Sungho-guyok;ID:1868997', '18313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18313', '112', '20190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1868997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20191', '1079', '1', 'Sunch’ŏn-si', 'KP.15.1869013', 'ASCII:Sunch''on-si;ID:1869013', '18314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18314', '112', '20191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1869013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20192', '1079', '1', 'Sunan-guyŏk', 'KP.12.1869019', 'ASCII:Sunan-guyok;ID:1869019', '18315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18315', '112', '20192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1869019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20193', '1079', '1', 'Sukch’ŏn-gun', 'KP.15.Sukch’ŏn-gun', 'ASCII:Sukch''on-gun;ID:1869039', '18316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18316', '112', '20193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.Sukch''on-gun» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20194', '1079', '1', 'Suan-gun', 'KP.07.1869140', 'ASCII:Suan-gun;ID:1869140', '18317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18317', '112', '20194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1869140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20195', '1079', '1', 'Sŏsŏng-kuyŏk', 'KP.12.1869227', 'ASCII:Sosong-kuyok;ID:1869227', '18318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18318', '112', '20195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1869227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20196', '1079', '1', 'Sŏn’gyo-guyŏk', 'KP.12.1869345', 'ASCII:Son''gyo-guyok;ID:1869345', '18319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18319', '112', '20196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1869345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20197', '1079', '1', 'Songnim-si', 'KP.07.1869433', 'ASCII:Songnim-si;ID:1869433', '18320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18320', '112', '20197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1869433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20198', '1079', '1', 'Songhwa-gun', 'KP.06.1869582', 'ASCII:Songhwa-gun;ID:1869582', '18321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18321', '112', '20198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1869582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20199', '1079', '1', 'Sŏngch’ŏn-gun', 'KP.15.1869676', 'ASCII:Songch''on-gun;ID:1869676', '18322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18322', '112', '20199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1869676» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20200', '1079', '1', 'Sŏnch’ŏn-gun', 'KP.11.1869746', 'ASCII:Sonch''on-gun;ID:1869746', '18323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18323', '112', '20200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1869746» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20201', '1079', '1', 'Sŏhŏng-gun', 'KP.07.1870041', 'ASCII:Sohong-gun;ID:1870041', '18324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18324', '112', '20201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1870041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20202', '1079', '1', 'Sinyang-gun', 'KP.15.1870271', 'ASCII:Sinyang-gun;ID:1870271', '18325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18325', '112', '20202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1870271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20203', '1079', '1', 'Sinwŏn-gun', 'KP.06.1870278', 'ASCII:Sinwon-gun;ID:1870278', '18326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18326', '112', '20203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1870278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20204', '1079', '1', 'Sinp’yŏng-gun', 'KP.07.1870370', 'ASCII:Sinp''yong-gun;ID:1870370', '18327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18327', '112', '20204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1870370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20205', '1079', '1', 'Sin’gye-gun', 'KP.07.1870544', 'ASCII:Sin''gye-gun;ID:1870544', '18328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18328', '112', '20205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1870544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20206', '1079', '1', 'Sinch’ŏn-gun', 'KP.06.1870659', 'ASCII:Sinch''on-gun;ID:1870659', '18329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18329', '112', '20206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1870659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20207', '1079', '1', 'Sep’o-gun', 'KP.09.1870827', 'ASCII:Sep''o-gun;ID:1870827', '18330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18330', '112', '20207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1870827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20208', '1079', '1', 'Sariwŏn-si', 'KP.07.1870881', 'ASCII:Sariwon-si;ID:1870881', '18331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18331', '112', '20208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1870881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20209', '1079', '1', 'Sangwŏn-gun', 'KP.12.1870984', 'ASCII:Sangwon-gun;ID:1870984', '18332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18332', '112', '20209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1870984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20210', '1079', '1', 'Samsŏk-kuyŏk', 'KP.12.1871416', 'ASCII:Samsok-kuyok;ID:1871416', '18333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18333', '112', '20210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1871416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20211', '1079', '1', 'Samch’ŏn-gun', 'KP.06.1871541', 'ASCII:Samch''on-gun;ID:1871541', '18334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18334', '112', '20211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1871541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20212', '1079', '1', 'Sadong-guyŏk', 'KP.12.1871810', 'ASCII:Sadong-guyok;ID:1871810', '18335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18335', '112', '20212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1871810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20213', '1079', '1', 'P’yŏngwŏn-gun', 'KP.15.P’yŏngwŏn-gun', 'ASCII:P''yongwon-gun;ID:1871865', '18336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18336', '112', '20213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.P''yongwon-gun» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20214', '1079', '1', 'P’yŏngsŏng-si', 'KP.15.1871869', 'ASCII:P''yongsong-si;ID:1871869', '18337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18337', '112', '20214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1871869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20215', '1079', '1', 'P’yŏngsan-gun', 'KP.07.1871875', 'ASCII:P''yongsan-gun;ID:1871875', '18338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18338', '112', '20215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1871875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20216', '1079', '1', 'P’yŏnggang-gun', 'KP.09.1871928', 'ASCII:P''yonggang-gun;ID:1871928', '18339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18339', '112', '20216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1871928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20217', '1079', '1', 'P’yŏngch’ŏn-guyŏk', 'KP.12.1871937', 'ASCII:P''yongch''on-guyok;ID:1871937', '18340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18340', '112', '20217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1871937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20218', '1079', '1', 'P’yŏngch’ŏn-gun', 'KP.06.1871938', 'ASCII:P''yongch''on-gun;ID:1871938', '18341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18341', '112', '20218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1871938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20219', '1079', '1', 'Pyŏksŏng-gun', 'KP.06.1871968', 'ASCII:Pyoksong-gun;ID:1871968', '18342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18342', '112', '20219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1871968» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20220', '1079', '1', 'Pukch’ang-gun', 'KP.15.1872201', 'ASCII:Pukch''ang-gun;ID:1872201', '18343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18343', '112', '20220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1872201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20221', '1079', '1', 'Pot’onggang-kuyŏk', 'KP.12.1872260', 'ASCII:Pot''onggang-kuyok;ID:1872260', '18344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18344', '112', '20221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1872260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20222', '1079', '1', 'Pŏptong-gun', 'KP.09.1872294', 'ASCII:Poptong-gun;ID:1872294', '18345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18345', '112', '20222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1872294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20223', '1079', '1', 'Pongsan-gun', 'KP.07.1872337', 'ASCII:Pongsan-gun;ID:1872337', '18346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18346', '112', '20223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1872337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20224', '1079', '1', 'P’ihyŏn-gun', 'KP.11.1872626', 'ASCII:P''ihyon-gun;ID:1872626', '18347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18347', '112', '20224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1872626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20225', '1079', '1', 'P’anmun-gun', 'KP.08.1872688', 'ASCII:P''anmun-gun;ID:1872688', '18348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18348', '112', '20225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.08.1872688» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20226', '1079', '1', 'P’an’gyo-gun', 'KP.09.1872704', 'ASCII:P''an''gyo-gun;ID:1872704', '18349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18349', '112', '20226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1872704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20227', '1079', '1', 'Pakch’ŏn-gun', 'KP.11.1872819', 'ASCII:Pakch''on-gun;ID:1872819', '18350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18350', '112', '20227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1872819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20228', '1079', '1', 'Paech’ŏn-gun', 'KP.06.1873016', 'ASCII:Paech''on-gun;ID:1873016', '18351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18351', '112', '20228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1873016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20229', '1079', '1', 'Ongjin-gun', 'KP.06.1873174', 'ASCII:Ongjin-gun;ID:1873174', '18352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18352', '112', '20229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1873174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20230', '1079', '1', 'Onch’ŏn-gun', 'KP.15.1873193', 'ASCII:Onch''on-gun;ID:1873193', '18353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18353', '112', '20230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1873193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20231', '1079', '1', 'Nangnang-guyŏk', 'KP.12.1873641', 'ASCII:Nangnang-guyok;ID:1873641', '18354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18354', '112', '20231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1873641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20232', '1079', '1', 'Nagwŏn-gun', 'KP.03.1873885', 'ASCII:Nagwon-gun;ID:1873885', '18355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18355', '112', '20232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.1873885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20233', '1079', '1', 'Mundŏk-kun', 'KP.15.1874222', 'ASCII:Mundok-kun;ID:1874222', '18356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18356', '112', '20233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1874222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20234', '1079', '1', 'Munch’ŏn-si', 'KP.09.1874228', 'ASCII:Munch''on-si;ID:1874228', '18357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18357', '112', '20234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1874228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20235', '1079', '1', 'Moranbong-kuyŏk', 'KP.00.1874339', 'ASCII:Moranbong-kuyok;ID:1874339', '18358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18358', '112', '20235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.00.1874339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20236', '1079', '1', 'Man’gyŏngdae-kuyŏk', 'KP.12.1874534', 'ASCII:Man''gyongdae-kuyok;ID:1874534', '18359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18359', '112', '20236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1874534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20237', '1079', '1', 'Maengsan-gun', 'KP.15.1874668', 'ASCII:Maengsan-gun;ID:1874668', '18360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18360', '112', '20237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1874668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20238', '1079', '1', 'Kwaksan-gun', 'KP.11.1875055', 'ASCII:Kwaksan-gun;ID:1875055', '18361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18361', '112', '20238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1875055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20239', '1079', '1', 'Kwail-gun', 'KP.06.1875061', 'ASCII:Kwail-gun;ID:1875061', '18362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18362', '112', '20239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1875061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20240', '1079', '1', 'Kusŏng-si', 'KP.11.1875101', 'ASCII:Kusong-si;ID:1875101', '18363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18363', '112', '20240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1875101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20241', '1079', '1', 'Kŏmya-gun', 'KP.03.1875280', 'ASCII:Komya-gun;ID:1875280', '18364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18364', '112', '20241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.1875280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20242', '1079', '1', 'Kŏmgang-gun', 'KP.09.1875385', 'ASCII:Komgang-gun;ID:1875385', '18365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18365', '112', '20242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1875385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20243', '1079', '1', 'Kŏmch’ŏn-gun', 'KP.07.1875414', 'ASCII:Komch''on-gun;ID:1875414', '18366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18366', '112', '20243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1875414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20244', '1079', '1', 'Kujang-gun', 'KP.11.1875509', 'ASCII:Kujang-gun;ID:1875509', '18367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18367', '112', '20244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1875509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20245', '1079', '1', 'Kowŏn-gun', 'KP.03.1875589', 'ASCII:Kowon-gun;ID:1875589', '18368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18368', '112', '20245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.1875589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20246', '1079', '1', 'Kosŏng-gun', 'KP.09.1875619', 'ASCII:Kosong-gun;ID:1875619', '18369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18369', '112', '20246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1875619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20247', '1079', '1', 'Kosan-gun', 'KP.09.1875637', 'ASCII:Kosan-gun;ID:1875637', '18370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18370', '112', '20247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1875637» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20248', '1079', '1', 'Koksan-gun', 'KP.07.1875793', 'ASCII:Koksan-gun;ID:1875793', '18371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18371', '112', '20248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1875793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20249', '1079', '1', 'Kimhwa-gun', 'KP.09.Kimhwa-gun', 'ASCII:Kimhwa-gun;ID:1875980', '18372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18372', '112', '20249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.Kimhwa-gun» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20250', '1079', '1', 'Kangnyŏng-gun', 'KP.06.1876125', 'ASCII:Kangnyong-gun;ID:1876125', '18373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18373', '112', '20250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1876125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20251', '1079', '1', 'Kangnam-gun', 'KP.12.1876132', 'ASCII:Kangnam-gun;ID:1876132', '18374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18374', '112', '20251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1876132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20252', '1079', '1', 'Kangdong-gun', 'KP.12.1876156', 'ASCII:Kangdong-gun;ID:1876156', '18375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18375', '112', '20252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1876156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20253', '1079', '1', 'Kaesŏng-si', 'KP.08.1876370', 'ASCII:Kaesong-si;ID:1876370', '18376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18376', '112', '20253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.08.1876370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20254', '1079', '1', 'Kaep’ung-gun', 'KP.08.Kaep’ung-gun', 'ASCII:Kaep''ung-gun;ID:1876380', '18377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18377', '112', '20254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.08.Kaep''ung-gun» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20255', '1079', '1', 'Kaech’ŏn-si', 'KP.13.Kaech’ŏn-si', 'ASCII:Kaech''on-si;ID:1876403', '18378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18378', '112', '20255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.Kaech''on-si» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20256', '1079', '1', 'Insan-gun', 'KP.07.1876510', 'ASCII:Insan-gun;ID:1876510', '18379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18379', '112', '20256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1876510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20257', '1079', '1', 'Ich’ŏn-gun', 'KP.09.1876674', 'ASCII:Ich''on-gun;ID:1876674', '18380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18380', '112', '20257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1876674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20258', '1079', '1', 'Hyŏngjesan-kuyŏk', 'KP.00.1876737', 'ASCII:Hyongjesan-kuyok;ID:1876737', '18381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18381', '112', '20258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.00.1876737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20259', '1079', '1', 'Hyangsan-gun', 'KP.11.1876770', 'ASCII:Hyangsan-gun;ID:1876770', '18382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18382', '112', '20259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1876770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20260', '1079', '1', 'Hwangju-gun', 'KP.07.1876874', 'ASCII:Hwangju-gun;ID:1876874', '18383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18383', '112', '20260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.07.1876874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20261', '1079', '1', 'Hoeyang-gun', 'KP.09.1877150', 'ASCII:Hoeyang-gun;ID:1877150', '18384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18384', '112', '20261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1877150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20262', '1079', '1', 'Hoech’ang-gun', 'KP.15.1877192', 'ASCII:Hoech''ang-gun;ID:1877192', '18385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18385', '112', '20262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1877192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20263', '1079', '1', 'Hamju-gun', 'KP.03.1877442', 'ASCII:Hamju-gun;ID:1877442', '18386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18386', '112', '20263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.1877442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20264', '1079', '1', 'Hamhŭng-si', 'KP.03.1877447', 'ASCII:Hamhung-si;ID:1877447', '18387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18387', '112', '20264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.1877447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20265', '1079', '1', 'Haeju-si', 'KP.06.1877609', 'ASCII:Haeju-si;ID:1877609', '18388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18388', '112', '20265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1877609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20266', '1079', '1', 'Chŏngsan-gun', 'KP.15.1877796', 'ASCII:Chongsan-gun;ID:1877796', '18389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18389', '112', '20266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1877796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20267', '1079', '1', 'Chung-kuyŏk', 'KP.12.1877859', 'ASCII:Chung-kuyok;ID:1877859', '18390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18390', '112', '20267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1877859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20268', '1079', '1', 'Chunghwa-gun', 'KP.12.1877875', 'ASCII:Chunghwa-gun;ID:1877875', '18391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18391', '112', '20268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.12.1877875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20269', '1079', '1', 'Ch’ŏrwŏn-gun', 'KP.09.1878166', 'ASCII:Ch''orwon-gun;ID:1878166', '18392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18392', '112', '20269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1878166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20270', '1079', '1', 'Ch’ŏnnae-gun', 'KP.09.1878230', 'ASCII:Ch''onnae-gun;ID:1878230', '18393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18393', '112', '20270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1878230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20271', '1079', '1', 'Chŏngp’yŏng-gun', 'KP.03.1878321', 'ASCII:Chongp''yong-gun;ID:1878321', '18394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18394', '112', '20271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.1878321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20272', '1079', '1', 'Ch''ŏngnam-gu', 'KP.15.1878380', 'ASCII:Ch''ongnam-gu;ID:1878380', '18395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18395', '112', '20272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1878380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20273', '1079', '1', 'Chŏngju-gun', 'KP.11.1878391', 'ASCII:Chongju-gun;ID:1878391', '18396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18396', '112', '20273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1878391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20274', '1079', '1', 'Ch’ŏngdan-gun', 'KP.06.1878459', 'ASCII:Ch''ongdan-gun;ID:1878459', '18397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18397', '112', '20274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1878459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20275', '1079', '1', 'Ch’ŏlsan-gun', 'KP.11.1878581', 'ASCII:Ch''olsan-gun;ID:1878581', '18398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18398', '112', '20275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.1878581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20276', '1079', '1', 'Changyŏn-gun', 'KP.06.1879031', 'ASCII:Changyon-gun;ID:1879031', '18399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18399', '112', '20276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1879031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20277', '1079', '1', 'Changp’ung-gun', 'KP.08.1879105', 'ASCII:Changp''ung-gun;ID:1879105', '18400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18400', '112', '20277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.08.1879105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20278', '1079', '1', 'Ch’angdo-gun', 'KP.09.1879312', 'ASCII:Ch''angdo-gun;ID:1879312', '18401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18401', '112', '20278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1879312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20279', '1079', '1', 'Chaeryŏng-gun', 'KP.06.1879491', 'ASCII:Chaeryong-gun;ID:1879491', '18402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18402', '112', '20279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1879491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20280', '1079', '1', 'Anju-si', 'KP.15.1879614', 'ASCII:Anju-si;ID:1879614', '18403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18403', '112', '20280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.1879614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20281', '1079', '1', 'Anbyŏn-gun', 'KP.09.1879673', 'ASCII:Anbyon-gun;ID:1879673', '18404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18404', '112', '20281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.09.1879673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20282', '1079', '1', 'Anak-kun', 'KP.06.1879681', 'ASCII:Anak-kun;ID:1879681', '18405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18405', '112', '20282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.06.1879681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20283', '1079', '1', 'Hanggu-guyŏk', 'KP.14.1883585', 'ASCII:Hanggu-guyok;ID:1883585', '18406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18406', '112', '20283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.14.1883585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20284', '1079', '1', 'Waudo-guyŏk', 'KP.14.1883586', 'ASCII:Waudo-guyok;ID:1883586', '18407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18407', '112', '20284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.14.1883586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20285', '1079', '1', 'Yŏnsa-gun', 'KP.17.Yŏnsa-gun', 'ASCII:Yonsa-gun;ID:2038910', '18408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18408', '112', '20285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.Yonsa-gun» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20286', '1079', '1', 'Yongnim-gun', 'KP.01.2039045', 'ASCII:Yongnim-gun;ID:2039045', '18409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18409', '112', '20286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2039045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20287', '1079', '1', 'Yŏnggwang-gun', 'KP.03.2039115', 'ASCII:Yonggwang-gun;ID:2039115', '18410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18410', '112', '20287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.2039115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20288', '1079', '1', 'Wiwŏn-gun', 'KP.01.2039456', 'ASCII:Wiwon-gun;ID:2039456', '18411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18411', '112', '20288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2039456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20289', '1079', '1', 'Usi-gun', 'KP.01.2039499', 'ASCII:Usi-gun;ID:2039499', '18412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18412', '112', '20289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2039499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20290', '1079', '1', 'Ŭnsan-gun', 'KP.11.2039522', 'ASCII:Unsan-gun;ID:2039522', '18413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18413', '112', '20290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.2039522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20291', '1079', '1', 'Unhŏng-gun', 'KP.13.2039548', 'ASCII:Unhong-gun;ID:2039548', '18414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18414', '112', '20291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2039548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20292', '1079', '1', 'Ŭndŏk-kun', 'KP.17.2039588', 'ASCII:Undok-kun;ID:2039588', '18415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18415', '112', '20292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2039588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20293', '1079', '1', 'Ŏiju-gun', 'KP.11.2039624', 'ASCII:Oiju-gun;ID:2039624', '18416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18416', '112', '20293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.2039624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20294', '1079', '1', 'Tongsin-gun', 'KP.01.2039727', 'ASCII:Tongsin-gun;ID:2039727', '18417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18417', '112', '20294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2039727» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20295', '1079', '1', 'Tongch’ang-gun', 'KP.11.2039860', 'ASCII:Tongch''ang-gun;ID:2039860', '18418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18418', '112', '20295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.2039860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20296', '1079', '1', 'Tŏksŏng-gun', 'KP.03.2039905', 'ASCII:Toksong-gun;ID:2039905', '18419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18419', '112', '20296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.2039905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20297', '1079', '1', 'Tanch’ŏn-gun', 'KP.03.2040063', 'ASCII:Tanch''on-gun;ID:2040063', '18420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18420', '112', '20297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.2040063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20298', '1079', '1', 'Taehŏng-gun', 'KP.15.2040178', 'ASCII:Taehong-gun;ID:2040178', '18421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18421', '112', '20298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.2040178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20299', '1079', '1', 'Taehongdan-gun', 'KP.13.2040183', 'ASCII:Taehongdan-gun;ID:2040183', '18422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18422', '112', '20299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2040183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20300', '1079', '1', 'Taegwan-gun', 'KP.11.2040192', 'ASCII:Taegwan-gun;ID:2040192', '18423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18423', '112', '20300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.2040192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20301', '1079', '1', 'Songwŏn-gun', 'KP.01.2040482', 'ASCII:Songwon-gun;ID:2040482', '18424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18424', '112', '20301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2040482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20302', '1079', '1', 'Sŏnggan-gun', 'KP.01.2040630', 'ASCII:Songgan-gun;ID:2040630', '18425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18425', '112', '20302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2040630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20303', '1079', '1', 'Sŏnbong-gun', 'KP.18.2040675', 'ASCII:Sonbong-gun;ID:2040675', '18426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18426', '112', '20303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.18.2040675» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20304', '1079', '1', 'Sinŭiju-si', 'KP.11.2040892', 'ASCII:Sinuiju-si;ID:2040892', '18427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18427', '112', '20304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.2040892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20305', '1079', '1', 'Sinp’o-si', 'KP.03.2040953', 'ASCII:Sinp''o-si;ID:2040953', '18428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18428', '112', '20305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.2040953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20306', '1079', '1', 'Sinhŏng-gun', 'KP.03.2041012', 'ASCII:Sinhong-gun;ID:2041012', '18429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18429', '112', '20306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.2041012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20307', '1079', '1', 'Sijung-gun', 'KP.01.2041138', 'ASCII:Sijung-gun;ID:2041138', '18430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18430', '112', '20307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2041138» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20308', '1079', '1', 'Samsu-gun', 'KP.13.2041411', 'ASCII:Samsu-gun;ID:2041411', '18431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18431', '112', '20308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2041411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20309', '1079', '1', 'Samjiyŏn-gun', 'KP.13.2041443', 'ASCII:Samjiyon-gun;ID:2041443', '18432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18432', '112', '20309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2041443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20310', '1079', '1', 'Sakchu-gun', 'KP.11.2041535', 'ASCII:Sakchu-gun;ID:2041535', '18433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18433', '112', '20310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.2041535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20311', '1079', '1', 'Saebyŏl-gun', 'KP.17.2041593', 'ASCII:Saebyol-gun;ID:2041593', '18434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18434', '112', '20311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2041593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20312', '1079', '1', 'Pyŏktong-gun', 'KP.11.2041678', 'ASCII:Pyoktong-gun;ID:2041678', '18435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18435', '112', '20312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.2041678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20313', '1079', '1', 'Puryŏng-gun', 'KP.17.2041700', 'ASCII:Puryong-gun;ID:2041700', '18436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18436', '112', '20313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2041700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20314', '1079', '1', 'P’ungsŏ-gun', 'KP.13.P’ungsŏ-gun', 'ASCII:P''ungso-gun;ID:2041726', '18437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18437', '112', '20314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.P''ungso-gun» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20315', '1079', '1', 'Kimhyŏnggwŏn-gun', 'KP.13.2041732', 'ASCII:Kimhyonggwon-gun;ID:2041732', '18438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18438', '112', '20315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2041732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20316', '1079', '1', 'Pukch’ŏng-gun', 'KP.03.2041812', 'ASCII:Pukch''ong-gun;ID:2041812', '18439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18439', '112', '20316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.2041812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20317', '1079', '1', 'Pujŏn-gun', 'KP.00.2041826', 'ASCII:Pujon-gun;ID:2041826', '18440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18440', '112', '20317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.00.2041826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20318', '1079', '1', 'Poch’ŏn-gun', 'KP.13.2041997', 'ASCII:Poch''on-gun;ID:2041997', '18441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18441', '112', '20318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2041997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20319', '1079', '1', 'Paegam-gun', 'KP.13.2042211', 'ASCII:Paegam-gun;ID:2042211', '18442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18442', '112', '20319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2042211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20320', '1079', '1', 'Ŏrang-gun', 'KP.17.2042256', 'ASCII:Orang-gun;ID:2042256', '18443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18443', '112', '20320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2042256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20321', '1079', '1', 'Onsŏng-gun', 'KP.17.2042268', 'ASCII:Onsong-gun;ID:2042268', '18444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18444', '112', '20321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2042268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20322', '1079', '1', 'Nangnim-gun', 'KP.01.2042491', 'ASCII:Nangnim-gun;ID:2042491', '18445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18445', '112', '20322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2042491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20323', '1079', '1', 'Najin-guyŏk', 'KP.18.2042641', 'ASCII:Najin-guyok;ID:2042641', '18446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18446', '112', '20323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.18.2042641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20324', '1079', '1', 'Hwasŏng-gun', 'KP.17.2042710', 'ASCII:Hwasong-gun;ID:2042710', '18447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18447', '112', '20324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2042710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20325', '1079', '1', 'Myŏngch’ŏn-gun', 'KP.17.2042719', 'ASCII:Myongch''on-gun;ID:2042719', '18448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18448', '112', '20325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2042719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20326', '1079', '1', 'Musan-gun', 'KP.17.2042740', 'ASCII:Musan-gun;ID:2042740', '18449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18449', '112', '20326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2042740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20327', '1079', '1', 'Manp’o-si', 'KP.01.2042891', 'ASCII:Manp''o-si;ID:2042891', '18450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18450', '112', '20327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2042891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20328', '1079', '1', 'Kyŏngsŏng-gun', 'KP.17.2042989', 'ASCII:Kyongsong-gun;ID:2042989', '18451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18451', '112', '20328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2042989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20329', '1079', '1', 'Kop’ung-gun', 'KP.01.2043336', 'ASCII:Kop''ung-gun;ID:2043336', '18452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18452', '112', '20329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2043336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20330', '1079', '1', 'Kimjŏngsuk-kun', 'KP.13.2043475', 'ASCII:Kimjongsuk-kun;ID:2043475', '18453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18453', '112', '20330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2043475» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20331', '1079', '1', 'Kimch''aek-si', 'KP.17.2043476', 'ASCII:Kimch''aek-si;ID:2043476', '18454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18454', '112', '20331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2043476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20332', '1079', '1', 'Kilchu-gun', 'KP.17.2043486', 'ASCII:Kilchu-gun;ID:2043486', '18455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18455', '112', '20332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2043486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20333', '1079', '1', 'Kapsan-gun', 'KP.13.2043532', 'ASCII:Kapsan-gun;ID:2043532', '18456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18456', '112', '20333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2043532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20334', '1079', '1', 'Kanggye-si', 'KP.01.2043568', 'ASCII:Kanggye-si;ID:2043568', '18457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18457', '112', '20334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2043568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20335', '1079', '1', 'Iwŏn-gun', 'KP.03.2043679', 'ASCII:Iwon-gun;ID:2043679', '18458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18458', '112', '20335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.2043679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20336', '1079', '1', 'Hyesan-si', 'KP.13.2043834', 'ASCII:Hyesan-si;ID:2043834', '18459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18459', '112', '20336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2043834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20337', '1079', '1', 'Hwap’yŏng-gun', 'KP.01.2043879', 'ASCII:Hwap''yong-gun;ID:2043879', '18460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18460', '112', '20337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2043879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20338', '1079', '1', 'Hwadae-gun', 'KP.17.2043963', 'ASCII:Hwadae-gun;ID:2043963', '18461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18461', '112', '20338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2043963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20339', '1079', '1', 'Hŏich’ŏn-si', 'KP.01.2044013', 'ASCII:Hoich''on-si;ID:2044013', '18462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18462', '112', '20339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2044013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20340', '1079', '1', 'Kimhyŏngjik-kun', 'KP.13.2044027', 'ASCII:Kimhyongjik-kun;ID:2044027', '18463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18463', '112', '20340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.13.2044027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20341', '1079', '1', 'Hongwŏn-gun', 'KP.03.2044051', 'ASCII:Hongwon-gun;ID:2044051', '18464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18464', '112', '20341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.2044051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20342', '1079', '1', 'Hoeryŏng-gun', 'KP.17.2044094', 'ASCII:Hoeryong-gun;ID:2044094', '18465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18465', '112', '20342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2044094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20343', '1079', '1', 'Hŏch’ŏn-gun', 'KP.03.2044126', 'ASCII:Hoch''on-gun;ID:2044126', '18466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18466', '112', '20343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.2044126» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20344', '1079', '1', 'Chunggang-gun', 'KP.01.2044491', 'ASCII:Chunggang-gun;ID:2044491', '18467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18467', '112', '20344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2044491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20345', '1079', '1', 'Ch’osan-gun', 'KP.01.2044602', 'ASCII:Ch''osan-gun;ID:2044602', '18468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18468', '112', '20345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2044602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20346', '1079', '1', 'Ch’ŏnma-gun', 'KP.11.2044670', 'ASCII:Ch''onma-gun;ID:2044670', '18469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18469', '112', '20346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.2044670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20347', '1079', '1', 'Ch’ŏngjin-si', 'KP.17.2044754', 'ASCII:Ch''ongjin-si;ID:2044754', '18470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18470', '112', '20347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.17.2044754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20348', '1079', '1', 'Chŏnch’ŏn-gun', 'KP.01.Chŏnch’ŏn-gun', 'ASCII:Chonch''on-gun;ID:2044803', '18471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18471', '112', '20348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.Chonch''on-gun» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20349', '1079', '1', 'Chasŏng-gun', 'KP.01.2045006', 'ASCII:Chasong-gun;ID:2045006', '18472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18472', '112', '20349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2045006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20350', '1079', '1', 'Ch’angsŏng-gun', 'KP.11.2045038', 'ASCII:Ch''angsong-gun;ID:2045038', '18473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18473', '112', '20350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.2045038» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20351', '1079', '1', 'Changjin-gun', 'KP.03.2045125', 'ASCII:Changjin-gun;ID:2045125', '18474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18474', '112', '20351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.2045125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20352', '1079', '1', 'Changgang-gun', 'KP.01.2045178', 'ASCII:Changgang-gun;ID:2045178', '18475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18475', '112', '20352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.01.2045178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20353', '1079', '1', 'ŏnsan-gun', 'KP.15.6258672', 'ASCII:onsan-gun;ID:6258672', '18476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18476', '112', '20353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.15.6258672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20354', '1079', '1', 'Ch’ŏllima-guyŏk', 'KP.14.6258673', 'ASCII:Ch''ollima-guyok;ID:6258673', '18477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18477', '112', '20354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.14.6258673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20355', '1079', '1', 'Taean-guyŏk', 'KP.14.6258674', 'ASCII:Taean-guyok;ID:6258674', '18478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18478', '112', '20355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.14.6258674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20356', '1079', '1', 'Sudong-gu', 'KP.03.6258675', 'ASCII:Sudong-gu;ID:6258675', '18479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18479', '112', '20356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.03.6258675» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20357', '1079', '1', 'Sindo-gun', 'KP.11.6279118', 'ASCII:Sindo-gun;ID:6279118', '18480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18480', '112', '20357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KP.11.6279118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20358', '1079', '1', 'Yongin-gun', 'KR.00.1832426', 'ASCII:Yongin-gun;ID:1832426', '18481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18481', '112', '20358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1832426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20359', '1079', '1', 'Yŏngil-gun', 'KR.14.1832431', 'ASCII:Yongil-gun;ID:1832431', '18482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18482', '112', '20359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.14.1832431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20360', '1079', '1', 'Yŏnggwang-gun', 'KR.00.1832500', 'ASCII:Yonggwang-gun;ID:1832500', '18483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18483', '112', '20360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1832500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20361', '1079', '1', 'Yŏngdong-gun', 'KR.05.1832561', 'ASCII:Yongdong-gun;ID:1832561', '18484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18484', '112', '20361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.05.1832561» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20362', '1079', '1', 'Yangyang-gun', 'KR.06.1832808', 'ASCII:Yangyang-gun;ID:1832808', '18485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18485', '112', '20362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.06.1832808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20363', '1079', '1', 'Yangsan-gun', 'KR.00.1832824', 'ASCII:Yangsan-gun;ID:1832824', '18486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18486', '112', '20363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1832824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20364', '1079', '1', 'Wŏlsŏng-gun', 'KR.00.1833276', 'ASCII:Wolsong-gun;ID:1833276', '18487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18487', '112', '20364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1833276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20365', '1079', '1', 'Wando-gun', 'KR.16.1833493', 'ASCII:Wando-gun;ID:1833493', '18488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18488', '112', '20365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.16.1833493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20366', '1079', '1', 'Ŭnp''yŏng-gu', 'KR.00.1833594', 'ASCII:Unp''yong-gu;ID:1833594', '18489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18489', '112', '20366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1833594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20367', '1079', '1', 'Ullŭng-gun', 'KR.14.1833753', 'ASCII:Ullung-gun;ID:1833753', '18490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18490', '112', '20367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.14.1833753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20368', '1079', '1', 'Ulchin-gun', 'KR.00.1833762', 'ASCII:Ulchin-gun;ID:1833762', '18491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18491', '112', '20368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1833762» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20369', '1079', '1', 'Tongnae-gun', 'KR.00.1834199', 'ASCII:Tongnae-gun;ID:1834199', '18492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18492', '112', '20369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1834199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20370', '1079', '1', 'Tongjak-ku', 'KR.00.1834245', 'ASCII:Tongjak-ku;ID:1834245', '18493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18493', '112', '20370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1834245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20371', '1079', '1', 'Tonghae-si', 'KR.06.1834262', 'ASCII:Tonghae-si;ID:1834262', '18494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18494', '112', '20371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.06.1834262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20372', '1079', '1', 'Tongduch''ŏn-si', 'KR.00.1834308', 'ASCII:Tongduch''on-si;ID:1834308', '18495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18495', '112', '20372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1834308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20373', '1079', '1', 'Tongdaemun-gu', 'KR.00.1834328', 'ASCII:Tongdaemun-gu;ID:1834328', '18496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18496', '112', '20373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1834328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20374', '1079', '1', 'Tobong-gu', 'KR.00.1834758', 'ASCII:Tobong-gu;ID:1834758', '18497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18497', '112', '20374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1834758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20375', '1079', '1', 'Tanyang-gun', 'KR.05.1834820', 'ASCII:Tanyang-gun;ID:1834820', '18498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18498', '112', '20375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.05.1834820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20376', '1079', '1', 'Talsŏng-gun', 'KR.00.1834970', 'ASCII:Talsong-gun;ID:1834970', '18499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18499', '112', '20376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1834970» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20377', '1079', '1', 'Sunch’ŏn-si', 'KR.16.1835646', 'ASCII:Sunch''on-si;ID:1835646', '18500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18500', '112', '20377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.16.1835646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20378', '1079', '1', 'Sŏsan-gun', 'KR.17.1835889', 'ASCII:Sosan-gun;ID:1835889', '18501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18501', '112', '20378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.17.1835889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20379', '1079', '1', 'Sŏngnam-si', 'KR.00.1836091', 'ASCII:Songnam-si;ID:1836091', '18502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18502', '112', '20379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1836091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20380', '1079', '1', 'Sŏgwip''o-si', 'KR.01.1836630', 'ASCII:Sogwip''o-si;ID:1836630', '18503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18503', '112', '20380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.01.1836630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20381', '1079', '1', 'Sinan-gun', 'KR.16.1837286', 'ASCII:Sinan-gun;ID:1837286', '18504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18504', '112', '20381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.16.1837286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20382', '1079', '1', 'Sihŭng-si', 'KR.13.1837364', 'ASCII:Sihung-si;ID:1837364', '18505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18505', '112', '20382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.13.1837364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20383', '1079', '1', 'Sangju-gun', 'KR.00.1837705', 'ASCII:Sangju-gun;ID:1837705', '18506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18506', '112', '20383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1837705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20384', '1079', '1', 'P''yŏngt''aek-kun', 'KR.00.1838341', 'ASCII:P''yongt''aek-kun;ID:1838341', '18507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18507', '112', '20384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1838341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20385', '1079', '1', 'P''yŏngch''ang-gun', 'KR.06.1838467', 'ASCII:P''yongch''ang-gun;ID:1838467', '18508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18508', '112', '20385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.06.1838467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20386', '1079', '1', 'Puyŏ-gun', 'KR.00.1838507', 'ASCII:Puyo-gun;ID:1838507', '18509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18509', '112', '20386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1838507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20387', '1079', '1', 'Pukcheju-gun', 'KR.01.1838660', 'ASCII:Pukcheju-gun;ID:1838660', '18510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18510', '112', '20387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.01.1838660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20388', '1079', '1', 'Puch''ŏn-si', 'KR.13.1838715', 'ASCII:Puch''on-si;ID:1838715', '18511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18511', '112', '20388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.13.1838715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20389', '1079', '1', 'Poŭn-gun', 'KR.05.1838730', 'ASCII:Poun-gun;ID:1838730', '18512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18512', '112', '20389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.05.1838730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20390', '1079', '1', 'Posŏng-gun', 'KR.00.1838737', 'ASCII:Posong-gun;ID:1838737', '18513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18513', '112', '20390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1838737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20391', '1079', '1', 'Poryŏng-gun', 'KR.17.1838749', 'ASCII:Poryong-gun;ID:1838749', '18514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18514', '112', '20391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.17.1838749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20392', '1079', '1', 'Ponghwa-gun', 'KR.00.1838893', 'ASCII:Ponghwa-gun;ID:1838893', '18515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18515', '112', '20392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1838893» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20393', '1079', '1', 'P''och''ŏn-gun', 'KR.13.1839102', 'ASCII:P''och''on-gun;ID:1839102', '18516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18516', '112', '20393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.13.1839102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20394', '1079', '1', 'P''aju-si', 'KR.13.1839430', 'ASCII:P''aju-si;ID:1839430', '18517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18517', '112', '20394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.13.1839430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20395', '1079', '1', 'Okku-gun', 'KR.00.1839851', 'ASCII:Okku-gun;ID:1839851', '18518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18518', '112', '20395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1839851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20396', '1079', '1', 'Okch''ŏn-gun', 'KR.05.1839869', 'ASCII:Okch''on-gun;ID:1839869', '18519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18519', '112', '20396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.05.1839869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20397', '1079', '1', 'Namyangju-gun', 'KR.00.1840374', 'ASCII:Namyangju-gun;ID:1840374', '18520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18520', '112', '20397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1840374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20398', '1079', '1', 'Namwŏn-gun', 'KR.00.1840378', 'ASCII:Namwon-gun;ID:1840378', '18521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18521', '112', '20398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1840378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20399', '1079', '1', 'Namjeju-gun', 'KR.01.1840441', 'ASCII:Namjeju-gun;ID:1840441', '18522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18522', '112', '20399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.01.1840441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20400', '1079', '1', 'Naju-gun', 'KR.16.1840535', 'ASCII:Naju-gun;ID:1840535', '18523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18523', '112', '20400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.16.1840535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20401', '1079', '1', 'Mun''gyōng-gun', 'KR.00.1840886', 'ASCII:Mun''gyong-gun;ID:1840886', '18524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18524', '112', '20401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1840886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20402', '1079', '1', 'Miryang-gun', 'KR.00.1841147', 'ASCII:Miryang-gun;ID:1841147', '18525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18525', '112', '20402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1841147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20403', '1079', '1', 'Kwangyang-gun', 'KR.00.1841773', 'ASCII:Kwangyang-gun;ID:1841773', '18526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18526', '112', '20403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1841773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20404', '1079', '1', 'Kwangsan-gun', 'KR.00.1841791', 'ASCII:Kwangsan-gun;ID:1841791', '18527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18527', '112', '20404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1841791» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20405', '1079', '1', 'Kwanak-ku', 'KR.00.1841893', 'ASCII:Kwanak-ku;ID:1841893', '18528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18528', '112', '20405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1841893» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20406', '1079', '1', 'Kuro-gu', 'KR.00.1841986', 'ASCII:Kuro-gu;ID:1841986', '18529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18529', '112', '20406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1841986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20407', '1079', '1', 'Kŭmp''o-gun', 'KR.00.1842170', 'ASCII:Kump''o-gun;ID:1842170', '18530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18530', '112', '20407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1842170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20408', '1079', '1', 'Kŭmje-gun', 'KR.00.1842211', 'ASCII:Kumje-gun;ID:1842211', '18531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18531', '112', '20408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1842211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20409', '1079', '1', 'Kumi-si', 'KR.00.1842218', 'ASCII:Kumi-si;ID:1842218', '18532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18532', '112', '20409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1842218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20410', '1079', '1', 'Koyang-gun', 'KR.00.1842486', 'ASCII:Koyang-gun;ID:1842486', '18533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18533', '112', '20410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1842486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20411', '1079', '1', 'Kosŏng-gun', 'KR.20.1842515', 'ASCII:Kosong-gun;ID:1842515', '18534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18534', '112', '20411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.20.1842515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20412', '1079', '1', 'Koryŏng-gun', 'KR.00.1842555', 'ASCII:Koryong-gun;ID:1842555', '18535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18535', '112', '20412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1842555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20413', '1079', '1', 'Kohŭng-gun', 'KR.00.1842780', 'ASCII:Kohung-gun;ID:1842780', '18536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18536', '112', '20413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1842780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20414', '1079', '1', 'Koesan-gun', 'KR.00.1842799', 'ASCII:Koesan-gun;ID:1842799', '18537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18537', '112', '20414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1842799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20415', '1079', '1', 'Kŏch''ang-gun', 'KR.00.1842853', 'ASCII:Koch''ang-gun;ID:1842853', '18538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18538', '112', '20415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1842853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20416', '1079', '1', 'Koch''ang-gun', 'KR.00.1842854', 'ASCII:Koch''ang-gun;ID:1842854', '18539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18539', '112', '20416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1842854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20417', '1079', '1', 'Kap''yŏng-gun', 'KR.00.1843082', 'ASCII:Kap''yong-gun;ID:1843082', '18540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18540', '112', '20417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1843082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20418', '1079', '1', 'Kangsŏ-gu', 'KR.00.1843128', 'ASCII:Kangso-gu;ID:1843128', '18541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18541', '112', '20418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1843128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20419', '1079', '1', 'Kangnam-ku', 'KR.00.1843140', 'ASCII:Kangnam-ku;ID:1843140', '18542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18542', '112', '20419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1843140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20420', '1079', '1', 'Kanghwa-gun', 'KR.00.1843160', 'ASCII:Kanghwa-gun;ID:1843160', '18543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18543', '112', '20420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1843160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20421', '1079', '1', 'Kangdong-gu', 'KR.00.1843175', 'ASCII:Kangdong-gu;ID:1843175', '18544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18544', '112', '20421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1843175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20422', '1079', '1', 'Imsil-gun', 'KR.00.1843583', 'ASCII:Imsil-gun;ID:1843583', '18545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18545', '112', '20422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1843583» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20423', '1079', '1', 'Iksan-gun', 'KR.00.1843663', 'ASCII:Iksan-gun;ID:1843663', '18546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18546', '112', '20423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1843663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20424', '1079', '1', 'Hwasun-gun', 'KR.16.1843839', 'ASCII:Hwasun-gun;ID:1843839', '18547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18547', '112', '20424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.16.1843839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20425', '1079', '1', 'Hwasŏng-gun', 'KR.00.1843847', 'ASCII:Hwasong-gun;ID:1843847', '18548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18548', '112', '20425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1843847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20426', '1079', '1', 'Hongsŏng-gun', 'KR.00.1844173', 'ASCII:Hongsong-gun;ID:1844173', '18549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18549', '112', '20426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1844173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20427', '1079', '1', 'Hapch''ŏn-gun', 'KR.00.1844410', 'ASCII:Hapch''on-gun;ID:1844410', '18550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18550', '112', '20427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1844410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20428', '1079', '1', 'Hamyang-gun', 'KR.00.1844532', 'ASCII:Hamyang-gun;ID:1844532', '18551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18551', '112', '20428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1844532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20429', '1079', '1', 'Haman-gun', 'KR.00.1844557', 'ASCII:Haman-gun;ID:1844557', '18552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18552', '112', '20429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1844557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20430', '1079', '1', 'Yŏngju-gun', 'KR.00.1844834', 'ASCII:Yongju-gun;ID:1844834', '18553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18553', '112', '20430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1844834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20431', '1079', '1', 'T''ongyŏng-si', 'KR.20.1845017', 'ASCII:T''ongyong-si;ID:1845017', '18554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18554', '112', '20431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.20.1845017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20432', '1079', '1', 'Ch’unch’ŏn-si', 'KR.06.1845134', 'ASCII:Ch''unch''on-si;ID:1845134', '18555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18555', '112', '20432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.06.1845134» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20433', '1079', '1', 'Ch''ŏwŏn-gun', 'KR.06.1845344', 'ASCII:Ch''owon-gun;ID:1845344', '18556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18556', '112', '20433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.06.1845344» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20434', '1079', '1', 'Ch''ŏnwŏn-gun', 'KR.00.1845416', 'ASCII:Ch''onwon-gun;ID:1845416', '18557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18557', '112', '20434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1845416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20435', '1079', '1', 'Ch''ŏngyang-gun', 'KR.00.1845490', 'ASCII:Ch''ongyang-gun;ID:1845490', '18558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18558', '112', '20435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1845490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20436', '1079', '1', 'Chŏngsŏn-gun', 'KR.06.1845515', 'ASCII:Chongson-gun;ID:1845515', '18559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18559', '112', '20436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.06.1845515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20437', '1079', '1', 'Ch''ŏngsong-gun', 'KR.14.1845519', 'ASCII:Ch''ongsong-gun;ID:1845519', '18560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18560', '112', '20437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.14.1845519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20438', '1079', '1', 'Ch''ŏngdo-gun', 'KR.00.1845685', 'ASCII:Ch''ongdo-gun;ID:1845685', '18561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18561', '112', '20438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1845685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20439', '1079', '1', 'Chinyang-gun', 'KR.00.1846008', 'ASCII:Chinyang-gun;ID:1846008', '18562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18562', '112', '20439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1846008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20440', '1079', '1', 'Chindo-gun', 'KR.16.1846089', 'ASCII:Chindo-gun;ID:1846089', '18563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18563', '112', '20440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.16.1846089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20441', '1079', '1', 'Ch''ilgok-kun', 'KR.00.1846148', 'ASCII:Ch''ilgok-kun;ID:1846148', '18564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18564', '112', '20441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1846148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20442', '1079', '1', 'Cheju-si', 'KR.01.1846261', 'ASCII:Cheju-si;ID:1846261', '18565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18565', '112', '20442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.01.1846261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20443', '1079', '1', 'Chech''ŏn-gun', 'KR.05.1846277', 'ASCII:Chech''on-gun;ID:1846277', '18566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18566', '112', '20443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.05.1846277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20444', '1079', '1', 'Ch''angwŏn-si', 'KR.00.1846322', 'ASCII:Ch''angwon-si;ID:1846322', '18567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18567', '112', '20444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1846322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20445', '1079', '1', 'Changsu-gun', 'KR.00.1846351', 'ASCII:Changsu-gun;ID:1846351', '18568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18568', '112', '20445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1846351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20446', '1079', '1', 'Changsŏng-gun', 'KR.00.1846368', 'ASCII:Changsong-gun;ID:1846368', '18569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18569', '112', '20446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1846368» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20447', '1079', '1', 'Asan-gun', 'KR.00.1846848', 'ASCII:Asan-gun;ID:1846848', '18570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18570', '112', '20447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1846848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20448', '1079', '1', 'Anyang-si', 'KR.00.1846894', 'ASCII:Anyang-si;ID:1846894', '18571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18571', '112', '20448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KR.00.1846894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20449', '1079', '1', 'Zelenoe Aūdany', 'KZ.07.607687', 'ASCII:Zelenoe Audany;ID:607687', '18572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18572', '112', '20449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.607687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20450', '1079', '1', 'Qaraqīya Aūdany', 'KZ.09.607726', 'ASCII:Qaraqiya Audany;ID:607726', '18573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18573', '112', '20450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.09.607726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20451', '1079', '1', 'Orda Aūdany', 'KZ.07.607842', 'ASCII:Orda Audany;ID:607842', '18574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18574', '112', '20451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.607842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20452', '1079', '1', 'Oyyl Aūdany', 'KZ.04.607866', 'ASCII:Oyyl Audany;ID:607866', '18575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18575', '112', '20452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.607866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20453', '1079', '1', 'Terekti Aūdany', 'KZ.07.608022', 'ASCII:Terekti Audany;ID:608022', '18576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18576', '112', '20453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.608022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20454', '1079', '1', 'Temir Aūdany', 'KZ.04.608031', 'ASCII:Temir Audany;ID:608031', '18577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18577', '112', '20454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.608031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20455', '1079', '1', 'Taypaq Aūdany', 'KZ.07.608048', 'ASCII:Taypaq Audany;ID:608048', '18578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18578', '112', '20455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.608048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20456', '1079', '1', 'Prīūral''e Aūdany', 'KZ.07.608573', 'ASCII:Priural''e Audany;ID:608573', '18579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18579', '112', '20456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.608573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20457', '1079', '1', 'Oktyabr''sk Aūdany', 'KZ.04.608677', 'ASCII:Oktyabr''sk Audany;ID:608677', '18580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18580', '112', '20457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.608677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20458', '1079', '1', 'Khromtaū Aūdany', 'KZ.04.608707', 'ASCII:Khromtau Audany;ID:608707', '18581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18581', '112', '20458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.608707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20459', '1079', '1', 'Īsatay Aūdany', 'KZ.06.608723', 'ASCII:Isatay Audany;ID:608723', '18582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18582', '112', '20459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.06.608723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20460', '1079', '1', 'Mughalzhar Aūdany', 'KZ.04.608796', 'ASCII:Mughalzhar Audany;ID:608796', '18583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18583', '112', '20460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.608796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20461', '1079', '1', 'Mortyq Aūdany', 'KZ.04.608866', 'ASCII:Mortyq Audany;ID:608866', '18584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18584', '112', '20461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.608866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20462', '1079', '1', 'Mangghystaū Aūdany', 'KZ.09.608878', 'ASCII:Mangghystau Audany;ID:608878', '18585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18585', '112', '20462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.09.608878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20463', '1079', '1', 'Makhambet Aūdany', 'KZ.06.608914', 'ASCII:Makhambet Audany;ID:608914', '18586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18586', '112', '20463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.06.608914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20464', '1079', '1', 'Maqat Aūdany', 'KZ.06.608919', 'ASCII:Maqat Audany;ID:608919', '18587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18587', '112', '20464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.06.608919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20465', '1079', '1', 'Leninskiy Rayon', 'KZ.04.608948', 'ASCII:Leninskiy Rayon;ID:608948', '18588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18588', '112', '20465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.608948» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20466', '1079', '1', 'Qyzylqogha Aūdany', 'KZ.06.608966', 'ASCII:Qyzylqogha Audany;ID:608966', '18589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18589', '112', '20466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.06.608966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20467', '1079', '1', 'Qobda Aūdany', 'KZ.04.609408', 'ASCII:Qobda Audany;ID:609408', '18590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18590', '112', '20467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.609408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20468', '1079', '1', 'Kaztalovka Aūdany', 'KZ.07.609453', 'ASCII:Kaztalovka Audany;ID:609453', '18591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18591', '112', '20468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.609453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20469', '1079', '1', 'Qaratöbe Aūdany', 'KZ.07.609541', 'ASCII:Qaratobe Audany;ID:609541', '18592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18592', '112', '20469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.609541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20470', '1079', '1', 'Tasqala Aūdany', 'KZ.07.609717', 'ASCII:Tasqala Audany;ID:609717', '18593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18593', '112', '20470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.609717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20471', '1079', '1', 'Īsatay Aūdany', 'KZ.04.609786', 'ASCII:Isatay Audany;ID:609786', '18594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18594', '112', '20471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.609786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20472', '1079', '1', 'Īnder Aūdany', 'KZ.06.609795', 'ASCII:Inder Audany;ID:609795', '18595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18595', '112', '20472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.06.609795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20473', '1079', '1', 'Zhalpaqtal Aūdany', 'KZ.07.609902', 'ASCII:Zhalpaqtal Audany;ID:609902', '18596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18596', '112', '20473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.609902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20474', '1079', '1', 'Zhylyoy Aūdany', 'KZ.06.609923', 'ASCII:Zhylyoy Audany;ID:609923', '18597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18597', '112', '20474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.06.609923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20475', '1079', '1', 'Zhänibek Aūdany', 'KZ.07.609952', 'ASCII:Zhanibek Audany;ID:609952', '18598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18598', '112', '20475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.609952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20476', '1079', '1', 'Zhangaqala Aūdany', 'KZ.07.609964', 'ASCII:Zhangaqala Audany;ID:609964', '18599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18599', '112', '20476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.609964» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20477', '1079', '1', 'Syrym Aūdany', 'KZ.07.609978', 'ASCII:Syrym Audany;ID:609978', '18600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18600', '112', '20477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.609978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20478', '1079', '1', 'Kurmanghazy Aūdany', 'KZ.06.610044', 'ASCII:Kurmanghazy Audany;ID:610044', '18601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18601', '112', '20478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.06.610044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20479', '1079', '1', 'Shyngghyrlaū Aūdany', 'KZ.07.610089', 'ASCII:Shyngghyrlau Audany;ID:610089', '18602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18602', '112', '20479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.610089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20480', '1079', '1', 'Shalqar Aūdany', 'KZ.04.610114', 'ASCII:Shalqar Audany;ID:610114', '18603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18603', '112', '20480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.610114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20481', '1079', '1', 'Chapaev Aūdany', 'KZ.07.610130', 'ASCII:Chapaev Audany;ID:610130', '18604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18604', '112', '20481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.610130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20482', '1079', '1', 'Börili Aūdany', 'KZ.07.610162', 'ASCII:Borili Audany;ID:610162', '18605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18605', '112', '20482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.610162» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20483', '1079', '1', 'Beyneū Aūdany', 'KZ.09.610297', 'ASCII:Beyneu Audany;ID:610297', '18606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18606', '112', '20483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.09.610297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20484', '1079', '1', 'Bayghanīn Aūdany', 'KZ.04.610385', 'ASCII:Bayghanin Audany;ID:610385', '18607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18607', '112', '20484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.610385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20485', '1079', '1', 'Balyqshy Aūdany', 'KZ.06.610444', 'ASCII:Balyqshy Audany;ID:610444', '18608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18608', '112', '20485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.06.610444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20486', '1079', '1', 'Algha Aūdany', 'KZ.04.610656', 'ASCII:Algha Audany;ID:610656', '18609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18609', '112', '20486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.610656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20487', '1079', '1', 'Aqzhayyq Aūdany', 'KZ.07.610685', 'ASCII:Aqzhayyq Audany;ID:610685', '18610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18610', '112', '20487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.610685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20488', '1079', '1', 'Aqtöbe Aūdany', 'KZ.04.610687', 'ASCII:Aqtobe Audany;ID:610687', '18611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18611', '112', '20488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.610687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20489', '1079', '1', 'Gorod Ural''sk', 'KZ.07.828320', 'ASCII:Gorod Ural''sk;ID:828320', '18612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18612', '112', '20489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.07.828320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20490', '1079', '1', 'Atyraū Qalasy', 'KZ.06.828321', 'ASCII:Atyrau Qalasy;ID:828321', '18613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18613', '112', '20490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.06.828321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20491', '1079', '1', 'Tupqaraghan Aūdany', 'KZ.09.828323', 'ASCII:Tupqaraghan Audany;ID:828323', '18614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18614', '112', '20491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.09.828323» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20492', '1079', '1', 'Aqtaū Qalasy', 'KZ.09.828324', 'ASCII:Aqtau Qalasy;ID:828324', '18615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18615', '112', '20492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.09.828324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20493', '1079', '1', 'Zhangaözen Qalasy', 'KZ.09.828325', 'ASCII:Zhangaozen Qalasy;ID:828325', '18616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18616', '112', '20493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.09.828325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20494', '1079', '1', 'Aqtöbe Qalasy', 'KZ.04.828331', 'ASCII:Aqtobe Qalasy;ID:828331', '18617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18617', '112', '20494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.828331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20495', '1079', '1', 'Zyryanovsk Aūdany', 'KZ.15.1516437', 'ASCII:Zyryanovsk Audany;ID:1516437', '18618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18618', '112', '20495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1516437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20496', '1079', '1', 'Zhelezīnka Aūdany', 'KZ.11.1516632', 'ASCII:Zhelezinka Audany;ID:1516632', '18619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18619', '112', '20496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1516632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20497', '1079', '1', 'Zharma Aūdany', 'KZ.15.1516713', 'ASCII:Zharma Audany;ID:1516713', '18620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18620', '112', '20497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1516713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20498', '1079', '1', 'Zhangasemey Aūdany', 'KZ.15.1516846', 'ASCII:Zhangasemey Audany;ID:1516846', '18621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18621', '112', '20498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1516846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20499', '1079', '1', 'Zhangadala Aūdany', 'KZ.03.1516873', 'ASCII:Zhangadala Audany;ID:1516873', '18622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18622', '112', '20499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1516873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20500', '1079', '1', 'Zhangaarqa Aūdany', 'KZ.12.1516894', 'ASCII:Zhangaarqa Audany;ID:1516894', '18623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18623', '112', '20500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1516894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20501', '1079', '1', 'Zhaqsy Aūdany', 'KZ.03.1517012', 'ASCII:Zhaqsy Audany;ID:1517012', '18624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18624', '112', '20501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1517012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20502', '1079', '1', 'Zerendi Aūdany', 'KZ.16.1517044', 'ASCII:Zerendi Audany;ID:1517044', '18625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18625', '112', '20502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1517044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20503', '1079', '1', 'Zaysan Aūdany', 'KZ.15.1517057', 'ASCII:Zaysan Audany;ID:1517057', '18626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18626', '112', '20503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1517057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20504', '1079', '1', 'Esil Aūdany', 'KZ.03.1517166', 'ASCII:Esil Audany;ID:1517166', '18627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18627', '112', '20504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1517166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20505', '1079', '1', 'Ereymentaū Aūdany', 'KZ.03.1517189', 'ASCII:Ereymentau Audany;ID:1517189', '18628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18628', '112', '20505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1517189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20506', '1079', '1', 'Aqsū Aūdany', 'KZ.11.1517194', 'ASCII:Aqsu Audany;ID:1517194', '18629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18629', '112', '20506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1517194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20507', '1079', '1', 'Qazybek Bī Aūdany', 'KZ.12.1517288', 'ASCII:Qazybek Bi Audany;ID:1517288', '18630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18630', '112', '20507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1517288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20508', '1079', '1', 'Zhangaqorghan Aūdany', 'KZ.14.1517322', 'ASCII:Zhangaqorghan Audany;ID:1517322', '18631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18631', '112', '20508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.14.1517322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20509', '1079', '1', 'Vozvyshenka Aūdany', 'KZ.16.1517353', 'ASCII:Vozvyshenka Audany;ID:1517353', '18632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18632', '112', '20509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1517353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20510', '1079', '1', 'Ayyrtaū Aūdany', 'KZ.16.1517412', 'ASCII:Ayyrtau Audany;ID:1517412', '18633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18633', '112', '20510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1517412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20511', '1079', '1', 'Arshaly Aūdany', 'KZ.03.1517439', 'ASCII:Arshaly Audany;ID:1517439', '18634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18634', '112', '20511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1517439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20512', '1079', '1', 'Ūälīkhanov Aūdany', 'KZ.16.1517502', 'ASCII:Ualikhanov Audany;ID:1517502', '18635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18635', '112', '20512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1517502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20513', '1079', '1', 'Üyghyr Aūdany', 'KZ.01.1517577', 'ASCII:Uyghyr Audany;ID:1517577', '18636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18636', '112', '20513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1517577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20514', '1079', '1', 'Ūspenka Aūdany', 'KZ.11.1517619', 'ASCII:Uspenka Audany;ID:1517619', '18637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18637', '112', '20514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1517619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20515', '1079', '1', 'Ūrītskīy Aūdany', 'KZ.13.1517715', 'ASCII:Uritskiy Audany;ID:1517715', '18638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18638', '112', '20515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1517715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20516', '1079', '1', 'Ürzhar Aūdany', 'KZ.15.1517718', 'ASCII:Urzhar Audany;ID:1517718', '18639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18639', '112', '20516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1517718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20517', '1079', '1', 'Ulytaū Aūdany', 'KZ.12.1517740', 'ASCII:Ulytau Audany;ID:1517740', '18640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18640', '112', '20517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1517740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20518', '1079', '1', 'Ūl''yanov Aūdany', 'KZ.12.1517745', 'ASCII:Ul''yanov Audany;ID:1517745', '18641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18641', '112', '20518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1517745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20519', '1079', '1', 'Ulan Aūdany', 'KZ.15.1517810', 'ASCII:Ulan Audany;ID:1517810', '18642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18642', '112', '20519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1517810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20520', '1079', '1', 'Tülkibas Aūdany', 'KZ.10.1517878', 'ASCII:Tulkibas Audany;ID:1517878', '18643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18643', '112', '20520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1517878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20521', '1079', '1', 'Türkistan Aūdany', 'KZ.10.1517946', 'ASCII:Turkistan Audany;ID:1517946', '18644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18644', '112', '20521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1517946» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20522', '1079', '1', 'Tselīnograd Aūdany', 'KZ.03.1518002', 'ASCII:Tselinograd Audany;ID:1518002', '18645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18645', '112', '20522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1518002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20523', '1079', '1', 'Tīmīryazev Aūdany', 'KZ.16.1518161', 'ASCII:Timiryazev Audany;ID:1518161', '18646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18646', '112', '20523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1518161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20524', '1079', '1', 'Terengözek Aūdany', 'KZ.14.1518202', 'ASCII:Terengozek Audany;ID:1518202', '18647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18647', '112', '20524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.14.1518202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20525', '1079', '1', 'Tengiz Aūdany', 'KZ.12.1518252', 'ASCII:Tengiz Audany;ID:1518252', '18648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18648', '112', '20525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1518252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20526', '1079', '1', 'Tel''man Aūdany', 'KZ.12.1518281', 'ASCII:Tel''man Audany;ID:1518281', '18649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18649', '112', '20526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1518281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20527', '1079', '1', 'Tavrīya Aūdany', 'KZ.15.1518334', 'ASCII:Tavriya Audany;ID:1518334', '18650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18650', '112', '20527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1518334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20528', '1079', '1', 'Taskesken Aūdany', 'KZ.15.1518415', 'ASCII:Taskesken Audany;ID:1518415', '18651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18651', '112', '20528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1518415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20529', '1079', '1', 'Tarbaghatay Aūdany', 'KZ.15.1518456', 'ASCII:Tarbaghatay Audany;ID:1518456', '18652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18652', '112', '20529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1518456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20530', '1079', '1', 'Taranovskiy Rayon', 'KZ.13.1518463', 'ASCII:Taranovskiy Rayon;ID:1518463', '18653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18653', '112', '20530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1518463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20531', '1079', '1', 'Talghar Aūdany', 'KZ.01.1518519', 'ASCII:Talghar Audany;ID:1518519', '18654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18654', '112', '20531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1518519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20532', '1079', '1', 'Taldyqorghan Aūdany', 'KZ.01.1518545', 'ASCII:Taldyqorghan Audany;ID:1518545', '18655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18655', '112', '20532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1518545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20533', '1079', '1', 'Talas Aūdany', 'KZ.17.1518589', 'ASCII:Talas Audany;ID:1518589', '18656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18656', '112', '20533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1518589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20534', '1079', '1', 'Syrdarīya Aūdany', 'KZ.14.1518650', 'ASCII:Syrdariya Audany;ID:1518650', '18657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18657', '112', '20534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.14.1518650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20535', '1079', '1', 'Sverdlov Aūdany', 'KZ.17.1518673', 'ASCII:Sverdlov Audany;ID:1518673', '18658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18658', '112', '20535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1518673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20536', '1079', '1', 'Sozaq Aūdany', 'KZ.10.1518678', 'ASCII:Sozaq Audany;ID:1518678', '18659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18659', '112', '20536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1518678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20537', '1079', '1', 'Sovet Aūdany', 'KZ.16.1518835', 'ASCII:Sovet Audany;ID:1518835', '18660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18660', '112', '20537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1518835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20538', '1079', '1', 'Sokolovka Aūdany', 'KZ.16.1518912', 'ASCII:Sokolovka Audany;ID:1518912', '18661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18661', '112', '20538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1518912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20539', '1079', '1', 'Shortandy Aūdany', 'KZ.03.1519052', 'ASCII:Shortandy Audany;ID:1519052', '18662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18662', '112', '20539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1519052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20540', '1079', '1', 'Shet Aūdany', 'KZ.12.1519197', 'ASCII:Shet Audany;ID:1519197', '18663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18663', '112', '20540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1519197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20541', '1079', '1', 'Shemonaīkha Aūdany', 'KZ.15.1519224', 'ASCII:Shemonaikha Audany;ID:1519224', '18664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18664', '112', '20541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1519224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20542', '1079', '1', 'Shchūchīnsk Aūdany', 'KZ.16.1519241', 'ASCII:Shchuchinsk Audany;ID:1519241', '18665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18665', '112', '20542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1519241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20543', '1079', '1', 'Sharbaqty Aūdany', 'KZ.11.1519247', 'ASCII:Sharbaqty Audany;ID:1519247', '18666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18666', '112', '20543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1519247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20544', '1079', '1', 'Sergeevka Aūdany', 'KZ.16.1519383', 'ASCII:Sergeevka Audany;ID:1519383', '18667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18667', '112', '20544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1519383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20545', '1079', '1', 'Semiozërnyy Rayon', 'KZ.13.1519416', 'ASCII:Semiozernyy Rayon;ID:1519416', '18668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18668', '112', '20545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1519416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20546', '1079', '1', 'Sileti Aūdany', 'KZ.03.1519433', 'ASCII:Sileti Audany;ID:1519433', '18669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18669', '112', '20546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1519433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20547', '1079', '1', 'Sayram Aūdany', 'KZ.10.1519452', 'ASCII:Sayram Audany;ID:1519452', '18670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18670', '112', '20547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1519452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20548', '1079', '1', 'Sarysū Aūdany', 'KZ.17.1519552', 'ASCII:Sarysu Audany;ID:1519552', '18671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18671', '112', '20548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1519552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20549', '1079', '1', 'Saryaghash Aūdany', 'KZ.10.1519675', 'ASCII:Saryaghash Audany;ID:1519675', '18672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18672', '112', '20549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1519675» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20550', '1079', '1', 'Sarqan Aūdany', 'KZ.01.1519704', 'ASCII:Sarqan Audany;ID:1519704', '18673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18673', '112', '20550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1519704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20551', '1079', '1', 'Samarskoe Aūdany', 'KZ.15.1519757', 'ASCII:Samarskoe Audany;ID:1519757', '18674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18674', '112', '20551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1519757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20552', '1079', '1', 'Rūzaevka Aūdany', 'KZ.16.1519834', 'ASCII:Ruzaevka Audany;ID:1519834', '18675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18675', '112', '20552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1519834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20553', '1079', '1', 'Presnovka Aūdany', 'KZ.16.1520047', 'ASCII:Presnovka Audany;ID:1520047', '18676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18676', '112', '20553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1520047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20554', '1079', '1', 'Pavlodar Aūdany', 'KZ.11.1520238', 'ASCII:Pavlodar Audany;ID:1520238', '18677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18677', '112', '20554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1520238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20555', '1079', '1', 'Panfīlov Aūdany', 'KZ.01.1520251', 'ASCII:Panfilov Audany;ID:1520251', '18678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18678', '112', '20555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1520251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20556', '1079', '1', 'Maqtaaral Aūdany', 'KZ.10.1520258', 'ASCII:Maqtaaral Audany;ID:1520258', '18679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18679', '112', '20556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1520258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20557', '1079', '1', 'Osakarovka Aūdany', 'KZ.12.1520325', 'ASCII:Osakarovka Audany;ID:1520325', '18680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18680', '112', '20557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1520325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20558', '1079', '1', 'Ordzhonīkīdze Aūdany', 'KZ.13.1520378', 'ASCII:Ordzhonikidze Audany;ID:1520378', '18681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18681', '112', '20558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1520378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20559', '1079', '1', 'Nura Aūdany', 'KZ.12.1520497', 'ASCII:Nura Audany;ID:1520497', '18682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18682', '112', '20559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1520497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20560', '1079', '1', 'Novoshūl''ba Aūdany', 'KZ.15.1520548', 'ASCII:Novoshul''ba Audany;ID:1520548', '18683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18683', '112', '20560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1520548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20561', '1079', '1', 'Naūryzym Aūdany', 'KZ.13.1520735', 'ASCII:Nauryzym Audany;ID:1520735', '18684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18684', '112', '20561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1520735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20562', '1079', '1', 'Rayymbek Aūdany', 'KZ.01.1520746', 'ASCII:Rayymbek Audany;ID:1520746', '18685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18685', '112', '20562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1520746» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20563', '1079', '1', 'Moyynqum Aūdany', 'KZ.17.1520845', 'ASCII:Moyynqum Audany;ID:1520845', '18686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18686', '112', '20563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1520845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20564', '1079', '1', 'Moskva Aūdany', 'KZ.16.1520854', 'ASCII:Moskva Audany;ID:1520854', '18687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18687', '112', '20564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1520854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20565', '1079', '1', 'Molodezhnyy Aūdany', 'KZ.12.1520873', 'ASCII:Molodezhnyy Audany;ID:1520873', '18688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18688', '112', '20565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1520873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20566', '1079', '1', 'Mīchūrīn Aūdany', 'KZ.12.1520952', 'ASCII:Michurin Audany;ID:1520952', '18689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18689', '112', '20566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1520952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20567', '1079', '1', 'Merke Aūdany', 'KZ.17.1520965', 'ASCII:Merke Audany;ID:1520965', '18690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18690', '112', '20567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1520965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20568', '1079', '1', 'May Aūdany', 'KZ.11.1521012', 'ASCII:May Audany;ID:1521012', '18691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18691', '112', '20568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1521012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20569', '1079', '1', 'Marqaköl Aūdany', 'KZ.15.1521109', 'ASCII:Marqakol Audany;ID:1521109', '18692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18692', '112', '20569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1521109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20570', '1079', '1', 'Mamlyutka Aūdany', 'KZ.16.1521151', 'ASCII:Mamlyutka Audany;ID:1521151', '18693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18693', '112', '20570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1521151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20571', '1079', '1', 'Bulandy Aūdany', 'KZ.03.1521227', 'ASCII:Bulandy Audany;ID:1521227', '18694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18694', '112', '20571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1521227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20572', '1079', '1', 'Maqanshy Aūdany', 'KZ.15.1521244', 'ASCII:Maqanshy Audany;ID:1521244', '18695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18695', '112', '20572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1521244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20573', '1079', '1', 'Lūgovoe Aūdany', 'KZ.17.1521288', 'ASCII:Lugovoe Audany;ID:1521288', '18696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18696', '112', '20573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1521288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20574', '1079', '1', 'Lenīn Aūdany', 'KZ.16.1521352', 'ASCII:Lenin Audany;ID:1521352', '18697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18697', '112', '20574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1521352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20575', '1079', '1', 'Qazyqurt Aūdany', 'KZ.10.1521354', 'ASCII:Qazyqurt Audany;ID:1521354', '18698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18698', '112', '20575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1521354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20576', '1079', '1', 'Lenīn Aūdany', 'KZ.13.1521358', 'ASCII:Lenin Audany;ID:1521358', '18699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18699', '112', '20576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1521358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20577', '1079', '1', 'Lenīn Aūdany', 'KZ.16.1521359', 'ASCII:Lenin Audany;ID:1521359', '18700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18700', '112', '20577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1521359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20578', '1079', '1', 'Lenīngrad Aūdany', 'KZ.16.1521375', 'ASCII:Leningrad Audany;ID:1521375', '18701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18701', '112', '20578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1521375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20579', '1079', '1', 'Töle Bī Aūdany', 'KZ.10.1521378', 'ASCII:Tole Bi Audany;ID:1521378', '18702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18702', '112', '20579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1521378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20580', '1079', '1', 'Lebyazh''e Aūdany', 'KZ.11.1521382', 'ASCII:Lebyazh''e Audany;ID:1521382', '18703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18703', '112', '20580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1521382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20581', '1079', '1', 'Qyzyltū Aūdany', 'KZ.16.1521400', 'ASCII:Qyzyltu Audany;ID:1521400', '18704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18704', '112', '20581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1521400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20582', '1079', '1', 'Otyrar Aūdany', 'KZ.10.1521407', 'ASCII:Otyrar Audany;ID:1521407', '18705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18705', '112', '20582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1521407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20583', '1079', '1', 'Kūybyshev Aūdany', 'KZ.16.1521634', 'ASCII:Kuybyshev Audany;ID:1521634', '18706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18706', '112', '20583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1521634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20584', '1079', '1', 'Kustanayskiy Rayon', 'KZ.13.1521667', 'ASCII:Kustanayskiy Rayon;ID:1521667', '18707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18707', '112', '20584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1521667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20585', '1079', '1', 'Kürti Aūdany', 'KZ.01.1521711', 'ASCII:Kurti Audany;ID:1521711', '18708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18708', '112', '20585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1521711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20586', '1079', '1', 'Qorghalzhyn Aūdany', 'KZ.03.1521748', 'ASCII:Qorghalzhyn Audany;ID:1521748', '18709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18709', '112', '20586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1521748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20587', '1079', '1', 'Qorday Aūdany', 'KZ.17.1521754', 'ASCII:Qorday Audany;ID:1521754', '18710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18710', '112', '20587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1521754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20588', '1079', '1', 'Kürshim Aūdany', 'KZ.15.1521759', 'ASCII:Kurshim Audany;ID:1521759', '18711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18711', '112', '20588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1521759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20589', '1079', '1', 'Egindiköl Aūdany', 'KZ.03.1521995', 'ASCII:Egindikol Audany;ID:1521995', '18712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18712', '112', '20589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1521995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20590', '1079', '1', 'Aqtoghay Aūdany', 'KZ.11.1522019', 'ASCII:Aqtoghay Audany;ID:1522019', '18713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18713', '112', '20590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1522019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20591', '1079', '1', 'Krasnoarmeysk Aūdany', 'KZ.16.1522032', 'ASCII:Krasnoarmeysk Audany;ID:1522032', '18714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18714', '112', '20591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1522032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20592', '1079', '1', 'Komsomol Aūdany', 'KZ.13.1522333', 'ASCII:Komsomol Audany;ID:1522333', '18715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18715', '112', '20592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1522333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20593', '1079', '1', 'Bögetköl Aūdany', 'KZ.04.1522334', 'ASCII:Bogetkol Audany;ID:1522334', '18716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18716', '112', '20593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.1522334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20594', '1079', '1', 'Kökpekti Aūdany', 'KZ.15.1522504', 'ASCII:Kokpekti Audany;ID:1522504', '18717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18717', '112', '20594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1522504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20595', '1079', '1', 'Kökshetaū Aūdany', 'KZ.16.1522531', 'ASCII:Kokshetau Audany;ID:1522531', '18718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18718', '112', '20595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1522531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20596', '1079', '1', 'Qīma Aūdany', 'KZ.03.1522599', 'ASCII:Qima Audany;ID:1522599', '18719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18719', '112', '20596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1522599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20597', '1079', '1', 'Köksū Aūdany', 'KZ.01.1522636', 'ASCII:Koksu Audany;ID:1522636', '18720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18720', '112', '20597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1522636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20598', '1079', '1', 'Kīrov Aūdany', 'KZ.10.1522640', 'ASCII:Kirov Audany;ID:1522640', '18721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18721', '112', '20598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1522640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20599', '1079', '1', 'Kerbulaq Aūdany', 'KZ.01.1522739', 'ASCII:Kerbulaq Audany;ID:1522739', '18722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18722', '112', '20599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1522739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20600', '1079', '1', 'Kellerovka Aūdany', 'KZ.16.1522808', 'ASCII:Kellerovka Audany;ID:1522808', '18723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18723', '112', '20600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1522808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20601', '1079', '1', 'Keles Aūdany', 'KZ.10.1522812', 'ASCII:Keles Audany;ID:1522812', '18724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18724', '112', '20601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1522812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20602', '1079', '1', 'Kegen Aūdany', 'KZ.01.1522816', 'ASCII:Kegen Audany;ID:1522816', '18725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18725', '112', '20602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1522816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20603', '1079', '1', 'Qazaly Aūdany', 'KZ.14.1522859', 'ASCII:Qazaly Audany;ID:1522859', '18726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18726', '112', '20603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.14.1522859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20604', '1079', '1', 'Qotanqaraghay Aūdany', 'KZ.15.1522926', 'ASCII:Qotanqaraghay Audany;ID:1522926', '18727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18727', '112', '20604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1522926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20605', '1079', '1', 'Qaskeleng Aūdany', 'KZ.01.1522943', 'ASCII:Qaskeleng Audany;ID:1522943', '18728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18728', '112', '20605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1522943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20606', '1079', '1', 'Qarmaqshy Aūdany', 'KZ.14.1522998', 'ASCII:Qarmaqshy Audany;ID:1522998', '18729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18729', '112', '20606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.14.1522998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20607', '1079', '1', 'Qarqaraly Aūdany', 'KZ.12.1523004', 'ASCII:Qarqaraly Audany;ID:1523004', '18730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18730', '112', '20607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1523004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20608', '1079', '1', 'Qaratal Aūdany', 'KZ.01.1523101', 'ASCII:Qaratal Audany;ID:1523101', '18731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18731', '112', '20608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1523101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20609', '1079', '1', 'Qarasū Aūdany', 'KZ.13.1523115', 'ASCII:Qarasu Audany;ID:1523115', '18732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18732', '112', '20609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1523115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20610', '1079', '1', 'Äyteke Bī Aūdany', 'KZ.04.1523423', 'ASCII:Ayteke Bi Audany;ID:1523423', '18733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18733', '112', '20610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.1523423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20611', '1079', '1', 'Qapal Aūdany', 'KZ.01.1523500', 'ASCII:Qapal Audany;ID:1523500', '18734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18734', '112', '20611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1523500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20612', '1079', '1', 'Qamysty Aūdany', 'KZ.13.1523544', 'ASCII:Qamysty Audany;ID:1523544', '18735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18735', '112', '20612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1523544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20613', '1079', '1', 'Kachīry Aūdany', 'KZ.11.1523663', 'ASCII:Kachiry Audany;ID:1523663', '18736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18736', '112', '20613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1523663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20614', '1079', '1', 'Ertis Aūdany', 'KZ.11.1523767', 'ASCII:Ertis Audany;ID:1523767', '18737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18737', '112', '20614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1523767» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20615', '1079', '1', 'Yrghyz Aūdany', 'KZ.04.1523782', 'ASCII:Yrghyz Audany;ID:1523782', '18738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18738', '112', '20615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.04.1523782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20616', '1079', '1', 'Ile Aūdany', 'KZ.01.1524128', 'ASCII:Ile Audany;ID:1524128', '18739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18739', '112', '20616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1524128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20617', '1079', '1', 'Gvardīya Aūdany', 'KZ.01.1524156', 'ASCII:Gvardiya Audany;ID:1524156', '18740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18740', '112', '20617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1524156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20618', '1079', '1', 'Glūbokoe Aūdany', 'KZ.15.1524226', 'ASCII:Glubokoe Audany;ID:1524226', '18741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18741', '112', '20618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1524226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20619', '1079', '1', 'Fedorovka Aūdany', 'KZ.13.1524278', 'ASCII:Fedorovka Audany;ID:1524278', '18742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18742', '112', '20619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1524278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20620', '1079', '1', 'Ėngbekshilder Aūdany', 'KZ.16.1524313', 'ASCII:Engbekshilder Audany;ID:1524313', '18743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18743', '112', '20620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1524313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20621', '1079', '1', 'Engbekshiqazaq Aūdany', 'KZ.01.1524315', 'ASCII:Engbekshiqazaq Audany;ID:1524315', '18744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18744', '112', '20621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1524315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20622', '1079', '1', 'Ekibastuz Aūdany', 'KZ.11.1524322', 'ASCII:Ekibastuz Audany;ID:1524322', '18745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18745', '112', '20622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1524322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20623', '1079', '1', 'Zhūaly Aūdany', 'KZ.17.1524333', 'ASCII:Zhualy Audany;ID:1524333', '18746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18746', '112', '20623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1524333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20624', '1079', '1', 'Zhezdi Aūdany', 'KZ.12.1524382', 'ASCII:Zhezdi Audany;ID:1524382', '18747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18747', '112', '20624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1524382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20625', '1079', '1', 'Zhetisay Aūdany', 'KZ.10.1524384', 'ASCII:Zhetisay Audany;ID:1524384', '18748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18748', '112', '20625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1524384» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20626', '1079', '1', 'Zhetiqara Aūdany', 'KZ.13.1524388', 'ASCII:Zhetiqara Audany;ID:1524388', '18749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18749', '112', '20626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1524388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20627', '1079', '1', 'Zhangeldīn Aūdany', 'KZ.13.1524425', 'ASCII:Zhangeldin Audany;ID:1524425', '18750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18750', '112', '20627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1524425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20628', '1079', '1', 'Zhambyl Aūdany', 'KZ.01.1524438', 'ASCII:Zhambyl Audany;ID:1524438', '18751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18751', '112', '20628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1524438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20629', '1079', '1', 'Zhambyl Aūdany', 'KZ.17.1524439', 'ASCII:Zhambyl Audany;ID:1524439', '18752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18752', '112', '20629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1524439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20630', '1079', '1', 'Zhambyl Aūdany', 'KZ.16.1524440', 'ASCII:Zhambyl Audany;ID:1524440', '18753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18753', '112', '20630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1524440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20631', '1079', '1', 'Zhalaghash Aūdany', 'KZ.14.1524477', 'ASCII:Zhalaghash Audany;ID:1524477', '18754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18754', '112', '20631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.14.1524477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20632', '1079', '1', 'Zharqayyng Aūdany', 'KZ.03.1524603', 'ASCII:Zharqayyng Audany;ID:1524603', '18755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18755', '112', '20632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1524603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20633', '1079', '1', 'Shū Aūdany', 'KZ.17.1524678', 'ASCII:Shu Audany;ID:1524678', '18756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18756', '112', '20633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1524678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20634', '1079', '1', 'Shubartaū Aūdany', 'KZ.15.1524717', 'ASCII:Shubartau Audany;ID:1524717', '18757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18757', '112', '20634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1524717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20635', '1079', '1', 'Chkalov Aūdany', 'KZ.16.1524749', 'ASCII:Chkalov Audany;ID:1524749', '18758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18758', '112', '20635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1524749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20636', '1079', '1', 'Chīstopol''e Aūdany', 'KZ.16.1524766', 'ASCII:Chistopol''e Audany;ID:1524766', '18759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18759', '112', '20636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1524766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20637', '1079', '1', 'Shelek Aūdany', 'KZ.01.1524792', 'ASCII:Shelek Audany;ID:1524792', '18760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18760', '112', '20637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1524792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20638', '1079', '1', 'Shīeli Aūdany', 'KZ.14.1524798', 'ASCII:Shieli Audany;ID:1524798', '18761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18761', '112', '20638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.14.1524798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20639', '1079', '1', 'Shar Aūdany', 'KZ.15.1524882', 'ASCII:Shar Audany;ID:1524882', '18762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18762', '112', '20639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1524882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20640', '1079', '1', 'Shardara Aūdany', 'KZ.10.1524885', 'ASCII:Shardara Audany;ID:1524885', '18763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18763', '112', '20640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1524885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20641', '1079', '1', 'Börilitöbe Aūdany', 'KZ.01.1524969', 'ASCII:Borilitobe Audany;ID:1524969', '18764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18764', '112', '20641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1524969» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20642', '1079', '1', 'Būlaevo Aūdany', 'KZ.16.1525010', 'ASCII:Bulaevo Audany;ID:1525010', '18765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18765', '112', '20642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1525010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20643', '1079', '1', 'Ordabasy Aūdany', 'KZ.10.1525042', 'ASCII:Ordabasy Audany;ID:1525042', '18766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18766', '112', '20643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1525042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20644', '1079', '1', 'Mendykarinskiy Rayon', 'KZ.13.1525120', 'ASCII:Mendykarinskiy Rayon;ID:1525120', '18767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18767', '112', '20644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1525120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20645', '1079', '1', 'Borodūlīkha Aūdany', 'KZ.15.1525133', 'ASCII:Borodulikha Audany;ID:1525133', '18768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18768', '112', '20645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1525133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20646', '1079', '1', 'Ülkennaryn Aūdany', 'KZ.15.1525198', 'ASCII:Ulkennaryn Audany;ID:1525198', '18769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18769', '112', '20646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1525198» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20647', '1079', '1', 'Besköl Aūdany', 'KZ.16.1525293', 'ASCII:Beskol Audany;ID:1525293', '18770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18770', '112', '20647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1525293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20648', '1079', '1', 'Besqaraghay Aūdany', 'KZ.15.1525406', 'ASCII:Besqaraghay Audany;ID:1525406', '18771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18771', '112', '20648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1525406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20649', '1079', '1', 'Bayanaūyl Aūdany', 'KZ.11.1525651', 'ASCII:Bayanauyl Audany;ID:1525651', '18772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18772', '112', '20649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1525651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20650', '1079', '1', 'Balqash Aūdany', 'KZ.01.1525804', 'ASCII:Balqash Audany;ID:1525804', '18773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18773', '112', '20650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1525804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20651', '1079', '1', 'Sandyqtaū Aūdany', 'KZ.03.1525806', 'ASCII:Sandyqtau Audany;ID:1525806', '18774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18774', '112', '20651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1525806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20652', '1079', '1', 'Ayaköz Qalasy', 'KZ.15.1525986', 'ASCII:Ayakoz Qalasy;ID:1525986', '18775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18775', '112', '20652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1525986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20653', '1079', '1', 'Auezovskiy Rayon', 'KZ.02.1526020', 'ASCII:Auezovskiy Rayon;ID:1526020', '18776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18776', '112', '20653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.02.1526020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20654', '1079', '1', 'Atbasar Aūdany', 'KZ.03.1526033', 'ASCII:Atbasar Audany;ID:1526033', '18777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18777', '112', '20654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1526033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20655', '1079', '1', 'Astrakhan Aūdany', 'KZ.03.1526056', 'ASCII:Astrakhan Audany;ID:1526056', '18778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18778', '112', '20655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1526056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20656', '1079', '1', 'Aryqbalyq Aūdany', 'KZ.16.1526177', 'ASCII:Aryqbalyq Audany;ID:1526177', '18779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18779', '112', '20656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1526177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20657', '1079', '1', 'Arqalyq Aūdany', 'KZ.13.1526209', 'ASCII:Arqalyq Audany;ID:1526209', '18780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18780', '112', '20657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1526209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20658', '1079', '1', 'Aral Aūdany', 'KZ.14.1526248', 'ASCII:Aral Audany;ID:1526248', '18781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18781', '112', '20658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.14.1526248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20659', '1079', '1', 'Üygentas Aūdany', 'KZ.01.1526298', 'ASCII:Uygentas Audany;ID:1526298', '18782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18782', '112', '20659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1526298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20660', '1079', '1', 'Amantoghay Aūdany', 'KZ.13.1526321', 'ASCII:Amantoghay Audany;ID:1526321', '18783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18783', '112', '20660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1526321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20661', '1079', '1', 'Amangeldi Aūdany', 'KZ.13.1526340', 'ASCII:Amangeldi Audany;ID:1526340', '18784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18784', '112', '20661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1526340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20662', '1079', '1', 'Alghabas Aūdany', 'KZ.10.1526412', 'ASCII:Alghabas Audany;ID:1526412', '18785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18785', '112', '20662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1526412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20663', '1079', '1', 'Aqköl Aūdany', 'KZ.03.1526436', 'ASCII:Aqkol Audany;ID:1526436', '18786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18786', '112', '20663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1526436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20664', '1079', '1', 'Alaköl Aūdany', 'KZ.01.1526489', 'ASCII:Alakol Audany;ID:1526489', '18787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18787', '112', '20664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1526489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20665', '1079', '1', 'Aqtoghay Aūdany', 'KZ.12.1526570', 'ASCII:Aqtoghay Audany;ID:1526570', '18788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18788', '112', '20665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1526570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20666', '1079', '1', 'Aqsū Aūdany', 'KZ.01.1526631', 'ASCII:Aqsu Audany;ID:1526631', '18789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18789', '112', '20666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1526631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20667', '1079', '1', 'Aqsūat Aūdany', 'KZ.15.1526637', 'ASCII:Aqsuat Audany;ID:1526637', '18790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18790', '112', '20667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1526637» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20668', '1079', '1', 'Aqadyr Aūdany', 'KZ.12.1526940', 'ASCII:Aqadyr Audany;ID:1526940', '18791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18791', '112', '20668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1526940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20669', '1079', '1', 'Abay Aūdany', 'KZ.15.1526967', 'ASCII:Abay Audany;ID:1526967', '18792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18792', '112', '20669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1526967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20670', '1079', '1', 'Altynsarinskiy Rayon', 'KZ.13.1537245', 'ASCII:Altynsarinskiy Rayon;ID:1537245', '18793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18793', '112', '20670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1537245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20671', '1079', '1', 'Qostanay Qalasy', 'KZ.13.1537246', 'ASCII:Qostanay Qalasy;ID:1537246', '18794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18794', '112', '20671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1537246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20672', '1079', '1', 'Zhetiqara Qalasy', 'KZ.13.1537247', 'ASCII:Zhetiqara Qalasy;ID:1537247', '18795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18795', '112', '20672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1537247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20673', '1079', '1', 'Līsakovsk Qalasy', 'KZ.13.1537248', 'ASCII:Lisakovsk Qalasy;ID:1537248', '18796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18796', '112', '20673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1537248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20674', '1079', '1', 'Rūdnyy Qalasy', 'KZ.13.1537249', 'ASCII:Rudnyy Qalasy;ID:1537249', '18797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18797', '112', '20674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1537249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20675', '1079', '1', 'Oktyabr'' Aūdany', 'KZ.13.1537251', 'ASCII:Oktyabr'' Audany;ID:1537251', '18798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18798', '112', '20675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.13.1537251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20676', '1079', '1', 'Toqyraūyn Aūdany', 'KZ.12.1537252', 'ASCII:Toqyrauyn Audany;ID:1537252', '18799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18799', '112', '20676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1537252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20677', '1079', '1', 'Zhezqazghan Qalasy', 'KZ.12.1537254', 'ASCII:Zhezqazghan Qalasy;ID:1537254', '18800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18800', '112', '20677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1537254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20678', '1079', '1', 'Balqash Qalasy', 'KZ.12.1537255', 'ASCII:Balqash Qalasy;ID:1537255', '18801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18801', '112', '20678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1537255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20679', '1079', '1', 'Qarazhal Qalasy', 'KZ.12.1537256', 'ASCII:Qarazhal Qalasy;ID:1537256', '18802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18802', '112', '20679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1537256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20680', '1079', '1', 'Qalasy Sätbaev', 'KZ.12.1537257', 'ASCII:Qalasy Satbaev;ID:1537257', '18803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18803', '112', '20680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1537257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20681', '1079', '1', 'Kökshetaū Qalasy', 'KZ.16.1537261', 'ASCII:Kokshetau Qalasy;ID:1537261', '18804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18804', '112', '20681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1537261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20682', '1079', '1', 'Shchūchīnsk Qalasy', 'KZ.16.1537262', 'ASCII:Shchuchinsk Qalasy;ID:1537262', '18805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18805', '112', '20682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.16.1537262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20683', '1079', '1', 'Aqmola Qalasy', 'KZ.03.1537263', 'ASCII:Aqmola Qalasy;ID:1537263', '18806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18806', '112', '20683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1537263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20684', '1079', '1', 'Atbasar Qalasy', 'KZ.03.1537264', 'ASCII:Atbasar Qalasy;ID:1537264', '18807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18807', '112', '20684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1537264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20685', '1079', '1', 'Stepnogorsk Qalasy', 'KZ.03.1537265', 'ASCII:Stepnogorsk Qalasy;ID:1537265', '18808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18808', '112', '20685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.03.1537265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20686', '1079', '1', 'Qaraghandy Qalasy', 'KZ.12.1537266', 'ASCII:Qaraghandy Qalasy;ID:1537266', '18809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18809', '112', '20686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1537266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20687', '1079', '1', 'Abay Qalasy', 'KZ.12.1537267', 'ASCII:Abay Qalasy;ID:1537267', '18810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18810', '112', '20687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1537267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20688', '1079', '1', 'Sorang Qalasy', 'KZ.12.1537268', 'ASCII:Sorang Qalasy;ID:1537268', '18811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18811', '112', '20688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1537268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20689', '1079', '1', 'Temirtaū Qalasy', 'KZ.12.1537269', 'ASCII:Temirtau Qalasy;ID:1537269', '18812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18812', '112', '20689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1537269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20690', '1079', '1', 'Shakhtīnsk Qalasy', 'KZ.12.1537270', 'ASCII:Shakhtinsk Qalasy;ID:1537270', '18813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18813', '112', '20690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.12.1537270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20691', '1079', '1', 'Arys Aūdany', 'KZ.10.1537271', 'ASCII:Arys Audany;ID:1537271', '18814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18814', '112', '20691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1537271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20692', '1079', '1', 'Shymkent Qalasy', 'KZ.10.1537272', 'ASCII:Shymkent Qalasy;ID:1537272', '18815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18815', '112', '20692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1537272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20693', '1079', '1', 'Arys Qalasy', 'KZ.10.1537273', 'ASCII:Arys Qalasy;ID:1537273', '18816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18816', '112', '20693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1537273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20694', '1079', '1', 'Kentaū Qalasy', 'KZ.10.1537274', 'ASCII:Kentau Qalasy;ID:1537274', '18817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18817', '112', '20694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1537274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20695', '1079', '1', 'Lenger Qalasy', 'KZ.10.1537275', 'ASCII:Lenger Qalasy;ID:1537275', '18818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18818', '112', '20695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1537275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20696', '1079', '1', 'Türkistan Qalasy', 'KZ.10.1537276', 'ASCII:Turkistan Qalasy;ID:1537276', '18819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18819', '112', '20696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.10.1537276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20697', '1079', '1', 'Zhambyl Qalasy', 'KZ.17.1537277', 'ASCII:Zhambyl Qalasy;ID:1537277', '18820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18820', '112', '20697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1537277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20698', '1079', '1', 'Zhangatas Qalasy', 'KZ.17.1537278', 'ASCII:Zhangatas Qalasy;ID:1537278', '18821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18821', '112', '20698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1537278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20699', '1079', '1', 'Qarataū Qalasy', 'KZ.17.1537279', 'ASCII:Qaratau Qalasy;ID:1537279', '18822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18822', '112', '20699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1537279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20700', '1079', '1', 'Shū Qalasy', 'KZ.17.1537280', 'ASCII:Shu Qalasy;ID:1537280', '18823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18823', '112', '20700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.17.1537280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20701', '1079', '1', 'Qapshaghay Qalasy', 'KZ.01.1537281', 'ASCII:Qapshaghay Qalasy;ID:1537281', '18824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18824', '112', '20701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1537281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20702', '1079', '1', 'Talghar Qalasy', 'KZ.01.1537282', 'ASCII:Talghar Qalasy;ID:1537282', '18825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18825', '112', '20702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1537282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20703', '1079', '1', 'Taldyqorghan Qalasy', 'KZ.01.1537283', 'ASCII:Taldyqorghan Qalasy;ID:1537283', '18826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18826', '112', '20703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1537283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20704', '1079', '1', 'Tekeli Qalasy', 'KZ.01.1537284', 'ASCII:Tekeli Qalasy;ID:1537284', '18827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18827', '112', '20704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.01.1537284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20705', '1079', '1', 'Semey Qalasy', 'KZ.15.1537285', 'ASCII:Semey Qalasy;ID:1537285', '18828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18828', '112', '20705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1537285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20706', '1079', '1', 'Öskemen Qalasy', 'KZ.15.1537286', 'ASCII:Oskemen Qalasy;ID:1537286', '18829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18829', '112', '20706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1537286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20707', '1079', '1', 'Zyryanovsk Qalasy', 'KZ.15.1537287', 'ASCII:Zyryanovsk Qalasy;ID:1537287', '18830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18830', '112', '20707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1537287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20708', '1079', '1', 'Lenīnogorsk Qalasy', 'KZ.15.1537288', 'ASCII:Leninogorsk Qalasy;ID:1537288', '18831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18831', '112', '20708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1537288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20709', '1079', '1', 'Serebryansk Qalasy', 'KZ.15.1537289', 'ASCII:Serebryansk Qalasy;ID:1537289', '18832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18832', '112', '20709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1537289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20710', '1079', '1', 'Pavlodar Qalasy', 'KZ.11.1537290', 'ASCII:Pavlodar Qalasy;ID:1537290', '18833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18833', '112', '20710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1537290» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20711', '1079', '1', 'Aqsū Qalasy', 'KZ.11.1537291', 'ASCII:Aqsu Qalasy;ID:1537291', '18834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18834', '112', '20711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1537291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20712', '1079', '1', 'Ekibastuz Qalasy', 'KZ.11.1537292', 'ASCII:Ekibastuz Qalasy;ID:1537292', '18835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18835', '112', '20712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.11.1537292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20713', '1079', '1', 'Abyraly Aūdany', 'KZ.15.1537309', 'ASCII:Abyraly Audany;ID:1537309', '18836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18836', '112', '20713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «KZ.15.1537309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20714', '1079', '1', 'Muang Houayxay', 'LA.22.1651946', 'ASCII:Muang Houayxay;ID:1651946', '18837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18837', '112', '20714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.22.1651946» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20715', '1079', '1', 'Muang Ngeun', 'LA.13.1652070', 'ASCII:Muang Ngeun;ID:1652070', '18838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18838', '112', '20715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.13.1652070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20716', '1079', '1', 'Muang Xiangkhoang', 'LA.14.1652076', 'ASCII:Muang Xiangkhoang;ID:1652076', '18839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18839', '112', '20716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.14.1652076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20717', '1079', '1', 'Muang Xianghon', 'LA.13.1652081', 'ASCII:Muang Xianghon;ID:1652081', '18840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18840', '112', '20717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.13.1652081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20718', '1079', '1', 'Muang Xépôn', 'LA.20.1652095', 'ASCII:Muang Xepon;ID:1652095', '18841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18841', '112', '20718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1652095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20719', '1079', '1', 'Muang Xai', 'LA.07.1652132', 'ASCII:Muang Xai;ID:1652132', '18842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18842', '112', '20719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.07.1652132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20720', '1079', '1', 'Muang Xam Nua', 'LA.03.1652202', 'ASCII:Muang Xam Nua;ID:1652202', '18843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18843', '112', '20720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.03.1652202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20721', '1079', '1', 'Muang Xaignabouli', 'LA.13.1652209', 'ASCII:Muang Xaignabouli;ID:1652209', '18844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18844', '112', '20721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.13.1652209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20722', '1079', '1', 'Muang Vapi', 'LA.19.1652275', 'ASCII:Muang Vapi;ID:1652275', '18845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18845', '112', '20722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.19.1652275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20723', '1079', '1', 'Muang Vangviang', 'LA.24.1652280', 'ASCII:Muang Vangviang;ID:1652280', '18846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18846', '112', '20723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1652280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20724', '1079', '1', 'Muang Thoulakhôm', 'LA.24.1652341', 'ASCII:Muang Thoulakhom;ID:1652341', '18847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18847', '112', '20724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1652341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20725', '1079', '1', 'Muang Thathôm', 'LA.25.1652593', 'ASCII:Muang Thathom;ID:1652593', '18848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18848', '112', '20725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.25.1652593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20726', '1079', '1', 'Muang Thatèng', 'LA.26.1652594', 'ASCII:Muang Thateng;ID:1652594', '18849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18849', '112', '20726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.26.1652594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20727', '1079', '1', 'Muang Ta-Ôy', 'LA.19.1652935', 'ASCII:Muang Ta-Oy;ID:1652935', '18850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18850', '112', '20727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.19.1652935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20728', '1079', '1', 'Muang Soukhouma', 'LA.02.1653008', 'ASCII:Muang Soukhouma;ID:1653008', '18851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18851', '112', '20728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.02.1653008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20729', '1079', '1', 'Muang Songkhon', 'LA.20.1653070', 'ASCII:Muang Songkhon;ID:1653070', '18852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18852', '112', '20729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1653070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20730', '1079', '1', 'Muang Sing', 'LA.16.1653142', 'ASCII:Muang Sing;ID:1653142', '18853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18853', '112', '20730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.16.1653142» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20731', '1079', '1', 'Muang Salavan', 'LA.19.1653332', 'ASCII:Muang Salavan;ID:1653332', '18854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18854', '112', '20731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.19.1653332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20732', '1079', '1', 'Muang Phônthong', 'LA.02.1653886', 'ASCII:Muang Phonthong;ID:1653886', '18855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18855', '112', '20732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.02.1653886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20733', '1079', '1', 'Muang Phôn-Hông', 'LA.24.1653888', 'ASCII:Muang Phon-Hong;ID:1653888', '18856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18856', '112', '20733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1653888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20734', '1079', '1', 'Muang Phôngsali', 'LA.18.1653892', 'ASCII:Muang Phongsali;ID:1653892', '18857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18857', '112', '20734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.18.1653892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20735', '1079', '1', 'Muang Phin', 'LA.20.1653916', 'ASCII:Muang Phin;ID:1653916', '18858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18858', '112', '20735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1653916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20736', '1079', '1', 'Muang Pèk', 'LA.14.1654248', 'ASCII:Muang Pek;ID:1654248', '18859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18859', '112', '20736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.14.1654248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20737', '1079', '1', 'Muang Pathoumphon', 'LA.02.1654276', 'ASCII:Muang Pathoumphon;ID:1654276', '18860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18860', '112', '20737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.02.1654276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20738', '1079', '1', 'Muang Pakxong', 'LA.02.1654374', 'ASCII:Muang Pakxong;ID:1654374', '18861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18861', '112', '20738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.02.1654374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20739', '1079', '1', 'Muang Pakxé', 'LA.02.1654378', 'ASCII:Muang Pakxe;ID:1654378', '18862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18862', '112', '20739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.02.1654378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20740', '1079', '1', 'Muang Pakxan', 'LA.23.1654380', 'ASCII:Muang Pakxan;ID:1654380', '18863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18863', '112', '20740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.23.1654380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20741', '1079', '1', 'Muang Paktha', 'LA.22.1654385', 'ASCII:Muang Paktha;ID:1654385', '18864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18864', '112', '20741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.22.1654385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20742', '1079', '1', 'Muang Pak-Ou', 'LA.17.1654392', 'ASCII:Muang Pak-Ou;ID:1654392', '18865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18865', '112', '20742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.17.1654392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20743', '1079', '1', 'Muang Paklay', 'LA.13.1654398', 'ASCII:Muang Paklay;ID:1654398', '18866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18866', '112', '20743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.13.1654398» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20744', '1079', '1', 'Muang Pakkading', 'LA.23.1654415', 'ASCII:Muang Pakkading;ID:1654415', '18867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18867', '112', '20744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.23.1654415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20745', '1079', '1', 'Muang Pakbèng', 'LA.07.1654418', 'ASCII:Muang Pakbeng;ID:1654418', '18868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18868', '112', '20745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.07.1654418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20746', '1079', '1', 'Muang Nong', 'LA.20.1654616', 'ASCII:Muang Nong;ID:1654616', '18869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18869', '112', '20746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1654616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20747', '1079', '1', 'Muang Ngoy', 'LA.17.1654686', 'ASCII:Muang Ngoy;ID:1654686', '18870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18870', '112', '20747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.17.1654686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20748', '1079', '1', 'Muang Nan', 'LA.17.1654833', 'ASCII:Muang Nan;ID:1654833', '18871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18871', '112', '20748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.17.1654833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20749', '1079', '1', 'Muang Namo', 'LA.07.1654902', 'ASCII:Muang Namo;ID:1654902', '18872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18872', '112', '20749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.07.1654902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20750', '1079', '1', 'Muang Nambak', 'LA.17.1654981', 'ASCII:Muang Nambak;ID:1654981', '18873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18873', '112', '20750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.17.1654981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20751', '1079', '1', 'Muang Mounlapamôk', 'LA.02.1655243', 'ASCII:Muang Mounlapamok;ID:1655243', '18874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18874', '112', '20751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.02.1655243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20752', '1079', '1', 'Muang Mahaxai', 'LA.15.1655492', 'ASCII:Muang Mahaxai;ID:1655492', '18875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18875', '112', '20752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.15.1655492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20753', '1079', '1', 'Muang Louangphrabang', 'LA.17.1655557', 'ASCII:Muang Louangphrabang;ID:1655557', '18876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18876', '112', '20753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.17.1655557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20754', '1079', '1', 'Muang Louang Namtha', 'LA.16.1655560', 'ASCII:Muang Louang Namtha;ID:1655560', '18877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18877', '112', '20754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.16.1655560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20755', '1079', '1', 'Muang Laongam', 'LA.19.1655850', 'ASCII:Muang Laongam;ID:1655850', '18878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18878', '112', '20755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.19.1655850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20756', '1079', '1', 'Muang Lakhonphéng', 'LA.19.1655961', 'ASCII:Muang Lakhonpheng;ID:1655961', '18879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18879', '112', '20756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.19.1655961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20757', '1079', '1', 'Muang La', 'LA.07.1656000', 'ASCII:Muang La;ID:1656000', '18880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18880', '112', '20757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.07.1656000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20758', '1079', '1', 'Muang Khôngxédôn', 'LA.19.1656324', 'ASCII:Muang Khongxedon;ID:1656324', '18881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18881', '112', '20758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.19.1656324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20759', '1079', '1', 'Muang Không', 'LA.02.1656331', 'ASCII:Muang Khong;ID:1656331', '18882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18882', '112', '20759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.02.1656331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20760', '1079', '1', 'Muang Thakhèk', 'LA.15.1656537', 'ASCII:Muang Thakhek;ID:1656537', '18883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18883', '112', '20760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.15.1656537» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20761', '1079', '1', 'Muang Khamkeut', 'LA.23.1656546', 'ASCII:Muang Khamkeut;ID:1656546', '18884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18884', '112', '20761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.23.1656546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20762', '1079', '1', 'Muang Kasi', 'LA.24.1656743', 'ASCII:Muang Kasi;ID:1656743', '18885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18885', '112', '20762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1656743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20763', '1079', '1', 'Muang Hun', 'LA.07.1656964', 'ASCII:Muang Hun;ID:1656964', '18886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18886', '112', '20763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.07.1656964» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20764', '1079', '1', 'Muang Houamuang', 'LA.03.1657120', 'ASCII:Muang Houamuang;ID:1657120', '18887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18887', '112', '20764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.03.1657120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20765', '1079', '1', 'Muang Hôngsa', 'LA.13.1657146', 'ASCII:Muang Hongsa;ID:1657146', '18888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18888', '112', '20765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.13.1657146» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20766', '1079', '1', 'Muang Hinboun', 'LA.15.1657260', 'ASCII:Muang Hinboun;ID:1657260', '18889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18889', '112', '20766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.15.1657260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20767', '1079', '1', 'Muang Champhon', 'LA.20.1657816', 'ASCII:Muang Champhon;ID:1657816', '18890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18890', '112', '20767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1657816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20768', '1079', '1', 'Muang Champasak', 'LA.02.1657817', 'ASCII:Muang Champasak;ID:1657817', '18891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18891', '112', '20768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.02.1657817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20769', '1079', '1', 'Muang Boun Tai', 'LA.18.1657870', 'ASCII:Muang Boun Tai;ID:1657870', '18892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18892', '112', '20769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.18.1657870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20770', '1079', '1', 'Muang Bolikhan', 'LA.23.1657896', 'ASCII:Muang Bolikhan;ID:1657896', '18893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18893', '112', '20770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.23.1657896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20771', '1079', '1', 'Muang Bèng', 'LA.07.1657942', 'ASCII:Muang Beng;ID:1657942', '18894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18894', '112', '20771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.07.1657942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20772', '1079', '1', 'Muang Bachang', 'LA.02.1904701', 'ASCII:Muang Bachang;ID:1904701', '18895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18895', '112', '20772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.02.1904701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20773', '1079', '1', 'Muang Dakchung', 'LA.26.1904713', 'ASCII:Muang Dakchung;ID:1904713', '18896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18896', '112', '20773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.26.1904713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20774', '1079', '1', 'Muang Toumlan', 'LA.19.1904719', 'ASCII:Muang Toumlan;ID:1904719', '18897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18897', '112', '20774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.19.1904719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20775', '1079', '1', 'Muang Laman', 'LA.26.1904768', 'ASCII:Muang Laman;ID:1904768', '18898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18898', '112', '20775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.26.1904768» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20776', '1079', '1', 'Muang Xaiséttha', 'LA.01.1904769', 'ASCII:Muang Xaisettha;ID:1904769', '18899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18899', '112', '20776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.01.1904769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20777', '1079', '1', 'Muang Samakhixai', 'LA.01.1904770', 'ASCII:Muang Samakhixai;ID:1904770', '18900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18900', '112', '20777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.01.1904770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20778', '1079', '1', 'Muang Sanamxai', 'LA.01.1904771', 'ASCII:Muang Sanamxai;ID:1904771', '18901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18901', '112', '20778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.01.1904771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20779', '1079', '1', 'Muang Phouvong', 'LA.01.1904772', 'ASCII:Muang Phouvong;ID:1904772', '18902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18902', '112', '20779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.01.1904772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20780', '1079', '1', 'Muang Sanxai', 'LA.01.1904773', 'ASCII:Muang Sanxai;ID:1904773', '18903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18903', '112', '20780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.01.1904773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20781', '1079', '1', 'Muang Xanasômboun', 'LA.02.1904774', 'ASCII:Muang Xanasomboun;ID:1904774', '18904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18904', '112', '20781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.02.1904774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20782', '1079', '1', 'Muang Kaluni', 'LA.26.1904775', 'ASCII:Muang Kaluni;ID:1904775', '18905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18905', '112', '20782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.26.1904775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20783', '1079', '1', 'Muang Thapangthong', 'LA.20.1904777', 'ASCII:Muang Thapangthong;ID:1904777', '18906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18906', '112', '20783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1904777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20784', '1079', '1', 'Muang Khanthabouli', 'LA.20.1904778', 'ASCII:Muang Khanthabouli;ID:1904778', '18907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18907', '112', '20784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1904778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20785', '1079', '1', 'Muang Xônbouli', 'LA.20.1904780', 'ASCII:Muang Xonbouli;ID:1904780', '18908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18908', '112', '20785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1904780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20786', '1079', '1', 'Muang Samouay', 'LA.19.1904781', 'ASCII:Muang Samouay;ID:1904781', '18909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18909', '112', '20786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.19.1904781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20787', '1079', '1', 'Muang Outhoumphon', 'LA.20.1904783', 'ASCII:Muang Outhoumphon;ID:1904783', '18910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18910', '112', '20787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1904783» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20788', '1079', '1', 'Muang Alsaphangthong', 'LA.20.1904784', 'ASCII:Muang Alsaphangthong;ID:1904784', '18911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18911', '112', '20788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1904784» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20789', '1079', '1', 'Muang Xaibouli', 'LA.20.1904785', 'ASCII:Muang Xaibouli;ID:1904785', '18912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18912', '112', '20789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1904785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20790', '1079', '1', 'Muang Atsaphan', 'LA.20.1904786', 'ASCII:Muang Atsaphan;ID:1904786', '18913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18913', '112', '20790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1904786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20791', '1079', '1', 'Muang Vilabouli', 'LA.20.1904787', 'ASCII:Muang Vilabouli;ID:1904787', '18914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18914', '112', '20791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.20.1904787» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20792', '1079', '1', 'Muang Nongbôk', 'LA.15.1904788', 'ASCII:Muang Nongbok;ID:1904788', '18915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18915', '112', '20792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.15.1904788» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20793', '1079', '1', 'Muang Xebangfai', 'LA.15.1904789', 'ASCII:Muang Xebangfai;ID:1904789', '18916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18916', '112', '20793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.15.1904789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20794', '1079', '1', 'Muang Xaibouathong', 'LA.15.1904790', 'ASCII:Muang Xaibouathong;ID:1904790', '18917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18917', '112', '20794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.15.1904790» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20795', '1079', '1', 'Muang Boualapha', 'LA.15.1904791', 'ASCII:Muang Boualapha;ID:1904791', '18918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18918', '112', '20795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.15.1904791» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20796', '1079', '1', 'Muang Gnômmalat', 'LA.15.1904792', 'ASCII:Muang Gnommalat;ID:1904792', '18919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18919', '112', '20796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.15.1904792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20797', '1079', '1', 'Muang Na Kay', 'LA.15.1904793', 'ASCII:Muang Na Kay;ID:1904793', '18920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18920', '112', '20797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.15.1904793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20798', '1079', '1', 'Muang Viangthong', 'LA.23.1904794', 'ASCII:Muang Viangthong;ID:1904794', '18921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18921', '112', '20798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.23.1904794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20799', '1079', '1', 'Muang Thaphabat', 'LA.23.1904795', 'ASCII:Muang Thaphabat;ID:1904795', '18922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18922', '112', '20799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.23.1904795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20800', '1079', '1', 'Muang Longxan', 'LA.25.1904796', 'ASCII:Muang Longxan;ID:1904796', '18923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18923', '112', '20800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.25.1904796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20801', '1079', '1', 'Muang Kèo-Oudôm', 'LA.24.1904797', 'ASCII:Muang Keo-Oudom;ID:1904797', '18924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18924', '112', '20801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20802', '1079', '1', 'Muang Hôm', 'LA.25.1904798', 'ASCII:Muang Hom;ID:1904798', '18925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18925', '112', '20802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.25.1904798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20803', '1079', '1', 'Muang Xaisômboun', 'LA.25.1904799', 'ASCII:Muang Xaisomboun;ID:1904799', '18926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18926', '112', '20803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.25.1904799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20804', '1079', '1', 'Muang Phoun', 'LA.25.1904800', 'ASCII:Muang Phoun;ID:1904800', '18927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18927', '112', '20804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.25.1904800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20805', '1079', '1', 'Muang Xanakham', 'LA.24.1904801', 'ASCII:Muang Xanakham;ID:1904801', '18928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18928', '112', '20805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20806', '1079', '1', 'Muang Fuang', 'LA.24.1904802', 'ASCII:Muang Fuang;ID:1904802', '18929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18929', '112', '20806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20807', '1079', '1', 'Muang Botèn', 'LA.13.1904803', 'ASCII:Muang Boten;ID:1904803', '18930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18930', '112', '20807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.13.1904803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20808', '1079', '1', 'Muang Kénthao', 'LA.13.1904804', 'ASCII:Muang Kenthao;ID:1904804', '18931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18931', '112', '20808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.13.1904804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20809', '1079', '1', 'Muang Phiang', 'LA.13.1904805', 'ASCII:Muang Phiang;ID:1904805', '18932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18932', '112', '20809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.13.1904805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20810', '1079', '1', 'Muang Khop', 'LA.13.1904806', 'ASCII:Muang Khop;ID:1904806', '18933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18933', '112', '20810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.13.1904806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20811', '1079', '1', 'Muang Chomphét', 'LA.17.1904807', 'ASCII:Muang Chomphet;ID:1904807', '18934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18934', '112', '20811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.17.1904807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20812', '1079', '1', 'Muang Phou Khoun', 'LA.17.1904808', 'ASCII:Muang Phou Khoun;ID:1904808', '18935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18935', '112', '20812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.17.1904808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20813', '1079', '1', 'Muang Phônxai', 'LA.17.1904809', 'ASCII:Muang Phonxai;ID:1904809', '18936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18936', '112', '20813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.17.1904809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20814', '1079', '1', 'Muang Pakxèng', 'LA.17.1904810', 'ASCII:Muang Pakxeng;ID:1904810', '18937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18937', '112', '20814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.17.1904810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20815', '1079', '1', 'Muang Viangkhan', 'LA.17.1904811', 'ASCII:Muang Viangkhan;ID:1904811', '18938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18938', '112', '20815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.17.1904811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20816', '1079', '1', 'Muang Nonghèt', 'LA.14.1904812', 'ASCII:Muang Nonghet;ID:1904812', '18939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18939', '112', '20816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.14.1904812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20817', '1079', '1', 'Muang Phaxai', 'LA.14.1904813', 'ASCII:Muang Phaxai;ID:1904813', '18940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18940', '112', '20817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.14.1904813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20818', '1079', '1', 'Muang Khoun', 'LA.14.1904814', 'ASCII:Muang Khoun;ID:1904814', '18941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18941', '112', '20818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.14.1904814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20819', '1079', '1', 'Muang Mok-Mai', 'LA.14.1904815', 'ASCII:Muang Mok-Mai;ID:1904815', '18942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18942', '112', '20819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.14.1904815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20820', '1079', '1', 'Muang Phou Kont', 'LA.14.1904816', 'ASCII:Muang Phou Kont;ID:1904816', '18943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18943', '112', '20820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.14.1904816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20821', '1079', '1', 'Muang Xam-Tai', 'LA.03.1904817', 'ASCII:Muang Xam-Tai;ID:1904817', '18944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18944', '112', '20821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.03.1904817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20822', '1079', '1', 'Muang Viangxai', 'LA.03.1904818', 'ASCII:Muang Viangxai;ID:1904818', '18945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18945', '112', '20822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.03.1904818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20823', '1079', '1', 'Muang Viangthong', 'LA.03.1904819', 'ASCII:Muang Viangthong;ID:1904819', '18946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18946', '112', '20823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.03.1904819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20824', '1079', '1', 'Muang Nga', 'LA.07.1904820', 'ASCII:Muang Nga;ID:1904820', '18947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18947', '112', '20824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.07.1904820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20825', '1079', '1', 'Muang Pha Oudôm', 'LA.22.1904821', 'ASCII:Muang Pha Oudom;ID:1904821', '18948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18948', '112', '20825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.22.1904821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20826', '1079', '1', 'Muang Tônpheung', 'LA.22.1904822', 'ASCII:Muang Tonpheung;ID:1904822', '18949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18949', '112', '20826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.22.1904822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20827', '1079', '1', 'Muang Meung', 'LA.22.1904823', 'ASCII:Muang Meung;ID:1904823', '18950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18950', '112', '20827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.22.1904823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20828', '1079', '1', 'Muang Nalè', 'LA.16.1904824', 'ASCII:Muang Nale;ID:1904824', '18951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18951', '112', '20828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.16.1904824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20829', '1079', '1', 'Muang Viangphoukha', 'LA.16.1904825', 'ASCII:Muang Viangphoukha;ID:1904825', '18952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18952', '112', '20829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.16.1904825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20830', '1079', '1', 'Muang Long', 'LA.16.1904826', 'ASCII:Muang Long;ID:1904826', '18953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18953', '112', '20830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.16.1904826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20831', '1079', '1', 'Muang Khoa', 'LA.18.1904827', 'ASCII:Muang Khoa;ID:1904827', '18954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18954', '112', '20831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.18.1904827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20832', '1079', '1', 'Muang Mai', 'LA.18.1904828', 'ASCII:Muang Mai;ID:1904828', '18955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18955', '112', '20832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.18.1904828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20833', '1079', '1', 'Muang Boun-Nua', 'LA.18.1904829', 'ASCII:Muang Boun-Nua;ID:1904829', '18956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18956', '112', '20833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.18.1904829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20834', '1079', '1', 'Muang Gnot-Ou', 'LA.18.1904830', 'ASCII:Muang Gnot-Ou;ID:1904830', '18957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18957', '112', '20834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.18.1904830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20835', '1079', '1', 'Muang Chanthabouli', 'LA.24.1904831', 'ASCII:Muang Chanthabouli;ID:1904831', '18958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18958', '112', '20835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904831» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20836', '1079', '1', 'Muang Sisattanak', 'LA.24.1904832', 'ASCII:Muang Sisattanak;ID:1904832', '18959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18959', '112', '20836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20837', '1079', '1', 'Muang Xaiséttha', 'LA.24.1904833', 'ASCII:Muang Xaisettha;ID:1904833', '18960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18960', '112', '20837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20838', '1079', '1', 'Muang Sikhôttabong', 'LA.24.1904834', 'ASCII:Muang Sikhottabong;ID:1904834', '18961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18961', '112', '20838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20839', '1079', '1', 'Muang Hatxayfong', 'LA.24.1904835', 'ASCII:Muang Hatxayfong;ID:1904835', '18962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18962', '112', '20839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20840', '1079', '1', 'Muang Xaithani', 'LA.24.1904836', 'ASCII:Muang Xaithani;ID:1904836', '18963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18963', '112', '20840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20841', '1079', '1', 'Muang Naxaythong', 'LA.24.1904837', 'ASCII:Muang Naxaythong;ID:1904837', '18964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18964', '112', '20841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904837» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20842', '1079', '1', 'Muang Sangthong', 'LA.24.1904838', 'ASCII:Muang Sangthong;ID:1904838', '18965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18965', '112', '20842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20843', '1079', '1', 'Muang Pakngum', 'LA.24.1904839', 'ASCII:Muang Pakngum;ID:1904839', '18966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18966', '112', '20843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LA.24.1904839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20844', '1079', '1', 'Qaḑā’ Zghartā', 'LB.09.265845', 'ASCII:Qada'' Zgharta;ID:265845', '18967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18967', '112', '20844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.09.265845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20845', '1079', '1', 'Qaḑā’ Zaḩlah', 'LB.08.266042', 'ASCII:Qada'' Zahlah;ID:266042', '18968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18968', '112', '20845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.08.266042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20846', '1079', '1', 'Qaḑā’ Ţarābulus', 'LB.09.266825', 'ASCII:Qada'' Tarabulus;ID:266825', '18969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18969', '112', '20846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.09.266825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20847', '1079', '1', 'Qaḑā’ Şūr', 'LB.06.267006', 'ASCII:Qada'' Sur;ID:267006', '18970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18970', '112', '20847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.06.267006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20848', '1079', '1', 'Qaḑā’ Rāshayyā', 'LB.08.268737', 'ASCII:Qada'' Rashayya;ID:268737', '18971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18971', '112', '20848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.08.268737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20849', '1079', '1', 'Mukhayyam an Nabaţīyah', 'LB.07.270013', 'ASCII:Mukhayyam an Nabatiyah;ID:270013', '18972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18972', '112', '20849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.07.270013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20850', '1079', '1', 'Qaḑā’ Marji`yūn', 'LB.07.271225', 'ASCII:Qada'' Marji`yun;ID:271225', '18973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18973', '112', '20850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.07.271225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20851', '1079', '1', 'Qaḑā'' Kisrwān', 'LB.05.272300', 'ASCII:Qada'' Kisrwan;ID:272300', '18974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18974', '112', '20851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.05.272300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20852', '1079', '1', 'Qadā'' Jubayl', 'LB.05.273201', 'ASCII:Qada'' Jubayl;ID:273201', '18975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18975', '112', '20852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.05.273201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20853', '1079', '1', 'Qadā’ Jazzīn', 'LB.06.273359', 'ASCII:Qada'' Jazzin;ID:273359', '18976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18976', '112', '20853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.06.273359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20854', '1079', '1', 'Qaḑā’ Ḩāşbayyā', 'LB.07.274311', 'ASCII:Qada'' Hasbayya;ID:274311', '18977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18977', '112', '20854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.07.274311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20855', '1079', '1', 'Qaḑā’ Bsharrī', 'LB.09.276358', 'ASCII:Qada'' Bsharri;ID:276358', '18978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18978', '112', '20855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.09.276358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20856', '1079', '1', 'Qaḑā’ Bint Jubayl', 'LB.07.276591', 'ASCII:Qada'' Bint Jubayl;ID:276591', '18979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18979', '112', '20856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.07.276591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20857', '1079', '1', 'Qaḑā’ Ba‘labakk', 'LB.11.277129', 'ASCII:Qada'' Ba`labakk;ID:277129', '18980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18980', '112', '20857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.11.277129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20858', '1079', '1', 'Qaḑā'' B`abdā', 'LB.05.277225', 'ASCII:Qada'' B`abda;ID:277225', '18981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18981', '112', '20858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.05.277225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20859', '1079', '1', 'Qaḑā'' ash Shūf', 'LB.05.278156', 'ASCII:Qada'' ash Shuf;ID:278156', '18982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18982', '112', '20859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.05.278156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20860', '1079', '1', 'Qaḑā'' an Nabaţīyah', 'LB.07.278915', 'ASCII:Qada'' an Nabatiyah;ID:278915', '18983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18983', '112', '20860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.07.278915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20861', '1079', '1', 'Qaḑā'' al Matn', 'LB.05.279440', 'ASCII:Qada'' al Matn;ID:279440', '18984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18984', '112', '20861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.05.279440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20862', '1079', '1', 'Qadā’ al Kūrah', 'LB.09.279676', 'ASCII:Qada'' al Kurah;ID:279676', '18985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18985', '112', '20862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.09.279676» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20863', '1079', '1', 'Qaḑā’ al Hirmil', 'LB.11.279999', 'ASCII:Qada'' al Hirmil;ID:279999', '18986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18986', '112', '20863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.11.279999» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20864', '1079', '1', 'Qaḑā’ al Biqā‘ al Gharbī', 'LB.08.280280', 'ASCII:Qada'' al Biqa` al Gharbi;ID:280280', '18987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18987', '112', '20864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.08.280280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20865', '1079', '1', 'Qaḑā’ al Batrūn', 'LB.09.280329', 'ASCII:Qada'' al Batrun;ID:280329', '18988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18988', '112', '20865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.09.280329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20866', '1079', '1', 'Qaḑā'' `Ālayh', 'LB.05.280424', 'ASCII:Qada'' `Alayh;ID:280424', '18989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18989', '112', '20866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.05.280424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20867', '1079', '1', 'Qaḑā’ ‘Akkār', 'LB.10.280572', 'ASCII:Qada'' `Akkar;ID:280572', '18990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18990', '112', '20867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LB.10.280572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20868', '1079', '1', 'Vavuniya District', 'LK.31.1225017', 'ASCII:Vavuniya District;ID:1225017', '18991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18991', '112', '20868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.31.1225017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20869', '1079', '1', 'Trincomalee District', 'LK.31.1226258', 'ASCII:Trincomalee District;ID:1226258', '18992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18992', '112', '20869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.31.1226258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20870', '1079', '1', 'Ratnapura District', 'LK.33.1228729', 'ASCII:Ratnapura District;ID:1228729', '18993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18993', '112', '20870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.33.1228729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20871', '1079', '1', 'Puttalam District', 'LK.32.1229292', 'ASCII:Puttalam District;ID:1229292', '18994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18994', '112', '20871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.32.1229292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20872', '1079', '1', 'Polonnaruwa District', 'LK.30.1229899', 'ASCII:Polonnaruwa District;ID:1229899', '18995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18995', '112', '20872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.30.1229899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20873', '1079', '1', 'Nuwara Eliya District', 'LK.29.1232781', 'ASCII:Nuwara Eliya District;ID:1232781', '18996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18996', '112', '20873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.29.1232781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20874', '1079', '1', 'Mullaittivu District', 'LK.31.1234392', 'ASCII:Mullaittivu District;ID:1234392', '18997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18997', '112', '20874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.31.1234392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20875', '1079', '1', 'Monaragala District', 'LK.35.1234818', 'ASCII:Monaragala District;ID:1234818', '18998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18998', '112', '20875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.35.1234818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20876', '1079', '1', 'Matara District', 'LK.34.1235845', 'ASCII:Matara District;ID:1235845', '18999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('18999', '112', '20876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.34.1235845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20877', '1079', '1', 'Matale District', 'LK.29.1235854', 'ASCII:Matale District;ID:1235854', '19000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19000', '112', '20877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.29.1235854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20878', '1079', '1', 'Mannar District', 'LK.31.1236148', 'ASCII:Mannar District;ID:1236148', '19001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19001', '112', '20878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.31.1236148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20879', '1079', '1', 'Kurunegala District', 'LK.32.1237978', 'ASCII:Kurunegala District;ID:1237978', '19002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19002', '112', '20879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.32.1237978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20880', '1079', '1', 'Kilinochchi District', 'LK.31.1240371', 'ASCII:Kilinochchi District;ID:1240371', '19003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19003', '112', '20880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.31.1240371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20881', '1079', '1', 'Kegalla District', 'LK.33.1240722', 'ASCII:Kegalla District;ID:1240722', '19004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19004', '112', '20881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.33.1240722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20882', '1079', '1', 'Kandy District', 'LK.29.1241621', 'ASCII:Kandy District;ID:1241621', '19005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19005', '112', '20882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.29.1241621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20883', '1079', '1', 'Kalutara District', 'LK.36.1241963', 'ASCII:Kalutara District;ID:1241963', '19006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19006', '112', '20883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.36.1241963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20884', '1079', '1', 'Jaffna District', 'LK.31.1242831', 'ASCII:Jaffna District;ID:1242831', '19007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19007', '112', '20884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.31.1242831» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20885', '1079', '1', 'Hambantota District', 'LK.34.1244925', 'ASCII:Hambantota District;ID:1244925', '19008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19008', '112', '20885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.34.1244925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20886', '1079', '1', 'Gampaha District', 'LK.36.1246005', 'ASCII:Gampaha District;ID:1246005', '19009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19009', '112', '20886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.36.1246005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20887', '1079', '1', 'Galle District', 'LK.34.1246292', 'ASCII:Galle District;ID:1246292', '19010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19010', '112', '20887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.34.1246292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20888', '1079', '1', 'Colombo District', 'LK.36.1248990', 'ASCII:Colombo District;ID:1248990', '19011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19011', '112', '20888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.36.1248990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20889', '1079', '1', 'Batticaloa District', 'LK.31.1250159', 'ASCII:Batticaloa District;ID:1250159', '19012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19012', '112', '20889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.31.1250159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20890', '1079', '1', 'Badulla District', 'LK.35.1250614', 'ASCII:Badulla District;ID:1250614', '19013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19013', '112', '20890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.35.1250614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20891', '1079', '1', 'Anuradhapura District', 'LK.30.1251080', 'ASCII:Anuradhapura District;ID:1251080', '19014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19014', '112', '20891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.30.1251080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20892', '1079', '1', 'Ampara District', 'LK.31.1251460', 'ASCII:Ampara District;ID:1251460', '19015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19015', '112', '20892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LK.31.1251460» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20893', '1079', '1', 'Zota', 'LR.01.2272532', 'ASCII:Zota;ID:2272532', '19016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19016', '112', '20893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.01.2272532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20894', '1079', '1', 'Zo-Ge', 'LR.09.2272565', 'ASCII:Zo-Ge;ID:2272565', '19017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19017', '112', '20894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.09.2272565» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20895', '1079', '1', 'Yederabo', 'LR.13.2272794', 'ASCII:Yederabo;ID:2272794', '19018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19018', '112', '20895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2272794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20896', '1079', '1', 'Yawein-Mesono', 'LR.09.2272804', 'ASCII:Yawein-Mesono;ID:2272804', '19019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19019', '112', '20896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.09.2272804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20897', '1079', '1', 'Wedjah-Cabade', 'LR.10.2273181', 'ASCII:Wedjah-Cabade;ID:2273181', '19020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19020', '112', '20897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2273181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20898', '1079', '1', 'Webo', 'LR.19.2273186', 'ASCII:Webo;ID:2273186', '19021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19021', '112', '20898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2273186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20899', '1079', '1', 'Webado', 'LR.16.2273190', 'ASCII:Webado;ID:2273190', '19022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19022', '112', '20899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.16.2273190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20900', '1079', '1', 'Waiglomai-Woniglomai', 'LR.20.2273272', 'ASCII:Waiglomai-Woniglomai;ID:2273272', '19023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19023', '112', '20900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2273272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20901', '1079', '1', 'Tuobo', 'LR.13.2273404', 'ASCII:Tuobo;ID:2273404', '19024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19024', '112', '20901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2273404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20902', '1079', '1', 'Tuobo', 'LR.19.2273443', 'ASCII:Tuobo;ID:2273443', '19025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19025', '112', '20902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2273443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20903', '1079', '1', 'Toto', 'LR.10.2273473', 'ASCII:Toto;ID:2273473', '19026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19026', '112', '20903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2273473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20904', '1079', '1', 'Topo', 'LR.10.2273482', 'ASCII:Topo;ID:2273482', '19027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19027', '112', '20904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2273482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20905', '1079', '1', 'Tombe', 'LR.12.2273511', 'ASCII:Tombe;ID:2273511', '19028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19028', '112', '20905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.12.2273511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20906', '1079', '1', 'Todi', 'LR.08.2273549', 'ASCII:Todi;ID:2273549', '19029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19029', '112', '20906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.08.2273549» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20907', '1079', '1', 'Tienpo', 'LR.19.2273599', 'ASCII:Tienpo;ID:2273599', '19030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19030', '112', '20907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2273599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20908', '1079', '1', 'Three B', 'LR.11.2273621', 'ASCII:Three B;ID:2273621', '19031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19031', '112', '20908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.11.2273621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20909', '1079', '1', 'Three A', 'LR.11.2273622', 'ASCII:Three A;ID:2273622', '19032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19032', '112', '20909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.11.2273622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20910', '1079', '1', 'Tewo', 'LR.12.2273632', 'ASCII:Tewo;ID:2273632', '19033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19033', '112', '20910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.12.2273632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20911', '1079', '1', 'Tenor', 'LR.11.2273635', 'ASCII:Tenor;ID:2273635', '19034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19034', '112', '20911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.11.2273635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20912', '1079', '1', 'Tchien', 'LR.19.2273657', 'ASCII:Tchien;ID:2273657', '19035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19035', '112', '20912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2273657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20913', '1079', '1', 'Tasu', 'LR.10.2273679', 'ASCII:Tasu;ID:2273679', '19036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19036', '112', '20913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2273679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20914', '1079', '1', 'Tarjuazon', 'LR.10.2273682', 'ASCII:Tarjuazon;ID:2273682', '19037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19037', '112', '20914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2273682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20915', '1079', '1', 'Sodoke', 'LR.13.2273858', 'ASCII:Sodoke;ID:2273858', '19038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19038', '112', '20915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2273858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20916', '1079', '1', 'Seedor', 'LR.10.2274043', 'ASCII:Seedor;ID:2274043', '19039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19039', '112', '20916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2274043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20917', '1079', '1', 'Sasstown', 'LR.16.2274101', 'ASCII:Sasstown;ID:2274101', '19040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19040', '112', '20917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.16.2274101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20918', '1079', '1', 'Sanoyie', 'LR.01.2274124', 'ASCII:Sanoyie;ID:2274124', '19041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19041', '112', '20918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.01.2274124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20919', '1079', '1', 'Sanokole-Ma', 'LR.09.2274125', 'ASCII:Sanokole-Ma;ID:2274125', '19042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19042', '112', '20919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.09.2274125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20920', '1079', '1', 'Sagleipie-Ma', 'LR.09.2274221', 'ASCII:Sagleipie-Ma;ID:2274221', '19043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19043', '112', '20920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.09.2274221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20921', '1079', '1', 'Sabo', 'LR.19.2274235', 'ASCII:Sabo;ID:2274235', '19044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19044', '112', '20921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2274235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20922', '1079', '1', 'Rock Town', 'LR.13.2274269', 'ASCII:Rock Town;ID:2274269', '19045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19045', '112', '20922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2274269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20923', '1079', '1', 'Rock Cess', 'LR.18.2274273', 'ASCII:Rock Cess;ID:2274273', '19046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19046', '112', '20923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.18.2274273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20924', '1079', '1', 'Putu', 'LR.19.2274312', 'ASCII:Putu;ID:2274312', '19047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19047', '112', '20924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2274312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20925', '1079', '1', 'Po River', 'LR.13.2274336', 'ASCII:Po River;ID:2274336', '19048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19048', '112', '20925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2274336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20926', '1079', '1', 'Pokpa', 'LR.12.2274351', 'ASCII:Pokpa;ID:2274351', '19049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19049', '112', '20926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.12.2274351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20927', '1079', '1', 'Plibo', 'LR.13.2274373', 'ASCII:Plibo;ID:2274373', '19050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19050', '112', '20927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2274373» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20928', '1079', '1', 'Picnicess', 'LR.13.2274403', 'ASCII:Picnicess;ID:2274403', '19051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19051', '112', '20928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2274403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20929', '1079', '1', 'Pate', 'LR.13.2274476', 'ASCII:Pate;ID:2274476', '19052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19052', '112', '20929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2274476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20930', '1079', '1', 'Panta', 'LR.01.2274491', 'ASCII:Panta;ID:2274491', '19053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19053', '112', '20930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.01.2274491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20931', '1079', '1', 'Palipo', 'LR.19.2274502', 'ASCII:Palipo;ID:2274502', '19054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19054', '112', '20931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2274502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20932', '1079', '1', 'Nyanbo', 'LR.13.2274569', 'ASCII:Nyanbo;ID:2274569', '19055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19055', '112', '20932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2274569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20933', '1079', '1', 'Nyafokole', 'LR.01.2274578', 'ASCII:Nyafokole;ID:2274578', '19056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19056', '112', '20933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.01.2274578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20934', '1079', '1', 'Nuohn Point', 'LR.10.2274591', 'ASCII:Nuohn Point;ID:2274591', '19057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19057', '112', '20934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2274591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20935', '1079', '1', 'Numo', 'LR.10.2274596', 'ASCII:Numo;ID:2274596', '19058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19058', '112', '20935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2274596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20936', '1079', '1', 'Niabo', 'LR.19.2274719', 'ASCII:Niabo;ID:2274719', '19059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19059', '112', '20936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2274719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20937', '1079', '1', 'Nemea', 'LR.13.2274778', 'ASCII:Nemea;ID:2274778', '19060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19060', '112', '20937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2274778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20938', '1079', '1', 'Nana Kru', 'LR.10.2274818', 'ASCII:Nana Kru;ID:2274818', '19061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19061', '112', '20938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2274818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20939', '1079', '1', 'Nake', 'LR.10.2274827', 'ASCII:Nake;ID:2274827', '19062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19062', '112', '20939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2274827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20940', '1079', '1', 'Mecca', 'LR.15.2275016', 'ASCII:Mecca;ID:2275016', '19063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19063', '112', '20940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.15.2275016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20941', '1079', '1', 'Matro', 'LR.10.2275067', 'ASCII:Matro;ID:2275067', '19064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19064', '112', '20941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2275067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20942', '1079', '1', 'Mamba', 'LR.08.2275179', 'ASCII:Mamba;ID:2275179', '19065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19065', '112', '20942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.08.2275179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20943', '1079', '1', 'Little Wrebo', 'LR.13.2275351', 'ASCII:Little Wrebo;ID:2275351', '19066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19066', '112', '20943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2275351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20944', '1079', '1', 'Kulu', 'LR.10.2275592', 'ASCII:Kulu;ID:2275592', '19067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19067', '112', '20944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2275592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20945', '1079', '1', 'Keaple', 'LR.09.2275644', 'ASCII:Keaple;ID:2275644', '19068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19068', '112', '20945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.09.2275644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20946', '1079', '1', 'Konobo', 'LR.19.2275728', 'ASCII:Konobo;ID:2275728', '19069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19069', '112', '20946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2275728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20947', '1079', '1', 'Kone', 'LR.12.2275757', 'ASCII:Kone;ID:2275757', '19070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19070', '112', '20947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.12.2275757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20948', '1079', '1', 'Komgba', 'LR.20.2275770', 'ASCII:Komgba;ID:2275770', '19071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19071', '112', '20948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2275770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20949', '1079', '1', 'Kokoya', 'LR.01.2275814', 'ASCII:Kokoya;ID:2275814', '19072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19072', '112', '20949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.01.2275814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20950', '1079', '1', 'Kitabo', 'LR.19.2275896', 'ASCII:Kitabo;ID:2275896', '19073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19073', '112', '20950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2275896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20951', '1079', '1', 'Kisi', 'LR.20.2275898', 'ASCII:Kisi;ID:2275898', '19074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19074', '112', '20951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2275898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20952', '1079', '1', 'Kambo Hills', 'LR.20.2276054', 'ASCII:Kambo Hills;ID:2276054', '19075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19075', '112', '20952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2276054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20953', '1079', '1', 'Kakata', 'LR.08.2276087', 'ASCII:Kakata;ID:2276087', '19076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19076', '112', '20953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.08.2276087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20954', '1079', '1', 'Kabor', 'LR.10.2276117', 'ASCII:Kabor;ID:2276117', '19077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19077', '112', '20954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2276117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20955', '1079', '1', 'Kaba', 'LR.08.2276128', 'ASCII:Kaba;ID:2276128', '19078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19078', '112', '20955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.08.2276128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20956', '1079', '1', 'Sikohn', 'LR.10.2276156', 'ASCII:Sikohn;ID:2276156', '19079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19079', '112', '20956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2276156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20957', '1079', '1', 'Jroh', 'LR.10.2276161', 'ASCII:Jroh;ID:2276161', '19080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19080', '112', '20957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2276161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20958', '1079', '1', 'Jokole', 'LR.01.2276212', 'ASCII:Jokole;ID:2276212', '19081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19081', '112', '20958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.01.2276212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20959', '1079', '1', 'Jeetrah', 'LR.10.2276354', 'ASCII:Jeetrah;ID:2276354', '19082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19082', '112', '20959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2276354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20960', '1079', '1', 'Jedepo', 'LR.10.2276356', 'ASCII:Jedepo;ID:2276356', '19083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19083', '112', '20960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2276356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20961', '1079', '1', 'Jayah', 'LR.11.2276367', 'ASCII:Jayah;ID:2276367', '19084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19084', '112', '20961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.11.2276367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20962', '1079', '1', 'Harper', 'LR.13.2276493', 'ASCII:Harper;ID:2276493', '19085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19085', '112', '20962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2276493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20963', '1079', '1', 'Guma-Mendi', 'LR.20.2276555', 'ASCII:Guma-Mendi;ID:2276555', '19086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19086', '112', '20963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2276555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20964', '1079', '1', 'Grawa', 'LR.13.2276614', 'ASCII:Grawa;ID:2276614', '19087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19087', '112', '20964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2276614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20965', '1079', '1', 'Grand Cess', 'LR.13.2276626', 'ASCII:Grand Cess;ID:2276626', '19088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19088', '112', '20965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2276626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20966', '1079', '1', 'Gota Kone', 'LR.04.2276661', 'ASCII:Gota Kone;ID:2276661', '19089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19089', '112', '20966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.04.2276661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20967', '1079', '1', 'Gola', 'LR.15.2276737', 'ASCII:Gola;ID:2276737', '19090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19090', '112', '20967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.15.2276737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20968', '1079', '1', 'Goije', 'LR.20.2276743', 'ASCII:Goije;ID:2276743', '19091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19091', '112', '20968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2276743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20969', '1079', '1', 'Glio-Twabo', 'LR.19.2276801', 'ASCII:Glio-Twabo;ID:2276801', '19092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19092', '112', '20969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2276801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20970', '1079', '1', 'Glebo', 'LR.13.2276816', 'ASCII:Glebo;ID:2276816', '19093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19093', '112', '20970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2276816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20971', '1079', '1', 'Glarkon', 'LR.11.2276820', 'ASCII:Glarkon;ID:2276820', '19094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19094', '112', '20971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.11.2276820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20972', '1079', '1', 'Gizima-Ziema', 'LR.20.2276828', 'ASCII:Gizima-Ziema;ID:2276828', '19095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19095', '112', '20972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2276828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20973', '1079', '1', 'Gibi', 'LR.01.2276853', 'ASCII:Gibi;ID:2276853', '19096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19096', '112', '20973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.01.2276853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20974', '1079', '1', 'Gedetarbo', 'LR.13.2276908', 'ASCII:Gedetarbo;ID:2276908', '19097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19097', '112', '20974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2276908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20975', '1079', '1', 'Gedabo', 'LR.13.2276909', 'ASCII:Gedabo;ID:2276909', '19098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19098', '112', '20975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2276909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20976', '1079', '1', 'Glaro', 'LR.19.2276934', 'ASCII:Glaro;ID:2276934', '19099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19099', '112', '20976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2276934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20977', '1079', '1', 'Gbokole', 'LR.09.2276973', 'ASCII:Gbokole;ID:2276973', '19100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19100', '112', '20977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.09.2276973» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20978', '1079', '1', 'Gbobo', 'LR.19.2276983', 'ASCII:Gbobo;ID:2276983', '19101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19101', '112', '20978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2276983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20979', '1079', '1', 'Gbi-Doru', 'LR.09.2277003', 'ASCII:Gbi-Doru;ID:2277003', '19102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19102', '112', '20979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.09.2277003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20980', '1079', '1', 'Gbeta Klepo', 'LR.13.2277011', 'ASCII:Gbeta Klepo;ID:2277011', '19103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19103', '112', '20980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2277011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20981', '1079', '1', 'Gbele-Ge', 'LR.09.2277028', 'ASCII:Gbele-Ge;ID:2277028', '19104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19104', '112', '20981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.09.2277028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20982', '1079', '1', 'Gbelakpo', 'LR.13.2277030', 'ASCII:Gbelakpo;ID:2277030', '19105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19105', '112', '20982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2277030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20983', '1079', '1', 'Gbeapo', 'LR.19.2277041', 'ASCII:Gbeapo;ID:2277041', '19106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19106', '112', '20983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2277041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20984', '1079', '1', 'Gbazohn', 'LR.19.2277043', 'ASCII:Gbazohn;ID:2277043', '19107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19107', '112', '20984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2277043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20985', '1079', '1', 'Gbarlobo', 'LR.13.2277061', 'ASCII:Gbarlobo;ID:2277061', '19108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19108', '112', '20985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2277061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20986', '1079', '1', 'Gbandi', 'LR.20.2277082', 'ASCII:Gbandi;ID:2277082', '19109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19109', '112', '20986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2277082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20987', '1079', '1', 'Gbalein Faala', 'LR.20.2277102', 'ASCII:Gbalein Faala;ID:2277102', '19110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19110', '112', '20987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2277102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20988', '1079', '1', 'Gawula', 'LR.12.2277160', 'ASCII:Gawula;ID:2277160', '19111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19111', '112', '20988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.12.2277160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20989', '1079', '1', 'Garawe', 'LR.13.2277191', 'ASCII:Garawe;ID:2277191', '19112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19112', '112', '20989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2277191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20990', '1079', '1', 'Fuama', 'LR.01.2277288', 'ASCII:Fuama;ID:2277288', '19113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19113', '112', '20990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.01.2277288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20991', '1079', '1', 'Trade Town', 'LR.11.2277306', 'ASCII:Trade Town;ID:2277306', '19114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19114', '112', '20991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.11.2277306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20992', '1079', '1', 'Flenipo', 'LR.13.2277359', 'ASCII:Flenipo;ID:2277359', '19115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19115', '112', '20992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2277359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20993', '1079', '1', 'Mowe', 'LR.18.2277365', 'ASCII:Mowe;ID:2277365', '19116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19116', '112', '20993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.18.2277365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20994', '1079', '1', 'Five A', 'LR.11.2277366', 'ASCII:Five A;ID:2277366', '19117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19117', '112', '20994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.11.2277366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20995', '1079', '1', 'Fish Town', 'LR.13.2277375', 'ASCII:Fish Town;ID:2277375', '19118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19118', '112', '20995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2277375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20996', '1079', '1', 'Firestone', 'LR.13.2277383', 'ASCII:Firestone;ID:2277383', '19119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19119', '112', '20996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2277383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20997', '1079', '1', 'Dorobo', 'LR.13.2277593', 'ASCII:Dorobo;ID:2277593', '19120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19120', '112', '20997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2277593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20998', '1079', '1', 'Ding', 'LR.08.2277769', 'ASCII:Ding;ID:2277769', '19121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19121', '112', '20998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.08.2277769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('20999', '1079', '1', 'Dei', 'LR.08.2277849', 'ASCII:Dei;ID:2277849', '19122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19122', '112', '20999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.08.2277849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21000', '1079', '1', 'Dedabo', 'LR.13.2277859', 'ASCII:Dedabo;ID:2277859', '19123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19123', '112', '21000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2277859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21001', '1079', '1', 'Chelepo', 'LR.19.2278019', 'ASCII:Chelepo;ID:2278019', '19124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19124', '112', '21001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2278019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21002', '1079', '1', 'Cavalla', 'LR.13.2278062', 'ASCII:Cavalla;ID:2278062', '19125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19125', '112', '21002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2278062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21003', '1079', '1', 'Careysburg', 'LR.08.2278073', 'ASCII:Careysburg;ID:2278073', '19126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19126', '112', '21003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.08.2278073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21004', '1079', '1', 'Campwood', 'LR.11.2278080', 'ASCII:Campwood;ID:2278080', '19127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19127', '112', '21004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.11.2278080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21005', '1079', '1', 'Buto', 'LR.10.2278113', 'ASCII:Buto;ID:2278113', '19128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19128', '112', '21005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2278113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21006', '1079', '1', 'Bua', 'LR.13.2278169', 'ASCII:Bua;ID:2278169', '19129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19129', '112', '21006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2278169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21007', '1079', '1', 'Bopolu', 'LR.20.2278250', 'ASCII:Bopolu;ID:2278250', '19130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19130', '112', '21007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2278250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21008', '1079', '1', 'Bonde-Wubomai', 'LR.20.2278307', 'ASCII:Bonde-Wubomai;ID:2278307', '19131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19131', '112', '21008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2278307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21009', '1079', '1', 'Bolobo', 'LR.13.2278356', 'ASCII:Bolobo;ID:2278356', '19132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19132', '112', '21009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2278356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21010', '1079', '1', 'Bolo', 'LR.10.2278361', 'ASCII:Bolo;ID:2278361', '19133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19133', '112', '21010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.10.2278361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21011', '1079', '1', 'Bokomu', 'LR.20.2278379', 'ASCII:Bokomu;ID:2278379', '19134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19134', '112', '21011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2278379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21012', '1079', '1', 'Biai', 'LR.19.2278611', 'ASCII:Biai;ID:2278611', '19135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19135', '112', '21012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.19.2278611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21013', '1079', '1', 'Belle', 'LR.20.2278733', 'ASCII:Belle;ID:2278733', '19136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19136', '112', '21013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2278733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21014', '1079', '1', 'Barobo', 'LR.13.2278880', 'ASCII:Barobo;ID:2278880', '19137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19137', '112', '21014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2278880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21015', '1079', '1', 'Barclayville', 'LR.13.2278890', 'ASCII:Barclayville;ID:2278890', '19138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19138', '112', '21015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.13.2278890» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21016', '1079', '1', 'Do', 'LR.09.2279133', 'ASCII:Do;ID:2279133', '19139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19139', '112', '21016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.09.2279133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21017', '1079', '1', 'Guma', 'LR.20.2569974', 'ASCII:Guma;ID:2569974', '19140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19140', '112', '21017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LR.20.2569974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21018', '1079', '1', 'Zarasų Rajonas', 'LT.64.592889', 'ASCII:Zarasu Rajonas;ID:592889', '19141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19141', '112', '21018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.592889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21019', '1079', '1', 'Vilnius', 'LT.65.593118', 'ASCII:Vilnius;ID:593118', '19142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19142', '112', '21019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.593118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21020', '1079', '1', 'Vilniaus Rajonas', 'LT.65.593120', 'ASCII:Vilniaus Rajonas;ID:593120', '19143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19143', '112', '21020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.593120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21021', '1079', '1', 'Vilkaviškio Rajonas', 'LT.59.593154', 'ASCII:Vilkaviskio Rajonas;ID:593154', '19144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19144', '112', '21021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.59.593154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21022', '1079', '1', 'Varėnos Rajonas', 'LT.56.593403', 'ASCII:Varenos Rajonas;ID:593403', '19145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19145', '112', '21022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.56.593403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21023', '1079', '1', 'Utenos Rajonas', 'LT.64.593668', 'ASCII:Utenos Rajonas;ID:593668', '19146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19146', '112', '21023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.593668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21024', '1079', '1', 'Ukmergės Rajonas', 'LT.65.593732', 'ASCII:Ukmerges Rajonas;ID:593732', '19147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19147', '112', '21024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.593732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21025', '1079', '1', 'Trakų Rajonas', 'LT.65.593850', 'ASCII:Traku Rajonas;ID:593850', '19148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19148', '112', '21025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.593850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21026', '1079', '1', 'Telšių Rajonas', 'LT.63.593925', 'ASCII:Telsiu Rajonas;ID:593925', '19149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19149', '112', '21026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.63.593925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21027', '1079', '1', 'Tauragės Rajonas', 'LT.62.593957', 'ASCII:Taurages Rajonas;ID:593957', '19150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19150', '112', '21027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.62.593957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21028', '1079', '1', 'Švenčionių Rajonas', 'LT.65.594065', 'ASCII:Svencioniu Rajonas;ID:594065', '19151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19151', '112', '21028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.594065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21029', '1079', '1', 'Skuodo Rajonas', 'LT.58.594486', 'ASCII:Skuodo Rajonas;ID:594486', '19152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19152', '112', '21029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.594486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21030', '1079', '1', 'Širvintų Rajonas', 'LT.65.594606', 'ASCII:Sirvintu Rajonas;ID:594606', '19153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19153', '112', '21030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.594606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21031', '1079', '1', 'Šilutės Rajonas', 'LT.58.594654', 'ASCII:Silutes Rajonas;ID:594654', '19154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19154', '112', '21031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.594654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21032', '1079', '1', 'Šilalės Rajonas', 'LT.62.594692', 'ASCII:Silales Rajonas;ID:594692', '19155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19155', '112', '21032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.62.594692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21033', '1079', '1', 'Šiaulių Rajonas', 'LT.61.594736', 'ASCII:Siauliu Rajonas;ID:594736', '19156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19156', '112', '21033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.594736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21034', '1079', '1', 'Šiauliai', 'LT.61.594743', 'ASCII:Siauliai;ID:594743', '19157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19157', '112', '21034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.594743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21035', '1079', '1', 'Šalčininkų Rajonas', 'LT.65.595014', 'ASCII:Salcininku Rajonas;ID:595014', '19158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19158', '112', '21035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.595014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21036', '1079', '1', 'Šakių Rajonas', 'LT.59.595037', 'ASCII:Sakiu Rajonas;ID:595037', '19159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19159', '112', '21036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.59.595037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21037', '1079', '1', 'Rokiškio Rajonas', 'LT.60.595215', 'ASCII:Rokiskio Rajonas;ID:595215', '19160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19160', '112', '21037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.60.595215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21038', '1079', '1', 'Raseinių Rajonas', 'LT.57.595376', 'ASCII:Raseiniu Rajonas;ID:595376', '19161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19161', '112', '21038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.595376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21039', '1079', '1', 'Radviliškio Rajonas', 'LT.61.595451', 'ASCII:Radviliskio Rajonas;ID:595451', '19162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19162', '112', '21039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.595451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21040', '1079', '1', 'Prienų Rajonas', 'LT.57.595590', 'ASCII:Prienu Rajonas;ID:595590', '19163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19163', '112', '21040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.595590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21041', '1079', '1', 'Plungės Rajonas', 'LT.63.595688', 'ASCII:Plunges Rajonas;ID:595688', '19164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19164', '112', '21041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.63.595688» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21042', '1079', '1', 'Pasvalio Rajonas', 'LT.60.595998', 'ASCII:Pasvalio Rajonas;ID:595998', '19165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19165', '112', '21042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.60.595998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21043', '1079', '1', 'Panevėžys', 'LT.60.596130', 'ASCII:Panevezys;ID:596130', '19166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19166', '112', '21043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.60.596130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21044', '1079', '1', 'Panevėžio Rajonas', 'LT.60.596132', 'ASCII:Panevezio Rajonas;ID:596132', '19167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19167', '112', '21044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.60.596132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21045', '1079', '1', 'Palanga', 'LT.58.596240', 'ASCII:Palanga;ID:596240', '19168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19168', '112', '21045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.596240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21046', '1079', '1', 'Pakruojo Rajonas', 'LT.61.596259', 'ASCII:Pakruojo Rajonas;ID:596259', '19169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19169', '112', '21046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.596259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21047', '1079', '1', 'Neringa', 'LT.58.596644', 'ASCII:Neringa;ID:596644', '19170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19170', '112', '21047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.596644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21048', '1079', '1', 'Molėtų Rajonas', 'LT.64.596866', 'ASCII:Moletu Rajonas;ID:596866', '19171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19171', '112', '21048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.596866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21049', '1079', '1', 'Mažeikių Rajonas', 'LT.63.597186', 'ASCII:Mazeikiu Rajonas;ID:597186', '19172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19172', '112', '21049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.63.597186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21050', '1079', '1', 'Marijampolės Rajonas', 'LT.59.597229', 'ASCII:Marijampoles Rajonas;ID:597229', '19173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19173', '112', '21050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.59.597229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21051', '1079', '1', 'Marijampolė', 'LT.59.597233', 'ASCII:Marijampole;ID:597233', '19174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19174', '112', '21051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.59.597233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21052', '1079', '1', 'Lazdijų Rajonas', 'LT.56.597595', 'ASCII:Lazdiju Rajonas;ID:597595', '19175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19175', '112', '21052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.56.597595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21053', '1079', '1', 'Kupiškio Rajonas', 'LT.60.597807', 'ASCII:Kupiskio Rajonas;ID:597807', '19176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19176', '112', '21053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.60.597807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21054', '1079', '1', 'Kretingos Rajonas', 'LT.58.597985', 'ASCII:Kretingos Rajonas;ID:597985', '19177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19177', '112', '21054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.597985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21055', '1079', '1', 'Klaipėdos Rajonas', 'LT.58.598095', 'ASCII:Klaipedos Rajonas;ID:598095', '19178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19178', '112', '21055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.598095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21056', '1079', '1', 'Klaipėda', 'LT.58.598099', 'ASCII:Klaipeda;ID:598099', '19179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19179', '112', '21056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.598099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21057', '1079', '1', 'Kelmės Rajonas', 'LT.61.598256', 'ASCII:Kelmes Rajonas;ID:598256', '19180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19180', '112', '21057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.598256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21058', '1079', '1', 'Kėdainių Rajonas', 'LT.57.598271', 'ASCII:Kedainiu Rajonas;ID:598271', '19181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19181', '112', '21058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.598271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21059', '1079', '1', 'Kauno Rajonas', 'LT.57.598313', 'ASCII:Kauno Rajonas;ID:598313', '19182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19182', '112', '21059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.598313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21060', '1079', '1', 'Kaunas', 'LT.57.598318', 'ASCII:Kaunas;ID:598318', '19183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19183', '112', '21060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.598318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21061', '1079', '1', 'Kaišiadorių Rajonas', 'LT.57.598568', 'ASCII:Kaisiadoriu Rajonas;ID:598568', '19184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19184', '112', '21061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.598568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21062', '1079', '1', 'Jurbarko Rajonas', 'LT.62.598653', 'ASCII:Jurbarko Rajonas;ID:598653', '19185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19185', '112', '21062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.62.598653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21063', '1079', '1', 'Joniškio Rajonas', 'LT.61.598798', 'ASCII:Joniskio Rajonas;ID:598798', '19186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19186', '112', '21063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.598798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21064', '1079', '1', 'Jonavos Rajonas', 'LT.57.598814', 'ASCII:Jonavos Rajonas;ID:598814', '19187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19187', '112', '21064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.598814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21065', '1079', '1', 'Ignalinos Rajonas', 'LT.64.598997', 'ASCII:Ignalinos Rajonas;ID:598997', '19188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19188', '112', '21065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.598997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21066', '1079', '1', 'Druskininkai', 'LT.56.599759', 'ASCII:Druskininkai;ID:599759', '19189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19189', '112', '21066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.56.599759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21067', '1079', '1', 'Biržų Rajonas', 'LT.60.600428', 'ASCII:Birzu Rajonas;ID:600428', '19190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19190', '112', '21067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.60.600428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21068', '1079', '1', 'Birštonas', 'LT.57.600444', 'ASCII:Birstonas;ID:600444', '19191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19191', '112', '21068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.600444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21069', '1079', '1', 'Anykščių Rajonas', 'LT.64.600992', 'ASCII:Anyksciu Rajonas;ID:600992', '19192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19192', '112', '21069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.600992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21070', '1079', '1', 'Alytus', 'LT.56.601086', 'ASCII:Alytus;ID:601086', '19193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19193', '112', '21070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.56.601086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21071', '1079', '1', 'Alytaus Rajonas', 'LT.56.601087', 'ASCII:Alytaus Rajonas;ID:601087', '19194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19194', '112', '21071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.56.601087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21072', '1079', '1', 'Akmenės Rajonas', 'LT.61.601179', 'ASCII:Akmenes Rajonas;ID:601179', '19195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19195', '112', '21072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.601179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21073', '1079', '1', 'Lazdijai', 'LT.56.864486', 'ASCII:Lazdijai;ID:864486', '19196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19196', '112', '21073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.56.864486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21074', '1079', '1', 'Varėna', 'LT.56.864487', 'ASCII:Varena;ID:864487', '19197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19197', '112', '21074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.56.864487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21075', '1079', '1', 'Jonava', 'LT.57.864488', 'ASCII:Jonava;ID:864488', '19198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19198', '112', '21075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.864488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21076', '1079', '1', 'Kaišiadorys', 'LT.57.864489', 'ASCII:Kaisiadorys;ID:864489', '19199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19199', '112', '21076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.864489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21077', '1079', '1', 'Kėdainiai', 'LT.57.864490', 'ASCII:Kedainiai;ID:864490', '19200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19200', '112', '21077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.864490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21078', '1079', '1', 'Prienai', 'LT.57.864491', 'ASCII:Prienai;ID:864491', '19201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19201', '112', '21078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.864491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21079', '1079', '1', 'Raseiniai', 'LT.57.864492', 'ASCII:Raseiniai;ID:864492', '19202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19202', '112', '21079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.57.864492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21080', '1079', '1', 'Gargždai', 'LT.58.864493', 'ASCII:Gargzdai;ID:864493', '19203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19203', '112', '21080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.864493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21081', '1079', '1', 'Kretinga', 'LT.58.864494', 'ASCII:Kretinga;ID:864494', '19204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19204', '112', '21081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.864494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21082', '1079', '1', 'Skuodas', 'LT.58.864495', 'ASCII:Skuodas;ID:864495', '19205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19205', '112', '21082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.864495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21083', '1079', '1', 'Šilutė', 'LT.58.864496', 'ASCII:Silute;ID:864496', '19206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19206', '112', '21083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.58.864496» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21084', '1079', '1', 'Šakiai', 'LT.59.864497', 'ASCII:Sakiai;ID:864497', '19207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19207', '112', '21084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.59.864497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21085', '1079', '1', 'Vilkaviškis', 'LT.59.864498', 'ASCII:Vilkaviskis;ID:864498', '19208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19208', '112', '21085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.59.864498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21086', '1079', '1', 'Biržai', 'LT.60.864499', 'ASCII:Birzai;ID:864499', '19209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19209', '112', '21086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.60.864499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21087', '1079', '1', 'Kupiškis', 'LT.60.864500', 'ASCII:Kupiskis;ID:864500', '19210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19210', '112', '21087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.60.864500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21088', '1079', '1', 'Pasvalys', 'LT.60.864501', 'ASCII:Pasvalys;ID:864501', '19211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19211', '112', '21088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.60.864501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21089', '1079', '1', 'Rokiškis', 'LT.60.864502', 'ASCII:Rokiskis;ID:864502', '19212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19212', '112', '21089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.60.864502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21090', '1079', '1', 'Naujoji Akmenė', 'LT.61.864503', 'ASCII:Naujoji Akmene;ID:864503', '19213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19213', '112', '21090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.864503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21091', '1079', '1', 'Joniškis', 'LT.61.864504', 'ASCII:Joniskis;ID:864504', '19214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19214', '112', '21091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.864504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21092', '1079', '1', 'Kelmė', 'LT.61.864505', 'ASCII:Kelme;ID:864505', '19215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19215', '112', '21092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.864505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21093', '1079', '1', 'Pakruojis', 'LT.61.864506', 'ASCII:Pakruojis;ID:864506', '19216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19216', '112', '21093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.864506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21094', '1079', '1', 'Radviliškis', 'LT.61.864507', 'ASCII:Radviliskis;ID:864507', '19217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19217', '112', '21094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.61.864507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21095', '1079', '1', 'Tauragė', 'LT.62.864508', 'ASCII:Taurage;ID:864508', '19218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19218', '112', '21095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.62.864508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21096', '1079', '1', 'Jurbarkas', 'LT.62.864509', 'ASCII:Jurbarkas;ID:864509', '19219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19219', '112', '21096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.62.864509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21097', '1079', '1', 'Šilalė', 'LT.62.864510', 'ASCII:Silale;ID:864510', '19220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19220', '112', '21097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.62.864510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21098', '1079', '1', 'Telšiai', 'LT.63.864511', 'ASCII:Telsiai;ID:864511', '19221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19221', '112', '21098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.63.864511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21099', '1079', '1', 'Mažeikiai', 'LT.63.864512', 'ASCII:Mazeikiai;ID:864512', '19222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19222', '112', '21099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.63.864512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21100', '1079', '1', 'Plungė', 'LT.63.864513', 'ASCII:Plunge;ID:864513', '19223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19223', '112', '21100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.63.864513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21101', '1079', '1', 'Utena', 'LT.64.864514', 'ASCII:Utena;ID:864514', '19224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19224', '112', '21101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.864514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21102', '1079', '1', 'Visaginas', 'LT.64.864515', 'ASCII:Visaginas;ID:864515', '19225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19225', '112', '21102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.864515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21103', '1079', '1', 'Anykščiai', 'LT.64.864516', 'ASCII:Anyksciai;ID:864516', '19226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19226', '112', '21103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.864516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21104', '1079', '1', 'Ignalina', 'LT.64.864517', 'ASCII:Ignalina;ID:864517', '19227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19227', '112', '21104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.864517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21105', '1079', '1', 'Molėtai', 'LT.64.864518', 'ASCII:Moletai;ID:864518', '19228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19228', '112', '21105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.864518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21106', '1079', '1', 'Zarasai', 'LT.64.864519', 'ASCII:Zarasai;ID:864519', '19229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19229', '112', '21106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.64.864519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21107', '1079', '1', 'Šalčininkai', 'LT.65.864520', 'ASCII:Salcininkai;ID:864520', '19230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19230', '112', '21107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.864520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21108', '1079', '1', 'Širvintos', 'LT.65.864521', 'ASCII:Sirvintos;ID:864521', '19231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19231', '112', '21108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.864521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21109', '1079', '1', 'Švenčionys', 'LT.65.864522', 'ASCII:Svencionys;ID:864522', '19232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19232', '112', '21109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.864522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21110', '1079', '1', 'Trakai', 'LT.65.864523', 'ASCII:Trakai;ID:864523', '19233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19233', '112', '21110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.864523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21111', '1079', '1', 'Ukmergė', 'LT.65.864524', 'ASCII:Ukmerge;ID:864524', '19234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19234', '112', '21111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LT.65.864524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21112', '1079', '1', 'Canton de Wiltz', 'LU.01.09', 'ASCII:Canton de Wiltz;ID:2959975', '19235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19235', '112', '21112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.01.09» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21113', '1079', '1', 'Canton de Vianden', 'LU.01.10', 'ASCII:Canton de Vianden;ID:2960020', '19236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19236', '112', '21113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.01.10» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21114', '1079', '1', 'Canton de Remich', 'LU.02.13', 'ASCII:Canton de Remich;ID:2960152', '19237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19237', '112', '21114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.02.13» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21115', '1079', '1', 'Canton de Redange', 'LU.01.08', 'ASCII:Canton de Redange;ID:2960161', '19238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19238', '112', '21115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.01.08» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21116', '1079', '1', 'Canton de Mersch', 'LU.03.05', 'ASCII:Canton de Mersch;ID:2960275', '19239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19239', '112', '21116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.03.05» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21117', '1079', '1', 'Canton de Luxembourg', 'LU.03.04', 'ASCII:Canton de Luxembourg;ID:2960315', '19240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19240', '112', '21117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.03.04» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21118', '1079', '1', 'Canton de Grevenmacher', 'LU.02.12', 'ASCII:Canton de Grevenmacher;ID:2960514', '19241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19241', '112', '21118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.02.12» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21119', '1079', '1', 'Canton d''Esch-sur-Alzette', 'LU.03.03', 'ASCII:Canton d''Esch-sur-Alzette;ID:2960599', '19242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19242', '112', '21119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.03.03» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21120', '1079', '1', 'Canton d''Echternach', 'LU.02.11', 'ASCII:Canton d''Echternach;ID:2960629', '19243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19243', '112', '21120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.02.11» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21121', '1079', '1', 'Canton de Diekirch', 'LU.01.07', 'ASCII:Canton de Diekirch;ID:2960656', '19244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19244', '112', '21121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.01.07» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21122', '1079', '1', 'Canton de Clervaux', 'LU.01.06', 'ASCII:Canton de Clervaux;ID:2960683', '19245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19245', '112', '21122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.01.06» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21123', '1079', '1', 'Canton de Capellen', 'LU.03.02', 'ASCII:Canton de Capellen;ID:2960696', '19246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19246', '112', '21123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LU.03.02» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21124', '1079', '1', 'Mutuşarrifīyat Ghadāmis', 'LY.56.2208403', 'ASCII:Mutusarrifiyat Ghadamis;ID:2208403', '19247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19247', '112', '21124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «LY.56.2208403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21125', '1079', '1', 'Tiznit', 'MA.55.581', 'ASCII:Tiznit;ID:2527087', '19248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19248', '112', '21125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.55.581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21126', '1079', '1', 'Tetouan', 'MA.57.571', 'ASCII:Tetouan;ID:2528907', '19249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19249', '112', '21126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.57.571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21127', '1079', '1', 'Taza', 'MA.58.561', 'ASCII:Taza;ID:2529313', '19250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19250', '112', '21127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.58.561» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21128', '1079', '1', 'Tata', 'MA.53.551', 'ASCII:Tata;ID:2529360', '19251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19251', '112', '21128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.53.551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21129', '1079', '1', 'Taroudannt', 'MA.55.541', 'ASCII:Taroudannt;ID:2529647', '19252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19252', '112', '21129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.55.541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21130', '1079', '1', 'Taounate', 'MA.58.531', 'ASCII:Taounate;ID:2530153', '19253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19253', '112', '21130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.58.531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21131', '1079', '1', 'Tan-Tan', 'MA.53.521', 'ASCII:Tan-Tan;ID:2530240', '19254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19254', '112', '21131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.53.521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21132', '1079', '1', 'Tanger-Assilah', 'MA.57.511', 'ASCII:Tanger-Assilah;ID:2530333', '19255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19255', '112', '21132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.57.511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21133', '1079', '1', 'Sidi-Kacem', 'MA.52.481', 'ASCII:Sidi-Kacem;ID:2534445', '19256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19256', '112', '21133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.52.481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21134', '1079', '1', 'Settat', 'MA.50.461', 'ASCII:Settat;ID:2537405', '19257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19257', '112', '21134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.50.461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21135', '1079', '1', 'Sale', 'MA.49.441', 'ASCII:Sale;ID:2537762', '19258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19258', '112', '21135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.49.441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21136', '1079', '1', 'Safi', 'MA.51.431', 'ASCII:Safi;ID:2537878', '19259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19259', '112', '21136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.51.431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21137', '1079', '1', 'Rabat', 'MA.49.421', 'ASCII:Rabat;ID:2538474', '19260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19260', '112', '21137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.49.421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21138', '1079', '1', 'Oujda-Angad', 'MA.54.411', 'ASCII:Oujda-Angad;ID:2540482', '19261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19261', '112', '21138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.54.411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21139', '1079', '1', 'Ouarzazate', 'MA.55.401', 'ASCII:Ouarzazate;ID:2540846', '19262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19262', '112', '21139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.55.401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21140', '1079', '1', 'Nador', 'MA.54.381', 'ASCII:Nador;ID:2541472', '19263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19263', '112', '21140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.54.381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21141', '1079', '1', 'Larache', 'MA.57.331', 'ASCII:Larache;ID:2543546', '19264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19264', '112', '21141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.57.331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21142', '1079', '1', 'Laayoune', 'MA.59.321', 'ASCII:Laayoune;ID:2543878', '19265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19265', '112', '21142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.59.321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21143', '1079', '1', 'Khouribga', 'MA.50.311', 'ASCII:Khouribga;ID:2544246', '19266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19266', '112', '21143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.50.311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21144', '1079', '1', 'Khenifra', 'MA.48.301', 'ASCII:Khenifra;ID:2544331', '19267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19267', '112', '21144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.48.301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21145', '1079', '1', 'Khemisset', 'MA.49.291', 'ASCII:Khemisset;ID:2544363', '19268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19268', '112', '21145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.49.291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21146', '1079', '1', 'Kenitra', 'MA.52.281', 'ASCII:Kenitra;ID:2544568', '19269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19269', '112', '21146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.52.281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21147', '1079', '1', 'Inezgane-Ait Mellou', 'MA.55.273', 'ASCII:Inezgane-Ait Mellou;ID:2545956', '19270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19270', '112', '21147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.55.273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21148', '1079', '1', 'Ifrane', 'MA.48.271', 'ASCII:Ifrane;ID:2546906', '19271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19271', '112', '21148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.48.271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21149', '1079', '1', 'Guelmim', 'MA.53.261', 'ASCII:Guelmim;ID:2548525', '19272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19272', '112', '21149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.53.261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21150', '1079', '1', 'Figuig', 'MA.54.251', 'ASCII:Figuig;ID:2548849', '19273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19273', '112', '21150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.54.251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21151', '1079', '1', 'Essaouira', 'MA.47.211', 'ASCII:Essaouira;ID:2549259', '19274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19274', '112', '21151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.47.211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21152', '1079', '1', 'Errachidia', 'MA.48.201', 'ASCII:Errachidia;ID:2549340', '19275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19275', '112', '21152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.48.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21153', '1079', '1', 'Kelaa-Des-Sraghna', 'MA.47.191', 'ASCII:Kelaa-Des-Sraghna;ID:2549978', '19276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19276', '112', '21153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.47.191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21154', '1079', '1', 'El-Jadida', 'MA.51.181', 'ASCII:El-Jadida;ID:2550076', '19277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19277', '112', '21154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.51.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21155', '1079', '1', 'Chefchaouen', 'MA.57.151', 'ASCII:Chefchaouen;ID:2553533', '19278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19278', '112', '21155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.57.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21156', '1079', '1', 'Boulemane', 'MA.46.131', 'ASCII:Boulemane;ID:2554387', '19279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19279', '112', '21156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.46.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21157', '1079', '1', 'Benslimane', 'MA.50.111', 'ASCII:Benslimane;ID:2555517', '19280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19280', '112', '21157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.50.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21158', '1079', '1', 'Beni-Mellal', 'MA.56.091', 'ASCII:Beni-Mellal;ID:2555742', '19281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19281', '112', '21158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.56.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21159', '1079', '1', 'Azilal', 'MA.56.081', 'ASCII:Azilal;ID:2556569', '19282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19282', '112', '21159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.56.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21160', '1079', '1', 'Al-Hoceima', 'MA.58.051', 'ASCII:Al-Hoceima;ID:2558543', '19283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19283', '112', '21160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.58.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21161', '1079', '1', 'Agadir-Ida-ou-Tnan', 'MA.55.001', 'ASCII:Agadir-Ida-ou-Tnan;ID:2561655', '19284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19284', '112', '21161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.55.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21162', '1079', '1', 'Skhirate-Temara', 'MA.49.501', 'ASCII:Skhirate-Temara;ID:2562053', '19285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19285', '112', '21162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.49.501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21163', '1079', '1', 'Assa-Zag', 'MA.53.071', 'ASCII:Assa-Zag;ID:2595329', '19286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19286', '112', '21163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.53.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21164', '1079', '1', 'Es-Semara', 'MA.53.221', 'ASCII:Es-Semara;ID:2595330', '19287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19287', '112', '21164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.53.221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21165', '1079', '1', 'Meknes', 'MA.48.061', 'ASCII:Meknes;ID:6547283', '19288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19288', '112', '21165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.48.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21166', '1079', '1', 'Chichaoua', 'MA.47.161', 'ASCII:Chichaoua;ID:6547284', '19289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19289', '112', '21166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.47.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21167', '1079', '1', 'Marrakech', 'MA.47.351', 'ASCII:Marrakech;ID:6547285', '19290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19290', '112', '21167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.47.351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21168', '1079', '1', 'Sefrou', 'MA.46.451', 'ASCII:Sefrou;ID:6547286', '19291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19291', '112', '21168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.46.451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21169', '1079', '1', 'Berkane', 'MA.54.113', 'ASCII:Berkane;ID:6547287', '19292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19292', '112', '21169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.54.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21170', '1079', '1', 'Jerada', 'MA.54.275', 'ASCII:Jerada;ID:6547288', '19293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19293', '112', '21170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.54.275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21171', '1079', '1', 'Taourirt', 'MA.54.533', 'ASCII:Taourirt;ID:6547289', '19294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19294', '112', '21171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.54.533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21172', '1079', '1', 'Boujdour', 'MA.59.121', 'ASCII:Boujdour;ID:6547290', '19295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19295', '112', '21172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.59.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21173', '1079', '1', 'Chtouka-Ait-Baha', 'MA.55.163', 'ASCII:Chtouka-Ait-Baha;ID:6547291', '19296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19296', '112', '21173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.55.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21174', '1079', '1', 'Al-Haouz', 'MA.47.041', 'ASCII:Al-Haouz;ID:6547292', '19297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19297', '112', '21174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.47.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21175', '1079', '1', 'Fahs-Anjra', 'MA.57.227', 'ASCII:Fahs-Anjra;ID:6547293', '19298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19298', '112', '21175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.57.227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21176', '1079', '1', 'Casablanca', 'MA.45.141', 'ASCII:Casablanca;ID:6547294', '19299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19299', '112', '21176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.45.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21177', '1079', '1', 'Moulay-Yacoub', 'MA.46.591', 'ASCII:Moulay-Yacoub;ID:6547295', '19300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19300', '112', '21177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.46.591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21178', '1079', '1', 'El-Hajeb', 'MA.48.171', 'ASCII:El-Hajeb;ID:6547296', '19301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19301', '112', '21178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.48.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21179', '1079', '1', 'Aousserd', 'MA..066', 'ASCII:Aousserd;ID:6547297', '19302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19302', '112', '21179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA..066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21180', '1079', '1', 'Oued-Ed-Dahab', 'MA..391', 'ASCII:Oued-Ed-Dahab;ID:6547298', '19303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19303', '112', '21180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA..391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21181', '1079', '1', 'Nouaceur', 'MA.45.385', 'ASCII:Nouaceur;ID:6547299', '19304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19304', '112', '21181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.45.385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21182', '1079', '1', 'Fes', 'MA.46.231', 'ASCII:Fes;ID:6547300', '19305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19305', '112', '21182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.46.231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21183', '1079', '1', 'Mohammedia', 'MA.45.371', 'ASCII:Mohammedia;ID:6547301', '19306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19306', '112', '21183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.45.371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21184', '1079', '1', 'Zagora', 'MA.55.587', 'ASCII:Zagora;ID:6547302', '19307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19307', '112', '21184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.55.587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21185', '1079', '1', 'Mediouna', 'MA.45.355', 'ASCII:Mediouna;ID:6547303', '19308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19308', '112', '21185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MA.45.355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21186', '1079', '1', 'Sovetskiy Rayon', 'MD.00.617365', 'ASCII:Sovetskiy Rayon;ID:617365', '19309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19309', '112', '21186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MD.00.617365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21187', '1079', '1', 'Oktyabr''skiy Rayon', 'MD.00.617653', 'ASCII:Oktyabr''skiy Rayon;ID:617653', '19310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19310', '112', '21187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MD.00.617653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21188', '1079', '1', 'Leninskiy Rayon', 'MD.00.617908', 'ASCII:Leninskiy Rayon;ID:617908', '19311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19311', '112', '21188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MD.00.617908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21189', '1079', '1', 'Frunzenskiy Rayon', 'MD.00.618319', 'ASCII:Frunzenskiy Rayon;ID:618319', '19312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19312', '112', '21189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MD.00.618319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21190', '1079', '1', 'Arrondissement de Saint-Martin-Saint-Barthélemy', 'MF.00.3578419', 'ASCII:Arrondissement de Saint-Martin-Saint-Barthelemy;ID:3578419', '19313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19313', '112', '21190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MF.00.3578419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21191', '1079', '1', 'Vinica Opština', 'MK.00.784423', 'ASCII:Vinica Opstina;ID:784423', '19314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19314', '112', '21191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.784423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21192', '1079', '1', 'Titov Veles Opština', 'MK.00.785057', 'ASCII:Titov Veles Opstina;ID:785057', '19315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19315', '112', '21192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.785057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21193', '1079', '1', 'Tetovo Opština', 'MK.00.785081', 'ASCII:Tetovo Opstina;ID:785081', '19316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19316', '112', '21193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.785081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21194', '1079', '1', 'Sveti Nikole Opština', 'MK.00.785200', 'ASCII:Sveti Nikole Opstina;ID:785200', '19317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19317', '112', '21194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.785200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21195', '1079', '1', 'Strumica Opština', 'MK.00.785379', 'ASCII:Strumica Opstina;ID:785379', '19318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19318', '112', '21195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.785379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21196', '1079', '1', 'Struga Opština', 'MK.00.785386', 'ASCII:Struga Opstina;ID:785386', '19319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19319', '112', '21196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.785386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21197', '1079', '1', 'Štip Opština', 'MK.00.785481', 'ASCII:Stip Opstina;ID:785481', '19320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19320', '112', '21197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.785481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21198', '1079', '1', 'Skopje Opština', 'MK.00.785841', 'ASCII:Skopje Opstina;ID:785841', '19321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19321', '112', '21198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.785841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21199', '1079', '1', 'Radoviš Opština', 'MK.00.786564', 'ASCII:Radovis Opstina;ID:786564', '19322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19322', '112', '21199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.786564» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21200', '1079', '1', 'Probištip Opština', 'MK.00.786699', 'ASCII:Probistip Opstina;ID:786699', '19323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19323', '112', '21200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.786699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21201', '1079', '1', 'Prilep Opština', 'MK.00.786733', 'ASCII:Prilep Opstina;ID:786733', '19324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19324', '112', '21201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.786733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21202', '1079', '1', 'Ohrid Opština', 'MK.00.787486', 'ASCII:Ohrid Opstina;ID:787486', '19325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19325', '112', '21202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.787486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21203', '1079', '1', 'Negotino Opština', 'MK.00.787714', 'ASCII:Negotino Opstina;ID:787714', '19326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19326', '112', '21203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.787714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21204', '1079', '1', 'Kumanovo Opština', 'MK.00.788884', 'ASCII:Kumanovo Opstina;ID:788884', '19327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19327', '112', '21204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.788884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21205', '1079', '1', 'Kruševo Opština', 'MK.00.788956', 'ASCII:Krusevo Opstina;ID:788956', '19328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19328', '112', '21205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.788956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21206', '1079', '1', 'Општина „Крива Паланка“', 'MK.00.789044', 'ASCII:Kriva Palanka;ID:789044', '19329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19329', '112', '21206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.789044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21207', '1079', '1', 'Kocani Opština', 'MK.00.789402', 'ASCII:Kocani Opstina;ID:789402', '19330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19330', '112', '21207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.789402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21208', '1079', '1', 'Kicevo Opština', 'MK.00.789526', 'ASCII:Kicevo Opstina;ID:789526', '19331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19331', '112', '21208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.789526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21209', '1079', '1', 'Kavadarci Opština', 'MK.00.789540', 'ASCII:Kavadarci Opstina;ID:789540', '19332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19332', '112', '21209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.789540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21210', '1079', '1', 'Gostivar Opština', 'MK.00.790294', 'ASCII:Gostivar Opstina;ID:790294', '19333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19333', '112', '21210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.790294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21211', '1079', '1', 'Gevgelija Opština', 'MK.00.790743', 'ASCII:Gevgelija Opstina;ID:790743', '19334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19334', '112', '21211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.790743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21212', '1079', '1', 'Demir Hisar Opština', 'MK.00.791545', 'ASCII:Demir Hisar Opstina;ID:791545', '19335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19335', '112', '21212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.791545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21213', '1079', '1', 'Delcevo Opština', 'MK.00.791558', 'ASCII:Delcevo Opstina;ID:791558', '19336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19336', '112', '21213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.791558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21214', '1079', '1', 'Debar Opština', 'MK.00.791605', 'ASCII:Debar Opstina;ID:791605', '19337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19337', '112', '21214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.791605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21215', '1079', '1', 'Brod Opština', 'MK.00.792253', 'ASCII:Brod Opstina;ID:792253', '19338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19338', '112', '21215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.792253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21216', '1079', '1', 'Bitola Opština', 'MK.00.792577', 'ASCII:Bitola Opstina;ID:792577', '19339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19339', '112', '21216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.792577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21217', '1079', '1', 'Berovo Opština', 'MK.00.792655', 'ASCII:Berovo Opstina;ID:792655', '19340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19340', '112', '21217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.792655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21218', '1079', '1', 'Kratovo Opština', 'MK.00.863868', 'ASCII:Kratovo Opstina;ID:863868', '19341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19341', '112', '21218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MK.00.863868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21219', '1079', '1', 'Songino', 'MN.09.1515279', 'ASCII:Songino;ID:1515279', '19342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19342', '112', '21219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.1515279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21220', '1079', '1', 'Tariat', 'MN.01.1515709', 'ASCII:Tariat;ID:1515709', '19343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19343', '112', '21220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.1515709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21221', '1079', '1', 'Dörgön', 'MN.12.1516065', 'ASCII:Doergoen;ID:1516065', '19344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19344', '112', '21221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.1516065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21222', '1079', '1', 'Bayannuur', 'MN.03.1516281', 'ASCII:Bayannuur;ID:1516281', '19345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19345', '112', '21222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.1516281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21223', '1079', '1', 'Tarialan', 'MN.13.2029006', 'ASCII:Tarialan;ID:2029006', '19346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19346', '112', '21223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.2029006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21224', '1079', '1', 'Nomgon', 'MN.14.2029819', 'ASCII:Nomgon;ID:2029819', '19347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19347', '112', '21224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.2029819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21225', '1079', '1', 'Bayan-Önjüül', 'MN.18.2032495', 'ASCII:Bayan-OEnjueuel;ID:2032495', '19348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19348', '112', '21225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.2032495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21226', '1079', '1', 'Bayangol', 'MN.16.2032552', 'ASCII:Bayangol;ID:2032552', '19349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19349', '112', '21226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.2032552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21227', '1079', '1', 'Halhgol', 'MN.06.6618688', 'ASCII:Halhgol;ID:6618688', '19350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19350', '112', '21227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618688» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21228', '1079', '1', 'Matad', 'MN.06.6618689', 'ASCII:Matad;ID:6618689', '19351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19351', '112', '21228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21229', '1079', '1', 'Bayantümen', 'MN.06.6618690', 'ASCII:Bayantuemen;ID:6618690', '19352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19352', '112', '21229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21230', '1079', '1', 'Bulgan', 'MN.06.6618691', 'ASCII:Bulgan;ID:6618691', '19353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19353', '112', '21230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618691» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21231', '1079', '1', 'Hölönbuyr', 'MN.06.6618692', 'ASCII:Hoeloenbuyr;ID:6618692', '19354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19354', '112', '21231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21232', '1079', '1', 'Choybalsan', 'MN.06.6618693', 'ASCII:Choybalsan;ID:6618693', '19355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19355', '112', '21232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21233', '1079', '1', 'Chuluunhoroot', 'MN.06.6618694', 'ASCII:Chuluunhoroot;ID:6618694', '19356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19356', '112', '21233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618694» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21234', '1079', '1', 'Dashbalbar', 'MN.06.6618695', 'ASCII:Dashbalbar;ID:6618695', '19357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19357', '112', '21234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21235', '1079', '1', 'Gurvandzagal', 'MN.06.6618696', 'ASCII:Gurvandzagal;ID:6618696', '19358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19358', '112', '21235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21236', '1079', '1', 'Sergelen', 'MN.06.6618697', 'ASCII:Sergelen;ID:6618697', '19359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19359', '112', '21236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618697» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21237', '1079', '1', 'Tsagaan-Ovoo', 'MN.06.6618698', 'ASCII:Tsagaan-Ovoo;ID:6618698', '19360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19360', '112', '21237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21238', '1079', '1', 'Bayandun', 'MN.06.6618699', 'ASCII:Bayandun;ID:6618699', '19361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19361', '112', '21238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21239', '1079', '1', 'Bayan-Uul', 'MN.06.6618700', 'ASCII:Bayan-Uul;ID:6618700', '19362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19362', '112', '21239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21240', '1079', '1', 'Herlen', 'MN.06.6618701', 'ASCII:Herlen;ID:6618701', '19363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19363', '112', '21240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.06.6618701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21241', '1079', '1', 'Erdenetsagaan', 'MN.17.6618702', 'ASCII:Erdenetsagaan;ID:6618702', '19364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19364', '112', '21241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21242', '1079', '1', 'Darĭganga', 'MN.17.6618703', 'ASCII:Dariganga;ID:6618703', '19365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19365', '112', '21242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21243', '1079', '1', 'Ongon', 'MN.17.6618704', 'ASCII:Ongon;ID:6618704', '19366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19366', '112', '21243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21244', '1079', '1', 'Naran', 'MN.17.6618705', 'ASCII:Naran;ID:6618705', '19367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19367', '112', '21244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21245', '1079', '1', 'Bayandelger', 'MN.17.6618706', 'ASCII:Bayandelger;ID:6618706', '19368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19368', '112', '21245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21246', '1079', '1', 'Haldzan', 'MN.17.6618707', 'ASCII:Haldzan;ID:6618707', '19369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19369', '112', '21246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21247', '1079', '1', 'Uulbayan', 'MN.17.6618708', 'ASCII:Uulbayan;ID:6618708', '19370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19370', '112', '21247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21248', '1079', '1', 'Mönhhaan', 'MN.17.6618709', 'ASCII:Moenhhaan;ID:6618709', '19371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19371', '112', '21248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21249', '1079', '1', 'Tümentsogt', 'MN.17.6618710', 'ASCII:Tuementsogt;ID:6618710', '19372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19372', '112', '21249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21250', '1079', '1', 'Sühbaatar', 'MN.17.6618711', 'ASCII:Suehbaatar;ID:6618711', '19373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19373', '112', '21250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21251', '1079', '1', 'Tüvshinshiree', 'MN.17.6618712', 'ASCII:Tuevshinshiree;ID:6618712', '19374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19374', '112', '21251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21252', '1079', '1', 'Asgat', 'MN.17.6618713', 'ASCII:Asgat;ID:6618713', '19375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19375', '112', '21252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21253', '1079', '1', 'Baruun-Urt', 'MN.17.6618714', 'ASCII:Baruun-Urt;ID:6618714', '19376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19376', '112', '21253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.17.6618714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21254', '1079', '1', 'Ömnödelger', 'MN.11.6618715', 'ASCII:OEmnoedelger;ID:6618715', '19377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19377', '112', '21254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21255', '1079', '1', 'Darhan', 'MN.11.6618719', 'ASCII:Darhan;ID:6618719', '19378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19378', '112', '21255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21256', '1079', '1', 'Bayanmönh', 'MN.11.6618720', 'ASCII:Bayanmoenh;ID:6618720', '19379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19379', '112', '21256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21257', '1079', '1', 'Delgerhaan', 'MN.11.6618721', 'ASCII:Delgerhaan;ID:6618721', '19380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19380', '112', '21257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21258', '1079', '1', 'Jargalthaan', 'MN.11.6618722', 'ASCII:Jargalthaan;ID:6618722', '19381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19381', '112', '21258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21259', '1079', '1', 'Tsenhermandal', 'MN.11.6618723', 'ASCII:Tsenhermandal;ID:6618723', '19382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19382', '112', '21259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21260', '1079', '1', 'Mörön', 'MN.11.6618725', 'ASCII:Moeroen;ID:6618725', '19383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19383', '112', '21260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21261', '1079', '1', 'Herlen', 'MN.11.6618726', 'ASCII:Herlen;ID:6618726', '19384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19384', '112', '21261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21262', '1079', '1', 'Bayanhutag', 'MN.11.6618727', 'ASCII:Bayanhutag;ID:6618727', '19385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19385', '112', '21262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618727» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21263', '1079', '1', 'Galshar', 'MN.11.6618728', 'ASCII:Galshar;ID:6618728', '19386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19386', '112', '21263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21264', '1079', '1', 'Batshireet', 'MN.11.6618729', 'ASCII:Batshireet;ID:6618729', '19387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19387', '112', '21264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21265', '1079', '1', 'Binder', 'MN.11.6618730', 'ASCII:Binder;ID:6618730', '19388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19388', '112', '21265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21266', '1079', '1', 'Bayan-Adarga', 'MN.11.6618731', 'ASCII:Bayan-Adarga;ID:6618731', '19389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19389', '112', '21266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21267', '1079', '1', 'Dadal', 'MN.11.6618732', 'ASCII:Dadal;ID:6618732', '19390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19390', '112', '21267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21268', '1079', '1', 'Batnorov', 'MN.11.6618733', 'ASCII:Batnorov;ID:6618733', '19391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19391', '112', '21268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21269', '1079', '1', 'Bayan-Ovoo', 'MN.11.6618734', 'ASCII:Bayan-Ovoo;ID:6618734', '19392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19392', '112', '21269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21270', '1079', '1', 'Norovlin', 'MN.11.6618735', 'ASCII:Norovlin;ID:6618735', '19393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19393', '112', '21270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.11.6618735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21271', '1079', '1', 'Dalanjargalan', 'MN.07.6618754', 'ASCII:Dalanjargalan;ID:6618754', '19394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19394', '112', '21271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21272', '1079', '1', 'Ayrag', 'MN.07.6618755', 'ASCII:Ayrag;ID:6618755', '19395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19395', '112', '21272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21273', '1079', '1', 'Ihhet', 'MN.07.6618756', 'ASCII:Ihhet;ID:6618756', '19396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19396', '112', '21273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21274', '1079', '1', 'Altanshiree', 'MN.07.6618757', 'ASCII:Altanshiree;ID:6618757', '19397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19397', '112', '21274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21275', '1079', '1', 'Delgereh', 'MN.07.6618758', 'ASCII:Delgereh;ID:6618758', '19398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19398', '112', '21275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21276', '1079', '1', 'Saynshand', 'MN.07.6618760', 'ASCII:Saynshand;ID:6618760', '19399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19399', '112', '21276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21277', '1079', '1', 'Örgön', 'MN.07.6618761', 'ASCII:OErgoen;ID:6618761', '19400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19400', '112', '21277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21278', '1079', '1', 'Erdene', 'MN.07.6618762', 'ASCII:Erdene;ID:6618762', '19401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19401', '112', '21278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618762» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21279', '1079', '1', 'Dzamyn Üüd', 'MN.07.6618763', 'ASCII:Dzamyn UEued;ID:6618763', '19402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19402', '112', '21279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21280', '1079', '1', 'Ulaanbadrah', 'MN.07.6618764', 'ASCII:Ulaanbadrah;ID:6618764', '19403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19403', '112', '21280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21281', '1079', '1', 'Sayhandulaan', 'MN.07.6618765', 'ASCII:Sayhandulaan;ID:6618765', '19404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19404', '112', '21281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21282', '1079', '1', 'Mandah', 'MN.07.6618766', 'ASCII:Mandah;ID:6618766', '19405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19405', '112', '21282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21283', '1079', '1', 'Hövsgöl', 'MN.07.6618767', 'ASCII:Hoevsgoel;ID:6618767', '19406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19406', '112', '21283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618767» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21284', '1079', '1', 'Hatanbulag', 'MN.07.6618768', 'ASCII:Hatanbulag;ID:6618768', '19407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19407', '112', '21284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618768» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21285', '1079', '1', 'Sümber', 'MN.08.6618769', 'ASCII:Suember;ID:6618769', '19408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19408', '112', '21285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21286', '1079', '1', 'Bayantal', 'MN.18.6618770', 'ASCII:Bayantal;ID:6618770', '19409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19409', '112', '21286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21287', '1079', '1', 'Shiveegovĭ', 'MN.07.6618771', 'ASCII:Shiveegovi;ID:6618771', '19410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19410', '112', '21287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.07.6618771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21288', '1079', '1', 'Mandal-Ovoo', 'MN.14.6618789', 'ASCII:Mandal-Ovoo;ID:6618789', '19411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19411', '112', '21288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21289', '1079', '1', 'Tsogt-Ovoo', 'MN.14.6618790', 'ASCII:Tsogt-Ovoo;ID:6618790', '19412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19412', '112', '21289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618790» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21290', '1079', '1', 'Hanhongor', 'MN.14.6618791', 'ASCII:Hanhongor;ID:6618791', '19413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19413', '112', '21290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618791» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21291', '1079', '1', 'Tsogttsetsiy', 'MN.14.6618792', 'ASCII:Tsogttsetsiy;ID:6618792', '19414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19414', '112', '21291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21292', '1079', '1', 'Manlay', 'MN.14.6618793', 'ASCII:Manlay;ID:6618793', '19415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19415', '112', '21292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21293', '1079', '1', 'Hanbogd', 'MN.14.6618794', 'ASCII:Hanbogd;ID:6618794', '19416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19416', '112', '21293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21294', '1079', '1', 'Bayan-Ovoo', 'MN.14.6618795', 'ASCII:Bayan-Ovoo;ID:6618795', '19417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19417', '112', '21294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21295', '1079', '1', 'Hürmen', 'MN.14.6618796', 'ASCII:Huermen;ID:6618796', '19418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19418', '112', '21295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21296', '1079', '1', 'Bayandalay', 'MN.14.6618797', 'ASCII:Bayandalay;ID:6618797', '19419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19419', '112', '21296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21297', '1079', '1', 'Bulgan', 'MN.14.6618798', 'ASCII:Bulgan;ID:6618798', '19420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19420', '112', '21297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21298', '1079', '1', 'Sevrey', 'MN.14.6618799', 'ASCII:Sevrey;ID:6618799', '19421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19421', '112', '21298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21299', '1079', '1', 'Noyon', 'MN.14.6618800', 'ASCII:Noyon;ID:6618800', '19422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19422', '112', '21299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21300', '1079', '1', 'Gurvantes', 'MN.14.6618801', 'ASCII:Gurvantes;ID:6618801', '19423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19423', '112', '21300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21301', '1079', '1', 'Dalandzadgad', 'MN.14.6618802', 'ASCII:Dalandzadgad;ID:6618802', '19424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19424', '112', '21301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.14.6618802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21302', '1079', '1', 'Sayhan-Ovoo', 'MN.08.6618803', 'ASCII:Sayhan-Ovoo;ID:6618803', '19425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19425', '112', '21302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21303', '1079', '1', 'Delgerhangay', 'MN.08.6618804', 'ASCII:Delgerhangay;ID:6618804', '19426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19426', '112', '21303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21304', '1079', '1', 'Huld', 'MN.08.6618805', 'ASCII:Huld;ID:6618805', '19427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19427', '112', '21304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21305', '1079', '1', 'Luus', 'MN.08.6618806', 'ASCII:Luus;ID:6618806', '19428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19428', '112', '21305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21306', '1079', '1', 'Erdenedalay', 'MN.08.6618807', 'ASCII:Erdenedalay;ID:6618807', '19429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19429', '112', '21306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21307', '1079', '1', 'Adaatsag', 'MN.08.6618808', 'ASCII:Adaatsag;ID:6618808', '19430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19430', '112', '21307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21308', '1079', '1', 'Delgertsogt', 'MN.08.6618809', 'ASCII:Delgertsogt;ID:6618809', '19431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19431', '112', '21308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21309', '1079', '1', 'Deren', 'MN.08.6618810', 'ASCII:Deren;ID:6618810', '19432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19432', '112', '21309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21310', '1079', '1', 'Tsagaandelger', 'MN.08.6618811', 'ASCII:Tsagaandelger;ID:6618811', '19433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19433', '112', '21310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21311', '1079', '1', 'Govĭ-Ugtaal', 'MN.08.6618812', 'ASCII:Govi-Ugtaal;ID:6618812', '19434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19434', '112', '21311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21312', '1079', '1', 'Bayanjargalan', 'MN.08.6618813', 'ASCII:Bayanjargalan;ID:6618813', '19435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19435', '112', '21312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21313', '1079', '1', 'Gurvansayhan', 'MN.08.6618814', 'ASCII:Gurvansayhan;ID:6618814', '19436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19436', '112', '21313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21314', '1079', '1', 'Öndörshil', 'MN.08.6618815', 'ASCII:OEndoershil;ID:6618815', '19437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19437', '112', '21314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21315', '1079', '1', 'Öldziyt', 'MN.08.6618816', 'ASCII:OEldziyt;ID:6618816', '19438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19438', '112', '21315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21316', '1079', '1', 'Saintsagaan', 'MN.08.6618817', 'ASCII:Saintsagaan;ID:6618817', '19439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19439', '112', '21316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.08.6618817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21317', '1079', '1', 'Delgerhaan', 'MN.18.6618822', 'ASCII:Delgerhaan;ID:6618822', '19440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19440', '112', '21317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21318', '1079', '1', 'Büren', 'MN.18.6618823', 'ASCII:Bueren;ID:6618823', '19441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19441', '112', '21318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21319', '1079', '1', 'Bayantsagaan', 'MN.18.6618824', 'ASCII:Bayantsagaan;ID:6618824', '19442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19442', '112', '21319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21320', '1079', '1', 'Sergelen', 'MN.18.6618826', 'ASCII:Sergelen;ID:6618826', '19443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19443', '112', '21320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21321', '1079', '1', 'Altanbulag', 'MN.18.6618827', 'ASCII:Altanbulag;ID:6618827', '19444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19444', '112', '21321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21322', '1079', '1', 'Öndörshireet', 'MN.18.6618828', 'ASCII:OEndoershireet;ID:6618828', '19445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19445', '112', '21322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21323', '1079', '1', 'Erdenesant', 'MN.18.6618829', 'ASCII:Erdenesant;ID:6618829', '19446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19446', '112', '21323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21324', '1079', '1', 'Lün', 'MN.18.6618830', 'ASCII:Luen;ID:6618830', '19447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19447', '112', '21324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21325', '1079', '1', 'Bayanhangay', 'MN.18.6618831', 'ASCII:Bayanhangay;ID:6618831', '19448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19448', '112', '21325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618831» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21326', '1079', '1', 'Argalant', 'MN.18.6618832', 'ASCII:Argalant;ID:6618832', '19449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19449', '112', '21326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21327', '1079', '1', 'Bayantsogt', 'MN.18.6618833', 'ASCII:Bayantsogt;ID:6618833', '19450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19450', '112', '21327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21328', '1079', '1', 'Ugtaal', 'MN.18.6618834', 'ASCII:Ugtaal;ID:6618834', '19451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19451', '112', '21328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21329', '1079', '1', 'Dzaamar', 'MN.18.6618835', 'ASCII:Dzaamar;ID:6618835', '19452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19452', '112', '21329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21330', '1079', '1', 'Tseel', 'MN.18.6618836', 'ASCII:Tseel;ID:6618836', '19453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19453', '112', '21330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21331', '1079', '1', 'Jargalant', 'MN.18.6618837', 'ASCII:Jargalant;ID:6618837', '19454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19454', '112', '21331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618837» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21332', '1079', '1', 'Sümber', 'MN.18.6618838', 'ASCII:Suember;ID:6618838', '19455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19455', '112', '21332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21333', '1079', '1', 'Bornuur', 'MN.18.6618839', 'ASCII:Bornuur;ID:6618839', '19456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19456', '112', '21333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21334', '1079', '1', 'Bayanchandmanĭ', 'MN.18.6618840', 'ASCII:Bayanchandmani;ID:6618840', '19457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19457', '112', '21334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21335', '1079', '1', 'Batsümber', 'MN.18.6618841', 'ASCII:Batsuember;ID:6618841', '19458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19458', '112', '21335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21336', '1079', '1', 'Möngönmorĭt', 'MN.18.6618842', 'ASCII:Moengoenmorit;ID:6618842', '19459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19459', '112', '21336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21337', '1079', '1', 'Bayandelger', 'MN.18.6618843', 'ASCII:Bayandelger;ID:6618843', '19460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19460', '112', '21337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21338', '1079', '1', 'Erdene', 'MN.18.6618844', 'ASCII:Erdene;ID:6618844', '19461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19461', '112', '21338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618844» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21339', '1079', '1', 'Arhust', 'MN.18.6618845', 'ASCII:Arhust;ID:6618845', '19462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19462', '112', '21339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21340', '1079', '1', 'Bayan', 'MN.18.6618846', 'ASCII:Bayan;ID:6618846', '19463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19463', '112', '21340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21341', '1079', '1', 'Bayanjargalan', 'MN.18.6618847', 'ASCII:Bayanjargalan;ID:6618847', '19464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19464', '112', '21341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21342', '1079', '1', 'Dzuunmod', 'MN.18.6618848', 'ASCII:Dzuunmod;ID:6618848', '19465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19465', '112', '21342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21343', '1079', '1', 'Baganuur', 'MN.18.6618851', 'ASCII:Baganuur;ID:6618851', '19466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19466', '112', '21343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.18.6618851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21344', '1079', '1', 'Bayandzürh', 'MN.20.6618852', 'ASCII:Bayandzuerh;ID:6618852', '19467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19467', '112', '21344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.20.6618852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21345', '1079', '1', 'Sharïngol', 'MN.23.6618853', 'ASCII:Sharingol;ID:6618853', '19468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19468', '112', '21345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.23.6618853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21346', '1079', '1', 'Hongor', 'MN.23.6618854', 'ASCII:Hongor;ID:6618854', '19469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19469', '112', '21346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.23.6618854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21347', '1079', '1', 'Orhon', 'MN.23.6618855', 'ASCII:Orhon;ID:6618855', '19470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19470', '112', '21347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.23.6618855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21348', '1079', '1', 'Mandal', 'MN.16.6618857', 'ASCII:Mandal;ID:6618857', '19471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19471', '112', '21348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21349', '1079', '1', 'Orhon', 'MN.16.6618859', 'ASCII:Orhon;ID:6618859', '19472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19472', '112', '21349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21350', '1079', '1', 'Sayhan', 'MN.16.6618861', 'ASCII:Sayhan;ID:6618861', '19473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19473', '112', '21350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21351', '1079', '1', 'Sant', 'MN.16.6618862', 'ASCII:Sant;ID:6618862', '19474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19474', '112', '21351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618862» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21352', '1079', '1', 'Baruunbüren', 'MN.16.6618863', 'ASCII:Baruunbueren;ID:6618863', '19475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19475', '112', '21352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21353', '1079', '1', 'Orhontuul', 'MN.16.6618864', 'ASCII:Orhontuul;ID:6618864', '19476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19476', '112', '21353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21354', '1079', '1', 'Shaamar', 'MN.16.6618865', 'ASCII:Shaamar;ID:6618865', '19477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19477', '112', '21354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21355', '1079', '1', 'Dzüünbüren', 'MN.16.6618866', 'ASCII:Dzueuenbueren;ID:6618866', '19478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19478', '112', '21355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21356', '1079', '1', 'Tsagaannuur', 'MN.16.6618867', 'ASCII:Tsagaannuur;ID:6618867', '19479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19479', '112', '21356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21357', '1079', '1', 'Tüshig', 'MN.16.6618868', 'ASCII:Tueshig;ID:6618868', '19480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19480', '112', '21357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21358', '1079', '1', 'Sühbaatar', 'MN.16.6618869', 'ASCII:Suehbaatar;ID:6618869', '19481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19481', '112', '21358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21359', '1079', '1', 'Altanbulag', 'MN.16.6618870', 'ASCII:Altanbulag;ID:6618870', '19482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19482', '112', '21359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21360', '1079', '1', 'Yöröö', 'MN.16.6618871', 'ASCII:Yoeroeoe;ID:6618871', '19483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19483', '112', '21360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618871» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21361', '1079', '1', 'Hüder', 'MN.16.6618872', 'ASCII:Hueder;ID:6618872', '19484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19484', '112', '21361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21362', '1079', '1', 'Javhlant', 'MN.16.6618873', 'ASCII:Javhlant;ID:6618873', '19485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19485', '112', '21362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21363', '1079', '1', 'Hushaat', 'MN.16.6618874', 'ASCII:Hushaat;ID:6618874', '19486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19486', '112', '21363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.16.6618874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21364', '1079', '1', 'Bayan-Öndör', 'MN.25.6618875', 'ASCII:Bayan-OEndoer;ID:6618875', '19487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19487', '112', '21364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.25.6618875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21365', '1079', '1', 'Jargalant', 'MN.25.6618877', 'ASCII:Jargalant;ID:6618877', '19488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19488', '112', '21365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.25.6618877» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21366', '1079', '1', 'Hangal', 'MN.21.6618878', 'ASCII:Hangal;ID:6618878', '19489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19489', '112', '21366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21367', '1079', '1', 'Selenge', 'MN.21.6618879', 'ASCII:Selenge;ID:6618879', '19490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19490', '112', '21367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21368', '1079', '1', 'Teshig', 'MN.21.6618881', 'ASCII:Teshig;ID:6618881', '19491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19491', '112', '21368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21369', '1079', '1', 'Hutag-Öndör', 'MN.21.6618882', 'ASCII:Hutag-OEndoer;ID:6618882', '19492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19492', '112', '21369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21370', '1079', '1', 'Bugat', 'MN.21.6618883', 'ASCII:Bugat;ID:6618883', '19493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19493', '112', '21370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21371', '1079', '1', 'Bayan-Agt', 'MN.21.6618884', 'ASCII:Bayan-Agt;ID:6618884', '19494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19494', '112', '21371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21372', '1079', '1', 'Sayhan', 'MN.21.6618885', 'ASCII:Sayhan;ID:6618885', '19495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19495', '112', '21372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21373', '1079', '1', 'Orhon', 'MN.21.6618886', 'ASCII:Orhon;ID:6618886', '19496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19496', '112', '21373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21374', '1079', '1', 'Hishig-Öndör', 'MN.21.6618887', 'ASCII:Hishig-OEndoer;ID:6618887', '19497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19497', '112', '21374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21375', '1079', '1', 'Mogod', 'MN.21.6618888', 'ASCII:Mogod;ID:6618888', '19498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19498', '112', '21375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21376', '1079', '1', 'Büreghangay', 'MN.21.6618889', 'ASCII:Buereghangay;ID:6618889', '19499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19499', '112', '21376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21377', '1079', '1', 'Dashinchilen', 'MN.21.6618890', 'ASCII:Dashinchilen;ID:6618890', '19500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19500', '112', '21377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618890» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21378', '1079', '1', 'Bayannuur', 'MN.21.6618892', 'ASCII:Bayannuur;ID:6618892', '19501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19501', '112', '21378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21379', '1079', '1', 'Gurvanbulag', 'MN.21.6618893', 'ASCII:Gurvanbulag;ID:6618893', '19502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19502', '112', '21379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618893» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21380', '1079', '1', 'Rashaant', 'MN.01.6618894', 'ASCII:Rashaant;ID:6618894', '19503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19503', '112', '21380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6618894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21381', '1079', '1', 'Bulgan', 'MN.21.6618895', 'ASCII:Bulgan;ID:6618895', '19504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19504', '112', '21381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.21.6618895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21382', '1079', '1', 'Renchinlhümbe', 'MN.13.6618997', 'ASCII:Renchinlhuembe;ID:6618997', '19505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19505', '112', '21382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6618997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21383', '1079', '1', 'Tsagaannuur', 'MN.13.6618998', 'ASCII:Tsagaannuur;ID:6618998', '19506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19506', '112', '21383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6618998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21384', '1079', '1', 'Ulaan-Uul', 'MN.13.6618999', 'ASCII:Ulaan-Uul;ID:6618999', '19507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19507', '112', '21384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6618999» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21385', '1079', '1', 'Bayandzürh', 'MN.13.6619000', 'ASCII:Bayandzuerh;ID:6619000', '19508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19508', '112', '21385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21386', '1079', '1', 'Alag-Erdene', 'MN.13.6619001', 'ASCII:Alag-Erdene;ID:6619001', '19509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19509', '112', '21386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21387', '1079', '1', 'Arbulag', 'MN.13.6619002', 'ASCII:Arbulag;ID:6619002', '19510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19510', '112', '21387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21388', '1079', '1', 'Tsagaan-Uul', 'MN.13.6619003', 'ASCII:Tsagaan-Uul;ID:6619003', '19511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19511', '112', '21388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21389', '1079', '1', 'Tsetserleg', 'MN.13.6619004', 'ASCII:Tsetserleg;ID:6619004', '19512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19512', '112', '21389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21390', '1079', '1', 'Mörön', 'MN.13.6619005', 'ASCII:Moeroen;ID:6619005', '19513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19513', '112', '21390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21391', '1079', '1', 'Bürentogtoh', 'MN.13.6619006', 'ASCII:Buerentogtoh;ID:6619006', '19514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19514', '112', '21391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21392', '1079', '1', 'Tömörbulag', 'MN.13.6619007', 'ASCII:Toemoerbulag;ID:6619007', '19515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19515', '112', '21392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21393', '1079', '1', 'Shine-Ider', 'MN.13.6619008', 'ASCII:Shine-Ider;ID:6619008', '19516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19516', '112', '21393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21394', '1079', '1', 'Galt', 'MN.13.6619009', 'ASCII:Galt;ID:6619009', '19517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19517', '112', '21394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21395', '1079', '1', 'Jargalant', 'MN.13.6619010', 'ASCII:Jargalant;ID:6619010', '19518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19518', '112', '21395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21396', '1079', '1', 'Tosontsengel', 'MN.13.6619011', 'ASCII:Tosontsengel;ID:6619011', '19519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19519', '112', '21396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21397', '1079', '1', 'Ih-Uul', 'MN.13.6619012', 'ASCII:Ih-Uul;ID:6619012', '19520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19520', '112', '21397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21398', '1079', '1', 'Rashaant', 'MN.13.6619013', 'ASCII:Rashaant;ID:6619013', '19521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19521', '112', '21398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21399', '1079', '1', 'Tünel', 'MN.13.6619014', 'ASCII:Tuenel;ID:6619014', '19522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19522', '112', '21399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21400', '1079', '1', 'Chandmanĭ-Öndör', 'MN.13.6619015', 'ASCII:Chandmani-OEndoer;ID:6619015', '19523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19523', '112', '21400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21401', '1079', '1', 'Tsagaan-Üür', 'MN.13.6619016', 'ASCII:Tsagaan-UEuer;ID:6619016', '19524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19524', '112', '21401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21402', '1079', '1', 'Erdenebulgan', 'MN.13.6619017', 'ASCII:Erdenebulgan;ID:6619017', '19525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19525', '112', '21402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21403', '1079', '1', 'Hanh', 'MN.13.6619018', 'ASCII:Hanh;ID:6619018', '19526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19526', '112', '21403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.13.6619018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21404', '1079', '1', 'Tsetserleg', 'MN.01.6619019', 'ASCII:Tsetserleg;ID:6619019', '19527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19527', '112', '21404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21405', '1079', '1', 'Jargalant', 'MN.01.6619020', 'ASCII:Jargalant;ID:6619020', '19528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19528', '112', '21405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21406', '1079', '1', 'Erdenemandal', 'MN.01.6619021', 'ASCII:Erdenemandal;ID:6619021', '19529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19529', '112', '21406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21407', '1079', '1', 'Hayrhan', 'MN.01.6619022', 'ASCII:Hayrhan;ID:6619022', '19530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19530', '112', '21407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21408', '1079', '1', 'Erdenebulgan', 'MN.01.6619023', 'ASCII:Erdenebulgan;ID:6619023', '19531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19531', '112', '21408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21409', '1079', '1', 'Ihtamir', 'MN.01.6619024', 'ASCII:Ihtamir;ID:6619024', '19532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19532', '112', '21409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21410', '1079', '1', 'Öndör-Ulaan', 'MN.01.6619025', 'ASCII:OEndoer-Ulaan;ID:6619025', '19533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19533', '112', '21410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21411', '1079', '1', 'Chuluut', 'MN.01.6619026', 'ASCII:Chuluut;ID:6619026', '19534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19534', '112', '21411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21412', '1079', '1', 'Hangay', 'MN.01.6619027', 'ASCII:Hangay;ID:6619027', '19535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19535', '112', '21412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21413', '1079', '1', 'Tsahir', 'MN.01.6619028', 'ASCII:Tsahir;ID:6619028', '19536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19536', '112', '21413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21414', '1079', '1', 'Bulgan', 'MN.01.6619029', 'ASCII:Bulgan;ID:6619029', '19537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19537', '112', '21414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21415', '1079', '1', 'Tsenher', 'MN.01.6619030', 'ASCII:Tsenher;ID:6619030', '19538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19538', '112', '21415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21416', '1079', '1', 'Tüvshrüüleh', 'MN.01.6619031', 'ASCII:Tuevshrueueleh;ID:6619031', '19539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19539', '112', '21416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21417', '1079', '1', 'Hotont', 'MN.01.6619032', 'ASCII:Hotont;ID:6619032', '19540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19540', '112', '21417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21418', '1079', '1', 'Hashaat', 'MN.01.6619033', 'ASCII:Hashaat;ID:6619033', '19541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19541', '112', '21418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21419', '1079', '1', 'Ögiynuur', 'MN.01.6619034', 'ASCII:OEgiynuur;ID:6619034', '19542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19542', '112', '21419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21420', '1079', '1', 'Battsengel', 'MN.01.6619035', 'ASCII:Battsengel;ID:6619035', '19543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19543', '112', '21420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21421', '1079', '1', 'Öldziyt', 'MN.01.6619036', 'ASCII:OEldziyt;ID:6619036', '19544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19544', '112', '21421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.01.6619036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21422', '1079', '1', 'Harhorin', 'MN.15.6619042', 'ASCII:Harhorin;ID:6619042', '19545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19545', '112', '21422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21423', '1079', '1', 'Hujirt', 'MN.15.6619043', 'ASCII:Hujirt;ID:6619043', '19546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19546', '112', '21423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21424', '1079', '1', 'Bat-Öldziy', 'MN.15.6619044', 'ASCII:Bat-OEldziy;ID:6619044', '19547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19547', '112', '21424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21425', '1079', '1', 'Uyanga', 'MN.15.6619045', 'ASCII:Uyanga;ID:6619045', '19548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19548', '112', '21425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21426', '1079', '1', 'Dzüünbayan-Ulaan', 'MN.15.6619046', 'ASCII:Dzueuenbayan-Ulaan;ID:6619046', '19549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19549', '112', '21426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619046» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21427', '1079', '1', 'Taragt', 'MN.15.6619047', 'ASCII:Taragt;ID:6619047', '19550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19550', '112', '21427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21428', '1079', '1', 'Arvayheer', 'MN.15.6619048', 'ASCII:Arvayheer;ID:6619048', '19551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19551', '112', '21428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21429', '1079', '1', 'Hayrhandulaan', 'MN.15.6619049', 'ASCII:Hayrhandulaan;ID:6619049', '19552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19552', '112', '21429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21430', '1079', '1', 'Nariynteel', 'MN.15.6619050', 'ASCII:Nariynteel;ID:6619050', '19553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19553', '112', '21430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21431', '1079', '1', 'Baruunbayan-Ulaan', 'MN.15.6619051', 'ASCII:Baruunbayan-Ulaan;ID:6619051', '19554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19554', '112', '21431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21432', '1079', '1', 'Guchin-Us', 'MN.15.6619052', 'ASCII:Guchin-Us;ID:6619052', '19555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19555', '112', '21432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21433', '1079', '1', 'Bogd', 'MN.15.6619053', 'ASCII:Bogd;ID:6619053', '19556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19556', '112', '21433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21434', '1079', '1', 'Tögrög', 'MN.15.6619054', 'ASCII:Toegroeg;ID:6619054', '19557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19557', '112', '21434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21435', '1079', '1', 'Bayangol', 'MN.15.6619056', 'ASCII:Bayangol;ID:6619056', '19558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19558', '112', '21435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21436', '1079', '1', 'Sant', 'MN.15.6619057', 'ASCII:Sant;ID:6619057', '19559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19559', '112', '21436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21437', '1079', '1', 'Bayan-Öndör', 'MN.15.6619058', 'ASCII:Bayan-OEndoer;ID:6619058', '19560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19560', '112', '21437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21438', '1079', '1', 'Öldziyt', 'MN.15.6619059', 'ASCII:OEldziyt;ID:6619059', '19561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19561', '112', '21438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21439', '1079', '1', 'Yösöndzüyl', 'MN.15.6619060', 'ASCII:Yoesoendzueyl;ID:6619060', '19562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19562', '112', '21439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21440', '1079', '1', 'Bürd', 'MN.15.6619061', 'ASCII:Buerd;ID:6619061', '19563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19563', '112', '21440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.15.6619061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21441', '1079', '1', 'Dzag', 'MN.02.6619062', 'ASCII:Dzag;ID:6619062', '19564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19564', '112', '21441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21442', '1079', '1', 'Gurvanbulag', 'MN.02.6619063', 'ASCII:Gurvanbulag;ID:6619063', '19565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19565', '112', '21442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21443', '1079', '1', 'Jargalant', 'MN.02.6619064', 'ASCII:Jargalant;ID:6619064', '19566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19566', '112', '21443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21444', '1079', '1', 'Bayanbulag', 'MN.02.6619065', 'ASCII:Bayanbulag;ID:6619065', '19567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19567', '112', '21444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21445', '1079', '1', 'Bayantsagaan', 'MN.02.6619066', 'ASCII:Bayantsagaan;ID:6619066', '19568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19568', '112', '21445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21446', '1079', '1', 'Hüreemaral', 'MN.02.6619067', 'ASCII:Huereemaral;ID:6619067', '19569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19569', '112', '21446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21447', '1079', '1', 'Buutsagaan', 'MN.02.6619068', 'ASCII:Buutsagaan;ID:6619068', '19570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19570', '112', '21447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21448', '1079', '1', 'Bömbögör', 'MN.02.6619069', 'ASCII:Boemboegoer;ID:6619069', '19571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19571', '112', '21448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21449', '1079', '1', 'Bayan-Ovoo', 'MN.02.6619070', 'ASCII:Bayan-Ovoo;ID:6619070', '19572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19572', '112', '21449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21450', '1079', '1', 'Galuut', 'MN.02.6619071', 'ASCII:Galuut;ID:6619071', '19573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19573', '112', '21450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21451', '1079', '1', 'Erdenetsogt', 'MN.02.6619072', 'ASCII:Erdenetsogt;ID:6619072', '19574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19574', '112', '21451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21452', '1079', '1', 'Bayanhongor', 'MN.02.6619073', 'ASCII:Bayanhongor;ID:6619073', '19575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19575', '112', '21452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21453', '1079', '1', 'Öldziyt', 'MN.02.6619074', 'ASCII:OEldziyt;ID:6619074', '19576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19576', '112', '21453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21454', '1079', '1', 'Jinst', 'MN.02.6619075', 'ASCII:Jinst;ID:6619075', '19577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19577', '112', '21454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21455', '1079', '1', 'Bogd', 'MN.02.6619076', 'ASCII:Bogd;ID:6619076', '19578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19578', '112', '21455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21456', '1079', '1', 'Bayangovĭ', 'MN.02.6619077', 'ASCII:Bayangovi;ID:6619077', '19579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19579', '112', '21456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21457', '1079', '1', 'Bayanlig', 'MN.02.6619078', 'ASCII:Bayanlig;ID:6619078', '19580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19580', '112', '21457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21458', '1079', '1', 'Baatsagaan', 'MN.02.6619079', 'ASCII:Baatsagaan;ID:6619079', '19581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19581', '112', '21458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21459', '1079', '1', 'Bayan-Öndör', 'MN.02.6619080', 'ASCII:Bayan-OEndoer;ID:6619080', '19582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19582', '112', '21459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21460', '1079', '1', 'Shinejinst', 'MN.02.6619081', 'ASCII:Shinejinst;ID:6619081', '19583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19583', '112', '21460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.02.6619081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21461', '1079', '1', 'Höhmorĭt', 'MN.10.6619082', 'ASCII:Hoehmorit;ID:6619082', '19584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19584', '112', '21461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21462', '1079', '1', 'Bayan-Uul', 'MN.10.6619083', 'ASCII:Bayan-Uul;ID:6619083', '19585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19585', '112', '21462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21463', '1079', '1', 'Jargalan', 'MN.10.6619084', 'ASCII:Jargalan;ID:6619084', '19586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19586', '112', '21463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21464', '1079', '1', 'Tayshir', 'MN.10.6619085', 'ASCII:Tayshir;ID:6619085', '19587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19587', '112', '21464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21465', '1079', '1', 'Delger', 'MN.10.6619086', 'ASCII:Delger;ID:6619086', '19588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19588', '112', '21465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21466', '1079', '1', 'Sharga', 'MN.10.6619087', 'ASCII:Sharga;ID:6619087', '19589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19589', '112', '21466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21467', '1079', '1', 'Darvi', 'MN.10.6619088', 'ASCII:Darvi;ID:6619088', '19590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19590', '112', '21467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21468', '1079', '1', 'Tonhil', 'MN.10.6619089', 'ASCII:Tonhil;ID:6619089', '19591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19591', '112', '21468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21469', '1079', '1', 'Tögrög', 'MN.10.6619090', 'ASCII:Toegroeg;ID:6619090', '19592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19592', '112', '21469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21470', '1079', '1', 'Bugat', 'MN.10.6619091', 'ASCII:Bugat;ID:6619091', '19593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19593', '112', '21470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21471', '1079', '1', 'Yösönbulag', 'MN.10.6619092', 'ASCII:Yoesoenbulag;ID:6619092', '19594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19594', '112', '21471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21472', '1079', '1', 'Haliun', 'MN.10.6619093', 'ASCII:Haliun;ID:6619093', '19595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19595', '112', '21472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21473', '1079', '1', 'Tseel', 'MN.10.6619094', 'ASCII:Tseel;ID:6619094', '19596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19596', '112', '21473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21474', '1079', '1', 'Altay', 'MN.10.6619095', 'ASCII:Altay;ID:6619095', '19597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19597', '112', '21474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21475', '1079', '1', 'Tsogt', 'MN.10.6619096', 'ASCII:Tsogt;ID:6619096', '19598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19598', '112', '21475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21476', '1079', '1', 'Biger', 'MN.10.6619097', 'ASCII:Biger;ID:6619097', '19599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19599', '112', '21476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21477', '1079', '1', 'Chandmanĭ', 'MN.10.6619098', 'ASCII:Chandmani;ID:6619098', '19600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19600', '112', '21477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21478', '1079', '1', 'Erdene', 'MN.10.6619099', 'ASCII:Erdene;ID:6619099', '19601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19601', '112', '21478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21479', '1079', '1', 'Erdenebüren', 'MN.12.6619109', 'ASCII:Erdenebueren;ID:6619109', '19602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19602', '112', '21479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21480', '1079', '1', 'Buyant', 'MN.12.6619110', 'ASCII:Buyant;ID:6619110', '19603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19603', '112', '21480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21481', '1079', '1', 'Myangad', 'MN.12.6619111', 'ASCII:Myangad;ID:6619111', '19604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19604', '112', '21481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21482', '1079', '1', 'Jargalant', 'MN.12.6619113', 'ASCII:Jargalant;ID:6619113', '19605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19605', '112', '21482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21483', '1079', '1', 'Hovd', 'MN.12.6619115', 'ASCII:Hovd;ID:6619115', '19606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19606', '112', '21483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21484', '1079', '1', 'Duut', 'MN.12.6619116', 'ASCII:Duut;ID:6619116', '19607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19607', '112', '21484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21485', '1079', '1', 'Manhan', 'MN.12.6619117', 'ASCII:Manhan;ID:6619117', '19608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19608', '112', '21485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21486', '1079', '1', 'Dzereg', 'MN.12.6619118', 'ASCII:Dzereg;ID:6619118', '19609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19609', '112', '21486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21487', '1079', '1', 'Mönhhayrhan', 'MN.12.6619119', 'ASCII:Moenhhayrhan;ID:6619119', '19610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19610', '112', '21487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21488', '1079', '1', 'Chandmanĭ', 'MN.12.6619120', 'ASCII:Chandmani;ID:6619120', '19611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19611', '112', '21488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21489', '1079', '1', 'Darvi', 'MN.12.6619121', 'ASCII:Darvi;ID:6619121', '19612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19612', '112', '21489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21490', '1079', '1', 'Tsetseg', 'MN.12.6619122', 'ASCII:Tsetseg;ID:6619122', '19613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19613', '112', '21490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21491', '1079', '1', 'Möst', 'MN.12.6619123', 'ASCII:Moest;ID:6619123', '19614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19614', '112', '21491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21492', '1079', '1', 'Üyönch', 'MN.12.6619124', 'ASCII:UEyoench;ID:6619124', '19615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19615', '112', '21492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21493', '1079', '1', 'Bulgan', 'MN.12.6619125', 'ASCII:Bulgan;ID:6619125', '19616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19616', '112', '21493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21494', '1079', '1', 'Altay', 'MN.12.6619126', 'ASCII:Altay;ID:6619126', '19617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19617', '112', '21494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.12.6619126» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21495', '1079', '1', 'Tsagaannuur', 'MN.03.6619140', 'ASCII:Tsagaannuur;ID:6619140', '19618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19618', '112', '21495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21496', '1079', '1', 'Nogoonnuur', 'MN.03.6619141', 'ASCII:Nogoonnuur;ID:6619141', '19619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19619', '112', '21496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21497', '1079', '1', 'Ulaanhus', 'MN.03.6619142', 'ASCII:Ulaanhus;ID:6619142', '19620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19620', '112', '21497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619142» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21498', '1079', '1', 'Tsengel', 'MN.03.6619143', 'ASCII:Tsengel;ID:6619143', '19621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19621', '112', '21498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21499', '1079', '1', 'Sagsay', 'MN.03.6619144', 'ASCII:Sagsay;ID:6619144', '19622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19622', '112', '21499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21500', '1079', '1', 'Bugat', 'MN.03.6619145', 'ASCII:Bugat;ID:6619145', '19623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19623', '112', '21500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21501', '1079', '1', 'Ölgiy', 'MN.03.6619146', 'ASCII:OElgiy;ID:6619146', '19624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19624', '112', '21501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619146» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21502', '1079', '1', 'Altantsögts', 'MN.03.6619147', 'ASCII:Altantsoegts;ID:6619147', '19625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19625', '112', '21502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21503', '1079', '1', 'Tolbo', 'MN.03.6619149', 'ASCII:Tolbo;ID:6619149', '19626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19626', '112', '21503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21504', '1079', '1', 'Altay', 'MN.03.6619150', 'ASCII:Altay;ID:6619150', '19627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19627', '112', '21504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21505', '1079', '1', 'Buyant', 'MN.03.6619151', 'ASCII:Buyant;ID:6619151', '19628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19628', '112', '21505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21506', '1079', '1', 'Delüün', 'MN.03.6619152', 'ASCII:Delueuen;ID:6619152', '19629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19629', '112', '21506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21507', '1079', '1', 'Bulgan', 'MN.03.6619153', 'ASCII:Bulgan;ID:6619153', '19630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19630', '112', '21507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.03.6619153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21508', '1079', '1', 'Davst', 'MN.19.6619154', 'ASCII:Davst;ID:6619154', '19631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19631', '112', '21508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21509', '1079', '1', 'Sagil', 'MN.19.6619155', 'ASCII:Sagil;ID:6619155', '19632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19632', '112', '21509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21510', '1079', '1', 'Türgen', 'MN.19.6619156', 'ASCII:Tuergen;ID:6619156', '19633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19633', '112', '21510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21511', '1079', '1', 'Tarialan', 'MN.19.6619157', 'ASCII:Tarialan;ID:6619157', '19634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19634', '112', '21511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21512', '1079', '1', 'Ulaangom', 'MN.19.6619158', 'ASCII:Ulaangom;ID:6619158', '19635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19635', '112', '21512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21513', '1079', '1', 'Naranbulag', 'MN.19.6619159', 'ASCII:Naranbulag;ID:6619159', '19636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19636', '112', '21513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21514', '1079', '1', 'Ölgiy', 'MN.19.6619160', 'ASCII:OElgiy;ID:6619160', '19637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19637', '112', '21514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21515', '1079', '1', 'Ömnögovĭ', 'MN.19.6619161', 'ASCII:OEmnoegovi;ID:6619161', '19638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19638', '112', '21515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21516', '1079', '1', 'Hovd', 'MN.19.6619162', 'ASCII:Hovd;ID:6619162', '19639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19639', '112', '21516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619162» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21517', '1079', '1', 'Böhmörön', 'MN.19.6619163', 'ASCII:Boehmoeroen;ID:6619163', '19640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19640', '112', '21517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21518', '1079', '1', 'Tes', 'MN.19.6619164', 'ASCII:Tes;ID:6619164', '19641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19641', '112', '21518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21519', '1079', '1', 'Dzüüngovĭ', 'MN.19.6619165', 'ASCII:Dzueuengovi;ID:6619165', '19642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19642', '112', '21519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21520', '1079', '1', 'Malchin', 'MN.19.6619166', 'ASCII:Malchin;ID:6619166', '19643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19643', '112', '21520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21521', '1079', '1', 'Dzavhan', 'MN.19.6619167', 'ASCII:Dzavhan;ID:6619167', '19644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19644', '112', '21521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21522', '1079', '1', 'Hyargas', 'MN.19.6619168', 'ASCII:Hyargas;ID:6619168', '19645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19645', '112', '21522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21523', '1079', '1', 'Tsagaanhayrhan', 'MN.19.6619169', 'ASCII:Tsagaanhayrhan;ID:6619169', '19646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19646', '112', '21523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21524', '1079', '1', 'Baruunturuun', 'MN.19.6619170', 'ASCII:Baruunturuun;ID:6619170', '19647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19647', '112', '21524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21525', '1079', '1', 'Öndörhangay', 'MN.19.6619171', 'ASCII:OEndoerhangay;ID:6619171', '19648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19648', '112', '21525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21526', '1079', '1', 'Dzüünhangay', 'MN.19.6619172', 'ASCII:Dzueuenhangay;ID:6619172', '19649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19649', '112', '21526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.19.6619172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21527', '1079', '1', 'Bayantes', 'MN.09.6619214', 'ASCII:Bayantes;ID:6619214', '19650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19650', '112', '21527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21528', '1079', '1', 'Tes', 'MN.09.6619215', 'ASCII:Tes;ID:6619215', '19651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19651', '112', '21528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21529', '1079', '1', 'Asgat', 'MN.09.6619216', 'ASCII:Asgat;ID:6619216', '19652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19652', '112', '21529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21530', '1079', '1', 'Bayanhayrhan', 'MN.09.6619217', 'ASCII:Bayanhayrhan;ID:6619217', '19653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19653', '112', '21530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21531', '1079', '1', 'Tüdevtey', 'MN.09.6619218', 'ASCII:Tuedevtey;ID:6619218', '19654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19654', '112', '21531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21532', '1079', '1', 'Tsetsen-Uul', 'MN.09.6619220', 'ASCII:Tsetsen-Uul;ID:6619220', '19655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19655', '112', '21532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619220» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21533', '1079', '1', 'Nömrög', 'MN.09.6619221', 'ASCII:Noemroeg;ID:6619221', '19656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19656', '112', '21533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21534', '1079', '1', 'Santmargats', 'MN.09.6619222', 'ASCII:Santmargats;ID:6619222', '19657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19657', '112', '21534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21535', '1079', '1', 'Urgamal', 'MN.09.6619223', 'ASCII:Urgamal;ID:6619223', '19658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19658', '112', '21535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21536', '1079', '1', 'Dzavhanmandal', 'MN.09.6619224', 'ASCII:Dzavhanmandal;ID:6619224', '19659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19659', '112', '21536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21537', '1079', '1', 'Dörvöljin', 'MN.10.6619225', 'ASCII:Doervoeljin;ID:6619225', '19660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19660', '112', '21537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.10.6619225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21538', '1079', '1', 'Erdenehayrhan', 'MN.09.6619226', 'ASCII:Erdenehayrhan;ID:6619226', '19661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19661', '112', '21538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21539', '1079', '1', 'Uliastay', 'MN.09.6619227', 'ASCII:Uliastay;ID:6619227', '19662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19662', '112', '21539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21540', '1079', '1', 'Aldarhaan', 'MN.09.6619228', 'ASCII:Aldarhaan;ID:6619228', '19663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19663', '112', '21540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21541', '1079', '1', 'Yaruu', 'MN.09.6619229', 'ASCII:Yaruu;ID:6619229', '19664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19664', '112', '21541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21542', '1079', '1', 'Tsagaanhayrhan', 'MN.09.6619230', 'ASCII:Tsagaanhayrhan;ID:6619230', '19665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19665', '112', '21542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21543', '1079', '1', 'Tsagaanchuluut', 'MN.09.6619231', 'ASCII:Tsagaanchuluut;ID:6619231', '19666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19666', '112', '21543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21544', '1079', '1', 'Shilüüstey', 'MN.09.6619232', 'ASCII:Shilueuestey;ID:6619232', '19667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19667', '112', '21544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619232» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21545', '1079', '1', 'Otgon', 'MN.09.6619233', 'ASCII:Otgon;ID:6619233', '19668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19668', '112', '21545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21546', '1079', '1', 'Ider', 'MN.09.6619234', 'ASCII:Ider;ID:6619234', '19669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19669', '112', '21546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21547', '1079', '1', 'Telmen', 'MN.09.6619235', 'ASCII:Telmen;ID:6619235', '19670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19670', '112', '21547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21548', '1079', '1', 'Tosontsengel', 'MN.09.6619236', 'ASCII:Tosontsengel;ID:6619236', '19671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19671', '112', '21548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619236» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21549', '1079', '1', 'Ih-Uul', 'MN.09.6619238', 'ASCII:Ih-Uul;ID:6619238', '19672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19672', '112', '21549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MN.09.6619238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21550', '1079', '1', 'Département de La Martinique', 'MQ.MQ.972', 'ASCII:Departement de La Martinique;ID:6690604', '19673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19673', '112', '21550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MQ.MQ.972» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21551', '1079', '1', 'Langkawi', 'MY.00.1222381', 'ASCII:Langkawi;ID:1222381', '19674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19674', '112', '21551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.00.1222381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21552', '1079', '1', 'Bahagian Pantai Barat', 'MY.16.1732562', 'ASCII:Bahagian Pantai Barat;ID:1732562', '19675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19675', '112', '21552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.16.1732562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21553', '1079', '1', 'Temerluh', 'MY.00.1732585', 'ASCII:Temerluh;ID:1732585', '19676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19676', '112', '21553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.00.1732585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21554', '1079', '1', 'Daerah Kuala Selangor', 'MY.00.1732890', 'ASCII:Daerah Kuala Selangor;ID:1732890', '19677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19677', '112', '21554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.00.1732890» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21555', '1079', '1', 'Daerah Klang', 'MY.12.1732904', 'ASCII:Daerah Klang;ID:1732904', '19678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19678', '112', '21555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.12.1732904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21556', '1079', '1', 'Bahagian Sandakan', 'MY.16.1733564', 'ASCII:Bahagian Sandakan;ID:1733564', '19679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19679', '112', '21556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.16.1733564» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21557', '1079', '1', 'Bahagian Tawau', 'MY.16.1733595', 'ASCII:Bahagian Tawau;ID:1733595', '19680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19680', '112', '21557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.16.1733595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21558', '1079', '1', 'Bahagian Pedalaman', 'MY.16.1734148', 'ASCII:Bahagian Pedalaman;ID:1734148', '19681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19681', '112', '21558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.16.1734148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21559', '1079', '1', 'Kulim', 'MY.02.1734392', 'ASCII:Kulim;ID:1734392', '19682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19682', '112', '21559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.1734392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21560', '1079', '1', 'Larut Matang & Selama', 'MY.07.1734400', 'ASCII:Larut Matang & Selama;ID:1734400', '19683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19683', '112', '21560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.07.1734400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21561', '1079', '1', 'Bandar Baharu', 'MY.02.1734406', 'ASCII:Bandar Baharu;ID:1734406', '19684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19684', '112', '21561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.1734406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21562', '1079', '1', 'Baling', 'MY.02.1734449', 'ASCII:Baling;ID:1734449', '19685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19685', '112', '21562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.1734449» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21563', '1079', '1', 'Daerah Tanah Merah', 'MY.03.1734461', 'ASCII:Daerah Tanah Merah;ID:1734461', '19686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19686', '112', '21563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.03.1734461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21564', '1079', '1', 'Bahagian Kuching', 'MY.11.1734504', 'ASCII:Bahagian Kuching;ID:1734504', '19687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19687', '112', '21564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.11.1734504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21565', '1079', '1', 'Daerah Kuala Langat', 'MY.12.1734782', 'ASCII:Daerah Kuala Langat;ID:1734782', '19688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19688', '112', '21565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.12.1734782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21566', '1079', '1', 'Daerah Sepang', 'MY.00.1734789', 'ASCII:Daerah Sepang;ID:1734789', '19689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19689', '112', '21566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.00.1734789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21567', '1079', '1', 'Daerha Rompin', 'MY.00.1734905', 'ASCII:Daerha Rompin;ID:1734905', '19690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19690', '112', '21567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.00.1734905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21568', '1079', '1', 'Bera', 'MY.00.1734988', 'ASCII:Bera;ID:1734988', '19691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19691', '112', '21568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.00.1734988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21569', '1079', '1', 'Selatan', 'MY.09.1735085', 'ASCII:Selatan;ID:1735085', '19692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19692', '112', '21569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.09.1735085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21570', '1079', '1', 'Daerah Timur Laut', 'MY.09.1735104', 'ASCII:Daerah Timur Laut;ID:1735104', '19693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19693', '112', '21570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.09.1735104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21571', '1079', '1', 'Daerah Gombak', 'MY.00.1735136', 'ASCII:Daerah Gombak;ID:1735136', '19694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19694', '112', '21571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.00.1735136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21572', '1079', '1', 'Daerah Hulu Selangor', 'MY.12.1735145', 'ASCII:Daerah Hulu Selangor;ID:1735145', '19695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19695', '112', '21572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.12.1735145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21573', '1079', '1', 'Petaling', 'MY.12.1735156', 'ASCII:Petaling;ID:1735156', '19696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19696', '112', '21573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.12.1735156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21574', '1079', '1', 'Daerah Sabak Bernam', 'MY.12.1735194', 'ASCII:Daerah Sabak Bernam;ID:1735194', '19697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19697', '112', '21574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.12.1735194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21575', '1079', '1', 'Daerah Jerantut', 'MY.00.1735203', 'ASCII:Daerah Jerantut;ID:1735203', '19698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19698', '112', '21575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.00.1735203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21576', '1079', '1', 'Daerah Barat Daya', 'MY.00.1735411', 'ASCII:Daerah Barat Daya;ID:1735411', '19699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19699', '112', '21576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.00.1735411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21577', '1079', '1', 'Yan', 'MY.02.1735487', 'ASCII:Yan;ID:1735487', '19700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19700', '112', '21577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.1735487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21578', '1079', '1', 'Bahagian Sarikei', 'MY.11.1735861', 'ASCII:Bahagian Sarikei;ID:1735861', '19701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19701', '112', '21578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.11.1735861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21579', '1079', '1', 'Daerah Kubang Pasu', 'MY.02.1736296', 'ASCII:Daerah Kubang Pasu;ID:1736296', '19702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19702', '112', '21579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.1736296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21580', '1079', '1', 'Padang Terap', 'MY.02.1736333', 'ASCII:Padang Terap;ID:1736333', '19703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19703', '112', '21580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.1736333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21581', '1079', '1', 'Pendang', 'MY.00.1736341', 'ASCII:Pendang;ID:1736341', '19704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19704', '112', '21581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.00.1736341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21582', '1079', '1', 'Kota Setar', 'MY.02.1736342', 'ASCII:Kota Setar;ID:1736342', '19705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19705', '112', '21582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.1736342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21583', '1079', '1', 'Bahagian Pantai Barat', 'MY.16.1736645', 'ASCII:Bahagian Pantai Barat;ID:1736645', '19706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19706', '112', '21583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.16.1736645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21584', '1079', '1', 'Bahagian Sri Aman', 'MY.11.1736901', 'ASCII:Bahagian Sri Aman;ID:1736901', '19707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19707', '112', '21584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.11.1736901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21585', '1079', '1', 'Bahagian Sibu', 'MY.11.1736980', 'ASCII:Bahagian Sibu;ID:1736980', '19708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19708', '112', '21585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.11.1736980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21586', '1079', '1', 'Bahagian Limbang', 'MY.11.1737785', 'ASCII:Bahagian Limbang;ID:1737785', '19709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19709', '112', '21586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.11.1737785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21587', '1079', '1', 'Bahagian Kapit', 'MY.11.1737860', 'ASCII:Bahagian Kapit;ID:1737860', '19710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19710', '112', '21587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.11.1737860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21588', '1079', '1', 'Bahagian Miri', 'MY.11.1738079', 'ASCII:Bahagian Miri;ID:1738079', '19711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19711', '112', '21588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.11.1738079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21589', '1079', '1', 'Bahagian Kudat', 'MY.16.1966738', 'ASCII:Bahagian Kudat;ID:1966738', '19712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19712', '112', '21589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.16.1966738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21590', '1079', '1', 'Bahagian Bintulu', 'MY.11.1966740', 'ASCII:Bahagian Bintulu;ID:1966740', '19713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19713', '112', '21590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.11.1966740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21591', '1079', '1', 'Bahagian Samarahan', 'MY.11.1966741', 'ASCII:Bahagian Samarahan;ID:1966741', '19714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19714', '112', '21591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.11.1966741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21592', '1079', '1', 'Kuala Muda', 'MY.02.6805171', 'ASCII:Kuala Muda;ID:6805171', '19715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19715', '112', '21592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.6805171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21593', '1079', '1', 'Kota Setar', 'MY.02.6807221', 'ASCII:Kota Setar;ID:6807221', '19716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19716', '112', '21593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.6807221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21594', '1079', '1', 'Utara', 'MY.09.6823231', 'ASCII:Utara;ID:6823231', '19717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19717', '112', '21594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.09.6823231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21595', '1079', '1', 'Barat Daya', 'MY.09.6833194', 'ASCII:Barat Daya;ID:6833194', '19718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19718', '112', '21595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.09.6833194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21596', '1079', '1', 'Naga Lilit', 'MY.02.6857715', 'ASCII:Naga Lilit;ID:6857715', '19719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19719', '112', '21596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.6857715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21597', '1079', '1', 'Bagan Sena', 'MY.02.6857718', 'ASCII:Bagan Sena;ID:6857718', '19720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19720', '112', '21597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.6857718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21598', '1079', '1', 'Bakai', 'MY.02.6857723', 'ASCII:Bakai;ID:6857723', '19721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19721', '112', '21598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.6857723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21599', '1079', '1', 'Mahang', 'MY.02.6857732', 'ASCII:Mahang;ID:6857732', '19722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19722', '112', '21599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MY.02.6857732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21600', '1079', '1', 'Circunscrição de Mungári', 'MZ.00.1035732', 'ASCII:Circunscricao de Mungari;ID:1035732', '19723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19723', '112', '21600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MZ.00.1035732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21601', '1079', '1', 'Distrito de Manjacaze', 'MZ.00.1040936', 'ASCII:Distrito de Manjacaze;ID:1040936', '19724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19724', '112', '21601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «MZ.00.1040936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21602', '1079', '1', 'Circonscription de La Foa', 'NC.00.2140464', 'ASCII:Circonscription de La Foa;ID:2140464', '19725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19725', '112', '21602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NC.00.2140464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21603', '1079', '1', 'Circonscription de Koumac', 'NC.00.2140556', 'ASCII:Circonscription de Koumac;ID:2140556', '19726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19726', '112', '21603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NC.00.2140556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21604', '1079', '1', 'KonéCirconscription de', 'NC.00.2140685', 'ASCII:KoneCirconscription de;ID:2140685', '19727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19727', '112', '21604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NC.00.2140685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21605', '1079', '1', 'Circonscription de Bourail', 'NC.00.2141713', 'ASCII:Circonscription de Bourail;ID:2141713', '19728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19728', '112', '21605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NC.00.2141713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21606', '1079', '1', 'Arrondissement de Tillabéri', 'NE.08.2438677', 'ASCII:Arrondissement de Tillaberi;ID:2438677', '19729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19729', '112', '21606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.08.2438677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21607', '1079', '1', 'Arrondissement de Tessaoua', 'NE.04.2438821', 'ASCII:Arrondissement de Tessaoua;ID:2438821', '19730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19730', '112', '21607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.04.2438821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21608', '1079', '1', 'Arrondissement de Téra', 'NE.08.2438854', 'ASCII:Arrondissement de Tera;ID:2438854', '19731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19731', '112', '21608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.08.2438854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21609', '1079', '1', 'Arrondissement de Tchin-Tabaraden', 'NE.06.2438973', 'ASCII:Arrondissement de Tchin-Tabaraden;ID:2438973', '19732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19732', '112', '21609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.06.2438973» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21610', '1079', '1', 'Arrondissement de Tânout', 'NE.07.2439154', 'ASCII:Arrondissement de Tanout;ID:2439154', '19733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19733', '112', '21610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.07.2439154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21611', '1079', '1', 'Arrondissement de Tahoua', 'NE.06.2439375', 'ASCII:Arrondissement de Tahoua;ID:2439375', '19734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19734', '112', '21611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.06.2439375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21612', '1079', '1', 'Arrondissement de Say', 'NE.08.2439811', 'ASCII:Arrondissement de Say;ID:2439811', '19735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19735', '112', '21612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.08.2439811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21613', '1079', '1', 'Arrondissement de Ouallam', 'NE.08.2440370', 'ASCII:Arrondissement de Ouallam;ID:2440370', '19736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19736', '112', '21613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.08.2440370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21614', '1079', '1', 'Arrondissement de Niamey', 'NE.08.2440482', 'ASCII:Arrondissement de Niamey;ID:2440482', '19737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19737', '112', '21614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.08.2440482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21615', '1079', '1', 'Arrondissement de Nguigmi', 'NE.02.2440494', 'ASCII:Arrondissement de Nguigmi;ID:2440494', '19738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19738', '112', '21615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.02.2440494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21616', '1079', '1', 'Arrondissement de Mirria', 'NE.07.2440920', 'ASCII:Arrondissement de Mirria;ID:2440920', '19739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19739', '112', '21616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.07.2440920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21617', '1079', '1', 'Arrondissement de Mayahi', 'NE.04.2441193', 'ASCII:Arrondissement de Mayahi;ID:2441193', '19740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19740', '112', '21617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.04.2441193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21618', '1079', '1', 'Arrondissement de Matameye', 'NE.07.2441216', 'ASCII:Arrondissement de Matameye;ID:2441216', '19741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19741', '112', '21618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.07.2441216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21619', '1079', '1', 'Arrondissement de Maradi', 'NE.04.2441290', 'ASCII:Arrondissement de Maradi;ID:2441290', '19742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19742', '112', '21619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.04.2441290» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21620', '1079', '1', 'Arrondissement de Maïné-Soroa', 'NE.02.2441446', 'ASCII:Arrondissement de Maine-Soroa;ID:2441446', '19743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19743', '112', '21620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.02.2441446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21621', '1079', '1', 'Arrondissement de Magaria', 'NE.07.2441474', 'ASCII:Arrondissement de Magaria;ID:2441474', '19744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19744', '112', '21621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.07.2441474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21622', '1079', '1', 'Arrondissement de Madaoua', 'NE.06.2441528', 'ASCII:Arrondissement de Madaoua;ID:2441528', '19745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19745', '112', '21622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.06.2441528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21623', '1079', '1', 'Arrondissement de Loga', 'NE.03.2441629', 'ASCII:Arrondissement de Loga;ID:2441629', '19746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19746', '112', '21623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.03.2441629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21624', '1079', '1', 'Arrondissement de Keïta', 'NE.06.2442477', 'ASCII:Arrondissement de Keita;ID:2442477', '19747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19747', '112', '21624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.06.2442477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21625', '1079', '1', 'Arrondissement d'' Illéla', 'NE.06.2443303', 'ASCII:Arrondissement d'' Illela;ID:2443303', '19748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19748', '112', '21625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.06.2443303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21626', '1079', '1', 'Arrondissement de Gouré', 'NE.07.2444218', 'ASCII:Arrondissement de Goure;ID:2444218', '19749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19749', '112', '21626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.07.2444218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21627', '1079', '1', 'Arrondissement de Gaya', 'NE.03.2444487', 'ASCII:Arrondissement de Gaya;ID:2444487', '19750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19750', '112', '21627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.03.2444487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21628', '1079', '1', 'Arrondissement de Filingué', 'NE.08.2444994', 'ASCII:Arrondissement de Filingue;ID:2444994', '19751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19751', '112', '21628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.08.2444994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21629', '1079', '1', 'Arrondissement de Dosso', 'NE.03.2445487', 'ASCII:Arrondissement de Dosso;ID:2445487', '19752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19752', '112', '21629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.03.2445487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21630', '1079', '1', 'Arrondissement de Dogondoutchi', 'NE.03.2445552', 'ASCII:Arrondissement de Dogondoutchi;ID:2445552', '19753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19753', '112', '21630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.03.2445552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21631', '1079', '1', 'Arrondissement de Diffa', 'NE.02.2445703', 'ASCII:Arrondissement de Diffa;ID:2445703', '19754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19754', '112', '21631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.02.2445703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21632', '1079', '1', 'Arrondissement de Dakoro', 'NE.04.2446266', 'ASCII:Arrondissement de Dakoro;ID:2446266', '19755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19755', '112', '21632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.04.2446266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21633', '1079', '1', 'Arrondissement de Bouza', 'NE.06.2446465', 'ASCII:Arrondissement de Bouza;ID:2446465', '19756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19756', '112', '21633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.06.2446465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21634', '1079', '1', 'Arrondissement du Boboye', 'NE.03.2446715', 'ASCII:Arrondissement du Boboye;ID:2446715', '19757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19757', '112', '21634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.03.2446715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21635', '1079', '1', 'Arrondissement de Birni Nkonni', 'NE.06.2446752', 'ASCII:Arrondissement de Birni Nkonni;ID:2446752', '19758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19758', '112', '21635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.06.2446752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21636', '1079', '1', 'Arrondissement de Bilma', 'NE.01.2446795', 'ASCII:Arrondissement de Bilma;ID:2446795', '19759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19759', '112', '21636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.01.2446795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21637', '1079', '1', 'Arrondissement d'' Agadez', 'NE.01.2448084', 'ASCII:Arrondissement d'' Agadez;ID:2448084', '19760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19760', '112', '21637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NE.01.2448084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21638', '1079', '1', 'Owerri Division', 'NG.28.2325327', 'ASCII:Owerri Division;ID:2325327', '19761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19761', '112', '21638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NG.28.2325327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21639', '1079', '1', 'Jos Division', 'NG.00.2335951', 'ASCII:Jos Division;ID:2335951', '19762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19762', '112', '21639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NG.00.2335951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21640', '1079', '1', 'Ekiti Division', 'NG.00.2343699', 'ASCII:Ekiti Division;ID:2343699', '19763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19763', '112', '21640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NG.00.2343699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21641', '1079', '1', 'Municipio de Wiwilí', 'NI.13.3615682', 'ASCII:Municipio de Wiwili;ID:3615682', '19764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19764', '112', '21641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.13.3615682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21642', '1079', '1', 'Municipio de Villa Sandino', 'NI.04.3615812', 'ASCII:Municipio de Villa Sandino;ID:3615812', '19765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19765', '112', '21642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.04.3615812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21643', '1079', '1', 'Municipio de Villa Nueva', 'NI.03.3615816', 'ASCII:Municipio de Villa Nueva;ID:3615816', '19766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19766', '112', '21643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.03.3615816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21644', '1079', '1', 'Municipio de Santo Tomás del Norte', 'NI.03.3616345', 'ASCII:Municipio de Santo Tomas del Norte;ID:3616345', '19767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19767', '112', '21644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.03.3616345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21645', '1079', '1', 'Municipio de San Pedro del Norte', 'NI.03.3616610', 'ASCII:Municipio de San Pedro del Norte;ID:3616610', '19768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19768', '112', '21645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.03.3616610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21646', '1079', '1', 'Municipio de San Juan del Sur', 'NI.15.3616724', 'ASCII:Municipio de San Juan del Sur;ID:3616724', '19769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19769', '112', '21646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.15.3616724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21647', '1079', '1', 'Municipio de San José de los Remates', 'NI.01.3616752', 'ASCII:Municipio de San Jose de los Remates;ID:3616752', '19770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19770', '112', '21647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.01.3616752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21648', '1079', '1', 'Municipio de San Francisco del Norte', 'NI.03.3616851', 'ASCII:Municipio de San Francisco del Norte;ID:3616851', '19771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19771', '112', '21648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.03.3616851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21649', '1079', '1', 'Municipio de Río Blanco', 'NI.12.3617068', 'ASCII:Municipio de Rio Blanco;ID:3617068', '19772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19772', '112', '21649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.12.3617068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21650', '1079', '1', 'Municipio de Muelle de los Bueyes', 'NI.18.3617561', 'ASCII:Municipio de Muelle de los Bueyes;ID:3617561', '19773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19773', '112', '21650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.18.3617561» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21651', '1079', '1', 'Municipio de Ciudad Sandino', 'NI.13.3620347', 'ASCII:Municipio de Ciudad Sandino;ID:3620347', '19774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19774', '112', '21651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.13.3620347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21652', '1079', '1', 'Municipio de Catarina', 'NI.11.3620438', 'ASCII:Municipio de Catarina;ID:3620438', '19775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19775', '112', '21652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.11.3620438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21653', '1079', '1', 'Municipio de Carlos Fonseca Amador', 'NI.10.3620472', 'ASCII:Municipio de Carlos Fonseca Amador;ID:3620472', '19776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19776', '112', '21653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.10.3620472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21654', '1079', '1', 'Municipio de Boaco', 'NI.01.3620672', 'ASCII:Municipio de Boaco;ID:3620672', '19777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19777', '112', '21654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.01.3620672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21655', '1079', '1', 'Municipio de Belén', 'NI.15.3620731', 'ASCII:Municipio de Belen;ID:3620731', '19778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19778', '112', '21655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NI.15.3620731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21656', '1079', '1', 'Gemeente Zwolle', 'NL.15.0193', 'ASCII:Gemeente Zwolle;ID:2743476', '19779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19779', '112', '21656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21657', '1079', '1', 'Gemeente Zwijndrecht', 'NL.11.0642', 'ASCII:Gemeente Zwijndrecht;ID:2743492', '19780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19780', '112', '21657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0642» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21658', '1079', '1', 'Gemeente Zutphen', 'NL.03.0301', 'ASCII:Gemeente Zutphen;ID:2743607', '19781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19781', '112', '21658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21659', '1079', '1', 'Gemeente Zundert', 'NL.06.0879', 'ASCII:Gemeente Zundert;ID:2743618', '19782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19782', '112', '21659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21660', '1079', '1', 'Gemeente Zuidhorn', 'NL.04.0056', 'ASCII:Gemeente Zuidhorn;ID:2743693', '19783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19783', '112', '21660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21661', '1079', '1', 'Gemeente Zoeterwoude', 'NL.11.0638', 'ASCII:Gemeente Zoeterwoude;ID:2743852', '19784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19784', '112', '21661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21662', '1079', '1', 'Gemeente Zoetermeer', 'NL.11.0637', 'ASCII:Gemeente Zoetermeer;ID:2743855', '19785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19785', '112', '21662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0637» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21663', '1079', '1', 'Gemeente Zijpe', 'NL.07.0476', 'ASCII:Gemeente Zijpe;ID:2743882', '19786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19786', '112', '21663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21664', '1079', '1', 'Gemeente Zevenaar', 'NL.03.0299', 'ASCII:Gemeente Zevenaar;ID:2743948', '19787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19787', '112', '21664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0299» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21665', '1079', '1', 'Gemeente Zeist', 'NL.09.0355', 'ASCII:Gemeente Zeist;ID:2743976', '19788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19788', '112', '21665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21666', '1079', '1', 'Gemeente Zeewolde', 'NL.16.0050', 'ASCII:Gemeente Zeewolde;ID:2743996', '19789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19789', '112', '21666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.16.0050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21667', '1079', '1', 'Gemeente Zeevang', 'NL.07.0478', 'ASCII:Gemeente Zeevang;ID:2743999', '19790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19790', '112', '21667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21668', '1079', '1', 'Gemeente Zandvoort', 'NL.07.0473', 'ASCII:Gemeente Zandvoort;ID:2744040', '19791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19791', '112', '21668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21669', '1079', '1', 'Gemeente Zaltbommel', 'NL.03.0297', 'ASCII:Gemeente Zaltbommel;ID:2744101', '19792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19792', '112', '21669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21670', '1079', '1', 'Gemeente Zaanstad', 'NL.07.0479', 'ASCII:Gemeente Zaanstad;ID:2744113', '19793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19793', '112', '21670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21671', '1079', '1', 'Gemeente Wymbritseradiel', 'NL.02.0683', 'ASCII:Gemeente Wymbritseradiel;ID:2744131', '19794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19794', '112', '21671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21672', '1079', '1', 'Gemeente Woudrichem', 'NL.06.0874', 'ASCII:Gemeente Woudrichem;ID:2744155', '19795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19795', '112', '21672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21673', '1079', '1', 'Gemeente Woudenberg', 'NL.09.0351', 'ASCII:Gemeente Woudenberg;ID:2744162', '19796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19796', '112', '21673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21674', '1079', '1', 'Gemeente Woerden', 'NL.09.0632', 'ASCII:Gemeente Woerden;ID:2744247', '19797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19797', '112', '21674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21675', '1079', '1', 'Gemeente Woensdrecht', 'NL.06.0873', 'ASCII:Gemeente Woensdrecht;ID:2744256', '19798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19798', '112', '21675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21676', '1079', '1', 'Gemeente Winterswijk', 'NL.03.0294', 'ASCII:Gemeente Winterswijk;ID:2744331', '19799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19799', '112', '21676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21677', '1079', '1', 'Gemeente Winsum', 'NL.04.0053', 'ASCII:Gemeente Winsum;ID:2744336', '19800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19800', '112', '21677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21678', '1079', '1', 'Gemeente Winschoten', 'NL.04.0052', 'ASCII:Gemeente Winschoten;ID:2744343', '19801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19801', '112', '21678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21679', '1079', '1', 'Gemeente Wijk bij Duurstede', 'NL.09.0352', 'ASCII:Gemeente Wijk bij Duurstede;ID:2744482', '19802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19802', '112', '21679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21680', '1079', '1', 'Gemeente Wijchen', 'NL.03.0296', 'ASCII:Gemeente Wijchen;ID:2744513', '19803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19803', '112', '21680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21681', '1079', '1', 'Gemeente Wieringermeer', 'NL.07.0463', 'ASCII:Gemeente Wieringermeer;ID:2744537', '19804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19804', '112', '21681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21682', '1079', '1', 'Gemeente Wieringen', 'NL.07.0462', 'ASCII:Wieringen;ID:2744540', '19805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19805', '112', '21682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21683', '1079', '1', 'Gemeente Wierden', 'NL.15.0189', 'ASCII:Gemeente Wierden;ID:2744548', '19806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19806', '112', '21683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21684', '1079', '1', 'Gemeente Westvoorne', 'NL.11.0614', 'ASCII:Gemeente Westvoorne;ID:2744605', '19807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19807', '112', '21684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21685', '1079', '1', 'Gemeente Weststellingwerf', 'NL.02.0098', 'ASCII:Gemeente Weststellingwerf;ID:2744609', '19808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19808', '112', '21685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21686', '1079', '1', 'Gemeente Westervoort', 'NL.03.0293', 'ASCII:Gemeente Westervoort;ID:2744674', '19809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19809', '112', '21686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21687', '1079', '1', 'Gemeente Wervershoof', 'NL.07.0459', 'ASCII:Gemeente Wervershoof;ID:2744819', '19810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19810', '112', '21687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21688', '1079', '1', 'Gemeente Werkendam', 'NL.06.0870', 'ASCII:Gemeente Werkendam;ID:2744826', '19811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19811', '112', '21688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21689', '1079', '1', 'Gemeente Weesp', 'NL.07.0457', 'ASCII:Gemeente Weesp;ID:2744903', '19812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19812', '112', '21689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21690', '1079', '1', 'Gemeente Weert', 'NL.05.0988', 'ASCII:Gemeente Weert;ID:2744910', '19813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19813', '112', '21690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21691', '1079', '1', 'Gemeente Wassenaar', 'NL.11.0629', 'ASCII:Gemeente Wassenaar;ID:2744989', '19814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19814', '112', '21691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21692', '1079', '1', 'Gemeente Wageningen', 'NL.03.0289', 'ASCII:Gemeente Wageningen;ID:2745087', '19815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19815', '112', '21692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21693', '1079', '1', 'Gemeente Waddinxveen', 'NL.11.0627', 'ASCII:Gemeente Waddinxveen;ID:2745095', '19816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19816', '112', '21693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21694', '1079', '1', 'Gemeente Waalwijk', 'NL.06.0867', 'ASCII:Gemeente Waalwijk;ID:2745122', '19817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19817', '112', '21694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21695', '1079', '1', 'Gemeente Waalre', 'NL.06.0866', 'ASCII:Gemeente Waalre;ID:2745126', '19818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19818', '112', '21695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21696', '1079', '1', 'Gemeente Vught', 'NL.06.0865', 'ASCII:Gemeente Vught;ID:2745153', '19819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19819', '112', '21696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21697', '1079', '1', 'Gemeente Voorst', 'NL.03.0285', 'ASCII:Gemeente Voorst;ID:2745295', '19820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19820', '112', '21697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21698', '1079', '1', 'Gemeente Voorschoten', 'NL.11.0626', 'ASCII:Gemeente Voorschoten;ID:2745300', '19821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19821', '112', '21698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21699', '1079', '1', 'Gemeente Voerendaal', 'NL.05.0986', 'ASCII:Gemeente Voerendaal;ID:2745368', '19822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19822', '112', '21699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21700', '1079', '1', 'Gemeente Vlist', 'NL.11.0623', 'ASCII:Gemeente Vlist;ID:2745386', '19823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19823', '112', '21700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21701', '1079', '1', 'Gemeente Vlissingen', 'NL.10.0718', 'ASCII:Gemeente Vlissingen;ID:2745391', '19824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19824', '112', '21701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.0718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21702', '1079', '1', 'Gemeente Vlieland', 'NL.02.0096', 'ASCII:Gemeente Vlieland;ID:2745417', '19825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19825', '112', '21702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21703', '1079', '1', 'Gemeente Vlagtwedde', 'NL.04.0048', 'ASCII:Gemeente Vlagtwedde;ID:2745460', '19826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19826', '112', '21703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21704', '1079', '1', 'Gemeente Vlaardingen', 'NL.11.0622', 'ASCII:Gemeente Vlaardingen;ID:2745466', '19827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19827', '112', '21704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21705', '1079', '1', 'Gemeente Vianen', 'NL.09.0620', 'ASCII:Gemeente Vianen;ID:2745579', '19828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19828', '112', '21705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21706', '1079', '1', 'Gemeente Venray', 'NL.05.0984', 'ASCII:Gemeente Venray;ID:2745633', '19829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19829', '112', '21706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21707', '1079', '1', 'Gemeente Venlo', 'NL.05.0983', 'ASCII:Gemeente Venlo;ID:2745640', '19830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19830', '112', '21707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21708', '1079', '1', 'Gemeente Velsen', 'NL.07.0453', 'ASCII:Gemeente Velsen;ID:2745675', '19831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19831', '112', '21708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21709', '1079', '1', 'Gemeente Veldhoven', 'NL.06.0861', 'ASCII:Gemeente Veldhoven;ID:2745704', '19832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19832', '112', '21709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21710', '1079', '1', 'Gemeente Veghel', 'NL.06.0860', 'ASCII:Gemeente Veghel;ID:2745725', '19833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19833', '112', '21710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21711', '1079', '1', 'Gemeente Veere', 'NL.10.0717', 'ASCII:Gemeente Veere;ID:2745738', '19834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19834', '112', '21711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.0717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21712', '1079', '1', 'Gemeente Veenendaal', 'NL.09.0345', 'ASCII:Gemeente Veenendaal;ID:2745773', '19835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19835', '112', '21712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21713', '1079', '1', 'Gemeente Veendam', 'NL.04.0047', 'ASCII:Gemeente Veendam;ID:2745782', '19836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19836', '112', '21713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21714', '1079', '1', 'Gemeente Valkenswaard', 'NL.06.0858', 'ASCII:Gemeente Valkenswaard;ID:2745859', '19837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19837', '112', '21714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21715', '1079', '1', 'Gemeente Vaals', 'NL.05.0981', 'ASCII:Gemeente Vaals;ID:2745904', '19838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19838', '112', '21715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21716', '1079', '1', 'Gemeente Utrecht', 'NL.09.0344', 'ASCII:Gemeente Utrecht;ID:2745911', '19839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19839', '112', '21716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0344» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21717', '1079', '1', 'Gemeente Urk', 'NL.16.0184', 'ASCII:Gemeente Urk;ID:2745931', '19840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19840', '112', '21717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.16.0184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21718', '1079', '1', 'Gemeente Uithoorn', 'NL.07.0451', 'ASCII:Gemeente Uithoorn;ID:2745972', '19841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19841', '112', '21718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21719', '1079', '1', 'Gemeente Uitgeest', 'NL.07.0450', 'ASCII:Gemeente Uitgeest;ID:2745977', '19842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19842', '112', '21719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21720', '1079', '1', 'Gemeente Uden', 'NL.06.0856', 'ASCII:Gemeente Uden;ID:2746004', '19843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19843', '112', '21720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21721', '1079', '1', 'Gemeente Ubbergen', 'NL.03.0282', 'ASCII:Gemeente Ubbergen;ID:2746011', '19844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19844', '112', '21721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21722', '1079', '1', 'Gemeente Tubbergen', 'NL.15.0183', 'ASCII:Gemeente Tubbergen;ID:2746132', '19845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19845', '112', '21722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21723', '1079', '1', 'Gemeente Tilburg', 'NL.06.0855', 'ASCII:Gemeente Tilburg;ID:2746300', '19846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19846', '112', '21723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21724', '1079', '1', 'Gemeente Tiel', 'NL.03.0281', 'ASCII:Gemeente Tiel;ID:2746330', '19847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19847', '112', '21724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21725', '1079', '1', 'Gemeente Tholen', 'NL.10.0716', 'ASCII:Gemeente Tholen;ID:2746350', '19848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19848', '112', '21725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.0716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21726', '1079', '1', 'Gemeente Texel', 'NL.07.0448', 'ASCII:Gemeente Texel;ID:2746383', '19849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19849', '112', '21726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21727', '1079', '1', 'Gemeente Terschelling', 'NL.02.0093', 'ASCII:Gemeente Terschelling;ID:2746412', '19850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19850', '112', '21727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21728', '1079', '1', 'Gemeente Terneuzen', 'NL.10.0715', 'ASCII:Gemeente Terneuzen;ID:2746421', '19851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19851', '112', '21728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.0715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21729', '1079', '1', 'Gemeente Ten Boer', 'NL.04.0009', 'ASCII:Gemeente Ten Boer;ID:2746490', '19852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19852', '112', '21729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21730', '1079', '1', 'Gemeente Strijen', 'NL.11.0617', 'ASCII:Gemeente Strijen;ID:2746607', '19853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19853', '112', '21730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21731', '1079', '1', 'Gemeente Stein', 'NL.05.0971', 'ASCII:Gemeente Stein;ID:2746746', '19854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19854', '112', '21731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21732', '1079', '1', 'Gemeente Steenbergen', 'NL.06.0851', 'ASCII:Gemeente Steenbergen;ID:2746801', '19855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19855', '112', '21732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21733', '1079', '1', 'Gemeente Staphorst', 'NL.15.0180', 'ASCII:Gemeente Staphorst;ID:2746837', '19856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19856', '112', '21733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21734', '1079', '1', 'Gemeente Stadskanaal', 'NL.04.0037', 'ASCII:Gemeente Stadskanaal;ID:2746859', '19857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19857', '112', '21734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21735', '1079', '1', 'Gemeente Spijkenisse', 'NL.11.0612', 'ASCII:Gemeente Spijkenisse;ID:2746931', '19858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19858', '112', '21735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21736', '1079', '1', 'Gemeente Son en Breugel', 'NL.06.0848', 'ASCII:Gemeente Son en Breugel;ID:2747009', '19859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19859', '112', '21736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21737', '1079', '1', 'Gemeente Someren', 'NL.06.0847', 'ASCII:Gemeente Someren;ID:2747020', '19860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19860', '112', '21737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21738', '1079', '1', 'Gemeente Soest', 'NL.09.0342', 'ASCII:Gemeente Soest;ID:2747033', '19861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19861', '112', '21738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21739', '1079', '1', 'Gemeente Sneek', 'NL.02.0091', 'ASCII:Gemeente Sneek;ID:2747062', '19862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19862', '112', '21739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21740', '1079', '1', 'Gemeente Smallingerland', 'NL.02.0090', 'ASCII:Gemeente Smallingerland;ID:2747091', '19863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19863', '112', '21740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21741', '1079', '1', 'Gemeente Sluis', 'NL.10.1714', 'ASCII:Gemeente Sluis;ID:2747114', '19864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19864', '112', '21741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.1714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21742', '1079', '1', 'Gemeente Slochteren', 'NL.04.0040', 'ASCII:Gemeente Slochteren;ID:2747142', '19865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19865', '112', '21742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21743', '1079', '1', 'Gemeente Sliedrecht', 'NL.11.0610', 'ASCII:Gemeente Sliedrecht;ID:2747168', '19866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19866', '112', '21743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21744', '1079', '1', 'Gemeente Sint-Oedenrode', 'NL.06.0846', 'ASCII:Gemeente Sint-Oedenrode;ID:2747226', '19867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19867', '112', '21744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21745', '1079', '1', 'Gemeente Sint-Michielsgestel', 'NL.06.0845', 'ASCII:Gemeente Sint-Michielsgestel;ID:2747233', '19868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19868', '112', '21745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21746', '1079', '1', 'Gemeente Simpelveld', 'NL.05.0965', 'ASCII:Gemeente Simpelveld;ID:2747311', '19869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19869', '112', '21746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21747', '1079', '1', 'Gemeente ''s-Hertogenbosch', 'NL.06.0796', 'ASCII:Gemeente ''s-Hertogenbosch;ID:2747350', '19870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19870', '112', '21747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21748', '1079', '1', 'Gemeente ''s-Gravenhage', 'NL.11.0518', 'ASCII:Gemeente ''s-Gravenhage;ID:2747372', '19871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19871', '112', '21748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21749', '1079', '1', 'Gemeente Sevenum', 'NL.05.0964', 'ASCII:Gemeente Sevenum;ID:2747381', '19872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19872', '112', '21749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0964» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21750', '1079', '1', 'Gemeente Schoonhoven', 'NL.11.0608', 'ASCII:Gemeente Schoonhoven;ID:2747505', '19873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19873', '112', '21750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21751', '1079', '1', 'Gemeente Schinnen', 'NL.05.0962', 'ASCII:Gemeente Schinnen;ID:2747552', '19874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19874', '112', '21751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21752', '1079', '1', 'Gemeente Schijndel', 'NL.06.0844', 'ASCII:Gemeente Schijndel;ID:2747583', '19875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19875', '112', '21752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0844» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21753', '1079', '1', 'Gemeente Schiermonnikoog', 'NL.02.0088', 'ASCII:Gemeente Schiermonnikoog;ID:2747589', '19876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19876', '112', '21753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21754', '1079', '1', 'Gemeente Schiedam', 'NL.11.0606', 'ASCII:Gemeente Schiedam;ID:2747595', '19877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19877', '112', '21754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21755', '1079', '1', 'Gemeente Scherpenzeel', 'NL.03.0279', 'ASCII:Gemeente Scherpenzeel;ID:2747605', '19878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19878', '112', '21755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21756', '1079', '1', 'Gemeente Schermer', 'NL.07.0458', 'ASCII:Gemeente Schermer;ID:2747618', '19879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19879', '112', '21756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21757', '1079', '1', 'Gemeente Scheemda', 'NL.04.0039', 'ASCII:Gemeente Scheemda;ID:2747660', '19880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19880', '112', '21757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21758', '1079', '1', 'Gemeente Schagen', 'NL.07.0441', 'ASCII:Gemeente Schagen;ID:2747719', '19881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19881', '112', '21758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21759', '1079', '1', 'Gemeente Rucphen', 'NL.06.0840', 'ASCII:Gemeente Rucphen;ID:2747857', '19882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19882', '112', '21759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21760', '1079', '1', 'Gemeente Rozendaal', 'NL.03.0277', 'ASCII:Gemeente Rozendaal;ID:2747863', '19883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19883', '112', '21760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21761', '1079', '1', 'Gemeente Rozenburg', 'NL.11.0600', 'ASCII:Gemeente Rozenburg;ID:2747868', '19884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19884', '112', '21761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21762', '1079', '1', 'Gemeente Rotterdam', 'NL.11.0599', 'ASCII:Gemeente Rotterdam;ID:2747890', '19885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19885', '112', '21762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21763', '1079', '1', 'Gemeente Roosendaal en Nispen', 'NL.06.1674', 'ASCII:Gemeente Roosendaal en Nispen;ID:2747929', '19886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19886', '112', '21763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21764', '1079', '1', 'Gemeente Roermond', 'NL.05.0957', 'ASCII:Gemeente Roermond;ID:2747999', '19887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19887', '112', '21764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21765', '1079', '1', 'Gemeente Rijswijk', 'NL.11.0603', 'ASCII:Gemeente Rijswijk;ID:2748075', '19888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19888', '112', '21765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21766', '1079', '1', 'Gemeente Ridderkerk', 'NL.11.0597', 'ASCII:Gemeente Ridderkerk;ID:2748171', '19889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19889', '112', '21766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21767', '1079', '1', 'Gemeente Rhenen', 'NL.09.0340', 'ASCII:Gemeente Rhenen;ID:2748184', '19890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19890', '112', '21767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21768', '1079', '1', 'Gemeente Rheden', 'NL.03.0275', 'ASCII:Gemeente Rheden;ID:2748200', '19891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19891', '112', '21768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21769', '1079', '1', 'Gemeente Renswoude', 'NL.09.0339', 'ASCII:Gemeente Renswoude;ID:2748227', '19892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19892', '112', '21769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21770', '1079', '1', 'Gemeente Renkum', 'NL.03.0274', 'ASCII:Gemeente Renkum;ID:2748235', '19893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19893', '112', '21770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21771', '1079', '1', 'Gemeente Reimerswaal', 'NL.10.0703', 'ASCII:Gemeente Reimerswaal;ID:2748254', '19894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19894', '112', '21771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.0703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21772', '1079', '1', 'Gemeente Reeuwijk', 'NL.11.0595', 'ASCII:Gemeente Reeuwijk;ID:2748279', '19895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19895', '112', '21772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21773', '1079', '1', 'Gemeente Raalte', 'NL.15.0177', 'ASCII:Gemeente Raalte;ID:2748370', '19896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19896', '112', '21773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21774', '1079', '1', 'Gemeente Putten', 'NL.03.0273', 'ASCII:Gemeente Putten;ID:2748391', '19897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19897', '112', '21774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21775', '1079', '1', 'Gemeente Purmerend', 'NL.07.0439', 'ASCII:Gemeente Purmerend;ID:2748412', '19898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19898', '112', '21775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21776', '1079', '1', 'Gemeente Papendrecht', 'NL.11.0590', 'ASCII:Gemeente Papendrecht;ID:2748728', '19899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19899', '112', '21776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21777', '1079', '1', 'Gemeente Oudewater', 'NL.09.0589', 'ASCII:Gemeente Oudewater;ID:2748978', '19900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19900', '112', '21777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21778', '1079', '1', 'Gemeente Ouderkerk aan den IJssel', 'NL.11.0644', 'ASCII:Gemeente Ouderkerk aan den IJssel;ID:2749015', '19901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19901', '112', '21778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21779', '1079', '1', 'Gemeente Ouder-Amstel', 'NL.07.0437', 'ASCII:Ouder-Amstel;ID:2749027', '19902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19902', '112', '21779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21780', '1079', '1', 'Gemeente Oud-Beijerland', 'NL.11.0584', 'ASCII:Gemeente Oud-Beijerland;ID:2749181', '19903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19903', '112', '21780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21781', '1079', '1', 'Gemeente Oss', 'NL.06.0828', 'ASCII:Gemeente Oss;ID:2749233', '19904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19904', '112', '21781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21782', '1079', '1', 'Gemeente Opsterland', 'NL.02.0086', 'ASCII:Gemeente Opsterland;ID:2749277', '19905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19905', '112', '21782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21783', '1079', '1', 'Gemeente Opmeer', 'NL.07.0432', 'ASCII:Gemeente Opmeer;ID:2749285', '19906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19906', '112', '21783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21784', '1079', '1', 'Gemeente Sint Anthonis', 'NL.06.1702', 'ASCII:Gemeente Sint Anthonis;ID:2749288', '19907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19907', '112', '21784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21785', '1079', '1', 'Gemeente Oostzaan', 'NL.07.0431', 'ASCII:Gemeente Oostzaan;ID:2749319', '19908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19908', '112', '21785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21786', '1079', '1', 'Gemeente Ooststellingwerf', 'NL.02.0085', 'ASCII:Gemeente Ooststellingwerf;ID:2749339', '19909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19909', '112', '21786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21787', '1079', '1', 'Gemeente Oostflakkee', 'NL.11.0580', 'ASCII:Gemeente Oostflakkee;ID:2749380', '19910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19910', '112', '21787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21788', '1079', '1', 'Gemeente Oosterhout', 'NL.06.0826', 'ASCII:Gemeente Oosterhout;ID:2749447', '19911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19911', '112', '21788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21789', '1079', '1', 'Gemeente Dongeradeel', 'NL.02.0058', 'ASCII:Gemeente Dongeradeel;ID:2749535', '19912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19912', '112', '21789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21790', '1079', '1', 'Gemeente Ommen', 'NL.15.0175', 'ASCII:Gemeente Ommen;ID:2749611', '19913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19913', '112', '21790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21791', '1079', '1', 'Gemeente Oldenzaal', 'NL.15.0173', 'ASCII:Gemeente Oldenzaal;ID:2749643', '19914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19914', '112', '21791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21792', '1079', '1', 'Gemeente Oldebroek', 'NL.03.0269', 'ASCII:Gemeente Oldebroek;ID:2749667', '19915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19915', '112', '21792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21793', '1079', '1', 'Gemeente Oisterwijk', 'NL.06.0824', 'ASCII:Gemeente Oisterwijk;ID:2749679', '19916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19916', '112', '21793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21794', '1079', '1', 'Gemeente Oirschot', 'NL.06.0823', 'ASCII:Gemeente Oirschot;ID:2749682', '19917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19917', '112', '21794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21795', '1079', '1', 'Gemeente Oegstgeest', 'NL.11.0579', 'ASCII:Gemeente Oegstgeest;ID:2749722', '19918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19918', '112', '21795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21796', '1079', '1', 'Gemeente Nuth', 'NL.05.0951', 'ASCII:Gemeente Nuth;ID:2749752', '19919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19919', '112', '21796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21797', '1079', '1', 'Gemeente Nunspeet', 'NL.03.0302', 'ASCII:Gemeente Nunspeet;ID:2749754', '19920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19920', '112', '21797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21798', '1079', '1', 'Gemeente Nuenen, Gerwen en Nederwetten', 'NL.06.0820', 'ASCII:Nuenen;ID:2749779', '19921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19921', '112', '21798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21799', '1079', '1', 'Gemeente Noordwijkerhout', 'NL.11.0576', 'ASCII:Gemeente Noordwijkerhout;ID:2749810', '19922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19922', '112', '21799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21800', '1079', '1', 'Gemeente Noordwijk', 'NL.11.0575', 'ASCII:Gemeente Noordwijk;ID:2749814', '19923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19923', '112', '21800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21801', '1079', '1', 'Gemeente Noordoostpolder', 'NL.16.0171', 'ASCII:Gemeente Noordoostpolder;ID:2749851', '19924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19924', '112', '21801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.16.0171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21802', '1079', '1', 'Gemeente Nijmegen', 'NL.03.0268', 'ASCII:Gemeente Nijmegen;ID:2750052', '19925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19925', '112', '21802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21803', '1079', '1', 'Gemeente Nijkerk', 'NL.03.0267', 'ASCII:Gemeente Nijkerk;ID:2750064', '19926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19926', '112', '21803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21804', '1079', '1', 'Gemeente Nieuw-Lekkerland', 'NL.11.0571', 'ASCII:Gemeente Nieuw-Lekkerland;ID:2750162', '19927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19927', '112', '21804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21805', '1079', '1', 'Gemeente Nieuwkoop', 'NL.11.0569', 'ASCII:Gemeente Nieuwkoop;ID:2750186', '19928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19928', '112', '21805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21806', '1079', '1', 'Gemeente Nieuwerkerk aan den IJssel', 'NL.11.0567', 'ASCII:Gemeente Nieuwerkerk aan den IJssel;ID:2750262', '19929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19929', '112', '21806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0567» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21807', '1079', '1', 'Gemeente Nieuwegein', 'NL.09.0356', 'ASCII:Gemeente Nieuwegein;ID:2750324', '19930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19930', '112', '21807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21808', '1079', '1', 'Gemeente Niedorp', 'NL.07.0412', 'ASCII:Gemeente Niedorp;ID:2750395', '19931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19931', '112', '21808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21809', '1079', '1', 'Gemeente Nederweert', 'NL.05.0946', 'ASCII:Gemeente Nederweert;ID:2750466', '19932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19932', '112', '21809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0946» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21810', '1079', '1', 'Gemeente Naarden', 'NL.07.0425', 'ASCII:Gemeente Naarden;ID:2750520', '19933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19933', '112', '21810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21811', '1079', '1', 'Gemeente Muiden', 'NL.07.0424', 'ASCII:Gemeente Muiden;ID:2750568', '19934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19934', '112', '21811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21812', '1079', '1', 'Gemeente Moordrecht', 'NL.11.0563', 'ASCII:Gemeente Moordrecht;ID:2750612', '19935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19935', '112', '21812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21813', '1079', '1', 'Gemeente Mook en Middelaar', 'NL.05.0944', 'ASCII:Gemeente Mook en Middelaar;ID:2750620', '19936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19936', '112', '21813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0944» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21814', '1079', '1', 'Gemeente Montfoort', 'NL.09.0335', 'ASCII:Gemeente Montfoort;ID:2750625', '19937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19937', '112', '21814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0335» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21815', '1079', '1', 'Gemeente Millingen aan de Rijn', 'NL.03.0265', 'ASCII:Gemeente Millingen aan de Rijn;ID:2750796', '19938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19938', '112', '21815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21816', '1079', '1', 'Gemeente Mill en Sint Hubert', 'NL.06.0815', 'ASCII:Mill en Sint Hubert;ID:2750800', '19939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19939', '112', '21816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21817', '1079', '1', 'Gemeente Middelharnis', 'NL.11.0559', 'ASCII:Gemeente Middelharnis;ID:2750883', '19940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19940', '112', '21817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21818', '1079', '1', 'Gemeente Middelburg', 'NL.10.0687', 'ASCII:Gemeente Middelburg;ID:2750894', '19941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19941', '112', '21818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.0687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21819', '1079', '1', 'Gemeente Meppel', 'NL.01.0119', 'ASCII:Gemeente Meppel;ID:2750946', '19942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19942', '112', '21819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.0119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21820', '1079', '1', 'Gemeente Menaldumadeel', 'NL.02.0083', 'ASCII:Gemeente Menaldumadeel;ID:2750964', '19943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19943', '112', '21820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21821', '1079', '1', 'Gemeente Meijel', 'NL.05.0941', 'ASCII:Gemeente Meijel;ID:2750994', '19944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19944', '112', '21821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21822', '1079', '1', 'Gemeente Meerssen', 'NL.05.0938', 'ASCII:Gemeente Meerssen;ID:2751036', '19945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19945', '112', '21822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21823', '1079', '1', 'Gemeente Meerlo-Wanssum', 'NL.05.0993', 'ASCII:Gemeente Meerlo-Wanssum;ID:2751041', '19946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19946', '112', '21823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0993» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21824', '1079', '1', 'Gemeente Medemblik', 'NL.07.0420', 'ASCII:Gemeente Medemblik;ID:2751072', '19947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19947', '112', '21824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21825', '1079', '1', 'Gemeente Marum', 'NL.04.0025', 'ASCII:Gemeente Marum;ID:2751110', '19948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19948', '112', '21825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21826', '1079', '1', 'Gemeente Margraten', 'NL.05.0936', 'ASCII:Gemeente Margraten;ID:2751198', '19949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19949', '112', '21826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21827', '1079', '1', 'Gemeente Made en Drimmelen', 'NL.06.1719', 'ASCII:Gemeente Made en Drimmelen;ID:2751271', '19950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19950', '112', '21827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21828', '1079', '1', 'Gemeente Maastricht', 'NL.05.0935', 'ASCII:Gemeente Maastricht;ID:2751282', '19951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19951', '112', '21828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21829', '1079', '1', 'Gemeente Maassluis', 'NL.11.0556', 'ASCII:Gemeente Maassluis;ID:2751284', '19952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19952', '112', '21829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21830', '1079', '1', 'Gemeente Maasdriel', 'NL.03.0263', 'ASCII:Gemeente Maasdriel;ID:2751295', '19953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19953', '112', '21830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21831', '1079', '1', 'Gemeente Maasbree', 'NL.05.0934', 'ASCII:Gemeente Maasbree;ID:2751300', '19954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19954', '112', '21831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21832', '1079', '1', 'Gemeente Maarssen', 'NL.09.0333', 'ASCII:Gemeente Maarssen;ID:2751315', '19955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19955', '112', '21832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21833', '1079', '1', 'Gemeente Losser', 'NL.15.0168', 'ASCII:Gemeente Losser;ID:2751423', '19956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19956', '112', '21833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21834', '1079', '1', 'Gemeente Loppersum', 'NL.04.0024', 'ASCII:Gemeente Loppersum;ID:2751428', '19957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19957', '112', '21834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21835', '1079', '1', 'Gemeente Lopik', 'NL.09.0331', 'ASCII:Gemeente Lopik;ID:2751435', '19958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19958', '112', '21835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21836', '1079', '1', 'Gemeente Loon op Zand', 'NL.06.0809', 'ASCII:Gemeente Loon op Zand;ID:2751455', '19959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19959', '112', '21836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21837', '1079', '1', 'Gemeente Loenen', 'NL.09.0329', 'ASCII:Gemeente Loenen;ID:2751522', '19960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19960', '112', '21837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21838', '1079', '1', 'Gemeente Lochem', 'NL.03.0262', 'ASCII:Gemeente Lochem;ID:2751536', '19961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19961', '112', '21838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21839', '1079', '1', 'Gemeente Lith', 'NL.06.0808', 'ASCII:Gemeente Lith;ID:2751542', '19962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19962', '112', '21839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21840', '1079', '1', 'Gemeente Lisse', 'NL.11.0553', 'ASCII:Gemeente Lisse;ID:2751546', '19963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19963', '112', '21840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21841', '1079', '1', 'Gemeente Leusden', 'NL.09.0327', 'ASCII:Gemeente Leusden;ID:2751688', '19964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19964', '112', '21841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21842', '1079', '1', 'Gemeente Lemsterland', 'NL.02.0082', 'ASCII:Gemeente Lemsterland;ID:2751721', '19965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19965', '112', '21842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21843', '1079', '1', 'Gemeente Lelystad', 'NL.16.0995', 'ASCII:Gemeente Lelystad;ID:2751737', '19966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19966', '112', '21843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.16.0995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21844', '1079', '1', 'Gemeente Leiderdorp', 'NL.11.0547', 'ASCII:Gemeente Leiderdorp;ID:2751770', '19967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19967', '112', '21844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21845', '1079', '1', 'Gemeente Leiden', 'NL.11.0546', 'ASCII:Gemeente Leiden;ID:2751772', '19968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19968', '112', '21845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21846', '1079', '1', 'Gemeente Leeuwarderadeel', 'NL.02.0081', 'ASCII:Gemeente Leeuwarderadeel;ID:2751790', '19969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19969', '112', '21846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21847', '1079', '1', 'Gemeente Leeuwarden', 'NL.02.0080', 'ASCII:Gemeente Leeuwarden;ID:2751791', '19970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19970', '112', '21847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21848', '1079', '1', 'Gemeente Leerdam', 'NL.11.0545', 'ASCII:Gemeente Leerdam;ID:2751807', '19971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19971', '112', '21848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21849', '1079', '1', 'Gemeente Leek', 'NL.04.0022', 'ASCII:Gemeente Leek;ID:2751833', '19972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19972', '112', '21849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21850', '1079', '1', 'Gemeente Laren', 'NL.07.0417', 'ASCII:Gemeente Laren;ID:2751873', '19973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19973', '112', '21850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21851', '1079', '1', 'Gemeente Langedijk', 'NL.07.0416', 'ASCII:Gemeente Langedijk;ID:2751962', '19974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19974', '112', '21851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21852', '1079', '1', 'Gemeente Landsmeer', 'NL.07.0415', 'ASCII:Gemeente Landsmeer;ID:2751979', '19975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19975', '112', '21852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21853', '1079', '1', 'Gemeente Krimpen aan den IJssel', 'NL.11.0542', 'ASCII:Gemeente Krimpen aan den IJssel;ID:2752263', '19976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19976', '112', '21853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0542» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21854', '1079', '1', 'Gemeente Kollumerland en Nieuwkruisland', 'NL.02.0079', 'ASCII:Gemeente Kollumerland en Nieuwkruisland;ID:2752523', '19977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19977', '112', '21854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21855', '1079', '1', 'Gemeente Kessel', 'NL.05.0929', 'ASCII:Gemeente Kessel;ID:2752904', '19978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19978', '112', '21855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21856', '1079', '1', 'Gemeente Kerkrade', 'NL.05.0928', 'ASCII:Gemeente Kerkrade;ID:2752922', '19979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19979', '112', '21856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21857', '1079', '1', 'Gemeente Katwijk', 'NL.11.0537', 'ASCII:Gemeente Katwijk;ID:2753012', '19980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19980', '112', '21857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0537» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21858', '1079', '1', 'Gemeente Kapelle', 'NL.10.0678', 'ASCII:Gemeente Kapelle;ID:2753069', '19981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19981', '112', '21858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.0678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21859', '1079', '1', 'Gemeente Kampen', 'NL.15.0166', 'ASCII:Gemeente Kampen;ID:2753104', '19982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19982', '112', '21859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21860', '1079', '1', 'Gemeente IJsselstein', 'NL.09.0353', 'ASCII:Gemeente IJsselstein;ID:2753354', '19983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19983', '112', '21860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21861', '1079', '1', 'Gemeente Boarnsterhim', 'NL.02.0055', 'ASCII:Gemeente Boarnsterhim;ID:2753394', '19984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19984', '112', '21861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21862', '1079', '1', 'Gemeente Hulst', 'NL.10.0677', 'ASCII:Gemeente Hulst;ID:2753437', '19985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19985', '112', '21862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.0677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21863', '1079', '1', 'Gemeente Huizen', 'NL.07.0406', 'ASCII:Gemeente Huizen;ID:2753467', '19986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19986', '112', '21863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21864', '1079', '1', 'Gemeente Houten', 'NL.09.0321', 'ASCII:Gemeente Houten;ID:2753556', '19987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19987', '112', '21864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21865', '1079', '1', 'Gemeente Hoorn', 'NL.07.0405', 'ASCII:Gemeente Hoorn;ID:2753635', '19988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19988', '112', '21865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21866', '1079', '1', 'Gemeente Hoogezand-Sappemeer', 'NL.04.0018', 'ASCII:Gemeente Hoogezand-Sappemeer;ID:2753705', '19989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19989', '112', '21866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21867', '1079', '1', 'Gemeente Hoogeveen', 'NL.01.0118', 'ASCII:Gemeente Hoogeveen;ID:2753718', '19990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19990', '112', '21867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.0118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21868', '1079', '1', 'Gemeente Hilversum', 'NL.07.0402', 'ASCII:Gemeente Hilversum;ID:2754063', '19991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19991', '112', '21868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21869', '1079', '1', 'Gemeente Hilvarenbeek', 'NL.06.0798', 'ASCII:Gemeente Hilvarenbeek;ID:2754065', '19992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19992', '112', '21869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21870', '1079', '1', 'Gemeente Hillegom', 'NL.11.0534', 'ASCII:Gemeente Hillegom;ID:2754072', '19993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19993', '112', '21870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21871', '1079', '1', 'Gemeente Heusden', 'NL.06.0797', 'ASCII:Gemeente Heusden;ID:2754134', '19994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19994', '112', '21871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21872', '1079', '1', 'Gemeente Heumen', 'NL.03.0252', 'ASCII:Gemeente Heumen;ID:2754146', '19995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19995', '112', '21872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21873', '1079', '1', 'Gemeente het Bildt', 'NL.02.0063', 'ASCII:Gemeente het Bildt;ID:2754301', '19996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19996', '112', '21873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21874', '1079', '1', 'Gemeente Hengelo', 'NL.15.0164', 'ASCII:Gemeente Hengelo;ID:2754392', '19997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19997', '112', '21874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21875', '1079', '1', 'Gemeente Hendrik-Ido-Ambacht', 'NL.11.0531', 'ASCII:Gemeente Hendrik-Ido-Ambacht;ID:2754407', '19998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19998', '112', '21875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21876', '1079', '1', 'Gemeente Helmond', 'NL.06.0794', 'ASCII:Gemeente Helmond;ID:2754446', '19999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('19999', '112', '21876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21877', '1079', '1', 'Gemeente Hellevoetsluis', 'NL.11.0530', 'ASCII:Gemeente Hellevoetsluis;ID:2754453', '20000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20000', '112', '21877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21878', '1079', '1', 'Gemeente Hellendoorn', 'NL.15.0163', 'ASCII:Gemeente Hellendoorn;ID:2754456', '20001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20001', '112', '21878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21879', '1079', '1', 'Gemeente Helden', 'NL.05.0918', 'ASCII:Gemeente Helden;ID:2754481', '20002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20002', '112', '21879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21880', '1079', '1', 'Gemeente Heiloo', 'NL.07.0399', 'ASCII:Gemeente Heiloo;ID:2754515', '20003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20003', '112', '21880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21881', '1079', '1', 'Gemeente Heerlen', 'NL.05.0917', 'ASCII:Gemeente Heerlen;ID:2754651', '20004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20004', '112', '21881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21882', '1079', '1', 'Gemeente Heerhugowaard', 'NL.07.0398', 'ASCII:Gemeente Heerhugowaard;ID:2754658', '20005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20005', '112', '21882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0398» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21883', '1079', '1', 'Gemeente Heerenveen', 'NL.02.0074', 'ASCII:Gemeente Heerenveen;ID:2754668', '20006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20006', '112', '21883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21884', '1079', '1', 'Gemeente Heerde', 'NL.03.0246', 'ASCII:Gemeente Heerde;ID:2754680', '20007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20007', '112', '21884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21885', '1079', '1', 'Gemeente Heemstede', 'NL.07.0397', 'ASCII:Gemeente Heemstede;ID:2754691', '20008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20008', '112', '21885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21886', '1079', '1', 'Gemeente Heemskerk', 'NL.07.0396', 'ASCII:Gemeente Heemskerk;ID:2754696', '20009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20009', '112', '21886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21887', '1079', '1', 'Gemeente Hattem', 'NL.03.0244', 'ASCII:Gemeente Hattem;ID:2754767', '20010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20010', '112', '21887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21888', '1079', '1', 'Gemeente Harlingen', 'NL.02.0072', 'ASCII:Gemeente Harlingen;ID:2754816', '20011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20011', '112', '21888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21889', '1079', '1', 'Gemeente Harenkarspel', 'NL.07.0395', 'ASCII:Gemeente Harenkarspel;ID:2754836', '20012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20012', '112', '21889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21890', '1079', '1', 'Gemeente Haren', 'NL.04.0017', 'ASCII:Gemeente Haren;ID:2754840', '20013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20013', '112', '21890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21891', '1079', '1', 'Gemeente Hardinxveld-Giessendam', 'NL.11.0523', 'ASCII:Gemeente Hardinxveld-Giessendam;ID:2754843', '20014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20014', '112', '21891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21892', '1079', '1', 'Gemeente Harderwijk', 'NL.03.0243', 'ASCII:Gemeente Harderwijk;ID:2754846', '20015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20015', '112', '21892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21893', '1079', '1', 'Gemeente Hardenberg', 'NL.15.0160', 'ASCII:Gemeente Hardenberg;ID:2754858', '20016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20016', '112', '21893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21894', '1079', '1', 'Gemeente Haarlemmermeer', 'NL.07.0394', 'ASCII:Gemeente Haarlemmermeer;ID:2754999', '20017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20017', '112', '21894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21895', '1079', '1', 'Gemeente Haarlemmerliede en Spaarnwoude', 'NL.07.0393', 'ASCII:Haarlemmerliede en Spaarnwoude;ID:2755000', '20018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20018', '112', '21895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0393» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21896', '1079', '1', 'Gemeente Haarlem', 'NL.07.0392', 'ASCII:Gemeente Haarlem;ID:2755002', '20019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20019', '112', '21896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21897', '1079', '1', 'Gemeente Haaren', 'NL.06.0788', 'ASCII:Gemeente Haaren;ID:2755008', '20020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20020', '112', '21897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0788» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21898', '1079', '1', 'Gemeente Haaksbergen', 'NL.15.0158', 'ASCII:Gemeente Haaksbergen;ID:2755031', '20021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20021', '112', '21898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21899', '1079', '1', 'Gemeente Grootegast', 'NL.04.0015', 'ASCII:Gemeente Grootegast;ID:2755203', '20022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20022', '112', '21899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21900', '1079', '1', 'Gemeente Groningen', 'NL.04.0014', 'ASCII:Gemeente Groningen;ID:2755250', '20023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20023', '112', '21900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21901', '1079', '1', 'Gemeente Groesbeek', 'NL.03.0241', 'ASCII:Gemeente Groesbeek;ID:2755270', '20024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20024', '112', '21901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21902', '1079', '1', 'Gemeente Grave', 'NL.06.0786', 'ASCII:Gemeente Grave;ID:2755357', '20025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20025', '112', '21902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21903', '1079', '1', 'Gemeente Graft-De Rijp', 'NL.07.0365', 'ASCII:Graft-De Rijp;ID:2755374', '20026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20026', '112', '21903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21904', '1079', '1', 'Gemeente Gouda', 'NL.11.0513', 'ASCII:Gemeente Gouda;ID:2755419', '20027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20027', '112', '21904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21905', '1079', '1', 'Gemeente Gorinchem', 'NL.11.0512', 'ASCII:Gemeente Gorinchem;ID:2755433', '20028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20028', '112', '21905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21906', '1079', '1', 'Gemeente Goirle', 'NL.06.0785', 'ASCII:Gemeente Goirle;ID:2755463', '20029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20029', '112', '21906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21907', '1079', '1', 'Gemeente Goes', 'NL.10.0664', 'ASCII:Gemeente Goes;ID:2755475', '20030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20030', '112', '21907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.0664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21908', '1079', '1', 'Gemeente Goedereede', 'NL.11.0511', 'ASCII:Gemeente Goedereede;ID:2755484', '20031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20031', '112', '21908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21909', '1079', '1', 'Gemeente Gilze en Rijen', 'NL.06.0784', 'ASCII:Gemeente Gilze en Rijen;ID:2755506', '20032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20032', '112', '21909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0784» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21910', '1079', '1', 'Gemeente Gennep', 'NL.05.0907', 'ASCII:Gemeente Gennep;ID:2755583', '20033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20033', '112', '21910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21911', '1079', '1', 'Gemeente Geldermalsen', 'NL.03.0236', 'ASCII:Gemeente Geldermalsen;ID:2755632', '20034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20034', '112', '21911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0236» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21912', '1079', '1', 'Gemeente Geertruidenberg', 'NL.06.0779', 'ASCII:Gemeente Geertruidenberg;ID:2755668', '20035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20035', '112', '21912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21913', '1079', '1', 'Gemeente Franekeradeel', 'NL.02.0070', 'ASCII:Gemeente Franekeradeel;ID:2755843', '20036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20036', '112', '21913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21914', '1079', '1', 'Gemeente Ferwerderadiel', 'NL.02.1722', 'ASCII:Gemeente Ferwerderadiel;ID:2755918', '20037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20037', '112', '21914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.1722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21915', '1079', '1', 'Gemeente Etten-Leur', 'NL.06.0777', 'ASCII:Gemeente Etten-Leur;ID:2755994', '20038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20038', '112', '21915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21916', '1079', '1', 'Gemeente Ermelo', 'NL.03.0233', 'ASCII:Gemeente Ermelo;ID:2756038', '20039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20039', '112', '21916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21917', '1079', '1', 'Gemeente Epe', 'NL.03.0232', 'ASCII:Gemeente Epe;ID:2756058', '20040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20040', '112', '21917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0232» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21918', '1079', '1', 'Gemeente Enschede', 'NL.15.0153', 'ASCII:Gemeente Enschede;ID:2756070', '20041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20041', '112', '21918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21919', '1079', '1', 'Gemeente Enkhuizen', 'NL.07.0388', 'ASCII:Gemeente Enkhuizen;ID:2756076', '20042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20042', '112', '21919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21920', '1079', '1', 'Gemeente Emmen', 'NL.01.0114', 'ASCII:Gemeente Emmen;ID:2756134', '20043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20043', '112', '21920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.0114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21921', '1079', '1', 'Gemeente Elburg', 'NL.03.0230', 'ASCII:Gemeente Elburg;ID:2756231', '20044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20044', '112', '21921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21922', '1079', '1', 'Gemeente Eindhoven', 'NL.06.0772', 'ASCII:Gemeente Eindhoven;ID:2756252', '20045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20045', '112', '21922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21923', '1079', '1', 'Gemeente Eijsden', 'NL.05.0905', 'ASCII:Gemeente Eijsden;ID:2756282', '20046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20046', '112', '21923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21924', '1079', '1', 'Gemeente Eersel', 'NL.06.0770', 'ASCII:Gemeente Eersel;ID:2756341', '20047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20047', '112', '21924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21925', '1079', '1', 'Gemeente Eemnes', 'NL.09.0317', 'ASCII:Gemeente Eemnes;ID:2756393', '20048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20048', '112', '21925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21926', '1079', '1', 'Gemeente Ede', 'NL.03.0228', 'ASCII:Gemeente Ede;ID:2756428', '20049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20049', '112', '21926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21927', '1079', '1', 'Gemeente Edam-Volendam', 'NL.07.0385', 'ASCII:Edam-Volendam;ID:2756430', '20050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20050', '112', '21927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21928', '1079', '1', 'Gemeente Echt-Susteren', 'NL.05.1711', 'ASCII:Gemeente Echt-Susteren;ID:2756443', '20051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20051', '112', '21928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.1711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21929', '1079', '1', 'Gemeente Duiven', 'NL.03.0226', 'ASCII:Gemeente Duiven;ID:2756506', '20052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20052', '112', '21929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21930', '1079', '1', 'Gemeente Druten', 'NL.03.0225', 'ASCII:Gemeente Druten;ID:2756538', '20053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20053', '112', '21930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21931', '1079', '1', 'Gemeente Dronten', 'NL.16.0303', 'ASCII:Gemeente Dronten;ID:2756558', '20054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20054', '112', '21931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.16.0303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21932', '1079', '1', 'Gemeente Dordrecht', 'NL.11.0505', 'ASCII:Gemeente Dordrecht;ID:2756668', '20055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20055', '112', '21932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21933', '1079', '1', 'Gemeente Utrechtse Heuvelrug', 'NL.09.1581', 'ASCII:Gemeente Utrechtse Heuvelrug;ID:2756685', '20056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20056', '112', '21933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.1581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21934', '1079', '1', 'Gemeente Dongen', 'NL.06.0766', 'ASCII:Gemeente Dongen;ID:2756722', '20057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20057', '112', '21934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21935', '1079', '1', 'Gemeente Doetinchem', 'NL.03.0222', 'ASCII:Gemeente Doetinchem;ID:2756766', '20058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20058', '112', '21935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21936', '1079', '1', 'Gemeente Doesburg', 'NL.03.0221', 'ASCII:Gemeente Doesburg;ID:2756770', '20059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20059', '112', '21936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21937', '1079', '1', 'Gemeente Dirksland', 'NL.11.0504', 'ASCII:Gemeente Dirksland;ID:2756786', '20060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20060', '112', '21937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21938', '1079', '1', 'Gemeente Diemen', 'NL.07.0384', 'ASCII:Gemeente Diemen;ID:2756887', '20061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20061', '112', '21938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0384» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21939', '1079', '1', 'Gemeente Deventer', 'NL.15.0150', 'ASCII:Gemeente Deventer;ID:2756986', '20062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20062', '112', '21939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21940', '1079', '1', 'Gemeente Deurne', 'NL.06.0762', 'ASCII:Gemeente Deurne;ID:2757008', '20063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20063', '112', '21940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0762» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21941', '1079', '1', 'Gemeente Den Helder', 'NL.07.0400', 'ASCII:Gemeente Den Helder;ID:2757219', '20064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20064', '112', '21941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21942', '1079', '1', 'Gemeente Delfzijl', 'NL.04.0010', 'ASCII:Gemeente Delfzijl;ID:2757339', '20065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20065', '112', '21942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21943', '1079', '1', 'Gemeente Delft', 'NL.11.0503', 'ASCII:Gemeente Delft;ID:2757344', '20066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20066', '112', '21943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21944', '1079', '1', 'Gemeente De Bilt', 'NL.09.0310', 'ASCII:Gemeente De Bilt;ID:2757782', '20067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20067', '112', '21944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21945', '1079', '1', 'Gemeente Dantumadeel', 'NL.02.0065', 'ASCII:Gemeente Dantumadeel;ID:2757834', '20068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20068', '112', '21945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21946', '1079', '1', 'Gemeente Dalfsen', 'NL.15.0148', 'ASCII:Gemeente Dalfsen;ID:2757849', '20069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20069', '112', '21946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21947', '1079', '1', 'Gemeente Culemborg', 'NL.03.0216', 'ASCII:Gemeente Culemborg;ID:2757871', '20070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20070', '112', '21947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21948', '1079', '1', 'Gemeente Cuijk', 'NL.06.1684', 'ASCII:Gemeente Cuijk;ID:2757873', '20071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20071', '112', '21948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21949', '1079', '1', 'Gemeente Coevorden', 'NL.01.0109', 'ASCII:Gemeente Coevorden;ID:2757936', '20072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20072', '112', '21949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.0109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21950', '1079', '1', 'Gemeente Castricum', 'NL.07.0383', 'ASCII:Gemeente Castricum;ID:2757990', '20073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20073', '112', '21950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21951', '1079', '1', 'Gemeente Capelle aan den IJssel', 'NL.11.0502', 'ASCII:Gemeente Capelle aan den IJssel;ID:2758011', '20074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20074', '112', '21951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21952', '1079', '1', 'Gemeente Bussum', 'NL.07.0381', 'ASCII:Gemeente Bussum;ID:2758063', '20075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20075', '112', '21952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21953', '1079', '1', 'Gemeente Buren', 'NL.03.0214', 'ASCII:Gemeente Buren;ID:2758095', '20076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20076', '112', '21953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21954', '1079', '1', 'Gemeente Bunschoten', 'NL.09.0313', 'ASCII:Gemeente Bunschoten;ID:2758103', '20077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20077', '112', '21954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21955', '1079', '1', 'Gemeente Bunnik', 'NL.09.0312', 'ASCII:Gemeente Bunnik;ID:2758105', '20078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20078', '112', '21955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21956', '1079', '1', 'Gemeente Brunssum', 'NL.05.0899', 'ASCII:Gemeente Brunssum;ID:2758173', '20079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20079', '112', '21956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21957', '1079', '1', 'Gemeente Brummen', 'NL.03.0213', 'ASCII:Gemeente Brummen;ID:2758176', '20080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20080', '112', '21957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21958', '1079', '1', 'Gemeente Waterland', 'NL.07.0852', 'ASCII:Gemeente Waterland;ID:2758257', '20081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20081', '112', '21958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21959', '1079', '1', 'Gemeente Brielle', 'NL.11.0501', 'ASCII:Gemeente Brielle;ID:2758325', '20082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20082', '112', '21959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21960', '1079', '1', 'Gemeente Breukelen', 'NL.09.0311', 'ASCII:Gemeente Breukelen;ID:2758332', '20083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20083', '112', '21960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21961', '1079', '1', 'Gemeente Breda', 'NL.06.0758', 'ASCII:Gemeente Breda;ID:2758400', '20084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20084', '112', '21961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21962', '1079', '1', 'Gemeente Boxtel', 'NL.06.0757', 'ASCII:Gemeente Boxtel;ID:2758459', '20085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20085', '112', '21962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21963', '1079', '1', 'Gemeente Boxmeer', 'NL.06.0756', 'ASCII:Gemeente Boxmeer;ID:2758461', '20086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20086', '112', '21963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21964', '1079', '1', 'Gemeente Boskoop', 'NL.11.0499', 'ASCII:Gemeente Boskoop;ID:2758546', '20087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20087', '112', '21964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21965', '1079', '1', 'Gemeente Borsele', 'NL.10.0654', 'ASCII:Gemeente Borsele;ID:2758588', '20088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20088', '112', '21965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.0654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21966', '1079', '1', 'Gemeente Borne', 'NL.15.0147', 'ASCII:Gemeente Borne;ID:2758597', '20089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20089', '112', '21966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21967', '1079', '1', 'Gemeente Borger-Odoorn', 'NL.01.1681', 'ASCII:Gemeente Borger-Odoorn;ID:2758619', '20090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20090', '112', '21967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.1681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21968', '1079', '1', 'Gemeente Bolsward', 'NL.02.0064', 'ASCII:Gemeente Bolsward;ID:2758681', '20091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20091', '112', '21968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21969', '1079', '1', 'Gemeente Boekel', 'NL.06.0755', 'ASCII:Gemeente Boekel;ID:2758757', '20092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20092', '112', '21969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21970', '1079', '1', 'Gemeente Bodegraven', 'NL.11.0497', 'ASCII:Gemeente Bodegraven;ID:2758764', '20093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20093', '112', '21970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21971', '1079', '1', 'Gemeente Bloemendaal', 'NL.07.0377', 'ASCII:Gemeente Bloemendaal;ID:2758802', '20094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20094', '112', '21971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21972', '1079', '1', 'Gemeente Blaricum', 'NL.07.0376', 'ASCII:Gemeente Blaricum;ID:2758867', '20095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20095', '112', '21972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21973', '1079', '1', 'Gemeente Bladel en Netersel', 'NL.06.1728', 'ASCII:Gemeente Bladel en Netersel;ID:2758877', '20096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20096', '112', '21973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21974', '1079', '1', 'Gemeente Beverwijk', 'NL.07.0375', 'ASCII:Gemeente Beverwijk;ID:2758997', '20097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20097', '112', '21974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21975', '1079', '1', 'Gemeente Beuningen', 'NL.03.0209', 'ASCII:Gemeente Beuningen;ID:2759014', '20098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20098', '112', '21975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21976', '1079', '1', 'Gemeente Best', 'NL.06.0753', 'ASCII:Gemeente Best;ID:2759039', '20099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20099', '112', '21976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21977', '1079', '1', 'Gemeente Bergeijk', 'NL.06.1724', 'ASCII:Gemeente Bergeijk;ID:2759131', '20100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20100', '112', '21977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21978', '1079', '1', 'Gemeente Bergen op Zoom', 'NL.06.0748', 'ASCII:Gemeente Bergen op Zoom;ID:2759144', '20101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20101', '112', '21978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21979', '1079', '1', 'Gemeente Bergen', 'NL.07.0373', 'ASCII:Gemeente Bergen;ID:2759151', '20102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20102', '112', '21979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0373» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21980', '1079', '1', 'Gemeente Bergen', 'NL.05.0893', 'ASCII:Gemeente Bergen;ID:2759152', '20103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20103', '112', '21980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0893» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21981', '1079', '1', 'Gemeente Bergambacht', 'NL.11.0491', 'ASCII:Gemeente Bergambacht;ID:2759157', '20104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20104', '112', '21981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21982', '1079', '1', 'Gemeente Bellingwedde', 'NL.04.0007', 'ASCII:Bellingwedde;ID:2759248', '20105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20105', '112', '21982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21983', '1079', '1', 'Gemeente Beesel', 'NL.05.0889', 'ASCII:Gemeente Beesel;ID:2759285', '20106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20106', '112', '21983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21984', '1079', '1', 'Gemeente Beemster', 'NL.07.0370', 'ASCII:Gemeente Beemster;ID:2759320', '20107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20107', '112', '21984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21985', '1079', '1', 'Gemeente Beek', 'NL.05.0888', 'ASCII:Gemeente Beek;ID:2759343', '20108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20108', '112', '21985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21986', '1079', '1', 'Gemeente Bedum', 'NL.04.0005', 'ASCII:Gemeente Bedum;ID:2759355', '20109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20109', '112', '21986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21987', '1079', '1', 'Gemeente Barneveld', 'NL.03.0203', 'ASCII:Gemeente Barneveld;ID:2759406', '20110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20110', '112', '21987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21988', '1079', '1', 'Gemeente Barendrecht', 'NL.11.0489', 'ASCII:Gemeente Barendrecht;ID:2759425', '20111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20111', '112', '21988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21989', '1079', '1', 'Gemeente Baarn', 'NL.09.0308', 'ASCII:Gemeente Baarn;ID:2759543', '20112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20112', '112', '21989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21990', '1079', '1', 'Gemeente Baarle-Nassau', 'NL.06.0744', 'ASCII:Gemeente Baarle-Nassau;ID:2759553', '20113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20113', '112', '21990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21991', '1079', '1', 'Gemeente Asten', 'NL.06.0743', 'ASCII:Gemeente Asten;ID:2759619', '20114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20114', '112', '21991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21992', '1079', '1', 'Gemeente Assen', 'NL.01.0106', 'ASCII:Gemeente Assen;ID:2759632', '20115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20115', '112', '21992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.0106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21993', '1079', '1', 'Gemeente Arnhem', 'NL.03.0202', 'ASCII:Gemeente Arnhem;ID:2759660', '20116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20116', '112', '21993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21994', '1079', '1', 'Gemeente Arcen en Velden', 'NL.05.0885', 'ASCII:Arcen en Velden;ID:2759682', '20117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20117', '112', '21994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21995', '1079', '1', 'Gemeente Appingedam', 'NL.04.0003', 'ASCII:Gemeente Appingedam;ID:2759686', '20118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20118', '112', '21995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21996', '1079', '1', 'Gemeente Apeldoorn', 'NL.03.0200', 'ASCII:Gemeente Apeldoorn;ID:2759705', '20119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20119', '112', '21996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21997', '1079', '1', 'Gemeente Anna Paulowna', 'NL.07.0366', 'ASCII:Gemeente Anna Paulowna;ID:2759736', '20120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20120', '112', '21997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21998', '1079', '1', 'Gemeente Andijk', 'NL.07.0364', 'ASCII:Gemeente Andijk;ID:2759773', '20121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20121', '112', '21998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('21999', '1079', '1', 'Gemeente Amsterdam', 'NL.07.0363', 'ASCII:Gemeente Amsterdam;ID:2759793', '20122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20122', '112', '21999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0363» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22000', '1079', '1', 'Gemeente Amstelveen', 'NL.07.0362', 'ASCII:Gemeente Amstelveen;ID:2759797', '20123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20123', '112', '22000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22001', '1079', '1', 'Gemeente Amersfoort', 'NL.09.0307', 'ASCII:Gemeente Amersfoort;ID:2759820', '20124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20124', '112', '22001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22002', '1079', '1', 'Gemeente Ameland', 'NL.02.0060', 'ASCII:Gemeente Ameland;ID:2759844', '20125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20125', '112', '22002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22003', '1079', '1', 'Gemeente Alphen aan den Rijn', 'NL.11.0484', 'ASCII:Gemeente Alphen aan den Rijn;ID:2759874', '20126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20126', '112', '22003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22004', '1079', '1', 'Gemeente Almelo', 'NL.15.0141', 'ASCII:Gemeente Almelo;ID:2759886', '20127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20127', '112', '22004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.0141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22005', '1079', '1', 'Gemeente Alkmaar', 'NL.07.0361', 'ASCII:Gemeente Alkmaar;ID:2759898', '20128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20128', '112', '22005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22006', '1079', '1', 'Gemeente Alblasserdam', 'NL.11.0482', 'ASCII:Gemeente Alblasserdam;ID:2759914', '20129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20129', '112', '22006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22007', '1079', '1', 'Gemeente Achtkarspelen', 'NL.02.0059', 'ASCII:Achtkarspelen;ID:2759982', '20130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20130', '112', '22007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22008', '1079', '1', 'Gemeente Abcoude', 'NL.09.0305', 'ASCII:Gemeente Abcoude;ID:2760066', '20131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20131', '112', '22008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22009', '1079', '1', 'Gemeente Aalten', 'NL.03.0197', 'ASCII:Gemeente Aalten;ID:2760122', '20132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20132', '112', '22009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22010', '1079', '1', 'Gemeente Aalsmeer', 'NL.07.0358', 'ASCII:Gemeente Aalsmeer;ID:2760133', '20133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20133', '112', '22010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22011', '1079', '1', 'Gemeente Aalburg', 'NL.06.0738', 'ASCII:Gemeente Aalburg;ID:2760143', '20134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20134', '112', '22011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.0738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22012', '1079', '1', 'Gemeente Wijdemeren', 'NL.07.1696', 'ASCII:Wijdemeren;ID:3345301', '20135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20135', '112', '22012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.1696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22013', '1079', '1', 'Gemeente Moerdijk', 'NL.06.1709', 'ASCII:Gemeente Moerdijk;ID:6251995', '20136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20136', '112', '22013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22014', '1079', '1', 'Gemeente Koggenland', 'NL.07.1598', 'ASCII:Gemeente Koggenland;ID:6544220', '20137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20137', '112', '22014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.1598» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22015', '1079', '1', 'Gemeente Pijnacker-Nootdorp', 'NL.11.1926', 'ASCII:Gemeente Pijnacker-Nootdorp;ID:6544221', '20138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20138', '112', '22015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.1926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22016', '1079', '1', 'Oude IJsselstreek', 'NL.03.1509', 'ASCII:Oude IJsselstreek;ID:6544222', '20139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20139', '112', '22016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.1509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22017', '1079', '1', 'Gemeente Kaag en Braassem', 'NL.11.1884', 'ASCII:Gemeente Kaag en Braassem;ID:6544223', '20140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20140', '112', '22017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.1884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22018', '1079', '1', 'Gemeente Reiderland', 'NL.04.1661', 'ASCII:Gemeente Reiderland;ID:6544224', '20141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20141', '112', '22018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.1661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22019', '1079', '1', 'Gulpen-Wittem', 'NL.05.1729', 'ASCII:Gulpen-Wittem;ID:6544225', '20142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20142', '112', '22019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.1729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22020', '1079', '1', 'Gemeente Leudal', 'NL.05.1640', 'ASCII:Gemeente Leudal;ID:6544226', '20143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20143', '112', '22020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.1640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22021', '1079', '1', 'Gemeente De Wolden', 'NL.01.1690', 'ASCII:Gemeente De Wolden;ID:6544227', '20144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20144', '112', '22021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.1690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22022', '1079', '1', 'Oost Gelre', 'NL.03.1586', 'ASCII:Oost Gelre;ID:6544228', '20145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20145', '112', '22022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.1586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22023', '1079', '1', 'Gemeente De Marne', 'NL.04.1663', 'ASCII:Gemeente De Marne;ID:6544229', '20146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20146', '112', '22023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.1663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22024', '1079', '1', 'Gemeente Rijssen-Holten', 'NL.15.1742', 'ASCII:Gemeente Rijssen-Holten;ID:6544230', '20147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20147', '112', '22024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.1742» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22025', '1079', '1', 'Gemeente Menterwolde', 'NL.04.1987', 'ASCII:Gemeente Menterwolde;ID:6544231', '20148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20148', '112', '22025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.1987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22026', '1079', '1', 'Gemeente Geldrop-Mierlo', 'NL.06.1771', 'ASCII:Gemeente Geldrop-Mierlo;ID:6544232', '20149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20149', '112', '22026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22027', '1079', '1', 'Gemeente Horst aan de Maas', 'NL.05.1507', 'ASCII:Gemeente Horst aan de Maas;ID:6544233', '20150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20150', '112', '22027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.1507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22028', '1079', '1', 'Gemeente Pekela', 'NL.04.0765', 'ASCII:Gemeente Pekela;ID:6544234', '20151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20151', '112', '22028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.0765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22029', '1079', '1', 'Gemeente Steenwijkerland', 'NL.15.1708', 'ASCII:Gemeente Steenwijkerland;ID:6544235', '20152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20152', '112', '22029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.1708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22030', '1079', '1', 'Gemeente Lingewaard', 'NL.03.1705', 'ASCII:Gemeente Lingewaard;ID:6544236', '20153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20153', '112', '22030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.1705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22031', '1079', '1', 'Gemeente Giessenlanden', 'NL.11.0689', 'ASCII:Gemeente Giessenlanden;ID:6544237', '20154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20154', '112', '22031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22032', '1079', '1', 'Gemeente Stede Broec', 'NL.07.0532', 'ASCII:Gemeente Stede Broec;ID:6544238', '20155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20155', '112', '22032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22033', '1079', '1', 'Gemeente Westerveld', 'NL.01.1701', 'ASCII:Gemeente Westerveld;ID:6544239', '20156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20156', '112', '22033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.1701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22034', '1079', '1', 'Gemeente Binnenmaas', 'NL.11.0585', 'ASCII:Gemeente Binnenmaas;ID:6544240', '20157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20157', '112', '22034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22035', '1079', '1', 'Gemeente Bernisse', 'NL.11.0568', 'ASCII:Gemeente Bernisse;ID:6544241', '20158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20158', '112', '22035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22036', '1079', '1', 'Gemeente Albrandswaard', 'NL.11.0613', 'ASCII:Gemeente Albrandswaard;ID:6544242', '20159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20159', '112', '22036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22037', '1079', '1', 'Gemeente Lingewaal', 'NL.03.0733', 'ASCII:Gemeente Lingewaal;ID:6544243', '20160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20160', '112', '22037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22038', '1079', '1', 'Gemeente Maasgouw', 'NL.05.1641', 'ASCII:Gemeente Maasgouw;ID:6544244', '20161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20161', '112', '22038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.1641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22039', '1079', '1', 'Gemeente Twenterand', 'NL.15.1700', 'ASCII:Gemeente Twenterand;ID:6544245', '20162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20162', '112', '22039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.1700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22040', '1079', '1', 'Gemeente Olst-Wijhe', 'NL.15.1773', 'ASCII:Gemeente Olst-Wijhe;ID:6544248', '20163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20163', '112', '22040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.1773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22041', '1079', '1', 'Gemeente Alphen-Chaam', 'NL.06.1723', 'ASCII:Gemeente Alphen-Chaam;ID:6544249', '20164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20164', '112', '22041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22042', '1079', '1', 'Gemeente De Ronde Venen', 'NL.09.0736', 'ASCII:Gemeente De Ronde Venen;ID:6544250', '20165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20165', '112', '22042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.09.0736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22043', '1079', '1', 'Schouwen-Duiveland', 'NL.10.1676', 'ASCII:Schouwen-Duiveland;ID:6544251', '20166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20166', '112', '22043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.1676» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22044', '1079', '1', 'Gemeente Leidschendam-Voorburg', 'NL.11.1916', 'ASCII:Gemeente Leidschendam-Voorburg;ID:6544252', '20167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20167', '112', '22044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.1916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22045', '1079', '1', 'Gemeente Noord-Beveland', 'NL.10.1695', 'ASCII:Gemeente Noord-Beveland;ID:6544253', '20168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20168', '112', '22045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.10.1695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22046', '1079', '1', 'Gemeente Drechterland', 'NL.07.0498', 'ASCII:Gemeente Drechterland;ID:6544254', '20169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20169', '112', '22046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22047', '1079', '1', 'Gemeente Sittard-Geleen', 'NL.05.1883', 'ASCII:Gemeente Sittard-Geleen;ID:6544255', '20170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20170', '112', '22047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.1883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22048', '1079', '1', 'Gemeente Montferland', 'NL.03.1955', 'ASCII:Gemeente Montferland;ID:6544256', '20171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20171', '112', '22048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.1955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22049', '1079', '1', 'Gemeente Zevenhuizen-Moerkapelle', 'NL.11.1666', 'ASCII:Gemeente Zevenhuizen-Moerkapelle;ID:6544257', '20172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20172', '112', '22049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.1666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22050', '1079', '1', 'Landgraaf', 'NL.05.0882', 'ASCII:Landgraaf;ID:6544258', '20173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20173', '112', '22050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22051', '1079', '1', 'Gemeente Almere', 'NL.16.0034', 'ASCII:Gemeente Almere;ID:6544259', '20174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20174', '112', '22051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.16.0034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22052', '1079', '1', 'Gemeente Zwartewaterland', 'NL.15.1896', 'ASCII:Gemeente Zwartewaterland;ID:6544260', '20175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20175', '112', '22052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.1896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22053', '1079', '1', 'Gemeente Westland', 'NL.11.1783', 'ASCII:Gemeente Westland;ID:6544261', '20176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20176', '112', '22053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.1783» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22054', '1079', '1', 'Gemeente Midden-Delfland', 'NL.11.1842', 'ASCII:Gemeente Midden-Delfland;ID:6544262', '20177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20177', '112', '22054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.1842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22055', '1079', '1', 'Gemeente Wormerland', 'NL.07.0880', 'ASCII:Gemeente Wormerland;ID:6544263', '20178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20178', '112', '22055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.07.0880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22056', '1079', '1', 'Gemeente Roerdalen', 'NL.05.1669', 'ASCII:Gemeente Roerdalen;ID:6544264', '20179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20179', '112', '22056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.1669» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22057', '1079', '1', 'Gemeente West Maas en Waal', 'NL.03.0668', 'ASCII:Gemeente West Maas en Waal;ID:6544265', '20180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20180', '112', '22057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22058', '1079', '1', 'Gemeente Laarbeek', 'NL.06.1659', 'ASCII:Gemeente Laarbeek;ID:6544266', '20181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20181', '112', '22058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22059', '1079', '1', 'Gemeente Zederik', 'NL.11.0707', 'ASCII:Gemeente Zederik;ID:6544267', '20182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20182', '112', '22059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22060', '1079', '1', 'Gemeente Bernheze', 'NL.06.1721', 'ASCII:Gemeente Bernheze;ID:6544268', '20183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20183', '112', '22060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22061', '1079', '1', 'Gemeente Neder-Betuwe', 'NL.03.1740', 'ASCII:Gemeente Neder-Betuwe;ID:6544269', '20184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20184', '112', '22061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.1740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22062', '1079', '1', 'Gemeente Liesveld', 'NL.11.0694', 'ASCII:Gemeente Liesveld;ID:6544270', '20185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20185', '112', '22062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0694» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22063', '1079', '1', 'Gemeente Halderberge', 'NL.06.1655', 'ASCII:Gemeente Halderberge;ID:6544271', '20186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20186', '112', '22063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22064', '1079', '1', 'Gemeente Graafstroom', 'NL.11.0693', 'ASCII:Gemeente Graafstroom;ID:6544272', '20187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20187', '112', '22064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22065', '1079', '1', 'Gemeente Rijnwoude', 'NL.11.1672', 'ASCII:Gemeente Rijnwoude;ID:6544273', '20188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20188', '112', '22065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.1672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22066', '1079', '1', 'Gemeente Rijnwaarden', 'NL.03.0196', 'ASCII:Gemeente Rijnwaarden;ID:6544274', '20189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20189', '112', '22066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22067', '1079', '1', 'Gemeente Overbetuwe', 'NL.03.1734', 'ASCII:Gemeente Overbetuwe;ID:6544276', '20190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20190', '112', '22067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.1734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22068', '1079', '1', 'Gemeente Heeze-Leende', 'NL.06.1658', 'ASCII:Gemeente Heeze-Leende;ID:6544277', '20191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20191', '112', '22068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22069', '1079', '1', 'Gemeente Eemsmond', 'NL.04.1651', 'ASCII:Gemeente Eemsmond;ID:6544278', '20192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20192', '112', '22069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.04.1651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22070', '1079', '1', 'Gemeente Gemert-Bakel', 'NL.06.1652', 'ASCII:Gemeente Gemert-Bakel;ID:6544279', '20193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20193', '112', '22070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22071', '1079', '1', 'Gemeente Reusel-De Mierden', 'NL.06.1667', 'ASCII:Gemeente Reusel-De Mierden;ID:6544280', '20194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20194', '112', '22071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22072', '1079', '1', 'Gemeente Nederlek', 'NL.11.0643', 'ASCII:Gemeente Nederlek;ID:6544281', '20195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20195', '112', '22072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0643» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22073', '1079', '1', 'Gemeente Tynaarlo', 'NL.01.1730', 'ASCII:Gemeente Tynaarlo;ID:6544282', '20196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20196', '112', '22073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.1730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22074', '1079', '1', 'Gemeente Maasdonk', 'NL.06.1671', 'ASCII:Gemeente Maasdonk;ID:6544283', '20197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20197', '112', '22074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22075', '1079', '1', 'Gemeente Cromstrijen', 'NL.11.0611', 'ASCII:Gemeente Cromstrijen;ID:6544284', '20198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20198', '112', '22075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22076', '1079', '1', 'Gemeente Dinkelland', 'NL.15.1774', 'ASCII:Gemeente Dinkelland;ID:6544285', '20199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20199', '112', '22076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.1774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22077', '1079', '1', 'Berkelland', 'NL.03.1859', 'ASCII:Berkelland;ID:6544286', '20200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20200', '112', '22077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.1859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22078', '1079', '1', 'Gemeente Noordenveld', 'NL.01.1699', 'ASCII:Gemeente Noordenveld;ID:6544287', '20201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20201', '112', '22078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.1699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22079', '1079', '1', 'Gemeente Cranendonck', 'NL.06.1706', 'ASCII:Gemeente Cranendonck;ID:6544288', '20202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20202', '112', '22079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22080', '1079', '1', 'Gemeente Hof van Twente', 'NL.15.1735', 'ASCII:Gemeente Hof van Twente;ID:6544289', '20203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20203', '112', '22080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.15.1735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22081', '1079', '1', 'Gemeente Bronckhorst', 'NL.03.1876', 'ASCII:Gemeente Bronckhorst;ID:6544290', '20204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20204', '112', '22081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.1876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22082', '1079', '1', 'Gemeente Lansingerland', 'NL.11.1621', 'ASCII:Gemeente Lansingerland;ID:6544291', '20205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20205', '112', '22082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.1621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22083', '1079', '1', 'Gemeente Landerd', 'NL.06.1685', 'ASCII:Gemeente Landerd;ID:6544292', '20206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20206', '112', '22083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.06.1685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22084', '1079', '1', 'Gemeente Teylingen', 'NL.11.1525', 'ASCII:Gemeente Teylingen;ID:6544293', '20207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20207', '112', '22084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.1525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22085', '1079', '1', 'Gemeente Neerijnen', 'NL.03.0304', 'ASCII:Gemeente Neerijnen;ID:6544294', '20208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20208', '112', '22085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.03.0304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22086', '1079', '1', 'Gemeente Korendijk', 'NL.11.0588', 'ASCII:Gemeente Korendijk;ID:6544295', '20209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20209', '112', '22086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.11.0588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22087', '1079', '1', 'Gemeente Aa en Hunze', 'NL.01.1680', 'ASCII:Gemeente Aa en Hunze;ID:6544296', '20210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20210', '112', '22087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.1680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22088', '1079', '1', 'Gemeente Midden-Drenthe', 'NL.01.1731', 'ASCII:Gemeente Midden-Drenthe;ID:6544297', '20211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20211', '112', '22088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.01.1731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22089', '1079', '1', 'Gemeente Onderbanken', 'NL.05.0881', 'ASCII:Gemeente Onderbanken;ID:6544298', '20212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20212', '112', '22089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22090', '1079', '1', 'Valkenburg aan de Geul', 'NL.05.0994', 'ASCII:Valkenburg aan de Geul;ID:6544299', '20213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20213', '112', '22090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.05.0994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22091', '1079', '1', 'Gemeente Littenseradiel', 'NL.02.0140', 'ASCII:Gemeente Littenseradiel;ID:6544300', '20214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20214', '112', '22091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22092', '1079', '1', 'Gemeente Gaasterlân-Sleat', 'NL.02.0653', 'ASCII:Gemeente Gaasterlan-Sleat;ID:6544301', '20215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20215', '112', '22092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22093', '1079', '1', 'Gemeente Nijefurd', 'NL.02.0104', 'ASCII:Gemeente Nijefurd;ID:6544302', '20216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20216', '112', '22093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22094', '1079', '1', 'Gemeente Skarsterlân', 'NL.02.0051', 'ASCII:Gemeente Skarsterlan;ID:6544303', '20217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20217', '112', '22094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22095', '1079', '1', 'Gemeente Tytsjerksteradiel', 'NL.02.0737', 'ASCII:Gemeente Tytsjerksteradiel;ID:6544304', '20218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20218', '112', '22095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22096', '1079', '1', 'Gemeente Wûnseradiel', 'NL.02.0710', 'ASCII:Gemeente Wunseradiel;ID:6544305', '20219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20219', '112', '22096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NL.02.0710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22097', '1079', '1', 'Tana', 'NO.05.2025', 'ASCII:Tana;ID:777197', '20220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20220', '112', '22097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22098', '1079', '1', 'Storfjord', 'NO.18.1939', 'ASCII:Storfjord;ID:777394', '20221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20221', '112', '22098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22099', '1079', '1', 'Sør-Varanger', 'NO.05.2030', 'ASCII:Sor-Varanger;ID:777554', '20222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20222', '112', '22099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22100', '1079', '1', 'Skjervøy', 'NO.18.1941', 'ASCII:Skjervoy;ID:777680', '20223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20223', '112', '22100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22101', '1079', '1', 'Nordreisa', 'NO.18.1942', 'ASCII:Nordreisa;ID:778430', '20224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20224', '112', '22101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22102', '1079', '1', 'Nordkapp', 'NO.05.2019', 'ASCII:Nordkapp;ID:778459', '20225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20225', '112', '22102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22103', '1079', '1', 'Nesseby', 'NO.05.2027', 'ASCII:Nesseby;ID:778559', '20226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20226', '112', '22103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22104', '1079', '1', 'Måsøy', 'NO.05.2018', 'ASCII:Masoy;ID:778730', '20227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20227', '112', '22104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22105', '1079', '1', 'Lyngen', 'NO.18.1938', 'ASCII:Lyngen;ID:778840', '20228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20228', '112', '22105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22106', '1079', '1', 'Loppa', 'NO.05.2014', 'ASCII:Loppa;ID:778877', '20229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20229', '112', '22106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22107', '1079', '1', 'Lebesby', 'NO.05.2022', 'ASCII:Lebesby;ID:778967', '20230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20230', '112', '22107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22108', '1079', '1', 'Kvalsund', 'NO.05.2017', 'ASCII:Kvalsund;ID:779143', '20231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20231', '112', '22108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22109', '1079', '1', 'Kvænangen', 'NO.18.1943', 'ASCII:Kvaenangen;ID:779159', '20232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20232', '112', '22109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22110', '1079', '1', 'Kautokeino', 'NO.05.2011', 'ASCII:Kautokeino;ID:779327', '20233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20233', '112', '22110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22111', '1079', '1', 'Karlsøy', 'NO.18.1936', 'ASCII:Karlsoy;ID:779339', '20234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20234', '112', '22111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22112', '1079', '1', 'Karasjok', 'NO.05.2021', 'ASCII:Karasjok;ID:779349', '20235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20235', '112', '22112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22113', '1079', '1', 'Kåfjord', 'NO.18.1940', 'ASCII:Kafjord;ID:779367', '20236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20236', '112', '22113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22114', '1079', '1', 'Hasvik', 'NO.05.2015', 'ASCII:Hasvik;ID:779641', '20237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20237', '112', '22114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22115', '1079', '1', 'Gamvik', 'NO.05.2023', 'ASCII:Gamvik;ID:779933', '20238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20238', '112', '22115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22116', '1079', '1', 'Berlevåg', 'NO.05.2024', 'ASCII:Berlevag;ID:780686', '20239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20239', '112', '22116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22117', '1079', '1', 'Båtsfjord', 'NO.05.2028', 'ASCII:Batsfjord;ID:780714', '20240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20240', '112', '22117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22118', '1079', '1', 'Alta', 'NO.05.2012', 'ASCII:Alta;ID:780946', '20241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20241', '112', '22118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22119', '1079', '1', 'Voss', 'NO.07.1235', 'ASCII:Voss;ID:3131325', '20242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20242', '112', '22119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22120', '1079', '1', 'Volda', 'NO.08.1519', 'ASCII:Volda;ID:3131447', '20243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20243', '112', '22120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22121', '1079', '1', 'Vikna', 'NO.10.1750', 'ASCII:Vikna;ID:3131656', '20244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20244', '112', '22121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22122', '1079', '1', 'Vik', 'NO.15.1417', 'ASCII:Vik;ID:3131675', '20245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20245', '112', '22122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22123', '1079', '1', 'Vevelstad', 'NO.09.1816', 'ASCII:Vevelstad;ID:3131900', '20246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20246', '112', '22123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22124', '1079', '1', 'Vestre Toten', 'NO.11.0529', 'ASCII:Vestre Toten;ID:3131957', '20247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20247', '112', '22124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22125', '1079', '1', 'Vestre Slidre', 'NO.11.0543', 'ASCII:Vestre Slidre;ID:3131961', '20248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20248', '112', '22125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22126', '1079', '1', 'Lillesand', 'NO.02.0926', 'ASCII:Lillesand;ID:3131969', '20249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20249', '112', '22126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22127', '1079', '1', 'Vestby', 'NO.01.0211', 'ASCII:Vestby;ID:3132050', '20250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20250', '112', '22127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22128', '1079', '1', 'Verran', 'NO.10.1724', 'ASCII:Verran;ID:3132142', '20251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20251', '112', '22128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22129', '1079', '1', 'Verdal', 'NO.10.1721', 'ASCII:Verdal;ID:3132178', '20252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20252', '112', '22129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22130', '1079', '1', 'Vennesla', 'NO.19.1014', 'ASCII:Vennesla;ID:3132206', '20253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20253', '112', '22130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22131', '1079', '1', 'Vegårshei', 'NO.02.0912', 'ASCII:Vegarshei;ID:3132337', '20254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20254', '112', '22131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22132', '1079', '1', 'Vefsn', 'NO.09.1824', 'ASCII:Vefsn;ID:3132346', '20255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20255', '112', '22132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22133', '1079', '1', 'Vanylven', 'NO.08.1511', 'ASCII:Vanylven;ID:3132715', '20256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20256', '112', '22133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22134', '1079', '1', 'Valle', 'NO.02.0940', 'ASCII:Valle;ID:3132848', '20257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20257', '112', '22134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22135', '1079', '1', 'Våle', 'NO.20.0716', 'ASCII:Vale;ID:3132904', '20258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20258', '112', '22135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22136', '1079', '1', 'Vågan', 'NO.09.1865', 'ASCII:Vagan;ID:3133044', '20259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20259', '112', '22136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22137', '1079', '1', 'Vågå', 'NO.11.0515', 'ASCII:Vaga;ID:3133054', '20260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20260', '112', '22137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22138', '1079', '1', 'Værøy', 'NO.09.1857', 'ASCII:Vaeroy;ID:3133071', '20261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20261', '112', '22138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22139', '1079', '1', 'Utsira', 'NO.14.1151', 'ASCII:Utsira;ID:3133144', '20262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20262', '112', '22139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22140', '1079', '1', 'Ulvik', 'NO.07.1233', 'ASCII:Ulvik;ID:3133311', '20263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20263', '112', '22140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22141', '1079', '1', 'Ulstein', 'NO.08.1516', 'ASCII:Ulstein;ID:3133350', '20264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20264', '112', '22141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22142', '1079', '1', 'Ullensvang', 'NO.07.1231', 'ASCII:Ullensvang;ID:3133379', '20265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20265', '112', '22142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22143', '1079', '1', 'Ullensaker', 'NO.01.0235', 'ASCII:Ullensaker;ID:3133381', '20266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20266', '112', '22143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22144', '1079', '1', 'Tysvær', 'NO.14.1146', 'ASCII:Tysvaer;ID:3133447', '20267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20267', '112', '22144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1146» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22145', '1079', '1', 'Tysnes', 'NO.07.1223', 'ASCII:Tysnes;ID:3133472', '20268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20268', '112', '22145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22146', '1079', '1', 'Tysfjord', 'NO.09.1850', 'ASCII:Tysfjord;ID:3133482', '20269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20269', '112', '22146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22147', '1079', '1', 'Tynset', 'NO.06.0437', 'ASCII:Tynset;ID:3133497', '20270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20270', '112', '22147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22148', '1079', '1', 'Tydal', 'NO.16.1665', 'ASCII:Tydal;ID:3133517', '20271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20271', '112', '22148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22149', '1079', '1', 'Tvedestrand', 'NO.02.0914', 'ASCII:Tvedestrand;ID:3133680', '20272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20272', '112', '22149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22150', '1079', '1', 'Tustna', 'NO.08.1572', 'ASCII:Tustna;ID:3133704', '20273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20273', '112', '22150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22151', '1079', '1', 'Trysil', 'NO.06.0428', 'ASCII:Trysil;ID:3133817', '20274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20274', '112', '22151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22152', '1079', '1', 'Trondheim', 'NO.16.1601', 'ASCII:Trondheim;ID:3133881', '20275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20275', '112', '22152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22153', '1079', '1', 'Trøgstad', 'NO.13.0122', 'ASCII:Trogstad;ID:3133977', '20276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20276', '112', '22153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22154', '1079', '1', 'Tranøy', 'NO.18.1927', 'ASCII:Tranoy;ID:3134052', '20277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20277', '112', '22154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22155', '1079', '1', 'Træna', 'NO.09.1835', 'ASCII:Traena;ID:3134084', '20278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20278', '112', '22155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22156', '1079', '1', 'Torsken', 'NO.18.1928', 'ASCII:Torsken;ID:3134206', '20279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20279', '112', '22156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22157', '1079', '1', 'Tjøme', 'NO.20.0723', 'ASCII:Tjome;ID:3134520', '20280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20280', '112', '22157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22158', '1079', '1', 'Tjeldsund', 'NO.09.1852', 'ASCII:Tjeldsund;ID:3134549', '20281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20281', '112', '22158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22159', '1079', '1', 'Tinn', 'NO.17.0826', 'ASCII:Tinn;ID:3134592', '20282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20282', '112', '22159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22160', '1079', '1', 'Tingvoll', 'NO.08.1560', 'ASCII:Tingvoll;ID:3134596', '20283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20283', '112', '22160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22161', '1079', '1', 'Time', 'NO.14.1121', 'ASCII:Time;ID:3134627', '20284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20284', '112', '22161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22162', '1079', '1', 'Sykkylven', 'NO.08.1528', 'ASCII:Sykkylven;ID:3134983', '20285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20285', '112', '22162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22163', '1079', '1', 'Sveio', 'NO.07.1216', 'ASCII:Sveio;ID:3135136', '20286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20286', '112', '22163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22164', '1079', '1', 'Surnadal', 'NO.08.1566', 'ASCII:Surnadal;ID:3135358', '20287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20287', '112', '22164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1566» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22165', '1079', '1', 'Sunndal', 'NO.08.1563', 'ASCII:Sunndal;ID:3135381', '20288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20288', '112', '22165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22166', '1079', '1', 'Sund', 'NO.07.1245', 'ASCII:Sund;ID:3135436', '20289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20289', '112', '22166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22167', '1079', '1', 'Stryn', 'NO.15.1449', 'ASCII:Stryn;ID:3135597', '20290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20290', '112', '22167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1449» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22168', '1079', '1', 'Strand', 'NO.14.1130', 'ASCII:Strand;ID:3135788', '20291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20291', '112', '22168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22169', '1079', '1', 'Stranda', 'NO.08.1525', 'ASCII:Stranda;ID:3135806', '20292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20292', '112', '22169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22170', '1079', '1', 'Stor-Elvdal', 'NO.06.0430', 'ASCII:Stor-Elvdal;ID:3136387', '20293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20293', '112', '22170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22171', '1079', '1', 'Stord', 'NO.07.1221', 'ASCII:Stord;ID:3136522', '20294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20294', '112', '22171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22172', '1079', '1', 'Stordal', 'NO.08.1526', 'ASCII:Stordal;ID:3136539', '20295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20295', '112', '22172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22173', '1079', '1', 'Stokke', 'NO.20.0720', 'ASCII:Stokke;ID:3136717', '20296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20296', '112', '22173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22174', '1079', '1', 'Stjørdal', 'NO.10.1714', 'ASCII:Stjordal;ID:3136768', '20297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20297', '112', '22174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22175', '1079', '1', 'Steinkjer', 'NO.10.1702', 'ASCII:Steinkjer;ID:3136944', '20298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20298', '112', '22175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22176', '1079', '1', 'Steigen', 'NO.09.1848', 'ASCII:Steigen;ID:3137038', '20299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20299', '112', '22176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22177', '1079', '1', 'Stange', 'NO.06.0417', 'ASCII:Stange;ID:3137167', '20300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20300', '112', '22177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22178', '1079', '1', 'Spydeberg', 'NO.13.0123', 'ASCII:Spydeberg;ID:3137244', '20301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20301', '112', '22178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22179', '1079', '1', 'Sørum', 'NO.01.0226', 'ASCII:Sorum;ID:3137391', '20302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20302', '112', '22179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22180', '1079', '1', 'Sortland', 'NO.09.1870', 'ASCII:Sortland;ID:3137404', '20303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20303', '112', '22180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22181', '1079', '1', 'Sørreisa', 'NO.18.1925', 'ASCII:Sorreisa;ID:3137432', '20304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20304', '112', '22181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22182', '1079', '1', 'Sør-Odal', 'NO.06.0419', 'ASCII:Sor-Odal;ID:3137441', '20305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20305', '112', '22182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22183', '1079', '1', 'Sør-Fron', 'NO.11.0519', 'ASCII:Sor-Fron;ID:3137519', '20306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20306', '112', '22183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22184', '1079', '1', 'Sørfold', 'NO.09.1845', 'ASCII:Sorfold;ID:3137522', '20307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20307', '112', '22184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22185', '1079', '1', 'Sør-Aurdal', 'NO.11.0540', 'ASCII:Sor-Aurdal;ID:3137635', '20308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20308', '112', '22185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22186', '1079', '1', 'Audnedal', 'NO.19.1027', 'ASCII:Audnedal;ID:3137638', '20309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20309', '112', '22186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22187', '1079', '1', 'Søndre Land', 'NO.11.0536', 'ASCII:Sondre Land;ID:3137678', '20310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20310', '112', '22187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22188', '1079', '1', 'Sømna', 'NO.09.1812', 'ASCII:Somna;ID:3137700', '20311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20311', '112', '22188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22189', '1079', '1', 'Solund', 'NO.15.1412', 'ASCII:Solund;ID:3137740', '20312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20312', '112', '22189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22190', '1079', '1', 'Sola', 'NO.14.1124', 'ASCII:Sola;ID:3137941', '20313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20313', '112', '22190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22191', '1079', '1', 'Sokndal', 'NO.14.1111', 'ASCII:Sokndal;ID:3137953', '20314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20314', '112', '22191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22192', '1079', '1', 'Søgne', 'NO.19.1018', 'ASCII:Sogne;ID:3137970', '20315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20315', '112', '22192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22193', '1079', '1', 'Sogndal', 'NO.15.1420', 'ASCII:Sogndal;ID:3137974', '20316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20316', '112', '22193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22194', '1079', '1', 'Snillfjord', 'NO.16.1613', 'ASCII:Snillfjord;ID:3138047', '20317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20317', '112', '22194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22195', '1079', '1', 'Snåsa', 'NO.10.1736', 'ASCII:Snasa;ID:3138075', '20318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20318', '112', '22195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22196', '1079', '1', 'Smøla', 'NO.08.1573', 'ASCII:Smola;ID:3138113', '20319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20319', '112', '22196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22197', '1079', '1', 'Skodje', 'NO.08.1529', 'ASCII:Skodje;ID:3138746', '20320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20320', '112', '22197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22198', '1079', '1', 'Skjerstad', 'NO.09.1842', 'ASCII:Skjerstad;ID:3138837', '20321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20321', '112', '22198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22199', '1079', '1', 'Skjåk', 'NO.11.0513', 'ASCII:Skjak;ID:3138965', '20322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20322', '112', '22199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22200', '1079', '1', 'Skiptvet', 'NO.13.0127', 'ASCII:Skiptvet;ID:3139014', '20323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20323', '112', '22200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22201', '1079', '1', 'Ski', 'NO.01.0213', 'ASCII:Ski;ID:3139064', '20324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20324', '112', '22201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22202', '1079', '1', 'Skedsmo', 'NO.01.0231', 'ASCII:Skedsmo;ID:3139111', '20325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20325', '112', '22202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22203', '1079', '1', 'Skaun', 'NO.16.1657', 'ASCII:Skaun;ID:3139147', '20326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20326', '112', '22203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22204', '1079', '1', 'Skånland', 'NO.18.1913', 'ASCII:Skanland;ID:3139372', '20327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20327', '112', '22204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22205', '1079', '1', 'Sirdal', 'NO.19.1046', 'ASCII:Sirdal;ID:3139612', '20328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20328', '112', '22205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1046» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22206', '1079', '1', 'Siljan', 'NO.17.0811', 'ASCII:Siljan;ID:3139675', '20329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20329', '112', '22206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22207', '1079', '1', 'Sigdal', 'NO.04.0621', 'ASCII:Sigdal;ID:3139735', '20330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20330', '112', '22207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22208', '1079', '1', 'Seljord', 'NO.17.0828', 'ASCII:Seljord;ID:3139893', '20331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20331', '112', '22208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22209', '1079', '1', 'Selje', 'NO.15.1441', 'ASCII:Selje;ID:3139908', '20332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20332', '112', '22209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22210', '1079', '1', 'Sel', 'NO.11.0517', 'ASCII:Sel;ID:3139922', '20333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20333', '112', '22210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22211', '1079', '1', 'Selbu', 'NO.16.1664', 'ASCII:Selbu;ID:3139940', '20334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20334', '112', '22211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22212', '1079', '1', 'Sauherad', 'NO.17.0822', 'ASCII:Sauherad;ID:3140043', '20335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20335', '112', '22212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22213', '1079', '1', 'Sauda', 'NO.14.1135', 'ASCII:Sauda;ID:3140054', '20336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20336', '112', '22213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22214', '1079', '1', 'Sandøy', 'NO.08.1546', 'ASCII:Sandoy;ID:3140273', '20337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20337', '112', '22214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22215', '1079', '1', 'Samnanger', 'NO.07.1242', 'ASCII:Samnanger;ID:3140461', '20338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20338', '112', '22215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1242» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22216', '1079', '1', 'Saltdal', 'NO.09.1840', 'ASCII:Saltdal;ID:3140498', '20339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20339', '112', '22216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22217', '1079', '1', 'Salangen', 'NO.18.1923', 'ASCII:Salangen;ID:3140541', '20340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20340', '112', '22217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22218', '1079', '1', 'Rygge', 'NO.13.0136', 'ASCII:Rygge;ID:3140821', '20341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20341', '112', '22218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22219', '1079', '1', 'Røyrvik', 'NO.10.1739', 'ASCII:Royrvik;ID:3141059', '20342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20342', '112', '22219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22220', '1079', '1', 'Røyken', 'NO.04.0627', 'ASCII:Royken;ID:3141104', '20343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20343', '112', '22220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22221', '1079', '1', 'Røst', 'NO.09.1856', 'ASCII:Rost;ID:3141198', '20344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20344', '112', '22221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22222', '1079', '1', 'Rømskog', 'NO.13.0121', 'ASCII:Romskog;ID:3141407', '20345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20345', '112', '22222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22223', '1079', '1', 'Rollag', 'NO.04.0632', 'ASCII:Rollag;ID:3141467', '20346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20346', '112', '22223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22224', '1079', '1', 'Rødøy', 'NO.09.1836', 'ASCII:Rodoy;ID:3141588', '20347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20347', '112', '22224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22225', '1079', '1', 'Roan', 'NO.16.1632', 'ASCII:Roan;ID:3141654', '20348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20348', '112', '22225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22226', '1079', '1', 'Rissa', 'NO.16.1624', 'ASCII:Rissa;ID:3141725', '20349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20349', '112', '22226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22227', '1079', '1', 'Ringsaker', 'NO.06.0412', 'ASCII:Ringsaker;ID:3141831', '20350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20350', '112', '22227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22228', '1079', '1', 'Ringebu', 'NO.11.0520', 'ASCII:Ringebu;ID:3141849', '20351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20351', '112', '22228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22229', '1079', '1', 'Rindal', 'NO.08.1567', 'ASCII:Rindal;ID:3141865', '20352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20352', '112', '22229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1567» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22230', '1079', '1', 'Rennesøy', 'NO.14.1142', 'ASCII:Rennesoy;ID:3141965', '20353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20353', '112', '22230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1142» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22231', '1079', '1', 'Rennebu', 'NO.16.1635', 'ASCII:Rennebu;ID:3141967', '20354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20354', '112', '22231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22232', '1079', '1', 'Rendalen', 'NO.06.0432', 'ASCII:Rendalen;ID:3141977', '20355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20355', '112', '22232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22233', '1079', '1', 'Randaberg', 'NO.14.1127', 'ASCII:Randaberg;ID:3142395', '20356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20356', '112', '22233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22234', '1079', '1', 'Ramnes', 'NO.20.0718', 'ASCII:Ramnes;ID:3142475', '20357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20357', '112', '22234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22235', '1079', '1', 'Rakkestad', 'NO.13.0128', 'ASCII:Rakkestad;ID:3142518', '20358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20358', '112', '22235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22236', '1079', '1', 'Rælingen', 'NO.01.0228', 'ASCII:Raelingen;ID:3142561', '20359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20359', '112', '22236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22237', '1079', '1', 'Råde', 'NO.13.0135', 'ASCII:Rade;ID:3142567', '20360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20360', '112', '22237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22238', '1079', '1', 'Øystre Slidre', 'NO.11.0544', 'ASCII:Oystre Slidre;ID:3142751', '20361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20361', '112', '22238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22239', '1079', '1', 'øyer', 'NO.11.0521', 'ASCII:oyer;ID:3142849', '20362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20362', '112', '22239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22240', '1079', '1', 'Øvre Eiker', 'NO.04.0624', 'ASCII:Ovre Eiker;ID:3143010', '20363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20363', '112', '22240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22241', '1079', '1', 'Overhalla', 'NO.10.1744', 'ASCII:Overhalla;ID:3143058', '20364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20364', '112', '22241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22242', '1079', '1', 'Østre Toten', 'NO.11.0528', 'ASCII:Ostre Toten;ID:3143158', '20365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20365', '112', '22242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22243', '1079', '1', 'Osen', 'NO.16.1633', 'ASCII:Osen;ID:3143262', '20366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20366', '112', '22243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22244', '1079', '1', 'Ørsta', 'NO.08.1520', 'ASCII:Orsta;ID:3143333', '20367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20367', '112', '22244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22245', '1079', '1', 'Ørskog', 'NO.08.1523', 'ASCII:Orskog;ID:3143338', '20368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20368', '112', '22245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22246', '1079', '1', 'Ørland', 'NO.16.1621', 'ASCII:Orland;ID:3143410', '20369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20369', '112', '22246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22247', '1079', '1', 'Orkdal', 'NO.16.1638', 'ASCII:Orkdal;ID:3143419', '20370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20370', '112', '22247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22248', '1079', '1', 'Oppegård', 'NO.01.0217', 'ASCII:Oppegard;ID:3143498', '20371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20371', '112', '22248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22249', '1079', '1', 'Oppdal', 'NO.16.1634', 'ASCII:Oppdal;ID:3143508', '20372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20372', '112', '22249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22250', '1079', '1', 'Ølen', 'NO.07.1214', 'ASCII:Olen;ID:3143627', '20373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20373', '112', '22250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22251', '1079', '1', 'Øksnes', 'NO.09.1868', 'ASCII:Oksnes;ID:3143705', '20374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20374', '112', '22251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22252', '1079', '1', 'Odda', 'NO.07.1228', 'ASCII:Odda;ID:3143828', '20375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20375', '112', '22252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22253', '1079', '1', 'Nøtterøy', 'NO.20.0722', 'ASCII:Notteroy;ID:3144070', '20376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20376', '112', '22253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22254', '1079', '1', 'Nordre Land', 'NO.11.0538', 'ASCII:Nordre Land;ID:3144229', '20377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20377', '112', '22254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22255', '1079', '1', 'Nord-Odal', 'NO.06.0418', 'ASCII:Nord-Odal;ID:3144273', '20378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20378', '112', '22255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22256', '1079', '1', 'Nord-Fron', 'NO.11.0516', 'ASCII:Nord-Fron;ID:3144350', '20379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20379', '112', '22256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22257', '1079', '1', 'Norddal', 'NO.08.1524', 'ASCII:Norddal;ID:3144404', '20380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20380', '112', '22257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22258', '1079', '1', 'Nord-Aurdal', 'NO.11.0542', 'ASCII:Nord-Aurdal;ID:3144466', '20381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20381', '112', '22258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0542» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22259', '1079', '1', 'Nittedal', 'NO.01.0233', 'ASCII:Nittedal;ID:3144549', '20382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20382', '112', '22259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22260', '1079', '1', 'Nissedal', 'NO.17.0830', 'ASCII:Nissedal;ID:3144561', '20383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20383', '112', '22260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22261', '1079', '1', 'Nesset', 'NO.08.1543', 'ASCII:Nesset;ID:3144640', '20384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20384', '112', '22261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22262', '1079', '1', 'Nesodden', 'NO.01.0216', 'ASCII:Nesodden;ID:3144656', '20385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20385', '112', '22262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22263', '1079', '1', 'Nesna', 'NO.09.1828', 'ASCII:Nesna;ID:3144660', '20386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20386', '112', '22263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22264', '1079', '1', 'Nedre Eiker', 'NO.04.0625', 'ASCII:Nedre Eiker;ID:3144882', '20387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20387', '112', '22264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22265', '1079', '1', 'Naustdal', 'NO.15.1433', 'ASCII:Naustdal;ID:3144951', '20388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20388', '112', '22265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22266', '1079', '1', 'Nannestad', 'NO.01.0238', 'ASCII:Nannestad;ID:3145014', '20389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20389', '112', '22266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22267', '1079', '1', 'Namsskogan', 'NO.10.1740', 'ASCII:Namsskogan;ID:3145020', '20390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20390', '112', '22267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22268', '1079', '1', 'Namdalseid', 'NO.10.1725', 'ASCII:Namdalseid;ID:3145028', '20391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20391', '112', '22268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22269', '1079', '1', 'Nærøy', 'NO.10.1751', 'ASCII:Naeroy;ID:3145065', '20392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20392', '112', '22269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22270', '1079', '1', 'Mosvik', 'NO.10.1723', 'ASCII:Mosvik;ID:3145343', '20393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20393', '112', '22270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22271', '1079', '1', 'Moskenes', 'NO.09.1874', 'ASCII:Moskenes;ID:3145382', '20394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20394', '112', '22271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22272', '1079', '1', 'Molde', 'NO.08.1502', 'ASCII:Molde;ID:3145582', '20395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20395', '112', '22272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22273', '1079', '1', 'Modum', 'NO.04.0623', 'ASCII:Modum;ID:3145690', '20396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20396', '112', '22273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22274', '1079', '1', 'Modalen', 'NO.07.1252', 'ASCII:Modalen;ID:3145691', '20397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20397', '112', '22274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22275', '1079', '1', 'Meråker', 'NO.10.1711', 'ASCII:Meraker;ID:3146022', '20398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20398', '112', '22275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22276', '1079', '1', 'Meløy', 'NO.09.1837', 'ASCII:Meloy;ID:3146067', '20399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20399', '112', '22276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1837» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22277', '1079', '1', 'Melhus', 'NO.16.1653', 'ASCII:Melhus;ID:3146123', '20400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20400', '112', '22277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22278', '1079', '1', 'Meldal', 'NO.16.1636', 'ASCII:Meldal;ID:3146152', '20401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20401', '112', '22278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22279', '1079', '1', 'Meland', 'NO.07.1256', 'ASCII:Meland;ID:3146170', '20402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20402', '112', '22279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22280', '1079', '1', 'Masfjorden', 'NO.07.1266', 'ASCII:Masfjorden;ID:3146314', '20403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20403', '112', '22280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22281', '1079', '1', 'Malvik', 'NO.16.1663', 'ASCII:Malvik;ID:3146469', '20404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20404', '112', '22281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22282', '1079', '1', 'Målselv', 'NO.18.1924', 'ASCII:Malselv;ID:3146478', '20405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20405', '112', '22282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22283', '1079', '1', 'Lyngdal', 'NO.19.1032', 'ASCII:Lyngdal;ID:3146682', '20406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20406', '112', '22283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22284', '1079', '1', 'Luster', 'NO.15.1426', 'ASCII:Luster;ID:3146725', '20407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20407', '112', '22284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22285', '1079', '1', 'Lurøy', 'NO.09.1834', 'ASCII:Luroy;ID:3146743', '20408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20408', '112', '22285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22286', '1079', '1', 'Lunner', 'NO.11.0533', 'ASCII:Lunner;ID:3146759', '20409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20409', '112', '22286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22287', '1079', '1', 'Lund', 'NO.14.1112', 'ASCII:Lund;ID:3146777', '20410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20410', '112', '22287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22288', '1079', '1', 'Løten', 'NO.06.0415', 'ASCII:Loten;ID:3146896', '20411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20411', '112', '22288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22289', '1079', '1', 'Lørenskog', 'NO.01.0230', 'ASCII:Lorenskog;ID:3146936', '20412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20412', '112', '22289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22290', '1079', '1', 'Lom', 'NO.11.0514', 'ASCII:Lom;ID:3147022', '20413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20413', '112', '22290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22291', '1079', '1', 'Lødingen', 'NO.09.1851', 'ASCII:Lodingen;ID:3147101', '20414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20414', '112', '22291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22292', '1079', '1', 'Lindås', 'NO.07.1263', 'ASCII:Lindas;ID:3147439', '20415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20415', '112', '22292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22293', '1079', '1', 'Lier', 'NO.04.0626', 'ASCII:Lier;ID:3147541', '20416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20416', '112', '22293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22294', '1079', '1', 'Lesja', 'NO.11.0512', 'ASCII:Lesja;ID:3147714', '20417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20417', '112', '22294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22295', '1079', '1', 'Lenvik', 'NO.18.1931', 'ASCII:Lenvik;ID:3147742', '20418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20418', '112', '22295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1931» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22296', '1079', '1', 'Leksvik', 'NO.10.1718', 'ASCII:Leksvik;ID:3147775', '20419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20419', '112', '22296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22297', '1079', '1', 'Leka', 'NO.10.1755', 'ASCII:Leka;ID:3147796', '20420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20420', '112', '22297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22298', '1079', '1', 'Leirfjord', 'NO.09.1822', 'ASCII:Leirfjord;ID:3147877', '20421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20421', '112', '22298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22299', '1079', '1', 'Leikanger', 'NO.15.1419', 'ASCII:Leikanger;ID:3147943', '20422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20422', '112', '22299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22300', '1079', '1', 'Lavangen', 'NO.18.1920', 'ASCII:Lavangen;ID:3147989', '20423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20423', '112', '22300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22301', '1079', '1', 'Lærdal', 'NO.15.1422', 'ASCII:Laerdal;ID:3148572', '20424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20424', '112', '22301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22302', '1079', '1', 'Kvitsøy', 'NO.14.1144', 'ASCII:Kvitsoy;ID:3148673', '20425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20425', '112', '22302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22303', '1079', '1', 'Kviteseid', 'NO.17.0829', 'ASCII:Kviteseid;ID:3148725', '20426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20426', '112', '22303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22304', '1079', '1', 'Kvinnherad', 'NO.07.1224', 'ASCII:Kvinnherad;ID:3148768', '20427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20427', '112', '22304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22305', '1079', '1', 'Kvinesdal', 'NO.19.1037', 'ASCII:Kvinesdal;ID:3148775', '20428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20428', '112', '22305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22306', '1079', '1', 'Kvam', 'NO.07.1238', 'ASCII:Kvam;ID:3149017', '20429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20429', '112', '22306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22307', '1079', '1', 'Kvæfjord', 'NO.18.1911', 'ASCII:Kvaefjord;ID:3149109', '20430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20430', '112', '22307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22308', '1079', '1', 'Krødsherad', 'NO.04.0622', 'ASCII:Krodsherad;ID:3149302', '20431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20431', '112', '22308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22309', '1079', '1', 'Kragerø', 'NO.17.0815', 'ASCII:Kragero;ID:3149409', '20432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20432', '112', '22309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22310', '1079', '1', 'Kongsvinger', 'NO.06.0402', 'ASCII:Kongsvinger;ID:3149534', '20433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20433', '112', '22310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22311', '1079', '1', 'Klepp', 'NO.14.1120', 'ASCII:Klepp;ID:3149862', '20434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20434', '112', '22311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22312', '1079', '1', 'Klæbu', 'NO.16.1662', 'ASCII:Klaebu;ID:3149954', '20435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20435', '112', '22312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22313', '1079', '1', 'Jondal', 'NO.07.1227', 'ASCII:Jondal;ID:3150803', '20436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20436', '112', '22313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22314', '1079', '1', 'Jølster', 'NO.15.1431', 'ASCII:Jolster;ID:3150821', '20437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20437', '112', '22314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22315', '1079', '1', 'Jevnaker', 'NO.11.0532', 'ASCII:Jevnaker;ID:3150840', '20438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20438', '112', '22315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22316', '1079', '1', 'Iveland', 'NO.02.0935', 'ASCII:Iveland;ID:3150950', '20439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20439', '112', '22316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22317', '1079', '1', 'Inderøy', 'NO.10.1729', 'ASCII:Inderoy;ID:3151158', '20440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20440', '112', '22317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22318', '1079', '1', 'Ibestad', 'NO.18.1917', 'ASCII:Ibestad;ID:3151230', '20441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20441', '112', '22318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22319', '1079', '1', 'Hyllestad', 'NO.15.1413', 'ASCII:Hyllestad;ID:3151263', '20442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20442', '112', '22319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22320', '1079', '1', 'Hvaler', 'NO.13.0111', 'ASCII:Hvaler;ID:3151309', '20443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20443', '112', '22320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22321', '1079', '1', 'Hurum', 'NO.04.0628', 'ASCII:Hurum;ID:3151404', '20444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20444', '112', '22321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22322', '1079', '1', 'Hurdal', 'NO.01.0239', 'ASCII:Hurdal;ID:3151414', '20445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20445', '112', '22322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22323', '1079', '1', 'Høylandet', 'NO.10.1743', 'ASCII:Hoylandet;ID:3151536', '20446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20446', '112', '22323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22324', '1079', '1', 'Høyanger Herad', 'NO.15.1416', 'ASCII:Hoyanger Herad;ID:3151572', '20447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20447', '112', '22324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22325', '1079', '1', 'Hornindal', 'NO.15.1444', 'ASCII:Hornindal;ID:3151810', '20448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20448', '112', '22325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22326', '1079', '1', 'Hobøl', 'NO.13.0138', 'ASCII:Hobol;ID:3152504', '20449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20449', '112', '22326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0138» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22327', '1079', '1', 'Hjelmeland', 'NO.14.1133', 'ASCII:Hjelmeland;ID:3152560', '20450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20450', '112', '22327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22328', '1079', '1', 'Hjartdal', 'NO.17.0827', 'ASCII:Hjartdal;ID:3152610', '20451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20451', '112', '22328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22329', '1079', '1', 'Hitra', 'NO.16.1617', 'ASCII:Hitra;ID:3152623', '20452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20452', '112', '22329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22330', '1079', '1', 'Hemsedal', 'NO.04.0618', 'ASCII:Hemsedal;ID:3152987', '20453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20453', '112', '22330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22331', '1079', '1', 'Hemnes', 'NO.09.1832', 'ASCII:Hemnes;ID:3152993', '20454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20454', '112', '22331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22332', '1079', '1', 'Hemne', 'NO.16.1612', 'ASCII:Hemne;ID:3152998', '20455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20455', '112', '22332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22333', '1079', '1', 'Hattfjelldal', 'NO.09.1826', 'ASCII:Hattfjelldal;ID:3153753', '20456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20456', '112', '22333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22334', '1079', '1', 'Hareid', 'NO.08.1517', 'ASCII:Hareid;ID:3153860', '20457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20457', '112', '22334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22335', '1079', '1', 'Haram', 'NO.08.1534', 'ASCII:Haram;ID:3153889', '20458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20458', '112', '22335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22336', '1079', '1', 'Hamarøy', 'NO.09.1849', 'ASCII:Hamaroy;ID:3154063', '20459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20459', '112', '22336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22337', '1079', '1', 'Holtålen', 'NO.16.1644', 'ASCII:Holtalen;ID:3154114', '20460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20460', '112', '22337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22338', '1079', '1', 'Halsa', 'NO.08.1571', 'ASCII:Halsa;ID:3154148', '20461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20461', '112', '22338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22339', '1079', '1', 'Hægebostad', 'NO.19.1034', 'ASCII:Haegebostad;ID:3154388', '20462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20462', '112', '22339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22340', '1079', '1', 'Hadsel', 'NO.09.1866', 'ASCII:Hadsel;ID:3154394', '20463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20463', '112', '22340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22341', '1079', '1', 'Hå', 'NO.14.1119', 'ASCII:Ha;ID:3154414', '20464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20464', '112', '22341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22342', '1079', '1', 'Gulen', 'NO.15.1411', 'ASCII:Gulen;ID:3154556', '20465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20465', '112', '22342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22343', '1079', '1', 'Grue', 'NO.06.0423', 'ASCII:Grue;ID:3154695', '20466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20466', '112', '22343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22344', '1079', '1', 'Grong', 'NO.10.1742', 'ASCII:Grong;ID:3154905', '20467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20467', '112', '22344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1742» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22345', '1079', '1', 'Gratangen', 'NO.18.1919', 'ASCII:Gratangen;ID:3155195', '20468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20468', '112', '22345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22346', '1079', '1', 'Granvin', 'NO.07.1234', 'ASCII:Granvin;ID:3155244', '20469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20469', '112', '22346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22347', '1079', '1', 'Gran', 'NO.11.0534', 'ASCII:Gran;ID:3155280', '20470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20470', '112', '22347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22348', '1079', '1', 'Grane', 'NO.09.1825', 'ASCII:Grane;ID:3155295', '20471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20471', '112', '22348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22349', '1079', '1', 'Gol', 'NO.04.0617', 'ASCII:Gol;ID:3155419', '20472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20472', '112', '22349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22350', '1079', '1', 'Gloppen', 'NO.15.1445', 'ASCII:Gloppen;ID:3155473', '20473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20473', '112', '22350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22351', '1079', '1', 'Gjesdal', 'NO.14.1122', 'ASCII:Gjesdal;ID:3155644', '20474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20474', '112', '22351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22352', '1079', '1', 'Gjerstad', 'NO.02.0911', 'ASCII:Gjerstad;ID:3155672', '20475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20475', '112', '22352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22353', '1079', '1', 'Gjerdrum', 'NO.01.0234', 'ASCII:Gjerdrum;ID:3155709', '20476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20476', '112', '22353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22354', '1079', '1', 'Gjemnes', 'NO.08.1557', 'ASCII:Gjemnes;ID:3155751', '20477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20477', '112', '22354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22355', '1079', '1', 'Giske', 'NO.08.1532', 'ASCII:Giske;ID:3155805', '20478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20478', '112', '22355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22356', '1079', '1', 'Gildeskål', 'NO.09.1838', 'ASCII:Gildeskal;ID:3155849', '20479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20479', '112', '22356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22357', '1079', '1', 'Gausdal', 'NO.11.0522', 'ASCII:Gausdal;ID:3155962', '20480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20480', '112', '22357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22358', '1079', '1', 'Gaular', 'NO.15.1430', 'ASCII:Gaular;ID:3155980', '20481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20481', '112', '22358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22359', '1079', '1', 'Fyresdal', 'NO.17.0831', 'ASCII:Fyresdal;ID:3156247', '20482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20482', '112', '22359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0831» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22360', '1079', '1', 'Fusa', 'NO.07.1241', 'ASCII:Fusa;ID:3156272', '20483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20483', '112', '22360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22361', '1079', '1', 'Frosta', 'NO.10.1717', 'ASCII:Frosta;ID:3156441', '20484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20484', '112', '22361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22362', '1079', '1', 'Froland', 'NO.02.0919', 'ASCII:Froland;ID:3156455', '20485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20485', '112', '22362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22363', '1079', '1', 'Frogn', 'NO.01.0215', 'ASCII:Frogn;ID:3156466', '20486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20486', '112', '22363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22364', '1079', '1', 'Frei', 'NO.08.1556', 'ASCII:Frei;ID:3156522', '20487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20487', '112', '22364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22365', '1079', '1', 'Fræna', 'NO.08.1548', 'ASCII:Fraena;ID:3156555', '20488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20488', '112', '22365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22366', '1079', '1', 'Fosnes', 'NO.10.1748', 'ASCII:Fosnes;ID:3156675', '20489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20489', '112', '22366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22367', '1079', '1', 'Forsand', 'NO.14.1129', 'ASCII:Forsand;ID:3156724', '20490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20490', '112', '22367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22368', '1079', '1', 'Førde', 'NO.15.1432', 'ASCII:Forde;ID:3156800', '20491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20491', '112', '22368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22369', '1079', '1', 'Folldal', 'NO.06.0439', 'ASCII:Folldal;ID:3156866', '20492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20492', '112', '22369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22370', '1079', '1', 'Flora', 'NO.15.1401', 'ASCII:Flora;ID:3156987', '20493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20493', '112', '22370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22371', '1079', '1', 'Flesberg', 'NO.04.0631', 'ASCII:Flesberg;ID:3157053', '20494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20494', '112', '22371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22372', '1079', '1', 'Flatanger', 'NO.10.1749', 'ASCII:Flatanger;ID:3157170', '20495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20495', '112', '22372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22373', '1079', '1', 'Flakstad', 'NO.09.1859', 'ASCII:Flakstad;ID:3157197', '20496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20496', '112', '22373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22374', '1079', '1', 'Fjell', 'NO.07.1246', 'ASCII:Fjell;ID:3157357', '20497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20497', '112', '22374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22375', '1079', '1', 'Fjaler', 'NO.15.1429', 'ASCII:Fjaler;ID:3157409', '20498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20498', '112', '22375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22376', '1079', '1', 'Fitjar', 'NO.07.1222', 'ASCII:Fitjar;ID:3157435', '20499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20499', '112', '22376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22377', '1079', '1', 'Finnøy', 'NO.14.1141', 'ASCII:Finnoy;ID:3157573', '20500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20500', '112', '22377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22378', '1079', '1', 'Fet', 'NO.01.0227', 'ASCII:Fet;ID:3157694', '20501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20501', '112', '22378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22379', '1079', '1', 'Fedje', 'NO.07.1265', 'ASCII:Fedje;ID:3157764', '20502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20502', '112', '22379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22380', '1079', '1', 'Fauske', 'NO.09.1841', 'ASCII:Fauske;ID:3157780', '20503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20503', '112', '22380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22381', '1079', '1', 'Evje og Hornnes', 'NO.02.0937', 'ASCII:Evje og Hornnes;ID:3157976', '20504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20504', '112', '22381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22382', '1079', '1', 'Evenes', 'NO.09.1853', 'ASCII:Evenes;ID:3158002', '20505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20505', '112', '22382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22383', '1079', '1', 'Etne', 'NO.07.1211', 'ASCII:Etne;ID:3158016', '20506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20506', '112', '22383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22384', '1079', '1', 'Etnedal', 'NO.11.0541', 'ASCII:Etnedal;ID:3158018', '20507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20507', '112', '22384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22385', '1079', '1', 'Engerdal', 'NO.06.0434', 'ASCII:Engerdal;ID:3158205', '20508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20508', '112', '22385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0434» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22386', '1079', '1', 'Enebakk', 'NO.01.0229', 'ASCII:Enebakk;ID:3158260', '20509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20509', '112', '22386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22387', '1079', '1', 'Elverum', 'NO.06.0427', 'ASCII:Elverum;ID:3158299', '20510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20510', '112', '22387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22388', '1079', '1', 'Eigersund', 'NO.14.1101', 'ASCII:Eigersund;ID:3158591', '20511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20511', '112', '22388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22389', '1079', '1', 'Eidsvoll', 'NO.01.0237', 'ASCII:Eidsvoll;ID:3158606', '20512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20512', '112', '22389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22390', '1079', '1', 'Eidskog', 'NO.06.0420', 'ASCII:Eidskog;ID:3158629', '20513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20513', '112', '22390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22391', '1079', '1', 'Eidsberg', 'NO.13.0125', 'ASCII:Eidsberg;ID:3158648', '20514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20514', '112', '22391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22392', '1079', '1', 'Eidfjord', 'NO.07.1232', 'ASCII:Eidfjord;ID:3158666', '20515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20515', '112', '22392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1232» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22393', '1079', '1', 'Dyrøy', 'NO.18.1926', 'ASCII:Dyroy;ID:3158837', '20516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20516', '112', '22393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22394', '1079', '1', 'Drangedal', 'NO.17.0817', 'ASCII:Drangedal;ID:3159006', '20517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20517', '112', '22394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22395', '1079', '1', 'Dovre', 'NO.11.0511', 'ASCII:Dovre;ID:3159047', '20518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20518', '112', '22395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22396', '1079', '1', 'Dønna', 'NO.09.1827', 'ASCII:Donna;ID:3159094', '20519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20519', '112', '22396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22397', '1079', '1', 'Bykle', 'NO.02.0941', 'ASCII:Bykle;ID:3159574', '20520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20520', '112', '22397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22398', '1079', '1', 'Bygland', 'NO.02.0938', 'ASCII:Bygland;ID:3159581', '20521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20521', '112', '22398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22399', '1079', '1', 'Brønnøy', 'NO.09.1813', 'ASCII:Bronnoy;ID:3159955', '20522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20522', '112', '22399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22400', '1079', '1', 'Bremanger', 'NO.15.1438', 'ASCII:Bremanger;ID:3160090', '20523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20523', '112', '22400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22401', '1079', '1', 'Borre', 'NO.20.0701', 'ASCII:Borre;ID:3160606', '20524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20524', '112', '22401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22402', '1079', '1', 'Bømlo', 'NO.07.1219', 'ASCII:Bomlo;ID:3160744', '20525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20525', '112', '22402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22403', '1079', '1', 'Bokn', 'NO.14.1145', 'ASCII:Bokn;ID:3160810', '20526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20526', '112', '22403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22404', '1079', '1', 'Bjugn', 'NO.16.1627', 'ASCII:Bjugn;ID:3161159', '20527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20527', '112', '22404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22405', '1079', '1', 'Bjerkreim', 'NO.14.1114', 'ASCII:Bjerkreim;ID:3161457', '20528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20528', '112', '22405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22406', '1079', '1', 'Bjarkøy', 'NO.18.1915', 'ASCII:Bjarkoy;ID:3161499', '20529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20529', '112', '22406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22407', '1079', '1', 'Birkenes', 'NO.02.0928', 'ASCII:Birkenes;ID:3161528', '20530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20530', '112', '22407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22408', '1079', '1', 'Bindal', 'NO.09.1811', 'ASCII:Bindal;ID:3161552', '20531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20531', '112', '22408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22409', '1079', '1', 'Bergen', 'NO.07.1201', 'ASCII:Bergen;ID:3161733', '20532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20532', '112', '22409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22410', '1079', '1', 'Beiarn', 'NO.09.1839', 'ASCII:Beiarn;ID:3161943', '20533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20533', '112', '22410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22411', '1079', '1', 'Bardu', 'NO.18.1922', 'ASCII:Bardu;ID:3162043', '20534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20534', '112', '22411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22412', '1079', '1', 'Bamble', 'NO.17.0814', 'ASCII:Bamble;ID:3162078', '20535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20535', '112', '22412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22413', '1079', '1', 'Balsfjord', 'NO.18.1933', 'ASCII:Balsfjord;ID:3162091', '20536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20536', '112', '22413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22414', '1079', '1', 'Ballangen', 'NO.09.1854', 'ASCII:Ballangen;ID:3162107', '20537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20537', '112', '22414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22415', '1079', '1', 'Balestrand', 'NO.15.1418', 'ASCII:Balestrand;ID:3162115', '20538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20538', '112', '22415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22416', '1079', '1', 'Bærum', 'NO.01.0219', 'ASCII:Baerum;ID:3162212', '20539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20539', '112', '22416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22417', '1079', '1', 'Austrheim', 'NO.07.1264', 'ASCII:Austrheim;ID:3162270', '20540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20540', '112', '22417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22418', '1079', '1', 'Austevoll', 'NO.07.1244', 'ASCII:Austevoll;ID:3162320', '20541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20541', '112', '22418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22419', '1079', '1', 'Aurland', 'NO.15.1421', 'ASCII:Aurland;ID:3162403', '20542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20542', '112', '22419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22420', '1079', '1', 'Aure', 'NO.08.1569', 'ASCII:Aure;ID:3162407', '20543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20543', '112', '22420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22421', '1079', '1', 'Åsnes', 'NO.06.0425', 'ASCII:Asnes;ID:3162593', '20544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20544', '112', '22421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22422', '1079', '1', 'Askvoll', 'NO.15.1428', 'ASCII:Askvoll;ID:3162629', '20545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20545', '112', '22422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22423', '1079', '1', 'Askøy', 'NO.07.1247', 'ASCII:Askoy;ID:3162639', '20546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20546', '112', '22423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22424', '1079', '1', 'Askim', 'NO.13.0124', 'ASCII:Askim;ID:3162649', '20547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20547', '112', '22424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22425', '1079', '1', 'Asker', 'NO.01.0220', 'ASCII:Asker;ID:3162656', '20548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20548', '112', '22425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0220» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22426', '1079', '1', 'Ås', 'NO.01.0214', 'ASCII:As;ID:3162672', '20549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20549', '112', '22426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22427', '1079', '1', 'Åseral', 'NO.19.1026', 'ASCII:Aseral;ID:3162697', '20550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20550', '112', '22427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22428', '1079', '1', 'Aremark', 'NO.13.0118', 'ASCII:Aremark;ID:3162957', '20551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20551', '112', '22428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22429', '1079', '1', 'Andebu', 'NO.20.0719', 'ASCII:Andebu;ID:3163149', '20552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20552', '112', '22429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22430', '1079', '1', 'Åmot', 'NO.06.0429', 'ASCII:Amot;ID:3163189', '20553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20553', '112', '22430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22431', '1079', '1', 'Åmli', 'NO.02.0929', 'ASCII:Amli;ID:3163213', '20554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20554', '112', '22431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22432', '1079', '1', 'Alvdal', 'NO.06.0438', 'ASCII:Alvdal;ID:3163268', '20555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20555', '112', '22432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22433', '1079', '1', 'Alstahaug', 'NO.09.1820', 'ASCII:Alstahaug;ID:3163293', '20556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20556', '112', '22433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22434', '1079', '1', 'Ål', 'NO.04.0619', 'ASCII:Al;ID:3163374', '20557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20557', '112', '22434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22435', '1079', '1', 'Agdenes', 'NO.16.1622', 'ASCII:Agdenes;ID:3163525', '20558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20558', '112', '22435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22436', '1079', '1', 'Åfjord', 'NO.16.1630', 'ASCII:Afjord;ID:3163537', '20559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20559', '112', '22436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22437', '1079', '1', 'Hammerfest', 'NO.05.2004', 'ASCII:Hammerfest;ID:6453312', '20560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20560', '112', '22437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22438', '1079', '1', 'Vardø', 'NO.05.2002', 'ASCII:Vardo;ID:6453313', '20561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20561', '112', '22438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22439', '1079', '1', 'Porsanger', 'NO.05.2020', 'ASCII:Porsanger;ID:6453314', '20562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20562', '112', '22439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22440', '1079', '1', 'Vadsø', 'NO.05.2003', 'ASCII:Vadso;ID:6453315', '20563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20563', '112', '22440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.05.2003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22441', '1079', '1', 'Tromsø', 'NO.18.1902', 'ASCII:Tromso;ID:6453316', '20564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20564', '112', '22441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22442', '1079', '1', 'Berg', 'NO.18.1929', 'ASCII:Berg;ID:6453317', '20565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20565', '112', '22442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22443', '1079', '1', 'Andøy', 'NO.09.1871', 'ASCII:Andoy;ID:6453318', '20566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20566', '112', '22443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1871» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22444', '1079', '1', 'Harstad', 'NO.18.1901', 'ASCII:Harstad;ID:6453319', '20567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20567', '112', '22444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.18.1901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22445', '1079', '1', 'Bø', 'NO.09.1867', 'ASCII:Bo;ID:6453320', '20568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20568', '112', '22445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22446', '1079', '1', 'Narvik', 'NO.09.1805', 'ASCII:Narvik;ID:6453321', '20569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20569', '112', '22446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22447', '1079', '1', 'Vestvågøy', 'NO.09.1860', 'ASCII:Vestvagoy;ID:6453322', '20570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20570', '112', '22447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22448', '1079', '1', 'Bodø', 'NO.09.1804', 'ASCII:Bodo;ID:6453323', '20571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20571', '112', '22448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22449', '1079', '1', 'Rana', 'NO.09.1833', 'ASCII:Rana;ID:6453324', '20572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20572', '112', '22449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22450', '1079', '1', 'Herøy', 'NO.09.1818', 'ASCII:Heroy;ID:6453325', '20573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20573', '112', '22450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22451', '1079', '1', 'Vega', 'NO.09.1815', 'ASCII:Vega;ID:6453326', '20574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20574', '112', '22451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.09.1815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22452', '1079', '1', 'Lierne', 'NO.10.1738', 'ASCII:Lierne;ID:6453327', '20575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20575', '112', '22452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22453', '1079', '1', 'Namsos', 'NO.10.1703', 'ASCII:Namsos;ID:6453328', '20576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20576', '112', '22453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22454', '1079', '1', 'Frøya', 'NO.16.1620', 'ASCII:Froya;ID:6453329', '20577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20577', '112', '22454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22455', '1079', '1', 'Levanger', 'NO.10.1719', 'ASCII:Levanger;ID:6453330', '20578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20578', '112', '22455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.10.1719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22456', '1079', '1', 'Kristiansund', 'NO.08.1503', 'ASCII:Kristiansund;ID:6453331', '20579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20579', '112', '22456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22457', '1079', '1', 'Averøy', 'NO.08.1554', 'ASCII:Averoy;ID:6453332', '20580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20580', '112', '22457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22458', '1079', '1', 'Eide', 'NO.08.1551', 'ASCII:Eide;ID:6453333', '20581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20581', '112', '22458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22459', '1079', '1', 'Aukra', 'NO.08.1547', 'ASCII:Aukra;ID:6453334', '20582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20582', '112', '22459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22460', '1079', '1', 'Midtre Gauldal', 'NO.16.1648', 'ASCII:Midtre Gauldal;ID:6453335', '20583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20583', '112', '22460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22461', '1079', '1', 'Midsund', 'NO.08.1545', 'ASCII:Midsund;ID:6453336', '20584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20584', '112', '22461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22462', '1079', '1', 'Rauma', 'NO.08.1539', 'ASCII:Rauma;ID:6453337', '20585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20585', '112', '22462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22463', '1079', '1', 'Vestnes', 'NO.08.1535', 'ASCII:Vestnes;ID:6453338', '20586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20586', '112', '22463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22464', '1079', '1', 'Røros', 'NO.16.1640', 'ASCII:Roros;ID:6453339', '20587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20587', '112', '22464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.16.1640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22465', '1079', '1', 'Herøy', 'NO.08.1515', 'ASCII:Heroy;ID:6453340', '20588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20588', '112', '22465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22466', '1079', '1', 'Ålesund', 'NO.08.1504', 'ASCII:Alesund;ID:6453341', '20589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20589', '112', '22466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22467', '1079', '1', 'Os', 'NO.06.0441', 'ASCII:Os;ID:6453342', '20590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20590', '112', '22467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22468', '1079', '1', 'Sula', 'NO.08.1531', 'ASCII:Sula;ID:6453343', '20591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20591', '112', '22468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22469', '1079', '1', 'Tolga', 'NO.06.0436', 'ASCII:Tolga;ID:6453344', '20592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20592', '112', '22469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22470', '1079', '1', 'Sande', 'NO.08.1514', 'ASCII:Sande;ID:6453345', '20593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20593', '112', '22470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.08.1514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22471', '1079', '1', 'Vågsøy', 'NO.15.1439', 'ASCII:Vagsoy;ID:6453346', '20594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20594', '112', '22471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22472', '1079', '1', 'Eid', 'NO.15.1443', 'ASCII:Eid;ID:6453347', '20595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20595', '112', '22472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22473', '1079', '1', 'Årdal', 'NO.15.1424', 'ASCII:Ardal;ID:6453348', '20596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20596', '112', '22473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.15.1424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22474', '1079', '1', 'Vang', 'NO.11.0545', 'ASCII:Vang;ID:6453349', '20597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20597', '112', '22474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22475', '1079', '1', 'Lillehammer', 'NO.11.0501', 'ASCII:Lillehammer;ID:6453350', '20598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20598', '112', '22475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22476', '1079', '1', 'Hamar', 'NO.06.0403', 'ASCII:Hamar;ID:6453351', '20599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20599', '112', '22476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22477', '1079', '1', 'Vaksdal', 'NO.07.1251', 'ASCII:Vaksdal;ID:6453352', '20600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20600', '112', '22477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22478', '1079', '1', 'Øygarden', 'NO.07.1259', 'ASCII:Oygarden;ID:6453353', '20601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20601', '112', '22478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22479', '1079', '1', 'Radøy', 'NO.07.1260', 'ASCII:Radoy;ID:6453354', '20602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20602', '112', '22479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22480', '1079', '1', 'Gjøvik', 'NO.11.0502', 'ASCII:Gjovik;ID:6453355', '20603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20603', '112', '22480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.11.0502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22481', '1079', '1', 'Våler', 'NO.06.0426', 'ASCII:Valer;ID:6453356', '20604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20604', '112', '22481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.06.0426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22482', '1079', '1', 'Hol', 'NO.04.0620', 'ASCII:Hol;ID:6453357', '20605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20605', '112', '22482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22483', '1079', '1', 'Osterøy', 'NO.07.1253', 'ASCII:Osteroy;ID:6453358', '20606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20606', '112', '22483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22484', '1079', '1', 'Nes', 'NO.04.0616', 'ASCII:Nes;ID:6453359', '20607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20607', '112', '22484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22485', '1079', '1', 'Ringerike', 'NO.04.0605', 'ASCII:Ringerike;ID:6453360', '20608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20608', '112', '22485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22486', '1079', '1', 'Flå', 'NO.04.0615', 'ASCII:Fla;ID:6453361', '20609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20609', '112', '22486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22487', '1079', '1', 'Os', 'NO.07.1243', 'ASCII:Os;ID:6453362', '20610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20610', '112', '22487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.07.1243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22488', '1079', '1', 'Nore og Uvdal', 'NO.04.0633', 'ASCII:Nore og Uvdal;ID:6453363', '20611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20611', '112', '22488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22489', '1079', '1', 'Nes', 'NO.01.0236', 'ASCII:Nes;ID:6453364', '20612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20612', '112', '22489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0236» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22490', '1079', '1', 'Vinje', 'NO.17.0834', 'ASCII:Vinje;ID:6453365', '20613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20613', '112', '22490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22491', '1079', '1', 'Oslo', 'NO.12.0301', 'ASCII:Oslo;ID:6453366', '20614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20614', '112', '22491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.12.0301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22492', '1079', '1', 'Hole', 'NO.04.0612', 'ASCII:Hole;ID:6453367', '20615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20615', '112', '22492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22493', '1079', '1', 'Aurskog-Høland', 'NO.01.0221', 'ASCII:Aurskog-Holand;ID:6453368', '20616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20616', '112', '22493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.01.0221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22494', '1079', '1', 'Notodden', 'NO.17.0807', 'ASCII:Notodden;ID:6453369', '20617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20617', '112', '22494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22495', '1079', '1', 'Suldal', 'NO.14.1134', 'ASCII:Suldal;ID:6453370', '20618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20618', '112', '22495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1134» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22496', '1079', '1', 'Vindafjord', 'NO.14.1154', 'ASCII:Vindafjord;ID:6453371', '20619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20619', '112', '22496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22497', '1079', '1', 'Drammen', 'NO.04.0602', 'ASCII:Drammen;ID:6453372', '20620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20620', '112', '22497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22498', '1079', '1', 'Kongsberg', 'NO.04.0604', 'ASCII:Kongsberg;ID:6453373', '20621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20621', '112', '22498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.04.0604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22499', '1079', '1', 'Haugesund', 'NO.14.1106', 'ASCII:Haugesund;ID:6453374', '20622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20622', '112', '22499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22500', '1079', '1', 'Karmøy', 'NO.14.1149', 'ASCII:Karmoy;ID:6453375', '20623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20623', '112', '22500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22501', '1079', '1', 'Tokke', 'NO.17.0833', 'ASCII:Tokke;ID:6453376', '20624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20624', '112', '22501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22502', '1079', '1', 'Svelvik', 'NO.20.0711', 'ASCII:Svelvik;ID:6453377', '20625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20625', '112', '22502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22503', '1079', '1', 'Sande', 'NO.20.0713', 'ASCII:Sande;ID:6453378', '20626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20626', '112', '22503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22504', '1079', '1', 'Hof', 'NO.20.0714', 'ASCII:Hof;ID:6453379', '20627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20627', '112', '22504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22505', '1079', '1', 'Marker', 'NO.13.0119', 'ASCII:Marker;ID:6453380', '20628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20628', '112', '22505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22506', '1079', '1', 'Bø', 'NO.17.0821', 'ASCII:Bo;ID:6453381', '20629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20629', '112', '22506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22507', '1079', '1', 'Holmestrand', 'NO.20.0702', 'ASCII:Holmestrand;ID:6453382', '20630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20630', '112', '22507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22508', '1079', '1', 'Skien', 'NO.17.0806', 'ASCII:Skien;ID:6453383', '20631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20631', '112', '22508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22509', '1079', '1', 'Moss', 'NO.13.0104', 'ASCII:Moss;ID:6453384', '20632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20632', '112', '22509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22510', '1079', '1', 'Våler', 'NO.13.0137', 'ASCII:Valer;ID:6453385', '20633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20633', '112', '22510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22511', '1079', '1', 'Lardal', 'NO.20.0728', 'ASCII:Lardal;ID:6453386', '20634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20634', '112', '22511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22512', '1079', '1', 'Nome', 'NO.17.0819', 'ASCII:Nome;ID:6453387', '20635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20635', '112', '22512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22513', '1079', '1', 'Sarpsborg', 'NO.13.0105', 'ASCII:Sarpsborg;ID:6453388', '20636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20636', '112', '22513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22514', '1079', '1', 'Tønsberg', 'NO.20.0704', 'ASCII:Tonsberg;ID:6453389', '20637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20637', '112', '22514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22515', '1079', '1', 'Larvik', 'NO.20.0709', 'ASCII:Larvik;ID:6453390', '20638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20638', '112', '22515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22516', '1079', '1', 'Stavanger', 'NO.14.1103', 'ASCII:Stavanger;ID:6453391', '20639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20639', '112', '22516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22517', '1079', '1', 'Fredrikstad', 'NO.13.0106', 'ASCII:Fredrikstad;ID:6453392', '20640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20640', '112', '22517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22518', '1079', '1', 'Sandnes', 'NO.14.1102', 'ASCII:Sandnes;ID:6453393', '20641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20641', '112', '22518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.14.1102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22519', '1079', '1', 'Porsgrunn', 'NO.17.0805', 'ASCII:Porsgrunn;ID:6453394', '20642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20642', '112', '22519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.17.0805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22520', '1079', '1', 'Halden', 'NO.13.0101', 'ASCII:Halden;ID:6453395', '20643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20643', '112', '22520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.13.0101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22521', '1079', '1', 'Sandefjord', 'NO.20.0706', 'ASCII:Sandefjord;ID:6453396', '20644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20644', '112', '22521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.20.0706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22522', '1079', '1', 'Risør', 'NO.02.0901', 'ASCII:Risor;ID:6453397', '20645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20645', '112', '22522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22523', '1079', '1', 'Flekkefjord', 'NO.19.1004', 'ASCII:Flekkefjord;ID:6453398', '20646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20646', '112', '22523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22524', '1079', '1', 'Arendal', 'NO.02.0906', 'ASCII:Arendal;ID:6453399', '20647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20647', '112', '22524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22525', '1079', '1', 'Marnardal', 'NO.19.1021', 'ASCII:Marnardal;ID:6453400', '20648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20648', '112', '22525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22526', '1079', '1', 'Grimstad', 'NO.02.0904', 'ASCII:Grimstad;ID:6453401', '20649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20649', '112', '22526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.02.0904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22527', '1079', '1', 'Songdalen', 'NO.19.1017', 'ASCII:Songdalen;ID:6453402', '20650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20650', '112', '22527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22528', '1079', '1', 'Farsund', 'NO.19.1003', 'ASCII:Farsund;ID:6453403', '20651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20651', '112', '22528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22529', '1079', '1', 'Lindesnes', 'NO.19.1029', 'ASCII:Lindesnes;ID:6453404', '20652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20652', '112', '22529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22530', '1079', '1', 'Kristiansand', 'NO.19.1001', 'ASCII:Kristiansand;ID:6453405', '20653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20653', '112', '22530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22531', '1079', '1', 'Mandal', 'NO.19.1002', 'ASCII:Mandal;ID:6453406', '20654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20654', '112', '22531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NO.19.1002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22532', '1079', '1', 'Udayapur', 'NP.00.1282630', 'ASCII:Udayapur;ID:1282630', '20655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20655', '112', '22532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22533', '1079', '1', 'Tehrathum', 'NP.00.1282700', 'ASCII:Tehrathum;ID:1282700', '20656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20656', '112', '22533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22534', '1079', '1', 'Tāplejun', 'NP.00.1282713', 'ASCII:Taplejun;ID:1282713', '20657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20657', '112', '22534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22535', '1079', '1', 'Tanahun', 'NP.00.1282722', 'ASCII:Tanahun;ID:1282722', '20658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20658', '112', '22535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22536', '1079', '1', 'Syāngjā', 'NP.00.1282734', 'ASCII:Syangja;ID:1282734', '20659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20659', '112', '22536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22537', '1079', '1', 'Sunsarī', 'NP.00.1282744', 'ASCII:Sunsari;ID:1282744', '20660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20660', '112', '22537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22538', '1079', '1', 'Solukhumbū', 'NP.00.1282758', 'ASCII:Solukhumbu;ID:1282758', '20661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20661', '112', '22538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22539', '1079', '1', 'Sirāhā', 'NP.00.1282771', 'ASCII:Siraha;ID:1282771', '20662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20662', '112', '22539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22540', '1079', '1', 'Sindhu Pālchok', 'NP.00.1282774', 'ASCII:Sindhu Palchok;ID:1282774', '20663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20663', '112', '22540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22541', '1079', '1', 'Sindhulī', 'NP.00.1282776', 'ASCII:Sindhuli;ID:1282776', '20664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20664', '112', '22541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282776» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22542', '1079', '1', 'Sarlāhī', 'NP.00.1282806', 'ASCII:Sarlahi;ID:1282806', '20665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20665', '112', '22542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22543', '1079', '1', 'Saptarī', 'NP.00.1282810', 'ASCII:Saptari;ID:1282810', '20666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20666', '112', '22543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22544', '1079', '1', 'Sankhuwāsabhā', 'NP.00.1282812', 'ASCII:Sankhuwasabha;ID:1282812', '20667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20667', '112', '22544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22545', '1079', '1', 'Salyān', 'NP.00.1282827', 'ASCII:Salyan;ID:1282827', '20668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20668', '112', '22545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22546', '1079', '1', 'Rūpandehī', 'NP.00.1282837', 'ASCII:Rupandehi;ID:1282837', '20669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20669', '112', '22546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282837» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22547', '1079', '1', 'Rūkum', 'NP.00.1282843', 'ASCII:Rukum;ID:1282843', '20670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20670', '112', '22547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22548', '1079', '1', 'Rolpā', 'NP.00.1282847', 'ASCII:Rolpa;ID:1282847', '20671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20671', '112', '22548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22549', '1079', '1', 'Rautahat', 'NP.00.1282856', 'ASCII:Rautahat;ID:1282856', '20672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20672', '112', '22549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22550', '1079', '1', 'Rasuwā', 'NP.00.1282859', 'ASCII:Rasuwa;ID:1282859', '20673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20673', '112', '22550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22551', '1079', '1', 'Rāmechhāp', 'NP.00.1282879', 'ASCII:Ramechhap;ID:1282879', '20674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20674', '112', '22551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22552', '1079', '1', 'Pyūthān', 'NP.00.1282888', 'ASCII:Pyuthan;ID:1282888', '20675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20675', '112', '22552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22553', '1079', '1', 'Parsa', 'NP.00.1282938', 'ASCII:Parsa;ID:1282938', '20676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20676', '112', '22553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22554', '1079', '1', 'Parbat', 'NP.00.1282939', 'ASCII:Parbat;ID:1282939', '20677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20677', '112', '22554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22555', '1079', '1', 'Panchthar', 'NP.00.1282947', 'ASCII:Panchthar;ID:1282947', '20678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20678', '112', '22555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282947» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22556', '1079', '1', 'Pālpā', 'NP.00.1282954', 'ASCII:Palpa;ID:1282954', '20679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20679', '112', '22556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22557', '1079', '1', 'Okhalḍhungā', 'NP.00.1282969', 'ASCII:Okhaldhunga;ID:1282969', '20680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20680', '112', '22557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282969» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22558', '1079', '1', 'Nuwākot', 'NP.00.1282973', 'ASCII:Nuwakot;ID:1282973', '20681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20681', '112', '22558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282973» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22559', '1079', '1', 'Nawalparāsī', 'NP.00.1282991', 'ASCII:Nawalparasi;ID:1282991', '20682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20682', '112', '22559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1282991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22560', '1079', '1', 'Myāgdī', 'NP.00.1283020', 'ASCII:Myagdi;ID:1283020', '20683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20683', '112', '22560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22561', '1079', '1', 'Mustāng', 'NP.00.1283023', 'ASCII:Mustang;ID:1283023', '20684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20684', '112', '22561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22562', '1079', '1', 'Mūgu', 'NP.00.1283037', 'ASCII:Mugu;ID:1283037', '20685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20685', '112', '22562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22563', '1079', '1', 'Morang', 'NP.00.1283040', 'ASCII:Morang;ID:1283040', '20686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20686', '112', '22563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22564', '1079', '1', 'Manang', 'NP.00.1283077', 'ASCII:Manang;ID:1283077', '20687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20687', '112', '22564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22565', '1079', '1', 'Makwānpur', 'NP.00.1283085', 'ASCII:Makwanpur;ID:1283085', '20688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20688', '112', '22565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22566', '1079', '1', 'Mahottarī', 'NP.00.1283094', 'ASCII:Mahottari;ID:1283094', '20689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20689', '112', '22566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22567', '1079', '1', 'Lamjung', 'NP.00.1283151', 'ASCII:Lamjung;ID:1283151', '20690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20690', '112', '22567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22568', '1079', '1', 'Lalitpur', 'NP.00.1283154', 'ASCII:Lalitpur;ID:1283154', '20691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20691', '112', '22568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22569', '1079', '1', 'Khotang', 'NP.00.1283202', 'ASCII:Khotang;ID:1283202', '20692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20692', '112', '22569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22570', '1079', '1', 'Kathmandu', 'NP.00.1283241', 'ASCII:Kathmandu;ID:1283241', '20693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20693', '112', '22570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22571', '1079', '1', 'Kāskī', 'NP.00.1283243', 'ASCII:Kaski;ID:1283243', '20694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20694', '112', '22571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22572', '1079', '1', 'Kapilbastū', 'NP.00.1283251', 'ASCII:Kapilbastu;ID:1283251', '20695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20695', '112', '22572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22573', '1079', '1', 'Kanchanpur', 'NP.00.1283262', 'ASCII:Kanchanpur;ID:1283262', '20696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20696', '112', '22573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22574', '1079', '1', 'Kālīkot', 'NP.00.1283269', 'ASCII:Kalikot;ID:1283269', '20697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20697', '112', '22574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22575', '1079', '1', 'Kābhre Palānchok', 'NP.00.1283282', 'ASCII:Kabhre Palanchok;ID:1283282', '20698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20698', '112', '22575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22576', '1079', '1', 'Jhāpā', 'NP.00.1283307', 'ASCII:Jhapa;ID:1283307', '20699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20699', '112', '22576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22577', '1079', '1', 'Jājarkot', 'NP.00.1283325', 'ASCII:Jajarkot;ID:1283325', '20700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20700', '112', '22577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22578', '1079', '1', 'Ilām', 'NP.00.1283334', 'ASCII:Ilam;ID:1283334', '20701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20701', '112', '22578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22579', '1079', '1', 'Humlā', 'NP.00.1283335', 'ASCII:Humla;ID:1283335', '20702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20702', '112', '22579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283335» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22580', '1079', '1', 'Gulmī', 'NP.00.1283367', 'ASCII:Gulmi;ID:1283367', '20703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20703', '112', '22580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22581', '1079', '1', 'Gorkhā', 'NP.00.1283379', 'ASCII:Gorkha;ID:1283379', '20704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20704', '112', '22581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22582', '1079', '1', 'Dotī', 'NP.00.1283425', 'ASCII:Doti;ID:1283425', '20705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20705', '112', '22582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22583', '1079', '1', 'Dolpā', 'NP.00.1283428', 'ASCII:Dolpa;ID:1283428', '20706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20706', '112', '22583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22584', '1079', '1', 'Dolakhā', 'NP.00.1283431', 'ASCII:Dolakha;ID:1283431', '20707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20707', '112', '22584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22585', '1079', '1', 'Dhanūkha', 'NP.00.1283464', 'ASCII:Dhanukha;ID:1283464', '20708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20708', '112', '22585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22586', '1079', '1', 'Dhankutā', 'NP.00.1283466', 'ASCII:Dhankuta;ID:1283466', '20709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20709', '112', '22586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22587', '1079', '1', 'Dhāding', 'NP.00.1283472', 'ASCII:Dhading;ID:1283472', '20710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20710', '112', '22587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22588', '1079', '1', 'Dārchulā', 'NP.00.1283485', 'ASCII:Darchula;ID:1283485', '20711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20711', '112', '22588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22589', '1079', '1', 'Dāng', 'NP.00.1283489', 'ASCII:Dang;ID:1283489', '20712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20712', '112', '22589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22590', '1079', '1', 'Dailekh', 'NP.00.1283497', 'ASCII:Dailekh;ID:1283497', '20713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20713', '112', '22590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22591', '1079', '1', 'Chitawan', 'NP.00.1283517', 'ASCII:Chitawan;ID:1283517', '20714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20714', '112', '22591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22592', '1079', '1', 'Bājura', 'NP.00.1283697', 'ASCII:Bajura;ID:1283697', '20715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20715', '112', '22592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283697» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22593', '1079', '1', 'Bajhang', 'NP.00.1283699', 'ASCII:Bajhang;ID:1283699', '20716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20716', '112', '22593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22594', '1079', '1', 'Bāglung', 'NP.00.1283712', 'ASCII:Baglung;ID:1283712', '20717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20717', '112', '22594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22595', '1079', '1', 'Arghākhānchī', 'NP.00.1283726', 'ASCII:Arghakhanchi;ID:1283726', '20718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20718', '112', '22595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22596', '1079', '1', 'Achhām', 'NP.00.1283743', 'ASCII:Achham;ID:1283743', '20719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20719', '112', '22596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «NP.00.1283743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22597', '1079', '1', 'Corregimiento Tubualá', 'PA.09.3700392', 'ASCII:Corregimiento Tubuala;ID:3700392', '20720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20720', '112', '22597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.09.3700392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22598', '1079', '1', 'Distrito Tonosí', 'PA.07.3700535', 'ASCII:Distrito Tonosi;ID:3700535', '20721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20721', '112', '22598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.07.3700535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22599', '1079', '1', 'Distrito de Tolé', 'PA.02.3700557', 'ASCII:Distrito de Tole;ID:3700557', '20722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20722', '112', '22599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3700557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22600', '1079', '1', 'Distrito Taboga', 'PA.08.3700799', 'ASCII:Distrito Taboga;ID:3700799', '20723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20723', '112', '22600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3700799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22601', '1079', '1', 'Distrito Soná', 'PA.10.3700886', 'ASCII:Distrito Sona;ID:3700886', '20724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20724', '112', '22601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3700886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22602', '1079', '1', 'Distrito Santiago', 'PA.10.3701113', 'ASCII:Distrito Santiago;ID:3701113', '20725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20725', '112', '22602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3701113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22603', '1079', '1', 'Distrito Santa María', 'PA.06.3701171', 'ASCII:Distrito Santa Maria;ID:3701171', '20726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20726', '112', '22603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.06.3701171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22604', '1079', '1', 'Distrito Santa Isabel', 'PA.04.3701183', 'ASCII:Distrito Santa Isabel;ID:3701183', '20727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20727', '112', '22604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.04.3701183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22605', '1079', '1', 'Distrito Santa Fe', 'PA.10.3701191', 'ASCII:Distrito Santa Fe;ID:3701191', '20728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20728', '112', '22605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3701191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22606', '1079', '1', 'Distrito San Miguelito', 'PA.08.3701328', 'ASCII:Distrito San Miguelito;ID:3701328', '20729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20729', '112', '22606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3701328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22607', '1079', '1', 'Distrito San Lorenzo', 'PA.02.3701365', 'ASCII:Distrito San Lorenzo;ID:3701365', '20730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20730', '112', '22607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3701365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22608', '1079', '1', 'Distrito San Francisco', 'PA.10.3701474', 'ASCII:Distrito San Francisco;ID:3701474', '20731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20731', '112', '22608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3701474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22609', '1079', '1', 'Distrito San Félix', 'PA.02.3701489', 'ASCII:Distrito San Felix;ID:3701489', '20732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20732', '112', '22609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3701489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22610', '1079', '1', 'Distrito San Carlos', 'PA.08.3701523', 'ASCII:Distrito San Carlos;ID:3701523', '20733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20733', '112', '22610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3701523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22611', '1079', '1', 'Distrito Río de Jesús', 'PA.10.3701878', 'ASCII:Distrito Rio de Jesus;ID:3701878', '20734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20734', '112', '22611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3701878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22612', '1079', '1', 'Distrito Renacimiento', 'PA.02.3701989', 'ASCII:Distrito Renacimiento;ID:3701989', '20735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20735', '112', '22612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3701989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22613', '1079', '1', 'Distrito Remedios', 'PA.02.3701992', 'ASCII:Distrito Remedios;ID:3701992', '20736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20736', '112', '22613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3701992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22614', '1079', '1', 'Corregimiento Puerto Obaldía', 'PA.09.3702389', 'ASCII:Corregimiento Puerto Obaldia;ID:3702389', '20737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20737', '112', '22614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.09.3702389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22615', '1079', '1', 'Distrito Portobelo', 'PA.04.3702573', 'ASCII:Distrito Portobelo;ID:3702573', '20738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20738', '112', '22615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.04.3702573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22616', '1079', '1', 'Distrito de Pocrí', 'PA.07.3702627', 'ASCII:Distrito de Pocri;ID:3702627', '20739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20739', '112', '22616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.07.3702627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22617', '1079', '1', 'Distrito de Pinogana', 'PA.05.3702816', 'ASCII:Distrito de Pinogana;ID:3702816', '20740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20740', '112', '22617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.05.3702816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22618', '1079', '1', 'Distrito Pesé', 'PA.06.3703009', 'ASCII:Distrito Pese;ID:3703009', '20741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20741', '112', '22618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.06.3703009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22619', '1079', '1', 'Distrito Penonomé', 'PA.03.3703066', 'ASCII:Distrito Penonome;ID:3703066', '20742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20742', '112', '22619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.03.3703066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22620', '1079', '1', 'Distrito Pedasí', 'PA.07.3703237', 'ASCII:Distrito Pedasi;ID:3703237', '20743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20743', '112', '22620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.07.3703237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22621', '1079', '1', 'Distrito Parita', 'PA.06.3703351', 'ASCII:Distrito Parita;ID:3703351', '20744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20744', '112', '22621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.06.3703351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22622', '1079', '1', 'Distrito de Panamá', 'PA.08.3703439', 'ASCII:Distrito de Panama;ID:3703439', '20745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20745', '112', '22622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3703439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22623', '1079', '1', 'Distrito Olá', 'PA.03.3703743', 'ASCII:Distrito Ola;ID:3703743', '20746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20746', '112', '22623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.03.3703743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22624', '1079', '1', 'Distrito Ocú', 'PA.06.3703784', 'ASCII:Distrito Ocu;ID:3703784', '20747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20747', '112', '22624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.06.3703784» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22625', '1079', '1', 'Distrito Natá', 'PA.03.3703935', 'ASCII:Distrito Nata;ID:3703935', '20748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20748', '112', '22625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.03.3703935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22626', '1079', '1', 'Distrito Montijo', 'PA.10.3704121', 'ASCII:Distrito Montijo;ID:3704121', '20749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20749', '112', '22626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3704121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22627', '1079', '1', 'Distrito Macaracas', 'PA.07.3704872', 'ASCII:Distrito Macaracas;ID:3704872', '20750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20750', '112', '22627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.07.3704872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22628', '1079', '1', 'Distrito Los Santos', 'PA.07.3704962', 'ASCII:Distrito Los Santos;ID:3704962', '20751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20751', '112', '22628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.07.3704962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22629', '1079', '1', 'Distrito Los Pozos', 'PA.06.3705017', 'ASCII:Distrito Los Pozos;ID:3705017', '20752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20752', '112', '22629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.06.3705017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22630', '1079', '1', 'Las Tablas Abajo', 'PA.07.3706204', 'ASCII:Las Tablas Abajo;ID:3706204', '20753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20753', '112', '22630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.07.3706204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22631', '1079', '1', 'Distrito Las Tablas', 'PA.07.3706205', 'ASCII:Distrito Las Tablas;ID:3706205', '20754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20754', '112', '22631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.07.3706205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22632', '1079', '1', 'Distrito Las Palmas', 'PA.10.3706289', 'ASCII:Distrito Las Palmas;ID:3706289', '20755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20755', '112', '22632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3706289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22633', '1079', '1', 'Distrito Las Minas', 'PA.06.3706342', 'ASCII:Distrito Las Minas;ID:3706342', '20756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20756', '112', '22633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.06.3706342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22634', '1079', '1', 'Distrito La Pintada', 'PA.03.3706929', 'ASCII:Distrito La Pintada;ID:3706929', '20757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20757', '112', '22634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.03.3706929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22635', '1079', '1', 'Distrito La Mesa', 'PA.10.3707217', 'ASCII:Distrito La Mesa;ID:3707217', '20758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20758', '112', '22635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3707217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22636', '1079', '1', 'Distrito de La Chorrera', 'PA.08.3707960', 'ASCII:Distrito de La Chorrera;ID:3707960', '20759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20759', '112', '22636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3707960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22637', '1079', '1', 'Distrito Guararé', 'PA.07.3708907', 'ASCII:Distrito Guarare;ID:3708907', '20760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20760', '112', '22637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.07.3708907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22638', '1079', '1', 'Distrito Gualaca', 'PA.02.3708946', 'ASCII:Distrito Gualaca;ID:3708946', '20761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20761', '112', '22638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3708946» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22639', '1079', '1', 'Distrito Donoso', 'PA.04.3711599', 'ASCII:Distrito Donoso;ID:3711599', '20762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20762', '112', '22639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.04.3711599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22640', '1079', '1', 'Distrito Dolega', 'PA.02.3711616', 'ASCII:Distrito Dolega;ID:3711616', '20763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20763', '112', '22640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3711616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22641', '1079', '1', 'Distrito David', 'PA.02.3711666', 'ASCII:Distrito David;ID:3711666', '20764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20764', '112', '22641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3711666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22642', '1079', '1', 'Distrito de Colón', 'PA.04.3712075', 'ASCII:Distrito de Colon;ID:3712075', '20765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20765', '112', '22642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.04.3712075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22643', '1079', '1', 'Distrito de Chitré', 'PA.06.3712382', 'ASCII:Distrito de Chitre;ID:3712382', '20766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20766', '112', '22643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.06.3712382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22644', '1079', '1', 'Distrito Chiriquí Grande', 'PA.01.3712399', 'ASCII:Distrito Chiriqui Grande;ID:3712399', '20767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20767', '112', '22644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.01.3712399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22645', '1079', '1', 'Distrito Chimán', 'PA.08.3712446', 'ASCII:Distrito Chiman;ID:3712446', '20768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20768', '112', '22645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3712446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22646', '1079', '1', 'Distrito Chepo', 'PA.08.3712502', 'ASCII:Distrito Chepo;ID:3712502', '20769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20769', '112', '22646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3712502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22647', '1079', '1', 'Distrito de Chepigana', 'PA.05.3712512', 'ASCII:Distrito de Chepigana;ID:3712512', '20770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20770', '112', '22647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.05.3712512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22648', '1079', '1', 'Distrito Changuinola', 'PA.01.3712558', 'ASCII:Distrito Changuinola;ID:3712558', '20771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20771', '112', '22648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.01.3712558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22649', '1079', '1', 'Distrito Chame', 'PA.08.3712575', 'ASCII:Distrito Chame;ID:3712575', '20772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20772', '112', '22649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3712575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22650', '1079', '1', 'Distrito Chagres', 'PA.04.3712596', 'ASCII:Distrito Chagres;ID:3712596', '20773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20773', '112', '22650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.04.3712596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22651', '1079', '1', 'Distrito Capira', 'PA.08.3713045', 'ASCII:Distrito Capira;ID:3713045', '20774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20774', '112', '22651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3713045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22652', '1079', '1', 'Distrito Cañazas', 'PA.10.3713184', 'ASCII:Distrito Canazas;ID:3713184', '20775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20775', '112', '22652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3713184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22653', '1079', '1', 'Distrito Calobre', 'PA.10.3713393', 'ASCII:Distrito Calobre;ID:3713393', '20776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20776', '112', '22653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3713393» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22654', '1079', '1', 'Distrito Bugaba', 'PA.02.3713665', 'ASCII:Distrito Bugaba;ID:3713665', '20777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20777', '112', '22654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3713665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22655', '1079', '1', 'Distrito Boquete', 'PA.02.3713858', 'ASCII:Distrito Boquete;ID:3713858', '20778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20778', '112', '22655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3713858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22656', '1079', '1', 'Distrito Boquerón', 'PA.02.3713866', 'ASCII:Distrito Boqueron;ID:3713866', '20779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20779', '112', '22656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3713866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22657', '1079', '1', 'Distrito de Bocas del Toro', 'PA.01.3713955', 'ASCII:Distrito de Bocas del Toro;ID:3713955', '20780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20780', '112', '22657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.01.3713955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22658', '1079', '1', 'Distrito de Barú', 'PA.02.3714267', 'ASCII:Distrito de Baru;ID:3714267', '20781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20781', '112', '22658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3714267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22659', '1079', '1', 'Distrito Balboa', 'PA.08.3714424', 'ASCII:Distrito Balboa;ID:3714424', '20782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20782', '112', '22659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3714424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22660', '1079', '1', 'Distrito Atalaya', 'PA.10.3714595', 'ASCII:Distrito Atalaya;ID:3714595', '20783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20783', '112', '22660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.10.3714595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22661', '1079', '1', 'Distrito Arraiján', 'PA.08.3714635', 'ASCII:Distrito Arraijan;ID:3714635', '20784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20784', '112', '22661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.08.3714635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22662', '1079', '1', 'Distrito Antón', 'PA.03.3714708', 'ASCII:Distrito Anton;ID:3714708', '20785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20785', '112', '22662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.03.3714708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22663', '1079', '1', 'Distrito de Alanje', 'PA.02.3714937', 'ASCII:Distrito de Alanje;ID:3714937', '20786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20786', '112', '22663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.02.3714937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22664', '1079', '1', 'Corregimiento Ailigandí', 'PA.09.3714955', 'ASCII:Corregimiento Ailigandi;ID:3714955', '20787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20787', '112', '22664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.09.3714955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22665', '1079', '1', 'Distrito de Aguadulce', 'PA.03.3715037', 'ASCII:Distrito de Aguadulce;ID:3715037', '20788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20788', '112', '22665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PA.03.3715037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22666', '1079', '1', 'Provincia de Zarumilla', 'PE.24.3690615', 'ASCII:Provincia de Zarumilla;ID:3690615', '20789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20789', '112', '22666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.24.3690615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22667', '1079', '1', 'Provincia de Yungay', 'PE.02.3690672', 'ASCII:Provincia de Yungay;ID:3690672', '20790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20790', '112', '22667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3690672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22668', '1079', '1', 'Provincia de Ucayali', 'PE.16.3691097', 'ASCII:Provincia de Ucayali;ID:3691097', '20791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20791', '112', '22668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.16.3691097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22669', '1079', '1', 'Provincia de Tumbes', 'PE.24.3691145', 'ASCII:Provincia de Tumbes;ID:3691145', '20792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20792', '112', '22669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.24.3691145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22670', '1079', '1', 'Provincia de Trujillo', 'PE.13.3691174', 'ASCII:Provincia de Trujillo;ID:3691174', '20793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20793', '112', '22670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.13.3691174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22671', '1079', '1', 'Provincia de Talara', 'PE.20.3691580', 'ASCII:Provincia de Talara;ID:3691580', '20794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20794', '112', '22671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.20.3691580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22672', '1079', '1', 'Provincia de Sullana', 'PE.20.3691673', 'ASCII:Provincia de Sullana;ID:3691673', '20795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20795', '112', '22672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.20.3691673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22673', '1079', '1', 'Provincia de Sihuas', 'PE.02.3691835', 'ASCII:Provincia de Sihuas;ID:3691835', '20796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20796', '112', '22673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3691835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22674', '1079', '1', 'Provincia de Santiago de Chuco', 'PE.13.3692071', 'ASCII:Provincia de Santiago de Chuco;ID:3692071', '20797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20797', '112', '22674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.13.3692071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22675', '1079', '1', 'Provincia de Santa Cruz', 'PE.06.3692215', 'ASCII:Provincia de Santa Cruz;ID:3692215', '20798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20798', '112', '22675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3692215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22676', '1079', '1', 'Provincia de Santa', 'PE.02.3692276', 'ASCII:Provincia de Santa;ID:3692276', '20799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20799', '112', '22676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3692276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22677', '1079', '1', 'Provincia de San Miguel', 'PE.06.3692365', 'ASCII:Provincia de San Miguel;ID:3692365', '20800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20800', '112', '22677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3692365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22678', '1079', '1', 'Provincia de San Martín', 'PE.22.3692383', 'ASCII:Provincia de San Martin;ID:3692383', '20801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20801', '112', '22678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.22.3692383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22679', '1079', '1', 'Provincia de San Ignacio', 'PE.06.3692526', 'ASCII:Provincia de San Ignacio;ID:3692526', '20802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20802', '112', '22679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3692526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22680', '1079', '1', 'Provincia de Rodríguez de Mendoza', 'PE.01.3692841', 'ASCII:Provincia de Rodriguez de Mendoza;ID:3692841', '20803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20803', '112', '22680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.01.3692841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22681', '1079', '1', 'Provincia de Rioja', 'PE.22.3692862', 'ASCII:Provincia de Rioja;ID:3692862', '20804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20804', '112', '22681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.22.3692862» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22682', '1079', '1', 'Provincia de Requena', 'PE.16.3692894', 'ASCII:Provincia de Requena;ID:3692894', '20805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20805', '112', '22682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.16.3692894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22683', '1079', '1', 'Provincia de Pomabamba', 'PE.02.3693467', 'ASCII:Provincia de Pomabamba;ID:3693467', '20806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20806', '112', '22683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3693467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22684', '1079', '1', 'Provincia de Piura', 'PE.20.3693524', 'ASCII:Provincia de Piura;ID:3693524', '20807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20807', '112', '22684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.20.3693524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22685', '1079', '1', 'Provincia de Pataz', 'PE.13.3693821', 'ASCII:Provincia de Pataz;ID:3693821', '20808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20808', '112', '22685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.13.3693821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22686', '1079', '1', 'Provincia de Pallasca', 'PE.02.3694074', 'ASCII:Provincia de Pallasca;ID:3694074', '20809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20809', '112', '22686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3694074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22687', '1079', '1', 'Provincia de Paita', 'PE.20.3694110', 'ASCII:Provincia de Paita;ID:3694110', '20810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20810', '112', '22687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.20.3694110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22688', '1079', '1', 'Provincia de Pachitea', 'PE.10.3694144', 'ASCII:Provincia de Pachitea;ID:3694144', '20811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20811', '112', '22688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.10.3694144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22689', '1079', '1', 'Provincia de Pacasmayo', 'PE.13.3694175', 'ASCII:Provincia de Pacasmayo;ID:3694175', '20812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20812', '112', '22689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.13.3694175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22690', '1079', '1', 'Provincia de Otuzco', 'PE.13.3694211', 'ASCII:Provincia de Otuzco;ID:3694211', '20813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20813', '112', '22690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.13.3694211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22691', '1079', '1', 'Provincia de Moyobamba', 'PE.22.3694563', 'ASCII:Provincia de Moyobamba;ID:3694563', '20814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20814', '112', '22691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.22.3694563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22692', '1079', '1', 'Provincia de Morropón', 'PE.20.3694581', 'ASCII:Provincia de Morropon;ID:3694581', '20815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20815', '112', '22692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.20.3694581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22693', '1079', '1', 'Provincia de Maynas', 'PE.16.3694873', 'ASCII:Provincia de Maynas;ID:3694873', '20816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20816', '112', '22693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.16.3694873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22694', '1079', '1', 'Provincia de Mariscal Luzuriaga', 'PE.02.3694919', 'ASCII:Provincia de Mariscal Luzuriaga;ID:3694919', '20817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20817', '112', '22694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3694919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22695', '1079', '1', 'Provincia de Mariscal Cáceres', 'PE.22.3694924', 'ASCII:Provincia de Mariscal Caceres;ID:3694924', '20818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20818', '112', '22695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.22.3694924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22696', '1079', '1', 'Provincia de Marañón', 'PE.10.3694961', 'ASCII:Provincia de Maranon;ID:3694961', '20819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20819', '112', '22696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.10.3694961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22697', '1079', '1', 'Provincia de Luya', 'PE.01.3695112', 'ASCII:Provincia de Luya;ID:3695112', '20820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20820', '112', '22697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.01.3695112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22698', '1079', '1', 'Provincia de Loreto', 'PE.16.3695237', 'ASCII:Provincia de Loreto;ID:3695237', '20821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20821', '112', '22698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.16.3695237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22699', '1079', '1', 'Provincia de Leoncio Prado', 'PE.10.3695414', 'ASCII:Provincia de Leoncio Prado;ID:3695414', '20822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20822', '112', '22699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.10.3695414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22700', '1079', '1', 'Provincia de Lambayeque', 'PE.14.3695752', 'ASCII:Provincia de Lambayeque;ID:3695752', '20823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20823', '112', '22700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.14.3695752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22701', '1079', '1', 'Provincia de Lamas', 'PE.22.3695756', 'ASCII:Provincia de Lamas;ID:3695756', '20824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20824', '112', '22701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.22.3695756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22702', '1079', '1', 'Provincia de Jaén', 'PE.06.3696149', 'ASCII:Provincia de Jaen;ID:3696149', '20825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20825', '112', '22702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3696149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22703', '1079', '1', 'Provincia de Huaylas', 'PE.02.3696296', 'ASCII:Provincia de Huaylas;ID:3696296', '20826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20826', '112', '22703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3696296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22704', '1079', '1', 'Provincia de Huarmey', 'PE.02.3696358', 'ASCII:Provincia de Huarmey;ID:3696358', '20827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20827', '112', '22704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3696358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22705', '1079', '1', 'Provincia de Huari', 'PE.02.3696371', 'ASCII:Provincia de Huari;ID:3696371', '20828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20828', '112', '22705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3696371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22706', '1079', '1', 'Provincia de Huaraz', 'PE.02.3696377', 'ASCII:Provincia de Huaraz;ID:3696377', '20829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20829', '112', '22706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3696377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22707', '1079', '1', 'Provincia de Huánuco', 'PE.10.3696415', 'ASCII:Provincia de Huanuco;ID:3696415', '20830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20830', '112', '22707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.10.3696415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22708', '1079', '1', 'Provincia de Huancabamba', 'PE.20.3696465', 'ASCII:Provincia de Huancabamba;ID:3696465', '20831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20831', '112', '22708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.20.3696465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22709', '1079', '1', 'Provincia de Huamalíes', 'PE.10.3696505', 'ASCII:Provincia de Huamalies;ID:3696505', '20832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20832', '112', '22709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.10.3696505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22710', '1079', '1', 'Provincia de Huamachuco', 'PE.13.3696508', 'ASCII:Provincia de Huamachuco;ID:3696508', '20833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20833', '112', '22710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.13.3696508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22711', '1079', '1', 'Provincia de Huallaga', 'PE.22.3696534', 'ASCII:Provincia de Huallaga;ID:3696534', '20834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20834', '112', '22711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.22.3696534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22712', '1079', '1', 'Provincia de Hualgayoc', 'PE.06.3696537', 'ASCII:Provincia de Hualgayoc;ID:3696537', '20835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20835', '112', '22712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3696537» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22713', '1079', '1', 'Provincia de Ferreñafe', 'PE.14.3697032', 'ASCII:Provincia de Ferrenafe;ID:3697032', '20836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20836', '112', '22713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.14.3697032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22714', '1079', '1', 'Provincia de Dos de Mayo', 'PE.10.3697460', 'ASCII:Provincia de Dos de Mayo;ID:3697460', '20837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20837', '112', '22714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.10.3697460» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22715', '1079', '1', 'Provincia de Cutervo', 'PE.06.3697539', 'ASCII:Provincia de Cutervo;ID:3697539', '20838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20838', '112', '22715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3697539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22716', '1079', '1', 'Provincia de Corongo', 'PE.02.3697793', 'ASCII:Provincia de Corongo;ID:3697793', '20839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20839', '112', '22716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3697793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22717', '1079', '1', 'Provincia de Coronel Portillo', 'PE.25.3697795', 'ASCII:Provincia de Coronel Portillo;ID:3697795', '20840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20840', '112', '22717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.25.3697795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22718', '1079', '1', 'Provincia de Contumazá', 'PE.06.3697832', 'ASCII:Provincia de Contumaza;ID:3697832', '20841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20841', '112', '22718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3697832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22719', '1079', '1', 'Provincia de Contralmirante Villar', 'PE.24.3697834', 'ASCII:Provincia de Contralmirante Villar;ID:3697834', '20842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20842', '112', '22719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.24.3697834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22720', '1079', '1', 'Provincia de Chota', 'PE.06.3698139', 'ASCII:Provincia de Chota;ID:3698139', '20843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20843', '112', '22720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3698139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22721', '1079', '1', 'Provincia de Chiclayo', 'PE.13.3698348', 'ASCII:Provincia de Chiclayo;ID:3698348', '20844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20844', '112', '22721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.13.3698348» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22722', '1079', '1', 'Provincia de Chachapoyas', 'PE.01.3698538', 'ASCII:Provincia de Chachapoyas;ID:3698538', '20845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20845', '112', '22722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.01.3698538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22723', '1079', '1', 'Provincia de Celendín', 'PE.06.3698607', 'ASCII:Provincia de Celendin;ID:3698607', '20846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20846', '112', '22723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3698607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22724', '1079', '1', 'Provincia de Casma', 'PE.02.3698678', 'ASCII:Provincia de Casma;ID:3698678', '20847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20847', '112', '22724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3698678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22725', '1079', '1', 'Provincia de Carhuaz', 'PE.02.3698813', 'ASCII:Provincia de Carhuaz;ID:3698813', '20848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20848', '112', '22725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3698813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22726', '1079', '1', 'Provincia de Cajamarca', 'PE.06.3699086', 'ASCII:Provincia de Cajamarca;ID:3699086', '20849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20849', '112', '22726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3699086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22727', '1079', '1', 'Provincia de Cajabamba', 'PE.06.3699094', 'ASCII:Provincia de Cajabamba;ID:3699094', '20850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20850', '112', '22727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.06.3699094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22728', '1079', '1', 'Provincia de Bongará', 'PE.01.3699269', 'ASCII:Provincia de Bongara;ID:3699269', '20851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20851', '112', '22728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.01.3699269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22729', '1079', '1', 'Provincia de Bolívar', 'PE.13.3699282', 'ASCII:Provincia de Bolivar;ID:3699282', '20852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20852', '112', '22729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.13.3699282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22730', '1079', '1', 'Provincia de Bagua', 'PE.01.3699485', 'ASCII:Provincia de Bagua;ID:3699485', '20853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20853', '112', '22730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.01.3699485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22731', '1079', '1', 'Provincia de Ayabaca', 'PE.20.3699501', 'ASCII:Provincia de Ayabaca;ID:3699501', '20854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20854', '112', '22731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.20.3699501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22732', '1079', '1', 'Provincia de Antonio Raymondi', 'PE.02.3699607', 'ASCII:Provincia de Antonio Raymondi;ID:3699607', '20855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20855', '112', '22732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3699607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22733', '1079', '1', 'Provincia de Alto Amazonas', 'PE.16.3699735', 'ASCII:Provincia de Alto Amazonas;ID:3699735', '20856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20856', '112', '22733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.16.3699735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22734', '1079', '1', 'Provincia de Aija', 'PE.02.3699820', 'ASCII:Provincia de Aija;ID:3699820', '20857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20857', '112', '22734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3699820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22735', '1079', '1', 'Provincia de Ica', 'PE.11.3925316', 'ASCII:Provincia de Ica;ID:3925316', '20858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20858', '112', '22735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.11.3925316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22736', '1079', '1', 'Provincia de Yauyos', 'PE.15.3925567', 'ASCII:Provincia de Yauyos;ID:3925567', '20859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20859', '112', '22736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.15.3925567» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22737', '1079', '1', 'Provincia de Yauli', 'PE.12.3925598', 'ASCII:Provincia de Yauli;ID:3925598', '20860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20860', '112', '22737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.12.3925598» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22738', '1079', '1', 'Provincia de Víctor Fajardo', 'PE.05.3926224', 'ASCII:Provincia de Victor Fajardo;ID:3926224', '20861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20861', '112', '22738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.05.3926224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22739', '1079', '1', 'Provincia de Urubamba', 'PE.08.3926436', 'ASCII:Provincia de Urubamba;ID:3926436', '20862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20862', '112', '22739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3926436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22740', '1079', '1', 'Provincia de Tayacaja', 'PE.09.3927670', 'ASCII:Provincia de Tayacaja;ID:3927670', '20863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20863', '112', '22740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.09.3927670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22741', '1079', '1', 'Provincia de Tarma', 'PE.12.3927757', 'ASCII:Provincia de Tarma;ID:3927757', '20864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20864', '112', '22741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.12.3927757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22742', '1079', '1', 'Provincia de Tarata', 'PE.23.3927773', 'ASCII:Provincia de Tarata;ID:3927773', '20865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20865', '112', '22742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.23.3927773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22743', '1079', '1', 'Provincia de Tambopata', 'PE.17.3927937', 'ASCII:Provincia de Tambopata;ID:3927937', '20866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20866', '112', '22743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.17.3927937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22744', '1079', '1', 'Provincia de Tahuamanú', 'PE.17.3928091', 'ASCII:Provincia de Tahuamanu;ID:3928091', '20867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20867', '112', '22744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.17.3928091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22745', '1079', '1', 'Provincia de Tacna', 'PE.23.3928126', 'ASCII:Provincia de Tacna;ID:3928126', '20868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20868', '112', '22745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.23.3928126» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22746', '1079', '1', 'Provincia de Satipo', 'PE.12.3928923', 'ASCII:Provincia de Satipo;ID:3928923', '20869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20869', '112', '22746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.12.3928923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22747', '1079', '1', 'Provincia de San Román', 'PE.21.3929310', 'ASCII:Provincia de San Roman;ID:3929310', '20870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20870', '112', '22747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.21.3929310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22748', '1079', '1', 'Provincia de Sandia', 'PE.21.3929739', 'ASCII:Provincia de Sandia;ID:3929739', '20871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20871', '112', '22748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.21.3929739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22749', '1079', '1', 'Provincia de Recuay', 'PE.02.3930459', 'ASCII:Provincia de Recuay;ID:3930459', '20872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20872', '112', '22749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3930459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22750', '1079', '1', 'Provincia de Quispicanchis', 'PE.08.3930646', 'ASCII:Provincia de Quispicanchis;ID:3930646', '20873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20873', '112', '22750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3930646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22751', '1079', '1', 'Provincia de Puno', 'PE.21.3931274', 'ASCII:Provincia de Puno;ID:3931274', '20874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20874', '112', '22751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.21.3931274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22752', '1079', '1', 'Provincia de Pisco', 'PE.11.3932143', 'ASCII:Provincia de Pisco;ID:3932143', '20875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20875', '112', '22752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.11.3932143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22753', '1079', '1', 'Provincia de Paucartambo', 'PE.08.3932649', 'ASCII:Provincia de Paucartambo;ID:3932649', '20876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20876', '112', '22753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3932649» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22754', '1079', '1', 'Provincia de Pasco', 'PE.19.3932833', 'ASCII:Provincia de Pasco;ID:3932833', '20877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20877', '112', '22754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.19.3932833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22755', '1079', '1', 'Provincia de Paruro', 'PE.08.3932863', 'ASCII:Provincia de Paruro;ID:3932863', '20878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20878', '112', '22755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3932863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22756', '1079', '1', 'Provincia de Parinacochas', 'PE.05.3932906', 'ASCII:Provincia de Parinacochas;ID:3932906', '20879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20879', '112', '22756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.05.3932906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22757', '1079', '1', 'Provincia de Palpa', 'PE.11.3933344', 'ASCII:Provincia de Palpa;ID:3933344', '20880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20880', '112', '22757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.11.3933344» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22758', '1079', '1', 'Provincia de Oxapampa', 'PE.19.3933873', 'ASCII:Provincia de Oxapampa;ID:3933873', '20881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20881', '112', '22758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.19.3933873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22759', '1079', '1', 'Provincia de Nazca', 'PE.11.3934353', 'ASCII:Provincia de Nazca;ID:3934353', '20882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20882', '112', '22759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.11.3934353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22760', '1079', '1', 'Provincia de Melgar', 'PE.21.3935054', 'ASCII:Provincia de Melgar;ID:3935054', '20883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20883', '112', '22760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.21.3935054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22761', '1079', '1', 'Provincia de Mariscal Nieto', 'PE.18.3935255', 'ASCII:Provincia de Mariscal Nieto;ID:3935255', '20884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20884', '112', '22761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.18.3935255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22762', '1079', '1', 'Provincia de Manú', 'PE.17.3935423', 'ASCII:Provincia de Manu;ID:3935423', '20885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20885', '112', '22762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.17.3935423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22763', '1079', '1', 'Provincia de Lucanas', 'PE.05.3935835', 'ASCII:Provincia de Lucanas;ID:3935835', '20886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20886', '112', '22763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.05.3935835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22764', '1079', '1', 'Provincia de Lima', 'PE.15.3936451', 'ASCII:Provincia de Lima;ID:3936451', '20887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20887', '112', '22764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.15.3936451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22765', '1079', '1', 'Provincia de La Unión', 'PE.04.3936625', 'ASCII:Provincia de La Union;ID:3936625', '20888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20888', '112', '22765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.04.3936625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22766', '1079', '1', 'Provincia de Lampa', 'PE.21.3936995', 'ASCII:Provincia de Lampa;ID:3936995', '20889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20889', '112', '22766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.21.3936995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22767', '1079', '1', 'Provincia de La Mar', 'PE.09.3937045', 'ASCII:Provincia de La Mar;ID:3937045', '20890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20890', '112', '22767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.09.3937045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22768', '1079', '1', 'Provincia de La Convención', 'PE.08.3937248', 'ASCII:Provincia de La Convencion;ID:3937248', '20891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20891', '112', '22768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3937248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22769', '1079', '1', 'Provincia de Junín', 'PE.12.3937483', 'ASCII:Provincia de Junin;ID:3937483', '20892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20892', '112', '22769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.12.3937483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22770', '1079', '1', 'Provincia de Jauja', 'PE.12.3937732', 'ASCII:Provincia de Jauja;ID:3937732', '20893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20893', '112', '22770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.12.3937732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22771', '1079', '1', 'Provincia de Islay', 'PE.04.3938145', 'ASCII:Provincia de Islay;ID:3938145', '20894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20894', '112', '22771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.04.3938145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22772', '1079', '1', 'Provincia de Ilo', 'PE.18.3938414', 'ASCII:Provincia de Ilo;ID:3938414', '20895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20895', '112', '22772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.18.3938414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22773', '1079', '1', 'Provincia de Huarochirí', 'PE.15.3939153', 'ASCII:Provincia de Huarochiri;ID:3939153', '20896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20896', '112', '22773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.15.3939153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22774', '1079', '1', 'Provincia de Huaral', 'PE.15.3939284', 'ASCII:Provincia de Huaral;ID:3939284', '20897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20897', '112', '22774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.15.3939284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22775', '1079', '1', 'Provincia de Huanta', 'PE.05.3939385', 'ASCII:Provincia de Huanta;ID:3939385', '20898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20898', '112', '22775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.05.3939385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22776', '1079', '1', 'Provincia de Huancayo', 'PE.12.3939456', 'ASCII:Provincia de Huancayo;ID:3939456', '20899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20899', '112', '22776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.12.3939456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22777', '1079', '1', 'Provincia de Huancavelica', 'PE.09.3939465', 'ASCII:Provincia de Huancavelica;ID:3939465', '20900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20900', '112', '22777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.09.3939465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22778', '1079', '1', 'Provincia de Huancané', 'PE.21.3939536', 'ASCII:Provincia de Huancane;ID:3939536', '20901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20901', '112', '22778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.21.3939536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22779', '1079', '1', 'Provincia de Huamanga', 'PE.05.3939740', 'ASCII:Provincia de Huamanga;ID:3939740', '20902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20902', '112', '22779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.05.3939740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22780', '1079', '1', 'Provincia de Grau', 'PE.03.3940641', 'ASCII:Provincia de Grau;ID:3940641', '20903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20903', '112', '22780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.03.3940641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22781', '1079', '1', 'Provincia de General Sánchez Cerro', 'PE.18.3940771', 'ASCII:Provincia de General Sanchez Cerro;ID:3940771', '20904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20904', '112', '22781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.18.3940771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22782', '1079', '1', 'Provincia de Espinar', 'PE.08.3941092', 'ASCII:Provincia de Espinar;ID:3941092', '20905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20905', '112', '22782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3941092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22783', '1079', '1', 'Provincia de Daniel Carrión', 'PE.19.3941507', 'ASCII:Provincia de Daniel Carrion;ID:3941507', '20906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20906', '112', '22783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.19.3941507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22784', '1079', '1', 'Provincia de Cusco', 'PE.08.3941582', 'ASCII:Provincia de Cusco;ID:3941582', '20907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20907', '112', '22784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3941582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22785', '1079', '1', 'Provincia de Cotabambas', 'PE.03.3942083', 'ASCII:Provincia de Cotabambas;ID:3942083', '20908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20908', '112', '22785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.03.3942083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22786', '1079', '1', 'Provincia de Condesuyos', 'PE.04.3942520', 'ASCII:Provincia de Condesuyos;ID:3942520', '20909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20909', '112', '22786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.04.3942520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22787', '1079', '1', 'Provincia de Concepción', 'PE.12.3942545', 'ASCII:Provincia de Concepcion;ID:3942545', '20910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20910', '112', '22787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.12.3942545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22788', '1079', '1', 'Provincia de Chumbivilcas', 'PE.08.3943263', 'ASCII:Provincia de Chumbivilcas;ID:3943263', '20911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20911', '112', '22788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3943263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22789', '1079', '1', 'Provincia de Chucuito', 'PE.21.3943362', 'ASCII:Provincia de Chucuito;ID:3943362', '20912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20912', '112', '22789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.21.3943362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22790', '1079', '1', 'Provincia de Chincha', 'PE.11.3943790', 'ASCII:Provincia de Chincha;ID:3943790', '20913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20913', '112', '22790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.11.3943790» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22791', '1079', '1', 'Provincia de Caylloma', 'PE.04.3945135', 'ASCII:Provincia de Caylloma;ID:3945135', '20914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20914', '112', '22791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.04.3945135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22792', '1079', '1', 'Provincia de Castrovirreyna', 'PE.09.3945232', 'ASCII:Provincia de Castrovirreyna;ID:3945232', '20915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20915', '112', '22792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.09.3945232» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22793', '1079', '1', 'Provincia de Castilla', 'PE.04.3945239', 'ASCII:Provincia de Castilla;ID:3945239', '20916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20916', '112', '22793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.04.3945239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22794', '1079', '1', 'Provincia de Caravelí', 'PE.04.3945539', 'ASCII:Provincia de Caraveli;ID:3945539', '20917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20917', '112', '22794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.04.3945539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22795', '1079', '1', 'Provincia de Carabaya', 'PE.21.3945614', 'ASCII:Provincia de Carabaya;ID:3945614', '20918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20918', '112', '22795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.21.3945614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22796', '1079', '1', 'Provincia de Canta', 'PE.15.3945748', 'ASCII:Provincia de Canta;ID:3945748', '20919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20919', '112', '22796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.15.3945748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22797', '1079', '1', 'Provincia de Cangallo', 'PE.05.3945791', 'ASCII:Provincia de Cangallo;ID:3945791', '20920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20920', '112', '22797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.05.3945791» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22798', '1079', '1', 'Provincia de Cañete', 'PE.15.3945799', 'ASCII:Provincia de Canete;ID:3945799', '20921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20921', '112', '22798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.15.3945799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22799', '1079', '1', 'Provincia de Canchis', 'PE.08.3945823', 'ASCII:Provincia de Canchis;ID:3945823', '20922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20922', '112', '22799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3945823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22800', '1079', '1', 'Provincia de Canas', 'PE.08.3945875', 'ASCII:Provincia de Canas;ID:3945875', '20923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20923', '112', '22800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3945875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22801', '1079', '1', 'Provincia de Camaná', 'PE.04.3945982', 'ASCII:Provincia de Camana;ID:3945982', '20924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20924', '112', '22801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.04.3945982» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22802', '1079', '1', 'Provincia de Calca', 'PE.08.3946176', 'ASCII:Provincia de Calca;ID:3946176', '20925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20925', '112', '22802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3946176» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22803', '1079', '1', 'Provincia de Cajatambo', 'PE.15.3946262', 'ASCII:Provincia de Cajatambo;ID:3946262', '20926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20926', '112', '22803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.15.3946262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22804', '1079', '1', 'Provincia de Bolognesi', 'PE.02.3946643', 'ASCII:Provincia de Bolognesi;ID:3946643', '20927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20927', '112', '22804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.02.3946643» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22805', '1079', '1', 'Provincia de Azángaro', 'PE.21.3946936', 'ASCII:Provincia de Azangaro;ID:3946936', '20928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20928', '112', '22805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.21.3946936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22806', '1079', '1', 'Provincia de Aymaraes', 'PE.03.3946963', 'ASCII:Provincia de Aymaraes;ID:3946963', '20929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20929', '112', '22806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.03.3946963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22807', '1079', '1', 'Provincia de Arequipa', 'PE.04.3947318', 'ASCII:Provincia de Arequipa;ID:3947318', '20930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20930', '112', '22807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.04.3947318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22808', '1079', '1', 'Provincia de Antabamba', 'PE.03.3947611', 'ASCII:Provincia de Antabamba;ID:3947611', '20931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20931', '112', '22808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.03.3947611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22809', '1079', '1', 'Provincia de Anta', 'PE.08.3947623', 'ASCII:Provincia de Anta;ID:3947623', '20932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20932', '112', '22809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3947623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22810', '1079', '1', 'Provincia de Angaraes', 'PE.09.3947704', 'ASCII:Provincia de Angaraes;ID:3947704', '20933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20933', '112', '22810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.09.3947704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22811', '1079', '1', 'Provincia de Andahuaylas', 'PE.03.3947739', 'ASCII:Provincia de Andahuaylas;ID:3947739', '20934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20934', '112', '22811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.03.3947739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22812', '1079', '1', 'Provincia de Ambo', 'PE.10.3947955', 'ASCII:Provincia de Ambo;ID:3947955', '20935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20935', '112', '22812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.10.3947955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22813', '1079', '1', 'Provincia de Acomayo', 'PE.08.3948442', 'ASCII:Provincia de Acomayo;ID:3948442', '20936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20936', '112', '22813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.08.3948442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22814', '1079', '1', 'Provincia de Acobamba', 'PE.09.3948478', 'ASCII:Provincia de Acobamba;ID:3948478', '20937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20937', '112', '22814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.09.3948478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22815', '1079', '1', 'Provincia de Abancay', 'PE.03.3948641', 'ASCII:Provincia de Abancay;ID:3948641', '20938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20938', '112', '22815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PE.03.3948641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22816', '1079', '1', 'Circonscription Administrative des Îles Marquises', 'PF.00.4019991', 'ASCII:Circonscription Administrative des Iles Marquises;ID:4019991', '20939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20939', '112', '22816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PF.00.4019991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22817', '1079', '1', 'Circonscription Administrative des Îles Tuamotu et Gambier', 'PF.00.4030621', 'ASCII:Circonscription Administrative des Iles Tuamotu et Gambier;ID:4030621', '20940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20940', '112', '22817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PF.00.4030621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22818', '1079', '1', 'Circonscription Administrative des Îles Sous le Vent', 'PF.00.4034364', 'ASCII:Circonscription Administrative des Iles Sous le Vent;ID:4034364', '20941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20941', '112', '22818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PF.00.4034364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22819', '1079', '1', 'Circonscription Administrative des Îles du Vent', 'PF.00.4034365', 'ASCII:Circonscription Administrative des Iles du Vent;ID:4034365', '20942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20942', '112', '22819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PF.00.4034365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22820', '1079', '1', 'Circonscription Administrative des Îles Australes', 'PF.00.4034366', 'ASCII:Circonscription Administrative des Iles Australes;ID:4034366', '20943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20943', '112', '22820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PF.00.4034366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22821', '1079', '1', 'Zumarraga', 'PH.55.1679361', 'ASCII:Zumarraga;ID:1679361', '20944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20944', '112', '22821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1679361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22822', '1079', '1', 'Zarraga', 'PH.30.1679385', 'ASCII:Zarraga;ID:1679385', '20945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20945', '112', '22822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1679385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22823', '1079', '1', 'Zaragosa', 'PH.47.1679400', 'ASCII:Zaragosa;ID:1679400', '20946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20946', '112', '22823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1679400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22824', '1079', '1', 'Zamboanguita', 'PH.46.1679424', 'ASCII:Zamboanguita;ID:1679424', '20947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20947', '112', '22824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1679424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22825', '1079', '1', 'Wright', 'PH.55.1679560', 'ASCII:Wright;ID:1679560', '20948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20948', '112', '22825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1679560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22826', '1079', '1', 'Wao', 'PH.35.1679679', 'ASCII:Wao;ID:1679679', '20949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20949', '112', '22826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1679679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22827', '1079', '1', 'Virac', 'PH.19.1679804', 'ASCII:Virac;ID:1679804', '20950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20950', '112', '22827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1679804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22828', '1079', '1', 'Vinzons', 'PH.15.1679812', 'ASCII:Vinzons;ID:1679812', '20951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20951', '112', '22828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1679812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22829', '1079', '1', 'Vintar', 'PH.28.1679818', 'ASCII:Vintar;ID:1679818', '20952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20952', '112', '22829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1679818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22830', '1079', '1', 'Villaviciosa', 'PH.01.1679838', 'ASCII:Villaviciosa;ID:1679838', '20953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20953', '112', '22830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1679838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22831', '1079', '1', 'Villa Verde', 'PH.48.1679842', 'ASCII:Villa Verde;ID:1679842', '20954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20954', '112', '22831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1679842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22832', '1079', '1', 'Villasis', 'PH.51.1679846', 'ASCII:Villasis;ID:1679846', '20955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20955', '112', '22832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1679846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22833', '1079', '1', 'Villareal', 'PH.55.1679857', 'ASCII:Villareal;ID:1679857', '20956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20956', '112', '22833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1679857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22834', '1079', '1', 'Villanueva', 'PH.43.1679874', 'ASCII:Villanueva;ID:1679874', '20957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20957', '112', '22834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1679874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22835', '1079', '1', 'Villaba', 'PH.37.1679947', 'ASCII:Villaba;ID:1679947', '20958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20958', '112', '22835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1679947» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22836', '1079', '1', 'Vigan', 'PH.29.1679983', 'ASCII:Vigan;ID:1679983', '20959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20959', '112', '22836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1679983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22837', '1079', '1', 'Viga', 'PH.19.1679997', 'ASCII:Viga;ID:1679997', '20960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20960', '112', '22837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1679997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22838', '1079', '1', 'Victorias', 'PH.H3.1680009', 'ASCII:Victorias;ID:1680009', '20961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20961', '112', '22838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1680009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22839', '1079', '1', 'Victoria', 'PH.63.1680026', 'ASCII:Victoria;ID:1680026', '20962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20962', '112', '22839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1680026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22840', '1079', '1', 'Victoria', 'PH.33.1680027', 'ASCII:Victoria;ID:1680027', '20963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20963', '112', '22840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1680027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22841', '1079', '1', 'Victoria', 'PH.41.1680028', 'ASCII:Victoria;ID:1680028', '20964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20964', '112', '22841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1680028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22842', '1079', '1', 'Victoria', 'PH.67.1680029', 'ASCII:Victoria;ID:1680029', '20965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20965', '112', '22842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1680029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22843', '1079', '1', 'Veruela', 'PH.03.1680041', 'ASCII:Veruela;ID:1680041', '20966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20966', '112', '22843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.1680041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22844', '1079', '1', 'Vallehermoso', 'PH.46.1680094', 'ASCII:Vallehermoso;ID:1680094', '20967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20967', '112', '22844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1680094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22845', '1079', '1', 'Valladolid', 'PH.H3.1680100', 'ASCII:Valladolid;ID:1680100', '20968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20968', '112', '22845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1680100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22846', '1079', '1', 'Valenzuela', 'PH.53.1680103', 'ASCII:Valenzuela;ID:1680103', '20969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20969', '112', '22846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1680103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22847', '1079', '1', 'Valencia', 'PH.11.1680117', 'ASCII:Valencia;ID:1680117', '20970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20970', '112', '22847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1680117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22848', '1079', '1', 'Valencia', 'PH.46.1680118', 'ASCII:Valencia;ID:1680118', '20971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20971', '112', '22848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1680118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22849', '1079', '1', 'Valencia', 'PH.12.1680119', 'ASCII:Valencia;ID:1680119', '20972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20972', '112', '22849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1680119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22850', '1079', '1', 'Valderama', 'PH.06.1680128', 'ASCII:Valderama;ID:1680128', '20973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20973', '112', '22850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1680128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22851', '1079', '1', 'Uyugan', 'PH.08.1680133', 'ASCII:Uyugan;ID:1680133', '20974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20974', '112', '22851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.08.1680133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22852', '1079', '1', 'Uson', 'PH.39.1680175', 'ASCII:Uson;ID:1680175', '20975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20975', '112', '22852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1680175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22853', '1079', '1', 'Urdaneta', 'PH.51.1680199', 'ASCII:Urdaneta;ID:1680199', '20976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20976', '112', '22853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1680199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22854', '1079', '1', 'Urbiztondo', 'PH.51.1680202', 'ASCII:Urbiztondo;ID:1680202', '20977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20977', '112', '22854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1680202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22855', '1079', '1', 'Upi', 'PH.56.1680234', 'ASCII:Upi;ID:1680234', '20978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20978', '112', '22855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1680234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22856', '1079', '1', 'Unisan', 'PH.H2.1680251', 'ASCII:Unisan;ID:1680251', '20979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20979', '112', '22856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1680251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22857', '1079', '1', 'Umingan', 'PH.51.1680315', 'ASCII:Umingan;ID:1680315', '20980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20980', '112', '22857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1680315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22858', '1079', '1', 'Ubay', 'PH.11.1680477', 'ASCII:Ubay;ID:1680477', '20981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20981', '112', '22858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1680477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22859', '1079', '1', 'Tuy', 'PH.02.1680555', 'ASCII:Tuy;ID:1680555', '20982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20982', '112', '22859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.02.1680555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22860', '1079', '1', 'Turtle Islands', 'PH.72.1680579', 'ASCII:Turtle Islands;ID:1680579', '20983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20983', '112', '22860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.72.1680579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22861', '1079', '1', 'Tupi', 'PH.70.1680614', 'ASCII:Tupi;ID:1680614', '20984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20984', '112', '22861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1680614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22862', '1079', '1', 'Tungkil', 'PH.60.1680665', 'ASCII:Tungkil;ID:1680665', '20985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20985', '112', '22862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1680665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22863', '1079', '1', 'Tungawan', 'PH.66.1680678', 'ASCII:Tungawan;ID:1680678', '20986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20986', '112', '22863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1680678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22864', '1079', '1', 'Tunga', 'PH.37.1680700', 'ASCII:Tunga;ID:1680700', '20987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20987', '112', '22864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1680700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22865', '1079', '1', 'Tumauini', 'PH.31.1680754', 'ASCII:Tumauini;ID:1680754', '20988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20988', '112', '22865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1680754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22866', '1079', '1', 'Tulunan', 'PH.57.1680821', 'ASCII:Tulunan;ID:1680821', '20989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20989', '112', '22866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1680821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22867', '1079', '1', 'Tukuran', 'PH.66.1680886', 'ASCII:Tukuran;ID:1680886', '20990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20990', '112', '22867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1680886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22868', '1079', '1', 'Tuguegarao', 'PH.14.1680935', 'ASCII:Tuguegarao;ID:1680935', '20991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20991', '112', '22868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1680935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22869', '1079', '1', 'Tugaya', 'PH.35.1680967', 'ASCII:Tugaya;ID:1680967', '20992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20992', '112', '22869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1680967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22870', '1079', '1', 'Tudela', 'PH.21.1681029', 'ASCII:Tudela;ID:1681029', '20993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20993', '112', '22870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1681029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22871', '1079', '1', 'Municipality of Tudela', 'PH.42.1681030', 'ASCII:Municipality of Tudela;ID:1681030', '20994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20994', '112', '22871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1681030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22872', '1079', '1', 'Tuburan', 'PH.21.1681080', 'ASCII:Tuburan;ID:1681080', '20995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20995', '112', '22872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1681080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22873', '1079', '1', 'Tuburan', 'PH.22.1681081', 'ASCII:Tuburan;ID:1681081', '20996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20996', '112', '22873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.22.1681081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22874', '1079', '1', 'Tubungan', 'PH.30.1681088', 'ASCII:Tubungan;ID:1681088', '20997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20997', '112', '22874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1681088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22875', '1079', '1', 'Tubod', 'PH.61.1681151', 'ASCII:Tubod;ID:1681151', '20998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20998', '112', '22875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1681151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22876', '1079', '1', 'Municipality of Tubod', 'PH.34.1681152', 'ASCII:Municipality of Tubod;ID:1681152', '20999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('20999', '112', '22876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1681152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22877', '1079', '1', 'Tubo', 'PH.01.1681159', 'ASCII:Tubo;ID:1681159', '21000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21000', '112', '22877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1681159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22878', '1079', '1', 'Tublay', 'PH.10.1681168', 'ASCII:Tublay;ID:1681168', '21001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21001', '112', '22878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1681168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22879', '1079', '1', 'Tubigon', 'PH.11.1681183', 'ASCII:Tubigon;ID:1681183', '21002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21002', '112', '22879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1681183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22880', '1079', '1', 'Tubay', 'PH.02.1681236', 'ASCII:Tubay;ID:1681236', '21003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21003', '112', '22880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.02.1681236» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22881', '1079', '1', 'Tubaran', 'PH.35.1681243', 'ASCII:Tubaran;ID:1681243', '21004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21004', '112', '22881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1681243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22882', '1079', '1', 'Tubao', 'PH.36.1681246', 'ASCII:Tubao;ID:1681246', '21005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21005', '112', '22882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1681246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22883', '1079', '1', 'Tubajon', 'PH.61.1681261', 'ASCII:Tubajon;ID:1681261', '21006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21006', '112', '22883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1681261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22884', '1079', '1', 'Tuba', 'PH.10.1681277', 'ASCII:Tuba;ID:1681277', '21007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21007', '112', '22884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1681277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22885', '1079', '1', 'Tuao', 'PH.14.1681286', 'ASCII:Tuao;ID:1681286', '21008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21008', '112', '22885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1681286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22886', '1079', '1', 'Trinidad', 'PH.11.1681317', 'ASCII:Trinidad;ID:1681317', '21009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21009', '112', '22886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1681317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22887', '1079', '1', 'Trento', 'PH.03.1681334', 'ASCII:Trento;ID:1681334', '21010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21010', '112', '22887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.1681334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22888', '1079', '1', 'Torrijos', 'PH.38.1681393', 'ASCII:Torrijos;ID:1681393', '21011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21011', '112', '22888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.38.1681393» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22889', '1079', '1', 'Tomas Oppus', 'PH.59.1681545', 'ASCII:Tomas Oppus;ID:1681545', '21012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21012', '112', '22889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1681545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22890', '1079', '1', 'Tolosa', 'PH.37.1681574', 'ASCII:Tolosa;ID:1681574', '21013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21013', '112', '22890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1681574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22891', '1079', '1', 'Toboso', 'PH.H3.1681657', 'ASCII:Toboso;ID:1681657', '21014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21014', '112', '22891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1681657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22892', '1079', '1', 'Tiwi', 'PH.05.1681680', 'ASCII:Tiwi;ID:1681680', '21015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21015', '112', '22892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1681680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22893', '1079', '1', 'Titay', 'PH.66.1681690', 'ASCII:Titay;ID:1681690', '21016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21016', '112', '22893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1681690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22894', '1079', '1', 'Tipo-Tipo', 'PH.22.1681716', 'ASCII:Tipo-Tipo;ID:1681716', '21017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21017', '112', '22894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.22.1681716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22895', '1079', '1', 'Tingloy', 'PH.09.1681844', 'ASCII:Tingloy;ID:1681844', '21018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21018', '112', '22895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1681844» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22896', '1079', '1', 'Tinglayan', 'PH.32.1681847', 'ASCII:Tinglayan;ID:1681847', '21019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21019', '112', '22896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1681847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22897', '1079', '1', 'Tineg', 'PH.01.1681868', 'ASCII:Tineg;ID:1681868', '21020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21020', '112', '22897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1681868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22898', '1079', '1', 'Tinambac', 'PH.16.1681937', 'ASCII:Tinambac;ID:1681937', '21021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21021', '112', '22898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1681937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22899', '1079', '1', 'Tigbauan', 'PH.30.1682252', 'ASCII:Tigbauan;ID:1682252', '21022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21022', '112', '22899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1682252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22900', '1079', '1', 'Tigaon', 'PH.16.1682302', 'ASCII:Tigaon;ID:1682302', '21023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21023', '112', '22900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1682302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22901', '1079', '1', 'Tibiao', 'PH.06.1682408', 'ASCII:Tibiao;ID:1682408', '21024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21024', '112', '22901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1682408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22902', '1079', '1', 'Tiaong', 'PH.H2.1682443', 'ASCII:Tiaong;ID:1682443', '21025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21025', '112', '22902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1682443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22903', '1079', '1', 'Ternate', 'PH.20.1682474', 'ASCII:Ternate;ID:1682474', '21026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21026', '112', '22903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1682474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22904', '1079', '1', 'Teresa', 'PH.53.1682479', 'ASCII:Teresa;ID:1682479', '21027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21027', '112', '22904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1682479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22905', '1079', '1', 'T”boli', 'PH.70.1682561', 'ASCII:T"boli;ID:1682561', '21028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21028', '112', '22905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1682561» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22906', '1079', '1', 'Tayum', 'PH.01.1682571', 'ASCII:Tayum;ID:1682571', '21029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21029', '112', '22906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1682571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22907', '1079', '1', 'Tayug', 'PH.51.1682575', 'ASCII:Tayug;ID:1682575', '21030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21030', '112', '22907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1682575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22908', '1079', '1', 'Taytay', 'PH.53.1682615', 'ASCII:Taytay;ID:1682615', '21031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21031', '112', '22908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1682615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22909', '1079', '1', 'Taytay', 'PH.49.1682616', 'ASCII:Taytay;ID:1682616', '21032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21032', '112', '22909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1682616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22910', '1079', '1', 'Taysan', 'PH.09.1682621', 'ASCII:Taysan;ID:1682621', '21033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21033', '112', '22910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1682621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22911', '1079', '1', 'Tayasan', 'PH.46.1682644', 'ASCII:Tayasan;ID:1682644', '21034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21034', '112', '22911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1682644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22912', '1079', '1', 'Tayabas', 'PH.H2.1682660', 'ASCII:Tayabas;ID:1682660', '21035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21035', '112', '22912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1682660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22913', '1079', '1', 'Tarragona', 'PH.26.1682793', 'ASCII:Tarragona;ID:1682793', '21036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21036', '112', '22913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1682793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22914', '1079', '1', 'Tarlac', 'PH.63.1682813', 'ASCII:Tarlac;ID:1682813', '21037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21037', '112', '22914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1682813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22915', '1079', '1', 'Tarangnan', 'PH.55.1682845', 'ASCII:Tarangnan;ID:1682845', '21038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21038', '112', '22915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1682845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22916', '1079', '1', 'Taraka', 'PH.35.1682855', 'ASCII:Taraka;ID:1682855', '21039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21039', '112', '22916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1682855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22917', '1079', '1', 'Tapul', 'PH.60.1682895', 'ASCII:Tapul;ID:1682895', '21040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21040', '112', '22917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1682895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22918', '1079', '1', 'Tapaz', 'PH.18.1682961', 'ASCII:Tapaz;ID:1682961', '21041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21041', '112', '22918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1682961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22919', '1079', '1', 'Tanza', 'PH.20.1683019', 'ASCII:Tanza;ID:1683019', '21042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21042', '112', '22919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1683019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22920', '1079', '1', 'Tanudan', 'PH.32.1683030', 'ASCII:Tanudan;ID:1683030', '21043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21043', '112', '22920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1683030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22921', '1079', '1', 'Tantangan', 'PH.70.1683038', 'ASCII:Tantangan;ID:1683038', '21044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21044', '112', '22921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1683038» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22922', '1079', '1', 'Tanjay', 'PH.46.1683089', 'ASCII:Tanjay;ID:1683089', '21045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21045', '112', '22922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1683089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22923', '1079', '1', 'Tangcal', 'PH.34.1683197', 'ASCII:Tangcal;ID:1683197', '21046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21046', '112', '22923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1683197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22924', '1079', '1', 'Tangalan', 'PH.04.1683228', 'ASCII:Tangalan;ID:1683228', '21047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21047', '112', '22924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1683228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22925', '1079', '1', 'Tandubas', 'PH.72.1683265', 'ASCII:Tandubas;ID:1683265', '21048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21048', '112', '22925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.72.1683265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22926', '1079', '1', 'Tandag', 'PH.62.1683304', 'ASCII:Tandag;ID:1683304', '21049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21049', '112', '22926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1683304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22927', '1079', '1', 'Tanay', 'PH.53.1683322', 'ASCII:Tanay;ID:1683322', '21050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21050', '112', '22927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1683322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22928', '1079', '1', 'Tanauan', 'PH.09.1683343', 'ASCII:Tanauan;ID:1683343', '21051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21051', '112', '22928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1683343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22929', '1079', '1', 'Tanauan', 'PH.37.1683344', 'ASCII:Tanauan;ID:1683344', '21052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21052', '112', '22929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1683344» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22930', '1079', '1', 'Tampilisan', 'PH.65.1683412', 'ASCII:Tampilisan;ID:1683412', '21053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21053', '112', '22930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1683412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22931', '1079', '1', 'Tamparan', 'PH.35.1683426', 'ASCII:Tamparan;ID:1683426', '21054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21054', '112', '22931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1683426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22932', '1079', '1', 'Tampakan', 'PH.70.1683434', 'ASCII:Tampakan;ID:1683434', '21055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21055', '112', '22932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1683434» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22933', '1079', '1', 'Tambulig', 'PH.66.1683507', 'ASCII:Tambulig;ID:1683507', '21056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21056', '112', '22933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1683507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22934', '1079', '1', 'Talusan', 'PH.66.1683702', 'ASCII:Talusan;ID:1683702', '21057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21057', '112', '22934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1683702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22935', '1079', '1', 'Talisayan', 'PH.43.1683857', 'ASCII:Talisayan;ID:1683857', '21058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21058', '112', '22935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1683857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22936', '1079', '1', 'Talisay', 'PH.15.1683889', 'ASCII:Talisay;ID:1683889', '21059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21059', '112', '22936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1683889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22937', '1079', '1', 'Talisay', 'PH.09.1683890', 'ASCII:Talisay;ID:1683890', '21060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21060', '112', '22937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1683890» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22938', '1079', '1', 'Talisay', 'PH.H3.1683891', 'ASCII:Talisay;ID:1683891', '21061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21061', '112', '22938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1683891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22939', '1079', '1', 'Talisay', 'PH.21.1683892', 'ASCII:Talisay;ID:1683892', '21062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21062', '112', '22939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1683892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22940', '1079', '1', 'Talipaw', 'PH.60.1683901', 'ASCII:Talipaw;ID:1683901', '21063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21063', '112', '22940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1683901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22941', '1079', '1', 'Talibon', 'PH.11.1683963', 'ASCII:Talibon;ID:1683963', '21064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21064', '112', '22941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1683963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22942', '1079', '1', 'Talayan', 'PH.56.1684008', 'ASCII:Talayan;ID:1684008', '21065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21065', '112', '22942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1684008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22943', '1079', '1', 'Talavera', 'PH.47.1684019', 'ASCII:Talavera;ID:1684019', '21066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21066', '112', '22943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1684019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22944', '1079', '1', 'Talalora', 'PH.55.1684078', 'ASCII:Talalora;ID:1684078', '21067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21067', '112', '22944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1684078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22945', '1079', '1', 'Talakag', 'PH.12.1684088', 'ASCII:Talakag;ID:1684088', '21068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21068', '112', '22945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1684088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22946', '1079', '1', 'Talacogon', 'PH.03.1684139', 'ASCII:Talacogon;ID:1684139', '21069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21069', '112', '22946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.1684139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22947', '1079', '1', 'Tagum', 'PH.24.1684270', 'ASCII:Tagum;ID:1684270', '21070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21070', '112', '22947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1684270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22948', '1079', '1', 'Taguig', 'PH.53.1684309', 'ASCII:Taguig;ID:1684309', '21071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21071', '112', '22948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1684309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22949', '1079', '1', 'Tagudin', 'PH.29.1684322', 'ASCII:Tagudin;ID:1684322', '21072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21072', '112', '22949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1684322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22950', '1079', '1', 'Tagoloan', 'PH.43.1684382', 'ASCII:Tagoloan;ID:1684382', '21073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21073', '112', '22950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1684382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22951', '1079', '1', 'Tago', 'PH.62.1684397', 'ASCII:Tago;ID:1684397', '21074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21074', '112', '22951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1684397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22952', '1079', '1', 'Tagkawayan', 'PH.H2.1684424', 'ASCII:Tagkawayan;ID:1684424', '21075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21075', '112', '22952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1684424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22953', '1079', '1', 'Tagbina', 'PH.62.1684492', 'ASCII:Tagbina;ID:1684492', '21076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21076', '112', '22953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1684492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22954', '1079', '1', 'Tagapul-an', 'PH.55.1684584', 'ASCII:Tagapul-an;ID:1684584', '21077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21077', '112', '22954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1684584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22955', '1079', '1', 'Tagana-an', 'PH.61.1684611', 'ASCII:Tagana-an;ID:1684611', '21078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21078', '112', '22955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1684611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22956', '1079', '1', 'Taft', 'PH.23.1684661', 'ASCII:Taft;ID:1684661', '21079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21079', '112', '22956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1684661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22957', '1079', '1', 'Tadian', 'PH.44.1684673', 'ASCII:Tadian;ID:1684673', '21080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21080', '112', '22957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.44.1684673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22958', '1079', '1', 'Tacurong', 'PH.71.1684682', 'ASCII:Tacurong;ID:1684682', '21081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21081', '112', '22958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1684682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22959', '1079', '1', 'Tabuk', 'PH.32.1684806', 'ASCII:Tabuk;ID:1684806', '21082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21082', '112', '22959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1684806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22960', '1079', '1', 'Tabuelan', 'PH.21.1684822', 'ASCII:Tabuelan;ID:1684822', '21083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21083', '112', '22960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1684822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22961', '1079', '1', 'Tabontabon', 'PH.37.1684872', 'ASCII:Tabontabon;ID:1684872', '21084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21084', '112', '22961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1684872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22962', '1079', '1', 'Tabogon', 'PH.21.1684915', 'ASCII:Tabogon;ID:1684915', '21085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21085', '112', '22962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1684915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22963', '1079', '1', 'Tabina', 'PH.66.1684991', 'ASCII:Tabina;ID:1684991', '21086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21086', '112', '22963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1684991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22964', '1079', '1', 'Tabango', 'PH.37.1685072', 'ASCII:Tabango;ID:1685072', '21087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21087', '112', '22964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1685072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22965', '1079', '1', 'Tabaco', 'PH.05.1685118', 'ASCII:Tabaco;ID:1685118', '21088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21088', '112', '22965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1685118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22966', '1079', '1', 'Taal', 'PH.09.1685148', 'ASCII:Taal;ID:1685148', '21089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21089', '112', '22966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1685148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22967', '1079', '1', 'Suyo', 'PH.29.1685164', 'ASCII:Suyo;ID:1685164', '21090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21090', '112', '22967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1685164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22968', '1079', '1', 'Surallah', 'PH.70.1685231', 'ASCII:Surallah;ID:1685231', '21091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21091', '112', '22968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1685231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22969', '1079', '1', 'Sumisip', 'PH.22.1685297', 'ASCII:Sumisip;ID:1685297', '21092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21092', '112', '22969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.22.1685297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22970', '1079', '1', 'Sumilao', 'PH.12.1685303', 'ASCII:Sumilao;ID:1685303', '21093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21093', '112', '22970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1685303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22971', '1079', '1', 'Sultan sa Barongis', 'PH.56.1685374', 'ASCII:Sultan sa Barongis;ID:1685374', '21094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21094', '112', '22971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1685374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22972', '1079', '1', 'Sultan Kudarat', 'PH.56.1685379', 'ASCII:Sultan Kudarat;ID:1685379', '21095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21095', '112', '22972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1685379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22973', '1079', '1', 'Sultan Gumander', 'PH.35.1685382', 'ASCII:Sultan Gumander;ID:1685382', '21096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21096', '112', '22973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1685382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22974', '1079', '1', 'Sulop', 'PH.25.1685392', 'ASCII:Sulop;ID:1685392', '21097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21097', '112', '22974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1685392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22975', '1079', '1', 'Sulat', 'PH.23.1685419', 'ASCII:Sulat;ID:1685419', '21098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21098', '112', '22975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1685419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22976', '1079', '1', 'Sugpon', 'PH.29.1685477', 'ASCII:Sugpon;ID:1685477', '21099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21099', '112', '22976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1685477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22977', '1079', '1', 'Sugbongcogon', 'PH.43.1685507', 'ASCII:Sugbongcogon;ID:1685507', '21100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21100', '112', '22977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1685507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22978', '1079', '1', 'Sudipen', 'PH.36.1685533', 'ASCII:Sudipen;ID:1685533', '21101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21101', '112', '22978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1685533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22979', '1079', '1', 'Subic', 'PH.64.1685580', 'ASCII:Subic;ID:1685580', '21102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21102', '112', '22979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1685580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22980', '1079', '1', 'Sual', 'PH.51.1685635', 'ASCII:Sual;ID:1685635', '21103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21103', '112', '22980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1685635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22981', '1079', '1', 'South Upi', 'PH.56.1685693', 'ASCII:South Upi;ID:1685693', '21104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21104', '112', '22981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1685693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22982', '1079', '1', 'South Ubian', 'PH.72.1685696', 'ASCII:South Ubian;ID:1685696', '21105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21105', '112', '22982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.72.1685696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22983', '1079', '1', 'Sorsogon', 'PH.58.1685759', 'ASCII:Sorsogon;ID:1685759', '21106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21106', '112', '22983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1685759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22984', '1079', '1', 'Solsona', 'PH.28.1685832', 'ASCII:Solsona;ID:1685832', '21107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21107', '112', '22984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1685832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22985', '1079', '1', 'Solano', 'PH.48.1685876', 'ASCII:Solano;ID:1685876', '21108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21108', '112', '22985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1685876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22986', '1079', '1', 'Solana', 'PH.14.1685883', 'ASCII:Solana;ID:1685883', '21109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21109', '112', '22986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1685883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22987', '1079', '1', 'Sogod', 'PH.21.1685927', 'ASCII:Sogod;ID:1685927', '21110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21110', '112', '22987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1685927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22988', '1079', '1', 'Sogod', 'PH.59.1685928', 'ASCII:Sogod;ID:1685928', '21111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21111', '112', '22988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1685928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22989', '1079', '1', 'Socorro', 'PH.41.1685939', 'ASCII:Socorro;ID:1685939', '21112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21112', '112', '22989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1685939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22990', '1079', '1', 'Socorro', 'PH.61.1685940', 'ASCII:Socorro;ID:1685940', '21113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21113', '112', '22990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1685940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22991', '1079', '1', 'Sitangkai', 'PH.72.1686005', 'ASCII:Sitangkai;ID:1686005', '21114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21114', '112', '22991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.72.1686005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22992', '1079', '1', 'Sison', 'PH.51.1686010', 'ASCII:Sison;ID:1686010', '21115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21115', '112', '22992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1686010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22993', '1079', '1', 'Sison', 'PH.61.1686011', 'ASCII:Sison;ID:1686011', '21116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21116', '112', '22993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1686011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22994', '1079', '1', 'Siruma', 'PH.16.1686040', 'ASCII:Siruma;ID:1686040', '21117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21117', '112', '22994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1686040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22995', '1079', '1', 'Siraway', 'PH.65.1686048', 'ASCII:Siraway;ID:1686048', '21118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21118', '112', '22995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1686048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22996', '1079', '1', 'Siquijor', 'PH.69.1686067', 'ASCII:Siquijor;ID:1686067', '21119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21119', '112', '22996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.69.1686067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22997', '1079', '1', 'Sipocot', 'PH.16.1686079', 'ASCII:Sipocot;ID:1686079', '21120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21120', '112', '22997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1686079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22998', '1079', '1', 'Sipalay', 'PH.H3.1686104', 'ASCII:Sipalay;ID:1686104', '21121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21121', '112', '22998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1686104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('22999', '1079', '1', 'Siocon', 'PH.65.1686125', 'ASCII:Siocon;ID:1686125', '21122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21122', '112', '22999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1686125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23000', '1079', '1', 'Siniloan', 'PH.33.1686188', 'ASCII:Siniloan;ID:1686188', '21123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21123', '112', '23000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1686188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23001', '1079', '1', 'Sindañgan', 'PH.65.1686235', 'ASCII:Sindangan;ID:1686235', '21124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21124', '112', '23001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1686235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23002', '1079', '1', 'Sinait', 'PH.29.1686320', 'ASCII:Sinait;ID:1686320', '21125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21125', '112', '23002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1686320» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23003', '1079', '1', 'Sinacaban', 'PH.42.1686336', 'ASCII:Sinacaban;ID:1686336', '21126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21126', '112', '23003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1686336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23004', '1079', '1', 'Simunul', 'PH.72.1686356', 'ASCII:Simunul;ID:1686356', '21127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21127', '112', '23004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.72.1686356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23005', '1079', '1', 'Silvino Lobos', 'PH.67.1686437', 'ASCII:Silvino Lobos;ID:1686437', '21128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21128', '112', '23005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1686437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23006', '1079', '1', 'Silang', 'PH.20.1686549', 'ASCII:Silang;ID:1686549', '21129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21129', '112', '23006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1686549» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23007', '1079', '1', 'Silago', 'PH.59.1686560', 'ASCII:Silago;ID:1686560', '21130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21130', '112', '23007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1686560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23008', '1079', '1', 'Sikatuna', 'PH.11.1686583', 'ASCII:Sikatuna;ID:1686583', '21131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21131', '112', '23008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1686583» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23009', '1079', '1', 'Sigma', 'PH.18.1686616', 'ASCII:Sigma;ID:1686616', '21132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21132', '112', '23009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1686616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23010', '1079', '1', 'Sigay', 'PH.29.1686633', 'ASCII:Sigay;ID:1686633', '21133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21133', '112', '23010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1686633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23011', '1079', '1', 'Sierra-Bullones', 'PH.11.1686653', 'ASCII:Sierra-Bullones;ID:1686653', '21134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21134', '112', '23011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1686653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23012', '1079', '1', 'Sibutad', 'PH.65.1686713', 'ASCII:Sibutad;ID:1686713', '21135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21135', '112', '23012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1686713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23013', '1079', '1', 'Sibulan', 'PH.46.1686733', 'ASCII:Sibulan;ID:1686733', '21136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21136', '112', '23013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1686733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23014', '1079', '1', 'Sibuco', 'PH.65.1686761', 'ASCII:Sibuco;ID:1686761', '21137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21137', '112', '23014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1686761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23015', '1079', '1', 'Sibonga', 'PH.21.1686779', 'ASCII:Sibonga;ID:1686779', '21138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21138', '112', '23015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1686779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23016', '1079', '1', 'Sibalom', 'PH.06.1686820', 'ASCII:Sibalom;ID:1686820', '21139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21139', '112', '23016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1686820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23017', '1079', '1', 'Siayan', 'PH.65.1686859', 'ASCII:Siayan;ID:1686859', '21140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21140', '112', '23017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1686859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23018', '1079', '1', 'Siay', 'PH.66.1686863', 'ASCII:Siay;ID:1686863', '21141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21141', '112', '23018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1686863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23019', '1079', '1', 'Siaton', 'PH.46.1686869', 'ASCII:Siaton;ID:1686869', '21142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21142', '112', '23019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1686869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23020', '1079', '1', 'Siasi', 'PH.60.1686876', 'ASCII:Siasi;ID:1686876', '21143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21143', '112', '23020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1686876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23021', '1079', '1', 'Sexmoan', 'PH.50.1686934', 'ASCII:Sexmoan;ID:1686934', '21144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21144', '112', '23021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1686934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23022', '1079', '1', 'Sevilla', 'PH.11.1686941', 'ASCII:Sevilla;ID:1686941', '21145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21145', '112', '23022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1686941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23023', '1079', '1', 'Sergio Osmeña Sr', 'PH.65.1686955', 'ASCII:Sergio Osmena Sr;ID:1686955', '21146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21146', '112', '23023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1686955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23024', '1079', '1', 'Sebaste', 'PH.06.1687040', 'ASCII:Sebaste;ID:1687040', '21147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21147', '112', '23024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1687040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23025', '1079', '1', 'Sarrat', 'PH.28.1687148', 'ASCII:Sarrat;ID:1687148', '21148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21148', '112', '23025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1687148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23026', '1079', '1', 'Sariaya', 'PH.H2.1687165', 'ASCII:Sariaya;ID:1687165', '21149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21149', '112', '23026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1687165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23027', '1079', '1', 'Sarangani', 'PH.25.1687187', 'ASCII:Sarangani;ID:1687187', '21150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21150', '112', '23027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1687187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23028', '1079', '1', 'Sara', 'PH.30.1687197', 'ASCII:Sara;ID:1687197', '21151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21151', '112', '23028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1687197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23029', '1079', '1', 'Sapi-an', 'PH.18.1687239', 'ASCII:Sapi-an;ID:1687239', '21152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21152', '112', '23029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1687239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23030', '1079', '1', 'Sapa-Sapa', 'PH.72.1687250', 'ASCII:Sapa-Sapa;ID:1687250', '21153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21153', '112', '23030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.72.1687250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23031', '1079', '1', 'Sapang Dalaga', 'PH.42.1687276', 'ASCII:Sapang Dalaga;ID:1687276', '21154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21154', '112', '23031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1687276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23032', '1079', '1', 'Sapad', 'PH.34.1687325', 'ASCII:Sapad;ID:1687325', '21155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21155', '112', '23032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1687325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23033', '1079', '1', 'San Vicente', 'PH.29.1687489', 'ASCII:San Vicente;ID:1687489', '21156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21156', '112', '23033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1687489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23034', '1079', '1', 'San Vicente', 'PH.15.1687490', 'ASCII:San Vicente;ID:1687490', '21157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21157', '112', '23034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1687490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23035', '1079', '1', 'San Vicente', 'PH.67.1687491', 'ASCII:San Vicente;ID:1687491', '21158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21158', '112', '23035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1687491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23036', '1079', '1', 'San Vicente', 'PH.49.1687492', 'ASCII:San Vicente;ID:1687492', '21159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21159', '112', '23036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1687492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23037', '1079', '1', 'San Vicente', 'PH.24.1687493', 'ASCII:San Vicente;ID:1687493', '21160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21160', '112', '23037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1687493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23038', '1079', '1', 'Santo Tomas', 'PH.31.1687544', 'ASCII:Santo Tomas;ID:1687544', '21161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21161', '112', '23038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1687544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23039', '1079', '1', 'Santo Tomas', 'PH.36.1687545', 'ASCII:Santo Tomas;ID:1687545', '21162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21162', '112', '23039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1687545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23040', '1079', '1', 'Santo Tomas', 'PH.51.1687546', 'ASCII:Santo Tomas;ID:1687546', '21163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21163', '112', '23040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1687546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23041', '1079', '1', 'Santo Tomas', 'PH.50.1687547', 'ASCII:Santo Tomas;ID:1687547', '21164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21164', '112', '23041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1687547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23042', '1079', '1', 'Santo Tomas', 'PH.09.1687548', 'ASCII:Santo Tomas;ID:1687548', '21165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21165', '112', '23042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1687548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23043', '1079', '1', 'Santo Tomas', 'PH.24.1687549', 'ASCII:Santo Tomas;ID:1687549', '21166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21166', '112', '23043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1687549» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23044', '1079', '1', 'Santo Niño', 'PH.14.1687675', 'ASCII:Santo Nino;ID:1687675', '21167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21167', '112', '23044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1687675» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23045', '1079', '1', 'Santo Niño', 'PH.55.1687676', 'ASCII:Santo Nino;ID:1687676', '21168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21168', '112', '23045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1687676» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23046', '1079', '1', 'Santo Niño', 'PH.70.1687677', 'ASCII:Santo Nino;ID:1687677', '21169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21169', '112', '23046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1687677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23047', '1079', '1', 'Santol', 'PH.36.1687704', 'ASCII:Santol;ID:1687704', '21170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21170', '112', '23047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1687704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23048', '1079', '1', 'Santo Domingo', 'PH.29.1687747', 'ASCII:Santo Domingo;ID:1687747', '21171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21171', '112', '23048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1687747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23049', '1079', '1', 'Santo Domingo', 'PH.47.1687748', 'ASCII:Santo Domingo;ID:1687748', '21172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21172', '112', '23049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1687748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23050', '1079', '1', 'Santo Domingo', 'PH.05.1687749', 'ASCII:Santo Domingo;ID:1687749', '21173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21173', '112', '23050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1687749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23051', '1079', '1', 'Santiago', 'PH.29.1687835', 'ASCII:Santiago;ID:1687835', '21174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21174', '112', '23051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1687835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23052', '1079', '1', 'Santiago', 'PH.31.1687836', 'ASCII:Santiago;ID:1687836', '21175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21175', '112', '23052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1687836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23053', '1079', '1', 'San Teodoro', 'PH.31.1687839', 'ASCII:San Teodoro;ID:1687839', '21176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21176', '112', '23053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1687839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23054', '1079', '1', 'Santa Teresita', 'PH.14.1687851', 'ASCII:Santa Teresita;ID:1687851', '21177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21177', '112', '23054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1687851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23055', '1079', '1', 'Santa Teresita', 'PH.09.1687852', 'ASCII:Santa Teresita;ID:1687852', '21178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21178', '112', '23055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1687852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23056', '1079', '1', 'Santa Rosa', 'PH.47.1687914', 'ASCII:Santa Rosa;ID:1687914', '21179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21179', '112', '23056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1687914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23057', '1079', '1', 'Santa Rosa', 'PH.33.1687915', 'ASCII:Santa Rosa;ID:1687915', '21180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21180', '112', '23057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1687915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23058', '1079', '1', 'Santa Rita', 'PH.50.1687952', 'ASCII:Santa Rita;ID:1687952', '21181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21181', '112', '23058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1687952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23059', '1079', '1', 'Santa Rita', 'PH.55.1687953', 'ASCII:Santa Rita;ID:1687953', '21182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21182', '112', '23059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1687953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23060', '1079', '1', 'Santa Praxedes', 'PH.14.1687957', 'ASCII:Santa Praxedes;ID:1687957', '21183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21183', '112', '23060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1687957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23061', '1079', '1', 'Santander', 'PH.21.1687966', 'ASCII:Santander;ID:1687966', '21184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21184', '112', '23061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1687966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23062', '1079', '1', 'Santa Monica', 'PH.61.1687995', 'ASCII:Santa Monica;ID:1687995', '21185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21185', '112', '23062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1687995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23063', '1079', '1', 'Santa Maria', 'PH.31.1688059', 'ASCII:Santa Maria;ID:1688059', '21186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21186', '112', '23063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1688059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23064', '1079', '1', 'Santa Maria', 'PH.29.1688060', 'ASCII:Santa Maria;ID:1688060', '21187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21187', '112', '23064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1688060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23065', '1079', '1', 'Santa Maria', 'PH.51.1688061', 'ASCII:Santa Maria;ID:1688061', '21188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21188', '112', '23065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1688061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23066', '1079', '1', 'Santa Maria', 'PH.13.1688062', 'ASCII:Santa Maria;ID:1688062', '21189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21189', '112', '23066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1688062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23067', '1079', '1', 'Santa Maria', 'PH.33.1688063', 'ASCII:Santa Maria;ID:1688063', '21190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21190', '112', '23067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1688063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23068', '1079', '1', 'Santa Marcela', 'PH.32.1688070', 'ASCII:Santa Marcela;ID:1688070', '21191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21191', '112', '23068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1688070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23069', '1079', '1', 'Santa Magdalena', 'PH.58.1688073', 'ASCII:Santa Magdalena;ID:1688073', '21192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21192', '112', '23069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1688073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23070', '1079', '1', 'Santa Lucia', 'PH.29.1688112', 'ASCII:Santa Lucia;ID:1688112', '21193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21193', '112', '23070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1688112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23071', '1079', '1', 'Santa Josefa', 'PH.03.1688120', 'ASCII:Santa Josefa;ID:1688120', '21194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21194', '112', '23071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.1688120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23072', '1079', '1', 'Santa Ignacia', 'PH.63.1688146', 'ASCII:Santa Ignacia;ID:1688146', '21195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21195', '112', '23072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1688146» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23073', '1079', '1', 'Santa Fe', 'PH.48.1688177', 'ASCII:Santa Fe;ID:1688177', '21196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21196', '112', '23073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1688177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23074', '1079', '1', 'Santa Fe', 'PH.54.1688178', 'ASCII:Santa Fe;ID:1688178', '21197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21197', '112', '23074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1688178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23075', '1079', '1', 'Santa Fe', 'PH.37.1688179', 'ASCII:Santa Fe;ID:1688179', '21198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21198', '112', '23075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1688179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23076', '1079', '1', 'Santa Fe', 'PH.21.1688180', 'ASCII:Santa Fe;ID:1688180', '21199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21199', '112', '23076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1688180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23077', '1079', '1', 'Santa Elena', 'PH.15.1688193', 'ASCII:Santa Elena;ID:1688193', '21200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21200', '112', '23077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1688193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23078', '1079', '1', 'Santa Cruz', 'PH.29.1688323', 'ASCII:Santa Cruz;ID:1688323', '21201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21201', '112', '23078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1688323» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23079', '1079', '1', 'Santa Cruz', 'PH.64.1688324', 'ASCII:Santa Cruz;ID:1688324', '21202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21202', '112', '23079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1688324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23080', '1079', '1', 'Santa Cruz', 'PH.33.1688325', 'ASCII:Santa Cruz;ID:1688325', '21203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21203', '112', '23080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1688325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23081', '1079', '1', 'Santa Cruz', 'PH.38.1688326', 'ASCII:Santa Cruz;ID:1688326', '21204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21204', '112', '23081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.38.1688326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23082', '1079', '1', 'Santa Cruz', 'PH.40.1688327', 'ASCII:Santa Cruz;ID:1688327', '21205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21205', '112', '23082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1688327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23083', '1079', '1', 'Santa Cruz', 'PH.25.1688328', 'ASCII:Santa Cruz;ID:1688328', '21206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21206', '112', '23083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1688328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23084', '1079', '1', 'Santa Catalina', 'PH.29.1688364', 'ASCII:Santa Catalina;ID:1688364', '21207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21207', '112', '23084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1688364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23085', '1079', '1', 'Santa Catalina', 'PH.46.1688365', 'ASCII:Santa Catalina;ID:1688365', '21208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21208', '112', '23085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1688365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23086', '1079', '1', 'Santa Barbara', 'PH.51.1688385', 'ASCII:Santa Barbara;ID:1688385', '21209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21209', '112', '23086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1688385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23087', '1079', '1', 'Santa Barbara', 'PH.30.1688386', 'ASCII:Santa Barbara;ID:1688386', '21210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21210', '112', '23087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1688386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23088', '1079', '1', 'Santa Ana', 'PH.14.1688417', 'ASCII:Santa Ana;ID:1688417', '21211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21211', '112', '23088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1688417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23089', '1079', '1', 'Santa Ana', 'PH.50.1688418', 'ASCII:Santa Ana;ID:1688418', '21212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21212', '112', '23089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1688418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23090', '1079', '1', 'Santa', 'PH.29.1688422', 'ASCII:Santa;ID:1688422', '21213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21213', '112', '23090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1688422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23091', '1079', '1', 'San Simon', 'PH.50.1688427', 'ASCII:San Simon;ID:1688427', '21214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21214', '112', '23091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1688427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23092', '1079', '1', 'San Sebastian', 'PH.55.1688443', 'ASCII:San Sebastian;ID:1688443', '21215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21215', '112', '23092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1688443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23093', '1079', '1', 'San Roque', 'PH.67.1688584', 'ASCII:San Roque;ID:1688584', '21216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21216', '112', '23093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1688584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23094', '1079', '1', 'San Ricardo', 'PH.59.1688592', 'ASCII:San Ricardo;ID:1688592', '21217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21217', '112', '23094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1688592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23095', '1079', '1', 'San Remigio', 'PH.21.1688596', 'ASCII:San Remigio;ID:1688596', '21218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21218', '112', '23095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1688596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23096', '1079', '1', 'San Remigio', 'PH.06.1688597', 'ASCII:San Remigio;ID:1688597', '21219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21219', '112', '23096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1688597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23097', '1079', '1', 'San Rafael', 'PH.13.1688684', 'ASCII:San Rafael;ID:1688684', '21220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21220', '112', '23097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1688684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23098', '1079', '1', 'San Rafael', 'PH.30.1688685', 'ASCII:San Rafael;ID:1688685', '21221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21221', '112', '23098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1688685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23099', '1079', '1', 'San Quintin', 'PH.01.1688690', 'ASCII:San Quintin;ID:1688690', '21222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21222', '112', '23099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1688690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23100', '1079', '1', 'San Quintin', 'PH.51.1688691', 'ASCII:San Quintin;ID:1688691', '21223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21223', '112', '23100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1688691» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23101', '1079', '1', 'San Policarpo', 'PH.23.1688698', 'ASCII:San Policarpo;ID:1688698', '21224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21224', '112', '23101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1688698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23102', '1079', '1', 'San Pedro', 'PH.33.1688781', 'ASCII:San Pedro;ID:1688781', '21225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21225', '112', '23102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1688781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23103', '1079', '1', 'San Pascual', 'PH.09.1688802', 'ASCII:San Pascual;ID:1688802', '21226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21226', '112', '23103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1688802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23104', '1079', '1', 'San Pascual', 'PH.39.1688803', 'ASCII:San Pascual;ID:1688803', '21227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21227', '112', '23104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1688803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23105', '1079', '1', 'San Pablo', 'PH.31.1688845', 'ASCII:San Pablo;ID:1688845', '21228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21228', '112', '23105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1688845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23106', '1079', '1', 'Municipality of San Pablo', 'PH.66.1688846', 'ASCII:Municipality of San Pablo;ID:1688846', '21229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21229', '112', '23106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1688846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23107', '1079', '1', 'San Nicolas', 'PH.28.1688905', 'ASCII:San Nicolas;ID:1688905', '21230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21230', '112', '23107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1688905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23108', '1079', '1', 'San Nicolas', 'PH.51.1688906', 'ASCII:San Nicolas;ID:1688906', '21231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21231', '112', '23108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1688906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23109', '1079', '1', 'San Nicolas', 'PH.09.1688907', 'ASCII:San Nicolas;ID:1688907', '21232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21232', '112', '23109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1688907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23110', '1079', '1', 'San Narciso', 'PH.64.1688914', 'ASCII:San Narciso;ID:1688914', '21233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21233', '112', '23110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1688914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23111', '1079', '1', 'San Narciso', 'PH.H2.1688915', 'ASCII:San Narciso;ID:1688915', '21234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21234', '112', '23111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1688915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23112', '1079', '1', 'San Miguel', 'PH.13.1689027', 'ASCII:San Miguel;ID:1689027', '21235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21235', '112', '23112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1689027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23113', '1079', '1', 'San Miguel', 'PH.19.1689028', 'ASCII:San Miguel;ID:1689028', '21236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21236', '112', '23113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1689028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23114', '1079', '1', 'San Miguel', 'PH.37.1689029', 'ASCII:San Miguel;ID:1689029', '21237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21237', '112', '23114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1689029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23115', '1079', '1', 'San Miguel', 'PH.30.1689030', 'ASCII:San Miguel;ID:1689030', '21238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21238', '112', '23115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1689030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23116', '1079', '1', 'San Miguel', 'PH.11.1689031', 'ASCII:San Miguel;ID:1689031', '21239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21239', '112', '23116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1689031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23117', '1079', '1', 'San Miguel', 'PH.62.1689032', 'ASCII:San Miguel;ID:1689032', '21240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21240', '112', '23117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1689032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23118', '1079', '1', 'Municipality of San Miguel', 'PH.66.1689033', 'ASCII:Municipality of San Miguel;ID:1689033', '21241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21241', '112', '23118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1689033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23119', '1079', '1', 'San Mateo', 'PH.31.1689068', 'ASCII:San Mateo;ID:1689068', '21242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21242', '112', '23119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1689068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23120', '1079', '1', 'San Mateo', 'PH.53.1689069', 'ASCII:San Mateo;ID:1689069', '21243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21243', '112', '23120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1689069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23121', '1079', '1', 'San Mariano', 'PH.31.1689088', 'ASCII:San Mariano;ID:1689088', '21244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21244', '112', '23121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1689088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23122', '1079', '1', 'San Mariano', 'PH.24.1689089', 'ASCII:San Mariano;ID:1689089', '21245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21245', '112', '23122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1689089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23123', '1079', '1', 'San Marcelino', 'PH.64.1689101', 'ASCII:San Marcelino;ID:1689101', '21246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21246', '112', '23123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1689101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23124', '1079', '1', 'San Manuel', 'PH.31.1689113', 'ASCII:San Manuel;ID:1689113', '21247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21247', '112', '23124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1689113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23125', '1079', '1', 'San Manuel', 'PH.51.1689114', 'ASCII:San Manuel;ID:1689114', '21248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21248', '112', '23125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1689114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23126', '1079', '1', 'San Manuel', 'PH.63.1689115', 'ASCII:San Manuel;ID:1689115', '21249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21249', '112', '23126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1689115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23127', '1079', '1', 'San Luis', 'PH.G8.1689147', 'ASCII:San Luis;ID:1689147', '21250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21250', '112', '23127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.G8.1689147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23128', '1079', '1', 'San Luis', 'PH.50.1689148', 'ASCII:San Luis;ID:1689148', '21251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21251', '112', '23128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1689148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23129', '1079', '1', 'San Luis', 'PH.09.1689149', 'ASCII:San Luis;ID:1689149', '21252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21252', '112', '23129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1689149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23130', '1079', '1', 'San Leonardo', 'PH.47.1689172', 'ASCII:San Leonardo;ID:1689172', '21253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21253', '112', '23130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1689172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23131', '1079', '1', 'San Julian', 'PH.23.1689195', 'ASCII:San Julian;ID:1689195', '21254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21254', '112', '23131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1689195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23132', '1079', '1', 'San Juan', 'PH.29.1689355', 'ASCII:San Juan;ID:1689355', '21255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21255', '112', '23132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1689355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23133', '1079', '1', 'San Juan', 'PH.01.1689356', 'ASCII:San Juan;ID:1689356', '21256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21256', '112', '23133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1689356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23134', '1079', '1', 'San Juan', 'PH.36.1689357', 'ASCII:San Juan;ID:1689357', '21257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21257', '112', '23134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1689357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23135', '1079', '1', 'San Juan', 'PH.53.1689358', 'ASCII:San Juan;ID:1689358', '21258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21258', '112', '23135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1689358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23136', '1079', '1', 'San Juan', 'PH.09.1689359', 'ASCII:San Juan;ID:1689359', '21259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21259', '112', '23136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1689359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23137', '1079', '1', 'San Juan', 'PH.59.1689360', 'ASCII:San Juan;ID:1689360', '21260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21260', '112', '23137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1689360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23138', '1079', '1', 'San Juan', 'PH.69.1689361', 'ASCII:San Juan;ID:1689361', '21261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21261', '112', '23138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.69.1689361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23139', '1079', '1', 'San Jose del Monte', 'PH.13.1689396', 'ASCII:San Jose del Monte;ID:1689396', '21262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21262', '112', '23139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1689396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23140', '1079', '1', 'San Jose de Buan', 'PH.55.1689400', 'ASCII:San Jose de Buan;ID:1689400', '21263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21263', '112', '23140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1689400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23141', '1079', '1', 'San Jose', 'PH.09.1689571', 'ASCII:San Jose;ID:1689571', '21264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21264', '112', '23141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1689571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23142', '1079', '1', 'San Jose', 'PH.16.1689572', 'ASCII:San Jose;ID:1689572', '21265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21265', '112', '23142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1689572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23143', '1079', '1', 'San Jose', 'PH.67.1689573', 'ASCII:San Jose;ID:1689573', '21266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21266', '112', '23143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1689573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23144', '1079', '1', 'San Jose', 'PH.40.1689574', 'ASCII:San Jose;ID:1689574', '21267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21267', '112', '23144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1689574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23145', '1079', '1', 'San Jose', 'PH.54.1689575', 'ASCII:San Jose;ID:1689575', '21268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21268', '112', '23145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1689575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23146', '1079', '1', 'San Jose', 'PH.F6.1689576', 'ASCII:San Jose;ID:1689576', '21269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21269', '112', '23146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.F6.1689576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23147', '1079', '1', 'San Jose', 'PH.46.1689577', 'ASCII:San Jose;ID:1689577', '21270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21270', '112', '23147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1689577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23148', '1079', '1', 'San Jorge', 'PH.55.1689579', 'ASCII:San Jorge;ID:1689579', '21271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21271', '112', '23148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1689579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23149', '1079', '1', 'San Joaquin', 'PH.30.1689600', 'ASCII:San Joaquin;ID:1689600', '21272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21272', '112', '23149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1689600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23150', '1079', '1', 'San Jacinto', 'PH.51.1689610', 'ASCII:San Jacinto;ID:1689610', '21273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21273', '112', '23150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1689610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23151', '1079', '1', 'San Jacinto', 'PH.39.1689611', 'ASCII:San Jacinto;ID:1689611', '21274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21274', '112', '23151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1689611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23152', '1079', '1', 'San Isidro', 'PH.01.1689814', 'ASCII:San Isidro;ID:1689814', '21275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21275', '112', '23152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1689814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23153', '1079', '1', 'San Isidro', 'PH.31.1689815', 'ASCII:San Isidro;ID:1689815', '21276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21276', '112', '23153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1689815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23154', '1079', '1', 'San Isidro', 'PH.47.1689816', 'ASCII:San Isidro;ID:1689816', '21277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21277', '112', '23154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1689816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23155', '1079', '1', 'San Isidro', 'PH.67.1689817', 'ASCII:San Isidro;ID:1689817', '21278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21278', '112', '23155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1689817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23156', '1079', '1', 'San Isidro', 'PH.37.1689818', 'ASCII:San Isidro;ID:1689818', '21279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21279', '112', '23156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1689818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23157', '1079', '1', 'San Isidro', 'PH.61.1689819', 'ASCII:San Isidro;ID:1689819', '21280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21280', '112', '23157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1689819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23158', '1079', '1', 'San Isidro', 'PH.11.1689820', 'ASCII:San Isidro;ID:1689820', '21281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21281', '112', '23158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1689820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23159', '1079', '1', 'San Isidro', 'PH.26.1689821', 'ASCII:San Isidro;ID:1689821', '21282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21282', '112', '23159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1689821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23160', '1079', '1', 'San Ildefonso', 'PH.29.1689834', 'ASCII:San Ildefonso;ID:1689834', '21283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21283', '112', '23160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1689834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23161', '1079', '1', 'San Ildefonso', 'PH.13.1689835', 'ASCII:San Ildefonso;ID:1689835', '21284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21284', '112', '23161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1689835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23162', '1079', '1', 'San Guillermo', 'PH.31.1689855', 'ASCII:San Guillermo;ID:1689855', '21285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21285', '112', '23162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1689855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23163', '1079', '1', 'San Gabriel', 'PH.36.1689945', 'ASCII:San Gabriel;ID:1689945', '21286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21286', '112', '23163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1689945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23164', '1079', '1', 'San Francisco', 'PH.H2.1690020', 'ASCII:San Francisco;ID:1690020', '21287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21287', '112', '23164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1690020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23165', '1079', '1', 'San Francisco', 'PH.21.1690021', 'ASCII:San Francisco;ID:1690021', '21288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21288', '112', '23165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1690021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23166', '1079', '1', 'San Francisco', 'PH.59.1690022', 'ASCII:San Francisco;ID:1690022', '21289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21289', '112', '23166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1690022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23167', '1079', '1', 'San Francisco', 'PH.61.1690023', 'ASCII:San Francisco;ID:1690023', '21290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21290', '112', '23167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1690023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23168', '1079', '1', 'San Francisco', 'PH.03.1690024', 'ASCII:San Francisco;ID:1690024', '21291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21291', '112', '23168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.1690024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23169', '1079', '1', 'San Fernando', 'PH.36.1690064', 'ASCII:San Fernando;ID:1690064', '21292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21292', '112', '23169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1690064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23170', '1079', '1', 'San Fernando', 'PH.50.1690065', 'ASCII:San Fernando;ID:1690065', '21293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21293', '112', '23170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1690065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23171', '1079', '1', 'San Fernando', 'PH.16.1690066', 'ASCII:San Fernando;ID:1690066', '21294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21294', '112', '23171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1690066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23172', '1079', '1', 'San Fernando', 'PH.39.1690067', 'ASCII:San Fernando;ID:1690067', '21295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21295', '112', '23172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1690067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23173', '1079', '1', 'San Fernando', 'PH.54.1690068', 'ASCII:San Fernando;ID:1690068', '21296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21296', '112', '23173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1690068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23174', '1079', '1', 'San Fernando', 'PH.21.1690069', 'ASCII:San Fernando;ID:1690069', '21297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21297', '112', '23174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1690069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23175', '1079', '1', 'San Fernando', 'PH.12.1690070', 'ASCII:San Fernando;ID:1690070', '21298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21298', '112', '23175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1690070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23176', '1079', '1', 'San Felipe', 'PH.64.1690093', 'ASCII:San Felipe;ID:1690093', '21299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21299', '112', '23176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1690093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23177', '1079', '1', 'San Fabian', 'PH.51.1690096', 'ASCII:San Fabian;ID:1690096', '21300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21300', '112', '23177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1690096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23178', '1079', '1', 'San Esteban', 'PH.29.1690112', 'ASCII:San Esteban;ID:1690112', '21301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21301', '112', '23178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1690112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23179', '1079', '1', 'San Enrique', 'PH.30.1690120', 'ASCII:San Enrique;ID:1690120', '21302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21302', '112', '23179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1690120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23180', '1079', '1', 'San Enrique', 'PH.H3.1690121', 'ASCII:San Enrique;ID:1690121', '21303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21303', '112', '23180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1690121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23181', '1079', '1', 'San Emilio', 'PH.29.1690123', 'ASCII:San Emilio;ID:1690123', '21304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21304', '112', '23181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1690123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23182', '1079', '1', 'San Dionisio', 'PH.30.1690146', 'ASCII:San Dionisio;ID:1690146', '21305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21305', '112', '23182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1690146» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23183', '1079', '1', 'San Clemente', 'PH.63.1690192', 'ASCII:San Clemente;ID:1690192', '21306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21306', '112', '23183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1690192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23184', '1079', '1', 'Sanchez-Mira', 'PH.14.1690195', 'ASCII:Sanchez-Mira;ID:1690195', '21307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21307', '112', '23184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1690195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23185', '1079', '1', 'San Benito', 'PH.61.1690254', 'ASCII:San Benito;ID:1690254', '21308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21308', '112', '23185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1690254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23186', '1079', '1', 'San Antonio', 'PH.47.1690404', 'ASCII:San Antonio;ID:1690404', '21309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21309', '112', '23186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1690404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23187', '1079', '1', 'San Antonio', 'PH.64.1690405', 'ASCII:San Antonio;ID:1690405', '21310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21310', '112', '23187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1690405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23188', '1079', '1', 'San Antonio', 'PH.H2.1690406', 'ASCII:San Antonio;ID:1690406', '21311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21311', '112', '23188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1690406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23189', '1079', '1', 'San Antonio', 'PH.67.1690407', 'ASCII:San Antonio;ID:1690407', '21312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21312', '112', '23189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1690407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23190', '1079', '1', 'San Andres', 'PH.19.1690448', 'ASCII:San Andres;ID:1690448', '21313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21313', '112', '23190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1690448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23191', '1079', '1', 'San Andres', 'PH.H2.1690449', 'ASCII:San Andres;ID:1690449', '21314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21314', '112', '23191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1690449» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23192', '1079', '1', 'San Andres', 'PH.54.1690450', 'ASCII:San Andres;ID:1690450', '21315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21315', '112', '23192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1690450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23193', '1079', '1', 'San Agustin', 'PH.31.1690531', 'ASCII:San Agustin;ID:1690531', '21316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21316', '112', '23193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1690531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23194', '1079', '1', 'San Agustin', 'PH.54.1690532', 'ASCII:San Agustin;ID:1690532', '21317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21317', '112', '23194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1690532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23195', '1079', '1', 'San Agustin', 'PH.62.1690533', 'ASCII:San Agustin;ID:1690533', '21318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21318', '112', '23195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1690533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23196', '1079', '1', 'Sampaloc', 'PH.H2.1690588', 'ASCII:Sampaloc;ID:1690588', '21319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21319', '112', '23196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1690588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23197', '1079', '1', 'Samboan', 'PH.21.1690624', 'ASCII:Samboan;ID:1690624', '21320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21320', '112', '23197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1690624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23198', '1079', '1', 'Samal', 'PH.07.1690667', 'ASCII:Samal;ID:1690667', '21321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21321', '112', '23198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1690667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23199', '1079', '1', 'Samal', 'PH.24.1690668', 'ASCII:Samal;ID:1690668', '21322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21322', '112', '23199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1690668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23200', '1079', '1', 'Municipality of Salvador', 'PH.34.1690685', 'ASCII:Municipality of Salvador;ID:1690685', '21323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21323', '112', '23200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1690685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23201', '1079', '1', 'Salug', 'PH.65.1690775', 'ASCII:Salug;ID:1690775', '21324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21324', '112', '23201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1690775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23202', '1079', '1', 'Sal-Lapadan', 'PH.01.1690848', 'ASCII:Sal-Lapadan;ID:1690848', '21325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21325', '112', '23202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1690848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23203', '1079', '1', 'Salcedo', 'PH.29.1690913', 'ASCII:Salcedo;ID:1690913', '21326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21326', '112', '23203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1690913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23204', '1079', '1', 'Salcedo', 'PH.23.1690914', 'ASCII:Salcedo;ID:1690914', '21327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21327', '112', '23204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1690914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23205', '1079', '1', 'Salay', 'PH.43.1690935', 'ASCII:Salay;ID:1690935', '21328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21328', '112', '23205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1690935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23206', '1079', '1', 'Saint Bernard', 'PH.59.1691046', 'ASCII:Saint Bernard;ID:1691046', '21329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21329', '112', '23206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1691046» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23207', '1079', '1', 'Saguiaran', 'PH.35.1691087', 'ASCII:Saguiaran;ID:1691087', '21330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21330', '112', '23207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1691087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23208', '1079', '1', 'Saguday', 'PH.68.1691092', 'ASCII:Saguday;ID:1691092', '21331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21331', '112', '23208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.68.1691092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23209', '1079', '1', 'Sagnay', 'PH.16.1691124', 'ASCII:Sagnay;ID:1691124', '21332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21332', '112', '23209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1691124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23210', '1079', '1', 'Sagbayan', 'PH.11.1691138', 'ASCII:Sagbayan;ID:1691138', '21333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21333', '112', '23210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1691138» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23211', '1079', '1', 'Sagay', 'PH.H3.1691153', 'ASCII:Sagay;ID:1691153', '21334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21334', '112', '23211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1691153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23212', '1079', '1', 'Sagay', 'PH.17.1691154', 'ASCII:Sagay;ID:1691154', '21335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21335', '112', '23212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.17.1691154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23213', '1079', '1', 'Sagada', 'PH.44.1691185', 'ASCII:Sagada;ID:1691185', '21336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21336', '112', '23213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.44.1691185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23214', '1079', '1', 'Sadanga', 'PH.44.1691211', 'ASCII:Sadanga;ID:1691211', '21337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21337', '112', '23214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.44.1691211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23215', '1079', '1', 'Sabtang', 'PH.08.1691260', 'ASCII:Sabtang;ID:1691260', '21338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21338', '112', '23215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.08.1691260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23216', '1079', '1', 'Sablayan', 'PH.40.1691283', 'ASCII:Sablayan;ID:1691283', '21339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21339', '112', '23216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1691283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23217', '1079', '1', 'Sablan', 'PH.10.1691288', 'ASCII:Sablan;ID:1691288', '21340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21340', '112', '23217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1691288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23218', '1079', '1', 'Sabangan', 'PH.44.1691337', 'ASCII:Sabangan;ID:1691337', '21341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21341', '112', '23218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.44.1691337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23219', '1079', '1', 'Roxas', 'PH.31.1691448', 'ASCII:Roxas;ID:1691448', '21342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21342', '112', '23219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1691448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23220', '1079', '1', 'Roxas', 'PH.41.1691449', 'ASCII:Roxas;ID:1691449', '21343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21343', '112', '23220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1691449» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23221', '1079', '1', 'Roxas', 'PH.49.1691450', 'ASCII:Roxas;ID:1691450', '21344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21344', '112', '23221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1691450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23222', '1079', '1', 'Rosario', 'PH.36.1691502', 'ASCII:Rosario;ID:1691502', '21345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21345', '112', '23222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1691502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23223', '1079', '1', 'Rosario', 'PH.20.1691503', 'ASCII:Rosario;ID:1691503', '21346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21346', '112', '23223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1691503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23224', '1079', '1', 'Rosario', 'PH.09.1691504', 'ASCII:Rosario;ID:1691504', '21347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21347', '112', '23224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1691504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23225', '1079', '1', 'Rosario', 'PH.67.1691505', 'ASCII:Rosario;ID:1691505', '21348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21348', '112', '23225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1691505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23226', '1079', '1', 'Rosario', 'PH.03.1691506', 'ASCII:Rosario;ID:1691506', '21349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21349', '112', '23226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.1691506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23227', '1079', '1', 'Rosales', 'PH.51.1691511', 'ASCII:Rosales;ID:1691511', '21350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21350', '112', '23227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1691511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23228', '1079', '1', 'Ronda', 'PH.21.1691526', 'ASCII:Ronda;ID:1691526', '21351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21351', '112', '23228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1691526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23229', '1079', '1', 'Romblon', 'PH.54.1691541', 'ASCII:Romblon;ID:1691541', '21352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21352', '112', '23229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1691541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23230', '1079', '1', 'Rizal', 'PH.14.1691680', 'ASCII:Rizal;ID:1691680', '21353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21353', '112', '23230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1691680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23231', '1079', '1', 'Rizal', 'PH.32.1691681', 'ASCII:Rizal;ID:1691681', '21354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21354', '112', '23231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1691681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23232', '1079', '1', 'Rizal', 'PH.47.1691682', 'ASCII:Rizal;ID:1691682', '21355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21355', '112', '23232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1691682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23233', '1079', '1', 'Rizal', 'PH.33.1691683', 'ASCII:Rizal;ID:1691683', '21356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21356', '112', '23233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1691683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23234', '1079', '1', 'Rizal', 'PH.40.1691684', 'ASCII:Rizal;ID:1691684', '21357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21357', '112', '23234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1691684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23235', '1079', '1', 'Municipality of Rizal', 'PH.65.1691685', 'ASCII:Municipality of Rizal;ID:1691685', '21358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21358', '112', '23235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1691685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23236', '1079', '1', 'Reina Mercedes', 'PH.31.1691770', 'ASCII:Reina Mercedes;ID:1691770', '21359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21359', '112', '23236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1691770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23237', '1079', '1', 'Real', 'PH.H2.1691814', 'ASCII:Real;ID:1691814', '21360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21360', '112', '23237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1691814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23238', '1079', '1', 'Rapu-Rapu', 'PH.05.1691863', 'ASCII:Rapu-Rapu;ID:1691863', '21361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21361', '112', '23238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1691863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23239', '1079', '1', 'Ramos', 'PH.63.1691906', 'ASCII:Ramos;ID:1691906', '21362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21362', '112', '23239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1691906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23240', '1079', '1', 'Ramon Magsaysay', 'PH.66.1691910', 'ASCII:Ramon Magsaysay;ID:1691910', '21363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21363', '112', '23240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1691910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23241', '1079', '1', 'Ramon', 'PH.31.1691912', 'ASCII:Ramon;ID:1691912', '21364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21364', '112', '23241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1691912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23242', '1079', '1', 'Ramain', 'PH.35.1691920', 'ASCII:Ramain;ID:1691920', '21365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21365', '112', '23242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1691920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23243', '1079', '1', 'Ragay', 'PH.16.1691942', 'ASCII:Ragay;ID:1691942', '21366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21366', '112', '23243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1691942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23244', '1079', '1', 'Quirino', 'PH.31.1691978', 'ASCII:Quirino;ID:1691978', '21367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21367', '112', '23244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1691978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23245', '1079', '1', 'Quirino', 'PH.29.1691979', 'ASCII:Quirino;ID:1691979', '21368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21368', '112', '23245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1691979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23246', '1079', '1', 'Quinapundan', 'PH.23.1692067', 'ASCII:Quinapundan;ID:1692067', '21369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21369', '112', '23246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1692067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23247', '1079', '1', 'Quezon', 'PH.31.1692216', 'ASCII:Quezon;ID:1692216', '21370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21370', '112', '23247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1692216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23248', '1079', '1', 'Quezon', 'PH.48.1692217', 'ASCII:Quezon;ID:1692217', '21371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21371', '112', '23248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1692217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23249', '1079', '1', 'Quezon', 'PH.47.1692218', 'ASCII:Quezon;ID:1692218', '21372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21372', '112', '23249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1692218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23250', '1079', '1', 'Quezon', 'PH.H2.1692219', 'ASCII:Quezon;ID:1692219', '21373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21373', '112', '23250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1692219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23251', '1079', '1', 'Quezon', 'PH.49.1692220', 'ASCII:Quezon;ID:1692220', '21374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21374', '112', '23251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1692220» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23252', '1079', '1', 'Quezon', 'PH.12.1692221', 'ASCII:Quezon;ID:1692221', '21375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21375', '112', '23252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1692221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23253', '1079', '1', 'Pura', 'PH.63.1692378', 'ASCII:Pura;ID:1692378', '21376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21376', '112', '23253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1692378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23254', '1079', '1', 'Pulupandan', 'PH.H3.1692490', 'ASCII:Pulupandan;ID:1692490', '21377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21377', '112', '23254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1692490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23255', '1079', '1', 'Pulilan', 'PH.13.1692566', 'ASCII:Pulilan;ID:1692566', '21378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21378', '112', '23255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1692566» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23256', '1079', '1', 'Pugo', 'PH.36.1692656', 'ASCII:Pugo;ID:1692656', '21379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21379', '112', '23256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1692656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23257', '1079', '1', 'Puerto Galera', 'PH.41.1692689', 'ASCII:Puerto Galera;ID:1692689', '21380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21380', '112', '23257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1692689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23258', '1079', '1', 'Pudtol', 'PH.32.1692704', 'ASCII:Pudtol;ID:1692704', '21381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21381', '112', '23258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1692704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23259', '1079', '1', 'Pualas', 'PH.35.1692733', 'ASCII:Pualas;ID:1692733', '21382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21382', '112', '23259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1692733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23260', '1079', '1', 'Prosperidad', 'PH.03.1692748', 'ASCII:Prosperidad;ID:1692748', '21383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21383', '112', '23260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.1692748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23261', '1079', '1', 'Prieto Diaz', 'PH.58.1692777', 'ASCII:Prieto Diaz;ID:1692777', '21384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21384', '112', '23261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1692777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23262', '1079', '1', 'President Roxas', 'PH.18.1692782', 'ASCII:President Roxas;ID:1692782', '21385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21385', '112', '23262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1692782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23263', '1079', '1', 'President Roxas', 'PH.57.1692783', 'ASCII:President Roxas;ID:1692783', '21386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21386', '112', '23263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1692783» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23264', '1079', '1', 'President Quirino', 'PH.71.1692785', 'ASCII:President Quirino;ID:1692785', '21387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21387', '112', '23264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1692785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23265', '1079', '1', 'Municipality of President Manuel Acuña Roxas', 'PH.65.1692787', 'ASCII:Municipality of President Manuel Acuna Roxas;ID:1692787', '21388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21388', '112', '23265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1692787» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23266', '1079', '1', 'President Carlos Polestico Garcia', 'PH.11.1692789', 'ASCII:President Carlos Polestico Garcia;ID:1692789', '21389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21389', '112', '23266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1692789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23267', '1079', '1', 'Presentacion', 'PH.16.1692793', 'ASCII:Presentacion;ID:1692793', '21390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21390', '112', '23267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1692793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23268', '1079', '1', 'Pozorrubio', 'PH.51.1692803', 'ASCII:Pozorrubio;ID:1692803', '21391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21391', '112', '23268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1692803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23269', '1079', '1', 'Pototan', 'PH.30.1692818', 'ASCII:Pototan;ID:1692818', '21392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21392', '112', '23269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1692818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23270', '1079', '1', 'Potia', 'PH.27.1692845', 'ASCII:Potia;ID:1692845', '21393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21393', '112', '23270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.27.1692845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23271', '1079', '1', 'Poro', 'PH.21.1692902', 'ASCII:Poro;ID:1692902', '21394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21394', '112', '23271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1692902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23272', '1079', '1', 'Porac', 'PH.50.1692915', 'ASCII:Porac;ID:1692915', '21395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21395', '112', '23272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1692915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23273', '1079', '1', 'Poona-Piagapo', 'PH.34.1692938', 'ASCII:Poona-Piagapo;ID:1692938', '21396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21396', '112', '23273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1692938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23274', '1079', '1', 'Poon-a-Bayabao', 'PH.35.1692940', 'ASCII:Poon-a-Bayabao;ID:1692940', '21397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21397', '112', '23274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1692940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23275', '1079', '1', 'Pontevedra', 'PH.18.1692979', 'ASCII:Pontevedra;ID:1692979', '21398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21398', '112', '23275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1692979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23276', '1079', '1', 'Pontevedra', 'PH.H3.1692980', 'ASCII:Pontevedra;ID:1692980', '21399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21399', '112', '23276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1692980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23277', '1079', '1', 'Ponot', 'PH.65.1692990', 'ASCII:Ponot;ID:1692990', '21400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21400', '112', '23277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1692990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23278', '1079', '1', 'Polomolok', 'PH.70.1693078', 'ASCII:Polomolok;ID:1693078', '21401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21401', '112', '23278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1693078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23279', '1079', '1', 'Polillo', 'PH.H2.1693126', 'ASCII:Polillo;ID:1693126', '21402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21402', '112', '23279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1693126» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23280', '1079', '1', 'Polangui', 'PH.05.1693137', 'ASCII:Polangui;ID:1693137', '21403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21403', '112', '23280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1693137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23281', '1079', '1', 'Polanco', 'PH.65.1693146', 'ASCII:Polanco;ID:1693146', '21404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21404', '112', '23281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1693146» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23282', '1079', '1', 'Pola', 'PH.41.1693158', 'ASCII:Pola;ID:1693158', '21405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21405', '112', '23282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1693158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23283', '1079', '1', 'Plaridel', 'PH.13.1693256', 'ASCII:Plaridel;ID:1693256', '21406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21406', '112', '23283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1693256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23284', '1079', '1', 'Plaridel', 'PH.H2.1693257', 'ASCII:Plaridel;ID:1693257', '21407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21407', '112', '23284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1693257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23285', '1079', '1', 'Municipality of Plaridel', 'PH.42.1693258', 'ASCII:Municipality of Plaridel;ID:1693258', '21408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21408', '112', '23285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1693258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23286', '1079', '1', 'Placer', 'PH.39.1693271', 'ASCII:Placer;ID:1693271', '21409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21409', '112', '23286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1693271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23287', '1079', '1', 'Placer', 'PH.61.1693272', 'ASCII:Placer;ID:1693272', '21410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21410', '112', '23287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1693272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23288', '1079', '1', 'Pitogo', 'PH.H2.1693322', 'ASCII:Pitogo;ID:1693322', '21411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21411', '112', '23288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1693322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23289', '1079', '1', 'Municipality of Pitogo', 'PH.66.1693323', 'ASCII:Municipality of Pitogo;ID:1693323', '21412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21412', '112', '23289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1693323» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23290', '1079', '1', 'Pio V. Corpuz', 'PH.39.1693395', 'ASCII:Pio V. Corpuz;ID:1693395', '21413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21413', '112', '23290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1693395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23291', '1079', '1', 'Pio Duran', 'PH.05.1693397', 'ASCII:Pio Duran;ID:1693397', '21414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21414', '112', '23291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1693397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23292', '1079', '1', 'Pinukpuk', 'PH.32.1693408', 'ASCII:Pinukpuk;ID:1693408', '21415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21415', '112', '23292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1693408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23293', '1079', '1', 'Pintuyan', 'PH.59.1693411', 'ASCII:Pintuyan;ID:1693411', '21416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21416', '112', '23293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1693411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23294', '1079', '1', 'Pinili', 'PH.28.1693470', 'ASCII:Pinili;ID:1693470', '21417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21417', '112', '23294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1693470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23295', '1079', '1', 'Piñan', 'PH.65.1693568', 'ASCII:Pinan;ID:1693568', '21418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21418', '112', '23295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1693568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23296', '1079', '1', 'Pinamungajan', 'PH.21.1693575', 'ASCII:Pinamungajan;ID:1693575', '21419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21419', '112', '23296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1693575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23297', '1079', '1', 'Pinamalayan', 'PH.41.1693620', 'ASCII:Pinamalayan;ID:1693620', '21420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21420', '112', '23297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1693620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23298', '1079', '1', 'Pinabacdao', 'PH.55.1693734', 'ASCII:Pinabacdao;ID:1693734', '21421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21421', '112', '23298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1693734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23299', '1079', '1', 'Pililla', 'PH.53.1693779', 'ASCII:Pililla;ID:1693779', '21422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21422', '112', '23299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1693779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23300', '1079', '1', 'Pili', 'PH.16.1693812', 'ASCII:Pili;ID:1693812', '21423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21423', '112', '23300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1693812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23301', '1079', '1', 'Pilar', 'PH.01.1693851', 'ASCII:Pilar;ID:1693851', '21424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21424', '112', '23301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1693851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23302', '1079', '1', 'Pilar', 'PH.07.1693852', 'ASCII:Pilar;ID:1693852', '21425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21425', '112', '23302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1693852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23303', '1079', '1', 'Pilar', 'PH.58.1693853', 'ASCII:Pilar;ID:1693853', '21426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21426', '112', '23303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1693853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23304', '1079', '1', 'Pilar', 'PH.18.1693854', 'ASCII:Pilar;ID:1693854', '21427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21427', '112', '23304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1693854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23305', '1079', '1', 'Pilar', 'PH.21.1693855', 'ASCII:Pilar;ID:1693855', '21428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21428', '112', '23305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1693855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23306', '1079', '1', 'Pilar', 'PH.61.1693856', 'ASCII:Pilar;ID:1693856', '21429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21429', '112', '23306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1693856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23307', '1079', '1', 'Pilar', 'PH.11.1693857', 'ASCII:Pilar;ID:1693857', '21430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21430', '112', '23307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1693857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23308', '1079', '1', 'Pila', 'PH.33.1693873', 'ASCII:Pila;ID:1693873', '21431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21431', '112', '23308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1693873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23309', '1079', '1', 'Pikit', 'PH.57.1693875', 'ASCII:Pikit;ID:1693875', '21432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21432', '112', '23309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1693875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23310', '1079', '1', 'Pigkawayan', 'PH.57.1693904', 'ASCII:Pigkawayan;ID:1693904', '21433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21433', '112', '23310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1693904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23311', '1079', '1', 'Pidigan', 'PH.01.1693936', 'ASCII:Pidigan;ID:1693936', '21434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21434', '112', '23311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1693936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23312', '1079', '1', 'Piddig', 'PH.28.1693942', 'ASCII:Piddig;ID:1693942', '21435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21435', '112', '23312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1693942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23313', '1079', '1', 'Piat', 'PH.14.1693971', 'ASCII:Piat;ID:1693971', '21436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21436', '112', '23313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1693971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23314', '1079', '1', 'Perez', 'PH.H2.1694047', 'ASCII:Perez;ID:1694047', '21437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21437', '112', '23314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1694047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23315', '1079', '1', 'Peñarrubia', 'PH.01.1694073', 'ASCII:Penarrubia;ID:1694073', '21438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21438', '112', '23315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1694073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23316', '1079', '1', 'Peñaranda', 'PH.47.1694076', 'ASCII:Penaranda;ID:1694076', '21439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21439', '112', '23316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1694076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23317', '1079', '1', 'Peñablanca', 'PH.14.1694090', 'ASCII:Penablanca;ID:1694090', '21440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21440', '112', '23317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1694090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23318', '1079', '1', 'Payao', 'PH.66.1694211', 'ASCII:Payao;ID:1694211', '21441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21441', '112', '23318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1694211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23319', '1079', '1', 'Pavia', 'PH.30.1694263', 'ASCII:Pavia;ID:1694263', '21442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21442', '112', '23319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1694263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23320', '1079', '1', 'Patnoñgon', 'PH.06.1694366', 'ASCII:Patnongon;ID:1694366', '21443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21443', '112', '23320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1694366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23321', '1079', '1', 'Patnanungan', 'PH.H2.1694370', 'ASCII:Patnanungan;ID:1694370', '21444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21444', '112', '23321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1694370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23322', '1079', '1', 'Patikul', 'PH.60.1694388', 'ASCII:Patikul;ID:1694388', '21445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21445', '112', '23322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1694388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23323', '1079', '1', 'Pateros', 'PH.53.1694404', 'ASCII:Pateros;ID:1694404', '21446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21446', '112', '23323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1694404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23324', '1079', '1', 'Pata', 'PH.60.1694480', 'ASCII:Pata;ID:1694480', '21447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21447', '112', '23324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1694480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23325', '1079', '1', 'Pasuquin', 'PH.28.1694485', 'ASCII:Pasuquin;ID:1694485', '21448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21448', '112', '23325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1694485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23326', '1079', '1', 'Pastrana', 'PH.37.1694492', 'ASCII:Pastrana;ID:1694492', '21449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21449', '112', '23326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1694492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23327', '1079', '1', 'Passi', 'PH.30.1694500', 'ASCII:Passi;ID:1694500', '21450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21450', '112', '23327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1694500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23328', '1079', '1', 'Pasil', 'PH.32.1694563', 'ASCII:Pasil;ID:1694563', '21451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21451', '112', '23328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1694563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23329', '1079', '1', 'Pasig', 'PH.53.1694584', 'ASCII:Pasig;ID:1694584', '21452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21452', '112', '23329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1694584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23330', '1079', '1', 'Pasacao', 'PH.16.1694632', 'ASCII:Pasacao;ID:1694632', '21453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21453', '112', '23330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1694632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23331', '1079', '1', 'Parang', 'PH.56.1694777', 'ASCII:Parang;ID:1694777', '21454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21454', '112', '23331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1694777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23332', '1079', '1', 'Municipality of Parang', 'PH.60.1694778', 'ASCII:Municipality of Parang;ID:1694778', '21455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21455', '112', '23332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1694778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23333', '1079', '1', 'Parañaque', 'PH.30.1694782', 'ASCII:Paranaque;ID:1694782', '21456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21456', '112', '23333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1694782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23334', '1079', '1', 'Paracelis', 'PH.44.1694808', 'ASCII:Paracelis;ID:1694808', '21457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21457', '112', '23334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.44.1694808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23335', '1079', '1', 'Paracale', 'PH.15.1694813', 'ASCII:Paracale;ID:1694813', '21458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21458', '112', '23335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1694813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23336', '1079', '1', 'Paombong', 'PH.13.1694862', 'ASCII:Paombong;ID:1694862', '21459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21459', '112', '23336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1694862» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23337', '1079', '1', 'Paoay', 'PH.28.1694872', 'ASCII:Paoay;ID:1694872', '21460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21460', '112', '23337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1694872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23338', '1079', '1', 'Panukulan', 'PH.H2.1694896', 'ASCII:Panukulan;ID:1694896', '21461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21461', '112', '23338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1694896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23339', '1079', '1', 'Pantukan', 'PH.24.1694911', 'ASCII:Pantukan;ID:1694911', '21462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21462', '112', '23339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1694911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23340', '1079', '1', 'Pantar', 'PH.34.1694954', 'ASCII:Pantar;ID:1694954', '21463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21463', '112', '23340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1694954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23341', '1079', '1', 'Pantao-Ragat', 'PH.34.1694957', 'ASCII:Pantao-Ragat;ID:1694957', '21464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21464', '112', '23341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1694957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23342', '1079', '1', 'Pantabangan', 'PH.47.1694989', 'ASCII:Pantabangan;ID:1694989', '21465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21465', '112', '23342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1694989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23343', '1079', '1', 'Panitan', 'PH.18.1695084', 'ASCII:Panitan;ID:1695084', '21466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21466', '112', '23343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1695084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23344', '1079', '1', 'Paniqui', 'PH.63.1695103', 'ASCII:Paniqui;ID:1695103', '21467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21467', '112', '23344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1695103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23345', '1079', '1', 'Pangutaran', 'PH.60.1695181', 'ASCII:Pangutaran;ID:1695181', '21468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21468', '112', '23345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1695181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23346', '1079', '1', 'Panglao', 'PH.11.1695263', 'ASCII:Panglao;ID:1695263', '21469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21469', '112', '23346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1695263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23347', '1079', '1', 'Pangil', 'PH.33.1695286', 'ASCII:Pangil;ID:1695286', '21470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21470', '112', '23347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1695286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23348', '1079', '1', 'Pangantocan', 'PH.12.1695392', 'ASCII:Pangantocan;ID:1695392', '21471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21471', '112', '23348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1695392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23349', '1079', '1', 'Panganiban', 'PH.19.1695401', 'ASCII:Panganiban;ID:1695401', '21472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21472', '112', '23349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1695401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23350', '1079', '1', 'Pandi', 'PH.13.1695463', 'ASCII:Pandi;ID:1695463', '21473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21473', '112', '23350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1695463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23351', '1079', '1', 'Pandan', 'PH.19.1695569', 'ASCII:Pandan;ID:1695569', '21474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21474', '112', '23351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1695569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23352', '1079', '1', 'Pandan', 'PH.06.1695570', 'ASCII:Pandan;ID:1695570', '21475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21475', '112', '23352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1695570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23353', '1079', '1', 'Panay', 'PH.18.1695624', 'ASCII:Panay;ID:1695624', '21476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21476', '112', '23353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1695624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23354', '1079', '1', 'Panaon', 'PH.42.1695668', 'ASCII:Panaon;ID:1695668', '21477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21477', '112', '23354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1695668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23355', '1079', '1', 'Pananaw', 'PH.60.1695694', 'ASCII:Pananaw;ID:1695694', '21478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21478', '112', '23355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1695694» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23356', '1079', '1', 'Panabo', 'PH.24.1695805', 'ASCII:Panabo;ID:1695805', '21479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21479', '112', '23356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1695805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23357', '1079', '1', 'Pamplona', 'PH.14.1695836', 'ASCII:Pamplona;ID:1695836', '21480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21480', '112', '23357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1695836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23358', '1079', '1', 'Pamplona', 'PH.16.1695837', 'ASCII:Pamplona;ID:1695837', '21481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21481', '112', '23358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1695837» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23359', '1079', '1', 'Pamplona', 'PH.46.1695838', 'ASCII:Pamplona;ID:1695838', '21482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21482', '112', '23359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1695838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23360', '1079', '1', 'Pambujan', 'PH.67.1695888', 'ASCII:Pambujan;ID:1695888', '21483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21483', '112', '23360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1695888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23361', '1079', '1', 'Paluan', 'PH.40.1695983', 'ASCII:Paluan;ID:1695983', '21484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21484', '112', '23361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1695983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23362', '1079', '1', 'Palompon', 'PH.37.1696018', 'ASCII:Palompon;ID:1696018', '21485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21485', '112', '23362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1696018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23363', '1079', '1', 'Palo', 'PH.37.1696043', 'ASCII:Palo;ID:1696043', '21486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21486', '112', '23363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1696043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23364', '1079', '1', 'Palimbang', 'PH.71.1696106', 'ASCII:Palimbang;ID:1696106', '21487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21487', '112', '23364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1696106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23365', '1079', '1', 'Palauig', 'PH.64.1696190', 'ASCII:Palauig;ID:1696190', '21488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21488', '112', '23365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1696190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23366', '1079', '1', 'Palapag', 'PH.67.1696236', 'ASCII:Palapag;ID:1696236', '21489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21489', '112', '23366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1696236» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23367', '1079', '1', 'Palanas', 'PH.39.1696298', 'ASCII:Palanas;ID:1696298', '21490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21490', '112', '23367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1696298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23368', '1079', '1', 'Palanan', 'PH.31.1696307', 'ASCII:Palanan;ID:1696307', '21491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21491', '112', '23368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1696307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23369', '1079', '1', 'Pakil', 'PH.33.1696396', 'ASCII:Pakil;ID:1696396', '21492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21492', '112', '23369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1696396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23370', '1079', '1', 'Pagudpud', 'PH.28.1696484', 'ASCII:Pagudpud;ID:1696484', '21493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21493', '112', '23370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1696484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23371', '1079', '1', 'Pagsanjan', 'PH.33.1696507', 'ASCII:Pagsanjan;ID:1696507', '21494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21494', '112', '23371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1696507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23372', '1079', '1', 'Pagsanghan', 'PH.55.1696514', 'ASCII:Pagsanghan;ID:1696514', '21495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21495', '112', '23372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1696514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23373', '1079', '1', 'Pagbilao', 'PH.H2.1696615', 'ASCII:Pagbilao;ID:1696615', '21496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21496', '112', '23373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1696615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23374', '1079', '1', 'Pagayawan', 'PH.35.1696639', 'ASCII:Pagayawan;ID:1696639', '21497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21497', '112', '23374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1696639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23375', '1079', '1', 'Pagalungan', 'PH.56.1696686', 'ASCII:Pagalungan;ID:1696686', '21498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21498', '112', '23375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1696686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23376', '1079', '1', 'Paete', 'PH.33.1696719', 'ASCII:Paete;ID:1696719', '21499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21499', '112', '23376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1696719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23377', '1079', '1', 'Padre Garcia', 'PH.09.1696743', 'ASCII:Padre Garcia;ID:1696743', '21500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21500', '112', '23377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1696743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23378', '1079', '1', 'Padre Burgos', 'PH.H2.1696747', 'ASCII:Padre Burgos;ID:1696747', '21501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21501', '112', '23378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1696747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23379', '1079', '1', 'Padre Burgos', 'PH.59.1696748', 'ASCII:Padre Burgos;ID:1696748', '21502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21502', '112', '23379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1696748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23380', '1079', '1', 'Padada', 'PH.25.1696782', 'ASCII:Padada;ID:1696782', '21503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21503', '112', '23380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1696782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23381', '1079', '1', 'Oton', 'PH.30.1696943', 'ASCII:Oton;ID:1696943', '21504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21504', '112', '23381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1696943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23382', '1079', '1', 'Oslob', 'PH.21.1696990', 'ASCII:Oslob;ID:1696990', '21505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21505', '112', '23382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1696990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23383', '1079', '1', 'Orion', 'PH.07.1697024', 'ASCII:Orion;ID:1697024', '21506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21506', '112', '23383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1697024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23384', '1079', '1', 'Oras', 'PH.23.1697043', 'ASCII:Oras;ID:1697043', '21507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21507', '112', '23384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1697043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23385', '1079', '1', 'Orani', 'PH.07.1697047', 'ASCII:Orani;ID:1697047', '21508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21508', '112', '23385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1697047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23386', '1079', '1', 'Opol', 'PH.43.1697073', 'ASCII:Opol;ID:1697073', '21509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21509', '112', '23386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1697073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23387', '1079', '1', 'Olutanga', 'PH.66.1697156', 'ASCII:Olutanga;ID:1697156', '21510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21510', '112', '23387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1697156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23388', '1079', '1', 'Odiongan', 'PH.54.1697300', 'ASCII:Odiongan;ID:1697300', '21511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21511', '112', '23388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1697300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23389', '1079', '1', 'Ocampo', 'PH.16.1697333', 'ASCII:Ocampo;ID:1697333', '21512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21512', '112', '23389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1697333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23390', '1079', '1', 'Obando', 'PH.13.1697377', 'ASCII:Obando;ID:1697377', '21513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21513', '112', '23390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1697377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23391', '1079', '1', 'Oas', 'PH.05.1697385', 'ASCII:Oas;ID:1697385', '21514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21514', '112', '23391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1697385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23392', '1079', '1', 'Nunungan', 'PH.34.1697422', 'ASCII:Nunungan;ID:1697422', '21515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21515', '112', '23392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1697422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23393', '1079', '1', 'Numancia', 'PH.04.1697435', 'ASCII:Numancia;ID:1697435', '21516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21516', '112', '23393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1697435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23394', '1079', '1', 'Nueva Valencia', 'PH.30.1697460', 'ASCII:Nueva Valencia;ID:1697460', '21517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21517', '112', '23394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1697460» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23395', '1079', '1', 'Nueva Era', 'PH.28.1697472', 'ASCII:Nueva Era;ID:1697472', '21518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21518', '112', '23395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1697472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23396', '1079', '1', 'Noveleta', 'PH.20.1697487', 'ASCII:Noveleta;ID:1697487', '21519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21519', '112', '23396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1697487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23397', '1079', '1', 'Norzagaray', 'PH.13.1697498', 'ASCII:Norzagaray;ID:1697498', '21520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21520', '112', '23397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1697498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23398', '1079', '1', 'Norala', 'PH.70.1697578', 'ASCII:Norala;ID:1697578', '21521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21521', '112', '23398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1697578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23399', '1079', '1', 'New Washington', 'PH.04.1697735', 'ASCII:New Washington;ID:1697735', '21522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21522', '112', '23399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1697735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23400', '1079', '1', 'New Panamao', 'PH.60.1697755', 'ASCII:New Panamao;ID:1697755', '21523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21523', '112', '23400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1697755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23401', '1079', '1', 'New Lucena', 'PH.30.1697763', 'ASCII:New Lucena;ID:1697763', '21524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21524', '112', '23401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1697763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23402', '1079', '1', 'New Corella', 'PH.24.1697774', 'ASCII:New Corella;ID:1697774', '21525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21525', '112', '23402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1697774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23403', '1079', '1', 'New Bataan', 'PH.24.1697789', 'ASCII:New Bataan;ID:1697789', '21526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21526', '112', '23403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1697789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23404', '1079', '1', 'Navotas', 'PH.53.1697851', 'ASCII:Navotas;ID:1697851', '21527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21527', '112', '23404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1697851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23405', '1079', '1', 'Naval', 'PH.37.1697882', 'ASCII:Naval;ID:1697882', '21528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21528', '112', '23405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1697882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23406', '1079', '1', 'Naujan', 'PH.41.1697912', 'ASCII:Naujan;ID:1697912', '21529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21529', '112', '23406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1697912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23407', '1079', '1', 'Natonin', 'PH.44.1697959', 'ASCII:Natonin;ID:1697959', '21530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21530', '112', '23407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.44.1697959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23408', '1079', '1', 'Natividad', 'PH.51.1697980', 'ASCII:Natividad;ID:1697980', '21531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21531', '112', '23408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1697980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23409', '1079', '1', 'Nasugbu', 'PH.09.1698032', 'ASCII:Nasugbu;ID:1698032', '21532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21532', '112', '23409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1698032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23410', '1079', '1', 'Nasipit', 'PH.02.1698064', 'ASCII:Nasipit;ID:1698064', '21533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21533', '112', '23410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.02.1698064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23411', '1079', '1', 'Narvacan', 'PH.29.1698091', 'ASCII:Narvacan;ID:1698091', '21534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21534', '112', '23411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1698091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23412', '1079', '1', 'Narra', 'PH.49.1698104', 'ASCII:Narra;ID:1698104', '21535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21535', '112', '23412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1698104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23413', '1079', '1', 'Nampicuan', 'PH.47.1698358', 'ASCII:Nampicuan;ID:1698358', '21536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21536', '112', '23413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1698358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23414', '1079', '1', 'Naic', 'PH.20.1698549', 'ASCII:Naic;ID:1698549', '21537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21537', '112', '23414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1698549» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23415', '1079', '1', 'Naguilian', 'PH.31.1698597', 'ASCII:Naguilian;ID:1698597', '21538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21538', '112', '23415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1698597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23416', '1079', '1', 'Naguilian', 'PH.36.1698598', 'ASCII:Naguilian;ID:1698598', '21539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21539', '112', '23416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1698598» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23417', '1079', '1', 'Nagcarlan', 'PH.33.1698741', 'ASCII:Nagcarlan;ID:1698741', '21540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21540', '112', '23417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1698741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23418', '1079', '1', 'Nagbukel', 'PH.29.1698751', 'ASCII:Nagbukel;ID:1698751', '21541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21541', '112', '23418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1698751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23419', '1079', '1', 'Naga', 'PH.21.1698842', 'ASCII:Naga;ID:1698842', '21542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21542', '112', '23419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1698842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23420', '1079', '1', 'Naga', 'PH.66.1698843', 'ASCII:Naga;ID:1698843', '21543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21543', '112', '23420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1698843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23421', '1079', '1', 'Nabunturan', 'PH.24.1698888', 'ASCII:Nabunturan;ID:1698888', '21544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21544', '112', '23421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1698888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23422', '1079', '1', 'Nabua', 'PH.16.1698923', 'ASCII:Nabua;ID:1698923', '21545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21545', '112', '23422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1698923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23423', '1079', '1', 'Nabas', 'PH.04.1698977', 'ASCII:Nabas;ID:1698977', '21546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21546', '112', '23423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1698977» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23424', '1079', '1', 'Naawan', 'PH.43.1699011', 'ASCII:Naawan;ID:1699011', '21547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21547', '112', '23424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1699011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23425', '1079', '1', 'Mutia', 'PH.65.1699030', 'ASCII:Mutia;ID:1699030', '21548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21548', '112', '23425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1699030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23426', '1079', '1', 'Murcia', 'PH.H3.1699061', 'ASCII:Murcia;ID:1699061', '21549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21549', '112', '23426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1699061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23427', '1079', '1', 'Muntinglupa', 'PH.53.1699077', 'ASCII:Muntinglupa;ID:1699077', '21550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21550', '112', '23427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1699077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23428', '1079', '1', 'Muñoz', 'PH.47.1699090', 'ASCII:Munoz;ID:1699090', '21551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21551', '112', '23428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1699090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23429', '1079', '1', 'Munai', 'PH.34.1699101', 'ASCII:Munai;ID:1699101', '21552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21552', '112', '23429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1699101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23430', '1079', '1', 'Mulanay', 'PH.H2.1699135', 'ASCII:Mulanay;ID:1699135', '21553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21553', '112', '23430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1699135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23431', '1079', '1', 'Motiong', 'PH.55.1699181', 'ASCII:Motiong;ID:1699181', '21554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21554', '112', '23431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1699181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23432', '1079', '1', 'Morong', 'PH.07.1699207', 'ASCII:Morong;ID:1699207', '21555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21555', '112', '23432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1699207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23433', '1079', '1', 'Morong', 'PH.53.1699208', 'ASCII:Morong;ID:1699208', '21556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21556', '112', '23433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1699208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23434', '1079', '1', 'Montevista', 'PH.24.1699265', 'ASCII:Montevista;ID:1699265', '21557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21557', '112', '23434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1699265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23435', '1079', '1', 'Montalban', 'PH.53.1699298', 'ASCII:Montalban;ID:1699298', '21558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21558', '112', '23435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1699298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23436', '1079', '1', 'Monreal', 'PH.39.1699311', 'ASCII:Monreal;ID:1699311', '21559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21559', '112', '23436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1699311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23437', '1079', '1', 'Monkayo', 'PH.24.1699324', 'ASCII:Monkayo;ID:1699324', '21560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21560', '112', '23437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1699324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23438', '1079', '1', 'Mondragon', 'PH.67.1699343', 'ASCII:Mondragon;ID:1699343', '21561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21561', '112', '23438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1699343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23439', '1079', '1', 'Moncada', 'PH.63.1699346', 'ASCII:Moncada;ID:1699346', '21562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21562', '112', '23439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1699346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23440', '1079', '1', 'Molundo', 'PH.35.1699364', 'ASCII:Molundo;ID:1699364', '21563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21563', '112', '23440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1699364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23441', '1079', '1', 'Molave', 'PH.66.1699389', 'ASCII:Molave;ID:1699389', '21564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21564', '112', '23441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1699389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23442', '1079', '1', 'Moises Padilla', 'PH.H3.1699419', 'ASCII:Moises Padilla;ID:1699419', '21565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21565', '112', '23442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1699419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23443', '1079', '1', 'Mogpog', 'PH.38.1699429', 'ASCII:Mogpog;ID:1699429', '21566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21566', '112', '23443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.38.1699429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23444', '1079', '1', 'Mobo', 'PH.39.1699451', 'ASCII:Mobo;ID:1699451', '21567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21567', '112', '23444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1699451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23445', '1079', '1', 'Moalboal', 'PH.21.1699455', 'ASCII:Moalboal;ID:1699455', '21568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21568', '112', '23445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1699455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23446', '1079', '1', 'M”lang', 'PH.57.1699462', 'ASCII:M"lang;ID:1699462', '21569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21569', '112', '23446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1699462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23447', '1079', '1', 'Minglanilla', 'PH.21.1699573', 'ASCII:Minglanilla;ID:1699573', '21570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21570', '112', '23447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1699573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23448', '1079', '1', 'Minalin', 'PH.50.1699657', 'ASCII:Minalin;ID:1699657', '21571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21571', '112', '23448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1699657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23449', '1079', '1', 'Minalabac', 'PH.16.1699660', 'ASCII:Minalabac;ID:1699660', '21572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21572', '112', '23449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1699660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23450', '1079', '1', 'Mina', 'PH.30.1699685', 'ASCII:Mina;ID:1699685', '21573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21573', '112', '23450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1699685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23451', '1079', '1', 'Milaon', 'PH.16.1699714', 'ASCII:Milaon;ID:1699714', '21574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21574', '112', '23451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1699714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23452', '1079', '1', 'Milagros', 'PH.39.1699722', 'ASCII:Milagros;ID:1699722', '21575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21575', '112', '23452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1699722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23453', '1079', '1', 'Midsayap', 'PH.57.1699756', 'ASCII:Midsayap;ID:1699756', '21576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21576', '112', '23453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1699756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23454', '1079', '1', 'Midsalip', 'PH.66.1699758', 'ASCII:Midsalip;ID:1699758', '21577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21577', '112', '23454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1699758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23455', '1079', '1', 'Miagao', 'PH.30.1699792', 'ASCII:Miagao;ID:1699792', '21578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21578', '112', '23455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1699792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23456', '1079', '1', 'Meycauayan', 'PH.13.1699803', 'ASCII:Meycauayan;ID:1699803', '21579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21579', '112', '23456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1699803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23457', '1079', '1', 'Mexico', 'PH.50.1699806', 'ASCII:Mexico;ID:1699806', '21580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21580', '112', '23457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1699806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23458', '1079', '1', 'Metropolitan Manila', 'PH.00.1699807', 'ASCII:Metropolitan Manila;ID:1699807', '21581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21581', '112', '23458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.00.1699807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23459', '1079', '1', 'Merida', 'PH.37.1699828', 'ASCII:Merida;ID:1699828', '21582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21582', '112', '23459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1699828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23460', '1079', '1', 'Mercedes', 'PH.15.1699841', 'ASCII:Mercedes;ID:1699841', '21583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21583', '112', '23460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1699841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23461', '1079', '1', 'Mendez-Nuñez', 'PH.20.1699859', 'ASCII:Mendez-Nunez;ID:1699859', '21584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21584', '112', '23461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1699859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23462', '1079', '1', 'Medina', 'PH.43.1699891', 'ASCII:Medina;ID:1699891', '21585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21585', '112', '23462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1699891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23463', '1079', '1', 'Medellin', 'PH.21.1699898', 'ASCII:Medellin;ID:1699898', '21586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21586', '112', '23463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1699898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23464', '1079', '1', 'Mayorga', 'PH.37.1699961', 'ASCII:Mayorga;ID:1699961', '21587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21587', '112', '23464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1699961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23465', '1079', '1', 'Maydolong', 'PH.23.1700014', 'ASCII:Maydolong;ID:1700014', '21588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21588', '112', '23465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1700014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23466', '1079', '1', 'Mayaoyao', 'PH.27.1700063', 'ASCII:Mayaoyao;ID:1700063', '21589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21589', '112', '23466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.27.1700063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23467', '1079', '1', 'Mayantoc', 'PH.63.1700070', 'ASCII:Mayantoc;ID:1700070', '21590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21590', '112', '23467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1700070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23468', '1079', '1', 'Mawab', 'PH.24.1700117', 'ASCII:Mawab;ID:1700117', '21591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21591', '112', '23468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1700117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23469', '1079', '1', 'Mauban', 'PH.H2.1700180', 'ASCII:Mauban;ID:1700180', '21592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21592', '112', '23469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1700180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23470', '1079', '1', 'Matungao', 'PH.34.1700214', 'ASCII:Matungao;ID:1700214', '21593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21593', '112', '23470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1700214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23471', '1079', '1', 'Matuguinao', 'PH.55.1700224', 'ASCII:Matuguinao;ID:1700224', '21594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21594', '112', '23471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1700224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23472', '1079', '1', 'Matnog', 'PH.58.1700272', 'ASCII:Matnog;ID:1700272', '21595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21595', '112', '23472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1700272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23473', '1079', '1', 'Mati', 'PH.26.1700362', 'ASCII:Mati;ID:1700362', '21596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21596', '112', '23473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1700362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23474', '1079', '1', 'Matanog', 'PH.56.1700421', 'ASCII:Matanog;ID:1700421', '21597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21597', '112', '23474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1700421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23475', '1079', '1', 'Matanao', 'PH.25.1700448', 'ASCII:Matanao;ID:1700448', '21598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21598', '112', '23475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1700448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23476', '1079', '1', 'Matalom', 'PH.37.1700477', 'ASCII:Matalom;ID:1700477', '21599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21599', '112', '23476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1700477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23477', '1079', '1', 'Matalam', 'PH.57.1700491', 'ASCII:Matalam;ID:1700491', '21600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21600', '112', '23477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1700491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23478', '1079', '1', 'Matag-ob', 'PH.37.1700511', 'ASCII:Matag-ob;ID:1700511', '21601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21601', '112', '23478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1700511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23479', '1079', '1', 'Mataasnakahoy', 'PH.09.1700568', 'ASCII:Mataasnakahoy;ID:1700568', '21602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21602', '112', '23479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1700568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23480', '1079', '1', 'Maslog', 'PH.23.1700628', 'ASCII:Maslog;ID:1700628', '21603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21603', '112', '23480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1700628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23481', '1079', '1', 'Masiu', 'PH.35.1700639', 'ASCII:Masiu;ID:1700639', '21604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21604', '112', '23481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1700639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23482', '1079', '1', 'Masinloc', 'PH.64.1700667', 'ASCII:Masinloc;ID:1700667', '21605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21605', '112', '23482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1700667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23483', '1079', '1', 'Masbate', 'PH.39.1700715', 'ASCII:Masbate;ID:1700715', '21606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21606', '112', '23483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1700715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23484', '1079', '1', 'Masantol', 'PH.50.1700754', 'ASCII:Masantol;ID:1700754', '21607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21607', '112', '23484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1700754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23485', '1079', '1', 'Marunggas', 'PH.60.1700811', 'ASCII:Marunggas;ID:1700811', '21608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21608', '112', '23485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1700811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23486', '1079', '1', 'Marogong', 'PH.35.1700848', 'ASCII:Marogong;ID:1700848', '21609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21609', '112', '23486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1700848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23487', '1079', '1', 'Mariveles', 'PH.07.1700869', 'ASCII:Mariveles;ID:1700869', '21610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21610', '112', '23487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1700869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23488', '1079', '1', 'Maripipi', 'PH.37.1700888', 'ASCII:Maripipi;ID:1700888', '21611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21611', '112', '23488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1700888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23489', '1079', '1', 'Marilao', 'PH.13.1700919', 'ASCII:Marilao;ID:1700919', '21612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21612', '112', '23489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1700919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23490', '1079', '1', 'Marikina', 'PH.53.1700926', 'ASCII:Marikina;ID:1700926', '21613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21613', '112', '23490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1700926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23491', '1079', '1', 'Marihatag', 'PH.62.1700934', 'ASCII:Marihatag;ID:1700934', '21614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21614', '112', '23491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1700934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23492', '1079', '1', 'Maribojoc', 'PH.11.1700970', 'ASCII:Maribojoc;ID:1700970', '21615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21615', '112', '23492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1700970» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23493', '1079', '1', 'Mariano Marcos', 'PH.71.1700979', 'ASCII:Mariano Marcos;ID:1700979', '21616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21616', '112', '23493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1700979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23494', '1079', '1', 'Maria Aurora', 'PH.G8.1700995', 'ASCII:Maria Aurora;ID:1700995', '21617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21617', '112', '23494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.G8.1700995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23495', '1079', '1', 'Maria', 'PH.69.1701000', 'ASCII:Maria;ID:1701000', '21618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21618', '112', '23495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.69.1701000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23496', '1079', '1', 'Margosatubig', 'PH.66.1701004', 'ASCII:Margosatubig;ID:1701004', '21619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21619', '112', '23496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1701004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23497', '1079', '1', 'Marcos', 'PH.28.1701024', 'ASCII:Marcos;ID:1701024', '21620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21620', '112', '23497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1701024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23498', '1079', '1', 'Marantao', 'PH.35.1701089', 'ASCII:Marantao;ID:1701089', '21621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21621', '112', '23498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1701089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23499', '1079', '1', 'Maramag', 'PH.12.1701125', 'ASCII:Maramag;ID:1701125', '21622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21622', '112', '23499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1701125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23500', '1079', '1', 'Maragondon', 'PH.20.1701150', 'ASCII:Maragondon;ID:1701150', '21623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21623', '112', '23500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1701150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23501', '1079', '1', 'Marabut', 'PH.55.1701172', 'ASCII:Marabut;ID:1701172', '21624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21624', '112', '23501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1701172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23502', '1079', '1', 'Mapandan', 'PH.51.1701292', 'ASCII:Mapandan;ID:1701292', '21625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21625', '112', '23502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1701292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23503', '1079', '1', 'Mapanas', 'PH.67.1701297', 'ASCII:Mapanas;ID:1701297', '21626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21626', '112', '23503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1701297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23504', '1079', '1', 'Manukan', 'PH.65.1701396', 'ASCII:Manukan;ID:1701396', '21627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21627', '112', '23504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1701396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23505', '1079', '1', 'Manticao', 'PH.43.1701442', 'ASCII:Manticao;ID:1701442', '21628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21628', '112', '23505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1701442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23506', '1079', '1', 'Mansalay', 'PH.41.1701517', 'ASCII:Mansalay;ID:1701517', '21629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21629', '112', '23506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1701517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23507', '1079', '1', 'Manolo Fortich', 'PH.12.1701538', 'ASCII:Manolo Fortich;ID:1701538', '21630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21630', '112', '23507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1701538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23508', '1079', '1', 'Mankayan', 'PH.10.1701609', 'ASCII:Mankayan;ID:1701609', '21631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21631', '112', '23508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1701609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23509', '1079', '1', 'Manjuyod', 'PH.46.1701614', 'ASCII:Manjuyod;ID:1701614', '21632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21632', '112', '23509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1701614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23510', '1079', '1', 'Manito', 'PH.05.1701624', 'ASCII:Manito;ID:1701624', '21633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21633', '112', '23510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1701624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23511', '1079', '1', 'Mangatarem', 'PH.51.1701823', 'ASCII:Mangatarem;ID:1701823', '21634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21634', '112', '23511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1701823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23512', '1079', '1', 'Mangaldan', 'PH.51.1701873', 'ASCII:Mangaldan;ID:1701873', '21635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21635', '112', '23512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1701873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23513', '1079', '1', 'Mandaon', 'PH.39.1701955', 'ASCII:Mandaon;ID:1701955', '21636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21636', '112', '23513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1701955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23514', '1079', '1', 'Mandaluyong', 'PH.53.1701968', 'ASCII:Mandaluyong;ID:1701968', '21637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21637', '112', '23514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1701968» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23515', '1079', '1', 'Manay', 'PH.26.1702033', 'ASCII:Manay;ID:1702033', '21638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21638', '112', '23515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1702033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23516', '1079', '1', 'Manapla', 'PH.H3.1702078', 'ASCII:Manapla;ID:1702078', '21639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21639', '112', '23516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1702078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23517', '1079', '1', 'Manaoag', 'PH.51.1702098', 'ASCII:Manaoag;ID:1702098', '21640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21640', '112', '23517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1702098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23518', '1079', '1', 'Manabo', 'PH.01.1702196', 'ASCII:Manabo;ID:1702196', '21641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21641', '112', '23518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1702196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23519', '1079', '1', 'Mambusao', 'PH.18.1702259', 'ASCII:Mambusao;ID:1702259', '21642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21642', '112', '23519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1702259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23520', '1079', '1', 'Mamburao', 'PH.40.1702265', 'ASCII:Mamburao;ID:1702265', '21643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21643', '112', '23520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1702265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23521', '1079', '1', 'Mambajao', 'PH.17.1702349', 'ASCII:Mambajao;ID:1702349', '21644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21644', '112', '23521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.17.1702349» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23522', '1079', '1', 'Malvar', 'PH.09.1702415', 'ASCII:Malvar;ID:1702415', '21645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21645', '112', '23522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1702415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23523', '1079', '1', 'Maluso', 'PH.22.1702426', 'ASCII:Maluso;ID:1702426', '21646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21646', '112', '23523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.22.1702426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23524', '1079', '1', 'Mallig', 'PH.31.1702593', 'ASCII:Mallig;ID:1702593', '21647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21647', '112', '23524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1702593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23525', '1079', '1', 'Malitbog', 'PH.59.1702638', 'ASCII:Malitbog;ID:1702638', '21648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21648', '112', '23525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1702638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23526', '1079', '1', 'Malitbog', 'PH.12.1702639', 'ASCII:Malitbog;ID:1702639', '21649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21649', '112', '23526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1702639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23527', '1079', '1', 'Malita', 'PH.25.1702650', 'ASCII:Malita;ID:1702650', '21650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21650', '112', '23527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1702650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23528', '1079', '1', 'Malinao', 'PH.05.1702745', 'ASCII:Malinao;ID:1702745', '21651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21651', '112', '23528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1702745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23529', '1079', '1', 'Malinao', 'PH.04.1702746', 'ASCII:Malinao;ID:1702746', '21652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21652', '112', '23529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1702746» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23530', '1079', '1', 'Malimono', 'PH.61.1702757', 'ASCII:Malimono;ID:1702757', '21653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21653', '112', '23530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1702757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23531', '1079', '1', 'Malilipot', 'PH.05.1702764', 'ASCII:Malilipot;ID:1702764', '21654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21654', '112', '23531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1702764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23532', '1079', '1', 'Malibcong', 'PH.01.1702830', 'ASCII:Malibcong;ID:1702830', '21655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21655', '112', '23532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1702830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23533', '1079', '1', 'Malay', 'PH.04.1702955', 'ASCII:Malay;ID:1702955', '21656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21656', '112', '23533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1702955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23534', '1079', '1', 'Malasiqui', 'PH.51.1703011', 'ASCII:Malasiqui;ID:1703011', '21657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21657', '112', '23534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1703011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23535', '1079', '1', 'Malapatan', 'PH.70.1703052', 'ASCII:Malapatan;ID:1703052', '21658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21658', '112', '23535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1703052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23536', '1079', '1', 'Malangas', 'PH.66.1703103', 'ASCII:Malangas;ID:1703103', '21659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21659', '112', '23536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1703103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23537', '1079', '1', 'Malalag', 'PH.25.1703190', 'ASCII:Malalag;ID:1703190', '21660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21660', '112', '23537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1703190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23538', '1079', '1', 'Malabuyoc', 'PH.21.1703299', 'ASCII:Malabuyoc;ID:1703299', '21661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21661', '112', '23538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1703299» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23539', '1079', '1', 'Malabon', 'PH.53.1703321', 'ASCII:Malabon;ID:1703321', '21662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21662', '112', '23539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1703321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23540', '1079', '1', 'Malabang', 'PH.35.1703354', 'ASCII:Malabang;ID:1703354', '21663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21663', '112', '23540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1703354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23541', '1079', '1', 'Makilala', 'PH.57.1703406', 'ASCII:Makilala;ID:1703406', '21664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21664', '112', '23541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1703406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23542', '1079', '1', 'Makato', 'PH.04.1703413', 'ASCII:Makato;ID:1703413', '21665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21665', '112', '23542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1703413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23543', '1079', '1', 'Makati', 'PH.53.1703417', 'ASCII:Makati;ID:1703417', '21666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21666', '112', '23543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1703417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23544', '1079', '1', 'Majayjay', 'PH.33.1703451', 'ASCII:Majayjay;ID:1703451', '21667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21667', '112', '23544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1703451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23545', '1079', '1', 'Maitum', 'PH.70.1703472', 'ASCII:Maitum;ID:1703472', '21668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21668', '112', '23545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1703472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23546', '1079', '1', 'Mainit', 'PH.61.1703523', 'ASCII:Mainit;ID:1703523', '21669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21669', '112', '23546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1703523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23547', '1079', '1', 'Maimbung', 'PH.60.1703540', 'ASCII:Maimbung;ID:1703540', '21670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21670', '112', '23547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1703540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23548', '1079', '1', 'Maigo', 'PH.34.1703555', 'ASCII:Maigo;ID:1703555', '21671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21671', '112', '23548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1703555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23549', '1079', '1', 'Mahinog', 'PH.14.1703578', 'ASCII:Mahinog;ID:1703578', '21672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21672', '112', '23549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1703578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23550', '1079', '1', 'Mahayag', 'PH.66.1703600', 'ASCII:Mahayag;ID:1703600', '21673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21673', '112', '23550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1703600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23551', '1079', '1', 'Mahatao', 'PH.08.1703604', 'ASCII:Mahatao;ID:1703604', '21674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21674', '112', '23551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.08.1703604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23552', '1079', '1', 'Mahaplag', 'PH.37.1703609', 'ASCII:Mahaplag;ID:1703609', '21675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21675', '112', '23552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1703609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23553', '1079', '1', 'Maguing', 'PH.35.1703700', 'ASCII:Maguing;ID:1703700', '21676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21676', '112', '23553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1703700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23554', '1079', '1', 'Magsingal', 'PH.29.1703758', 'ASCII:Magsingal;ID:1703758', '21677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21677', '112', '23554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1703758» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23555', '1079', '1', 'Magsaysay', 'PH.31.1703774', 'ASCII:Magsaysay;ID:1703774', '21678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21678', '112', '23555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1703774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23556', '1079', '1', 'Magsaysay', 'PH.40.1703775', 'ASCII:Magsaysay;ID:1703775', '21679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21679', '112', '23556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1703775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23557', '1079', '1', 'Magsaysay', 'PH.49.1703776', 'ASCII:Magsaysay;ID:1703776', '21680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21680', '112', '23557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1703776» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23558', '1079', '1', 'Magsaysay', 'PH.43.1703777', 'ASCII:Magsaysay;ID:1703777', '21681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21681', '112', '23558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1703777» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23559', '1079', '1', 'Municipality of Magsaysay', 'PH.34.1703778', 'ASCII:Municipality of Magsaysay;ID:1703778', '21682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21682', '112', '23559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1703778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23560', '1079', '1', 'Magsaysay', 'PH.25.1703779', 'ASCII:Magsaysay;ID:1703779', '21683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21683', '112', '23560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1703779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23561', '1079', '1', 'Magpet', 'PH.57.1703793', 'ASCII:Magpet;ID:1703793', '21684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21684', '112', '23561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1703793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23562', '1079', '1', 'Magdiwang', 'PH.54.1703897', 'ASCII:Magdiwang;ID:1703897', '21685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21685', '112', '23562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1703897» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23563', '1079', '1', 'Magdalena', 'PH.33.1703917', 'ASCII:Magdalena;ID:1703917', '21686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21686', '112', '23563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1703917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23564', '1079', '1', 'Magarao', 'PH.16.1704003', 'ASCII:Magarao;ID:1704003', '21687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21687', '112', '23564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1704003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23565', '1079', '1', 'Maganoy', 'PH.56.1704022', 'ASCII:Maganoy;ID:1704022', '21688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21688', '112', '23565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1704022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23566', '1079', '1', 'Magallanes', 'PH.20.1704060', 'ASCII:Magallanes;ID:1704060', '21689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21689', '112', '23566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1704060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23567', '1079', '1', 'Magallanes', 'PH.58.1704061', 'ASCII:Magallanes;ID:1704061', '21690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21690', '112', '23567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1704061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23568', '1079', '1', 'Magallanes', 'PH.02.1704062', 'ASCII:Magallanes;ID:1704062', '21691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21691', '112', '23568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.02.1704062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23569', '1079', '1', 'Magalang', 'PH.50.1704068', 'ASCII:Magalang;ID:1704068', '21692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21692', '112', '23569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1704068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23570', '1079', '1', 'Madridejos', 'PH.21.1704128', 'ASCII:Madridejos;ID:1704128', '21693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21693', '112', '23570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1704128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23571', '1079', '1', 'Madrid', 'PH.62.1704130', 'ASCII:Madrid;ID:1704130', '21694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21694', '112', '23571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1704130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23572', '1079', '1', 'Maddela', 'PH.68.1704155', 'ASCII:Maddela;ID:1704155', '21695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21695', '112', '23572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.68.1704155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23573', '1079', '1', 'Madamba', 'PH.35.1704197', 'ASCII:Madamba;ID:1704197', '21696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21696', '112', '23573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1704197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23574', '1079', '1', 'Madalum', 'PH.35.1704202', 'ASCII:Madalum;ID:1704202', '21697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21697', '112', '23574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1704202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23575', '1079', '1', 'Madalag', 'PH.04.1704218', 'ASCII:Madalag;ID:1704218', '21698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21698', '112', '23575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1704218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23576', '1079', '1', 'Macrohon', 'PH.59.1704253', 'ASCII:Macrohon;ID:1704253', '21699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21699', '112', '23576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1704253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23577', '1079', '1', 'Maconacon', 'PH.31.1704266', 'ASCII:Maconacon;ID:1704266', '21700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21700', '112', '23577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1704266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23578', '1079', '1', 'Maco', 'PH.24.1704272', 'ASCII:Maco;ID:1704272', '21701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21701', '112', '23578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1704272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23579', '1079', '1', 'MacArthur', 'PH.37.1704334', 'ASCII:MacArthur;ID:1704334', '21702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21702', '112', '23579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1704334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23580', '1079', '1', 'Macalelon', 'PH.H2.1704395', 'ASCII:Macalelon;ID:1704395', '21703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21703', '112', '23580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1704395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23581', '1079', '1', 'Macabebe', 'PH.50.1704450', 'ASCII:Macabebe;ID:1704450', '21704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21704', '112', '23581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1704450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23582', '1079', '1', 'Mabuhay', 'PH.66.1704505', 'ASCII:Mabuhay;ID:1704505', '21705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21705', '112', '23582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1704505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23583', '1079', '1', 'Mabitac', 'PH.33.1704538', 'ASCII:Mabitac;ID:1704538', '21706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21706', '112', '23583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1704538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23584', '1079', '1', 'Mabini', 'PH.51.1704599', 'ASCII:Mabini;ID:1704599', '21707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21707', '112', '23584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1704599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23585', '1079', '1', 'Mabini', 'PH.09.1704600', 'ASCII:Mabini;ID:1704600', '21708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21708', '112', '23585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1704600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23586', '1079', '1', 'Mabini', 'PH.11.1704601', 'ASCII:Mabini;ID:1704601', '21709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21709', '112', '23586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1704601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23587', '1079', '1', 'Mabini', 'PH.24.1704602', 'ASCII:Mabini;ID:1704602', '21710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21710', '112', '23587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1704602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23588', '1079', '1', 'Mabinay', 'PH.46.1704607', 'ASCII:Mabinay;ID:1704607', '21711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21711', '112', '23588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1704607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23589', '1079', '1', 'Mabalacat', 'PH.50.1704704', 'ASCII:Mabalacat;ID:1704704', '21712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21712', '112', '23589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1704704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23590', '1079', '1', 'Ma-ayon', 'PH.18.1704731', 'ASCII:Ma-ayon;ID:1704731', '21713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21713', '112', '23590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1704731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23591', '1079', '1', 'Maasin', 'PH.30.1704763', 'ASCII:Maasin;ID:1704763', '21714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21714', '112', '23591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1704763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23592', '1079', '1', 'Maasin', 'PH.59.1704764', 'ASCII:Maasin;ID:1704764', '21715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21715', '112', '23592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1704764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23593', '1079', '1', 'Maasim', 'PH.70.1704773', 'ASCII:Maasim;ID:1704773', '21716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21716', '112', '23593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1704773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23594', '1079', '1', 'Luuk', 'PH.60.1704882', 'ASCII:Luuk;ID:1704882', '21717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21717', '112', '23594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1704882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23595', '1079', '1', 'Lutayan', 'PH.71.1704898', 'ASCII:Lutayan;ID:1704898', '21718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21718', '112', '23595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1704898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23596', '1079', '1', 'Lupon', 'PH.26.1704969', 'ASCII:Lupon;ID:1704969', '21719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21719', '112', '23596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1704969» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23597', '1079', '1', 'Lupi', 'PH.16.1704987', 'ASCII:Lupi;ID:1704987', '21720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21720', '112', '23597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1704987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23598', '1079', '1', 'Lupao', 'PH.47.1704995', 'ASCII:Lupao;ID:1704995', '21721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21721', '112', '23598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1704995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23599', '1079', '1', 'Luna', 'PH.32.1705113', 'ASCII:Luna;ID:1705113', '21722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21722', '112', '23599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1705113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23600', '1079', '1', 'Luna', 'PH.31.1705114', 'ASCII:Luna;ID:1705114', '21723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21723', '112', '23600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1705114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23601', '1079', '1', 'Luna', 'PH.36.1705115', 'ASCII:Luna;ID:1705115', '21724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21724', '112', '23601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1705115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23602', '1079', '1', 'Lumbayanague', 'PH.35.1705172', 'ASCII:Lumbayanague;ID:1705172', '21725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21725', '112', '23602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1705172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23603', '1079', '1', 'Lumbatan', 'PH.35.1705179', 'ASCII:Lumbatan;ID:1705179', '21726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21726', '112', '23603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1705179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23604', '1079', '1', 'Lumban', 'PH.33.1705192', 'ASCII:Lumban;ID:1705192', '21727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21727', '112', '23604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1705192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23605', '1079', '1', 'Lumba-a-Bayabao', 'PH.35.1705208', 'ASCII:Lumba-a-Bayabao;ID:1705208', '21728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21728', '112', '23605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1705208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23606', '1079', '1', 'Luisiana', 'PH.33.1705291', 'ASCII:Luisiana;ID:1705291', '21729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21729', '112', '23606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1705291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23607', '1079', '1', 'Lugait', 'PH.43.1705331', 'ASCII:Lugait;ID:1705331', '21730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21730', '112', '23607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1705331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23608', '1079', '1', 'Lucban', 'PH.H2.1705370', 'ASCII:Lucban;ID:1705370', '21731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21731', '112', '23608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1705370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23609', '1079', '1', 'Lubuagan', 'PH.32.1705392', 'ASCII:Lubuagan;ID:1705392', '21732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21732', '112', '23609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1705392» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23610', '1079', '1', 'Lubao', 'PH.50.1705441', 'ASCII:Lubao;ID:1705441', '21733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21733', '112', '23610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1705441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23611', '1079', '1', 'Lubang', 'PH.40.1705454', 'ASCII:Lubang;ID:1705454', '21734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21734', '112', '23611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1705454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23612', '1079', '1', 'Luba', 'PH.01.1705462', 'ASCII:Luba;ID:1705462', '21735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21735', '112', '23612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1705462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23613', '1079', '1', 'Los Baños', 'PH.33.1705539', 'ASCII:Los Banos;ID:1705539', '21736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21736', '112', '23613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1705539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23614', '1079', '1', 'Loreto', 'PH.61.1705553', 'ASCII:Loreto;ID:1705553', '21737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21737', '112', '23614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1705553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23615', '1079', '1', 'Lopez Jaena', 'PH.42.1705569', 'ASCII:Lopez Jaena;ID:1705569', '21738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21738', '112', '23615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1705569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23616', '1079', '1', 'Lopez', 'PH.H2.1705574', 'ASCII:Lopez;ID:1705574', '21739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21739', '112', '23616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1705574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23617', '1079', '1', 'Loon', 'PH.11.1705582', 'ASCII:Loon;ID:1705582', '21740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21740', '112', '23617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1705582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23618', '1079', '1', 'Looc', 'PH.40.1705667', 'ASCII:Looc;ID:1705667', '21741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21741', '112', '23618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1705667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23619', '1079', '1', 'Looc', 'PH.54.1705668', 'ASCII:Looc;ID:1705668', '21742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21742', '112', '23619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1705668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23620', '1079', '1', 'Loboc', 'PH.11.1705873', 'ASCII:Loboc;ID:1705873', '21743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21743', '112', '23620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1705873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23621', '1079', '1', 'Lobo', 'PH.09.1705884', 'ASCII:Lobo;ID:1705884', '21744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21744', '112', '23621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1705884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23622', '1079', '1', 'Loay', 'PH.11.1705898', 'ASCII:Loay;ID:1705898', '21745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21745', '112', '23622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1705898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23623', '1079', '1', 'Llorente', 'PH.23.1705911', 'ASCII:Llorente;ID:1705911', '21746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21746', '112', '23623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1705911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23624', '1079', '1', 'Llanera', 'PH.47.1705923', 'ASCII:Llanera;ID:1705923', '21747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21747', '112', '23624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1705923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23625', '1079', '1', 'Lingig', 'PH.62.1706177', 'ASCII:Lingig;ID:1706177', '21748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21748', '112', '23625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1706177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23626', '1079', '1', 'Lingayen', 'PH.51.1706191', 'ASCII:Lingayen;ID:1706191', '21749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21749', '112', '23626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1706191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23627', '1079', '1', 'Linapacan', 'PH.49.1706243', 'ASCII:Linapacan;ID:1706243', '21750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21750', '112', '23627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1706243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23628', '1079', '1', 'Linamon', 'PH.34.1706288', 'ASCII:Linamon;ID:1706288', '21751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21751', '112', '23628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1706288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23629', '1079', '1', 'Limay', 'PH.07.1706362', 'ASCII:Limay;ID:1706362', '21752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21752', '112', '23629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1706362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23630', '1079', '1', 'Liloy', 'PH.65.1706385', 'ASCII:Liloy;ID:1706385', '21753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21753', '112', '23630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1706385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23631', '1079', '1', 'Liloan', 'PH.21.1706400', 'ASCII:Liloan;ID:1706400', '21754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21754', '112', '23631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1706400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23632', '1079', '1', 'Liloan', 'PH.53.1706401', 'ASCII:Liloan;ID:1706401', '21755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21755', '112', '23632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1706401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23633', '1079', '1', 'Liliw', 'PH.33.1706403', 'ASCII:Liliw;ID:1706403', '21756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21756', '112', '23633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1706403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23634', '1079', '1', 'Lila', 'PH.11.1706423', 'ASCII:Lila;ID:1706423', '21757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21757', '112', '23634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1706423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23635', '1079', '1', 'Ligao', 'PH.05.1706476', 'ASCII:Ligao;ID:1706476', '21758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21758', '112', '23635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1706476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23636', '1079', '1', 'Lidlidda', 'PH.29.1706488', 'ASCII:Lidlidda;ID:1706488', '21759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21759', '112', '23636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1706488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23637', '1079', '1', 'Licuan', 'PH.01.1706502', 'ASCII:Licuan;ID:1706502', '21760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21760', '112', '23637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1706502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23638', '1079', '1', 'Licab', 'PH.47.1706533', 'ASCII:Licab;ID:1706533', '21761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21761', '112', '23638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1706533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23639', '1079', '1', 'Libungan', 'PH.57.1706551', 'ASCII:Libungan;ID:1706551', '21762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21762', '112', '23639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1706551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23640', '1079', '1', 'Libona', 'PH.12.1706608', 'ASCII:Libona;ID:1706608', '21763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21763', '112', '23640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1706608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23641', '1079', '1', 'Libon', 'PH.05.1706612', 'ASCII:Libon;ID:1706612', '21764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21764', '112', '23641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1706612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23642', '1079', '1', 'Libmanan', 'PH.16.1706630', 'ASCII:Libmanan;ID:1706630', '21765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21765', '112', '23642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1706630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23643', '1079', '1', 'Libjo', 'PH.61.1706651', 'ASCII:Libjo;ID:1706651', '21766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21766', '112', '23643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1706651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23644', '1079', '1', 'Libertad', 'PH.06.1706692', 'ASCII:Libertad;ID:1706692', '21767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21767', '112', '23644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1706692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23645', '1079', '1', 'Libagon', 'PH.59.1706751', 'ASCII:Libagon;ID:1706751', '21768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21768', '112', '23645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1706751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23646', '1079', '1', 'Libacao', 'PH.04.1706759', 'ASCII:Libacao;ID:1706759', '21769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21769', '112', '23646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1706759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23647', '1079', '1', 'Lianga', 'PH.62.1706782', 'ASCII:Lianga;ID:1706782', '21770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21770', '112', '23647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1706782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23648', '1079', '1', 'Lian', 'PH.09.1706788', 'ASCII:Lian;ID:1706788', '21771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21771', '112', '23648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1706788» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23649', '1079', '1', 'Lezo', 'PH.04.1706794', 'ASCII:Lezo;ID:1706794', '21772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21772', '112', '23649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1706794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23650', '1079', '1', 'Leyte', 'PH.37.1706803', 'ASCII:Leyte;ID:1706803', '21773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21773', '112', '23650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1706803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23651', '1079', '1', 'Leon', 'PH.30.1706844', 'ASCII:Leon;ID:1706844', '21774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21774', '112', '23651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1706844» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23652', '1079', '1', 'Lemery', 'PH.09.1706866', 'ASCII:Lemery;ID:1706866', '21775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21775', '112', '23652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1706866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23653', '1079', '1', 'Lemery', 'PH.30.1706867', 'ASCII:Lemery;ID:1706867', '21776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21776', '112', '23653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1706867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23654', '1079', '1', 'Leganes', 'PH.30.1706896', 'ASCII:Leganes;ID:1706896', '21777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21777', '112', '23654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1706896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23655', '1079', '1', 'Lebak', 'PH.71.1706919', 'ASCII:Lebak;ID:1706919', '21778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21778', '112', '23655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1706919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23656', '1079', '1', 'Lazi', 'PH.69.1706924', 'ASCII:Lazi;ID:1706924', '21779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21779', '112', '23656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.69.1706924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23657', '1079', '1', 'Lawa-an', 'PH.23.1707026', 'ASCII:Lawa-an;ID:1707026', '21780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21780', '112', '23657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1707026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23658', '1079', '1', 'Lawa-an', 'PH.06.1707027', 'ASCII:Lawa-an;ID:1707027', '21781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21781', '112', '23658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1707027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23659', '1079', '1', 'Lavezares', 'PH.67.1707036', 'ASCII:Lavezares;ID:1707036', '21782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21782', '112', '23659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1707036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23660', '1079', '1', 'Laurel', 'PH.09.1707047', 'ASCII:Laurel;ID:1707047', '21783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21783', '112', '23660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1707047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23661', '1079', '1', 'Laur', 'PH.47.1707050', 'ASCII:Laur;ID:1707050', '21784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21784', '112', '23661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1707050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23662', '1079', '1', 'La Trinidad', 'PH.10.1707125', 'ASCII:La Trinidad;ID:1707125', '21785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21785', '112', '23662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1707125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23663', '1079', '1', 'Las Piñas', 'PH.53.1707175', 'ASCII:Las Pinas;ID:1707175', '21786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21786', '112', '23663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1707175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23664', '1079', '1', 'Las Nieves', 'PH.02.1707178', 'ASCII:Las Nieves;ID:1707178', '21787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21787', '112', '23664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.02.1707178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23665', '1079', '1', 'Las Navas', 'PH.67.1707181', 'ASCII:Las Navas;ID:1707181', '21788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21788', '112', '23665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1707181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23666', '1079', '1', 'Lasam', 'PH.14.1707205', 'ASCII:Lasam;ID:1707205', '21789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21789', '112', '23666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1707205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23667', '1079', '1', 'Larena', 'PH.69.1707224', 'ASCII:Larena;ID:1707224', '21790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21790', '112', '23667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.69.1707224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23668', '1079', '1', 'Lapuyan', 'PH.66.1707251', 'ASCII:Lapuyan;ID:1707251', '21791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21791', '112', '23668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1707251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23669', '1079', '1', 'Lapinig', 'PH.67.1707313', 'ASCII:Lapinig;ID:1707313', '21792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21792', '112', '23669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1707313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23670', '1079', '1', 'La Paz', 'PH.01.1707345', 'ASCII:La Paz;ID:1707345', '21793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21793', '112', '23670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1707345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23671', '1079', '1', 'La Paz', 'PH.63.1707346', 'ASCII:La Paz;ID:1707346', '21794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21794', '112', '23671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1707346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23672', '1079', '1', 'La Paz', 'PH.37.1707347', 'ASCII:La Paz;ID:1707347', '21795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21795', '112', '23672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1707347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23673', '1079', '1', 'Laoang', 'PH.67.1707399', 'ASCII:Laoang;ID:1707399', '21796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21796', '112', '23673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1707399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23674', '1079', '1', 'Laoac', 'PH.51.1707410', 'ASCII:Laoac;ID:1707410', '21797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21797', '112', '23674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1707410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23675', '1079', '1', 'Lanuza', 'PH.62.1707416', 'ASCII:Lanuza;ID:1707416', '21798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21798', '112', '23675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1707416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23676', '1079', '1', 'Lantawan', 'PH.22.1707435', 'ASCII:Lantawan;ID:1707435', '21799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21799', '112', '23676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.22.1707435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23677', '1079', '1', 'Lantapan', 'PH.09.1707439', 'ASCII:Lantapan;ID:1707439', '21800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21800', '112', '23677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1707439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23678', '1079', '1', 'Languyan', 'PH.72.1707512', 'ASCII:Languyan;ID:1707512', '21801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21801', '112', '23678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.72.1707512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23679', '1079', '1', 'Langiden', 'PH.01.1707565', 'ASCII:Langiden;ID:1707565', '21802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21802', '112', '23679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1707565» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23680', '1079', '1', 'Lamut', 'PH.27.1707712', 'ASCII:Lamut;ID:1707712', '21803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21803', '112', '23680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.27.1707712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23681', '1079', '1', 'Lamitan', 'PH.22.1707763', 'ASCII:Lamitan;ID:1707763', '21804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21804', '112', '23681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.22.1707763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23682', '1079', '1', 'Lambunao', 'PH.30.1707801', 'ASCII:Lambunao;ID:1707801', '21805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21805', '112', '23682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1707801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23683', '1079', '1', 'Lal-lo', 'PH.14.1707883', 'ASCII:Lal-lo;ID:1707883', '21806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21806', '112', '23683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1707883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23684', '1079', '1', 'La Libertad', 'PH.46.1707893', 'ASCII:La Libertad;ID:1707893', '21807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21807', '112', '23684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1707893» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23685', '1079', '1', 'Municipality of La Libertad', 'PH.65.1707894', 'ASCII:Municipality of La Libertad;ID:1707894', '21808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21808', '112', '23685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1707894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23686', '1079', '1', 'Lala', 'PH.34.1707944', 'ASCII:Lala;ID:1707944', '21809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21809', '112', '23686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1707944» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23687', '1079', '1', 'Lakewood', 'PH.66.1707952', 'ASCII:Lakewood;ID:1707952', '21810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21810', '112', '23687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1707952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23688', '1079', '1', 'Laguindingan', 'PH.43.1708052', 'ASCII:Laguindingan;ID:1708052', '21811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21811', '112', '23688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1708052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23689', '1079', '1', 'Lagonoy', 'PH.16.1708079', 'ASCII:Lagonoy;ID:1708079', '21812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21812', '112', '23689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1708079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23690', '1079', '1', 'Lagonglong', 'PH.43.1708082', 'ASCII:Lagonglong;ID:1708082', '21813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21813', '112', '23690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1708082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23691', '1079', '1', 'Lagayan', 'PH.01.1708128', 'ASCII:Lagayan;ID:1708128', '21814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21814', '112', '23691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1708128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23692', '1079', '1', 'Lagawe', 'PH.27.1708131', 'ASCII:Lagawe;ID:1708131', '21815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21815', '112', '23692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.27.1708131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23693', '1079', '1', 'Lagangilang', 'PH.01.1708152', 'ASCII:Lagangilang;ID:1708152', '21816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21816', '112', '23693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1708152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23694', '1079', '1', 'Lacub', 'PH.01.1708194', 'ASCII:Lacub;ID:1708194', '21817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21817', '112', '23694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1708194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23695', '1079', '1', 'La Castellana', 'PH.H3.1708218', 'ASCII:La Castellana;ID:1708218', '21818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21818', '112', '23695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1708218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23696', '1079', '1', 'Labrador', 'PH.51.1708269', 'ASCII:Labrador;ID:1708269', '21819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21819', '112', '23696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1708269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23697', '1079', '1', 'Labo', 'PH.15.1708294', 'ASCII:Labo;ID:1708294', '21820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21820', '112', '23697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1708294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23698', '1079', '1', 'Labason', 'PH.65.1708336', 'ASCII:Labason;ID:1708336', '21821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21821', '112', '23698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1708336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23699', '1079', '1', 'Labangan', 'PH.66.1708369', 'ASCII:Labangan;ID:1708369', '21822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21822', '112', '23699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1708369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23700', '1079', '1', 'Kumalarang', 'PH.66.1708432', 'ASCII:Kumalarang;ID:1708432', '21823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21823', '112', '23700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1708432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23701', '1079', '1', 'Koronadal', 'PH.70.1708524', 'ASCII:Koronadal;ID:1708524', '21824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21824', '112', '23701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1708524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23702', '1079', '1', 'Kolambugan', 'PH.34.1708558', 'ASCII:Kolambugan;ID:1708558', '21825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21825', '112', '23702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1708558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23703', '1079', '1', 'Kitcharao', 'PH.02.1708601', 'ASCII:Kitcharao;ID:1708601', '21826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21826', '112', '23703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.02.1708601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23704', '1079', '1', 'Kitaotao', 'PH.12.1708605', 'ASCII:Kitaotao;ID:1708605', '21827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21827', '112', '23704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1708605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23705', '1079', '1', 'Kinogitan', 'PH.43.1708663', 'ASCII:Kinogitan;ID:1708663', '21828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21828', '112', '23705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1708663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23706', '1079', '1', 'Kidapawan', 'PH.57.1708825', 'ASCII:Kidapawan;ID:1708825', '21829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21829', '112', '23706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1708825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23707', '1079', '1', 'Kibungan', 'PH.10.1708839', 'ASCII:Kibungan;ID:1708839', '21830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21830', '112', '23707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1708839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23708', '1079', '1', 'Kiblawan', 'PH.25.1708861', 'ASCII:Kiblawan;ID:1708861', '21831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21831', '112', '23708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1708861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23709', '1079', '1', 'Kibawe', 'PH.12.1708866', 'ASCII:Kibawe;ID:1708866', '21832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21832', '112', '23709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1708866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23710', '1079', '1', 'Kiangan', 'PH.27.1708898', 'ASCII:Kiangan;ID:1708898', '21833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21833', '112', '23710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.27.1708898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23711', '1079', '1', 'Kiamba', 'PH.70.1708904', 'ASCII:Kiamba;ID:1708904', '21834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21834', '112', '23711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1708904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23712', '1079', '1', 'Kayapa', 'PH.48.1708984', 'ASCII:Kayapa;ID:1708984', '21835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21835', '112', '23712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1708984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23713', '1079', '1', 'Kawit', 'PH.20.1709007', 'ASCII:Kawit;ID:1709007', '21836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21836', '112', '23713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1709007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23714', '1079', '1', 'Kawayan', 'PH.37.1709025', 'ASCII:Kawayan;ID:1709025', '21837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21837', '112', '23714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1709025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23715', '1079', '1', 'Kauswagan', 'PH.34.1709042', 'ASCII:Kauswagan;ID:1709042', '21838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21838', '112', '23715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1709042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23716', '1079', '1', 'Katipunan', 'PH.65.1709083', 'ASCII:Katipunan;ID:1709083', '21839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21839', '112', '23716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1709083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23717', '1079', '1', 'Kasibu', 'PH.48.1709156', 'ASCII:Kasibu;ID:1709156', '21840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21840', '112', '23717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1709156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23718', '1079', '1', 'Karomatan', 'PH.34.1709173', 'ASCII:Karomatan;ID:1709173', '21841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21841', '112', '23718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1709173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23719', '1079', '1', 'Kaputian', 'PH.24.1709203', 'ASCII:Kaputian;ID:1709203', '21842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21842', '112', '23719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1709203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23720', '1079', '1', 'Kapatagan', 'PH.34.1709250', 'ASCII:Kapatagan;ID:1709250', '21843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21843', '112', '23720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1709250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23721', '1079', '1', 'Kapangan', 'PH.10.1709265', 'ASCII:Kapangan;ID:1709265', '21844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21844', '112', '23721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1709265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23722', '1079', '1', 'Kapalong', 'PH.24.1709274', 'ASCII:Kapalong;ID:1709274', '21845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21845', '112', '23722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1709274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23723', '1079', '1', 'Kapai', 'PH.35.1709284', 'ASCII:Kapai;ID:1709284', '21846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21846', '112', '23723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1709284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23724', '1079', '1', 'Kananga', 'PH.37.1709457', 'ASCII:Kananga;ID:1709457', '21847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21847', '112', '23724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1709457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23725', '1079', '1', 'Kalingalan Caluang', 'PH.60.1709618', 'ASCII:Kalingalan Caluang;ID:1709618', '21848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21848', '112', '23725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1709618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23726', '1079', '1', 'Kalilangan', 'PH.09.1709629', 'ASCII:Kalilangan;ID:1709629', '21849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21849', '112', '23726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1709629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23727', '1079', '1', 'Kalibo (Provincial Capitol Site)', 'PH.04.1709635', 'ASCII:Kalibo (Provincial Capitol Site);ID:1709635', '21850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21850', '112', '23727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1709635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23728', '1079', '1', 'Kalayaan', 'PH.33.1709651', 'ASCII:Kalayaan;ID:1709651', '21851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21851', '112', '23728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1709651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23729', '1079', '1', 'Kalamansig', 'PH.71.1709718', 'ASCII:Kalamansig;ID:1709718', '21852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21852', '112', '23729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1709718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23730', '1079', '1', 'Kadingilan', 'PH.09.1709829', 'ASCII:Kadingilan;ID:1709829', '21853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21853', '112', '23730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1709829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23731', '1079', '1', 'Kabuntalan', 'PH.56.1709853', 'ASCII:Kabuntalan;ID:1709853', '21854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21854', '112', '23731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1709853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23732', '1079', '1', 'Kabugao', 'PH.32.1709887', 'ASCII:Kabugao;ID:1709887', '21855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21855', '112', '23732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1709887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23733', '1079', '1', 'Kabayan', 'PH.10.1709934', 'ASCII:Kabayan;ID:1709934', '21856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21856', '112', '23733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1709934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23734', '1079', '1', 'Kabasalan', 'PH.66.1709958', 'ASCII:Kabasalan;ID:1709958', '21857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21857', '112', '23734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1709958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23735', '1079', '1', 'Kabankalan', 'PH.H3.1709970', 'ASCII:Kabankalan;ID:1709970', '21858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21858', '112', '23735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1709970» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23736', '1079', '1', 'Kabacan', 'PH.57.1710013', 'ASCII:Kabacan;ID:1710013', '21859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21859', '112', '23736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1710013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23737', '1079', '1', 'Jumalig', 'PH.H2.1710042', 'ASCII:Jumalig;ID:1710042', '21860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21860', '112', '23737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1710042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23738', '1079', '1', 'Julita', 'PH.37.1710055', 'ASCII:Julita;ID:1710055', '21861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21861', '112', '23738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1710055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23739', '1079', '1', 'Juban', 'PH.58.1710079', 'ASCII:Juban;ID:1710079', '21862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21862', '112', '23739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1710079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23740', '1079', '1', 'Jovellar', 'PH.05.1710100', 'ASCII:Jovellar;ID:1710100', '21863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21863', '112', '23740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1710100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23741', '1079', '1', 'Jose Panganiban', 'PH.15.1710104', 'ASCII:Jose Panganiban;ID:1710104', '21864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21864', '112', '23741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1710104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23742', '1079', '1', 'Josefina', 'PH.66.1710106', 'ASCII:Josefina;ID:1710106', '21865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21865', '112', '23742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1710106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23743', '1079', '1', 'Jose Abad Santos', 'PH.25.1710109', 'ASCII:Jose Abad Santos;ID:1710109', '21866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21866', '112', '23743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1710109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23744', '1079', '1', 'Jordan', 'PH.30.1710117', 'ASCII:Jordan;ID:1710117', '21867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21867', '112', '23744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1710117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23745', '1079', '1', 'Jones', 'PH.31.1710125', 'ASCII:Jones;ID:1710125', '21868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21868', '112', '23745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1710125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23746', '1079', '1', 'Jolo', 'PH.60.1710143', 'ASCII:Jolo;ID:1710143', '21869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21869', '112', '23746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1710143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23747', '1079', '1', 'Jipapad', 'PH.23.1710160', 'ASCII:Jipapad;ID:1710160', '21870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21870', '112', '23747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1710160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23748', '1079', '1', 'Jimenez', 'PH.42.1710182', 'ASCII:Jimenez;ID:1710182', '21871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21871', '112', '23748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1710182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23749', '1079', '1', 'Jimalalud', 'PH.46.1710192', 'ASCII:Jimalalud;ID:1710192', '21872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21872', '112', '23749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1710192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23750', '1079', '1', 'Jiabong', 'PH.55.1710217', 'ASCII:Jiabong;ID:1710217', '21873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21873', '112', '23750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1710217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23751', '1079', '1', 'Jetafe', 'PH.11.1710223', 'ASCII:Jetafe;ID:1710223', '21874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21874', '112', '23751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1710223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23752', '1079', '1', 'Javier', 'PH.37.1710248', 'ASCII:Javier;ID:1710248', '21875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21875', '112', '23752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1710248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23753', '1079', '1', 'Jasaan', 'PH.43.1710259', 'ASCII:Jasaan;ID:1710259', '21876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21876', '112', '23753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1710259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23754', '1079', '1', 'Jaro', 'PH.37.1710264', 'ASCII:Jaro;ID:1710264', '21877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21877', '112', '23754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1710264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23755', '1079', '1', 'Janiuay', 'PH.30.1710287', 'ASCII:Janiuay;ID:1710287', '21878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21878', '112', '23755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1710287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23756', '1079', '1', 'Jamindan', 'PH.18.1710326', 'ASCII:Jamindan;ID:1710326', '21879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21879', '112', '23756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1710326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23757', '1079', '1', 'Jalajala', 'PH.53.1710358', 'ASCII:Jalajala;ID:1710358', '21880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21880', '112', '23757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1710358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23758', '1079', '1', 'Jagna', 'PH.11.1710379', 'ASCII:Jagna;ID:1710379', '21881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21881', '112', '23758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1710379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23759', '1079', '1', 'Jaen', 'PH.47.1710390', 'ASCII:Jaen;ID:1710390', '21882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21882', '112', '23759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1710390» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23760', '1079', '1', 'Jabonga', 'PH.02.1710400', 'ASCII:Jabonga;ID:1710400', '21883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21883', '112', '23760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.02.1710400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23761', '1079', '1', 'Ivisan', 'PH.18.1710426', 'ASCII:Ivisan;ID:1710426', '21884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21884', '112', '23761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1710426» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23762', '1079', '1', 'Ivana', 'PH.08.1710429', 'ASCII:Ivana;ID:1710429', '21885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21885', '112', '23762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.08.1710429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23763', '1079', '1', 'Itogon', 'PH.10.1710442', 'ASCII:Itogon;ID:1710442', '21886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21886', '112', '23763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1710442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23764', '1079', '1', 'Itbayat', 'PH.08.1710457', 'ASCII:Itbayat;ID:1710457', '21887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21887', '112', '23764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.08.1710457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23765', '1079', '1', 'Isulan', 'PH.71.1710471', 'ASCII:Isulan;ID:1710471', '21888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21888', '112', '23765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1710471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23766', '1079', '1', 'Isabela', 'PH.H3.1710520', 'ASCII:Isabela;ID:1710520', '21889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21889', '112', '23766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1710520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23767', '1079', '1', 'Municipality of Isabela (Capital)', 'PH.22.1710521', 'ASCII:Municipality of Isabela (Capital);ID:1710521', '21890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21890', '112', '23767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.22.1710521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23768', '1079', '1', 'Isabel', 'PH.37.1710524', 'ASCII:Isabel;ID:1710524', '21891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21891', '112', '23768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1710524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23769', '1079', '1', 'Irosin', 'PH.58.1710532', 'ASCII:Irosin;ID:1710532', '21892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21892', '112', '23769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1710532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23770', '1079', '1', 'Ipil', 'PH.66.1710618', 'ASCII:Ipil;ID:1710618', '21893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21893', '112', '23770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1710618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23771', '1079', '1', 'Inopacan', 'PH.37.1710667', 'ASCII:Inopacan;ID:1710667', '21894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21894', '112', '23771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1710667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23772', '1079', '1', 'Initao', 'PH.43.1710706', 'ASCII:Initao;ID:1710706', '21895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21895', '112', '23772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1710706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23773', '1079', '1', 'Infanta', 'PH.51.1710746', 'ASCII:Infanta;ID:1710746', '21896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21896', '112', '23773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1710746» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23774', '1079', '1', 'Infanta', 'PH.H2.1710747', 'ASCII:Infanta;ID:1710747', '21897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21897', '112', '23774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1710747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23775', '1079', '1', 'Indang', 'PH.20.1710771', 'ASCII:Indang;ID:1710771', '21898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21898', '112', '23775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1710771» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23776', '1079', '1', 'Indanan', 'PH.60.1710773', 'ASCII:Indanan;ID:1710773', '21899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21899', '112', '23776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.1710773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23777', '1079', '1', 'Inabanga', 'PH.11.1710909', 'ASCII:Inabanga;ID:1710909', '21900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21900', '112', '23777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1710909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23778', '1079', '1', 'Imus', 'PH.20.1710915', 'ASCII:Imus;ID:1710915', '21901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21901', '112', '23778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1710915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23779', '1079', '1', 'Imelda', 'PH.15.1710951', 'ASCII:Imelda;ID:1710951', '21902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21902', '112', '23779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1710951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23780', '1079', '1', 'Imelda', 'PH.66.1710952', 'ASCII:Imelda;ID:1710952', '21903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21903', '112', '23780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1710952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23781', '1079', '1', 'Ilog', 'PH.H3.1711031', 'ASCII:Ilog;ID:1711031', '21904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21904', '112', '23781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1711031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23782', '1079', '1', 'Ilagan', 'PH.31.1711148', 'ASCII:Ilagan;ID:1711148', '21905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21905', '112', '23782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1711148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23783', '1079', '1', 'Iguig', 'PH.14.1711173', 'ASCII:Iguig;ID:1711173', '21906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21906', '112', '23783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1711173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23784', '1079', '1', 'Igbaras', 'PH.30.1711288', 'ASCII:Igbaras;ID:1711288', '21907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21907', '112', '23784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1711288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23785', '1079', '1', 'Ibajay', 'PH.04.1711405', 'ASCII:Ibajay;ID:1711405', '21908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21908', '112', '23785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1711405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23786', '1079', '1', 'Ibaan', 'PH.09.1711432', 'ASCII:Ibaan;ID:1711432', '21909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21909', '112', '23786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1711432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23787', '1079', '1', 'Iba', 'PH.64.1711447', 'ASCII:Iba;ID:1711447', '21910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21910', '112', '23787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1711447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23788', '1079', '1', 'Hungduan', 'PH.27.1711463', 'ASCII:Hungduan;ID:1711463', '21911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21911', '112', '23788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.27.1711463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23789', '1079', '1', 'Hinundayan', 'PH.59.1711594', 'ASCII:Hinundayan;ID:1711594', '21912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21912', '112', '23789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1711594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23790', '1079', '1', 'Hinunangan', 'PH.59.1711597', 'ASCII:Hinunangan;ID:1711597', '21913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21913', '112', '23790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1711597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23791', '1079', '1', 'Hinoba-an', 'PH.H3.1711613', 'ASCII:Hinoba-an;ID:1711613', '21914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21914', '112', '23791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1711613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23792', '1079', '1', 'Hinigaran', 'PH.H3.1711622', 'ASCII:Hinigaran;ID:1711622', '21915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21915', '112', '23792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1711622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23793', '1079', '1', 'Hindang', 'PH.37.1711646', 'ASCII:Hindang;ID:1711646', '21916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21916', '112', '23793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1711646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23794', '1079', '1', 'Hinatuan', 'PH.62.1711656', 'ASCII:Hinatuan;ID:1711656', '21917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21917', '112', '23794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1711656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23795', '1079', '1', 'Hinabangan', 'PH.55.1711684', 'ASCII:Hinabangan;ID:1711684', '21918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21918', '112', '23795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1711684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23796', '1079', '1', 'Himamaylan', 'PH.H3.1711719', 'ASCII:Himamaylan;ID:1711719', '21919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21919', '112', '23796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1711719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23797', '1079', '1', 'Hilongos', 'PH.56.1711744', 'ASCII:Hilongos;ID:1711744', '21920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21920', '112', '23797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1711744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23798', '1079', '1', 'Hernani', 'PH.23.1711822', 'ASCII:Hernani;ID:1711822', '21921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21921', '112', '23798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1711822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23799', '1079', '1', 'Hermosa', 'PH.07.1711830', 'ASCII:Hermosa;ID:1711830', '21922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21922', '112', '23799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1711830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23800', '1079', '1', 'Hamtic', 'PH.06.1711909', 'ASCII:Hamtic;ID:1711909', '21923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21923', '112', '23800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1711909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23801', '1079', '1', 'Hagonoy', 'PH.13.1711985', 'ASCII:Hagonoy;ID:1711985', '21924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21924', '112', '23801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1711985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23802', '1079', '1', 'Hagonoy', 'PH.25.1711986', 'ASCII:Hagonoy;ID:1711986', '21925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21925', '112', '23802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1711986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23803', '1079', '1', 'Gutalac', 'PH.65.1712069', 'ASCII:Gutalac;ID:1712069', '21926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21926', '112', '23803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1712069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23804', '1079', '1', 'Gumaca', 'PH.H2.1712164', 'ASCII:Gumaca;ID:1712164', '21927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21927', '112', '23804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1712164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23805', '1079', '1', 'Guiuan', 'PH.23.1712208', 'ASCII:Guiuan;ID:1712208', '21928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21928', '112', '23805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1712208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23806', '1079', '1', 'Guinsiliban', 'PH.17.1712298', 'ASCII:Guinsiliban;ID:1712298', '21929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21929', '112', '23806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.17.1712298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23807', '1079', '1', 'Guinobatan', 'PH.05.1712332', 'ASCII:Guinobatan;ID:1712332', '21930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21930', '112', '23807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1712332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23808', '1079', '1', 'Guindulman', 'PH.11.1712378', 'ASCII:Guindulman;ID:1712378', '21931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21931', '112', '23808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1712378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23809', '1079', '1', 'Guinayangan', 'PH.H2.1712416', 'ASCII:Guinayangan;ID:1712416', '21932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21932', '112', '23809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1712416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23810', '1079', '1', 'Guimbal', 'PH.30.1712485', 'ASCII:Guimbal;ID:1712485', '21933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21933', '112', '23810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1712485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23811', '1079', '1', 'Guimba', 'PH.47.1712491', 'ASCII:Guimba;ID:1712491', '21934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21934', '112', '23811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1712491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23812', '1079', '1', 'Guihulngan', 'PH.46.1712521', 'ASCII:Guihulngan;ID:1712521', '21935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21935', '112', '23812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1712521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23813', '1079', '1', 'Guiguinto', 'PH.13.1712532', 'ASCII:Guiguinto;ID:1712532', '21936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21936', '112', '23813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1712532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23814', '1079', '1', 'Gubat', 'PH.58.1712601', 'ASCII:Gubat;ID:1712601', '21937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21937', '112', '23814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1712601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23815', '1079', '1', 'Guagua', 'PH.50.1712628', 'ASCII:Guagua;ID:1712628', '21938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21938', '112', '23815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1712628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23816', '1079', '1', 'Gregorio del Pilar', 'PH.29.1712664', 'ASCII:Gregorio del Pilar;ID:1712664', '21939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21939', '112', '23816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1712664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23817', '1079', '1', 'Governor Generoso', 'PH.26.1712705', 'ASCII:Governor Generoso;ID:1712705', '21940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21940', '112', '23817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1712705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23818', '1079', '1', 'Gonzaga', 'PH.14.1712752', 'ASCII:Gonzaga;ID:1712752', '21941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21941', '112', '23818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1712752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23819', '1079', '1', 'Goa', 'PH.16.1712809', 'ASCII:Goa;ID:1712809', '21942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21942', '112', '23819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1712809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23820', '1079', '1', 'Gloria', 'PH.41.1712814', 'ASCII:Gloria;ID:1712814', '21943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21943', '112', '23820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1712814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23821', '1079', '1', 'Glan', 'PH.70.1712820', 'ASCII:Glan;ID:1712820', '21944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21944', '112', '23821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1712820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23822', '1079', '1', 'Gitagum', 'PH.43.1712833', 'ASCII:Gitagum;ID:1712833', '21945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21945', '112', '23822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1712833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23823', '1079', '1', 'Giporlos', 'PH.23.1712843', 'ASCII:Giporlos;ID:1712843', '21946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21946', '112', '23823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1712843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23824', '1079', '1', 'Ginatilan', 'PH.21.1712901', 'ASCII:Ginatilan;ID:1712901', '21947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21947', '112', '23824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1712901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23825', '1079', '1', 'Gigmoto', 'PH.19.1712962', 'ASCII:Gigmoto;ID:1712962', '21948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21948', '112', '23825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1712962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23826', '1079', '1', 'Gigaquit', 'PH.61.1712965', 'ASCII:Gigaquit;ID:1712965', '21949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21949', '112', '23826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1712965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23827', '1079', '1', 'Gerona', 'PH.63.1713005', 'ASCII:Gerona;ID:1713005', '21950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21950', '112', '23827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1713005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23828', '1079', '1', 'General Trias', 'PH.20.1713015', 'ASCII:General Trias;ID:1713015', '21951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21951', '112', '23828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1713015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23829', '1079', '1', 'General Tinio', 'PH.47.1713019', 'ASCII:General Tinio;ID:1713019', '21952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21952', '112', '23829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1713019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23830', '1079', '1', 'General Nakar', 'PH.H2.1713025', 'ASCII:General Nakar;ID:1713025', '21953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21953', '112', '23830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1713025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23831', '1079', '1', 'General Mamerto Natividad', 'PH.47.1713028', 'ASCII:General Mamerto Natividad;ID:1713028', '21954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21954', '112', '23831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1713028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23832', '1079', '1', 'General MacArthur', 'PH.23.1713031', 'ASCII:General MacArthur;ID:1713031', '21955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21955', '112', '23832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1713031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23833', '1079', '1', 'General Luna', 'PH.H2.1713047', 'ASCII:General Luna;ID:1713047', '21956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21956', '112', '23833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1713047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23834', '1079', '1', 'General Luna', 'PH.61.1713048', 'ASCII:General Luna;ID:1713048', '21957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21957', '112', '23834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1713048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23835', '1079', '1', 'General Emilio Aguinaldo', 'PH.20.1713054', 'ASCII:General Emilio Aguinaldo;ID:1713054', '21958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21958', '112', '23835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1713054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23836', '1079', '1', 'Gattaran', 'PH.14.1713117', 'ASCII:Gattaran;ID:1713117', '21959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21959', '112', '23836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1713117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23837', '1079', '1', 'Gasan', 'PH.38.1713155', 'ASCII:Gasan;ID:1713155', '21960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21960', '112', '23837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.38.1713155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23838', '1079', '1', 'Garcia-Hernandez', 'PH.11.1713186', 'ASCII:Garcia-Hernandez;ID:1713186', '21961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21961', '112', '23838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1713186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23839', '1079', '1', 'Garchitorena', 'PH.16.1713192', 'ASCII:Garchitorena;ID:1713192', '21962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21962', '112', '23839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1713192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23840', '1079', '1', 'Gapan', 'PH.47.1713227', 'ASCII:Gapan;ID:1713227', '21963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21963', '112', '23840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1713227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23841', '1079', '1', 'Gandara', 'PH.55.1713263', 'ASCII:Gandara;ID:1713263', '21964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21964', '112', '23841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1713263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23842', '1079', '1', 'Ganassi', 'PH.35.1713272', 'ASCII:Ganassi;ID:1713272', '21965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21965', '112', '23842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1713272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23843', '1079', '1', 'Gamu', 'PH.31.1713289', 'ASCII:Gamu;ID:1713289', '21966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21966', '112', '23843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1713289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23844', '1079', '1', 'Gamay', 'PH.67.1713310', 'ASCII:Gamay;ID:1713310', '21967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21967', '112', '23844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1713310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23845', '1079', '1', 'Galimuyod', 'PH.29.1713341', 'ASCII:Galimuyod;ID:1713341', '21968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21968', '112', '23845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1713341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23846', '1079', '1', 'Gainza', 'PH.16.1713388', 'ASCII:Gainza;ID:1713388', '21969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21969', '112', '23846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1713388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23847', '1079', '1', 'Gabaldon', 'PH.47.1713499', 'ASCII:Gabaldon;ID:1713499', '21970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21970', '112', '23847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1713499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23848', '1079', '1', 'Floridablanca', 'PH.50.1713602', 'ASCII:Floridablanca;ID:1713602', '21971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21971', '112', '23848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1713602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23849', '1079', '1', 'Flora', 'PH.32.1713615', 'ASCII:Flora;ID:1713615', '21972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21972', '112', '23849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1713615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23850', '1079', '1', 'Ferrol', 'PH.54.1713645', 'ASCII:Ferrol;ID:1713645', '21973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21973', '112', '23850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1713645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23851', '1079', '1', 'Famy', 'PH.33.1713666', 'ASCII:Famy;ID:1713666', '21974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21974', '112', '23851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1713666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23852', '1079', '1', 'Estancia', 'PH.30.1713738', 'ASCII:Estancia;ID:1713738', '21975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21975', '112', '23852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1713738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23853', '1079', '1', 'Espiritu', 'PH.28.1713753', 'ASCII:Espiritu;ID:1713753', '21976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21976', '112', '23853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1713753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23854', '1079', '1', 'Esperanza', 'PH.39.1713789', 'ASCII:Esperanza;ID:1713789', '21977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21977', '112', '23854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1713789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23855', '1079', '1', 'Esperanza', 'PH.71.1713791', 'ASCII:Esperanza;ID:1713791', '21978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21978', '112', '23855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1713791» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23856', '1079', '1', 'Escalante', 'PH.H3.1713819', 'ASCII:Escalante;ID:1713819', '21979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21979', '112', '23856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1713819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23857', '1079', '1', 'Enrique Villanueva', 'PH.69.1713854', 'ASCII:Enrique Villanueva;ID:1713854', '21980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21980', '112', '23857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.69.1713854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23858', '1079', '1', 'Enrique B. Magalona', 'PH.H3.1713858', 'ASCII:Enrique B. Magalona;ID:1713858', '21981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21981', '112', '23858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1713858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23859', '1079', '1', 'Enrile', 'PH.14.1713860', 'ASCII:Enrile;ID:1713860', '21982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21982', '112', '23859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1713860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23860', '1079', '1', 'El Salvador', 'PH.43.1713912', 'ASCII:El Salvador;ID:1713912', '21983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21983', '112', '23860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1713912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23861', '1079', '1', 'El Nido', 'PH.49.1713918', 'ASCII:El Nido;ID:1713918', '21984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21984', '112', '23861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1713918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23862', '1079', '1', 'Echague', 'PH.31.1713964', 'ASCII:Echague;ID:1713964', '21985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21985', '112', '23862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1713964» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23863', '1079', '1', 'Dupax del Sur', 'PH.48.1714051', 'ASCII:Dupax del Sur;ID:1714051', '21986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21986', '112', '23863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1714051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23864', '1079', '1', 'Dupax del Norte', 'PH.48.1714053', 'ASCII:Dupax del Norte;ID:1714053', '21987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21987', '112', '23864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1714053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23865', '1079', '1', 'Dumingag', 'PH.66.1714122', 'ASCII:Dumingag;ID:1714122', '21988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21988', '112', '23865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1714122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23866', '1079', '1', 'Dumarao', 'PH.18.1714141', 'ASCII:Dumarao;ID:1714141', '21989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21989', '112', '23866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1714141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23867', '1079', '1', 'Dumaran', 'PH.49.1714148', 'ASCII:Dumaran;ID:1714148', '21990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21990', '112', '23867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1714148» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23868', '1079', '1', 'Dumanjug', 'PH.21.1714164', 'ASCII:Dumanjug;ID:1714164', '21991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21991', '112', '23868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1714164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23869', '1079', '1', 'Dumangas', 'PH.30.1714169', 'ASCII:Dumangas;ID:1714169', '21992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21992', '112', '23869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1714169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23870', '1079', '1', 'Dumalneg', 'PH.28.1714173', 'ASCII:Dumalneg;ID:1714173', '21993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21993', '112', '23870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1714173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23871', '1079', '1', 'Dumalinao', 'PH.66.1714177', 'ASCII:Dumalinao;ID:1714177', '21994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21994', '112', '23871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1714177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23872', '1079', '1', 'Dumalag', 'PH.18.1714191', 'ASCII:Dumalag;ID:1714191', '21995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21995', '112', '23872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1714191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23873', '1079', '1', 'Dulag', 'PH.37.1714265', 'ASCII:Dulag;ID:1714265', '21996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21996', '112', '23873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1714265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23874', '1079', '1', 'Duero', 'PH.11.1714308', 'ASCII:Duero;ID:1714308', '21997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21997', '112', '23874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1714308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23875', '1079', '1', 'Dueñas', 'PH.30.1714310', 'ASCII:Duenas;ID:1714310', '21998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21998', '112', '23875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1714310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23876', '1079', '1', 'Donsol', 'PH.58.1714412', 'ASCII:Donsol;ID:1714412', '21999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('21999', '112', '23876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1714412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23877', '1079', '1', 'Don Marcelino', 'PH.25.1714417', 'ASCII:Don Marcelino;ID:1714417', '22000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22000', '112', '23877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1714417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23878', '1079', '1', 'Don Carlos', 'PH.12.1714442', 'ASCII:Don Carlos;ID:1714442', '22001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22001', '112', '23878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1714442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23879', '1079', '1', 'Doña Remedios Trinidad', 'PH.13.1714447', 'ASCII:Dona Remedios Trinidad;ID:1714447', '22002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22002', '112', '23879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1714447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23880', '1079', '1', 'Dolores', 'PH.01.1714512', 'ASCII:Dolores;ID:1714512', '22003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22003', '112', '23880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1714512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23881', '1079', '1', 'Dolores', 'PH.H2.1714513', 'ASCII:Dolores;ID:1714513', '22004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22004', '112', '23881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1714513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23882', '1079', '1', 'Dolores', 'PH.23.1714514', 'ASCII:Dolores;ID:1714514', '22005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22005', '112', '23882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1714514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23883', '1079', '1', 'Divilican', 'PH.31.1714587', 'ASCII:Divilican;ID:1714587', '22006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22006', '112', '23883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1714587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23884', '1079', '1', 'Ditsaan', 'PH.35.1714603', 'ASCII:Ditsaan;ID:1714603', '22007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22007', '112', '23884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1714603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23885', '1079', '1', 'Diplahan', 'PH.66.1714680', 'ASCII:Diplahan;ID:1714680', '22008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22008', '112', '23885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1714680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23886', '1079', '1', 'Dipaculao', 'PH.G8.1714701', 'ASCII:Dipaculao;ID:1714701', '22009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22009', '112', '23886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.G8.1714701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23887', '1079', '1', 'Dingras', 'PH.28.1714729', 'ASCII:Dingras;ID:1714729', '22010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22010', '112', '23887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1714729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23888', '1079', '1', 'Dingle', 'PH.30.1714735', 'ASCII:Dingle;ID:1714735', '22011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22011', '112', '23888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1714735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23889', '1079', '1', 'Dingalan', 'PH.G8.1714744', 'ASCII:Dingalan;ID:1714744', '22012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22012', '112', '23889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.G8.1714744» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23890', '1079', '1', 'Dinas', 'PH.66.1714752', 'ASCII:Dinas;ID:1714752', '22013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22013', '112', '23890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1714752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23891', '1079', '1', 'Dinapigui', 'PH.31.1714760', 'ASCII:Dinapigui;ID:1714760', '22014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22014', '112', '23891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1714760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23892', '1079', '1', 'Dinalupihan', 'PH.07.1714767', 'ASCII:Dinalupihan;ID:1714767', '22015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22015', '112', '23892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1714767» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23893', '1079', '1', 'Dinalongan', 'PH.G8.1714770', 'ASCII:Dinalongan;ID:1714770', '22016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22016', '112', '23893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.G8.1714770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23894', '1079', '1', 'Dinaig', 'PH.56.1714782', 'ASCII:Dinaig;ID:1714782', '22017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22017', '112', '23894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1714782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23895', '1079', '1', 'Dinagat', 'PH.61.1714796', 'ASCII:Dinagat;ID:1714796', '22018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22018', '112', '23895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1714796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23896', '1079', '1', 'Dimiao', 'PH.11.1714814', 'ASCII:Dimiao;ID:1714814', '22019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22019', '112', '23896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1714814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23897', '1079', '1', 'Dimataling', 'PH.66.1714822', 'ASCII:Dimataling;ID:1714822', '22020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22020', '112', '23897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1714822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23898', '1079', '1', 'Dimasalang', 'PH.39.1714825', 'ASCII:Dimasalang;ID:1714825', '22021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22021', '112', '23898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1714825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23899', '1079', '1', 'Dilasag', 'PH.G8.1714888', 'ASCII:Dilasag;ID:1714888', '22022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22022', '112', '23899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.G8.1714888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23900', '1079', '1', 'Digos', 'PH.25.1714957', 'ASCII:Digos;ID:1714957', '22023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22023', '112', '23900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1714957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23901', '1079', '1', 'Diffun', 'PH.68.1714976', 'ASCII:Diffun;ID:1714976', '22024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22024', '112', '23901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.68.1714976» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23902', '1079', '1', 'Diadi', 'PH.48.1715096', 'ASCII:Diadi;ID:1715096', '22025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22025', '112', '23902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1715096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23903', '1079', '1', 'Del Gallego', 'PH.16.1715199', 'ASCII:Del Gallego;ID:1715199', '22026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22026', '112', '23903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1715199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23904', '1079', '1', 'Del Carmen', 'PH.61.1715213', 'ASCII:Del Carmen;ID:1715213', '22027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22027', '112', '23904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1715213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23905', '1079', '1', 'Dauis', 'PH.11.1715367', 'ASCII:Dauis;ID:1715367', '22028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22028', '112', '23905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1715367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23906', '1079', '1', 'Dauin', 'PH.46.1715370', 'ASCII:Dauin;ID:1715370', '22029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22029', '112', '23906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1715370» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23907', '1079', '1', 'Datu Piang', 'PH.56.1715383', 'ASCII:Datu Piang;ID:1715383', '22030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22030', '112', '23907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1715383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23908', '1079', '1', 'Datu Paglas', 'PH.56.1715385', 'ASCII:Datu Paglas;ID:1715385', '22031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22031', '112', '23908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1715385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23909', '1079', '1', 'Dasol', 'PH.51.1715428', 'ASCII:Dasol;ID:1715428', '22032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22032', '112', '23909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1715428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23910', '1079', '1', 'Dasmariñas', 'PH.20.1715431', 'ASCII:Dasmarinas;ID:1715431', '22033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22033', '112', '23910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1715431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23911', '1079', '1', 'Daram', 'PH.55.1715494', 'ASCII:Daram;ID:1715494', '22034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22034', '112', '23911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1715494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23912', '1079', '1', 'Daraga', 'PH.05.1715509', 'ASCII:Daraga;ID:1715509', '22035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22035', '112', '23912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1715509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23913', '1079', '1', 'Dapa', 'PH.61.1715618', 'ASCII:Dapa;ID:1715618', '22036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22036', '112', '23913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1715618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23914', '1079', '1', 'Dao', 'PH.18.1715645', 'ASCII:Dao;ID:1715645', '22037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22037', '112', '23914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1715645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23915', '1079', '1', 'Dao', 'PH.06.1715646', 'ASCII:Dao;ID:1715646', '22038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22038', '112', '23915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1715646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23916', '1079', '1', 'Danglas', 'PH.01.1715705', 'ASCII:Danglas;ID:1715705', '22039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22039', '112', '23916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1715705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23917', '1079', '1', 'Dangcagan', 'PH.09.1715723', 'ASCII:Dangcagan;ID:1715723', '22040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22040', '112', '23917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1715723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23918', '1079', '1', 'Danao', 'PH.11.1715818', 'ASCII:Danao;ID:1715818', '22041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22041', '112', '23918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1715818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23919', '1079', '1', 'Damulog', 'PH.12.1715835', 'ASCII:Damulog;ID:1715835', '22042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22042', '112', '23919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1715835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23920', '1079', '1', 'Dalaguete', 'PH.21.1716108', 'ASCII:Dalaguete;ID:1716108', '22043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22043', '112', '23920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1716108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23921', '1079', '1', 'Daguioman', 'PH.01.1716215', 'ASCII:Daguioman;ID:1716215', '22044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22044', '112', '23921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1716215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23922', '1079', '1', 'Dagohoy', 'PH.11.1716234', 'ASCII:Dagohoy;ID:1716234', '22045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22045', '112', '23922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1716234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23923', '1079', '1', 'Dagami', 'PH.37.1716274', 'ASCII:Dagami;ID:1716274', '22046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22046', '112', '23923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1716274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23924', '1079', '1', 'Daet', 'PH.15.1716289', 'ASCII:Daet;ID:1716289', '22047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22047', '112', '23924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1716289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23925', '1079', '1', 'Daanbantayan', 'PH.21.1716389', 'ASCII:Daanbantayan;ID:1716389', '22048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22048', '112', '23925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1716389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23926', '1079', '1', 'Cuyo', 'PH.49.1716398', 'ASCII:Cuyo;ID:1716398', '22049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22049', '112', '23926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1716398» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23927', '1079', '1', 'Cuyapo', 'PH.47.1716404', 'ASCII:Cuyapo;ID:1716404', '22050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22050', '112', '23927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1716404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23928', '1079', '1', 'Currimao', 'PH.28.1716447', 'ASCII:Currimao;ID:1716447', '22051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22051', '112', '23928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1716447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23929', '1079', '1', 'Culasi', 'PH.06.1716576', 'ASCII:Culasi;ID:1716576', '22052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22052', '112', '23929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1716576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23930', '1079', '1', 'Culaba', 'PH.37.1716600', 'ASCII:Culaba;ID:1716600', '22053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22053', '112', '23930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1716600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23931', '1079', '1', 'Cuenca', 'PH.09.1716619', 'ASCII:Cuenca;ID:1716619', '22054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22054', '112', '23931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1716619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23932', '1079', '1', 'Cuartero', 'PH.18.1716673', 'ASCII:Cuartero;ID:1716673', '22055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22055', '112', '23932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.18.1716673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23933', '1079', '1', 'Cortes', 'PH.11.1716789', 'ASCII:Cortes;ID:1716789', '22056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22056', '112', '23933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1716789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23934', '1079', '1', 'Cortes', 'PH.62.1716790', 'ASCII:Cortes;ID:1716790', '22057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22057', '112', '23934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1716790» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23935', '1079', '1', 'Coron', 'PH.49.1716835', 'ASCII:Coron;ID:1716835', '22058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22058', '112', '23935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1716835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23936', '1079', '1', 'Corella', 'PH.11.1716850', 'ASCII:Corella;ID:1716850', '22059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22059', '112', '23936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1716850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23937', '1079', '1', 'Cordon', 'PH.31.1716856', 'ASCII:Cordon;ID:1716856', '22060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22060', '112', '23937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1716856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23938', '1079', '1', 'Cordova', 'PH.21.1716859', 'ASCII:Cordova;ID:1716859', '22061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22061', '112', '23938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1716859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23939', '1079', '1', 'Corcuera', 'PH.54.1716865', 'ASCII:Corcuera;ID:1716865', '22062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22062', '112', '23939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1716865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23940', '1079', '1', 'Consolacion', 'PH.21.1716928', 'ASCII:Consolacion;ID:1716928', '22063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22063', '112', '23940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1716928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23941', '1079', '1', 'Conner', 'PH.32.1716934', 'ASCII:Conner;ID:1716934', '22064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22064', '112', '23941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1716934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23942', '1079', '1', 'Concepcion', 'PH.63.1717036', 'ASCII:Concepcion;ID:1717036', '22065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22065', '112', '23942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1717036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23943', '1079', '1', 'Concepcion', 'PH.54.1717037', 'ASCII:Concepcion;ID:1717037', '22066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22066', '112', '23943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1717037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23944', '1079', '1', 'Concepcion', 'PH.30.1717038', 'ASCII:Concepcion;ID:1717038', '22067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22067', '112', '23944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1717038» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23945', '1079', '1', 'Municipality of Concepcion', 'PH.65.1717039', 'ASCII:Municipality of Concepcion;ID:1717039', '22068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22068', '112', '23945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.65.1717039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23946', '1079', '1', 'Compostela', 'PH.21.1717054', 'ASCII:Compostela;ID:1717054', '22069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22069', '112', '23946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1717054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23947', '1079', '1', 'Compostela', 'PH.24.1717055', 'ASCII:Compostela;ID:1717055', '22070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22070', '112', '23947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1717055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23948', '1079', '1', 'Columbio', 'PH.71.1717104', 'ASCII:Columbio;ID:1717104', '22071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22071', '112', '23948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1717104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23949', '1079', '1', 'Claveria', 'PH.14.1717353', 'ASCII:Claveria;ID:1717353', '22072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22072', '112', '23949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1717353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23950', '1079', '1', 'Claveria', 'PH.39.1717354', 'ASCII:Claveria;ID:1717354', '22073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22073', '112', '23950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1717354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23951', '1079', '1', 'Claveria', 'PH.43.1717355', 'ASCII:Claveria;ID:1717355', '22074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22074', '112', '23951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1717355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23952', '1079', '1', 'Claver', 'PH.61.1717357', 'ASCII:Claver;ID:1717357', '22075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22075', '112', '23952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1717357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23953', '1079', '1', 'Clarin', 'PH.11.1717365', 'ASCII:Clarin;ID:1717365', '22076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22076', '112', '23953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1717365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23954', '1079', '1', 'Municipality of Clarin', 'PH.42.1717366', 'ASCII:Municipality of Clarin;ID:1717366', '22077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22077', '112', '23954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1717366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23955', '1079', '1', 'Cervantes', 'PH.29.1717455', 'ASCII:Cervantes;ID:1717455', '22078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22078', '112', '23955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1717455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23956', '1079', '1', 'Cawayan', 'PH.39.1717629', 'ASCII:Cawayan;ID:1717629', '22079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22079', '112', '23956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1717629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23957', '1079', '1', 'Cavinti', 'PH.33.1717650', 'ASCII:Cavinti;ID:1717650', '22080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22080', '112', '23957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1717650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23958', '1079', '1', 'Cauayan', 'PH.31.1717740', 'ASCII:Cauayan;ID:1717740', '22081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22081', '112', '23958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1717740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23959', '1079', '1', 'Cauayan', 'PH.H3.1717741', 'ASCII:Cauayan;ID:1717741', '22082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22082', '112', '23959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1717741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23960', '1079', '1', 'Catubig', 'PH.67.1717794', 'ASCII:Catubig;ID:1717794', '22083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22083', '112', '23960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1717794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23961', '1079', '1', 'Catmon', 'PH.21.1717852', 'ASCII:Catmon;ID:1717852', '22084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22084', '112', '23961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1717852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23962', '1079', '1', 'Catigbian', 'PH.11.1717876', 'ASCII:Catigbian;ID:1717876', '22085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22085', '112', '23962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1717876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23963', '1079', '1', 'Cateel', 'PH.26.1717898', 'ASCII:Cateel;ID:1717898', '22086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22086', '112', '23963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1717898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23964', '1079', '1', 'Catbalogan', 'PH.55.1717912', 'ASCII:Catbalogan;ID:1717912', '22087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22087', '112', '23964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1717912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23965', '1079', '1', 'Catarman', 'PH.67.1717933', 'ASCII:Catarman;ID:1717933', '22088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22088', '112', '23965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1717933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23966', '1079', '1', 'Catarman', 'PH.17.1717934', 'ASCII:Catarman;ID:1717934', '22089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22089', '112', '23966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.17.1717934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23967', '1079', '1', 'Catanauan', 'PH.H2.1717961', 'ASCII:Catanauan;ID:1717961', '22090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22090', '112', '23967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1717961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23968', '1079', '1', 'Cataiñgan', 'PH.39.1717995', 'ASCII:Cataingan;ID:1717995', '22091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22091', '112', '23968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1717995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23969', '1079', '1', 'Castillejos', 'PH.64.1718080', 'ASCII:Castillejos;ID:1718080', '22092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22092', '112', '23969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1718080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23970', '1079', '1', 'Castilla', 'PH.58.1718086', 'ASCII:Castilla;ID:1718086', '22093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22093', '112', '23970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1718086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23971', '1079', '1', 'Casiguran', 'PH.G8.1718155', 'ASCII:Casiguran;ID:1718155', '22094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22094', '112', '23971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.G8.1718155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23972', '1079', '1', 'Casiguran', 'PH.58.1718156', 'ASCII:Casiguran;ID:1718156', '22095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22095', '112', '23972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1718156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23973', '1079', '1', 'Carrascal', 'PH.62.1718263', 'ASCII:Carrascal;ID:1718263', '22096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22096', '112', '23973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1718263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23974', '1079', '1', 'Carranglan', 'PH.47.1718267', 'ASCII:Carranglan;ID:1718267', '22097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22097', '112', '23974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1718267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23975', '1079', '1', 'Carmona', 'PH.20.1718307', 'ASCII:Carmona;ID:1718307', '22098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22098', '112', '23975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1718307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23976', '1079', '1', 'Carmen', 'PH.21.1718340', 'ASCII:Carmen;ID:1718340', '22099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22099', '112', '23976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1718340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23977', '1079', '1', 'Carmen', 'PH.11.1718341', 'ASCII:Carmen;ID:1718341', '22100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22100', '112', '23977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1718341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23978', '1079', '1', 'Carmen', 'PH.62.1718342', 'ASCII:Carmen;ID:1718342', '22101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22101', '112', '23978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1718342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23979', '1079', '1', 'Carmen', 'PH.02.1718343', 'ASCII:Carmen;ID:1718343', '22102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22102', '112', '23979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.02.1718343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23980', '1079', '1', 'Carmen', 'PH.24.1718344', 'ASCII:Carmen;ID:1718344', '22103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22103', '112', '23980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1718344» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23981', '1079', '1', 'Carmen', 'PH.57.1718345', 'ASCII:Carmen;ID:1718345', '22104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22104', '112', '23981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1718345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23982', '1079', '1', 'Carles', 'PH.30.1718363', 'ASCII:Carles;ID:1718363', '22105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22105', '112', '23982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1718363» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23983', '1079', '1', 'Carigara', 'PH.37.1718394', 'ASCII:Carigara;ID:1718394', '22106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22106', '112', '23983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1718394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23984', '1079', '1', 'Cardona', 'PH.53.1718427', 'ASCII:Cardona;ID:1718427', '22107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22107', '112', '23984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1718427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23985', '1079', '1', 'Carcar', 'PH.21.1718437', 'ASCII:Carcar;ID:1718437', '22108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22108', '112', '23985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1718437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23986', '1079', '1', 'Carasi', 'PH.28.1718466', 'ASCII:Carasi;ID:1718466', '22109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22109', '112', '23986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1718466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23987', '1079', '1', 'Caramoran', 'PH.19.1718504', 'ASCII:Caramoran;ID:1718504', '22110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22110', '112', '23987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1718504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23988', '1079', '1', 'Caramoan', 'PH.16.1718509', 'ASCII:Caramoan;ID:1718509', '22111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22111', '112', '23988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1718509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23989', '1079', '1', 'Caraga', 'PH.26.1718531', 'ASCII:Caraga;ID:1718531', '22112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22112', '112', '23989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1718531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23990', '1079', '1', 'Capul', 'PH.67.1718595', 'ASCII:Capul;ID:1718595', '22113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22113', '112', '23990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1718595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23991', '1079', '1', 'Capoocan', 'PH.37.1718622', 'ASCII:Capoocan;ID:1718622', '22114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22114', '112', '23991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1718622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23992', '1079', '1', 'Capas', 'PH.63.1718723', 'ASCII:Capas;ID:1718723', '22115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22115', '112', '23992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1718723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23993', '1079', '1', 'Capalonga', 'PH.15.1718763', 'ASCII:Capalonga;ID:1718763', '22116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22116', '112', '23993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1718763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23994', '1079', '1', 'Caoayan', 'PH.29.1718807', 'ASCII:Caoayan;ID:1718807', '22117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22117', '112', '23994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1718807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23995', '1079', '1', 'Cantilan', 'PH.62.1718867', 'ASCII:Cantilan;ID:1718867', '22118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22118', '112', '23995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1718867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23996', '1079', '1', 'Candoni', 'PH.H3.1719247', 'ASCII:Candoni;ID:1719247', '22119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22119', '112', '23996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1719247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23997', '1079', '1', 'Candon', 'PH.29.1719252', 'ASCII:Candon;ID:1719252', '22120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22120', '112', '23997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1719252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23998', '1079', '1', 'Candijay', 'PH.11.1719263', 'ASCII:Candijay;ID:1719263', '22121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22121', '112', '23998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1719263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('23999', '1079', '1', 'Candelaria', 'PH.64.1719277', 'ASCII:Candelaria;ID:1719277', '22122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22122', '112', '23999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1719277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24000', '1079', '1', 'Candelaria', 'PH.H2.1719278', 'ASCII:Candelaria;ID:1719278', '22123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22123', '112', '24000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1719278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24001', '1079', '1', 'Candaba', 'PH.50.1719330', 'ASCII:Candaba;ID:1719330', '22124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22124', '112', '24001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1719330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24002', '1079', '1', 'Can-Avid', 'PH.23.1719396', 'ASCII:Can-Avid;ID:1719396', '22125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22125', '112', '24002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1719396» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24003', '1079', '1', 'Canaman', 'PH.16.1719464', 'ASCII:Canaman;ID:1719464', '22126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22126', '112', '24003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1719464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24004', '1079', '1', 'Camiling', 'PH.63.1719685', 'ASCII:Camiling;ID:1719685', '22127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22127', '112', '24004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1719685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24005', '1079', '1', 'Camaligan', 'PH.16.1719933', 'ASCII:Camaligan;ID:1719933', '22128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22128', '112', '24005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1719933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24006', '1079', '1', 'Camalig', 'PH.05.1719937', 'ASCII:Camalig;ID:1719937', '22129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22129', '112', '24006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1719937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24007', '1079', '1', 'Camalaniugan', 'PH.14.1719941', 'ASCII:Camalaniugan;ID:1719941', '22130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22130', '112', '24007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1719941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24008', '1079', '1', 'Caluya', 'PH.06.1719993', 'ASCII:Caluya;ID:1719993', '22131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22131', '112', '24008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1719993» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24009', '1079', '1', 'Calumpit', 'PH.13.1720038', 'ASCII:Calumpit;ID:1720038', '22132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22132', '112', '24009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1720038» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24010', '1079', '1', 'Calubian', 'PH.37.1720107', 'ASCII:Calubian;ID:1720107', '22133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22133', '112', '24010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1720107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24011', '1079', '1', 'Calintaan', 'PH.40.1720272', 'ASCII:Calintaan;ID:1720272', '22134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22134', '112', '24011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1720272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24012', '1079', '1', 'Calinog', 'PH.30.1720276', 'ASCII:Calinog;ID:1720276', '22135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22135', '112', '24012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1720276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24013', '1079', '1', 'Calbiga', 'PH.55.1720398', 'ASCII:Calbiga;ID:1720398', '22136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22136', '112', '24013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1720398» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24014', '1079', '1', 'Calayan', 'PH.14.1720428', 'ASCII:Calayan;ID:1720428', '22137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22137', '112', '24014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1720428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24015', '1079', '1', 'Calauan', 'PH.33.1720467', 'ASCII:Calauan;ID:1720467', '22138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22138', '112', '24015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1720467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24016', '1079', '1', 'Calauag', 'PH.H2.1720475', 'ASCII:Calauag;ID:1720475', '22139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22139', '112', '24016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1720475» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24017', '1079', '1', 'Calatrava', 'PH.54.1720483', 'ASCII:Calatrava;ID:1720483', '22140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22140', '112', '24017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1720483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24018', '1079', '1', 'Calatrava', 'PH.H3.1720484', 'ASCII:Calatrava;ID:1720484', '22141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22141', '112', '24018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H3.1720484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24019', '1079', '1', 'Calatagan', 'PH.09.1720503', 'ASCII:Calatagan;ID:1720503', '22142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22142', '112', '24019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1720503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24020', '1079', '1', 'Calasiao', 'PH.51.1720509', 'ASCII:Calasiao;ID:1720509', '22143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22143', '112', '24020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1720509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24021', '1079', '1', 'Calape', 'PH.11.1720543', 'ASCII:Calape;ID:1720543', '22144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22144', '112', '24021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1720543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24022', '1079', '1', 'Calapan', 'PH.41.1720563', 'ASCII:Calapan;ID:1720563', '22145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22145', '112', '24022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1720563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24023', '1079', '1', 'Calanogas', 'PH.35.1720600', 'ASCII:Calanogas;ID:1720600', '22146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22146', '112', '24023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1720600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24024', '1079', '1', 'Calanasan', 'PH.32.1720644', 'ASCII:Calanasan;ID:1720644', '22147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22147', '112', '24024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1720644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24025', '1079', '1', 'Calamba', 'PH.33.1720685', 'ASCII:Calamba;ID:1720685', '22148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22148', '112', '24025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1720685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24026', '1079', '1', 'Municipality of Calamba', 'PH.42.1720686', 'ASCII:Municipality of Calamba;ID:1720686', '22149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22149', '112', '24026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1720686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24027', '1079', '1', 'Calaca', 'PH.09.1720752', 'ASCII:Calaca;ID:1720752', '22150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22150', '112', '24027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1720752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24028', '1079', '1', 'Calabanga', 'PH.16.1720794', 'ASCII:Calabanga;ID:1720794', '22151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22151', '112', '24028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1720794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24029', '1079', '1', 'Cajidiocan', 'PH.54.1720824', 'ASCII:Cajidiocan;ID:1720824', '22152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22152', '112', '24029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1720824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24030', '1079', '1', 'Cainta', 'PH.53.1720841', 'ASCII:Cainta;ID:1720841', '22153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22153', '112', '24030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1720841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24031', '1079', '1', 'Caibiran', 'PH.37.1720872', 'ASCII:Caibiran;ID:1720872', '22154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22154', '112', '24031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1720872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24032', '1079', '1', 'Cagwait', 'PH.62.1720908', 'ASCII:Cagwait;ID:1720908', '22155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22155', '112', '24032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1720908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24033', '1079', '1', 'Cagdianao', 'PH.61.1721011', 'ASCII:Cagdianao;ID:1721011', '22156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22156', '112', '24033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1721011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24034', '1079', '1', 'Cagayan de Tawi-Tawi', 'PH.72.1721078', 'ASCII:Cagayan de Tawi-Tawi;ID:1721078', '22157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22157', '112', '24034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.72.1721078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24035', '1079', '1', 'Cagayancillo', 'PH.49.1721083', 'ASCII:Cagayancillo;ID:1721083', '22158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22158', '112', '24035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1721083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24036', '1079', '1', 'Cabuyao', 'PH.33.1721286', 'ASCII:Cabuyao;ID:1721286', '22159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22159', '112', '24036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1721286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24037', '1079', '1', 'Cabusao', 'PH.16.1721298', 'ASCII:Cabusao;ID:1721298', '22160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22160', '112', '24037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1721298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24038', '1079', '1', 'Cabugao', 'PH.29.1721454', 'ASCII:Cabugao;ID:1721454', '22161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22161', '112', '24038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1721454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24039', '1079', '1', 'Cabucgayan', 'PH.37.1721471', 'ASCII:Cabucgayan;ID:1721471', '22162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22162', '112', '24039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1721471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24040', '1079', '1', 'Cabiao', 'PH.47.1721637', 'ASCII:Cabiao;ID:1721637', '22163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22163', '112', '24040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1721637» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24041', '1079', '1', 'Cabatuan', 'PH.31.1721722', 'ASCII:Cabatuan;ID:1721722', '22164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22164', '112', '24041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1721722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24042', '1079', '1', 'Cabatuan', 'PH.30.1721723', 'ASCII:Cabatuan;ID:1721723', '22165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22165', '112', '24042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1721723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24043', '1079', '1', 'Cabarroguis', 'PH.68.1721778', 'ASCII:Cabarroguis;ID:1721778', '22166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22166', '112', '24043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.68.1721778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24044', '1079', '1', 'Cabanglasan', 'PH.12.1721861', 'ASCII:Cabanglasan;ID:1721861', '22167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22167', '112', '24044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1721861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24045', '1079', '1', 'Cabangan', 'PH.64.1721879', 'ASCII:Cabangan;ID:1721879', '22168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22168', '112', '24045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1721879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24046', '1079', '1', 'Cabagan', 'PH.31.1722006', 'ASCII:Cabagan;ID:1722006', '22169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22169', '112', '24046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1722006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24047', '1079', '1', 'Cabadbaran', 'PH.02.1722033', 'ASCII:Cabadbaran;ID:1722033', '22170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22170', '112', '24047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.02.1722033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24048', '1079', '1', 'Caba', 'PH.36.1722069', 'ASCII:Caba;ID:1722069', '22171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22171', '112', '24048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1722069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24049', '1079', '1', 'Buug', 'PH.66.1722168', 'ASCII:Buug;ID:1722168', '22172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22172', '112', '24049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1722168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24050', '1079', '1', 'Butig', 'PH.35.1722218', 'ASCII:Butig;ID:1722218', '22173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22173', '112', '24050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1722218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24051', '1079', '1', 'Busuanga', 'PH.49.1722264', 'ASCII:Busuanga;ID:1722264', '22174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22174', '112', '24051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1722264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24052', '1079', '1', 'Bustos', 'PH.13.1722268', 'ASCII:Bustos;ID:1722268', '22175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22175', '112', '24052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1722268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24053', '1079', '1', 'Buruanga', 'PH.04.1722366', 'ASCII:Buruanga;ID:1722366', '22176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22176', '112', '24053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1722366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24054', '1079', '1', 'Burgos', 'PH.28.1722459', 'ASCII:Burgos;ID:1722459', '22177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22177', '112', '24054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1722459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24055', '1079', '1', 'Burgos', 'PH.29.1722460', 'ASCII:Burgos;ID:1722460', '22178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22178', '112', '24055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1722460» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24056', '1079', '1', 'Burgos', 'PH.31.1722461', 'ASCII:Burgos;ID:1722461', '22179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22179', '112', '24056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1722461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24057', '1079', '1', 'Burgos', 'PH.36.1722462', 'ASCII:Burgos;ID:1722462', '22180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22180', '112', '24057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1722462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24058', '1079', '1', 'Burgos', 'PH.51.1722463', 'ASCII:Burgos;ID:1722463', '22181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22181', '112', '24058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1722463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24059', '1079', '1', 'Burgos', 'PH.61.1722464', 'ASCII:Burgos;ID:1722464', '22182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22182', '112', '24059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1722464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24060', '1079', '1', 'Burdeos', 'PH.H2.1722468', 'ASCII:Burdeos;ID:1722468', '22183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22183', '112', '24060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1722468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24061', '1079', '1', 'Burauen', 'PH.37.1722482', 'ASCII:Burauen;ID:1722482', '22184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22184', '112', '24061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1722482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24062', '1079', '1', 'Bunawan', 'PH.03.1722733', 'ASCII:Bunawan;ID:1722733', '22185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22185', '112', '24062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.1722733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24063', '1079', '1', 'Bumbaran', 'PH.35.1722752', 'ASCII:Bumbaran;ID:1722752', '22186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22186', '112', '24063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1722752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24064', '1079', '1', 'Bulusan', 'PH.58.1722770', 'ASCII:Bulusan;ID:1722770', '22187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22187', '112', '24064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1722770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24065', '1079', '1', 'Buluan', 'PH.56.1722820', 'ASCII:Buluan;ID:1722820', '22188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22188', '112', '24065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1722820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24066', '1079', '1', 'Buldon', 'PH.56.1722910', 'ASCII:Buldon;ID:1722910', '22189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22189', '112', '24066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1722910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24067', '1079', '1', 'Bulan', 'PH.58.1722989', 'ASCII:Bulan;ID:1722989', '22190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22190', '112', '24067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1722989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24068', '1079', '1', 'Bulalakao', 'PH.41.1723004', 'ASCII:Bulalakao;ID:1723004', '22191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22191', '112', '24068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1723004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24069', '1079', '1', 'Bulacan', 'PH.13.1723071', 'ASCII:Bulacan;ID:1723071', '22192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22192', '112', '24069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1723071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24070', '1079', '1', 'Bula', 'PH.16.1723089', 'ASCII:Bula;ID:1723089', '22193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22193', '112', '24070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1723089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24071', '1079', '1', 'Buhi', 'PH.16.1723167', 'ASCII:Buhi;ID:1723167', '22194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22194', '112', '24071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1723167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24072', '1079', '1', 'Buguias', 'PH.10.1723213', 'ASCII:Buguias;ID:1723213', '22195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22195', '112', '24072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1723213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24073', '1079', '1', 'Buguey', 'PH.14.1723217', 'ASCII:Buguey;ID:1723217', '22196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22196', '112', '24073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1723217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24074', '1079', '1', 'Bugasong', 'PH.06.1723314', 'ASCII:Bugasong;ID:1723314', '22197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22197', '112', '24074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1723314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24075', '1079', '1', 'Bugallon', 'PH.51.1723338', 'ASCII:Bugallon;ID:1723338', '22198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22198', '112', '24075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1723338» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24076', '1079', '1', 'Buenavista', 'PH.H2.1723486', 'ASCII:Buenavista;ID:1723486', '22199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22199', '112', '24076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1723486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24077', '1079', '1', 'Buenavista', 'PH.38.1723487', 'ASCII:Buenavista;ID:1723487', '22200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22200', '112', '24077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.38.1723487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24078', '1079', '1', 'Buenavista', 'PH.30.1723488', 'ASCII:Buenavista;ID:1723488', '22201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22201', '112', '24078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1723488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24079', '1079', '1', 'Buenavista', 'PH.11.1723489', 'ASCII:Buenavista;ID:1723489', '22202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22202', '112', '24079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1723489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24080', '1079', '1', 'Buenavista', 'PH.02.1723490', 'ASCII:Buenavista;ID:1723490', '22203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22203', '112', '24080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.02.1723490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24081', '1079', '1', 'Bucloc', 'PH.01.1723553', 'ASCII:Bucloc;ID:1723553', '22204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22204', '112', '24081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1723553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24082', '1079', '1', 'Bucay', 'PH.01.1723570', 'ASCII:Bucay;ID:1723570', '22205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22205', '112', '24082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1723570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24083', '1079', '1', 'Bubong', 'PH.35.1723657', 'ASCII:Bubong;ID:1723657', '22206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22206', '112', '24083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1723657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24084', '1079', '1', 'Buadiposo-Buntong', 'PH.35.1723740', 'ASCII:Buadiposo-Buntong;ID:1723740', '22207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22207', '112', '24084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1723740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24085', '1079', '1', 'Brooke”s Point', 'PH.49.1723764', 'ASCII:Brooke"s Point;ID:1723764', '22208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22208', '112', '24085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1723764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24086', '1079', '1', 'Botolan', 'PH.64.1723823', 'ASCII:Botolan;ID:1723823', '22209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22209', '112', '24086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.64.1723823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24087', '1079', '1', 'Boston', 'PH.26.1723863', 'ASCII:Boston;ID:1723863', '22210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22210', '112', '24087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1723863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24088', '1079', '1', 'Borongan', 'PH.23.1723894', 'ASCII:Borongan;ID:1723894', '22211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22211', '112', '24088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1723894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24089', '1079', '1', 'Borbon', 'PH.21.1723928', 'ASCII:Borbon;ID:1723928', '22212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22212', '112', '24089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1723928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24090', '1079', '1', 'Bontoc', 'PH.44.1723986', 'ASCII:Bontoc;ID:1723986', '22213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22213', '112', '24090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.44.1723986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24091', '1079', '1', 'Bontoc', 'PH.59.1723987', 'ASCII:Bontoc;ID:1723987', '22214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22214', '112', '24091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1723987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24092', '1079', '1', 'Bonifacio', 'PH.42.1724029', 'ASCII:Bonifacio;ID:1724029', '22215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22215', '112', '24092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1724029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24093', '1079', '1', 'Bongao', 'PH.72.1724089', 'ASCII:Bongao;ID:1724089', '22216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22216', '112', '24093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.72.1724089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24094', '1079', '1', 'Bongabong', 'PH.41.1724105', 'ASCII:Bongabong;ID:1724105', '22217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22217', '112', '24094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1724105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24095', '1079', '1', 'Bongabon', 'PH.47.1724107', 'ASCII:Bongabon;ID:1724107', '22218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22218', '112', '24095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1724107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24096', '1079', '1', 'Bombon', 'PH.16.1724205', 'ASCII:Bombon;ID:1724205', '22219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22219', '112', '24096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1724205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24097', '1079', '1', 'Boljoon', 'PH.21.1724298', 'ASCII:Boljoon;ID:1724298', '22220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22220', '112', '24097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1724298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24098', '1079', '1', 'Boliney', 'PH.01.1724310', 'ASCII:Boliney;ID:1724310', '22221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22221', '112', '24098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1724310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24099', '1079', '1', 'Bolinao', 'PH.51.1724319', 'ASCII:Bolinao;ID:1724319', '22222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22222', '112', '24099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1724319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24100', '1079', '1', 'Bokod', 'PH.10.1724379', 'ASCII:Bokod;ID:1724379', '22223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22223', '112', '24100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1724379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24101', '1079', '1', 'Bogo', 'PH.21.1724439', 'ASCII:Bogo;ID:1724439', '22224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22224', '112', '24101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1724439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24102', '1079', '1', 'Bocaue', 'PH.13.1724490', 'ASCII:Bocaue;ID:1724490', '22225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22225', '112', '24102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1724490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24103', '1079', '1', 'Bobon', 'PH.67.1724545', 'ASCII:Bobon;ID:1724545', '22226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22226', '112', '24103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1724545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24104', '1079', '1', 'Boac', 'PH.38.1724578', 'ASCII:Boac;ID:1724578', '22227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22227', '112', '24104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.38.1724578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24105', '1079', '1', 'Bislig', 'PH.62.1724769', 'ASCII:Bislig;ID:1724769', '22228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22228', '112', '24105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1724769» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24106', '1079', '1', 'Biri', 'PH.67.1724805', 'ASCII:Biri;ID:1724805', '22229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22229', '112', '24106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1724805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24107', '1079', '1', 'Binuangan', 'PH.43.1724879', 'ASCII:Binuangan;ID:1724879', '22230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22230', '112', '24107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1724879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24108', '1079', '1', 'Binmaley', 'PH.51.1724957', 'ASCII:Binmaley;ID:1724957', '22231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22231', '112', '24108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1724957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24109', '1079', '1', 'Binidayan', 'PH.35.1724984', 'ASCII:Binidayan;ID:1724984', '22232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22232', '112', '24109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1724984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24110', '1079', '1', 'Bingawan', 'PH.30.1725012', 'ASCII:Bingawan;ID:1725012', '22233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22233', '112', '24110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1725012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24111', '1079', '1', 'Bindoy', 'PH.46.1725030', 'ASCII:Bindoy;ID:1725030', '22234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22234', '112', '24111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1725030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24112', '1079', '1', 'Binangonan', 'PH.53.1725095', 'ASCII:Binangonan;ID:1725095', '22235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22235', '112', '24112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1725095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24113', '1079', '1', 'Biñan', 'PH.33.1725117', 'ASCII:Binan;ID:1725117', '22236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22236', '112', '24113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1725117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24114', '1079', '1', 'Binalonan', 'PH.51.1725128', 'ASCII:Binalonan;ID:1725128', '22237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22237', '112', '24114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1725128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24115', '1079', '1', 'Binalbagan', 'PH.45.1725158', 'ASCII:Binalbagan;ID:1725158', '22238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22238', '112', '24115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.45.1725158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24116', '1079', '1', 'Biliran', 'PH.37.1725260', 'ASCII:Biliran;ID:1725260', '22239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22239', '112', '24116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1725260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24117', '1079', '1', 'Bilar', 'PH.11.1725295', 'ASCII:Bilar;ID:1725295', '22240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22240', '112', '24117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1725295» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24118', '1079', '1', 'Besao', 'PH.44.1725539', 'ASCII:Besao;ID:1725539', '22241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22241', '112', '24118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.44.1725539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24119', '1079', '1', 'Benito Soliven', 'PH.31.1725573', 'ASCII:Benito Soliven;ID:1725573', '22242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22242', '112', '24119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1725573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24120', '1079', '1', 'Belison', 'PH.06.1725610', 'ASCII:Belison;ID:1725610', '22243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22243', '112', '24120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1725610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24121', '1079', '1', 'Bayugan', 'PH.03.1725685', 'ASCII:Bayugan;ID:1725685', '22244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22244', '112', '24121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.1725685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24122', '1079', '1', 'Bayombong', 'PH.48.1725731', 'ASCII:Bayombong;ID:1725731', '22245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22245', '112', '24122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1725731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24123', '1079', '1', 'Bayog', 'PH.66.1725750', 'ASCII:Bayog;ID:1725750', '22246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22246', '112', '24123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1725750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24124', '1079', '1', 'Baybay', 'PH.37.1725800', 'ASCII:Baybay;ID:1725800', '22247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22247', '112', '24124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1725800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24125', '1079', '1', 'Bayawan', 'PH.46.1725805', 'ASCII:Bayawan;ID:1725805', '22248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22248', '112', '24125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1725805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24126', '1079', '1', 'Bayang', 'PH.35.1725845', 'ASCII:Bayang;ID:1725845', '22249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22249', '112', '24126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1725845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24127', '1079', '1', 'Bayambang', 'PH.51.1725864', 'ASCII:Bayambang;ID:1725864', '22250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22250', '112', '24127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1725864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24128', '1079', '1', 'Bayabas', 'PH.62.1725910', 'ASCII:Bayabas;ID:1725910', '22251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22251', '112', '24128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1725910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24129', '1079', '1', 'Bay', 'PH.33.1725921', 'ASCII:Bay;ID:1725921', '22252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22252', '112', '24129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1725921» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24130', '1079', '1', 'Bautista', 'PH.51.1725945', 'ASCII:Bautista;ID:1725945', '22253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22253', '112', '24130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1725945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24131', '1079', '1', 'Baungon', 'PH.12.1725950', 'ASCII:Baungon;ID:1725950', '22254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22254', '112', '24131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.1725950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24132', '1079', '1', 'Bauko', 'PH.44.1725954', 'ASCII:Bauko;ID:1725954', '22255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22255', '112', '24132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.44.1725954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24133', '1079', '1', 'Bauang', 'PH.36.1725987', 'ASCII:Bauang;ID:1725987', '22256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22256', '112', '24133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1725987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24134', '1079', '1', 'Bauan', 'PH.09.1725992', 'ASCII:Bauan;ID:1725992', '22257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22257', '112', '24134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1725992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24135', '1079', '1', 'Batuan', 'PH.39.1726065', 'ASCII:Batuan;ID:1726065', '22258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22258', '112', '24135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1726065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24136', '1079', '1', 'Batuan', 'PH.11.1726066', 'ASCII:Batuan;ID:1726066', '22259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22259', '112', '24136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1726066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24137', '1079', '1', 'Bato', 'PH.19.1726187', 'ASCII:Bato;ID:1726187', '22260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22260', '112', '24137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1726187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24138', '1079', '1', 'Bato', 'PH.16.1726188', 'ASCII:Bato;ID:1726188', '22261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22261', '112', '24138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1726188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24139', '1079', '1', 'Bato', 'PH.37.1726189', 'ASCII:Bato;ID:1726189', '22262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22262', '112', '24139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1726189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24140', '1079', '1', 'Batarasa', 'PH.49.1726257', 'ASCII:Batarasa;ID:1726257', '22263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22263', '112', '24140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1726257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24141', '1079', '1', 'Batan', 'PH.04.1726315', 'ASCII:Batan;ID:1726315', '22264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22264', '112', '24141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1726315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24142', '1079', '1', 'Batad', 'PH.30.1726334', 'ASCII:Batad;ID:1726334', '22265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22265', '112', '24142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1726334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24143', '1079', '1', 'Batac', 'PH.28.1726340', 'ASCII:Batac;ID:1726340', '22266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22266', '112', '24143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1726340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24144', '1079', '1', 'Basud', 'PH.15.1726364', 'ASCII:Basud;ID:1726364', '22267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22267', '112', '24144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.15.1726364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24145', '1079', '1', 'Basista', 'PH.51.1726386', 'ASCII:Basista;ID:1726386', '22268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22268', '112', '24145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1726386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24146', '1079', '1', 'Basilisa', 'PH.61.1726397', 'ASCII:Basilisa;ID:1726397', '22269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22269', '112', '24146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1726397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24147', '1079', '1', 'Basey', 'PH.55.1726437', 'ASCII:Basey;ID:1726437', '22270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22270', '112', '24147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1726437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24148', '1079', '1', 'Basco', 'PH.08.1726451', 'ASCII:Basco;ID:1726451', '22271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22271', '112', '24148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.08.1726451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24149', '1079', '1', 'Basay', 'PH.46.1726467', 'ASCII:Basay;ID:1726467', '22272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22272', '112', '24149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1726467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24150', '1079', '1', 'Barugo', 'PH.37.1726549', 'ASCII:Barugo;ID:1726549', '22273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22273', '112', '24150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1726549» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24151', '1079', '1', 'Baroy', 'PH.34.1726587', 'ASCII:Baroy;ID:1726587', '22274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22274', '112', '24151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.1726587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24152', '1079', '1', 'Barotac Viejo', 'PH.30.1726592', 'ASCII:Barotac Viejo;ID:1726592', '22275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22275', '112', '24152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1726592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24153', '1079', '1', 'Barotac Neuvo', 'PH.30.1726595', 'ASCII:Barotac Neuvo;ID:1726595', '22276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22276', '112', '24153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1726595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24154', '1079', '1', 'Barobo', 'PH.62.1726624', 'ASCII:Barobo;ID:1726624', '22277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22277', '112', '24154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.62.1726624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24155', '1079', '1', 'Barlig', 'PH.44.1726631', 'ASCII:Barlig;ID:1726631', '22278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22278', '112', '24155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.44.1726631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24156', '1079', '1', 'Barira', 'PH.56.1726656', 'ASCII:Barira;ID:1726656', '22279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22279', '112', '24156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1726656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24157', '1079', '1', 'Barili', 'PH.21.1726671', 'ASCII:Barili;ID:1726671', '22280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22280', '112', '24157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1726671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24158', '1079', '1', 'Barcelona', 'PH.58.1726709', 'ASCII:Barcelona;ID:1726709', '22281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22281', '112', '24158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1726709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24159', '1079', '1', 'Barbaza', 'PH.06.1726715', 'ASCII:Barbaza;ID:1726715', '22282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22282', '112', '24159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1726715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24160', '1079', '1', 'Baras', 'PH.53.1726781', 'ASCII:Baras;ID:1726781', '22283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22283', '112', '24160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1726781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24161', '1079', '1', 'Baras', 'PH.19.1726782', 'ASCII:Baras;ID:1726782', '22284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22284', '112', '24161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1726782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24162', '1079', '1', 'Banton', 'PH.54.1726962', 'ASCII:Banton;ID:1726962', '22285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22285', '112', '24162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1726962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24163', '1079', '1', 'Bantayan', 'PH.21.1727048', 'ASCII:Bantayan;ID:1727048', '22286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22286', '112', '24163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1727048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24164', '1079', '1', 'Bantay', 'PH.29.1727057', 'ASCII:Bantay;ID:1727057', '22287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22287', '112', '24164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1727057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24165', '1079', '1', 'Bansud', 'PH.41.1727074', 'ASCII:Bansud;ID:1727074', '22288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22288', '112', '24165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1727074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24166', '1079', '1', 'Bansalan', 'PH.25.1727081', 'ASCII:Bansalan;ID:1727081', '22289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22289', '112', '24166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.1727081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24167', '1079', '1', 'Bani', 'PH.51.1727200', 'ASCII:Bani;ID:1727200', '22290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22290', '112', '24167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1727200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24168', '1079', '1', 'Bangui', 'PH.28.1727212', 'ASCII:Bangui;ID:1727212', '22291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22291', '112', '24168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1727212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24169', '1079', '1', 'Bangued', 'PH.01.1727216', 'ASCII:Bangued;ID:1727216', '22292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22292', '112', '24169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.01.1727216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24170', '1079', '1', 'Bangar', 'PH.36.1727330', 'ASCII:Bangar;ID:1727330', '22293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22293', '112', '24170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1727330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24171', '1079', '1', 'Banga', 'PH.04.1727402', 'ASCII:Banga;ID:1727402', '22294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22294', '112', '24171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1727402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24172', '1079', '1', 'Banga', 'PH.70.1727403', 'ASCII:Banga;ID:1727403', '22295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22295', '112', '24172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1727403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24173', '1079', '1', 'Banayoyo', 'PH.29.1727514', 'ASCII:Banayoyo;ID:1727514', '22296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22296', '112', '24173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1727514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24174', '1079', '1', 'Banaybanay', 'PH.26.1727525', 'ASCII:Banaybanay;ID:1727525', '22297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22297', '112', '24174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1727525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24175', '1079', '1', 'Banaue', 'PH.27.1727538', 'ASCII:Banaue;ID:1727538', '22298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22298', '112', '24175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.27.1727538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24176', '1079', '1', 'Banate', 'PH.30.1727546', 'ASCII:Banate;ID:1727546', '22299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22299', '112', '24176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1727546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24177', '1079', '1', 'Bambang', 'PH.48.1727673', 'ASCII:Bambang;ID:1727673', '22300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22300', '112', '24177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1727673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24178', '1079', '1', 'Bamban', 'PH.63.1727690', 'ASCII:Bamban;ID:1727690', '22301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22301', '112', '24178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1727690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24179', '1079', '1', 'Balungao', 'PH.51.1727736', 'ASCII:Balungao;ID:1727736', '22302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22302', '112', '24179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1727736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24180', '1079', '1', 'Balud', 'PH.39.1727794', 'ASCII:Balud;ID:1727794', '22303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22303', '112', '24180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1727794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24181', '1079', '1', 'Ballesteros', 'PH.14.1727964', 'ASCII:Ballesteros;ID:1727964', '22304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22304', '112', '24181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1727964» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24182', '1079', '1', 'Baliuag', 'PH.13.1727996', 'ASCII:Baliuag;ID:1727996', '22305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22305', '112', '24182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1727996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24183', '1079', '1', 'Balingoan', 'PH.43.1728083', 'ASCII:Balingoan;ID:1728083', '22306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22306', '112', '24183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1728083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24184', '1079', '1', 'Balingasag', 'PH.43.1728099', 'ASCII:Balingasag;ID:1728099', '22307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22307', '112', '24184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1728099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24185', '1079', '1', 'Balindong', 'PH.35.1728104', 'ASCII:Balindong;ID:1728104', '22308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22308', '112', '24185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1728104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24186', '1079', '1', 'Balimbing', 'PH.72.1728126', 'ASCII:Balimbing;ID:1728126', '22309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22309', '112', '24186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.72.1728126» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24187', '1079', '1', 'Balilihan', 'PH.11.1728135', 'ASCII:Balilihan;ID:1728135', '22310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22310', '112', '24187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1728135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24188', '1079', '1', 'Baliangao', 'PH.42.1728216', 'ASCII:Baliangao;ID:1728216', '22311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22311', '112', '24188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1728216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24189', '1079', '1', 'Balete', 'PH.09.1728254', 'ASCII:Balete;ID:1728254', '22312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22312', '112', '24189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1728254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24190', '1079', '1', 'Balete', 'PH.04.1728255', 'ASCII:Balete;ID:1728255', '22313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22313', '112', '24190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1728255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24191', '1079', '1', 'Baler', 'PH.G8.1728266', 'ASCII:Baler;ID:1728266', '22314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22314', '112', '24191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.G8.1728266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24192', '1079', '1', 'Baleno', 'PH.39.1728273', 'ASCII:Baleno;ID:1728273', '22315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22315', '112', '24192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1728273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24193', '1079', '1', 'Balbalan', 'PH.32.1728306', 'ASCII:Balbalan;ID:1728306', '22316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22316', '112', '24193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.32.1728306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24194', '1079', '1', 'Balayan', 'PH.09.1728337', 'ASCII:Balayan;ID:1728337', '22317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22317', '112', '24194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1728337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24195', '1079', '1', 'Balatan', 'PH.16.1728391', 'ASCII:Balatan;ID:1728391', '22318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22318', '112', '24195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1728391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24196', '1079', '1', 'Balasan', 'PH.30.1728412', 'ASCII:Balasan;ID:1728412', '22319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22319', '112', '24196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1728412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24197', '1079', '1', 'Balaoan', 'PH.36.1728440', 'ASCII:Balaoan;ID:1728440', '22320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22320', '112', '24197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1728440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24198', '1079', '1', 'Balangkayan', 'PH.23.1728494', 'ASCII:Balangkayan;ID:1728494', '22321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22321', '112', '24198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1728494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24199', '1079', '1', 'Balangiga', 'PH.23.1728501', 'ASCII:Balangiga;ID:1728501', '22322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22322', '112', '24199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1728501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24200', '1079', '1', 'Balanga', 'PH.07.1728527', 'ASCII:Balanga;ID:1728527', '22323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22323', '112', '24200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1728527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24201', '1079', '1', 'Balamban', 'PH.21.1728547', 'ASCII:Balamban;ID:1728547', '22324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22324', '112', '24201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1728547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24202', '1079', '1', 'Balagtas', 'PH.13.1728587', 'ASCII:Balagtas;ID:1728587', '22325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22325', '112', '24202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1728587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24203', '1079', '1', 'Balabagan', 'PH.35.1728655', 'ASCII:Balabagan;ID:1728655', '22326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22326', '112', '24203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1728655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24204', '1079', '1', 'Balabac', 'PH.49.1728677', 'ASCII:Balabac;ID:1728677', '22327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22327', '112', '24204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1728677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24205', '1079', '1', 'Bakun', 'PH.10.1728690', 'ASCII:Bakun;ID:1728690', '22328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22328', '112', '24205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1728690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24206', '1079', '1', 'Bagumbayan', 'PH.71.1728908', 'ASCII:Bagumbayan;ID:1728908', '22329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22329', '112', '24206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.71.1728908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24207', '1079', '1', 'Bagulin', 'PH.30.1728915', 'ASCII:Bagulin;ID:1728915', '22330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22330', '112', '24207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1728915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24208', '1079', '1', 'Baggao', 'PH.14.1729120', 'ASCII:Baggao;ID:1729120', '22331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22331', '112', '24208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1729120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24209', '1079', '1', 'Baganga', 'PH.26.1729185', 'ASCII:Baganga;ID:1729185', '22332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22332', '112', '24209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.26.1729185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24210', '1079', '1', 'Bagamanoc', 'PH.19.1729196', 'ASCII:Bagamanoc;ID:1729196', '22333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22333', '112', '24210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.19.1729196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24211', '1079', '1', 'Bagac', 'PH.07.1729311', 'ASCII:Bagac;ID:1729311', '22334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22334', '112', '24211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1729311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24212', '1079', '1', 'Bagabag', 'PH.48.1729326', 'ASCII:Bagabag;ID:1729326', '22335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22335', '112', '24212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1729326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24213', '1079', '1', 'Badoc', 'PH.28.1729358', 'ASCII:Badoc;ID:1729358', '22336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22336', '112', '24213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1729358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24214', '1079', '1', 'Badiangan', 'PH.30.1729391', 'ASCII:Badiangan;ID:1729391', '22337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22337', '112', '24214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1729391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24215', '1079', '1', 'Badian', 'PH.21.1729413', 'ASCII:Badian;ID:1729413', '22338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22338', '112', '24215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1729413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24216', '1079', '1', 'Bacuag', 'PH.61.1729479', 'ASCII:Bacuag;ID:1729479', '22339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22339', '112', '24216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1729479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24217', '1079', '1', 'Bacoor', 'PH.20.1729525', 'ASCII:Bacoor;ID:1729525', '22340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22340', '112', '24217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1729525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24218', '1079', '1', 'Bacong', 'PH.46.1729553', 'ASCII:Bacong;ID:1729553', '22341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22341', '112', '24218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1729553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24219', '1079', '1', 'Bacon', 'PH.58.1729555', 'ASCII:Bacon;ID:1729555', '22342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22342', '112', '24219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.58.1729555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24220', '1079', '1', 'Bacolor', 'PH.50.1729558', 'ASCII:Bacolor;ID:1729558', '22343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22343', '112', '24220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1729558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24221', '1079', '1', 'Bacolod Grande', 'PH.35.1729563', 'ASCII:Bacolod Grande;ID:1729563', '22344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22344', '112', '24221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.1729563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24222', '1079', '1', 'Baco', 'PH.41.1729593', 'ASCII:Baco;ID:1729593', '22345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22345', '112', '24222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.41.1729593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24223', '1079', '1', 'Bacnotan', 'PH.36.1729595', 'ASCII:Bacnotan;ID:1729595', '22346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22346', '112', '24223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1729595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24224', '1079', '1', 'Baclayon', 'PH.11.1729606', 'ASCII:Baclayon;ID:1729606', '22347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22347', '112', '24224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1729606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24225', '1079', '1', 'Bacarra', 'PH.28.1729656', 'ASCII:Bacarra;ID:1729656', '22348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22348', '112', '24225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1729656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24226', '1079', '1', 'Bacacay', 'PH.05.1729702', 'ASCII:Bacacay;ID:1729702', '22349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22349', '112', '24226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.05.1729702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24227', '1079', '1', 'Babatñgon', 'PH.37.1729761', 'ASCII:Babatngon;ID:1729761', '22350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22350', '112', '24227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1729761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24228', '1079', '1', 'Babak', 'PH.24.1729786', 'ASCII:Babak;ID:1729786', '22351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22351', '112', '24228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1729786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24229', '1079', '1', 'Baao', 'PH.16.1729815', 'ASCII:Baao;ID:1729815', '22352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22352', '112', '24229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.16.1729815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24230', '1079', '1', 'Ayungon', 'PH.46.1729847', 'ASCII:Ayungon;ID:1729847', '22353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22353', '112', '24230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1729847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24231', '1079', '1', 'Aurora', 'PH.31.1729934', 'ASCII:Aurora;ID:1729934', '22354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22354', '112', '24231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1729934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24232', '1079', '1', 'Municipality of Aurora', 'PH.66.1729935', 'ASCII:Municipality of Aurora;ID:1729935', '22355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22355', '112', '24232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1729935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24233', '1079', '1', 'Atok', 'PH.10.1729970', 'ASCII:Atok;ID:1729970', '22356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22356', '112', '24233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.10.1729970» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24234', '1079', '1', 'Atimonan', 'PH.H2.1729988', 'ASCII:Atimonan;ID:1729988', '22357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22357', '112', '24234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1729988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24235', '1079', '1', 'Asuncion', 'PH.24.1730026', 'ASCII:Asuncion;ID:1730026', '22358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22358', '112', '24235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.24.1730026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24236', '1079', '1', 'Asturias', 'PH.21.1730034', 'ASCII:Asturias;ID:1730034', '22359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22359', '112', '24236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1730034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24237', '1079', '1', 'Asingan', 'PH.51.1730071', 'ASCII:Asingan;ID:1730071', '22360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22360', '112', '24237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1730071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24238', '1079', '1', 'Arteche', 'PH.23.1730125', 'ASCII:Arteche;ID:1730125', '22361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22361', '112', '24238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.23.1730125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24239', '1079', '1', 'Aroroy', 'PH.39.1730144', 'ASCII:Aroroy;ID:1730144', '22362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22362', '112', '24239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.39.1730144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24240', '1079', '1', 'Aritao', 'PH.48.1730163', 'ASCII:Aritao;ID:1730163', '22363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22363', '112', '24240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1730163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24241', '1079', '1', 'Aringay', 'PH.36.1730173', 'ASCII:Aringay;ID:1730173', '22364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22364', '112', '24241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1730173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24242', '1079', '1', 'Argao', 'PH.21.1730195', 'ASCII:Argao;ID:1730195', '22365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22365', '112', '24242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1730195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24243', '1079', '1', 'Arayat', 'PH.50.1730226', 'ASCII:Arayat;ID:1730226', '22366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22366', '112', '24243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1730226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24244', '1079', '1', 'Araceli', 'PH.49.1730273', 'ASCII:Araceli;ID:1730273', '22367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22367', '112', '24244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1730273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24245', '1079', '1', 'Aparri', 'PH.14.1730401', 'ASCII:Aparri;ID:1730401', '22368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22368', '112', '24245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1730401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24246', '1079', '1', 'Apalit', 'PH.50.1730414', 'ASCII:Apalit;ID:1730414', '22369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22369', '112', '24246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.50.1730414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24247', '1079', '1', 'Antipolo', 'PH.53.1730522', 'ASCII:Antipolo;ID:1730522', '22370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22370', '112', '24247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1730522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24248', '1079', '1', 'Antequera', 'PH.11.1730531', 'ASCII:Antequera;ID:1730531', '22371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22371', '112', '24248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1730531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24249', '1079', '1', 'Anini-y', 'PH.06.1730646', 'ASCII:Anini-y;ID:1730646', '22372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22372', '112', '24249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.06.1730646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24250', '1079', '1', 'Anilao', 'PH.30.1730667', 'ASCII:Anilao;ID:1730667', '22373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22373', '112', '24250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1730667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24251', '1079', '1', 'Angono', 'PH.53.1730714', 'ASCII:Angono;ID:1730714', '22374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22374', '112', '24251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.53.1730714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24252', '1079', '1', 'Angat', 'PH.13.1730750', 'ASCII:Angat;ID:1730750', '22375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22375', '112', '24252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.13.1730750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24253', '1079', '1', 'Angadanan', 'PH.31.1730772', 'ASCII:Angadanan;ID:1730772', '22376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22376', '112', '24253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1730772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24254', '1079', '1', 'Anda', 'PH.51.1730821', 'ASCII:Anda;ID:1730821', '22377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22377', '112', '24254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1730821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24255', '1079', '1', 'Anda', 'PH.11.1730822', 'ASCII:Anda;ID:1730822', '22378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22378', '112', '24255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1730822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24256', '1079', '1', 'Anao', 'PH.63.1730882', 'ASCII:Anao;ID:1730882', '22379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22379', '112', '24256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.63.1730882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24257', '1079', '1', 'Anahawan', 'PH.59.1730916', 'ASCII:Anahawan;ID:1730916', '22380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22380', '112', '24257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.59.1730916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24258', '1079', '1', 'Amulung', 'PH.14.1730957', 'ASCII:Amulung;ID:1730957', '22381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22381', '112', '24258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1730957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24259', '1079', '1', 'Ampatuan', 'PH.56.1730984', 'ASCII:Ampatuan;ID:1730984', '22382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22382', '112', '24259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.56.1730984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24260', '1079', '1', 'Amlan', 'PH.46.1731037', 'ASCII:Amlan;ID:1731037', '22383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22383', '112', '24260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.46.1731037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24261', '1079', '1', 'Ambaguio', 'PH.48.1731142', 'ASCII:Ambaguio;ID:1731142', '22384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22384', '112', '24261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1731142» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24262', '1079', '1', 'Amadeo', 'PH.20.1731214', 'ASCII:Amadeo;ID:1731214', '22385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22385', '112', '24262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1731214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24263', '1079', '1', 'Alubijid', 'PH.43.1731255', 'ASCII:Alubijid;ID:1731255', '22386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22386', '112', '24263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.1731255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24264', '1079', '1', 'Altavas', 'PH.04.1731277', 'ASCII:Altavas;ID:1731277', '22387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22387', '112', '24264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.04.1731277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24265', '1079', '1', 'Aloran', 'PH.42.1731289', 'ASCII:Aloran;ID:1731289', '22388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22388', '112', '24265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.1731289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24266', '1079', '1', 'Aloguinsan', 'PH.21.1731303', 'ASCII:Aloguinsan;ID:1731303', '22389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22389', '112', '24266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1731303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24267', '1079', '1', 'Almeria', 'PH.37.1731315', 'ASCII:Almeria;ID:1731315', '22390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22390', '112', '24267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1731315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24268', '1079', '1', 'Almagro', 'PH.55.1731325', 'ASCII:Almagro;ID:1731325', '22391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22391', '112', '24268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.55.1731325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24269', '1079', '1', 'Allen', 'PH.67.1731341', 'ASCII:Allen;ID:1731341', '22392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22392', '112', '24269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.67.1731341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24270', '1079', '1', 'Allacapan', 'PH.14.1731359', 'ASCII:Allacapan;ID:1731359', '22393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22393', '112', '24270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1731359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24271', '1079', '1', 'Alitagtag', 'PH.09.1731383', 'ASCII:Alitagtag;ID:1731383', '22394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22394', '112', '24271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1731383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24272', '1079', '1', 'Alimodian', 'PH.30.1731442', 'ASCII:Alimodian;ID:1731442', '22395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22395', '112', '24272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1731442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24273', '1079', '1', 'Alilem', 'PH.29.1731467', 'ASCII:Alilem;ID:1731467', '22396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22396', '112', '24273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.29.1731467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24274', '1079', '1', 'Alicia', 'PH.31.1731489', 'ASCII:Alicia;ID:1731489', '22397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22397', '112', '24274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.31.1731489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24275', '1079', '1', 'Alicia', 'PH.11.1731490', 'ASCII:Alicia;ID:1731490', '22398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22398', '112', '24275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1731490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24276', '1079', '1', 'Alicia', 'PH.66.1731491', 'ASCII:Alicia;ID:1731491', '22399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22399', '112', '24276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.1731491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24277', '1079', '1', 'Aliaga', 'PH.47.1731529', 'ASCII:Aliaga;ID:1731529', '22400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22400', '112', '24277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.47.1731529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24278', '1079', '1', 'Alfonso Castaneda', 'PH.48.1731535', 'ASCII:Alfonso Castaneda;ID:1731535', '22401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22401', '112', '24278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.48.1731535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24279', '1079', '1', 'Alfonso', 'PH.20.1731538', 'ASCII:Alfonso;ID:1731538', '22402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22402', '112', '24279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.20.1731538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24280', '1079', '1', 'Alegria', 'PH.21.1731575', 'ASCII:Alegria;ID:1731575', '22403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22403', '112', '24280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1731575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24281', '1079', '1', 'Alegria', 'PH.61.1731576', 'ASCII:Alegria;ID:1731576', '22404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22404', '112', '24281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.61.1731576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24282', '1079', '1', 'Alcoy', 'PH.21.1731587', 'ASCII:Alcoy;ID:1731587', '22405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22405', '112', '24282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1731587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24283', '1079', '1', 'Alcantara', 'PH.54.1731595', 'ASCII:Alcantara;ID:1731595', '22406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22406', '112', '24283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.54.1731595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24284', '1079', '1', 'Alcantara', 'PH.21.1731596', 'ASCII:Alcantara;ID:1731596', '22407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22407', '112', '24284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.21.1731596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24285', '1079', '1', 'Alcala', 'PH.14.1731600', 'ASCII:Alcala;ID:1731600', '22408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22408', '112', '24285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1731600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24286', '1079', '1', 'Alcala', 'PH.51.1731601', 'ASCII:Alcala;ID:1731601', '22409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22409', '112', '24286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1731601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24287', '1079', '1', 'Alburquerque', 'PH.11.1731605', 'ASCII:Alburquerque;ID:1731605', '22410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22410', '112', '24287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.11.1731605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24288', '1079', '1', 'Albuera', 'PH.37.1731609', 'ASCII:Albuera;ID:1731609', '22411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22411', '112', '24288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1731609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24289', '1079', '1', 'Alangalang', 'PH.37.1731680', 'ASCII:Alangalang;ID:1731680', '22412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22412', '112', '24289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1731680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24290', '1079', '1', 'Alaminos', 'PH.51.1731688', 'ASCII:Alaminos;ID:1731688', '22413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22413', '112', '24290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1731688» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24291', '1079', '1', 'Alaminos', 'PH.33.1731689', 'ASCII:Alaminos;ID:1731689', '22414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22414', '112', '24291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.33.1731689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24292', '1079', '1', 'Alamada', 'PH.57.1731695', 'ASCII:Alamada;ID:1731695', '22415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22415', '112', '24292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.57.1731695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24293', '1079', '1', 'Alabel', 'PH.70.1731745', 'ASCII:Alabel;ID:1731745', '22416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22416', '112', '24293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.1731745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24294', '1079', '1', 'Alabat', 'PH.H2.1731751', 'ASCII:Alabat;ID:1731751', '22417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22417', '112', '24294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1731751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24295', '1079', '1', 'Ajuy', 'PH.30.1731766', 'ASCII:Ajuy;ID:1731766', '22418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22418', '112', '24295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.30.1731766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24296', '1079', '1', 'Agutaya', 'PH.49.1731799', 'ASCII:Agutaya;ID:1731799', '22419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22419', '112', '24296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1731799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24297', '1079', '1', 'Aguilar', 'PH.51.1731862', 'ASCII:Aguilar;ID:1731862', '22420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22420', '112', '24297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1731862» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24298', '1079', '1', 'Agoo', 'PH.36.1731961', 'ASCII:Agoo;ID:1731961', '22421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22421', '112', '24298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.36.1731961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24299', '1079', '1', 'Agoncillo', 'PH.09.1731970', 'ASCII:Agoncillo;ID:1731970', '22422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22422', '112', '24299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.09.1731970» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24300', '1079', '1', 'Agno', 'PH.51.1732007', 'ASCII:Agno;ID:1732007', '22423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22423', '112', '24300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.51.1732007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24301', '1079', '1', 'Aglipay', 'PH.68.1732041', 'ASCII:Aglipay;ID:1732041', '22424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22424', '112', '24301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.68.1732041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24302', '1079', '1', 'Agdañgan', 'PH.H2.1732092', 'ASCII:Agdangan;ID:1732092', '22425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22425', '112', '24302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.H2.1732092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24303', '1079', '1', 'Adams', 'PH.28.1732260', 'ASCII:Adams;ID:1732260', '22426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22426', '112', '24303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.28.1732260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24304', '1079', '1', 'Abuyog', 'PH.37.1732313', 'ASCII:Abuyog;ID:1732313', '22427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22427', '112', '24304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.37.1732313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24305', '1079', '1', 'Abulug', 'PH.14.1732332', 'ASCII:Abulug;ID:1732332', '22428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22428', '112', '24305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.14.1732332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24306', '1079', '1', 'Abucay', 'PH.07.1732356', 'ASCII:Abucay;ID:1732356', '22429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22429', '112', '24306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.07.1732356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24307', '1079', '1', 'Abra de Ilog', 'PH.40.1732379', 'ASCII:Abra de Ilog;ID:1732379', '22430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22430', '112', '24307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.40.1732379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24308', '1079', '1', 'Aborlan', 'PH.49.1732386', 'ASCII:Aborlan;ID:1732386', '22431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22431', '112', '24308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.49.1732386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24309', '1079', '1', 'Municipality of San Luis', 'PH.03.6567699', 'ASCII:Municipality of San Luis;ID:6567699', '22432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22432', '112', '24309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.6567699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24310', '1079', '1', 'Municipality of Tagoloan', 'PH.34.6569470', 'ASCII:Municipality of Tagoloan;ID:6569470', '22433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22433', '112', '24310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6569470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24311', '1079', '1', 'Municipality of Kapai', 'PH.35.6569471', 'ASCII:Municipality of Kapai;ID:6569471', '22434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22434', '112', '24311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.6569471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24312', '1079', '1', 'Municipality of Tagoloan Two', 'PH.35.6569472', 'ASCII:Municipality of Tagoloan Two;ID:6569472', '22435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22435', '112', '24312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.6569472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24313', '1079', '1', 'Municipality of Bubong', 'PH.35.6569473', 'ASCII:Municipality of Bubong;ID:6569473', '22436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22436', '112', '24313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.6569473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24314', '1079', '1', 'Municipality of Saguiaran', 'PH.35.6569474', 'ASCII:Municipality of Saguiaran;ID:6569474', '22437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22437', '112', '24314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.35.6569474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24315', '1079', '1', 'Municipality of Bacolod', 'PH.34.6569491', 'ASCII:Municipality of Bacolod;ID:6569491', '22438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22438', '112', '24315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6569491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24316', '1079', '1', 'Municipality of Kauswagan', 'PH.34.6569492', 'ASCII:Municipality of Kauswagan;ID:6569492', '22439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22439', '112', '24316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6569492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24317', '1079', '1', 'Municipality of Linamon', 'PH.34.6569493', 'ASCII:Municipality of Linamon;ID:6569493', '22440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22440', '112', '24317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6569493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24318', '1079', '1', 'Municipality of Baloi', 'PH.34.6569494', 'ASCII:Municipality of Baloi;ID:6569494', '22441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22441', '112', '24318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6569494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24319', '1079', '1', 'Municipality of Matungao', 'PH.34.6569495', 'ASCII:Municipality of Matungao;ID:6569495', '22442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22442', '112', '24319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6569495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24320', '1079', '1', 'Municipality of Poona Piagapo', 'PH.34.6569496', 'ASCII:Municipality of Poona Piagapo;ID:6569496', '22443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22443', '112', '24320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6569496» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24321', '1079', '1', 'Municipality of Pantao Ragat', 'PH.34.6569497', 'ASCII:Municipality of Pantao Ragat;ID:6569497', '22444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22444', '112', '24321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6569497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24322', '1079', '1', 'Municipality of Pantar', 'PH.34.6569498', 'ASCII:Municipality of Pantar;ID:6569498', '22445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22445', '112', '24322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6569498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24323', '1079', '1', 'Municipality of Libertad', 'PH.43.6569538', 'ASCII:Municipality of Libertad;ID:6569538', '22446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22446', '112', '24323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.6569538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24324', '1079', '1', 'Municipality of Gitagum', 'PH.43.6569539', 'ASCII:Municipality of Gitagum;ID:6569539', '22447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22447', '112', '24324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.6569539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24325', '1079', '1', 'Municipality of Laguindingan', 'PH.43.6569540', 'ASCII:Municipality of Laguindingan;ID:6569540', '22448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22448', '112', '24325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.6569540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24326', '1079', '1', 'Municipality of Alubijid', 'PH.43.6569541', 'ASCII:Municipality of Alubijid;ID:6569541', '22449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22449', '112', '24326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.6569541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24327', '1079', '1', 'Municipality of Sumilao', 'PH.12.6569579', 'ASCII:Municipality of Sumilao;ID:6569579', '22450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22450', '112', '24327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.6569579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24328', '1079', '1', 'Municipality of Libona', 'PH.12.6569580', 'ASCII:Municipality of Libona;ID:6569580', '22451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22451', '112', '24328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.6569580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24329', '1079', '1', 'Municipality of Talakag', 'PH.12.6569600', 'ASCII:Municipality of Talakag;ID:6569600', '22452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22452', '112', '24329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.6569600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24330', '1079', '1', 'Municipality of Baungon', 'PH.12.6569624', 'ASCII:Municipality of Baungon;ID:6569624', '22453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22453', '112', '24330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.6569624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24331', '1079', '1', 'Municipality of Manolo Fortich', 'PH.12.6569640', 'ASCII:Municipality of Manolo Fortich;ID:6569640', '22454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22454', '112', '24331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.6569640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24332', '1079', '1', 'Municipality of Opol', 'PH.43.6569684', 'ASCII:Municipality of Opol;ID:6569684', '22455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22455', '112', '24332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.6569684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24333', '1079', '1', 'Municipality of Sarangani', 'PH.25.6569698', 'ASCII:Municipality of Sarangani;ID:6569698', '22456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22456', '112', '24333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.6569698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24334', '1079', '1', 'Municipality of Malapatan', 'PH.70.6569699', 'ASCII:Municipality of Malapatan;ID:6569699', '22457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22457', '112', '24334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.6569699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24335', '1079', '1', 'Municipality of Glan', 'PH.70.6569701', 'ASCII:Municipality of Glan;ID:6569701', '22458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22458', '112', '24335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.6569701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24336', '1079', '1', 'Municipality of Initao', 'PH.43.6569728', 'ASCII:Municipality of Initao;ID:6569728', '22459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22459', '112', '24336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.6569728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24337', '1079', '1', 'Municipality of El Salvador', 'PH.43.6569729', 'ASCII:Municipality of El Salvador;ID:6569729', '22460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22460', '112', '24337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.6569729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24338', '1079', '1', 'Municipality of Naawan', 'PH.43.6569730', 'ASCII:Municipality of Naawan;ID:6569730', '22461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22461', '112', '24338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.6569730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24339', '1079', '1', 'Municipality of Manticao', 'PH.43.6569731', 'ASCII:Municipality of Manticao;ID:6569731', '22462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22462', '112', '24339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.6569731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24340', '1079', '1', 'Municipality of Lugait', 'PH.43.6569732', 'ASCII:Municipality of Lugait;ID:6569732', '22463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22463', '112', '24340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.43.6569732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24341', '1079', '1', 'Municipality of Lantapan', 'PH.12.6569739', 'ASCII:Municipality of Lantapan;ID:6569739', '22464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22464', '112', '24341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.6569739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24342', '1079', '1', 'Municipality of Malungon', 'PH.70.6569745', 'ASCII:Municipality of Malungon;ID:6569745', '22465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22465', '112', '24342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.6569745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24343', '1079', '1', 'Municipality of Malita', 'PH.25.6569746', 'ASCII:Municipality of Malita;ID:6569746', '22466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22466', '112', '24343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.6569746» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24344', '1079', '1', 'Municipality of Alabel', 'PH.70.6569755', 'ASCII:Municipality of Alabel;ID:6569755', '22467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22467', '112', '24344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.70.6569755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24345', '1079', '1', 'Municipality of Santa Maria', 'PH.25.6569784', 'ASCII:Municipality of Santa Maria;ID:6569784', '22468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22468', '112', '24345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.6569784» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24346', '1079', '1', 'Municipality of Cabanglasan', 'PH.12.6569805', 'ASCII:Municipality of Cabanglasan;ID:6569805', '22469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22469', '112', '24346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.6569805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24347', '1079', '1', 'City of Malaybalay', 'PH.12.6569821', 'ASCII:City of Malaybalay;ID:6569821', '22470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22470', '112', '24347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.6569821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24348', '1079', '1', 'Municipality of Impasug-ong', 'PH.12.6569825', 'ASCII:Municipality of Impasug-ong;ID:6569825', '22471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22471', '112', '24348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.12.6569825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24349', '1079', '1', 'Municipality of Don Marcelino', 'PH.25.6569849', 'ASCII:Municipality of Don Marcelino;ID:6569849', '22472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22472', '112', '24349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.6569849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24350', '1079', '1', 'Municipality of Loreto', 'PH.03.6569908', 'ASCII:Municipality of Loreto;ID:6569908', '22473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22473', '112', '24350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.6569908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24351', '1079', '1', 'Municipality of La Paz', 'PH.03.6569924', 'ASCII:Municipality of La Paz;ID:6569924', '22474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22474', '112', '24351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.03.6569924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24352', '1079', '1', 'Municipality of Jose Abad Santos', 'PH.25.6569939', 'ASCII:Municipality of Jose Abad Santos;ID:6569939', '22475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22475', '112', '24352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.25.6569939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24353', '1079', '1', 'Municipality of Tangcal', 'PH.34.6656992', 'ASCII:Municipality of Tangcal;ID:6656992', '22476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22476', '112', '24353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6656992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24354', '1079', '1', 'Municipality of Lala', 'PH.34.6656993', 'ASCII:Municipality of Lala;ID:6656993', '22477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22477', '112', '24354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.34.6656993» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24355', '1079', '1', 'Municipality of Bonifacio', 'PH.42.6676059', 'ASCII:Municipality of Bonifacio;ID:6676059', '22478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22478', '112', '24355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.6676059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24356', '1079', '1', 'Municipality of Don Victoriano Chiongbian', 'PH.42.6676064', 'ASCII:Municipality of Don Victoriano Chiongbian;ID:6676064', '22479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22479', '112', '24356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.42.6676064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24357', '1079', '1', 'Municipality of Lugus', 'PH.60.6677963', 'ASCII:Municipality of Lugus;ID:6677963', '22480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22480', '112', '24357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.60.6677963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24358', '1079', '1', 'Municipality of Guipos', 'PH.66.6685903', 'ASCII:Municipality of Guipos;ID:6685903', '22481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22481', '112', '24358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.6685903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24359', '1079', '1', 'Municipality of Margosatubig', 'PH.66.6729298', 'ASCII:Municipality of Margosatubig;ID:6729298', '22482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22482', '112', '24359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.6729298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24360', '1079', '1', 'Municipality of Sominot', 'PH.66.6759270', 'ASCII:Municipality of Sominot;ID:6759270', '22483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22483', '112', '24360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PH.66.6759270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24361', '1079', '1', 'Zhob District', 'PK.02.1162104', 'ASCII:Zhob District;ID:1162104', '22484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22484', '112', '24361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1162104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24362', '1079', '1', 'Kech District', 'PK.02.1163052', 'ASCII:Kech District;ID:1163052', '22485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22485', '112', '24362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1163052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24363', '1079', '1', 'Thatta District', 'PK.05.1163570', 'ASCII:Thatta District;ID:1163570', '22486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22486', '112', '24363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.05.1163570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24364', '1079', '1', 'Thar Pārkar District', 'PK.05.1163602', 'ASCII:Thar Parkar District;ID:1163602', '22487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22487', '112', '24364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.05.1163602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24365', '1079', '1', 'South Wazīristān Agency', 'PK.01.1164536', 'ASCII:South Waziristan Agency;ID:1164536', '22488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22488', '112', '24365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.01.1164536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24366', '1079', '1', 'Sibi District', 'PK.02.1164895', 'ASCII:Sibi District;ID:1164895', '22489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22489', '112', '24366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1164895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24367', '1079', '1', 'Sargodha Division', 'PK.04.1165998', 'ASCII:Sargodha Division;ID:1165998', '22490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22490', '112', '24367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1165998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24368', '1079', '1', 'Rāwalpindi Division', 'PK.04.1166990', 'ASCII:Rawalpindi Division;ID:1166990', '22491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22491', '112', '24368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1166990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24369', '1079', '1', 'Quetta Division', 'PK.02.1167526', 'ASCII:Quetta Division;ID:1167526', '22492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22492', '112', '24369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1167526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24370', '1079', '1', 'Quetta District', 'PK.02.1167527', 'ASCII:Quetta District;ID:1167527', '22493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22493', '112', '24370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1167527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24371', '1079', '1', 'Pishīn District', 'PK.02.1167820', 'ASCII:Pishin District;ID:1167820', '22494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22494', '112', '24371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1167820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24372', '1079', '1', 'Peshāwar Division', 'PK.03.1168194', 'ASCII:Peshawar Division;ID:1168194', '22495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22495', '112', '24372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.03.1168194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24373', '1079', '1', 'Panjgūr District', 'PK.02.1168444', 'ASCII:Panjgur District;ID:1168444', '22496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22496', '112', '24373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1168444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24374', '1079', '1', 'Orakzai Agency', 'PK.01.1168705', 'ASCII:Orakzai Agency;ID:1168705', '22497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22497', '112', '24374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.01.1168705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24375', '1079', '1', 'North Wazīristān Agency', 'PK.01.1168875', 'ASCII:North Waziristan Agency;ID:1168875', '22498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22498', '112', '24375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.01.1168875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24376', '1079', '1', 'Nasīrābād District', 'PK.02.1169249', 'ASCII:Nasirabad District;ID:1169249', '22499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22499', '112', '24376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1169249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24377', '1079', '1', 'Multān Division', 'PK.04.1169820', 'ASCII:Multan Division;ID:1169820', '22500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22500', '112', '24377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1169820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24378', '1079', '1', 'Mohmand Agency', 'PK.01.1170122', 'ASCII:Mohmand Agency;ID:1170122', '22501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22501', '112', '24378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.01.1170122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24379', '1079', '1', 'Malakand Division', 'PK.03.1171387', 'ASCII:Malakand Division;ID:1171387', '22502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22502', '112', '24379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.03.1171387» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24380', '1079', '1', 'Makrān Division', 'PK.02.1171403', 'ASCII:Makran Division;ID:1171403', '22503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22503', '112', '24380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1171403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24381', '1079', '1', 'Loralai District', 'PK.02.1171867', 'ASCII:Loralai District;ID:1171867', '22504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22504', '112', '24381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1171867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24382', '1079', '1', 'Lasbela District', 'PK.02.1172115', 'ASCII:Lasbela District;ID:1172115', '22505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22505', '112', '24382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1172115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24383', '1079', '1', 'Lahore Division', 'PK.04.1172448', 'ASCII:Lahore Division;ID:1172448', '22506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22506', '112', '24383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1172448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24384', '1079', '1', 'Kurram Agency', 'PK.01.1172574', 'ASCII:Kurram Agency;ID:1172574', '22507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22507', '112', '24384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.01.1172574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24385', '1079', '1', 'Kohlu District', 'PK.02.1173463', 'ASCII:Kohlu District;ID:1173463', '22508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22508', '112', '24385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1173463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24386', '1079', '1', 'Khyber Agency', 'PK.01.1173641', 'ASCII:Khyber Agency;ID:1173641', '22509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22509', '112', '24386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.01.1173641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24387', '1079', '1', 'Khuzdār District', 'PK.02.1173663', 'ASCII:Khuzdar District;ID:1173663', '22510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22510', '112', '24387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1173663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24388', '1079', '1', 'Khārān District', 'PK.02.1174059', 'ASCII:Kharan District;ID:1174059', '22511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22511', '112', '24388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1174059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24389', '1079', '1', 'Khairpur Division', 'PK.05.1174348', 'ASCII:Khairpur Division;ID:1174348', '22512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22512', '112', '24389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.05.1174348» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24390', '1079', '1', 'Karāchi Division', 'PK.05.1174869', 'ASCII:Karachi Division;ID:1174869', '22513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22513', '112', '24390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.05.1174869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24391', '1079', '1', 'Karāchi District', 'PK.05.1174870', 'ASCII:Karachi District;ID:1174870', '22514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22514', '112', '24391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.05.1174870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24392', '1079', '1', 'Kalāt Division', 'PK.02.1175292', 'ASCII:Kalat Division;ID:1175292', '22515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22515', '112', '24392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1175292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24393', '1079', '1', 'Kalāt District', 'PK.02.1175293', 'ASCII:Kalat District;ID:1175293', '22516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22516', '112', '24393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1175293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24394', '1079', '1', 'Hyderābād Division', 'PK.05.1176732', 'ASCII:Hyderabad Division;ID:1176732', '22517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22517', '112', '24394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.05.1176732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24395', '1079', '1', 'Hyderābād District', 'PK.05.1176733', 'ASCII:Hyderabad District;ID:1176733', '22518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22518', '112', '24395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.05.1176733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24396', '1079', '1', 'Hazāra Division', 'PK.03.1176967', 'ASCII:Hazara Division;ID:1176967', '22519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22519', '112', '24396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.03.1176967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24397', '1079', '1', 'Gwādar District', 'PK.02.1177445', 'ASCII:Gwadar District;ID:1177445', '22520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22520', '112', '24397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1177445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24398', '1079', '1', 'Gujrānwāla Division', 'PK.04.1177657', 'ASCII:Gujranwala Division;ID:1177657', '22521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22521', '112', '24398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1177657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24399', '1079', '1', 'Faisalābād Division', 'PK.04.1179398', 'ASCII:Faisalabad Division;ID:1179398', '22522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22522', '112', '24399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1179398» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24400', '1079', '1', 'Dera Ismāīl Khān Division', 'PK.03.1180280', 'ASCII:Dera Ismail Khan Division;ID:1180280', '22523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22523', '112', '24400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.03.1180280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24401', '1079', '1', 'Dera Ghāzi Khān Division', 'PK.04.1180287', 'ASCII:Dera Ghazi Khan Division;ID:1180287', '22524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22524', '112', '24401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1180287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24402', '1079', '1', 'Chāgai District', 'PK.02.1181950', 'ASCII:Chagai District;ID:1181950', '22525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22525', '112', '24402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.1181950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24403', '1079', '1', 'Bannu District', 'PK.03.1183459', 'ASCII:Bannu District;ID:1183459', '22526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22526', '112', '24403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.03.1183459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24404', '1079', '1', 'Bājaur Agency', 'PK.01.1183781', 'ASCII:Bajaur Agency;ID:1183781', '22527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22527', '112', '24404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.01.1183781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24405', '1079', '1', 'Bahāwalpur Division', 'PK.04.1183875', 'ASCII:Bahawalpur Division;ID:1183875', '22528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22528', '112', '24405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1183875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24406', '1079', '1', 'Bahāwalpur District', 'PK.04.1183876', 'ASCII:Bahawalpur District;ID:1183876', '22529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22529', '112', '24406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1183876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24407', '1079', '1', 'Bahāwalnagar District', 'PK.04.1183882', 'ASCII:Bahawalnagar District;ID:1183882', '22530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22530', '112', '24407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1183882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24408', '1079', '1', 'Badīn District', 'PK.05.1184051', 'ASCII:Badin District;ID:1184051', '22531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22531', '112', '24408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.05.1184051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24409', '1079', '1', 'Attock District', 'PK.04.1184248', 'ASCII:Attock District;ID:1184248', '22532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22532', '112', '24409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.04.1184248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24410', '1079', '1', 'Abbottābād District', 'PK.03.1185055', 'ASCII:Abbottabad District;ID:1185055', '22533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22533', '112', '24410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.03.1185055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24411', '1079', '1', 'Awārān District', 'PK.02.6641896', 'ASCII:Awaran District;ID:6641896', '22534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22534', '112', '24411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24412', '1079', '1', 'Bārkhān District', 'PK.02.6641912', 'ASCII:Barkhan District;ID:6641912', '22535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22535', '112', '24412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24413', '1079', '1', 'Bolān District', 'PK.02.6641917', 'ASCII:Bolan District;ID:6641917', '22536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22536', '112', '24413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24414', '1079', '1', 'Dera Bugti  District', 'PK.02.6641919', 'ASCII:Dera Bugti  District;ID:6641919', '22537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22537', '112', '24414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24415', '1079', '1', 'Jāfarābād  District', 'PK.02.6641922', 'ASCII:Jafarabad  District;ID:6641922', '22538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22538', '112', '24415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24416', '1079', '1', 'Jhal Magsi District', 'PK.02.6641923', 'ASCII:Jhal Magsi District;ID:6641923', '22539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22539', '112', '24416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24417', '1079', '1', 'Mastung District', 'PK.02.6641952', 'ASCII:Mastung District;ID:6641952', '22540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22540', '112', '24417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24418', '1079', '1', 'Mūsa Khel District', 'PK.02.6641955', 'ASCII:Musa Khel District;ID:6641955', '22541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22541', '112', '24418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24419', '1079', '1', 'Nushki District', 'PK.02.6641960', 'ASCII:Nushki District;ID:6641960', '22542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22542', '112', '24419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24420', '1079', '1', 'Qila Abdullāh District', 'PK.02.6641961', 'ASCII:Qila Abdullah District;ID:6641961', '22543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22543', '112', '24420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24421', '1079', '1', 'Qila Saifullāh District', 'PK.02.6641963', 'ASCII:Qila Saifullah District;ID:6641963', '22544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22544', '112', '24421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24422', '1079', '1', 'Wāshuk District', 'PK.02.6641965', 'ASCII:Washuk District;ID:6641965', '22545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22545', '112', '24422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24423', '1079', '1', 'Ziārat District', 'PK.02.6641972', 'ASCII:Ziarat District;ID:6641972', '22546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22546', '112', '24423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PK.02.6641972» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24424', '1079', '1', 'Powiat będziński', 'PL.83.3079850', 'ASCII:Powiat bedzinski;ID:3079850', '22547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22547', '112', '24424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.83.3079850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24425', '1079', '1', 'Szczecinskie Województwo', 'PL.87.3083832', 'ASCII:Szczecinskie Wojewodztwo;ID:3083832', '22548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22548', '112', '24425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.87.3083832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24426', '1079', '1', 'Sławków', 'PL.83.3085616', 'ASCII:Slawkow;ID:3085616', '22549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22549', '112', '24426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.83.3085616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24427', '1079', '1', 'Koszalinskie Województwo', 'PL.87.3095050', 'ASCII:Koszalinskie Wojewodztwo;ID:3095050', '22550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22550', '112', '24427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.87.3095050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24428', '1079', '1', 'Powiat olsztyński', 'PL.85.6619358', 'ASCII:Powiat olsztynski;ID:6619358', '22551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22551', '112', '24428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.85.6619358» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24429', '1079', '1', 'Powiat bocheński', 'PL.77.6690149', 'ASCII:Powiat bochenski;ID:6690149', '22552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22552', '112', '24429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24430', '1079', '1', 'Powiat brzeski', 'PL.77.6690150', 'ASCII:Powiat brzeski;ID:6690150', '22553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22553', '112', '24430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24431', '1079', '1', 'Powiat chrzanowski', 'PL.77.6690151', 'ASCII:Powiat chrzanowski;ID:6690151', '22554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22554', '112', '24431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24432', '1079', '1', 'Powiat dąbrowski', 'PL.77.6690152', 'ASCII:Powiat dabrowski;ID:6690152', '22555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22555', '112', '24432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24433', '1079', '1', 'Powiat gorlicki', 'PL.77.6690153', 'ASCII:Powiat gorlicki;ID:6690153', '22556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22556', '112', '24433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24434', '1079', '1', 'Powiat krakowski', 'PL.77.6690154', 'ASCII:Powiat krakowski;ID:6690154', '22557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22557', '112', '24434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24435', '1079', '1', 'Powiat limanowski', 'PL.77.6690155', 'ASCII:Powiat limanowski;ID:6690155', '22558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22558', '112', '24435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24436', '1079', '1', 'Powiat myślenicki', 'PL.77.6690156', 'ASCII:Powiat myslenicki;ID:6690156', '22559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22559', '112', '24436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24437', '1079', '1', 'Powiat nowosądecki', 'PL.77.6690157', 'ASCII:Powiat nowosadecki;ID:6690157', '22560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22560', '112', '24437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24438', '1079', '1', 'Powiat nowotarski', 'PL.77.6690158', 'ASCII:Powiat nowotarski;ID:6690158', '22561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22561', '112', '24438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24439', '1079', '1', 'Powiat olkuski', 'PL.77.6690159', 'ASCII:Powiat olkuski;ID:6690159', '22562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22562', '112', '24439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24440', '1079', '1', 'Powiat oświęcimski', 'PL.77.6690160', 'ASCII:Powiat oswiecimski;ID:6690160', '22563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22563', '112', '24440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24441', '1079', '1', 'Powiat proszowicki', 'PL.77.6690161', 'ASCII:Powiat proszowicki;ID:6690161', '22564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22564', '112', '24441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24442', '1079', '1', 'Powiat suski', 'PL.77.6690162', 'ASCII:Powiat suski;ID:6690162', '22565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22565', '112', '24442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690162» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24443', '1079', '1', 'Powiat tarnowski', 'PL.77.6690163', 'ASCII:Powiat tarnowski;ID:6690163', '22566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22566', '112', '24443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24444', '1079', '1', 'Powiat tatrzański', 'PL.77.6690164', 'ASCII:Powiat tatrzanski;ID:6690164', '22567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22567', '112', '24444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24445', '1079', '1', 'Powiat wadowicki', 'PL.77.6690165', 'ASCII:Powiat wadowicki;ID:6690165', '22568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22568', '112', '24445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24446', '1079', '1', 'Powiat wielicki', 'PL.77.6690166', 'ASCII:Powiat wielicki;ID:6690166', '22569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22569', '112', '24446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.77.6690166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24447', '1079', '1', 'powiat Łódzki Wschodni', 'PL.74.6697536', 'ASCII:powiat Lodzki Wschodni;ID:6697536', '22570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22570', '112', '24447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PL.74.6697536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24448', '1079', '1', 'Commune de Saint-Pierre', 'PM.975.97502', 'ASCII:Commune de Saint-Pierre;ID:3424935', '22571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22571', '112', '24448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PM.975.97502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24449', '1079', '1', 'Commune de Miquelon-Langlade', 'PM.975.97501', 'ASCII:Commune de Miquelon-Langlade;ID:3424938', '22572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22572', '112', '24449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PM.975.97501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24450', '1079', '1', 'Crato', 'PT.16.2268835', 'ASCII:Crato;ID:2268835', '22573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22573', '112', '24450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.16.2268835» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24451', '1079', '1', 'Concelho de Tondela', 'PT.22.2733531', 'ASCII:Concelho de Tondela;ID:2733531', '22574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22574', '112', '24451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.22.2733531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24452', '1079', '1', 'Município de Gouveia', 'PT.11.2738888', 'ASCII:Municipio de Gouveia;ID:2738888', '22575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22575', '112', '24452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.11.2738888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24453', '1079', '1', 'Concelho do Fundão', 'PT.06.2739186', 'ASCII:Concelho do Fundao;ID:2739186', '22576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22576', '112', '24453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.06.2739186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24454', '1079', '1', 'Lisboa', 'PT.14.6458923', 'ASCII:Lisboa;ID:6458923', '22577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22577', '112', '24454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.14.6458923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24455', '1079', '1', 'Porto', 'PT.17.6458924', 'ASCII:Porto;ID:6458924', '22578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22578', '112', '24455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.17.6458924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24456', '1079', '1', 'Loures', 'PT.14.6930331', 'ASCII:Loures;ID:6930331', '22579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22579', '112', '24456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.14.6930331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24457', '1079', '1', 'Nisa', 'PT.16.6930614', 'ASCII:Nisa;ID:6930614', '22580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22580', '112', '24457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.16.6930614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24458', '1079', '1', 'Vila Velha de Rodão', 'PT.06.6930622', 'ASCII:Vila Velha de Rodao;ID:6930622', '22581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22581', '112', '24458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.06.6930622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24459', '1079', '1', 'Castelo de Vide', 'PT.16.6930628', 'ASCII:Castelo de Vide;ID:6930628', '22582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22582', '112', '24459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.16.6930628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24460', '1079', '1', 'Marvão', 'PT.16.6930631', 'ASCII:Marvao;ID:6930631', '22583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22583', '112', '24460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.16.6930631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24461', '1079', '1', 'Portalegre', 'PT.16.6930638', 'ASCII:Portalegre;ID:6930638', '22584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22584', '112', '24461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.16.6930638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24462', '1079', '1', 'Gavião', 'PT.16.6930673', 'ASCII:Gaviao;ID:6930673', '22585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22585', '112', '24462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.16.6930673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24463', '1079', '1', 'Ponte de Sor', 'PT.16.6930676', 'ASCII:Ponte de Sor;ID:6930676', '22586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22586', '112', '24463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.16.6930676» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24464', '1079', '1', 'Alter do Chão', 'PT.16.6930689', 'ASCII:Alter do Chao;ID:6930689', '22587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22587', '112', '24464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.16.6930689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24465', '1079', '1', 'Monforte', 'PT.16.6930694', 'ASCII:Monforte;ID:6930694', '22588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22588', '112', '24465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «PT.16.6930694» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24466', '1079', '1', 'Département de La Réunion', 'RE.RE.974', 'ASCII:Departement de La Reunion;ID:6690284', '22589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22589', '112', '24466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RE.RE.974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24467', '1079', '1', 'Someş', 'RO.00.666472', 'ASCII:Somes;ID:666472', '22590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22590', '112', '24467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.666472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24468', '1079', '1', 'Comuna Şoimuş', 'RO.00.666517', 'ASCII:Comuna Soimus;ID:666517', '22591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22591', '112', '24468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.666517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24469', '1079', '1', 'Comuna Padeş', 'RO.00.671558', 'ASCII:Comuna Pades;ID:671558', '22592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22592', '112', '24469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.671558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24470', '1079', '1', 'Comuna Movila', 'RO.00.672748', 'ASCII:Comuna Movila;ID:672748', '22593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22593', '112', '24470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.672748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24471', '1079', '1', 'Comună Meseşenii de Jos', 'RO.00.673532', 'ASCII:Comuna Mesesenii de Jos;ID:673532', '22594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22594', '112', '24471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.673532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24472', '1079', '1', 'Comuna Grădinari', 'RO.00.676827', 'ASCII:Comuna Gradinari;ID:676827', '22595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22595', '112', '24472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.676827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24473', '1079', '1', 'Comuna Ghimpaţi', 'RO.00.677369', 'ASCII:Comuna Ghimpati;ID:677369', '22596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22596', '112', '24473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.677369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24474', '1079', '1', 'Gheorghe Gheorghiu-Dej', 'RO.00.677464', 'ASCII:Gheorghe Gheorghiu-Dej;ID:677464', '22597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22597', '112', '24474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.677464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24475', '1079', '1', 'Comuna Ciumaţi', 'RO.00.681433', 'ASCII:Comuna Ciumati;ID:681433', '22598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22598', '112', '24475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.681433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24476', '1079', '1', 'Comuna Cîndeşti', 'RO.00.681815', 'ASCII:Comuna Cindesti;ID:681815', '22599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22599', '112', '24476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.681815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24477', '1079', '1', 'Comuna Cetăţeni', 'RO.00.682251', 'ASCII:Comuna Cetateni;ID:682251', '22600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22600', '112', '24477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.682251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24478', '1079', '1', 'Comună Cernat', 'RO.00.682330', 'ASCII:Comuna Cernat;ID:682330', '22601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22601', '112', '24478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.682330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24479', '1079', '1', 'Comuna Călugăriţa', 'RO.00.682891', 'ASCII:Comuna Calugarita;ID:682891', '22602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22602', '112', '24479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.682891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24480', '1079', '1', 'Comuna Căiuţi', 'RO.00.683043', 'ASCII:Comuna Caiuti;ID:683043', '22603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22603', '112', '24480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.683043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24481', '1079', '1', 'Municipiul Buzău', 'RO.11.683120', 'ASCII:Municipiul Buzau;ID:683120', '22604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22604', '112', '24481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.11.683120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24482', '1079', '1', 'Municipiul Botoşani', 'RO.00.684037', 'ASCII:Municipiul Botosani;ID:684037', '22605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22605', '112', '24482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.00.684037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24483', '1079', '1', 'Brasov', 'RO..6691648', 'ASCII:Brasov;ID:6691648', '22606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22606', '112', '24483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO..6691648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24484', '1079', '1', 'Constanta', 'RO.14.6691723', 'ASCII:Constanta;ID:6691723', '22607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22607', '112', '24484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RO.14.6691723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24485', '1079', '1', 'Opština Zvezdara', 'RS.00.783763', 'ASCII:Opstina Zvezdara;ID:783763', '22608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22608', '112', '24485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.783763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24486', '1079', '1', 'Opština Zemun', 'RS.00.783919', 'ASCII:Opstina Zemun;ID:783919', '22609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22609', '112', '24486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.783919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24487', '1079', '1', 'Opština Zaječar', 'RS.00.784023', 'ASCII:Opstina Zajecar;ID:784023', '22610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22610', '112', '24487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24488', '1079', '1', 'Opština Žagubica', 'RS.00.784030', 'ASCII:Opstina Zagubica;ID:784030', '22611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22611', '112', '24488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24489', '1079', '1', 'Opština Žabari', 'RS.00.784063', 'ASCII:Opstina Zabari;ID:784063', '22612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22612', '112', '24489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24490', '1079', '1', 'Opština Vrnjačka Banja', 'RS.00.784140', 'ASCII:Opstina Vrnjacka Banja;ID:784140', '22613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22613', '112', '24490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24491', '1079', '1', 'Opština Vranje', 'RS.00.784226', 'ASCII:Opstina Vranje;ID:784226', '22614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22614', '112', '24491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24492', '1079', '1', 'Opština Vračar', 'RS.00.784251', 'ASCII:Opstina Vracar;ID:784251', '22615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22615', '112', '24492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24493', '1079', '1', 'Opština Voždovac', 'RS.00.784255', 'ASCII:Opstina Vozdovac;ID:784255', '22616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22616', '112', '24493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24494', '1079', '1', 'Opština Vlasotince', 'RS.00.784317', 'ASCII:Opstina Vlasotince;ID:784317', '22617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22617', '112', '24494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24495', '1079', '1', 'Opština Vladičin Han', 'RS.00.784354', 'ASCII:Opstina Vladicin Han;ID:784354', '22618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22618', '112', '24495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24496', '1079', '1', 'Opština Veliko Gradište', 'RS.00.784534', 'ASCII:Opstina Veliko Gradiste;ID:784534', '22619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22619', '112', '24496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24497', '1079', '1', 'Opština Velika Plana', 'RS.00.784629', 'ASCII:Opstina Velika Plana;ID:784629', '22620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22620', '112', '24497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24498', '1079', '1', 'Opština Varvarin', 'RS.00.784703', 'ASCII:Opstina Varvarin;ID:784703', '22621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22621', '112', '24498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24499', '1079', '1', 'Opština Ub', 'RS.00.784793', 'ASCII:Opstina Ub;ID:784793', '22622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22622', '112', '24499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24500', '1079', '1', 'Opština Trstenik', 'RS.00.784872', 'ASCII:Opstina Trstenik;ID:784872', '22623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22623', '112', '24500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24501', '1079', '1', 'Opština Trgovište', 'RS.00.784943', 'ASCII:Opstina Trgoviste;ID:784943', '22624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22624', '112', '24501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.784943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24502', '1079', '1', 'Opština Topola', 'RS.00.785012', 'ASCII:Opstina Topola;ID:785012', '22625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22625', '112', '24502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.785012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24503', '1079', '1', 'Opština Svrljig', 'RS.00.785162', 'ASCII:Opstina Svrljig;ID:785162', '22626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22626', '112', '24503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.785162» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24504', '1079', '1', 'Opština Svilajnac', 'RS.00.785183', 'ASCII:Opstina Svilajnac;ID:785183', '22627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22627', '112', '24504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.785183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24505', '1079', '1', 'Opština Jagodina', 'RS.00.785186', 'ASCII:Opstina Jagodina;ID:785186', '22628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22628', '112', '24505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.785186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24506', '1079', '1', 'Opština Surdulica', 'RS.00.785284', 'ASCII:Opstina Surdulica;ID:785284', '22629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22629', '112', '24506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.785284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24507', '1079', '1', 'Opština Stari Grad', 'RS.00.785533', 'ASCII:Opstina Stari Grad;ID:785533', '22630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22630', '112', '24507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.785533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24508', '1079', '1', 'Opština Sopot', 'RS.00.785670', 'ASCII:Opstina Sopot;ID:785670', '22631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22631', '112', '24508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.785670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24509', '1079', '1', 'Opština Sokobanja', 'RS.00.785703', 'ASCII:Opstina Sokobanja;ID:785703', '22632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22632', '112', '24509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.785703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24510', '1079', '1', 'Opština Smederevska Palanka', 'RS.00.785752', 'ASCII:Opstina Smederevska Palanka;ID:785752', '22633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22633', '112', '24510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.785752» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24511', '1079', '1', 'Opština Smederevo', 'RS.00.785755', 'ASCII:Opstina Smederevo;ID:785755', '22634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22634', '112', '24511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.785755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24512', '1079', '1', ' Opština Savski Venac', 'RS.00.786048', 'ASCII: Opstina Savski Venac;ID:786048', '22635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22635', '112', '24512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.786048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24513', '1079', '1', 'Opština Rekovac', 'RS.00.786357', 'ASCII:Opstina Rekovac;ID:786357', '22636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22636', '112', '24513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.786357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24514', '1079', '1', 'Opština Ražanj', 'RS.00.786389', 'ASCII:Opstina Razanj;ID:786389', '22637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22637', '112', '24514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.786389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24515', '1079', '1', 'Opština Rača', 'RS.00.786622', 'ASCII:Opstina Raca;ID:786622', '22638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22638', '112', '24515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.786622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24516', '1079', '1', 'Opština Požega', 'RS.00.786823', 'ASCII:Opstina Pozega;ID:786823', '22639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22639', '112', '24516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.786823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24517', '1079', '1', 'Opština Požarevac', 'RS.00.786826', 'ASCII:Opstina Pozarevac;ID:786826', '22640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22640', '112', '24517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.786826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24518', '1079', '1', 'Opština Pirot', 'RS.00.787049', 'ASCII:Opstina Pirot;ID:787049', '22641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22641', '112', '24518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.787049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24519', '1079', '1', 'Opština Petrovac', 'RS.00.787077', 'ASCII:Opstina Petrovac;ID:787077', '22642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22642', '112', '24519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.787077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24520', '1079', '1', 'Opština Paraćin', 'RS.00.787214', 'ASCII:Opstina Paracin;ID:787214', '22643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22643', '112', '24520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.787214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24521', '1079', '1', 'Opština Palilula', 'RS.00.787252', 'ASCII:Opstina Palilula;ID:787252', '22644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22644', '112', '24521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.787252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24522', '1079', '1', 'Opština Obrenovac', 'RS.00.787515', 'ASCII:Opstina Obrenovac;ID:787515', '22645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22645', '112', '24522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.787515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24523', '1079', '1', 'Opština Novi Beograd', 'RS.00.787606', 'ASCII:Opstina Novi Beograd;ID:787606', '22646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22646', '112', '24523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.787606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24524', '1079', '1', 'Opština Niš', 'RS.00.787656', 'ASCII:Opstina Nis;ID:787656', '22647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22647', '112', '24524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.787656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24525', '1079', '1', 'Opština Negotin', 'RS.00.787717', 'ASCII:Opstina Negotin;ID:787717', '22648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22648', '112', '24525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.787717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24526', '1079', '1', 'Opština Mladenovac', 'RS.00.787891', 'ASCII:Opstina Mladenovac;ID:787891', '22649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22649', '112', '24526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.787891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24527', '1079', '1', 'Opština Mionica', 'RS.00.787934', 'ASCII:Opstina Mionica;ID:787934', '22650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22650', '112', '24527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.787934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24528', '1079', '1', 'Opština Malo Crniće', 'RS.00.788217', 'ASCII:Opstina Malo Crnice;ID:788217', '22651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22651', '112', '24528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.788217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24529', '1079', '1', 'Opština Majdanpek', 'RS.00.788356', 'ASCII:Opstina Majdanpek;ID:788356', '22652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22652', '112', '24529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.788356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24530', '1079', '1', 'Opština Lučani', 'RS.00.788451', 'ASCII:Opstina Lucani;ID:788451', '22653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22653', '112', '24530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.788451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24531', '1079', '1', 'Opština Ljig', 'RS.00.788582', 'ASCII:Opstina Ljig;ID:788582', '22654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22654', '112', '24531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.788582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24532', '1079', '1', 'Opština Leskovac', 'RS.00.788705', 'ASCII:Opstina Leskovac;ID:788705', '22655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22655', '112', '24532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.788705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24533', '1079', '1', 'Opština Lazarevac', 'RS.00.788770', 'ASCII:Opstina Lazarevac;ID:788770', '22656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22656', '112', '24533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.788770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24534', '1079', '1', 'Opština Lajkovac', 'RS.00.788811', 'ASCII:Opstina Lajkovac;ID:788811', '22657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22657', '112', '24534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.788811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24535', '1079', '1', 'Opština Kučevo', 'RS.00.788936', 'ASCII:Opstina Kucevo;ID:788936', '22658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22658', '112', '24535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.788936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24536', '1079', '1', 'Opština Kruševac', 'RS.00.788974', 'ASCII:Opstina Krusevac;ID:788974', '22659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22659', '112', '24536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.788974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24537', '1079', '1', 'Opština Kraljevo', 'RS.00.789106', 'ASCII:Opstina Kraljevo;ID:789106', '22660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22660', '112', '24537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.789106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24538', '1079', '1', 'Grad Kragujevac', 'RS.00.789127', 'ASCII:Grad Kragujevac;ID:789127', '22661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22661', '112', '24538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.789127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24539', '1079', '1', 'Opština Knjaževac', 'RS.00.789414', 'ASCII:Opstina Knjazevac;ID:789414', '22662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22662', '112', '24539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.789414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24540', '1079', '1', 'Opština Knić', 'RS.00.789416', 'ASCII:Opstina Knic;ID:789416', '22663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22663', '112', '24540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.789416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24541', '1079', '1', 'Opština Kladovo', 'RS.00.789484', 'ASCII:Opstina Kladovo;ID:789484', '22664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22664', '112', '24541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.789484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24542', '1079', '1', 'Opština Ivanjica', 'RS.00.789987', 'ASCII:Opstina Ivanjica;ID:789987', '22665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22665', '112', '24542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.789987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24543', '1079', '1', 'Opština Grocka', 'RS.00.790131', 'ASCII:Opstina Grocka;ID:790131', '22666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22666', '112', '24543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.790131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24544', '1079', '1', 'Opština Gornji Milanovac', 'RS.00.790366', 'ASCII:Opstina Gornji Milanovac;ID:790366', '22667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22667', '112', '24544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.790366» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24545', '1079', '1', 'Opština Golubac', 'RS.00.790558', 'ASCII:Opstina Golubac;ID:790558', '22668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22668', '112', '24545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.790558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24546', '1079', '1', 'Opština Gadžin Han', 'RS.00.790794', 'ASCII:Opstina Gadzin Han;ID:790794', '22669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22669', '112', '24546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.790794» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24547', '1079', '1', 'Opština Dimitrovgrad', 'RS.00.791486', 'ASCII:Opstina Dimitrovgrad;ID:791486', '22670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22670', '112', '24547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.791486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24548', '1079', '1', 'Opština Despotovac', 'RS.00.791515', 'ASCII:Opstina Despotovac;ID:791515', '22671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22671', '112', '24548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.791515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24549', '1079', '1', 'Opština Ćuprija', 'RS.00.791677', 'ASCII:Opstina Cuprija;ID:791677', '22672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22672', '112', '24549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.791677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24550', '1079', '1', 'Opština Čukarica', 'RS.00.791703', 'ASCII:Opstina Cukarica;ID:791703', '22673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22673', '112', '24550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.791703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24551', '1079', '1', 'Opština Crna Trava', 'RS.00.791839', 'ASCII:Opstina Crna Trava;ID:791839', '22674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22674', '112', '24551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.791839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24552', '1079', '1', 'Ćićevac Opština', 'RS.00.791935', 'ASCII:Cicevac Opstina;ID:791935', '22675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22675', '112', '24552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.791935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24553', '1079', '1', 'Opština Čačak', 'RS.00.792077', 'ASCII:Opstina Cacak;ID:792077', '22676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22676', '112', '24553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.792077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24554', '1079', '1', 'Opština Bosilegrad', 'RS.00.792420', 'ASCII:Opstina Bosilegrad;ID:792420', '22677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22677', '112', '24554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.792420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24555', '1079', '1', 'Opština Bor', 'RS.00.792455', 'ASCII:Opstina Bor;ID:792455', '22678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22678', '112', '24555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.792455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24556', '1079', '1', 'Opština Boljevac', 'RS.00.792469', 'ASCII:Opstina Boljevac;ID:792469', '22679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22679', '112', '24556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.792469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24557', '1079', '1', 'Opština Bela Palanka', 'RS.00.792783', 'ASCII:Opstina Bela Palanka;ID:792783', '22680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22680', '112', '24557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.792783» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24558', '1079', '1', 'Opština Batočina', 'RS.00.792829', 'ASCII:Opstina Batocina;ID:792829', '22681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22681', '112', '24558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.792829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24559', '1079', '1', 'Opština Barajevo', 'RS.00.792891', 'ASCII:Opstina Barajevo;ID:792891', '22682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22682', '112', '24559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.792891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24560', '1079', '1', 'Opština Babušnica', 'RS.00.793033', 'ASCII:Opstina Babusnica;ID:793033', '22683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22683', '112', '24560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.793033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24561', '1079', '1', 'Opština Arilje', 'RS.00.793092', 'ASCII:Opstina Arilje;ID:793092', '22684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22684', '112', '24561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.793092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24562', '1079', '1', 'Opština Aranđelovac', 'RS.00.793110', 'ASCII:Opstina Arandelovac;ID:793110', '22685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22685', '112', '24562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.793110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24563', '1079', '1', 'Opština Aleksinac', 'RS.00.793137', 'ASCII:Opstina Aleksinac;ID:793137', '22686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22686', '112', '24563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.793137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24564', '1079', '1', 'Opština Aleksandrovac', 'RS.00.793140', 'ASCII:Opstina Aleksandrovac;ID:793140', '22687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22687', '112', '24564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.793140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24565', '1079', '1', ' Opština Rakovica', 'RS.00.865080', 'ASCII: Opstina Rakovica;ID:865080', '22688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22688', '112', '24565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.865080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24566', '1079', '1', 'Opština Sjenica', 'RS.00.865081', 'ASCII:Opstina Sjenica;ID:865081', '22689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22689', '112', '24566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.865081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24567', '1079', '1', 'Opština Lapovo', 'RS.00.865082', 'ASCII:Opstina Lapovo;ID:865082', '22690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22690', '112', '24567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.865082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24568', '1079', '1', 'Grad Niš', 'RS.00.865083', 'ASCII:Grad Nis;ID:865083', '22691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22691', '112', '24568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.865083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24569', '1079', '1', 'Opština Valjevo', 'RS.00.3188401', 'ASCII:Opstina Valjevo;ID:3188401', '22692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22692', '112', '24569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3188401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24570', '1079', '1', 'Opština Koceljeva', 'RS.00.3197945', 'ASCII:Opstina Koceljeva;ID:3197945', '22693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22693', '112', '24570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3197945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24571', '1079', '1', 'Opština Šabac', 'RS.00.3343732', 'ASCII:Opstina Sabac;ID:3343732', '22694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22694', '112', '24571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24572', '1079', '1', 'Opština Vladimirci', 'RS.00.3343734', 'ASCII:Opstina Vladimirci;ID:3343734', '22695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22695', '112', '24572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24573', '1079', '1', 'Opština Bogatić', 'RS.00.3343735', 'ASCII:Opstina Bogatic;ID:3343735', '22696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22696', '112', '24573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24574', '1079', '1', 'Opština Loznica', 'RS.00.3343738', 'ASCII:Opstina Loznica;ID:3343738', '22697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22697', '112', '24574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24575', '1079', '1', 'Opština Mali Zvornik', 'RS.00.3343739', 'ASCII:Opstina Mali Zvornik;ID:3343739', '22698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22698', '112', '24575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24576', '1079', '1', 'Opština Krupanj', 'RS.00.3343741', 'ASCII:Opstina Krupanj;ID:3343741', '22699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22699', '112', '24576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24577', '1079', '1', 'Opština Osečina', 'RS.00.3343742', 'ASCII:Opstina Osecina;ID:3343742', '22700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22700', '112', '24577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343742» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24578', '1079', '1', 'Opština Ljubovija', 'RS.00.3343743', 'ASCII:Opstina Ljubovija;ID:3343743', '22701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22701', '112', '24578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24579', '1079', '1', ' Opštinać Kosjerić', 'RS.00.3343745', 'ASCII: Opstinac Kosjeric;ID:3343745', '22702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22702', '112', '24579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24580', '1079', '1', 'Opština Bajina Bašta', 'RS.00.3343746', 'ASCII:Opstina Bajina Basta;ID:3343746', '22703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22703', '112', '24580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343746» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24581', '1079', '1', 'Opština Užice', 'RS.00.3343747', 'ASCII:Opstina Uzice;ID:3343747', '22704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22704', '112', '24581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343747» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24582', '1079', '1', 'Opština Čajetina', 'RS.00.3343748', 'ASCII:Opstina Cajetina;ID:3343748', '22705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22705', '112', '24582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24583', '1079', '1', 'Opština Priboj', 'RS.00.3343749', 'ASCII:Opstina Priboj;ID:3343749', '22706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22706', '112', '24583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343749» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24584', '1079', '1', 'Opština Nova Varoš', 'RS.00.3343750', 'ASCII:Opstina Nova Varos;ID:3343750', '22707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22707', '112', '24584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24585', '1079', '1', 'Opština Prijepolje', 'RS.00.3343751', 'ASCII:Opstina Prijepolje;ID:3343751', '22708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22708', '112', '24585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RS.00.3343751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24586', '1079', '1', 'Zol''skiy Rayon', 'RU.22.462156', 'ASCII:Zol''skiy Rayon;ID:462156', '22709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22709', '112', '24586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.22.462156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24587', '1079', '1', 'Znamenskiy Rayon', 'RU.72.462315', 'ASCII:Znamenskiy Rayon;ID:462315', '22710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22710', '112', '24587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.72.462315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24588', '1079', '1', 'Zhukovskiy Rayon', 'RU.10.462753', 'ASCII:Zhukovskiy Rayon;ID:462753', '22711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22711', '112', '24588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.462753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24589', '1079', '1', 'Zhizdrinskiy Rayon', 'RU.25.462912', 'ASCII:Zhizdrinskiy Rayon;ID:462912', '22712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22712', '112', '24589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.462912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24590', '1079', '1', 'Zhirnovskiy Rayon', 'RU.84.462981', 'ASCII:Zhirnovskiy Rayon;ID:462981', '22713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22713', '112', '24590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.84.462981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24591', '1079', '1', 'Zelenogradskiy Rayon', 'RU.23.463825', 'ASCII:Zelenogradskiy Rayon;ID:463825', '22714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22714', '112', '24591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.463825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24592', '1079', '1', 'Zelenodol''skiy Rayon', 'RU.73.Zelenodol''skiy Rayon', 'ASCII:Zelenodol''skiy Rayon;ID:463834', '22715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22715', '112', '24592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Zelenodol''skiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24593', '1079', '1', 'Zav’yalovskiy Rayon', 'RU.80.464067', 'ASCII:Zav''yalovskiy Rayon;ID:464067', '22716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22716', '112', '24593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.80.464067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24594', '1079', '1', 'Zavolzhskiy Rayon', 'RU.21.464107', 'ASCII:Zavolzhskiy Rayon;ID:464107', '22717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22717', '112', '24594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.464107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24595', '1079', '1', 'Zaokskiy Rayon', 'RU.76.464992', 'ASCII:Zaokskiy Rayon;ID:464992', '22718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22718', '112', '24595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.76.464992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24596', '1079', '1', 'Zainskiy Rayon', 'RU.73.Zainskiy Rayon', 'ASCII:Zainskiy Rayon;ID:465542', '22719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22719', '112', '24596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Zainskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24597', '1079', '1', 'Yuzhskiy Rayon', 'RU.21.466002', 'ASCII:Yuzhskiy Rayon;ID:466002', '22720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22720', '112', '24597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.466002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24598', '1079', '1', 'Yus''vinskiy Rayon', 'RU.90.466117', 'ASCII:Yus''vinskiy Rayon;ID:466117', '22721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22721', '112', '24598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.90.466117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24599', '1079', '1', 'Yur''yevetskiy Rayon', 'RU.21.466254', 'ASCII:Yur''yevetskiy Rayon;ID:466254', '22722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22722', '112', '24599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.466254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24600', '1079', '1', 'Yur''yanskiy Rayon', 'RU.33.466268', 'ASCII:Yur''yanskiy Rayon;ID:466268', '22723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22723', '112', '24600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.466268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24601', '1079', '1', 'Yurlinskiy Rayon', 'RU.90.466348', 'ASCII:Yurlinskiy Rayon;ID:466348', '22724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22724', '112', '24601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.90.466348» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24602', '1079', '1', 'Yukhnovskiy Rayon', 'RU.25.466653', 'ASCII:Yukhnovskiy Rayon;ID:466653', '22725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22725', '112', '24602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.466653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24603', '1079', '1', 'Yenotayevskiy Rayon', 'RU.07.467477', 'ASCII:Yenotayevskiy Rayon;ID:467477', '22726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22726', '112', '24603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.467477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24604', '1079', '1', 'Yel’nikovskiy Rayon', 'RU.46.467756', 'ASCII:Yel''nikovskiy Rayon;ID:467756', '22727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22727', '112', '24604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.46.467756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24605', '1079', '1', 'Yelabuzhskiy Rayon', 'RU.73.Yelabuzhskiy Rayon', 'ASCII:Yelabuzhskiy Rayon;ID:468080', '22728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22728', '112', '24605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Yelabuzhskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24606', '1079', '1', 'Yaranskiy Rayon', 'RU.33.469004', 'ASCII:Yaranskiy Rayon;ID:469004', '22729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22729', '112', '24606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.469004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24607', '1079', '1', 'Yantikovskiy Rayon', 'RU.16.469048', 'ASCII:Yantikovskiy Rayon;ID:469048', '22730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22730', '112', '24607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.469048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24608', '1079', '1', 'Yal''chikskiy Rayon', 'RU.16.469395', 'ASCII:Yal''chikskiy Rayon;ID:469395', '22731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22731', '112', '24608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.469395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24609', '1079', '1', 'Yakovlevskiy Rayon', 'RU.09.469534', 'ASCII:Yakovlevskiy Rayon;ID:469534', '22732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22732', '112', '24609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.469534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24610', '1079', '1', 'Yadrinskiy Rayon', 'RU.16.469804', 'ASCII:Yadrinskiy Rayon;ID:469804', '22733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22733', '112', '24610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.469804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24611', '1079', '1', 'Vysokogorskiy Rayon', 'RU.73.Vysokogorskiy Rayon', 'ASCII:Vysokogorskiy Rayon;ID:470163', '22734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22734', '112', '24611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Vysokogorskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24612', '1079', '1', 'Vygonichskiy Rayon', 'RU.10.470470', 'ASCII:Vygonichskiy Rayon;ID:470470', '22735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22735', '112', '24612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.470470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24613', '1079', '1', 'Vurnarskiy Rayon', 'RU.16.470846', 'ASCII:Vurnarskiy Rayon;ID:470846', '22736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22736', '112', '24613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.470846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24614', '1079', '1', 'Voskresenskiy Rayon', 'RU.67.471644', 'ASCII:Voskresenskiy Rayon;ID:471644', '22737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22737', '112', '24614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.471644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24615', '1079', '1', 'Severnyy Administrativnyy Okrug', 'RU.48.471823', 'ASCII:Severnyy Administrativnyy Okrug;ID:471823', '22738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22738', '112', '24615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.48.471823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24616', '1079', '1', 'Volzhskiy Rayon', 'RU.45.472225', 'ASCII:Volzhskiy Rayon;ID:472225', '22739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22739', '112', '24616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.45.472225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24617', '1079', '1', 'Vol’skiy Rayon', 'RU.67.472276', 'ASCII:Vol''skiy Rayon;ID:472276', '22740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22740', '112', '24617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.472276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24618', '1079', '1', 'Volosovskiy Rayon', 'RU.42.472350', 'ASCII:Volosovsky Region;ID:472350', '22741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22741', '112', '24618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.42.472350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24619', '1079', '1', 'Volokonovskiy Rayon', 'RU.09.472424', 'ASCII:Volokonovskiy Rayon;ID:472424', '22742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22742', '112', '24619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.472424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24620', '1079', '1', 'Volokolamskiy Rayon', 'RU.47.472430', 'ASCII:Volokolamskiy Rayon;ID:472430', '22743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22743', '112', '24620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.472430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24621', '1079', '1', 'Volodarskiy Rayon', 'RU.07.472484', 'ASCII:Volodarskiy Rayon;ID:472484', '22744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22744', '112', '24621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.472484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24622', '1079', '1', 'Vilegodskiy Rayon', 'RU.06.473668', 'ASCII:Vilegodskiy Rayon;ID:473668', '22745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22745', '112', '24622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.06.473668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24623', '1079', '1', 'Vichugskiy Rayon', 'RU.21.473787', 'ASCII:Vichugskiy Rayon;ID:473787', '22746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22746', '112', '24623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.473787» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24624', '1079', '1', 'Veydelevskiy Rayon', 'RU.09.473855', 'ASCII:Veydelevskiy Rayon;ID:473855', '22747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22747', '112', '24624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.473855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24625', '1079', '1', 'Verkhoshizhemskiy Rayon', 'RU.33.474372', 'ASCII:Verkhoshizhemskiy Rayon;ID:474372', '22748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22748', '112', '24625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.474372» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24626', '1079', '1', 'Verkhneuslonskiy Rayon', 'RU.73.Verkhneuslonskiy Rayon', 'ASCII:Verkhneuslonskiy Rayon;ID:475457', '22749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22749', '112', '24626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Verkhneuslonskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24627', '1079', '1', 'Verkhneural''skiy Rayon', 'RU.13.475462', 'ASCII:Verkhneural''skiy Rayon;ID:475462', '22750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22750', '112', '24627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.475462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24628', '1079', '1', 'Verkhnelandekhovskiy Rayon', 'RU.21.475550', 'ASCII:Verkhnelandekhovskiy Rayon;ID:475550', '22751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22751', '112', '24628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.475550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24629', '1079', '1', 'Valuyskiy Rayon', 'RU.09.477189', 'ASCII:Valuyskiy Rayon;ID:477189', '22752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22752', '112', '24629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.477189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24630', '1079', '1', 'Valdayskiy Rayon', 'RU.52.477295', 'ASCII:Valdayskiy Rayon;ID:477295', '22753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22753', '112', '24630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.52.477295» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24631', '1079', '1', 'Urvanskiy Rayon', 'RU.22.478559', 'ASCII:Urvanskiy Rayon;ID:478559', '22754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22754', '112', '24631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.22.478559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24632', '1079', '1', 'Urmarskiy Rayon', 'RU.16.478690', 'ASCII:Urmarskiy Rayon;ID:478690', '22755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22755', '112', '24632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.478690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24633', '1079', '1', 'Untsukul''skiy Rayon', 'RU.17.Untsukul''skiy Rayon', 'ASCII:Untsukul''skiy Rayon;ID:478962', '22756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22756', '112', '24633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Untsukul''skiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24634', '1079', '1', 'Unechskiy Rayon', 'RU.10.479010', 'ASCII:Unechskiy Rayon;ID:479010', '22757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22757', '112', '24634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.479010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24635', '1079', '1', 'Ul’yanovskiy Rayon', 'RU.81.479105', 'ASCII:Ul''yanovskiy Rayon;ID:479105', '22758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22758', '112', '24635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.81.479105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24636', '1079', '1', 'Ugranskiy Rayon', 'RU.69.479469', 'ASCII:Ugranskiy Rayon;ID:479469', '22759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22759', '112', '24636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.69.479469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24637', '1079', '1', 'Severo-Zapadnyy Administrativnyy Okrug', 'RU.48.480141', 'ASCII:Severo-Zapadnyy Administrativnyy Okrug;ID:480141', '22760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22760', '112', '24637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.48.480141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24638', '1079', '1', 'Tukayevskiy Rayon', 'RU.73.Tukayevskiy Rayon', 'ASCII:Tukayevskiy Rayon;ID:480620', '22761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22761', '112', '24638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Tukayevskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24639', '1079', '1', 'Tsuntinskiy Rayon', 'RU.17.480801', 'ASCII:Tsuntinskiy Rayon;ID:480801', '22762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22762', '112', '24639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.480801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24640', '1079', '1', 'Tsumadinskiy Rayon', 'RU.17.Tsumadinskiy Rayon', 'ASCII:Tsumadinskiy Rayon;ID:480804', '22763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22763', '112', '24640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Tsumadinskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24641', '1079', '1', 'Tsivil''skiy Rayon', 'RU.16.480849', 'ASCII:Tsivil''skiy Rayon;ID:480849', '22764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22764', '112', '24641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.480849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24642', '1079', '1', 'Tsil’ninskiy Rayon', 'RU.81.480881', 'ASCII:Tsil''ninskiy Rayon;ID:480881', '22765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22765', '112', '24642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.81.480881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24643', '1079', '1', 'Trubchevskiy Rayon', 'RU.10.481349', 'ASCII:Trubchevskiy Rayon;ID:481349', '22766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22766', '112', '24643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.481349» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24644', '1079', '1', 'Torbeyevskiy Rayon', 'RU.46.482117', 'ASCII:Torbeyevskiy Rayon;ID:482117', '22767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22767', '112', '24644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.46.482117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24645', '1079', '1', 'Tokarevskiy Rayon', 'RU.72.482496', 'ASCII:Tokarevskiy Rayon;ID:482496', '22768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22768', '112', '24645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.72.482496» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24646', '1079', '1', 'Tlyaratinskiy Rayon', 'RU.17.482588', 'ASCII:Tlyaratinskiy Rayon;ID:482588', '22769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22769', '112', '24646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.482588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24647', '1079', '1', 'Teykovskiy Rayon', 'RU.21.483136', 'ASCII:Teykovskiy Rayon;ID:483136', '22770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22770', '112', '24647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.483136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24648', '1079', '1', 'Teuchezhskiy Rayon', 'RU.01.483141', 'ASCII:Teuchezhskiy Rayon;ID:483141', '22771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22771', '112', '24648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.01.483141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24649', '1079', '1', 'Tetyushskiy Rayon', 'RU.73.483145', 'ASCII:Tetyushskiy Rayon;ID:483145', '22772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22772', '112', '24649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.483145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24650', '1079', '1', 'Terskiy Rayon', 'RU.22.483273', 'ASCII:Terskiy Rayon;ID:483273', '22773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22773', '112', '24650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.22.483273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24651', '1079', '1', 'Temnikovskiy Rayon', 'RU.46.483682', 'ASCII:Temnikovskiy Rayon;ID:483682', '22774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22774', '112', '24651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.46.483682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24652', '1079', '1', 'Tarusskiy Rayon', 'RU.25.484282', 'ASCII:Tarusskiy Rayon;ID:484282', '22775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22775', '112', '24652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.484282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24653', '1079', '1', 'Tarumovskiy Rayon', 'RU.17.484288', 'ASCII:Tarumovskiy Rayon;ID:484288', '22776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22776', '112', '24653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.484288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24654', '1079', '1', 'Tabasaranskiy Rayon', 'RU.17.484957', 'ASCII:Tabasaranskiy Rayon;ID:484957', '22777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22777', '112', '24654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.484957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24655', '1079', '1', 'Sysol''skiy Rayon', 'RU.34.485121', 'ASCII:Sysol''skiy Rayon;ID:485121', '22778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22778', '112', '24655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.34.485121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24656', '1079', '1', 'Syktyvdinskiy Rayon', 'RU.34.485241', 'ASCII:Syktyvdinskiy Rayon;ID:485241', '22779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22779', '112', '24656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.34.485241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24657', '1079', '1', 'Suzemskiy Rayon', 'RU.10.485815', 'ASCII:Suzemskiy Rayon;ID:485815', '22780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22780', '112', '24657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.485815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24658', '1079', '1', 'Suvorovskiy Rayon', 'RU.76.485863', 'ASCII:Suvorovskiy Rayon;ID:485863', '22781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22781', '112', '24658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.76.485863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24659', '1079', '1', 'Surazhskiy Rayon', 'RU.10.486147', 'ASCII:Surazhskiy Rayon;ID:486147', '22782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22782', '112', '24659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.486147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24660', '1079', '1', 'Suleyman-Stal''skiy Rayon', 'RU.17.486360', 'ASCII:Suleyman-Stal''skiy Rayon;ID:486360', '22783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22783', '112', '24660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.486360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24661', '1079', '1', 'Sukhinichskiy Rayon', 'RU.25.486662', 'ASCII:Sukhinichskiy Rayon;ID:486662', '22784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22784', '112', '24661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.486662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24662', '1079', '1', 'Sudogodskiy Rayon', 'RU.83.486831', 'ASCII:Sudogodskiy Rayon;ID:486831', '22785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22785', '112', '24662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.83.486831» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24663', '1079', '1', 'Starooskol''skiy Rayon', 'RU.09.488709', 'ASCII:Starooskol''skiy Rayon;ID:488709', '22786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22786', '112', '24663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.488709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24664', '1079', '1', 'Starokulatkinskiy Rayon', 'RU.81.488775', 'ASCII:Starokulatkinskiy Rayon;ID:488775', '22787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22787', '112', '24664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.81.488775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24665', '1079', '1', 'Starodubskiy Rayon', 'RU.10.488848', 'ASCII:Starodubskiy Rayon;ID:488848', '22788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22788', '112', '24665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.488848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24666', '1079', '1', 'Spas-Demenskiy Rayon', 'RU.25.489867', 'ASCII:Spas-Demenskiy Rayon;ID:489867', '22789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22789', '112', '24666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.489867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24667', '1079', '1', 'Sovetskiy Rayon', 'RU.33.490023', 'ASCII:Sovetskiy Rayon;ID:490023', '22790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22790', '112', '24667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.490023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24668', '1079', '1', 'Sovetskiy Rayon', 'RU.45.490024', 'ASCII:Sovetskiy Rayon;ID:490024', '22791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22791', '112', '24668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.45.490024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24669', '1079', '1', 'Yuzhnyy Administrativnyy Okrug', 'RU.48.490025', 'ASCII:Yuzhnyy Administrativnyy Okrug;ID:490025', '22792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22792', '112', '24669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.48.490025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24670', '1079', '1', 'Sovetskiy Rayon', 'RU.67.490027', 'ASCII:Sovetskiy Rayon;ID:490027', '22793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22793', '112', '24670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.490027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24671', '1079', '1', 'Cherekskiy Rayon', 'RU.22.490029', 'ASCII:Cherekskiy Rayon;ID:490029', '22794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22794', '112', '24671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.22.490029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24672', '1079', '1', 'Shamil''skiy Rayon', 'RU.17.Shamil''skiy Rayon', 'ASCII:Shamil''skiy Rayon;ID:490031', '22795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22795', '112', '24672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Shamil''skiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24673', '1079', '1', 'Sosnovskiy Rayon', 'RU.51.490199', 'ASCII:Sosnovskiy Rayon;ID:490199', '22796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22796', '112', '24673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.51.490199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24674', '1079', '1', 'Zapadnyy Administrativnyy Okrug', 'RU.48.490968', 'ASCII:Zapadnyy Administrativnyy Okrug;ID:490968', '22797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22797', '112', '24674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.48.490968» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24675', '1079', '1', 'Slobodskoy Rayon', 'RU.33.491877', 'ASCII:Slobodskoy Rayon;ID:491877', '22798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22798', '112', '24675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.491877» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24676', '1079', '1', 'Slavskiy Rayon', 'RU.23.492111', 'ASCII:Slavskiy Rayon;ID:492111', '22799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22799', '112', '24676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.492111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24677', '1079', '1', 'Shuyskiy Rayon', 'RU.21.493203', 'ASCII:Shuyskiy Rayon;ID:493203', '22800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22800', '112', '24677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.493203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24678', '1079', '1', 'Shumerlinskiy Rayon', 'RU.16.493464', 'ASCII:Shumerlinskiy Rayon;ID:493464', '22801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22801', '112', '24678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.493464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24679', '1079', '1', 'Shovgenovskiy Rayon', 'RU.01.493720', 'ASCII:Shovgenovskiy Rayon;ID:493720', '22802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22802', '112', '24679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.01.493720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24680', '1079', '1', 'Shemurshinskiy Rayon', 'RU.16.494919', 'ASCII:Shemurshinskiy Rayon;ID:494919', '22803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22803', '112', '24680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.494919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24681', '1079', '1', 'Shelkovskiy Rayon', 'RU.CI.Shelkovskiy Rayon', 'ASCII:Shelkovskiy Rayon;ID:494999', '22804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22804', '112', '24681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.CI.Shelkovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24682', '1079', '1', 'Shchëlkovskiy Rayon', 'RU.47.495337', 'ASCII:Shchelkovskiy Rayon;ID:495337', '22805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22805', '112', '24682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.495337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24683', '1079', '1', 'Shalinskiy Rayon', 'RU.CI.Shalinskiy Rayon', 'ASCII:Shalinskiy Rayon;ID:495940', '22806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22806', '112', '24683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.CI.Shalinskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24684', '1079', '1', 'Shakhovskoy Rayon', 'RU.47.496029', 'ASCII:Shakhovskoy Rayon;ID:496029', '22807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22807', '112', '24684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.496029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24685', '1079', '1', 'Sevskiy Rayon', 'RU.10.496244', 'ASCII:Sevskiy Rayon;ID:496244', '22808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22808', '112', '24685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.496244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24686', '1079', '1', 'Serpukhovskiy Rayon', 'RU.47.496526', 'ASCII:Serpukhovskiy Rayon;ID:496526', '22809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22809', '112', '24686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.496526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24687', '1079', '1', 'Sernurskiy Rayon', 'RU.45.496560', 'ASCII:Sernurskiy Rayon;ID:496560', '22810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22810', '112', '24687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.45.496560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24688', '1079', '1', 'Sergokalinskiy Rayon', 'RU.17.496609', 'ASCII:Sergokalinskiy Rayon;ID:496609', '22811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22811', '112', '24688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.496609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24689', '1079', '1', 'Semënovskiy Rayon', 'RU.51.497311', 'ASCII:Semenovskiy Rayon;ID:497311', '22812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22812', '112', '24689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.51.497311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24690', '1079', '1', 'Savinskiy Rayon', 'RU.21.498203', 'ASCII:Savinskiy Rayon;ID:498203', '22813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22813', '112', '24690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.498203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24691', '1079', '1', 'Satkinskiy Rayon', 'RU.13.498416', 'ASCII:Satkinskiy Rayon;ID:498416', '22814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22814', '112', '24691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.498416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24692', '1079', '1', 'Sarmanovskiy Rayon', 'RU.73.Sarmanovskiy Rayon', 'ASCII:Sarmanovskiy Rayon;ID:498536', '22815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22815', '112', '24692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Sarmanovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24693', '1079', '1', 'Saratovskiy Rayon', 'RU.67.498661', 'ASCII:Saratovskiy Rayon;ID:498661', '22816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22816', '112', '24693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.498661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24694', '1079', '1', 'Sarapul’skiy Rayon', 'RU.80.498681', 'ASCII:Sarapul''skiy Rayon;ID:498681', '22817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22817', '112', '24694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.80.498681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24695', '1079', '1', 'Sampurskiy Rayon', 'RU.72.498933', 'ASCII:Sampurskiy Rayon;ID:498933', '22818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22818', '112', '24695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.72.498933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24696', '1079', '1', 'Sabinskiy Rayon', 'RU.73.Sabinskiy Rayon', 'ASCII:Sabinskiy Rayon;ID:499665', '22819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22819', '112', '24696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Sabinskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24697', '1079', '1', 'Rybno-Slobodskiy Rayon', 'RU.73.Rybno-Slobodskiy Rayon', 'ASCII:Rybno-Slobodskiy Rayon;ID:499980', '22820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22820', '112', '24697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Rybno-Slobodskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24698', '1079', '1', 'Rutul''skiy Rayon', 'RU.17.500315', 'ASCII:Rutul''skiy Rayon;ID:500315', '22821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22821', '112', '24698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.500315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24699', '1079', '1', 'Roven''skiy Rayon', 'RU.09.501124', 'ASCII:Roven''skiy Rayon;ID:501124', '22822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22822', '112', '24699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.501124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24700', '1079', '1', 'Rognedinskiy Rayon', 'RU.10.501624', 'ASCII:Rognedinskiy Rayon;ID:501624', '22823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22823', '112', '24700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.501624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24701', '1079', '1', 'Rodnikovskiy Rayon', 'RU.21.501709', 'ASCII:Rodnikovskiy Rayon;ID:501709', '22824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22824', '112', '24701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.501709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24702', '1079', '1', 'Rasskazovskiy Rayon', 'RU.72.502790', 'ASCII:Rasskazovskiy Rayon;ID:502790', '22825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22825', '112', '24702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.72.502790» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24703', '1079', '1', 'Rakityanskiy Rayon', 'RU.09.503055', 'ASCII:Rakityanskiy Rayon;ID:503055', '22826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22826', '112', '24703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.503055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24704', '1079', '1', 'Pushkinskiy Rayon', 'RU.47.503964', 'ASCII:Pushkinskiy Rayon;ID:503964', '22827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22827', '112', '24704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.503964» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24705', '1079', '1', 'Puchezhskiy Rayon', 'RU.21.504293', 'ASCII:Puchezhskiy Rayon;ID:504293', '22828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22828', '112', '24705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.504293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24706', '1079', '1', 'Prokhorovskiy Rayon', 'RU.09.504908', 'ASCII:Prokhorovskiy Rayon;ID:504908', '22829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22829', '112', '24706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.504908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24707', '1079', '1', 'Prokhladnenskiy Rayon', 'RU.22.504938', 'ASCII:Prokhladnenskiy Rayon;ID:504938', '22830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22830', '112', '24707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.22.504938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24708', '1079', '1', 'Privolzhskiy Rayon', 'RU.21.505049', 'ASCII:Privolzhskiy Rayon;ID:505049', '22831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22831', '112', '24708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.505049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24709', '1079', '1', 'Privolzhskiy Rayon', 'RU.07.505051', 'ASCII:Privolzhskiy Rayon;ID:505051', '22832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22832', '112', '24709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.505051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24710', '1079', '1', 'Pristenskiy Rayon', 'RU.41.505150', 'ASCII:Pristenskiy Rayon;ID:505150', '22833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22833', '112', '24710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.41.505150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24711', '1079', '1', 'Priluzskiy Rayon', 'RU.34.505282', 'ASCII:Priluzskiy Rayon;ID:505282', '22834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22834', '112', '24711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.34.505282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24712', '1079', '1', 'Prigorodnyy Rayon', 'RU.68.505371', 'ASCII:Prigorodnyy Rayon;ID:505371', '22835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22835', '112', '24712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.68.505371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24713', '1079', '1', 'Pravoberezhnyy Rayon', 'RU.68.505586', 'ASCII:Pravoberezhnyy Rayon;ID:505586', '22836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22836', '112', '24713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.68.505586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24714', '1079', '1', 'Pravdinskiy Rayon', 'RU.23.505596', 'ASCII:Pravdinskiy Rayon;ID:505596', '22837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22837', '112', '24714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.505596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24715', '1079', '1', 'Poretskiy Rayon', 'RU.16.506288', 'ASCII:Poretskiy Rayon;ID:506288', '22838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22838', '112', '24715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.506288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24716', '1079', '1', 'Polesskiy Rayon', 'RU.23.507290', 'ASCII:Polesskiy Rayon;ID:507290', '22839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22839', '112', '24716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.507290» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24717', '1079', '1', 'Pogarskiy Rayon', 'RU.10.507867', 'ASCII:Pogarskiy Rayon;ID:507867', '22840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22840', '112', '24717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.507867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24718', '1079', '1', 'Podol’skiy Rayon', 'RU.47.508091', 'ASCII:Podol''skiy Rayon;ID:508091', '22841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22841', '112', '24718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.508091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24719', '1079', '1', 'Pochepskiy Rayon', 'RU.10.508648', 'ASCII:Pochepskiy Rayon;ID:508648', '22842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22842', '112', '24719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.508648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24720', '1079', '1', 'Pizhanskiy Rayon', 'RU.33.509182', 'ASCII:Pizhanskiy Rayon;ID:509182', '22843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22843', '112', '24720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.509182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24721', '1079', '1', 'Pestyakovskiy Rayon', 'RU.21.510322', 'ASCII:Pestyakovskiy Rayon;ID:510322', '22844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22844', '112', '24721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.510322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24722', '1079', '1', 'Pestrechinskiy Rayon', 'RU.73.Pestrechinskiy Rayon', 'ASCII:Pestrechinskiy Rayon;ID:510344', '22845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22845', '112', '24722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Pestrechinskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24723', '1079', '1', 'Peremyshl’skiy Rayon', 'RU.25.511399', 'ASCII:Peremyshl''skiy Rayon;ID:511399', '22846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22846', '112', '24723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.511399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24724', '1079', '1', 'Pavlovskiy Rayon', 'RU.51.512018', 'ASCII:Pavlovskiy Rayon;ID:512018', '22847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22847', '112', '24724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.51.512018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24725', '1079', '1', 'Pavlovskiy Rayon', 'RU.81.512019', 'ASCII:Pavlovskiy Rayon;ID:512019', '22848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22848', '112', '24725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.81.512019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24726', '1079', '1', 'Pavlovo-Posadskiy Rayon', 'RU.47.512055', 'ASCII:Pavlovo-Posadskiy Rayon;ID:512055', '22849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22849', '112', '24726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.512055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24727', '1079', '1', 'Paran''ginskiy Rayon', 'RU.45.512616', 'ASCII:Paran''ginskiy Rayon;ID:512616', '22850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22850', '112', '24727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.45.512616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24728', '1079', '1', 'Palekhskiy Rayon', 'RU.21.513094', 'ASCII:Palekhskiy Rayon;ID:513094', '22851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22851', '112', '24728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.513094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24729', '1079', '1', 'Ozerskiy Rayon', 'RU.23.513394', 'ASCII:Ozerskiy Rayon;ID:513394', '22852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22852', '112', '24729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.513394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24730', '1079', '1', 'Ostrovskiy Rayon', 'RU.37.514056', 'ASCII:Ostrovskiy Rayon;ID:514056', '22853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22853', '112', '24730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.37.514056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24731', '1079', '1', 'Ostashkovskiy Rayon', 'RU.77.514249', 'ASCII:Ostashkovskiy Rayon;ID:514249', '22854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22854', '112', '24731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.77.514249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24732', '1079', '1', 'Orichevskiy Rayon', 'RU.33.514967', 'ASCII:Orichevskiy Rayon;ID:514967', '22855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22855', '112', '24732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.514967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24733', '1079', '1', 'Okulovskiy Rayon', 'RU.52.515748', 'ASCII:Okulovskiy Rayon;ID:515748', '22856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22856', '112', '24733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.52.515748» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24734', '1079', '1', 'Nurlatskiy Rayon', 'RU.73.Nurlatskiy Rayon', 'ASCII:Nurlatskiy Rayon;ID:515836', '22857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22857', '112', '24734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Nurlatskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24735', '1079', '1', 'Oboyanskiy Rayon', 'RU.41.516399', 'ASCII:Oboyanskiy Rayon;ID:516399', '22858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22858', '112', '24735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.41.516399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24736', '1079', '1', 'Nyazepetrovskiy Rayon', 'RU.13.516613', 'ASCII:Nyazepetrovskiy Rayon;ID:516613', '22859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22859', '112', '24736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.516613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24737', '1079', '1', 'Nozhay-Yurtovskiy Rayon', 'RU.CI.Nozhay-Yurtovskiy Rayon', 'ASCII:Nozhay-Yurtovskiy Rayon;ID:516779', '22860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22860', '112', '24737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.CI.Nozhay-Yurtovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24738', '1079', '1', 'Novozybkovskiy Rayon', 'RU.10.517267', 'ASCII:Novozybkovskiy Rayon;ID:517267', '22861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22861', '112', '24738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.517267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24739', '1079', '1', 'Novotor”yal’skiy Rayon', 'RU.45.517838', 'ASCII:Novotor"yal''skiy Rayon;ID:517838', '22862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22862', '112', '24739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.45.517838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24740', '1079', '1', 'Novooskol''skiy Rayon', 'RU.09.518413', 'ASCII:Novooskol''skiy Rayon;ID:518413', '22863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22863', '112', '24740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.518413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24741', '1079', '1', 'Novoorskiy Rayon', 'RU.55.518417', 'ASCII:Novoorskiy Rayon;ID:518417', '22864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22864', '112', '24741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.55.518417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24742', '1079', '1', 'Novolakskiy Rayon', 'RU.17.Novolakskiy Rayon', 'ASCII:Novolakskiy Rayon;ID:518649', '22865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22865', '112', '24742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Novolakskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24743', '1079', '1', 'Noginskiy Rayon', 'RU.47.520066', 'ASCII:Noginskiy Rayon;ID:520066', '22866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22866', '112', '24743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.520066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24744', '1079', '1', 'Nogayskiy Rayon', 'RU.17.520075', 'ASCII:Nogayskiy Rayon;ID:520075', '22867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22867', '112', '24744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.520075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24745', '1079', '1', 'Nizhnekamskiy Rayon', 'RU.73.Nizhnekamskiy Rayon', 'ASCII:Nizhnekamskiy Rayon;ID:521116', '22868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22868', '112', '24745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Nizhnekamskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24746', '1079', '1', 'Neverkinskiy Rayon', 'RU.57.522401', 'ASCII:Neverkinskiy Rayon;ID:522401', '22869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22869', '112', '24746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.57.522401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24747', '1079', '1', 'Nesterovskiy Rayon', 'RU.23.522467', 'ASCII:Nesterovskiy Rayon;ID:522467', '22870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22870', '112', '24747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.522467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24748', '1079', '1', 'Nerekhtskiy Rayon', 'RU.37.522591', 'ASCII:Nerekhtskiy Rayon;ID:522591', '22871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22871', '112', '24748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.37.522591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24749', '1079', '1', 'Nemanskiy Rayon', 'RU.23.522740', 'ASCII:Nemanskiy Rayon;ID:522740', '22872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22872', '112', '24749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.522740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24750', '1079', '1', 'Neftegorskiy Rayon', 'RU.65.522943', 'ASCII:Neftegorskiy Rayon;ID:522943', '22873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22873', '112', '24750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.65.522943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24751', '1079', '1', 'Nazranovskiy Rayon', 'RU.CI.Nazranovskiy Rayon', 'ASCII:Nazranovskiy Rayon;ID:523063', '22874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22874', '112', '24751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.CI.Nazranovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24752', '1079', '1', 'Navlinskiy Rayon', 'RU.10.523187', 'ASCII:Navlinskiy Rayon;ID:523187', '22875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22875', '112', '24752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.523187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24753', '1079', '1', 'Naurskiy Rayon', 'RU.CI.Naurskiy Rayon', 'ASCII:Naurskiy Rayon;ID:523209', '22876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22876', '112', '24753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.CI.Naurskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24754', '1079', '1', 'Narimanovskiy Rayon', 'RU.07.523439', 'ASCII:Narimanovskiy Rayon;ID:523439', '22877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22877', '112', '24754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.523439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24755', '1079', '1', 'Nagorskiy Rayon', 'RU.33.523582', 'ASCII:Nagorskiy Rayon;ID:523582', '22878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22878', '112', '24755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.523582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24756', '1079', '1', 'Nagaybakskiy Rayon', 'RU.13.523633', 'ASCII:Nagaybakskiy Rayon;ID:523633', '22879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22879', '112', '24756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.523633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24757', '1079', '1', 'Nadterechnyy Rayon', 'RU.CI.Nadterechnyy Rayon', 'ASCII:Nadterechnyy Rayon;ID:523654', '22880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22880', '112', '24757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.CI.Nadterechnyy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24758', '1079', '1', 'Mytishchinskiy Rayon', 'RU.47.523810', 'ASCII:Mytishchinskiy Rayon;ID:523810', '22881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22881', '112', '24758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.523810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24759', '1079', '1', 'Muslyumovskiy Rayon', 'RU.73.Muslyumovskiy Rayon', 'ASCII:Muslyumovskiy Rayon;ID:524181', '22882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22882', '112', '24759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Muslyumovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24760', '1079', '1', 'Mozdokskiy Rayon', 'RU.68.524734', 'ASCII:Mozdokskiy Rayon;ID:524734', '22883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22883', '112', '24760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.68.524734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24761', '1079', '1', 'Mosal''skiy Rayon', 'RU.25.525083', 'ASCII:Mosal''skiy Rayon;ID:525083', '22884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22884', '112', '24761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.525083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24762', '1079', '1', 'Morkinskiy Rayon', 'RU.45.525261', 'ASCII:Morkinskiy Rayon;ID:525261', '22885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22885', '112', '24762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.45.525261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24763', '1079', '1', 'Morgaushskiy Rayon', 'RU.16.525278', 'ASCII:Morgaushskiy Rayon;ID:525278', '22886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22886', '112', '24763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.525278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24764', '1079', '1', 'Mglinskiy Rayon', 'RU.10.527216', 'ASCII:Mglinskiy Rayon;ID:527216', '22887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22887', '112', '24764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.527216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24765', '1079', '1', 'Meshchovskiy Rayon', 'RU.25.527404', 'ASCII:Meshchovskiy Rayon;ID:527404', '22888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22888', '112', '24765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.527404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24766', '1079', '1', 'Menzelinskiy Rayon', 'RU.73.Menzelinskiy Rayon', 'ASCII:Menzelinskiy Rayon;ID:527526', '22889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22889', '112', '24766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Menzelinskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24767', '1079', '1', 'Mayskiy Rayon', 'RU.22.528218', 'ASCII:Mayskiy Rayon;ID:528218', '22890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22890', '112', '24767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.22.528218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24768', '1079', '1', 'Maykopskiy Rayon', 'RU.01.528290', 'ASCII:Maykopskiy Rayon;ID:528290', '22891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22891', '112', '24768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.01.528290» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24769', '1079', '1', 'Marksovskiy Rayon', 'RU.67.529068', 'ASCII:Marksovskiy Rayon;ID:529068', '22892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22892', '112', '24769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.529068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24770', '1079', '1', 'Mari-Turekskiy Rayon', 'RU.45.529194', 'ASCII:Mari-Turekskiy Rayon;ID:529194', '22893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22893', '112', '24770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.45.529194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24771', '1079', '1', 'Mariinsko-Posadskiy Rayon', 'RU.16.529342', 'ASCII:Mariinsko-Posadskiy Rayon;ID:529342', '22894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22894', '112', '24771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.529342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24772', '1079', '1', 'Mamadyshskiy Rayon', 'RU.73.Mamadyshskiy Rayon', 'ASCII:Mamadyshskiy Rayon;ID:529705', '22895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22895', '112', '24772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Mamadyshskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24773', '1079', '1', 'Maloyaroslavetskiy Rayon', 'RU.25.530848', 'ASCII:Maloyaroslavetskiy Rayon;ID:530848', '22896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22896', '112', '24773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.530848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24774', '1079', '1', 'Malgobekskiy Rayon', 'RU.CI.Malgobekskiy Rayon', 'ASCII:Malgobekskiy Rayon;ID:531127', '22897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22897', '112', '24774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.CI.Malgobekskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24775', '1079', '1', 'Magaramkentskiy Rayon', 'RU.17.532306', 'ASCII:Magaramkentskiy Rayon;ID:532306', '22898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22898', '112', '24775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.532306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24776', '1079', '1', 'Lyudinovskiy Rayon', 'RU.25.532457', 'ASCII:Lyudinovskiy Rayon;ID:532457', '22899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22899', '112', '24776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.532457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24777', '1079', '1', 'Lyubytinskiy Rayon', 'RU.52.532461', 'ASCII:Lyubytinskiy Rayon;ID:532461', '22900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22900', '112', '24777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.52.532461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24778', '1079', '1', 'Yugo-Vostochnyy Administrativnyy Okrug', 'RU.48.532527', 'ASCII:Yugo-Vostochnyy Administrativnyy Okrug;ID:532527', '22901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22901', '112', '24778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.48.532527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24779', '1079', '1', 'Lyuberetskiy Rayon', 'RU.47.532616', 'ASCII:Lyuberetskiy Rayon;ID:532616', '22902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22902', '112', '24779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.532616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24780', '1079', '1', 'Lukhskiy Rayon', 'RU.21.533539', 'ASCII:Lukhskiy Rayon;ID:533539', '22903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22903', '112', '24780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.533539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24781', '1079', '1', 'Lotoshinskiy Rayon', 'RU.47.533974', 'ASCII:Lotoshinskiy Rayon;ID:533974', '22904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22904', '112', '24781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.533974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24782', '1079', '1', 'Lomonosovskiy Rayon', 'RU.42.534332', 'ASCII:Lomonosovskiy Rayon;ID:534332', '22905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22905', '112', '24782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.42.534332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24783', '1079', '1', 'Limanskiy Rayon', 'RU.07.535210', 'ASCII:Limanskiy Rayon;ID:535210', '22906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22906', '112', '24783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.535210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24784', '1079', '1', 'Levashinskiy Rayon', 'RU.17.535538', 'ASCII:Levashinskiy Rayon;ID:535538', '22907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22907', '112', '24784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.535538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24785', '1079', '1', 'Karabudakhkentskiy Rayon', 'RU.17.536044', 'ASCII:Karabudakhkentskiy Rayon;ID:536044', '22908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22908', '112', '24785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.536044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24786', '1079', '1', 'Leninskiy Rayon', 'RU.47.536086', 'ASCII:Leninskiy Rayon;ID:536086', '22909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22909', '112', '24786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.536086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24787', '1079', '1', 'Leninogorskiy Rayon', 'RU.73.Leninogorskiy Rayon', 'ASCII:Leninogorskiy Rayon;ID:536160', '22910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22910', '112', '24787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Leninogorskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24788', '1079', '1', 'Lakskiy Rayon', 'RU.17.537098', 'ASCII:Lakskiy Rayon;ID:537098', '22911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22911', '112', '24788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.537098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24789', '1079', '1', 'Laishevskiy Rayon', 'RU.73.Laishevskiy Rayon', 'ASCII:Laishevskiy Rayon;ID:537156', '22912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22912', '112', '24789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Laishevskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24790', '1079', '1', 'Kvarkenskiy Rayon', 'RU.55.537539', 'ASCII:Kvarkenskiy Rayon;ID:537539', '22913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22913', '112', '24790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.55.537539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24791', '1079', '1', 'Kuzhenerskiy Rayon', 'RU.45.537938', 'ASCII:Kuzhenerskiy Rayon;ID:537938', '22914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22914', '112', '24791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.45.537938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24792', '1079', '1', 'Spasskiy Rayon', 'RU.73.Spasskiy Rayon', 'ASCII:Spasskiy Rayon;ID:538050', '22915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22915', '112', '24792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Spasskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24793', '1079', '1', 'Kusinskiy Rayon', 'RU.13.538327', 'ASCII:Kusinskiy Rayon;ID:538327', '22916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22916', '112', '24793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.538327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24794', '1079', '1', 'Kurskiy Rayon', 'RU.70.538550', 'ASCII:Kurskiy Rayon;ID:538550', '22917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22917', '112', '24794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.70.538550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24795', '1079', '1', 'Kurakhskiy Rayon', 'RU.17.538991', 'ASCII:Kurakhskiy Rayon;ID:538991', '22918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22918', '112', '24795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.538991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24796', '1079', '1', 'Kumenskiy Rayon', 'RU.33.539285', 'ASCII:Kumenskiy Rayon;ID:539285', '22919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22919', '112', '24796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.539285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24797', '1079', '1', 'Kulinskiy Rayon', 'RU.17.539432', 'ASCII:Kulinskiy Rayon;ID:539432', '22920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22920', '112', '24797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.539432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24798', '1079', '1', 'Kukmorskiy Rayon', 'RU.73.Kukmorskiy Rayon', 'ASCII:Kukmorskiy Rayon;ID:539687', '22921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22921', '112', '24798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Kukmorskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24799', '1079', '1', 'Kudymkarskiy Rayon', 'RU.90.539816', 'ASCII:Kudymkarskiy Rayon;ID:539816', '22922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22922', '112', '24799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.90.539816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24800', '1079', '1', 'Kstovskiy Rayon', 'RU.51.540102', 'ASCII:Kstovskiy Rayon;ID:540102', '22923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22923', '112', '24800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.51.540102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24801', '1079', '1', 'Krasnoznamenskiy Rayon', 'RU.23.541941', 'ASCII:Krasnoznamenskiy Rayon;ID:541941', '22924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22924', '112', '24801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.541941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24802', '1079', '1', 'Krasnoyarskiy Rayon', 'RU.65.542130', 'ASCII:Krasnoyarskiy Rayon;ID:542130', '22925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22925', '112', '24802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.65.542130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24803', '1079', '1', 'Krasnoyarskiy Rayon', 'RU.07.542131', 'ASCII:Krasnoyarskiy Rayon;ID:542131', '22926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22926', '112', '24803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.542131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24804', '1079', '1', 'Krasnoslobodskiy Rayon', 'RU.46.542209', 'ASCII:Krasnoslobodskiy Rayon;ID:542209', '22927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22927', '112', '24804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.46.542209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24805', '1079', '1', 'Krasnokutskiy Rayon', 'RU.67.542310', 'ASCII:Krasnokutskiy Rayon;ID:542310', '22928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22928', '112', '24805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.542310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24806', '1079', '1', 'Krasnogvardeyskiy Rayon', 'RU.09.542337', 'ASCII:Krasnogvardeyskiy Rayon;ID:542337', '22929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22929', '112', '24806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.542337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24807', '1079', '1', 'Krasnogvardeyskiy Rayon', 'RU.01.542340', 'ASCII:Krasnogvardeyskiy Rayon;ID:542340', '22930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22930', '112', '24807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.01.542340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24808', '1079', '1', 'Krasnogorskiy Rayon', 'RU.47.542363', 'ASCII:Krasnogorskiy Rayon;ID:542363', '22931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22931', '112', '24808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.542363» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24809', '1079', '1', 'Krasnogorskiy Rayon', 'RU.10.542364', 'ASCII:Krasnogorskiy Rayon;ID:542364', '22932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22932', '112', '24809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.542364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24810', '1079', '1', 'Krasnoborskiy Rayon', 'RU.06.542421', 'ASCII:Krasnoborskiy Rayon;ID:542421', '22933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22933', '112', '24810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.06.542421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24811', '1079', '1', 'Krasnoarmeyskiy Rayon', 'RU.16.542436', 'ASCII:Krasnoarmeyskiy Rayon;ID:542436', '22934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22934', '112', '24811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.542436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24812', '1079', '1', 'Krasnoarmeyskiy Rayon', 'RU.67.542438', 'ASCII:Krasnoarmeyskiy Rayon;ID:542438', '22935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22935', '112', '24812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.542438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24813', '1079', '1', 'Kozlovskiy Rayon', 'RU.16.543055', 'ASCII:Kozlovskiy Rayon;ID:543055', '22936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22936', '112', '24813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.543055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24814', '1079', '1', 'Kozel’skiy Rayon', 'RU.25.543347', 'ASCII:Kozel''skiy Rayon;ID:543347', '22937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22937', '112', '24814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.543347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24815', '1079', '1', 'Koygorodskiy Rayon', 'RU.34.543395', 'ASCII:Koygorodskiy Rayon;ID:543395', '22938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22938', '112', '24815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.34.543395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24816', '1079', '1', 'Kovylkinskiy Rayon', 'RU.46.543435', 'ASCII:Kovylkinskiy Rayon;ID:543435', '22939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22939', '112', '24816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.46.543435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24817', '1079', '1', 'Kovrovskiy Rayon', 'RU.83.543454', 'ASCII:Kovrovskiy Rayon;ID:543454', '22940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22940', '112', '24817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.83.543454» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24818', '1079', '1', 'Kotlasskiy Rayon', 'RU.06.543702', 'ASCII:Kotlasskiy Rayon;ID:543702', '22941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22941', '112', '24818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.06.543702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24819', '1079', '1', 'Kotel’nichskiy Rayon', 'RU.33.543733', 'ASCII:Kotel''nichskiy Rayon;ID:543733', '22942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22942', '112', '24819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.543733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24820', '1079', '1', 'Kostromskoy Rayon', 'RU.37.543869', 'ASCII:Kostromskoy Rayon;ID:543869', '22943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22943', '112', '24820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.37.543869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24821', '1079', '1', 'Kosinskiy Rayon', 'RU.90.544114', 'ASCII:Kosinskiy Rayon;ID:544114', '22944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22944', '112', '24821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.90.544114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24822', '1079', '1', 'Koshekhabl''skiy Rayon', 'RU.01.544261', 'ASCII:Koshekhabl''skiy Rayon;ID:544261', '22945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22945', '112', '24822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.01.544261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24823', '1079', '1', 'Korochanskiy Rayon', 'RU.09.544704', 'ASCII:Korochanskiy Rayon;ID:544704', '22946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22946', '112', '24823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.544704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24824', '1079', '1', 'Komsomol''skiy Rayon', 'RU.21.545702', 'ASCII:Komsomol''skiy Rayon;ID:545702', '22947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22947', '112', '24824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.545702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24825', '1079', '1', 'Komsomol''skiy Rayon', 'RU.16.545703', 'ASCII:Komsomol''skiy Rayon;ID:545703', '22948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22948', '112', '24825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.545703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24826', '1079', '1', 'Komarichskiy Rayon', 'RU.10.545945', 'ASCII:Komarichskiy Rayon;ID:545945', '22949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22949', '112', '24826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.545945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24827', '1079', '1', 'Kochevskiy Rayon', 'RU.90.546843', 'ASCII:Kochevskiy Rayon;ID:546843', '22950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22950', '112', '24827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.90.546843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24828', '1079', '1', 'Klintsovskiy Rayon', 'RU.10.547477', 'ASCII:Klintsovskiy Rayon;ID:547477', '22951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22951', '112', '24828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.547477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24829', '1079', '1', 'Klimovskiy Rayon', 'RU.10.547551', 'ASCII:Klimovskiy Rayon;ID:547551', '22952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22952', '112', '24829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.547551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24830', '1079', '1', 'Kletnyanskiy Rayon', 'RU.10.547680', 'ASCII:Kletnyanskiy Rayon;ID:547680', '22953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22953', '112', '24830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.547680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24831', '1079', '1', 'Kizlyarskiy Rayon', 'RU.17.547836', 'ASCII:Kizlyarskiy Rayon;ID:547836', '22954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22954', '112', '24831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.547836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24832', '1079', '1', 'Kizilyurtovskiy Rayon', 'RU.17.Kizilyurtovskiy Rayon', 'ASCII:Kizilyurtovskiy Rayon;ID:547846', '22955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22955', '112', '24832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Kizilyurtovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24833', '1079', '1', 'Kizil’skiy Rayon', 'RU.13.547854', 'ASCII:Kizil''skiy Rayon;ID:547854', '22956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22956', '112', '24833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.547854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24834', '1079', '1', 'Kiyasovskiy Rayon', 'RU.80.547926', 'ASCII:Kiyasovskiy Rayon;ID:547926', '22957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22957', '112', '24834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.80.547926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24835', '1079', '1', 'Kirovskiy Rayon', 'RU.25.548363', 'ASCII:Kirovskiy Rayon;ID:548363', '22958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22958', '112', '24835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.548363» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24836', '1079', '1', 'Kirovskiy Rayon', 'RU.68.548364', 'ASCII:Kirovskiy Rayon;ID:548364', '22959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22959', '112', '24836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.68.548364» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24837', '1079', '1', 'Kirovo-Chepetskiy Rayon', 'RU.33.548394', 'ASCII:Kirovo-Chepetskiy Rayon;ID:548394', '22960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22960', '112', '24837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.548394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24838', '1079', '1', 'Kingiseppskiy Rayon', 'RU.42.548601', 'ASCII:Kingiseppskiy Rayon;ID:548601', '22961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22961', '112', '24838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.42.548601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24839', '1079', '1', 'Kineshemskiy Rayon', 'RU.21.548606', 'ASCII:Kineshemskiy Rayon;ID:548606', '22962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22962', '112', '24839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.548606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24840', '1079', '1', 'Kinel’skiy Rayon', 'RU.65.548614', 'ASCII:Kinel''skiy Rayon;ID:548614', '22963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22963', '112', '24840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.65.548614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24841', '1079', '1', 'Khvalynskiy Rayon', 'RU.67.548980', 'ASCII:Khvalynskiy Rayon;ID:548980', '22964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22964', '112', '24841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.548980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24842', '1079', '1', 'Khunzakhskiy Rayon', 'RU.17.Khunzakhskiy Rayon', 'ASCII:Khunzakhskiy Rayon;ID:549104', '22965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22965', '112', '24842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Khunzakhskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24843', '1079', '1', 'Khivskiy Rayon', 'RU.17.550200', 'ASCII:Khivskiy Rayon;ID:550200', '22966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22966', '112', '24843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.550200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24844', '1079', '1', 'Khimkinskiy Rayon', 'RU.47.550279', 'ASCII:Khimkinskiy Rayon;ID:550279', '22967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22967', '112', '24844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.550279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24845', '1079', '1', 'Khaybullinskiy Rayon', 'RU.08.550406', 'ASCII:Khaybullinskiy Rayon;ID:550406', '22968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22968', '112', '24845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.08.550406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24846', '1079', '1', 'Khasavyurtovskiy Rayon', 'RU.17.Khasavyurtovskiy Rayon', 'ASCII:Khasavyurtovskiy Rayon;ID:550476', '22969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22969', '112', '24846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Khasavyurtovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24847', '1079', '1', 'Kharabalinskiy Rayon', 'RU.07.550669', 'ASCII:Kharabalinskiy Rayon;ID:550669', '22970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22970', '112', '24847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.550669» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24848', '1079', '1', 'Orlovskiy Rayon', 'RU.33.550782', 'ASCII:Orlovskiy Rayon;ID:550782', '22971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22971', '112', '24848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.550782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24849', '1079', '1', 'Kazbekovskiy Rayon', 'RU.17.Kazbekovskiy Rayon', 'ASCII:Kazbekovskiy Rayon;ID:551375', '22972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22972', '112', '24849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Kazbekovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24850', '1079', '1', 'Kaytagskiy Rayon', 'RU.17.551590', 'ASCII:Kaytagskiy Rayon;ID:551590', '22973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22973', '112', '24850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.551590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24851', '1079', '1', 'Kayakentskiy Rayon', 'RU.17.551645', 'ASCII:Kayakentskiy Rayon;ID:551645', '22974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22974', '112', '24851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.551645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24852', '1079', '1', 'Katav-Ivanovskiy Rayon', 'RU.13.551793', 'ASCII:Katav-Ivanovskiy Rayon;ID:551793', '22975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22975', '112', '24852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.551793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24853', '1079', '1', 'Karakulinskiy Rayon', 'RU.80.552829', 'ASCII:Karakulinskiy Rayon;ID:552829', '22976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22976', '112', '24853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.80.552829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24854', '1079', '1', 'Karachevskiy Rayon', 'RU.10.552912', 'ASCII:Karachevskiy Rayon;ID:552912', '22977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22977', '112', '24854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.552912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24855', '1079', '1', 'Kanashskiy Rayon', 'RU.16.553213', 'ASCII:Kanashskiy Rayon;ID:553213', '22978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22978', '112', '24855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.553213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24856', '1079', '1', 'Kamyzyakskiy Rayon', 'RU.07.553246', 'ASCII:Kamyzyakskiy Rayon;ID:553246', '22979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22979', '112', '24856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.553246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24857', '1079', '1', 'Kamsko-Ust''inskiy Rayon', 'RU.73.Kamsko-Ust''inskiy Rayon', 'ASCII:Kamsko-Ust''inskiy Rayon;ID:553346', '22980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22980', '112', '24857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Kamsko-Ust''inskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24858', '1079', '1', 'Kameshkirskiy Rayon', 'RU.57.553390', 'ASCII:Kameshkirskiy Rayon;ID:553390', '22981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22981', '112', '24858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.57.553390» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24859', '1079', '1', 'Kalininskiy Rayon', 'RU.77.554182', 'ASCII:Kalininskiy Rayon;ID:554182', '22982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22982', '112', '24859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.77.554182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24860', '1079', '1', 'Ivnyanskiy Rayon', 'RU.09.554969', 'ASCII:Ivnyanskiy Rayon;ID:554969', '22983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22983', '112', '24860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.554969» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24861', '1079', '1', 'Ivanovskiy Rayon', 'RU.21.555207', 'ASCII:Ivanovskiy Rayon;ID:555207', '22984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22984', '112', '24861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.555207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24862', '1079', '1', 'Irafskiy Rayon', 'RU.68.556219', 'ASCII:Irafskiy Rayon;ID:556219', '22985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22985', '112', '24862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.68.556219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24863', '1079', '1', 'Il''inskiy Rayon', 'RU.21.557129', 'ASCII:Il''inskiy Rayon;ID:557129', '22986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22986', '112', '24863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.557129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24864', '1079', '1', 'Ikryaninskiy Rayon', 'RU.07.557391', 'ASCII:Ikryaninskiy Rayon;ID:557391', '22987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22987', '112', '24864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.557391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24865', '1079', '1', 'Ibresinskiy Rayon', 'RU.16.557627', 'ASCII:Ibresinskiy Rayon;ID:557627', '22988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22988', '112', '24865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.557627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24866', '1079', '1', 'Gvardeyskiy Rayon', 'RU.23.557707', 'ASCII:Gvardeyskiy Rayon;ID:557707', '22989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22989', '112', '24866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.557707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24867', '1079', '1', 'Gusevskiy Rayon', 'RU.23.557841', 'ASCII:Gusevskiy Rayon;ID:557841', '22990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22990', '112', '24867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.557841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24868', '1079', '1', 'Gur''yevskiy Rayon', 'RU.23.557904', 'ASCII:Gur''yevskiy Rayon;ID:557904', '22991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22991', '112', '24868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.557904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24869', '1079', '1', 'Gunibskiy Rayon', 'RU.17.Gunibskiy Rayon', 'ASCII:Gunibskiy Rayon;ID:557977', '22992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22992', '112', '24869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Gunibskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24870', '1079', '1', 'Gumbetovskiy Rayon', 'RU.17.Gumbetovskiy Rayon', 'ASCII:Gumbetovskiy Rayon;ID:558024', '22993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22993', '112', '24870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Gumbetovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24871', '1079', '1', 'Gudermesskiy Rayon', 'RU.CI.Gudermesskiy Rayon', 'ASCII:Gudermesskiy Rayon;ID:558115', '22994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22994', '112', '24871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.CI.Gudermesskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24872', '1079', '1', 'Gubkinskiy Rayon', 'RU.09.558141', 'ASCII:Gubkinskiy Rayon;ID:558141', '22995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22995', '112', '24872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.558141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24873', '1079', '1', 'Gryazovetskiy Rayon', 'RU.85.558235', 'ASCII:Gryazovetskiy Rayon;ID:558235', '22996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22996', '112', '24873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.85.558235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24874', '1079', '1', 'Giaginskiy Rayon', 'RU.01.561514', 'ASCII:Giaginskiy Rayon;ID:561514', '22997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22997', '112', '24874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.01.561514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24875', '1079', '1', 'Gergebil''skiy Rayon', 'RU.17.Gergebil''skiy Rayon', 'ASCII:Gergebil''skiy Rayon;ID:561559', '22998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22998', '112', '24875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Gergebil''skiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24876', '1079', '1', 'Gayskiy Rayon', 'RU.55.561697', 'ASCII:Gayskiy Rayon;ID:561697', '22999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('22999', '112', '24876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.55.561697» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24877', '1079', '1', 'Gaynskiy Rayon', 'RU.90.561701', 'ASCII:Gaynskiy Rayon;ID:561701', '23000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23000', '112', '24877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.90.561701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24878', '1079', '1', 'Gavrilovo-Posadskiy Rayon', 'RU.21.561784', 'ASCII:Gavrilovo-Posadskiy Rayon;ID:561784', '23001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23001', '112', '24878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.561784» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24879', '1079', '1', 'Yugo-Zapadnyy Administrativnyy Okrug', 'RU.48.562221', 'ASCII:Yugo-Zapadnyy Administrativnyy Okrug;ID:562221', '23002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23002', '112', '24879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.48.562221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24880', '1079', '1', 'Furmanovskiy Rayon', 'RU.21.562305', 'ASCII:Furmanovskiy Rayon;ID:562305', '23003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23003', '112', '24880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.562305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24881', '1079', '1', 'Tsentral''nyy Administrativnyy Okrug', 'RU.48.562331', 'ASCII:Tsentral''nyy Administrativnyy Okrug;ID:562331', '23004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23004', '112', '24881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.48.562331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24882', '1079', '1', 'Firovskiy Rayon', 'RU.77.562626', 'ASCII:Firovskiy Rayon;ID:562626', '23005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23005', '112', '24882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.77.562626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24883', '1079', '1', 'Ferzikovskiy Rayon', 'RU.25.562871', 'ASCII:Ferzikovskiy Rayon;ID:562871', '23006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23006', '112', '24883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.562871» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24884', '1079', '1', 'Engel’sskiy Rayon', 'RU.67.563462', 'ASCII:Engel''sskiy Rayon;ID:563462', '23007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23007', '112', '24884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.563462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24885', '1079', '1', 'Dzerzhinskiy Rayon', 'RU.25.563697', 'ASCII:Dzerzhinskiy Rayon;ID:563697', '23008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23008', '112', '24885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.563697» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24886', '1079', '1', 'Dyat''kovskiy Rayon', 'RU.10.563821', 'ASCII:Dyat''kovskiy Rayon;ID:563821', '23009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23009', '112', '24886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.563821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24887', '1079', '1', 'Duminichskiy Rayon', 'RU.25.564189', 'ASCII:Duminichskiy Rayon;ID:564189', '23010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23010', '112', '24887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.564189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24888', '1079', '1', 'Dubrovskiy Rayon', 'RU.10.564343', 'ASCII:Dubrovskiy Rayon;ID:564343', '23011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23011', '112', '24888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.564343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24889', '1079', '1', 'Drozhzhanovskiy Rayon', 'RU.73.Drozhzhanovskiy Rayon', 'ASCII:Drozhzhanovskiy Rayon;ID:564943', '23012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23012', '112', '24889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Drozhzhanovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24890', '1079', '1', 'Domodedovskiy Rayon', 'RU.47.565379', 'ASCII:Domodedovskiy Rayon;ID:565379', '23013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23013', '112', '24890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.565379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24891', '1079', '1', 'Dobryanskiy Rayon', 'RU.90.565775', 'ASCII:Dobryanskiy Rayon;ID:565775', '23014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23014', '112', '24891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.90.565775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24892', '1079', '1', 'Diveyevskiy Rayon', 'RU.51.566164', 'ASCII:Diveyevskiy Rayon;ID:566164', '23015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23015', '112', '24892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.51.566164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24893', '1079', '1', 'Digorskiy Rayon', 'RU.68.566241', 'ASCII:Digorskiy Rayon;ID:566241', '23016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23016', '112', '24893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.68.566241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24894', '1079', '1', 'Derbentskiy Rayon', 'RU.17.566528', 'ASCII:Derbentskiy Rayon;ID:566528', '23017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23017', '112', '24894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.566528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24895', '1079', '1', 'Dakhadayevskiy Rayon', 'RU.17.567284', 'ASCII:Dakhadayevskiy Rayon;ID:567284', '23018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23018', '112', '24895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.567284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24896', '1079', '1', 'Chistopol''skiy Rayon', 'RU.73.Chistopol''skiy Rayon', 'ASCII:Chistopol''skiy Rayon;ID:567985', '23019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23019', '112', '24896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Chistopol''skiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24897', '1079', '1', 'Chernyanskiy Rayon', 'RU.09.568584', 'ASCII:Chernyanskiy Rayon;ID:568584', '23020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23020', '112', '24897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.568584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24898', '1079', '1', 'Chernyakhovskiy Rayon', 'RU.23.568594', 'ASCII:Chernyakhovskiy Rayon;ID:568594', '23021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23021', '112', '24898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.568594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24899', '1079', '1', 'Chernoyarskiy Rayon', 'RU.07.568698', 'ASCII:Chernoyarskiy Rayon;ID:568698', '23022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23022', '112', '24899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.568698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24900', '1079', '1', 'Cheremshanskiy Rayon', 'RU.73.Cheremshanskiy Rayon', 'ASCII:Cheremshanskiy Rayon;ID:569314', '23023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23023', '112', '24900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Cheremshanskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24901', '1079', '1', 'Cherdaklinskiy Rayon', 'RU.81.569361', 'ASCII:Cherdaklinskiy Rayon;ID:569361', '23024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23024', '112', '24901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.81.569361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24902', '1079', '1', 'Chekhovskiy Rayon', 'RU.47.569587', 'ASCII:Chekhovskiy Rayon;ID:569587', '23025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23025', '112', '24902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.569587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24903', '1079', '1', 'Chegemskiy Rayon', 'RU.22.569634', 'ASCII:Chegemskiy Rayon;ID:569634', '23026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23026', '112', '24903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.22.569634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24904', '1079', '1', 'Cheboksarskiy Rayon', 'RU.16.569698', 'ASCII:Cheboksarskiy Rayon;ID:569698', '23027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23027', '112', '24904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.569698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24905', '1079', '1', 'Charodinskiy Rayon', 'RU.17.569892', 'ASCII:Charodinskiy Rayon;ID:569892', '23028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23028', '112', '24905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.569892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24906', '1079', '1', 'Buynakskiy Rayon', 'RU.17.570478', 'ASCII:Buynakskiy Rayon;ID:570478', '23029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23029', '112', '24906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.570478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24907', '1079', '1', 'Buinskiy Rayon', 'RU.73.571151', 'ASCII:Buinskiy Rayon;ID:571151', '23030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23030', '112', '24907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.571151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24908', '1079', '1', 'Bugul''minskiy Rayon', 'RU.73.Bugul''minskiy Rayon', 'ASCII:Bugul''minskiy Rayon;ID:571167', '23031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23031', '112', '24908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Bugul''minskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24909', '1079', '1', 'Bryanskiy Rayon', 'RU.10.571467', 'ASCII:Bryanskiy Rayon;ID:571467', '23032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23032', '112', '24909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.571467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24910', '1079', '1', 'Brasovskiy Rayon', 'RU.10.571745', 'ASCII:Brasovskiy Rayon;ID:571745', '23033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23033', '112', '24910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.571745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24911', '1079', '1', 'Botlikhskiy Rayon', 'RU.17.Botlikhskiy Rayon', 'ASCII:Botlikhskiy Rayon;ID:571887', '23034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23034', '112', '24911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Botlikhskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24912', '1079', '1', 'Borskiy Rayon', 'RU.51.571988', 'ASCII:Borskiy Rayon;ID:571988', '23035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23035', '112', '24912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.51.571988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24913', '1079', '1', 'Borovichskiy Rayon', 'RU.52.572153', 'ASCII:Borovichskiy Rayon;ID:572153', '23036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23036', '112', '24913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.52.572153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24914', '1079', '1', 'Bondarskiy Rayon', 'RU.72.572682', 'ASCII:Bondarskiy Rayon;ID:572682', '23037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23037', '112', '24914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.72.572682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24915', '1079', '1', 'Bologovskiy Rayon', 'RU.77.575351', 'ASCII:Bologovskiy Rayon;ID:575351', '23038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23038', '112', '24915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.77.575351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24916', '1079', '1', 'Belokatayskiy Rayon', 'RU.08.577943', 'ASCII:Belokatayskiy Rayon;ID:577943', '23039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23039', '112', '24916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.08.577943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24917', '1079', '1', 'Bazarno-Karabulakskiy Rayon', 'RU.67.578469', 'ASCII:Bazarno-Karabulakskiy Rayon;ID:578469', '23040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23040', '112', '24917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.578469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24918', '1079', '1', 'Bavlinskiy Rayon', 'RU.73.Bavlinskiy Rayon', 'ASCII:Bavlinskiy Rayon;ID:578639', '23041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23041', '112', '24918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Bavlinskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24919', '1079', '1', 'Batyrevskiy Rayon', 'RU.16.578658', 'ASCII:Batyrevskiy Rayon;ID:578658', '23042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23042', '112', '24919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.578658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24920', '1079', '1', 'Baryatinskiy Rayon', 'RU.25.578944', 'ASCII:Baryatinskiy Rayon;ID:578944', '23043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23043', '112', '24920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.578944» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24921', '1079', '1', 'Baltayskiy Rayon', 'RU.67.579379', 'ASCII:Baltayskiy Rayon;ID:579379', '23044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23044', '112', '24921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.579379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24922', '1079', '1', 'Baltasinskiy Rayon', 'RU.73.Baltasinskiy Rayon', 'ASCII:Baltasinskiy Rayon;ID:579382', '23045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23045', '112', '24922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Baltasinskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24923', '1079', '1', 'Balashikhinskiy Rayon', 'RU.47.579462', 'ASCII:Balashikhinskiy Rayon;ID:579462', '23046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23046', '112', '24923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.47.579462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24924', '1079', '1', 'Baksanskiy Rayon', 'RU.22.579567', 'ASCII:Baksanskiy Rayon;ID:579567', '23047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23047', '112', '24924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.22.579567» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24925', '1079', '1', 'Bagrationovskiy Rayon', 'RU.23.579759', 'ASCII:Bagrationovskiy Rayon;ID:579759', '23048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23048', '112', '24925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.579759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24926', '1079', '1', 'Babyninskiy Rayon', 'RU.25.579834', 'ASCII:Babyninskiy Rayon;ID:579834', '23049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23049', '112', '24926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.25.579834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24927', '1079', '1', 'Severo-Vostochnyy Administrativnyy Okrug', 'RU.48.579866', 'ASCII:Severo-Vostochnyy Administrativnyy Okrug;ID:579866', '23050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23050', '112', '24927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.48.579866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24928', '1079', '1', 'Babayurtovskiy Rayon', 'RU.17.579998', 'ASCII:Babayurtovskiy Rayon;ID:579998', '23051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23051', '112', '24928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.579998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24929', '1079', '1', 'Aznakayevskiy Rayon', 'RU.73.Aznakayevskiy Rayon', 'ASCII:Aznakayevskiy Rayon;ID:580061', '23052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23052', '112', '24929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Aznakayevskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24930', '1079', '1', 'Atyur’yevskiy Rayon', 'RU.46.580367', 'ASCII:Atyur''yevskiy Rayon;ID:580367', '23053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23053', '112', '24930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.46.580367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24931', '1079', '1', 'Atkarskiy Rayon', 'RU.67.580419', 'ASCII:Atkarskiy Rayon;ID:580419', '23054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23054', '112', '24931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.67.580419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24932', '1079', '1', 'Ashinskiy Rayon', 'RU.13.580620', 'ASCII:Ashinskiy Rayon;ID:580620', '23055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23055', '112', '24932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.580620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24933', '1079', '1', 'Arzamasskiy Rayon', 'RU.51.580722', 'ASCII:Arzamasskiy Rayon;ID:580722', '23056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23056', '112', '24933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.51.580722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24934', '1079', '1', 'Arskiy Rayon', 'RU.73.Arskiy Rayon', 'ASCII:Arskiy Rayon;ID:580846', '23057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23057', '112', '24934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Arskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24935', '1079', '1', 'Ardonskiy Rayon', 'RU.68.581175', 'ASCII:Ardonskiy Rayon;ID:581175', '23058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23058', '112', '24935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.68.581175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24936', '1079', '1', 'Ardatovskiy Rayon', 'RU.51.581181', 'ASCII:Ardatovskiy Rayon;ID:581181', '23059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23059', '112', '24936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.51.581181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24937', '1079', '1', 'Arbazhskiy Rayon', 'RU.33.581227', 'ASCII:Arbazhskiy Rayon;ID:581227', '23060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23060', '112', '24937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.33.581227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24938', '1079', '1', 'Apastovskiy Rayon', 'RU.73.Apastovskiy Rayon', 'ASCII:Apastovskiy Rayon;ID:581358', '23061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23061', '112', '24938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Apastovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24939', '1079', '1', 'Al''met''yevskiy Rayon', 'RU.73.Al''met''yevskiy Rayon', 'ASCII:Al''met''yevskiy Rayon;ID:582431', '23062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23062', '112', '24939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Al''met''yevskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24940', '1079', '1', 'Al''keyevskiy Rayon', 'RU.73.Al''keyevskiy Rayon', 'ASCII:Al''keyevskiy Rayon;ID:582497', '23063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23063', '112', '24940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Al''keyevskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24941', '1079', '1', 'Alikovskiy Rayon', 'RU.16.582532', 'ASCII:Alikovskiy Rayon;ID:582532', '23064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23064', '112', '24941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.582532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24942', '1079', '1', 'Alekseyevskiy Rayon', 'RU.73.Alekseyevskiy Rayon', 'ASCII:Alekseyevskiy Rayon;ID:582785', '23065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23065', '112', '24942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Alekseyevskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24943', '1079', '1', 'Alekseyevskiy Rayon', 'RU.09.582787', 'ASCII:Alekseyevskiy Rayon;ID:582787', '23066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23066', '112', '24943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.582787» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24944', '1079', '1', 'Alatyrskiy Rayon', 'RU.16.583435', 'ASCII:Alatyrskiy Rayon;ID:583435', '23067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23067', '112', '24944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.583435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24945', '1079', '1', 'Alagirskiy Rayon', 'RU.68.583478', 'ASCII:Alagirskiy Rayon;ID:583478', '23068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23068', '112', '24945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.68.583478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24946', '1079', '1', 'Akushinskiy Rayon', 'RU.17.583511', 'ASCII:Akushinskiy Rayon;ID:583511', '23069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23069', '112', '24946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.583511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24947', '1079', '1', 'Aktanyshskiy Rayon', 'RU.73.Aktanyshskiy Rayon', 'ASCII:Aktanyshskiy Rayon;ID:583576', '23070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23070', '112', '24947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Aktanyshskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24948', '1079', '1', 'Aksubayevskiy Rayon', 'RU.73.Aksubayevskiy Rayon', 'ASCII:Aksubayevskiy Rayon;ID:583581', '23071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23071', '112', '24948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Aksubayevskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24949', '1079', '1', 'Akhvakhskiy Rayon', 'RU.17.Akhvakhskiy Rayon', 'ASCII:Akhvakhskiy Rayon;ID:583776', '23072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23072', '112', '24949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Akhvakhskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24950', '1079', '1', 'Akhtynskiy Rayon', 'RU.17.583791', 'ASCII:Akhtynskiy Rayon;ID:583791', '23073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23073', '112', '24950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.583791» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24951', '1079', '1', 'Akhtubinskiy Rayon', 'RU.07.583796', 'ASCII:Akhtubinskiy Rayon;ID:583796', '23074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23074', '112', '24951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.583796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24952', '1079', '1', 'Agul''skiy Rayon', 'RU.17.583977', 'ASCII:Agul''skiy Rayon;ID:583977', '23075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23075', '112', '24952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.583977» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24953', '1079', '1', 'Agryzskiy Rayon', 'RU.73.Agryzskiy Rayon', 'ASCII:Agryzskiy Rayon;ID:583978', '23076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23076', '112', '24953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Agryzskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24954', '1079', '1', 'Agapovskiy Rayon', 'RU.13.584048', 'ASCII:Agapovskiy Rayon;ID:584048', '23077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23077', '112', '24954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.584048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24955', '1079', '1', 'Achkhoy-Martanovskiy Rayon', 'RU.CI.Achkhoy-Martanovskiy Rayon', 'ASCII:Achkhoy-Martanovskiy Rayon;ID:584297', '23078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23078', '112', '24955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.CI.Achkhoy-Martanovskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24956', '1079', '1', 'Takhtamukayskiy Rayon', 'RU.01.824962', 'ASCII:Takhtamukayskiy Rayon;ID:824962', '23079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23079', '112', '24956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.01.824962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24957', '1079', '1', 'Gorod Maykop', 'RU.01.824963', 'ASCII:Gorod Maykop;ID:824963', '23080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23080', '112', '24957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.01.824963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24958', '1079', '1', 'Gorod Astrakhan''', 'RU.07.824964', 'ASCII:Gorod Astrakhan'';ID:824964', '23081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23081', '112', '24958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.07.824964» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24959', '1079', '1', 'Gorod Belgorod', 'RU.09.824987', 'ASCII:Gorod Belgorod;ID:824987', '23082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23082', '112', '24959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.824987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24960', '1079', '1', 'Gorod Shebekino', 'RU.09.824988', 'ASCII:Gorod Shebekino;ID:824988', '23083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23083', '112', '24960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.824988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24961', '1079', '1', 'Gorod Alekseyevka', 'RU.09.824989', 'ASCII:Gorod Alekseyevka;ID:824989', '23084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23084', '112', '24961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.824989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24962', '1079', '1', 'Grayvoronskiy Rayon', 'RU.09.824990', 'ASCII:Grayvoronskiy Rayon;ID:824990', '23085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23085', '112', '24962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.824990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24963', '1079', '1', 'Krasnenskiy Rayon', 'RU.09.824991', 'ASCII:Krasnenskiy Rayon;ID:824991', '23086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23086', '112', '24963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.824991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24964', '1079', '1', 'Krasnoyaruzhskiy Rayon', 'RU.09.824992', 'ASCII:Krasnoyaruzhskiy Rayon;ID:824992', '23087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23087', '112', '24964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.09.824992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24965', '1079', '1', 'Gordeyevskiy Rayon', 'RU.10.824993', 'ASCII:Gordeyevskiy Rayon;ID:824993', '23088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23088', '112', '24965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.824993» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24966', '1079', '1', 'Zhiryatinskiy Rayon', 'RU.10.824994', 'ASCII:Zhiryatinskiy Rayon;ID:824994', '23089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23089', '112', '24966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.824994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24967', '1079', '1', 'Zlynkovskiy Rayon', 'RU.10.824995', 'ASCII:Zlynkovskiy Rayon;ID:824995', '23090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23090', '112', '24967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.824995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24968', '1079', '1', 'Gorod Novozybkov', 'RU.10.824996', 'ASCII:Gorod Novozybkov;ID:824996', '23091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23091', '112', '24968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.824996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24969', '1079', '1', 'Gorod Bryansk', 'RU.10.824997', 'ASCII:Gorod Bryansk;ID:824997', '23092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23092', '112', '24969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.824997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24970', '1079', '1', 'Gorod Dyat''kovo', 'RU.10.824998', 'ASCII:Gorod Dyat''kovo;ID:824998', '23093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23093', '112', '24970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.10.824998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24971', '1079', '1', 'Gorod Zlatoust', 'RU.13.825029', 'ASCII:Gorod Zlatoust;ID:825029', '23094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23094', '112', '24971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.825029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24972', '1079', '1', 'Gorod Magnitogorsk', 'RU.13.825030', 'ASCII:Gorod Magnitogorsk;ID:825030', '23095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23095', '112', '24972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.825030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24973', '1079', '1', 'Gorod Ust''-Katav', 'RU.13.825031', 'ASCII:Gorod Ust''-Katav;ID:825031', '23096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23096', '112', '24973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.825031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24974', '1079', '1', 'Krasnochetayskiy Rayon', 'RU.16.825032', 'ASCII:Krasnochetayskiy Rayon;ID:825032', '23097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23097', '112', '24974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.16.825032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24975', '1079', '1', 'Dokuzparinskiy Rayon', 'RU.17.825033', 'ASCII:Dokuzparinskiy Rayon;ID:825033', '23098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23098', '112', '24975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.825033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24976', '1079', '1', 'Kumtorkalinskiy Rayon', 'RU.17.825034', 'ASCII:Kumtorkalinskiy Rayon;ID:825034', '23099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23099', '112', '24976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.825034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24977', '1079', '1', 'Gorod Vichuga', 'RU.21.825091', 'ASCII:Gorod Vichuga;ID:825091', '23100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23100', '112', '24977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.825091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24978', '1079', '1', 'Gorod Kineshma', 'RU.21.825092', 'ASCII:Gorod Kineshma;ID:825092', '23101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23101', '112', '24978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.825092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24979', '1079', '1', 'Gorod Shuya', 'RU.21.825093', 'ASCII:Gorod Shuya;ID:825093', '23102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23102', '112', '24979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.825093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24980', '1079', '1', 'Gorod Ivanovo', 'RU.21.825094', 'ASCII:Gorod Ivanovo;ID:825094', '23103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23103', '112', '24980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.825094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24981', '1079', '1', 'Gorod Teykovo', 'RU.21.825095', 'ASCII:Gorod Teykovo;ID:825095', '23104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23104', '112', '24981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.825095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24982', '1079', '1', 'Lezhnevskiy Rayon', 'RU.21.825096', 'ASCII:Lezhnevskiy Rayon;ID:825096', '23105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23105', '112', '24982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.825096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24983', '1079', '1', 'El''brusskiy Rayon', 'RU.22.825097', 'ASCII:El''brusskiy Rayon;ID:825097', '23106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23106', '112', '24983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.22.825097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24984', '1079', '1', 'Gorod Nal''chik', 'RU.22.825098', 'ASCII:Gorod Nal''chik;ID:825098', '23107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23107', '112', '24984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.22.825098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24985', '1079', '1', 'Gorod Sovetsk', 'RU.23.825113', 'ASCII:Gorod Sovetsk;ID:825113', '23108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23108', '112', '24985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.825113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24986', '1079', '1', 'Gorod Neman', 'RU.23.825114', 'ASCII:Gorod Neman;ID:825114', '23109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23109', '112', '24986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.825114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24987', '1079', '1', 'Gorod Svetlogorsk', 'RU.23.825115', 'ASCII:Gorod Svetlogorsk;ID:825115', '23110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23110', '112', '24987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.825115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24988', '1079', '1', 'Gorod Pionerskiy', 'RU.23.825116', 'ASCII:Gorod Pionerskiy;ID:825116', '23111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23111', '112', '24988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.825116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24989', '1079', '1', 'Gorod Svetlyy', 'RU.23.825117', 'ASCII:Gorod Svetlyy;ID:825117', '23112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23112', '112', '24989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.825117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24990', '1079', '1', 'Gorod Kaliningrad', 'RU.23.825118', 'ASCII:Gorod Kaliningrad;ID:825118', '23113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23113', '112', '24990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.825118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24991', '1079', '1', 'Gorod Chernyakhovsk', 'RU.23.825119', 'ASCII:Gorod Chernyakhovsk;ID:825119', '23114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23114', '112', '24991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.825119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24992', '1079', '1', 'Gorod Gusev', 'RU.23.825120', 'ASCII:Gorod Gusev;ID:825120', '23115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23115', '112', '24992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.825120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24993', '1079', '1', 'Gorod Makhachkala', 'RU.17.826309', 'ASCII:Gorod Makhachkala;ID:826309', '23116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23116', '112', '24993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.826309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24994', '1079', '1', 'Gorod Furmanovo', 'RU.21.826310', 'ASCII:Gorod Furmanovo;ID:826310', '23117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23117', '112', '24994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.21.826310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24995', '1079', '1', 'Bezhtinskiy Uchastok Rayon', 'RU.17.Bezhtinskiy Uchastok Rayon', 'ASCII:Bezhtinskiy Uchastok Rayon;ID:830805', '23118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23118', '112', '24995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Bezhtinskiy Uchastok Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24996', '1079', '1', 'Gorod Buynaksk', 'RU.17.830807', 'ASCII:Gorod Buynaksk;ID:830807', '23119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23119', '112', '24996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.830807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24997', '1079', '1', 'Gorod Derbent', 'RU.17.830809', 'ASCII:Gorod Derbent;ID:830809', '23120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23120', '112', '24997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.830809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24998', '1079', '1', 'Gorod Dagestanskiye Ogni', 'RU.17.830810', 'ASCII:Gorod Dagestanskiye Ogni;ID:830810', '23121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23121', '112', '24998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.830810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('24999', '1079', '1', 'Gorod Izberbash', 'RU.17.830811', 'ASCII:Gorod Izberbash;ID:830811', '23122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23122', '112', '24999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.830811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25000', '1079', '1', 'Gorod Kaspiysk', 'RU.17.830812', 'ASCII:Gorod Kaspiysk;ID:830812', '23123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23123', '112', '25000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.830812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25001', '1079', '1', 'Gorod Kizilyurt', 'RU.17.Gorod Kizilyurt', 'ASCII:Gorod Kizilyurt;ID:830813', '23124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23124', '112', '25001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Gorod Kizilyurt» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25002', '1079', '1', 'Gorod Kizlyar', 'RU.17.830814', 'ASCII:Gorod Kizlyar;ID:830814', '23125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23125', '112', '25002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.830814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25003', '1079', '1', 'Gorod Khasavyurt', 'RU.17.Khasavyurt, Gorod', 'ASCII:Gorod Khasavyurt;ID:830815', '23126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23126', '112', '25003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.Khasavyurt, Gorod» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25004', '1079', '1', 'Gorod Yuzhno-Sukhokumsk', 'RU.17.830816', 'ASCII:Gorod Yuzhno-Sukhokumsk;ID:830816', '23127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23127', '112', '25004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.17.830816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25005', '1079', '1', 'Gorod Kazan''', 'RU.73.Gorod Kazan''', 'ASCII:Gorod Kazan'';ID:862913', '23128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23128', '112', '25005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Gorod Kazan''» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25006', '1079', '1', 'Atninskiy Rayon', 'RU.73.Atninskiy Rayon', 'ASCII:Atninskiy Rayon;ID:862914', '23129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23129', '112', '25006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Atninskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25007', '1079', '1', 'Kaybitskiy Rayon', 'RU.73.Kaybitskiy Rayon', 'ASCII:Kaybitskiy Rayon;ID:862915', '23130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23130', '112', '25007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Kaybitskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25008', '1079', '1', 'Mendeleyevskiy Rayon', 'RU.73.Mendeleyevskiy Rayon', 'ASCII:Mendeleyevskiy Rayon;ID:862916', '23131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23131', '112', '25008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Mendeleyevskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25009', '1079', '1', 'Novosheshminskiy Rayon', 'RU.73.Novosheshminskiy Rayon', 'ASCII:Novosheshminskiy Rayon;ID:862917', '23132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23132', '112', '25009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Novosheshminskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25010', '1079', '1', 'Tyulyachinskiy Rayon', 'RU.73.Tyulyachinskiy Rayon', 'ASCII:Tyulyachinskiy Rayon;ID:862918', '23133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23133', '112', '25010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Tyulyachinskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25011', '1079', '1', 'Yutazinskiy Rayon', 'RU.73.Yutazinskiy Rayon', 'ASCII:Yutazinskiy Rayon;ID:862919', '23134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23134', '112', '25011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Yutazinskiy Rayon» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25012', '1079', '1', 'Gorod Al''met''yevsk', 'RU.73.Gorod Al''met''yevsk', 'ASCII:Gorod Al''met''yevsk;ID:862920', '23135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23135', '112', '25012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Gorod Al''met''yevsk» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25013', '1079', '1', 'Gorod Aznakayevo', 'RU.73.Gorod Aznakayevo', 'ASCII:Aznakayevo;ID:862921', '23136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23136', '112', '25013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Gorod Aznakayevo» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25014', '1079', '1', 'Gorod Bugul''ma', 'RU.73.862922', 'ASCII:Gorod Bugul''ma;ID:862922', '23137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23137', '112', '25014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.862922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25015', '1079', '1', 'Gorod Yelabuga', 'RU.73.862923', 'ASCII:Gorod Yelabuga;ID:862923', '23138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23138', '112', '25015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.862923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25016', '1079', '1', 'Gorod Zainsk', 'RU.73.862924', 'ASCII:Gorod Zainsk;ID:862924', '23139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23139', '112', '25016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.862924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25017', '1079', '1', 'Gorod Zelënodol''sk', 'RU.73.862925', 'ASCII:Gorod Zelenodol''sk;ID:862925', '23140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23140', '112', '25017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.862925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25018', '1079', '1', 'Gorod Leninogorsk', 'RU.73.862926', 'ASCII:Gorod Leninogorsk;ID:862926', '23141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23141', '112', '25018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.862926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25019', '1079', '1', 'Gorod Naberezhnyye Chelny', 'RU.73.862927', 'ASCII:Gorod Naberezhnyye Chelny;ID:862927', '23142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23142', '112', '25019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.862927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25020', '1079', '1', 'Gorod Nizhnekamsk', 'RU.73.862928', 'ASCII:Gorod Nizhnekamsk;ID:862928', '23143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23143', '112', '25020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.862928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25021', '1079', '1', 'Gorod Chistopol''', 'RU.73.862929', 'ASCII:Gorod Chistopol'';ID:862929', '23144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23144', '112', '25021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.862929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25022', '1079', '1', 'Gorod Buinsk', 'RU.73.862932', 'ASCII:Gorod Buinsk;ID:862932', '23145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23145', '112', '25022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.862932» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25023', '1079', '1', 'Gorod Bavly', 'RU.73.Gorod Bavly', 'ASCII:Gorod Bavly;ID:862934', '23146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23146', '112', '25023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Gorod Bavly» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25024', '1079', '1', 'Gorod Nurlat', 'RU.73.Gorod Nurlat', 'ASCII:Gorod Nurlat;ID:862935', '23147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23147', '112', '25024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.73.Gorod Nurlat» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25025', '1079', '1', 'Zonal''nyy Rayon', 'RU.04.1484980', 'ASCII:Zonal''nyy Rayon;ID:1484980', '23148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23148', '112', '25025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1484980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25026', '1079', '1', 'Zmeinogorskiy Rayon', 'RU.04.1485041', 'ASCII:Zmeinogorskiy Rayon;ID:1485041', '23149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23149', '112', '25026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1485041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25027', '1079', '1', 'Zdvinskiy Rayon', 'RU.53.1485310', 'ASCII:Zdvinskiy Rayon;ID:1485310', '23150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23150', '112', '25027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1485310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25028', '1079', '1', 'Zav''yalovskiy Rayon', 'RU.04.1485333', 'ASCII:Zav''yalovskiy Rayon;ID:1485333', '23151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23151', '112', '25028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1485333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25029', '1079', '1', 'Zarinskiy Rayon', 'RU.04.1485438', 'ASCII:Zarinskiy Rayon;ID:1485438', '23152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23152', '112', '25029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1485438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25030', '1079', '1', 'Zalesovskiy Rayon', 'RU.04.1485525', 'ASCII:Zalesovskiy Rayon;ID:1485525', '23153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23153', '112', '25030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1485525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25031', '1079', '1', 'Yurginskiy Rayon', 'RU.29.1485714', 'ASCII:Yurginskiy Rayon;ID:1485714', '23154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23154', '112', '25031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.29.1485714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25032', '1079', '1', 'Yetkul''skiy Rayon', 'RU.13.1485846', 'ASCII:Yetkul''skiy Rayon;ID:1485846', '23155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23155', '112', '25032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1485846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25033', '1079', '1', 'Yel''tsovskiy Rayon', 'RU.04.1486053', 'ASCII:Yel''tsovskiy Rayon;ID:1486053', '23156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23156', '112', '25033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1486053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25034', '1079', '1', 'Yegor''yevskiy Rayon', 'RU.04.1486214', 'ASCII:Yegor''yevskiy Rayon;ID:1486214', '23157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23157', '112', '25034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1486214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25035', '1079', '1', 'Volchikhinskiy Rayon', 'RU.04.1486980', 'ASCII:Volchikhinskiy Rayon;ID:1486980', '23158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23158', '112', '25035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1486980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25036', '1079', '1', 'Vengerovskiy Rayon', 'RU.53.1487613', 'ASCII:Vengerovskiy Rayon;ID:1487613', '23159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23159', '112', '25036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1487613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25037', '1079', '1', 'Varnenskiy Rayon', 'RU.13.1487759', 'ASCII:Varnenskiy Rayon;ID:1487759', '23160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23160', '112', '25037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1487759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25038', '1079', '1', 'Uzhurskiy Rayon', 'RU.39.1487880', 'ASCII:Uzhurskiy Rayon;ID:1487880', '23161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23161', '112', '25038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.39.1487880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25039', '1079', '1', 'Uyskiy Rayon', 'RU.13.1487907', 'ASCII:Uyskiy Rayon;ID:1487907', '23162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23162', '112', '25039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1487907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25040', '1079', '1', 'Uvel''skiy Rayon', 'RU.13.1487930', 'ASCII:Uvel''skiy Rayon;ID:1487930', '23163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23163', '112', '25040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1487930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25041', '1079', '1', 'Ust''-Tarkskiy Rayon', 'RU.53.1488072', 'ASCII:Ust''-Tarkskiy Rayon;ID:1488072', '23164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23164', '112', '25041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1488072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25042', '1079', '1', 'Ust''-Pristanskiy Rayon', 'RU.04.1488114', 'ASCII:Ust''-Pristanskiy Rayon;ID:1488114', '23165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23165', '112', '25042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1488114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25043', '1079', '1', 'Ust''-Koksinskiy Rayon', 'RU.03.1488166', 'ASCII:Ust''-Koksinskiy Rayon;ID:1488166', '23166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23166', '112', '25043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.03.1488166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25044', '1079', '1', 'Ust''-Kanskiy Rayon', 'RU.03.1488185', 'ASCII:Ust''-Kanskiy Rayon;ID:1488185', '23167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23167', '112', '25044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.03.1488185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25045', '1079', '1', 'Ust''-Kalmanskiy Rayon', 'RU.04.1488199', 'ASCII:Ust''-Kalmanskiy Rayon;ID:1488199', '23168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23168', '112', '25045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1488199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25046', '1079', '1', 'Ust''-Abakanskiy Rayon', 'RU.31.1488271', 'ASCII:Ust''-Abakanskiy Rayon;ID:1488271', '23169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23169', '112', '25046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1488271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25047', '1079', '1', 'Ulaganskiy Rayon', 'RU.03.1488576', 'ASCII:Ulaganskiy Rayon;ID:1488576', '23170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23170', '112', '25047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.03.1488576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25048', '1079', '1', 'Uglovskiy Rayon', 'RU.04.1488635', 'ASCII:Uglovskiy Rayon;ID:1488635', '23171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23171', '112', '25048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1488635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25049', '1079', '1', 'Ubinskiy Rayon', 'RU.53.1488709', 'ASCII:Ubinskiy Rayon;ID:1488709', '23172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23172', '112', '25049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1488709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25050', '1079', '1', 'Tyumentsevskiy Rayon', 'RU.04.1488739', 'ASCII:Tyumentsevskiy Rayon;ID:1488739', '23173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23173', '112', '25050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1488739» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25051', '1079', '1', 'Turochakskiy Rayon', 'RU.03.1488919', 'ASCII:Turochakskiy Rayon;ID:1488919', '23174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23174', '112', '25051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.03.1488919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25052', '1079', '1', 'Tselinnyy Rayon', 'RU.04.1489128', 'ASCII:Tselinnyy Rayon;ID:1489128', '23175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23175', '112', '25052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1489128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25053', '1079', '1', 'Troitskiy Rayon', 'RU.13.1489213', 'ASCII:Troitskiy Rayon;ID:1489213', '23176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23176', '112', '25053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1489213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25054', '1079', '1', 'Troitskiy Rayon', 'RU.04.1489214', 'ASCII:Troitskiy Rayon;ID:1489214', '23177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23177', '112', '25054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1489214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25055', '1079', '1', 'Tret''yakovskiy Rayon', 'RU.04.1489264', 'ASCII:Tret''yakovskiy Rayon;ID:1489264', '23178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23178', '112', '25055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1489264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25056', '1079', '1', 'Topchikhinskiy Rayon', 'RU.04.1489397', 'ASCII:Topchikhinskiy Rayon;ID:1489397', '23179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23179', '112', '25056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1489397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25057', '1079', '1', 'Tomskiy Rayon', 'RU.75.1489419', 'ASCII:Tomskiy Rayon;ID:1489419', '23180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23180', '112', '25057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.75.1489419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25058', '1079', '1', 'Togul''skiy Rayon', 'RU.04.1489502', 'ASCII:Togul''skiy Rayon;ID:1489502', '23181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23181', '112', '25058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1489502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25059', '1079', '1', 'Toguchinskiy Rayon', 'RU.53.1489505', 'ASCII:Toguchinskiy Rayon;ID:1489505', '23182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23182', '112', '25059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1489505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25060', '1079', '1', 'Tayshetskiy Rayon', 'RU.20.1489868', 'ASCII:Tayshetskiy Rayon;ID:1489868', '23183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23183', '112', '25060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.1489868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25061', '1079', '1', 'Tatarskiy Rayon', 'RU.53.1489996', 'ASCII:Tatarskiy Rayon;ID:1489996', '23184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23184', '112', '25061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1489996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25062', '1079', '1', 'Tashtypskiy Rayon', 'RU.31.1490033', 'ASCII:Tashtypskiy Rayon;ID:1490033', '23185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23185', '112', '25062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1490033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25063', '1079', '1', 'Tal’menskiy Rayon', 'RU.04.1490259', 'ASCII:Tal''menskiy Rayon;ID:1490259', '23186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23186', '112', '25063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1490259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25064', '1079', '1', 'Tabunskiy Rayon', 'RU.04.1490357', 'ASCII:Tabunskiy Rayon;ID:1490357', '23187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23187', '112', '25064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1490357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25065', '1079', '1', 'Sysertskiy Rayon', 'RU.71.1490399', 'ASCII:Sysertskiy Rayon;ID:1490399', '23188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23188', '112', '25065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.71.1490399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25066', '1079', '1', 'Suzunskiy Rayon', 'RU.53.1490549', 'ASCII:Suzunskiy Rayon;ID:1490549', '23189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23189', '112', '25066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1490549» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25067', '1079', '1', 'Sukholozhskiy Rayon', 'RU.71.1490708', 'ASCII:Sukholozhskiy Rayon;ID:1490708', '23190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23190', '112', '25067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.71.1490708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25068', '1079', '1', 'Sovetskiy Rayon', 'RU.04.1491227', 'ASCII:Sovetskiy Rayon;ID:1491227', '23191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23191', '112', '25068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1491227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25069', '1079', '1', 'Sosnovskiy Rayon', 'RU.13.1491282', 'ASCII:Sosnovskiy Rayon;ID:1491282', '23192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23192', '112', '25069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1491282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25070', '1079', '1', 'Soltonskiy Rayon', 'RU.04.1491425', 'ASCII:Soltonskiy Rayon;ID:1491425', '23193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23193', '112', '25070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1491425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25071', '1079', '1', 'Soloneshenskiy Rayon', 'RU.04.1491462', 'ASCII:Soloneshenskiy Rayon;ID:1491462', '23194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23194', '112', '25071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1491462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25072', '1079', '1', 'Smolenskiy Rayon', 'RU.04.1491634', 'ASCII:Smolenskiy Rayon;ID:1491634', '23195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23195', '112', '25072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1491634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25073', '1079', '1', 'Slavgorodskiy Rayon', 'RU.04.1491705', 'ASCII:Slavgorodskiy Rayon;ID:1491705', '23196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23196', '112', '25073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1491705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25074', '1079', '1', 'Shirinskiy Rayon', 'RU.31.1492146', 'ASCII:Shirinskiy Rayon;ID:1492146', '23197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23197', '112', '25074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1492146» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25075', '1079', '1', 'Shipunovskiy Rayon', 'RU.04.1492151', 'ASCII:Shipunovskiy Rayon;ID:1492151', '23198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23198', '112', '25075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1492151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25076', '1079', '1', 'Shebalinskiy Rayon', 'RU.03.1492297', 'ASCII:Shebalinskiy Rayon;ID:1492297', '23199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23199', '112', '25076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.03.1492297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25077', '1079', '1', 'Sharypovskiy Rayon', 'RU.39.1492400', 'ASCII:Sharypovskiy Rayon;ID:1492400', '23200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23200', '112', '25077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.39.1492400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25078', '1079', '1', 'Severnyy Rayon', 'RU.53.1492577', 'ASCII:Severnyy Rayon;ID:1492577', '23201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23201', '112', '25078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1492577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25079', '1079', '1', 'Rubtsovskiy Rayon', 'RU.04.1493465', 'ASCII:Rubtsovskiy Rayon;ID:1493465', '23202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23202', '112', '25079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1493465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25080', '1079', '1', 'Romanovskiy Rayon', 'RU.04.1493563', 'ASCII:Romanovskiy Rayon;ID:1493563', '23203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23203', '112', '25080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1493563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25081', '1079', '1', 'Rodinskiy Rayon', 'RU.04.1493622', 'ASCII:Rodinskiy Rayon;ID:1493622', '23204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23204', '112', '25081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1493622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25082', '1079', '1', 'Rebrikhinskiy Rayon', 'RU.04.1493721', 'ASCII:Rebrikhinskiy Rayon;ID:1493721', '23205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23205', '112', '25082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1493721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25083', '1079', '1', 'Pospelikhinskiy Rayon', 'RU.04.1494329', 'ASCII:Pospelikhinskiy Rayon;ID:1494329', '23206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23206', '112', '25083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1494329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25084', '1079', '1', 'Petropavlovskiy Rayon', 'RU.04.1495102', 'ASCII:Petropavlovskiy Rayon;ID:1495102', '23207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23207', '112', '25084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1495102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25085', '1079', '1', 'Pervomayskiy Rayon', 'RU.04.1495265', 'ASCII:Pervomayskiy Rayon;ID:1495265', '23208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23208', '112', '25085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1495265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25086', '1079', '1', 'Pavlovskiy Rayon', 'RU.04.1495439', 'ASCII:Pavlovskiy Rayon;ID:1495439', '23209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23209', '112', '25086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1495439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25087', '1079', '1', 'Pankrushikhinskiy Rayon', 'RU.04.1495612', 'ASCII:Pankrushikhinskiy Rayon;ID:1495612', '23210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23210', '112', '25087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1495612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25088', '1079', '1', 'Ordzhonikidzevskiy Rayon', 'RU.31.1496096', 'ASCII:Ordzhonikidzevskiy Rayon;ID:1496096', '23211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23211', '112', '25088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1496096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25089', '1079', '1', 'Ordynskiy Rayon', 'RU.53.1496101', 'ASCII:Ordynskiy Rayon;ID:1496101', '23212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23212', '112', '25089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1496101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25090', '1079', '1', 'Ongudayskiy Rayon', 'RU.03.1496129', 'ASCII:Ongudayskiy Rayon;ID:1496129', '23213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23213', '112', '25090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.03.1496129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25091', '1079', '1', 'Oktyabr''skiy Rayon', 'RU.13.1496266', 'ASCII:Oktyabr''skiy Rayon;ID:1496266', '23214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23214', '112', '25091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1496266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25092', '1079', '1', 'Novosibirskiy Rayon', 'RU.53.1496742', 'ASCII:Novosibirskiy Rayon;ID:1496742', '23215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23215', '112', '25092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1496742» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25093', '1079', '1', 'Novichikhinskiy Rayon', 'RU.04.1497219', 'ASCII:Novichikhinskiy Rayon;ID:1497219', '23216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23216', '112', '25093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1497219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25094', '1079', '1', 'Nizhneudinskiy Rayon', 'RU.20.1497548', 'ASCII:Nizhneudinskiy Rayon;ID:1497548', '23217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23217', '112', '25094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.1497548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25095', '1079', '1', 'Nizhneingashskiy Rayon', 'RU.39.1497575', 'ASCII:Nizhneingashskiy Rayon;ID:1497575', '23218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23218', '112', '25095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.39.1497575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25096', '1079', '1', 'Nazarovskiy Rayon', 'RU.39.1497938', 'ASCII:Nazarovskiy Rayon;ID:1497938', '23219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23219', '112', '25096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.39.1497938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25097', '1079', '1', 'Moshkovskiy Rayon', 'RU.53.1498386', 'ASCII:Moshkovskiy Rayon;ID:1498386', '23220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23220', '112', '25097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1498386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25098', '1079', '1', 'Mikhaylovskiy Rayon', 'RU.04.1498753', 'ASCII:Mikhaylovskiy Rayon;ID:1498753', '23221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23221', '112', '25098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1498753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25099', '1079', '1', 'Mayminskiy Rayon', 'RU.03.1499159', 'ASCII:Mayminskiy Rayon;ID:1499159', '23222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23222', '112', '25099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.03.1499159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25100', '1079', '1', 'Maslyaninskiy Rayon', 'RU.53.1499244', 'ASCII:Maslyaninskiy Rayon;ID:1499244', '23223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23223', '112', '25100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1499244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25101', '1079', '1', 'Mamontovskiy Rayon', 'RU.04.1499425', 'ASCII:Mamontovskiy Rayon;ID:1499425', '23224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23224', '112', '25101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1499425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25102', '1079', '1', 'Loktevskiy Rayon', 'RU.04.1500386', 'ASCII:Loktevskiy Rayon;ID:1500386', '23225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23225', '112', '25102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1500386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25103', '1079', '1', 'Kytmanovskiy Rayon', 'RU.04.1500989', 'ASCII:Kytmanovskiy Rayon;ID:1500989', '23226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23226', '112', '25103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1500989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25104', '1079', '1', 'Kyshtovskiy Rayon', 'RU.53.1500998', 'ASCII:Kyshtovskiy Rayon;ID:1500998', '23227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23227', '112', '25104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1500998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25105', '1079', '1', 'Kuybyshevskiy Rayon', 'RU.53.1501129', 'ASCII:Kuybyshevskiy Rayon;ID:1501129', '23228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23228', '112', '25105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1501129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25106', '1079', '1', 'Kur''inskiy Rayon', 'RU.04.1501302', 'ASCII:Kur''inskiy Rayon;ID:1501302', '23229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23229', '112', '25106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1501302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25107', '1079', '1', 'Kupinskiy Rayon', 'RU.53.1501362', 'ASCII:Kupinskiy Rayon;ID:1501362', '23230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23230', '112', '25107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1501362» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25108', '1079', '1', 'Kunashakskiy Rayon', 'RU.13.1501399', 'ASCII:Kunashakskiy Rayon;ID:1501399', '23231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23231', '112', '25108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1501399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25109', '1079', '1', 'Kulundinskiy Rayon', 'RU.04.1501455', 'ASCII:Kulundinskiy Rayon;ID:1501455', '23232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23232', '112', '25109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1501455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25110', '1079', '1', 'Krutikhinskiy Rayon', 'RU.04.1501693', 'ASCII:Krutikhinskiy Rayon;ID:1501693', '23233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23233', '112', '25110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1501693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25111', '1079', '1', 'Krasnozerskiy Rayon', 'RU.53.1501989', 'ASCII:Krasnozerskiy Rayon;ID:1501989', '23234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23234', '112', '25111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1501989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25112', '1079', '1', 'Krasnoshchekovskiy Rayon', 'RU.04.1502065', 'ASCII:Krasnoshchekovskiy Rayon;ID:1502065', '23235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23235', '112', '25112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1502065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25113', '1079', '1', 'Krasnogorskiy Rayon', 'RU.04.1502107', 'ASCII:Krasnogorskiy Rayon;ID:1502107', '23236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23236', '112', '25113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1502107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25114', '1079', '1', 'Krasnoarmeyskiy Rayon', 'RU.13.1502125', 'ASCII:Krasnoarmeyskiy Rayon;ID:1502125', '23237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23237', '112', '25114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1502125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25115', '1079', '1', 'Kozul’skiy Rayon', 'RU.39.1502206', 'ASCII:Kozul''skiy Rayon;ID:1502206', '23238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23238', '112', '25115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.39.1502206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25116', '1079', '1', 'Kosikhinskiy Rayon', 'RU.04.1502386', 'ASCII:Kosikhinskiy Rayon;ID:1502386', '23239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23239', '112', '25116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1502386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25117', '1079', '1', 'Kosh-Agachskiy Rayon', 'RU.03.1502421', 'ASCII:Kosh-Agachskiy Rayon;ID:1502421', '23240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23240', '112', '25117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.03.1502421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25118', '1079', '1', 'Kolyvanskiy Rayon', 'RU.53.1502815', 'ASCII:Kolyvanskiy Rayon;ID:1502815', '23241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23241', '112', '25118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1502815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25119', '1079', '1', 'Kochkovskiy Rayon', 'RU.53.1503053', 'ASCII:Kochkovskiy Rayon;ID:1503053', '23242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23242', '112', '25119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1503053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25120', '1079', '1', 'Kochenevskiy Rayon', 'RU.53.1503080', 'ASCII:Kochenevskiy Rayon;ID:1503080', '23243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23243', '112', '25120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1503080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25121', '1079', '1', 'Klyuchevskiy Rayon', 'RU.04.1503166', 'ASCII:Klyuchevskiy Rayon;ID:1503166', '23244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23244', '112', '25121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1503166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25122', '1079', '1', 'Khabarskiy Rayon', 'RU.04.1503857', 'ASCII:Khabarskiy Rayon;ID:1503857', '23245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23245', '112', '25122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1503857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25123', '1079', '1', 'Kaslinskiy Rayon', 'RU.13.1504250', 'ASCII:Kaslinskiy Rayon;ID:1504250', '23246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23246', '112', '25123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1504250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25124', '1079', '1', 'Kartalinskiy Rayon', 'RU.13.1504318', 'ASCII:Kartalinskiy Rayon;ID:1504318', '23247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23247', '112', '25124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1504318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25125', '1079', '1', 'Kargatskiy Rayon', 'RU.53.1504377', 'ASCII:Kargatskiy Rayon;ID:1504377', '23248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23248', '112', '25125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1504377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25126', '1079', '1', 'Karasukskiy Rayon', 'RU.53.1504478', 'ASCII:Karasukskiy Rayon;ID:1504478', '23249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23249', '112', '25126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1504478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25127', '1079', '1', 'Kamenskiy Rayon', 'RU.71.1504832', 'ASCII:Kamenskiy Rayon;ID:1504832', '23250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23250', '112', '25127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.71.1504832» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25128', '1079', '1', 'Kamenskiy Rayon', 'RU.04.1504833', 'ASCII:Kamenskiy Rayon;ID:1504833', '23251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23251', '112', '25128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1504833» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25129', '1079', '1', 'Kalmanskiy Rayon', 'RU.04.1504979', 'ASCII:Kalmanskiy Rayon;ID:1504979', '23252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23252', '112', '25129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1504979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25130', '1079', '1', 'Iskitimskiy Rayon', 'RU.53.1505424', 'ASCII:Iskitimskiy Rayon;ID:1505424', '23253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23253', '112', '25130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1505424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25131', '1079', '1', 'Dovolenskiy Rayon', 'RU.53.1507221', 'ASCII:Dovolenskiy Rayon;ID:1507221', '23254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23254', '112', '25131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1507221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25132', '1079', '1', 'Chunskiy Rayon', 'RU.20.1507634', 'ASCII:Chunskiy Rayon;ID:1507634', '23255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23255', '112', '25132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.1507634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25133', '1079', '1', 'Chulymskiy Rayon', 'RU.53.1507674', 'ASCII:Chulymskiy Rayon;ID:1507674', '23256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23256', '112', '25133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1507674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25134', '1079', '1', 'Choyskiy Rayon', 'RU.03.1507741', 'ASCII:Choyskiy Rayon;ID:1507741', '23257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23257', '112', '25134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.03.1507741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25135', '1079', '1', 'Chistoozernyy Rayon', 'RU.53.1507795', 'ASCII:Chistoozernyy Rayon;ID:1507795', '23258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23258', '112', '25135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1507795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25136', '1079', '1', 'Chesmenskiy Rayon', 'RU.13.1507924', 'ASCII:Chesmenskiy Rayon;ID:1507924', '23259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23259', '112', '25136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1507924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25137', '1079', '1', 'Cherepanovskiy Rayon', 'RU.53.1508155', 'ASCII:Cherepanovskiy Rayon;ID:1508155', '23260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23260', '112', '25137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1508155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25138', '1079', '1', 'Chebarkul''skiy Rayon', 'RU.13.1508346', 'ASCII:Chebarkul''skiy Rayon;ID:1508346', '23261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23261', '112', '25138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1508346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25139', '1079', '1', 'Charyshskiy Rayon', 'RU.04.1508428', 'ASCII:Charyshskiy Rayon;ID:1508428', '23262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23262', '112', '25139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1508428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25140', '1079', '1', 'Chanovskiy Rayon', 'RU.53.1508459', 'ASCII:Chanovskiy Rayon;ID:1508459', '23263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23263', '112', '25140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1508459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25141', '1079', '1', 'Bystroistokskiy Rayon', 'RU.04.1508527', 'ASCII:Bystroistokskiy Rayon;ID:1508527', '23264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23264', '112', '25141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1508527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25142', '1079', '1', 'Burlinskiy Rayon', 'RU.04.1508628', 'ASCII:Burlinskiy Rayon;ID:1508628', '23265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23265', '112', '25142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1508628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25143', '1079', '1', 'Bredinskiy Rayon', 'RU.13.1508812', 'ASCII:Bredinskiy Rayon;ID:1508812', '23266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23266', '112', '25143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1508812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25144', '1079', '1', 'Bol''sheuluyskiy Rayon', 'RU.39.1509484', 'ASCII:Bol''sheuluyskiy Rayon;ID:1509484', '23267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23267', '112', '25144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.39.1509484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25145', '1079', '1', 'Bolotninskiy Rayon', 'RU.53.1509820', 'ASCII:Bolotninskiy Rayon;ID:1509820', '23268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23268', '112', '25145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1509820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25146', '1079', '1', 'Bogradskiy Rayon', 'RU.31.1509846', 'ASCII:Bogradskiy Rayon;ID:1509846', '23269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23269', '112', '25146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1509846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25147', '1079', '1', 'Bogotol''skiy Rayon', 'RU.39.1509850', 'ASCII:Bogotol''skiy Rayon;ID:1509850', '23270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23270', '112', '25147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.39.1509850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25148', '1079', '1', 'Bogdanovichskiy Rayon', 'RU.71.1509887', 'ASCII:Bogdanovichskiy Rayon;ID:1509887', '23271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23271', '112', '25148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.71.1509887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25149', '1079', '1', 'Blagoveshchenskiy Rayon', 'RU.04.1509987', 'ASCII:Blagoveshchenskiy Rayon;ID:1509987', '23272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23272', '112', '25149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1509987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25150', '1079', '1', 'Biyskiy Rayon', 'RU.04.1510016', 'ASCII:Biyskiy Rayon;ID:1510016', '23273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23273', '112', '25150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1510016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25151', '1079', '1', 'Birilyusskiy Rayon', 'RU.39.1510060', 'ASCII:Birilyusskiy Rayon;ID:1510060', '23274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23274', '112', '25151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.39.1510060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25152', '1079', '1', 'Beyskiy Rayon', 'RU.31.1510122', 'ASCII:Beyskiy Rayon;ID:1510122', '23275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23275', '112', '25152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1510122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25153', '1079', '1', 'Beloyarskiy Rayon', 'RU.71.1510447', 'ASCII:Beloyarskiy Rayon;ID:1510447', '23276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23276', '112', '25153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.71.1510447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25154', '1079', '1', 'Bayevskiy Rayon', 'RU.04.1510708', 'ASCII:Bayevskiy Rayon;ID:1510708', '23277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23277', '112', '25154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1510708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25155', '1079', '1', 'Barabinskiy Rayon', 'RU.53.1510911', 'ASCII:Barabinskiy Rayon;ID:1510911', '23278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23278', '112', '25155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1510911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25156', '1079', '1', 'Baganskiy Rayon', 'RU.53.1511087', 'ASCII:Baganskiy Rayon;ID:1511087', '23279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23279', '112', '25156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.53.1511087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25157', '1079', '1', 'Askizskiy Rayon', 'RU.31.1511300', 'ASCII:Askizskiy Rayon;ID:1511300', '23280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23280', '112', '25157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1511300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25158', '1079', '1', 'Argayashskiy Rayon', 'RU.13.1511424', 'ASCII:Argayashskiy Rayon;ID:1511424', '23281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23281', '112', '25158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1511424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25159', '1079', '1', 'Altayskiy Rayon', 'RU.31.1511730', 'ASCII:Altayskiy Rayon;ID:1511730', '23282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23282', '112', '25159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1511730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25160', '1079', '1', 'Altayskiy Rayon', 'RU.04.1511731', 'ASCII:Altayskiy Rayon;ID:1511731', '23283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23283', '112', '25160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1511731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25161', '1079', '1', 'Aleyskiy Rayon', 'RU.04.1511780', 'ASCII:Aleyskiy Rayon;ID:1511780', '23284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23284', '112', '25161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1511780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25162', '1079', '1', 'Achinskiy Rayon', 'RU.39.1512163', 'ASCII:Achinskiy Rayon;ID:1512163', '23285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23285', '112', '25162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.39.1512163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25163', '1079', '1', 'Abanskiy Rayon', 'RU.39.1512216', 'ASCII:Abanskiy Rayon;ID:1512216', '23286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23286', '112', '25163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.39.1512216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25164', '1079', '1', 'Chemal''skiy Rayon', 'RU.03.1535927', 'ASCII:Chemal''skiy Rayon;ID:1535927', '23287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23287', '112', '25164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.03.1535927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25165', '1079', '1', 'Natsional''nyy Rayon Nemetskiy', 'RU.04.1535928', 'ASCII:Natsional''nyy Rayon Nemetskiy;ID:1535928', '23288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23288', '112', '25165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1535928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25166', '1079', '1', 'Suyetskiy Rayon', 'RU.04.1535929', 'ASCII:Suyetskiy Rayon;ID:1535929', '23289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23289', '112', '25166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1535929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25167', '1079', '1', 'Shelabolikhinskiy Rayon', 'RU.04.1535930', 'ASCII:Shelabolikhinskiy Rayon;ID:1535930', '23290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23290', '112', '25167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1535930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25168', '1079', '1', 'Gorod Barnaulskiy', 'RU.04.1535931', 'ASCII:Gorod Barnaulskiy;ID:1535931', '23291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23291', '112', '25168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.04.1535931» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25169', '1079', '1', 'Gorod Chelyabinsk', 'RU.13.1535932', 'ASCII:Gorod Chelyabinsk;ID:1535932', '23292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23292', '112', '25169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1535932» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25170', '1079', '1', 'Gorod Verkhniy Ufaley', 'RU.13.1535933', 'ASCII:Gorod Verkhniy Ufaley;ID:1535933', '23293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23293', '112', '25170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1535933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25171', '1079', '1', 'Gorod Yemanzhelinsk', 'RU.13.1535934', 'ASCII:Gorod Yemanzhelinsk;ID:1535934', '23294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23294', '112', '25171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1535934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25172', '1079', '1', 'Gorod Karabash', 'RU.13.1535935', 'ASCII:Gorod Karabash;ID:1535935', '23295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23295', '112', '25172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1535935» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25173', '1079', '1', 'Gorod Kopeysk', 'RU.13.1535936', 'ASCII:Gorod Kopeysk;ID:1535936', '23296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23296', '112', '25173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1535936» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25174', '1079', '1', 'Gorod Korkino', 'RU.13.1535937', 'ASCII:Gorod Korkino;ID:1535937', '23297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23297', '112', '25174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1535937» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25175', '1079', '1', 'Gorod Kyshtym', 'RU.13.1535938', 'ASCII:Gorod Kyshtym;ID:1535938', '23298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23298', '112', '25175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1535938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25176', '1079', '1', 'Gorod Miass', 'RU.13.1535939', 'ASCII:Gorod Miass;ID:1535939', '23299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23299', '112', '25176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1535939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25177', '1079', '1', 'Gorod Plast', 'RU.13.1535940', 'ASCII:Gorod Plast;ID:1535940', '23300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23300', '112', '25177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1535940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25178', '1079', '1', 'Gorod Yuzhnoural''sk', 'RU.13.1535941', 'ASCII:Gorod Yuzhnoural''sk;ID:1535941', '23301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23301', '112', '25178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.13.1535941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25179', '1079', '1', 'Polevskoy Gorod', 'RU.71.1536221', 'ASCII:Polevskoy Gorod;ID:1536221', '23302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23302', '112', '25179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.71.1536221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25180', '1079', '1', 'Chernogorsk Gorod', 'RU.31.1536883', 'ASCII:Chernogorsk Gorod;ID:1536883', '23303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23303', '112', '25180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1536883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25181', '1079', '1', 'Abakan Gorod', 'RU.31.1536884', 'ASCII:Abakan Gorod;ID:1536884', '23304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23304', '112', '25181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1536884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25182', '1079', '1', 'Sayanogorsk Gorod', 'RU.31.1536885', 'ASCII:Sayanogorsk Gorod;ID:1536885', '23305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23305', '112', '25182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.31.1536885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25183', '1079', '1', 'Ziminskiy Rayon', 'RU.20.2012482', 'ASCII:Ziminskiy Rayon;ID:2012482', '23306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23306', '112', '25183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2012482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25184', '1079', '1', 'Zhigalovskiy Rayon', 'RU.20.2012531', 'ASCII:Zhigalovskiy Rayon;ID:2012531', '23307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23307', '112', '25184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2012531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25185', '1079', '1', 'Zeyskiy Rayon', 'RU.05.2012589', 'ASCII:Zeyskiy Rayon;ID:2012589', '23308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23308', '112', '25185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2012589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25186', '1079', '1', 'Zavitinskiy Rayon', 'RU.05.2012624', 'ASCII:Zavitinskiy Rayon;ID:2012624', '23309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23309', '112', '25186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2012624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25187', '1079', '1', 'Zalarinskiy Rayon', 'RU.20.2012700', 'ASCII:Zalarinskiy Rayon;ID:2012700', '23310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23310', '112', '25187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2012700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25188', '1079', '1', 'Zakamenskiy Rayon', 'RU.11.2012726', 'ASCII:Zakamenskiy Rayon;ID:2012726', '23311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23311', '112', '25188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2012726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25189', '1079', '1', 'Zaigrayevskiy Rayon', 'RU.11.2012734', 'ASCII:Zaigrayevskiy Rayon;ID:2012734', '23312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23312', '112', '25189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2012734» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25190', '1079', '1', 'Yeravninskiy Rayon', 'RU.11.2012958', 'ASCII:Yeravninskiy Rayon;ID:2012958', '23313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23313', '112', '25190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2012958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25191', '1079', '1', 'Yakovlevskiy Rayon', 'RU.59.2013174', 'ASCII:Yakovlevskiy Rayon;ID:2013174', '23314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23314', '112', '25191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2013174» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25192', '1079', '1', 'Vyazemskiy Rayon', 'RU.30.2013228', 'ASCII:Vyazemskiy Rayon;ID:2013228', '23315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23315', '112', '25192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.30.2013228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25193', '1079', '1', 'Ust''-Udinskiy Rayon', 'RU.20.2013864', 'ASCII:Ust''-Udinskiy Rayon;ID:2013864', '23316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23316', '112', '25193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2013864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25194', '1079', '1', 'Ust''-Kutskiy Rayon', 'RU.20.2013922', 'ASCII:Ust''-Kutskiy Rayon;ID:2013922', '23317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23317', '112', '25194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2013922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25195', '1079', '1', 'Ust''-Ilimskiy Rayon', 'RU.20.2013951', 'ASCII:Ust''-Ilimskiy Rayon;ID:2013951', '23318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23318', '112', '25195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2013951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25196', '1079', '1', 'Ussuriyskiy Rayon', 'RU.59.2014004', 'ASCII:Ussuriyskiy Rayon;ID:2014004', '23319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23319', '112', '25196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2014004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25197', '1079', '1', 'Usol''skiy Rayon', 'RU.20.2014025', 'ASCII:Usol''skiy Rayon;ID:2014025', '23320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23320', '112', '25197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2014025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25198', '1079', '1', 'Tyndinskiy Rayon', 'RU.05.2014714', 'ASCII:Tyndinskiy Rayon;ID:2014714', '23321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23321', '112', '25198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2014714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25199', '1079', '1', 'Tunkinskiy Rayon', 'RU.11.2014864', 'ASCII:Tunkinskiy Rayon;ID:2014864', '23322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23322', '112', '25199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2014864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25200', '1079', '1', 'Tulunskiy Rayon', 'RU.20.2014922', 'ASCII:Tulunskiy Rayon;ID:2014922', '23323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23323', '112', '25200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2014922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25201', '1079', '1', 'Tambovskiy Rayon', 'RU.05.2015607', 'ASCII:Tambovskiy Rayon;ID:2015607', '23324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23324', '112', '25201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2015607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25202', '1079', '1', 'Svobodnenskiy Rayon', 'RU.05.2015840', 'ASCII:Svobodnenskiy Rayon;ID:2015840', '23325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23325', '112', '25202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2015840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25203', '1079', '1', 'Spasskiy Rayon', 'RU.59.2016184', 'ASCII:Spasskiy Rayon;ID:2016184', '23326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23326', '112', '25203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2016184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25204', '1079', '1', 'Smidovichskiy Rayon', 'RU.89.2016411', 'ASCII:Smidovichskiy Rayon;ID:2016411', '23327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23327', '112', '25204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.89.2016411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25205', '1079', '1', 'Slyudyanskiy Rayon', 'RU.20.2016415', 'ASCII:Slyudyanskiy Rayon;ID:2016415', '23328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23328', '112', '25205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2016415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25206', '1079', '1', 'Skovorodinskiy Rayon', 'RU.05.2016442', 'ASCII:Skovorodinskiy Rayon;ID:2016442', '23329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23329', '112', '25206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2016442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25207', '1079', '1', 'Shkotovskiy Rayon', 'RU.59.2016650', 'ASCII:Shkotovskiy Rayon;ID:2016650', '23330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23330', '112', '25207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2016650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25208', '1079', '1', 'Shimanovskiy Rayon', 'RU.05.2016700', 'ASCII:Shimanovskiy Rayon;ID:2016700', '23331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23331', '112', '25208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2016700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25209', '1079', '1', 'Severo-Baykal''skiy Rayon', 'RU.11.2016909', 'ASCII:Severo-Baykal''skiy Rayon;ID:2016909', '23332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23332', '112', '25209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2016909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25210', '1079', '1', 'Seryshevskiy Rayon', 'RU.05.2016941', 'ASCII:Seryshevskiy Rayon;ID:2016941', '23333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23333', '112', '25210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2016941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25211', '1079', '1', 'Selenginskiy Rayon', 'RU.11.2017058', 'ASCII:Selenginskiy Rayon;ID:2017058', '23334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23334', '112', '25211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2017058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25212', '1079', '1', 'Selemdzhinskiy Rayon', 'RU.05.2017066', 'ASCII:Selemdzhinskiy Rayon;ID:2017066', '23335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23335', '112', '25212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2017066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25213', '1079', '1', 'Romnenskiy Rayon', 'RU.05.2017411', 'ASCII:Romnenskiy Rayon;ID:2017411', '23336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23336', '112', '25213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2017411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25214', '1079', '1', 'Pribaykal''skiy Rayon', 'RU.11.2017644', 'ASCII:Pribaykal''skiy Rayon;ID:2017644', '23337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23337', '112', '25214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2017644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25215', '1079', '1', 'Osinskiy Rayon', 'RU.82.2018281', 'ASCII:Osinskiy Rayon;ID:2018281', '23338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23338', '112', '25215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.82.2018281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25216', '1079', '1', 'Ol''khonskiy Rayon', 'RU.20.2018527', 'ASCII:Ol''khonskiy Rayon;ID:2018527', '23339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23339', '112', '25216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2018527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25217', '1079', '1', 'Oktyabr’skiy Rayon', 'RU.05.2018608', 'ASCII:Oktyabr''skiy Rayon;ID:2018608', '23340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23340', '112', '25217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2018608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25218', '1079', '1', 'Oktyabr''skiy Rayon', 'RU.89.2018609', 'ASCII:Oktyabr''skiy Rayon;ID:2018609', '23341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23341', '112', '25218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.89.2018609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25219', '1079', '1', 'Okinskiy Rayon', 'RU.11.2018629', 'ASCII:Okinskiy Rayon;ID:2018629', '23342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23342', '112', '25219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2018629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25220', '1079', '1', 'Obluchenskiy Rayon', 'RU.89.2018720', 'ASCII:Obluchenskiy Rayon;ID:2018720', '23343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23343', '112', '25220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.89.2018720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25221', '1079', '1', 'Nukutskiy Rayon', 'RU.82.2018795', 'ASCII:Nukutskiy Rayon;ID:2018795', '23344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23344', '112', '25221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.82.2018795» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25222', '1079', '1', 'Nizhneilimskiy Rayon', 'RU.20.2019196', 'ASCII:Nizhneilimskiy Rayon;ID:2019196', '23345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23345', '112', '25222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2019196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25223', '1079', '1', 'Nadezhdinskiy Rayon', 'RU.59.2019548', 'ASCII:Nadezhdinskiy Rayon;ID:2019548', '23346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23346', '112', '25223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2019548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25224', '1079', '1', 'Mukhorshibirskiy Rayon', 'RU.11.2019707', 'ASCII:Mukhorshibirskiy Rayon;ID:2019707', '23347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23347', '112', '25224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2019707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25225', '1079', '1', 'Mikhaylovskiy Rayon', 'RU.05.2019985', 'ASCII:Mikhaylovskiy Rayon;ID:2019985', '23348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23348', '112', '25225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2019985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25226', '1079', '1', 'Mikhaylovskiy Rayon', 'RU.59.2019986', 'ASCII:Mikhaylovskiy Rayon;ID:2019986', '23349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23349', '112', '25226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2019986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25227', '1079', '1', 'Mazanovskiy Rayon', 'RU.05.2020117', 'ASCII:Mazanovskiy Rayon;ID:2020117', '23350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23350', '112', '25227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2020117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25228', '1079', '1', 'Mamsko-Chuyskiy Rayon', 'RU.20.2020302', 'ASCII:Mamsko-Chuyskiy Rayon;ID:2020302', '23351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23351', '112', '25228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2020302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25229', '1079', '1', 'Magdagachinskiy Rayon', 'RU.05.2020589', 'ASCII:Magdagachinskiy Rayon;ID:2020589', '23352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23352', '112', '25229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2020589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25230', '1079', '1', 'Leninskiy Rayon', 'RU.89.2020845', 'ASCII:Leninskiy Rayon;ID:2020845', '23353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23353', '112', '25230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.89.2020845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25231', '1079', '1', 'Lazovskiy Rayon', 'RU.59.2020883', 'ASCII:Lazovskiy Rayon;ID:2020883', '23354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23354', '112', '25231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2020883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25232', '1079', '1', 'Kyakhtinskiy Rayon', 'RU.11.2021063', 'ASCII:Kyakhtinskiy Rayon;ID:2021063', '23355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23355', '112', '25232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2021063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25233', '1079', '1', 'Kuytunskiy Rayon', 'RU.20.2021089', 'ASCII:Kuytunskiy Rayon;ID:2021089', '23356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23356', '112', '25233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2021089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25234', '1079', '1', 'Kurumkanskiy Rayon', 'RU.11.2021185', 'ASCII:Kurumkanskiy Rayon;ID:2021185', '23357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23357', '112', '25234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2021185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25235', '1079', '1', 'Konstantinovskiy Rayon', 'RU.05.2021792', 'ASCII:Konstantinovskiy Rayon;ID:2021792', '23358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23358', '112', '25235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2021792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25236', '1079', '1', 'Kizhinginskiy Rayon', 'RU.11.2022001', 'ASCII:Kizhinginskiy Rayon;ID:2022001', '23359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23359', '112', '25236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2022001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25237', '1079', '1', 'Kirovskiy Rayon', 'RU.59.2022059', 'ASCII:Kirovskiy Rayon;ID:2022059', '23360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23360', '112', '25237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2022059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25238', '1079', '1', 'Kirenskiy Rayon', 'RU.20.2022082', 'ASCII:Kirenskiy Rayon;ID:2022082', '23361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23361', '112', '25238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2022082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25239', '1079', '1', 'Khorol’skiy Rayon', 'RU.59.2022288', 'ASCII:Khorol''skiy Rayon;ID:2022288', '23362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23362', '112', '25239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2022288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25240', '1079', '1', 'Khorinskiy Rayon', 'RU.11.2022301', 'ASCII:Khorinskiy Rayon;ID:2022301', '23363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23363', '112', '25240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2022301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25241', '1079', '1', 'Khasanskiy Rayon', 'RU.59.2022584', 'ASCII:Khasanskiy Rayon;ID:2022584', '23364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23364', '112', '25241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2022584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25242', '1079', '1', 'Khabarovskiy Rayon', 'RU.30.2022887', 'ASCII:Khabarovskiy Rayon;ID:2022887', '23365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23365', '112', '25242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.30.2022887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25243', '1079', '1', 'Kazachinsko-Lenskiy Rayon', 'RU.20.2023030', 'ASCII:Kazachinsko-Lenskiy Rayon;ID:2023030', '23366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23366', '112', '25243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2023030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25244', '1079', '1', 'Katangskiy Rayon', 'RU.20.2023075', 'ASCII:Katangskiy Rayon;ID:2023075', '23367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23367', '112', '25244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2023075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25245', '1079', '1', 'Kachugskiy Rayon', 'RU.20.2023332', 'ASCII:Kachugskiy Rayon;ID:2023332', '23368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23368', '112', '25245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2023332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25246', '1079', '1', 'Kabanskiy Rayon', 'RU.11.2023349', 'ASCII:Kabanskiy Rayon;ID:2023349', '23369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23369', '112', '25246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2023349» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25247', '1079', '1', 'Ivanovskiy Rayon', 'RU.05.2023386', 'ASCII:Ivanovskiy Rayon;ID:2023386', '23370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23370', '112', '25247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2023386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25248', '1079', '1', 'Irkutskiy Rayon', 'RU.20.2023464', 'ASCII:Irkutskiy Rayon;ID:2023464', '23371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23371', '112', '25248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2023464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25249', '1079', '1', 'Ekhirit-Bulagatskiy Rayon', 'RU.82.2024464', 'ASCII:Ekhirit-Bulagatskiy Rayon;ID:2024464', '23372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23372', '112', '25249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.82.2024464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25250', '1079', '1', 'Dzhidinskiy Rayon', 'RU.11.2024574', 'ASCII:Dzhidinskiy Rayon;ID:2024574', '23373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23373', '112', '25250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2024574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25251', '1079', '1', 'Chitinskiy Rayon', 'RU.14.2025332', 'ASCII:Chitinskiy Rayon;ID:2025332', '23374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23374', '112', '25251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.14.2025332» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25252', '1079', '1', 'Chernigovskiy Rayon', 'RU.59.2025486', 'ASCII:Chernigovskiy Rayon;ID:2025486', '23375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23375', '112', '25252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2025486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25253', '1079', '1', 'Cheremkhovskiy Rayon', 'RU.20.2025526', 'ASCII:Cheremkhovskiy Rayon;ID:2025526', '23376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23376', '112', '25253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2025526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25254', '1079', '1', 'Bureyskiy Rayon', 'RU.05.2025915', 'ASCII:Bureyskiy Rayon;ID:2025915', '23377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23377', '112', '25254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2025915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25255', '1079', '1', 'Bratskiy Rayon', 'RU.20.2026092', 'ASCII:Bratskiy Rayon;ID:2026092', '23378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23378', '112', '25255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2026092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25256', '1079', '1', 'Bokhanskiy Rayon', 'RU.82.2026543', 'ASCII:Bokhanskiy Rayon;ID:2026543', '23379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23379', '112', '25256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.82.2026543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25257', '1079', '1', 'Bodaybinskiy Rayon', 'RU.20.2026584', 'ASCII:Bodaybinskiy Rayon;ID:2026584', '23380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23380', '112', '25257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2026584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25258', '1079', '1', 'Blagoveshchenskiy Rayon', 'RU.05.2026607', 'ASCII:Blagoveshchenskiy Rayon;ID:2026607', '23381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23381', '112', '25258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2026607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25259', '1079', '1', 'Birobidzhanskiy Rayon', 'RU.89.2026641', 'ASCII:Birobidzhanskiy Rayon;ID:2026641', '23382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23382', '112', '25259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.89.2026641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25260', '1079', '1', 'Bikinskiy Rayon', 'RU.30.2026693', 'ASCII:Bikinskiy Rayon;ID:2026693', '23383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23383', '112', '25260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.30.2026693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25261', '1079', '1', 'Bichurskiy Rayon', 'RU.11.2026705', 'ASCII:Bichurskiy Rayon;ID:2026705', '23384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23384', '112', '25261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2026705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25262', '1079', '1', 'Belogorskiy Rayon', 'RU.05.2026893', 'ASCII:Belogorskiy Rayon;ID:2026893', '23385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23385', '112', '25262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2026893» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25263', '1079', '1', 'Bayandayevskiy Rayon', 'RU.82.2027003', 'ASCII:Bayandayevskiy Rayon;ID:2027003', '23386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23386', '112', '25263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.82.2027003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25264', '1079', '1', 'Bauntovskiy Rayon', 'RU.11.2027013', 'ASCII:Bauntovskiy Rayon;ID:2027013', '23387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23387', '112', '25264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2027013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25265', '1079', '1', 'Barguzinskiy Rayon', 'RU.11.2027104', 'ASCII:Barguzinskiy Rayon;ID:2027104', '23388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23388', '112', '25265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2027104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25266', '1079', '1', 'Arkharinskiy Rayon', 'RU.05.2027485', 'ASCII:Arkharinskiy Rayon;ID:2027485', '23389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23389', '112', '25266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2027485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25267', '1079', '1', 'Anuchinskiy Rayon', 'RU.59.2027594', 'ASCII:Anuchinskiy Rayon;ID:2027594', '23390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23390', '112', '25267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.59.2027594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25268', '1079', '1', 'Alarskiy Rayon', 'RU.82.2027984', 'ASCII:Alarskiy Rayon;ID:2027984', '23391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23391', '112', '25268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.82.2027984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25269', '1079', '1', 'Ivolginskiy Rayon', 'RU.11.2050912', 'ASCII:Ivolginskiy Rayon;ID:2050912', '23392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23392', '112', '25269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2050912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25270', '1079', '1', 'Tarbagatayskiy Rayon', 'RU.11.2050913', 'ASCII:Tarbagatayskiy Rayon;ID:2050913', '23393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23393', '112', '25270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2050913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25271', '1079', '1', 'Muyskiy Rayon', 'RU.11.2050914', 'ASCII:Muyskiy Rayon;ID:2050914', '23394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23394', '112', '25271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.11.2050914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25272', '1079', '1', 'Gorod Blagoveshchensk', 'RU.05.2050916', 'ASCII:Gorod Blagoveshchensk;ID:2050916', '23395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23395', '112', '25272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2050916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25273', '1079', '1', 'Gorod Raychikhinsk', 'RU.05.2050917', 'ASCII:Gorod Raychikhinsk;ID:2050917', '23396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23396', '112', '25273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.05.2050917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25274', '1079', '1', 'Angarskiy Rayon', 'RU.20.2050918', 'ASCII:Angarskiy Rayon;ID:2050918', '23397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23397', '112', '25274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2050918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25275', '1079', '1', 'Balaganskiy Rayon', 'RU.20.2050919', 'ASCII:Balaganskiy Rayon;ID:2050919', '23398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23398', '112', '25275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2050919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25276', '1079', '1', 'Shelekhovskiy Rayon', 'RU.20.2050920', 'ASCII:Shelekhovskiy Rayon;ID:2050920', '23399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23399', '112', '25276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.20.2050920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25277', '1079', '1', 'Yagodninskiy Rayon', 'RU.44.2119629', 'ASCII:Yagodninskiy Rayon;ID:2119629', '23400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23400', '112', '25277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.44.2119629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25278', '1079', '1', 'Ten''kinskiy Rayon', 'RU.44.2120639', 'ASCII:Ten''kinskiy Rayon;ID:2120639', '23401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23401', '112', '25278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.44.2120639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25279', '1079', '1', 'Susumanskiy Rayon', 'RU.44.2120865', 'ASCII:Susumanskiy Rayon;ID:2120865', '23402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23402', '112', '25279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.44.2120865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25280', '1079', '1', 'Srednekanskiy Rayon', 'RU.44.2121026', 'ASCII:Srednekanskiy Rayon;ID:2121026', '23403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23403', '112', '25280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.44.2121026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25281', '1079', '1', 'Shmidtovskiy Rayon', 'RU.15.2121261', 'ASCII:Shmidtovskiy Rayon;ID:2121261', '23404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23404', '112', '25281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.15.2121261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25282', '1079', '1', 'Severo-Evenskiy Rayon', 'RU.44.2121386', 'ASCII:Severo-Evenskiy Rayon;ID:2121386', '23405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23405', '112', '25282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.44.2121386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25283', '1079', '1', 'Omsukchanskiy Rayon', 'RU.44.2122490', 'ASCII:Omsukchanskiy Rayon;ID:2122490', '23406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23406', '112', '25283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.44.2122490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25284', '1079', '1', 'Ol''skiy Rayon', 'RU.44.2122529', 'ASCII:Ol''skiy Rayon;ID:2122529', '23407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23407', '112', '25284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.44.2122529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25285', '1079', '1', 'Nevel’skiy Rayon', 'RU.64.2122891', 'ASCII:Nevel''skiy Rayon;ID:2122891', '23408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23408', '112', '25285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.64.2122891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25286', '1079', '1', 'Korsakovskiy Rayon', 'RU.64.2124282', 'ASCII:Korsakovskiy Rayon;ID:2124282', '23409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23409', '112', '25286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.64.2124282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25287', '1079', '1', 'Khasynskiy Rayon', 'RU.44.2124738', 'ASCII:Khasynskiy Rayon;ID:2124738', '23410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23410', '112', '25287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.44.2124738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25288', '1079', '1', 'Chaunskiy Rayon', 'RU.15.2126275', 'ASCII:Chaunskiy Rayon;ID:2126275', '23411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23411', '112', '25288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.15.2126275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25289', '1079', '1', 'Bilibinskiy Rayon', 'RU.15.2126681', 'ASCII:Bilibinskiy Rayon;ID:2126681', '23412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23412', '112', '25289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.15.2126681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25290', '1079', '1', 'Beringovskiy Rayon', 'RU.15.2126709', 'ASCII:Beringovskiy Rayon;ID:2126709', '23413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23413', '112', '25290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.15.2126709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25291', '1079', '1', 'Anivskiy Rayon', 'RU.64.2127149', 'ASCII:Anivskiy Rayon;ID:2127149', '23414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23414', '112', '25291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.64.2127149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25292', '1079', '1', 'Anadyrskiy Rayon', 'RU.15.2127198', 'ASCII:Anadyrskiy Rayon;ID:2127198', '23415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23415', '112', '25292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.15.2127198» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25293', '1079', '1', 'Gorod Magadan', 'RU.44.2131663', 'ASCII:Gorod Magadan;ID:2131663', '23416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23416', '112', '25293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.44.2131663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25294', '1079', '1', 'Gorod Baltiysk', 'RU.23.3233216', 'ASCII:Gorod Baltiysk;ID:3233216', '23417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23417', '112', '25294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.23.3233216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25295', '1079', '1', 'Providenskiy Rayon', 'RU.15.4031572', 'ASCII:Providenskiy Rayon;ID:4031572', '23418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23418', '112', '25295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.15.4031572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25296', '1079', '1', 'Iul''tinskiy Rayon', 'RU.15.4031694', 'ASCII:Iul''tinskiy Rayon;ID:4031694', '23419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23419', '112', '25296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.15.4031694» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25297', '1079', '1', 'Chukotskiy Rayon', 'RU.15.4031750', 'ASCII:Chukotskiy Rayon;ID:4031750', '23420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23420', '112', '25297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.15.4031750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25298', '1079', '1', 'Malopurginskiy Rayon', 'RU.80.6677912', 'ASCII:Malopurginskiy Rayon;ID:6677912', '23421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23421', '112', '25298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.80.6677912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25299', '1079', '1', 'Всеволжский Район', 'RU.42.6695195', 'ASCII:Vsevolzhskij Rajon;ID:6695195', '23422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23422', '112', '25299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.42.6695195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25300', '1079', '1', 'Приозерский Район', 'RU.42.6695196', 'ASCII:Priozersk Region;ID:6695196', '23423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23423', '112', '25300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.42.6695196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25301', '1079', '1', 'Sochi City', 'RU.38.6695246', 'ASCII:Sochi City;ID:6695246', '23424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23424', '112', '25301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «RU.38.6695246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25302', '1079', '1', 'Al Mudīrīyah ash Shamālīyah', 'SD.30.363412', 'ASCII:Al Mudiriyah ash Shamaliyah;ID:363412', '23425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23425', '112', '25302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.30.363412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25303', '1079', '1', 'Al Mudīrīyah al Istiwā''īyah al Gharbīyah', 'SD.28.363414', 'ASCII:Al Mudiriyah al Istiwa''iyah al Gharbiyah;ID:363414', '23426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23426', '112', '25303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.28.363414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25304', '1079', '1', 'Omdurman Municipal Council', 'SD.29.368767', 'ASCII:Omdurman Municipal Council;ID:368767', '23427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23427', '112', '25304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.29.368767» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25305', '1079', '1', 'Mudīrīyat Kurdufān ash Shamālīyah', 'SD.34.371850', 'ASCII:Mudiriyat Kurdufan ash Shamaliyah;ID:371850', '23428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23428', '112', '25305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.34.371850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25306', '1079', '1', 'Mudīrīyat Kurdufān al Janūbīyah', 'SD.34.371851', 'ASCII:Mudiriyat Kurdufan al Janubiyah;ID:371851', '23429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23429', '112', '25306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.34.371851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25307', '1079', '1', 'Khartoum Rural Council', 'SD.29.372533', 'ASCII:Khartoum Rural Council;ID:372533', '23430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23430', '112', '25307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.29.372533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25308', '1079', '1', 'Khartoum North Municipal Council', 'SD.29.372534', 'ASCII:Khartoum North Municipal Council;ID:372534', '23431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23431', '112', '25308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.29.372534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25309', '1079', '1', 'Khartoum Municipal Council', 'SD.29.372535', 'ASCII:Khartoum Municipal Council;ID:372535', '23432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23432', '112', '25309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.29.372535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25310', '1079', '1', 'Mudīrīyat Kassalā', 'SD.31.372751', 'ASCII:Mudiriyat Kassala;ID:372751', '23433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23433', '112', '25310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.31.372751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25311', '1079', '1', 'Mudīrīyat Junqalī', 'SD.26.373249', 'ASCII:Mudiriyat Junqali;ID:373249', '23434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23434', '112', '25311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.26.373249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25312', '1079', '1', 'Gedaref North Rural Council', 'SD.31.375038', 'ASCII:Gedaref North Rural Council;ID:375038', '23435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23435', '112', '25312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.31.375038» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25313', '1079', '1', 'El Meilig Rural Council', 'SD.27.375845', 'ASCII:El Meilig Rural Council;ID:375845', '23436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23436', '112', '25313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.27.375845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25314', '1079', '1', 'Mudīrīyat Dārfūr ash Shamālīyah', 'SD.33.376729', 'ASCII:Mudiriyat Darfur ash Shamaliyah;ID:376729', '23437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23437', '112', '25314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.33.376729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25315', '1079', '1', 'Mudīrīyat Dārfūr al Janūbīyah', 'SD.33.376730', 'ASCII:Mudiriyat Darfur al Janubiyah;ID:376730', '23438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23438', '112', '25315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.33.376730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25316', '1079', '1', 'Mudīrīyat Baḩr al Ghazāl ash Sharqīyah', 'SD.32.377888', 'ASCII:Mudiriyat Bahr al Ghazal ash Sharqiyah;ID:377888', '23439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23439', '112', '25316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.32.377888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25317', '1079', '1', 'Mudīrīyat Baḩr al Ghazāl al Gharbīyah', 'SD.32.377889', 'ASCII:Mudiriyat Bahr al Ghazal al Gharbiyah;ID:377889', '23440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23440', '112', '25317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.32.377889» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25318', '1079', '1', 'Mudīrīyat an Nīl al Azraq', 'SD.27.378708', 'ASCII:Mudiriyat an Nil al Azraq;ID:378708', '23441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23441', '112', '25318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.27.378708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25319', '1079', '1', 'Mudīrīyat an Nīl', 'SD.30.378709', 'ASCII:Mudiriyat an Nil;ID:378709', '23442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23442', '112', '25319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.30.378709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25320', '1079', '1', 'Mudīrīyat al Jazīrah', 'SD.27.379328', 'ASCII:Mudiriyat al Jazirah;ID:379328', '23443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23443', '112', '25320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.27.379328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25321', '1079', '1', 'Al Mudīrīyah al Istiwā''īyah ash Sharqīyah', 'SD.28.379350', 'ASCII:Al Mudiriyah al Istiwa''iyah ash Sharqiyah;ID:379350', '23444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23444', '112', '25321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.28.379350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25322', '1079', '1', 'Mudīrīyat al Buḩayrāt', 'SD.32.379602', 'ASCII:Mudiriyat al Buhayrat;ID:379602', '23445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23445', '112', '25322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.32.379602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25323', '1079', '1', 'Mudīrīyat al Baḩr al Aḩmar', 'SD.36.379654', 'ASCII:Mudiriyat al Bahr al Ahmar;ID:379654', '23446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23446', '112', '25323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.36.379654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25324', '1079', '1', 'Mudīrīyat al Baḩr al Abyaḑ', 'SD.27.379655', 'ASCII:Mudiriyat al Bahr al Abyad;ID:379655', '23447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23447', '112', '25324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.27.379655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25325', '1079', '1', 'Mudīrīyat A`ālī an Nīl', 'SD.26.381228', 'ASCII:Mudiriyat A`ali an Nil;ID:381228', '23448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23448', '112', '25325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SD.26.381228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25326', '1079', '1', 'Umeå Kommun', 'SE.23.2480', 'ASCII:Umea Kommun;ID:602149', '23449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23449', '112', '25326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25327', '1079', '1', 'Skellefteå Kommun', 'SE.23.2482', 'ASCII:Skelleftea Kommun;ID:602912', '23450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23450', '112', '25327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25328', '1079', '1', 'Robertsfors Kommun', 'SE.23.2409', 'ASCII:Robertsfors Kommun;ID:603302', '23451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23451', '112', '25328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25329', '1079', '1', 'Piteå Kommun', 'SE.14.2581', 'ASCII:Pitea Kommun;ID:603569', '23452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23452', '112', '25329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25330', '1079', '1', 'Pajala Kommun', 'SE.14.2521', 'ASCII:Pajala Kommun;ID:603760', '23453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23453', '112', '25330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25331', '1079', '1', 'Övertorneå Kommun', 'SE.14.2518', 'ASCII:Overtornea Kommun;ID:603813', '23454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23454', '112', '25331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25332', '1079', '1', 'Överkalix Kommun', 'SE.14.2513', 'ASCII:Overkalix Kommun;ID:603822', '23455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23455', '112', '25332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25333', '1079', '1', 'Luleå Kommun', 'SE.14.2580', 'ASCII:Lulea Kommun;ID:604488', '23456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23456', '112', '25333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25334', '1079', '1', 'Kalix Kommun', 'SE.14.2514', 'ASCII:Kalix Kommun;ID:605387', '23457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23457', '112', '25334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25335', '1079', '1', 'Haparanda Kommun', 'SE.14.2583', 'ASCII:Haparanda Kommun;ID:605857', '23458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23458', '112', '25335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2583» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25336', '1079', '1', 'Gällivare Kommun', 'SE.14.2523', 'ASCII:Gallivare Kommun;ID:606084', '23459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23459', '112', '25336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25337', '1079', '1', 'Bodens Kommun', 'SE.14.2582', 'ASCII:Bodens Kommun;ID:606530', '23460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23460', '112', '25337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25338', '1079', '1', 'Älvsbyns Kommun', 'SE.14.2560', 'ASCII:Alvsbyns Kommun;ID:606833', '23461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23461', '112', '25338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25339', '1079', '1', 'Ystads Kommun', 'SE.27.1286', 'ASCII:Ystads Kommun;ID:2662148', '23462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23462', '112', '25339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25340', '1079', '1', 'Ydre Kommun', 'SE.16.0512', 'ASCII:Ydre Kommun;ID:2662215', '23463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23463', '112', '25340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25341', '1079', '1', 'Vingåkers Kommun', 'SE.18.0428', 'ASCII:Vingakers Kommun;ID:2662828', '23464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23464', '112', '25341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.18.0428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25342', '1079', '1', 'Vindelns Kommun', 'SE.23.2404', 'ASCII:Vindelns Kommun;ID:2662850', '23465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23465', '112', '25342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25343', '1079', '1', 'Vimmerby Kommun', 'SE.09.0884', 'ASCII:Vimmerby Kommun;ID:2662880', '23466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23466', '112', '25343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25344', '1079', '1', 'Vilhelmina Kommun', 'SE.23.2462', 'ASCII:Vilhelmina Kommun;ID:2662934', '23467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23467', '112', '25344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25345', '1079', '1', 'Vetlanda Kommun', 'SE.08.0685', 'ASCII:Vetlanda Kommun;ID:2663292', '23468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23468', '112', '25345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25346', '1079', '1', 'Vellinge Kommun', 'SE.27.1233', 'ASCII:Vellinge Kommun;ID:2663398', '23469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23469', '112', '25346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25347', '1079', '1', 'Växjö Kommun', 'SE.12.0780', 'ASCII:Vaxjo Kommun;ID:2663535', '23470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23470', '112', '25347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.12.0780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25348', '1079', '1', 'Vaxholms Kommun', 'SE.26.0187', 'ASCII:Vaxholms Kommun;ID:2663537', '23471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23471', '112', '25348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25349', '1079', '1', 'Västerviks Kommun', 'SE.09.0883', 'ASCII:Vasterviks Kommun;ID:2664201', '23472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23472', '112', '25349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25350', '1079', '1', 'Västerås Kommun', 'SE.25.1980', 'ASCII:Vasteras Kommun;ID:2664441', '23473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23473', '112', '25350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.25.1980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25351', '1079', '1', 'Värnamo Kommun', 'SE.08.0683', 'ASCII:Varnamo Kommun;ID:2664852', '23474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23474', '112', '25351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25352', '1079', '1', 'Värmdö Kommun', 'SE.26.0120', 'ASCII:Varmdo Kommun;ID:2664880', '23475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23475', '112', '25352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25353', '1079', '1', 'Vårgårda Kommun', 'SE.28.1442', 'ASCII:Vargarda Kommun;ID:2664938', '23476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23476', '112', '25353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25354', '1079', '1', 'Varbergs Kommun', 'SE.06.1383', 'ASCII:Varbergs Kommun;ID:2664994', '23477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23477', '112', '25354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.06.1383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25355', '1079', '1', 'Vara Kommun', 'SE.28.1470', 'ASCII:Vara Kommun;ID:2665011', '23478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23478', '112', '25355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25356', '1079', '1', 'Vansbro Kommun', 'SE.10.2021', 'ASCII:Vansbro Kommun;ID:2665061', '23479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23479', '112', '25356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25357', '1079', '1', 'Vännäs Kommun', 'SE.23.2460', 'ASCII:Vannas Kommun;ID:2665089', '23480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23480', '112', '25357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2460» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25358', '1079', '1', 'Vänersborgs Kommun', 'SE.28.1487', 'ASCII:Vanersborgs Kommun;ID:2665170', '23481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23481', '112', '25358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25359', '1079', '1', 'Vallentuna Kommun', 'SE.26.0115', 'ASCII:Vallentuna Kommun;ID:2665451', '23482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23482', '112', '25359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25360', '1079', '1', 'Valdemarsviks Kommun', 'SE.16.0563', 'ASCII:Valdemarsviks Kommun;ID:2665672', '23483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23483', '112', '25360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25361', '1079', '1', 'Vaggeryds Kommun', 'SE.08.0665', 'ASCII:Vaggeryds Kommun;ID:2665856', '23484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23484', '112', '25361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25362', '1079', '1', 'Vadstena Kommun', 'SE.16.0584', 'ASCII:Vadstena Kommun;ID:2665901', '23485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23485', '112', '25362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25363', '1079', '1', 'Uppvidinge Kommun', 'SE.12.0760', 'ASCII:Uppvidinge Kommun;ID:2666201', '23486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23486', '112', '25363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.12.0760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25364', '1079', '1', 'Uppsala Kommun', 'SE.21.0380', 'ASCII:Uppsala Kommun;ID:2666219', '23487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23487', '112', '25364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.21.0380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25365', '1079', '1', 'Upplands-Väsby Kommun', 'SE.26.0114', 'ASCII:Upplands-Vasby Kommun;ID:2666237', '23488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23488', '112', '25365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25366', '1079', '1', 'Upplands-Bro Kommun', 'SE.26.0139', 'ASCII:Upplands-Bro Kommun;ID:2666240', '23489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23489', '112', '25366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25367', '1079', '1', 'Ulricehamns Kommun', 'SE.28.1491', 'ASCII:Ulricehamns Kommun;ID:2666492', '23490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23490', '112', '25367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25368', '1079', '1', 'Uddevalla Kommun', 'SE.28.1485', 'ASCII:Uddevalla Kommun;ID:2666669', '23491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23491', '112', '25368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25369', '1079', '1', 'Tyresö Kommun', 'SE.26.0138', 'ASCII:Tyreso Kommun;ID:2666778', '23492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23492', '112', '25369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0138» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25370', '1079', '1', 'Trollhättans Kommun', 'SE.28.1488', 'ASCII:Trollhattans Kommun;ID:2667302', '23493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23493', '112', '25370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25371', '1079', '1', 'Trelleborgs Kommun', 'SE.27.1287', 'ASCII:Trelleborgs Kommun;ID:2667401', '23494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23494', '112', '25371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25372', '1079', '1', 'Tranemo Kommun', 'SE.28.1452', 'ASCII:Tranemo Kommun;ID:2667598', '23495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23495', '112', '25372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25373', '1079', '1', 'Tranås Kommun', 'SE.08.0687', 'ASCII:Tranas Kommun;ID:2667625', '23496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23496', '112', '25373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25374', '1079', '1', 'Torsby Kommun', 'SE.22.1737', 'ASCII:Torsby Kommun;ID:2667872', '23497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23497', '112', '25374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1737» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25375', '1079', '1', 'Torsås Kommun', 'SE.09.0834', 'ASCII:Torsas Kommun;ID:2667902', '23498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23498', '112', '25375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25376', '1079', '1', 'Töreboda Kommun', 'SE.28.1473', 'ASCII:Toreboda Kommun;ID:2668246', '23499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23499', '112', '25376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25377', '1079', '1', 'Tomelilla Kommun', 'SE.27.1270', 'ASCII:Tomelilla Kommun;ID:2668364', '23500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23500', '112', '25377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25378', '1079', '1', 'Tjörns Kommun', 'SE.28.1419', 'ASCII:Tjorns Kommun;ID:2668674', '23501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23501', '112', '25378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25379', '1079', '1', 'Tingsryds Kommun', 'SE.12.0763', 'ASCII:Tingsryds Kommun;ID:2669018', '23502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23502', '112', '25379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.12.0763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25380', '1079', '1', 'Timrå Kommun', 'SE.24.2262', 'ASCII:Timra Kommun;ID:2669046', '23503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23503', '112', '25380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.24.2262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25381', '1079', '1', 'Tierps Kommun', 'SE.21.0360', 'ASCII:Tierps Kommun;ID:2669097', '23504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23504', '112', '25381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.21.0360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25382', '1079', '1', 'Tidaholms Kommun', 'SE.28.1498', 'ASCII:Tidaholms Kommun;ID:2669112', '23505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23505', '112', '25382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25383', '1079', '1', 'Tibro Kommun', 'SE.28.1472', 'ASCII:Tibro Kommun;ID:2669117', '23506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23506', '112', '25383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25384', '1079', '1', 'Tanums Kommun', 'SE.28.1435', 'ASCII:Tanums Kommun;ID:2669414', '23507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23507', '112', '25384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25385', '1079', '1', 'Täby Kommun', 'SE.26.0160', 'ASCII:Taby Kommun;ID:2669768', '23508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23508', '112', '25385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0160» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25386', '1079', '1', 'Svenljunga Kommun', 'SE.28.1465', 'ASCII:Svenljunga Kommun;ID:2670043', '23509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23509', '112', '25386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25387', '1079', '1', 'Svedala Kommun', 'SE.27.1263', 'ASCII:Svedala Kommun;ID:2670127', '23510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23510', '112', '25387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25388', '1079', '1', 'Svalövs Kommun', 'SE.27.1214', 'ASCII:Svalovs Kommun;ID:2670540', '23511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23511', '112', '25388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25389', '1079', '1', 'Surahammars Kommun', 'SE.25.1907', 'ASCII:Surahammars Kommun;ID:2670612', '23512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23512', '112', '25389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.25.1907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25390', '1079', '1', 'Sunne Kommun', 'SE.22.1766', 'ASCII:Sunne Kommun;ID:2670703', '23513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23513', '112', '25390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25391', '1079', '1', 'Sundsvalls Kommun', 'SE.24.2281', 'ASCII:Sundsvalls Kommun;ID:2670776', '23514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23514', '112', '25391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.24.2281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25392', '1079', '1', 'Sundbybergs Kommun', 'SE.26.0183', 'ASCII:Sundbybergs Kommun;ID:2670878', '23515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23515', '112', '25392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25393', '1079', '1', 'Strömsunds Kommun', 'SE.07.2313', 'ASCII:Stromsunds Kommun;ID:2671219', '23516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23516', '112', '25393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.07.2313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25394', '1079', '1', 'Strömstads Kommun', 'SE.28.1486', 'ASCII:Stromstads Kommun;ID:2671222', '23517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23517', '112', '25394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25395', '1079', '1', 'Strängnäs Kommun', 'SE.18.0486', 'ASCII:Strangnas Kommun;ID:2671389', '23518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23518', '112', '25395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.18.0486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25396', '1079', '1', 'Storumans Kommun', 'SE.23.2421', 'ASCII:Storumans Kommun;ID:2671529', '23519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23519', '112', '25396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25397', '1079', '1', 'Storfors Kommun', 'SE.22.1760', 'ASCII:Storfors Kommun;ID:2672047', '23520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23520', '112', '25397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25398', '1079', '1', 'Stockholms Kommun', 'SE.26.0180', 'ASCII:Stockholm municipality;ID:2673723', '23521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23521', '112', '25398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25399', '1079', '1', 'Stenungsunds Kommun', 'SE.28.1415', 'ASCII:Stenungsunds Kommun;ID:2673874', '23522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23522', '112', '25399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25400', '1079', '1', 'Staffanstorps Kommun', 'SE.27.1230', 'ASCII:Staffanstorps Kommun;ID:2674647', '23523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23523', '112', '25400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25401', '1079', '1', 'Sotenäs Kommun', 'SE.28.1427', 'ASCII:Sotenas Kommun;ID:2674968', '23524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23524', '112', '25401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25402', '1079', '1', 'Sorsele Kommun', 'SE.23.2422', 'ASCII:Sorsele Kommun;ID:2675078', '23525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23525', '112', '25402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2422» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25403', '1079', '1', 'Sölvesborgs Kommun', 'SE.02.1083', 'ASCII:Solvesborgs Kommun;ID:2675364', '23526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23526', '112', '25403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.02.1083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25404', '1079', '1', 'Solna Kommun', 'SE.26.0184', 'ASCII:Solna Kommun;ID:2675396', '23527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23527', '112', '25404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25405', '1079', '1', 'Sollentuna Kommun', 'SE.26.0163', 'ASCII:Sollentuna Kommun;ID:2675406', '23528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23528', '112', '25405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25406', '1079', '1', 'Sollefteå Kommun', 'SE.24.2283', 'ASCII:Solleftea Kommun;ID:2675415', '23529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23529', '112', '25406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.24.2283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25407', '1079', '1', 'Södertälje Kommun', 'SE.26.0181', 'ASCII:Sodertalje Kommun;ID:2676174', '23530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23530', '112', '25407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25408', '1079', '1', 'Söderköpings Kommun', 'SE.16.0582', 'ASCII:Soderkopings Kommun;ID:2676214', '23531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23531', '112', '25408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25409', '1079', '1', 'Söderhamns Kommun', 'SE.03.2182', 'ASCII:Soderhamns Kommun;ID:2676222', '23532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23532', '112', '25409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.03.2182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25410', '1079', '1', 'Smedjebackens Kommun', 'SE.10.2061', 'ASCII:Smedjebackens Kommun;ID:2676585', '23533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23533', '112', '25410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25411', '1079', '1', 'Skurups Kommun', 'SE.27.1264', 'ASCII:Skurups Kommun;ID:2677024', '23534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23534', '112', '25411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25412', '1079', '1', 'Skövde Kommun', 'SE.28.1496', 'ASCII:Skovde Kommun;ID:2677233', '23535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23535', '112', '25412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1496» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25413', '1079', '1', 'Skinnskattebergs Kommun', 'SE.25.1904', 'ASCII:Skinnskattebergs Kommun;ID:2677592', '23536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23536', '112', '25413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.25.1904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25414', '1079', '1', 'Skara Kommun', 'SE.28.1495', 'ASCII:Skara Kommun;ID:2678205', '23537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23537', '112', '25414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25415', '1079', '1', 'Sjöbo Kommun', 'SE.27.1265', 'ASCII:Sjobo Kommun;ID:2678902', '23538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23538', '112', '25415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25416', '1079', '1', 'Simrishamns Kommun', 'SE.27.1291', 'ASCII:Simrishamns Kommun;ID:2679106', '23539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23539', '112', '25416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25417', '1079', '1', 'Sigtuna Kommun', 'SE.26.0191', 'ASCII:Sigtuna Kommun;ID:2679300', '23540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23540', '112', '25417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25418', '1079', '1', 'Sävsjö Kommun', 'SE.08.0684', 'ASCII:Savsjo Kommun;ID:2679696', '23541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23541', '112', '25418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25419', '1079', '1', 'Säters Kommun', 'SE.10.2082', 'ASCII:Saters Kommun;ID:2679832', '23542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23542', '112', '25419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25420', '1079', '1', 'Sandvikens Kommun', 'SE.03.2181', 'ASCII:Sandvikens Kommun;ID:2680068', '23543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23543', '112', '25420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.03.2181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25421', '1079', '1', 'Salems Kommun', 'SE.26.0128', 'ASCII:Salems Kommun;ID:2680623', '23544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23544', '112', '25421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25422', '1079', '1', 'Sala Kommun', 'SE.25.1981', 'ASCII:Sala Kommun;ID:2680657', '23545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23545', '112', '25422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.25.1981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25423', '1079', '1', 'Säffle Kommun', 'SE.22.1785', 'ASCII:Saffle Kommun;ID:2680762', '23546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23546', '112', '25423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1785» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25424', '1079', '1', 'Ronneby Kommun', 'SE.02.1081', 'ASCII:Ronneby Kommun;ID:2681821', '23547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23547', '112', '25424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.02.1081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25425', '1079', '1', 'Rättviks Kommun', 'SE.10.2031', 'ASCII:Rattviks Kommun;ID:2682993', '23548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23548', '112', '25425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25426', '1079', '1', 'Ragunda Kommun', 'SE.07.2303', 'ASCII:Ragunda Kommun;ID:2683605', '23549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23549', '112', '25426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.07.2303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25427', '1079', '1', 'Perstorps Kommun', 'SE.27.1275', 'ASCII:Perstorps Kommun;ID:2684202', '23550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23550', '112', '25427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25428', '1079', '1', 'Partille Kommun', 'SE.28.1402', 'ASCII:Partille Kommun;ID:2684394', '23551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23551', '112', '25428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25429', '1079', '1', 'Oxelösunds Kommun', 'SE.18.0481', 'ASCII:Oxelosunds Kommun;ID:2684652', '23552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23552', '112', '25429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.18.0481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25430', '1079', '1', 'Ovanåkers Kommun', 'SE.03.2121', 'ASCII:Ovanakers Kommun;ID:2685092', '23553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23553', '112', '25430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.03.2121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25431', '1079', '1', 'Östra Göinge Kommun', 'SE.27.1256', 'ASCII:Ostra Goinge Kommun;ID:2685543', '23554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23554', '112', '25431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25432', '1079', '1', 'Östhammars Kommun', 'SE.21.0382', 'ASCII:Osthammars Kommun;ID:2685697', '23555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23555', '112', '25432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.21.0382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25433', '1079', '1', 'Östersunds Kommun', 'SE.07.2380', 'ASCII:OEstersund municipality;ID:2685747', '23556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23556', '112', '25433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.07.2380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25434', '1079', '1', 'Österåkers Kommun', 'SE.26.0117', 'ASCII:Osterakers Kommun;ID:2685981', '23557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23557', '112', '25434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25435', '1079', '1', 'Oskarshamns Kommun', 'SE.09.0882', 'ASCII:Oskarshamns Kommun;ID:2686161', '23558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23558', '112', '25435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25436', '1079', '1', 'Osby Kommun', 'SE.27.1273', 'ASCII:Osby Kommun;ID:2686197', '23559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23559', '112', '25436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25437', '1079', '1', 'Orusts Kommun', 'SE.28.1421', 'ASCII:Orusts Kommun;ID:2686246', '23560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23560', '112', '25437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25438', '1079', '1', 'Orsa Kommun', 'SE.10.2034', 'ASCII:Orsa Kommun;ID:2686378', '23561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23561', '112', '25438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25439', '1079', '1', 'Örnsköldsviks Kommun', 'SE.24.2284', 'ASCII:Ornskoldsviks Kommun;ID:2686466', '23562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23562', '112', '25439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.24.2284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25440', '1079', '1', 'Örkelljunga Kommun', 'SE.27.1257', 'ASCII:Orkelljunga Kommun;ID:2686595', '23563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23563', '112', '25440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25441', '1079', '1', 'Örebro Kommun', 'SE.15.1880', 'ASCII:Orebro Kommun;ID:2686656', '23564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23564', '112', '25441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25442', '1079', '1', 'Olofströms Kommun', 'SE.02.1060', 'ASCII:Olofstroms Kommun;ID:2687061', '23565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23565', '112', '25442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.02.1060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25443', '1079', '1', 'Ödeshögs Kommun', 'SE.16.0509', 'ASCII:Odeshogs Kommun;ID:2687419', '23566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23566', '112', '25443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25444', '1079', '1', 'Öckerö Kommun', 'SE.28.1407', 'ASCII:Ockero Kommun;ID:2687508', '23567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23567', '112', '25444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25445', '1079', '1', 'Ockelbo Kommun', 'SE.03.2101', 'ASCII:Ockelbo Kommun;ID:2687516', '23568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23568', '112', '25445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.03.2101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25446', '1079', '1', 'Nynäshamns Kommun', 'SE.26.0192', 'ASCII:Nynashamns Kommun;ID:2687635', '23569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23569', '112', '25446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25447', '1079', '1', 'Nyköpings Kommun', 'SE.18.0480', 'ASCII:Nykopings Kommun;ID:2687698', '23570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23570', '112', '25447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.18.0480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25448', '1079', '1', 'Nybro Kommun', 'SE.09.0881', 'ASCII:Nybro Kommun;ID:2687897', '23571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23571', '112', '25448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25449', '1079', '1', 'Norsjö Kommun', 'SE.23.2417', 'ASCII:Norsjo Kommun;ID:2688170', '23572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23572', '112', '25449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25450', '1079', '1', 'Norrtälje Kommun', 'SE.26.0188', 'ASCII:Norrtalje Kommun;ID:2688248', '23573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23573', '112', '25450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25451', '1079', '1', 'Norrköpings Kommun', 'SE.16.0581', 'ASCII:Norrkopings Kommun;ID:2688367', '23574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23574', '112', '25451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25452', '1079', '1', 'Nordmalings Kommun', 'SE.23.2401', 'ASCII:Nordmalings Kommun;ID:2689334', '23575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23575', '112', '25452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25453', '1079', '1', 'Nordanstigs Kommun', 'SE.03.2132', 'ASCII:Nordanstigs Kommun;ID:2689383', '23576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23576', '112', '25453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.03.2132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25454', '1079', '1', 'Norbergs Kommun', 'SE.25.1962', 'ASCII:Norbergs Kommun;ID:2689450', '23577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23577', '112', '25454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.25.1962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25455', '1079', '1', 'Nora Kommun', 'SE.15.1884', 'ASCII:Nora Kommun;ID:2689465', '23578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23578', '112', '25455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25456', '1079', '1', 'Nässjö Kommun', 'SE.08.0682', 'ASCII:Nassjo Kommun;ID:2690167', '23579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23579', '112', '25456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25457', '1079', '1', 'Nacka Kommun', 'SE.26.0182', 'ASCII:Nacka Kommun;ID:2690578', '23580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23580', '112', '25457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25458', '1079', '1', 'Munkfors Kommun', 'SE.22.1762', 'ASCII:Munkfors Kommun;ID:2690828', '23581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23581', '112', '25458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1762» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25459', '1079', '1', 'Munkedals Kommun', 'SE.28.1430', 'ASCII:Munkedals Kommun;ID:2690840', '23582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23582', '112', '25459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25460', '1079', '1', 'Mullsjö Kommun', 'SE.08.0642', 'ASCII:Mullsjo Kommun;ID:2690899', '23583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23583', '112', '25460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0642» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25461', '1079', '1', 'Motala Kommun', 'SE.16.0583', 'ASCII:Motala Kommun;ID:2690959', '23584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23584', '112', '25461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0583» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25462', '1079', '1', 'Mörbylånga Kommun', 'SE.09.0840', 'ASCII:Morbylanga Kommun;ID:2691347', '23585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23585', '112', '25462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25463', '1079', '1', 'Mora Kommun', 'SE.10.2062', 'ASCII:Mora Kommun;ID:2691395', '23586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23586', '112', '25463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25464', '1079', '1', 'Mönsterås Kommun', 'SE.09.0861', 'ASCII:Monsteras Kommun;ID:2691406', '23587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23587', '112', '25464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25465', '1079', '1', 'Mölndals Kommun', 'SE.28.1481', 'ASCII:Molndals Kommun;ID:2691457', '23588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23588', '112', '25465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25466', '1079', '1', 'Mjölby Kommun', 'SE.16.0586', 'ASCII:Mjolby Kommun;ID:2691742', '23589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23589', '112', '25466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25467', '1079', '1', 'Melleruds Kommun', 'SE.28.1461', 'ASCII:Melleruds Kommun;ID:2692047', '23590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23590', '112', '25467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25468', '1079', '1', 'Marks Kommun', 'SE.28.1463', 'ASCII:Marks Kommun;ID:2692570', '23591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23591', '112', '25468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25469', '1079', '1', 'Markaryds Kommun', 'SE.12.0767', 'ASCII:Markaryds Kommun;ID:2692595', '23592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23592', '112', '25469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.12.0767» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25470', '1079', '1', 'Mariestads Kommun', 'SE.28.1493', 'ASCII:Mariestads Kommun;ID:2692611', '23593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23593', '112', '25470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25471', '1079', '1', 'Malungs Kommun', 'SE.10.2023', 'ASCII:Malungs Kommun;ID:2692868', '23594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23594', '112', '25471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25472', '1079', '1', 'Malmö Kommun', 'SE.27.1280', 'ASCII:Malmo Kommun;ID:2692965', '23595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23595', '112', '25472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25473', '1079', '1', 'Malå Kommun', 'SE.23.2418', 'ASCII:Mala Kommun;ID:2693147', '23596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23596', '112', '25473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25474', '1079', '1', 'Lysekils Kommun', 'SE.28.1484', 'ASCII:Lysekils Kommun;ID:2693300', '23597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23597', '112', '25474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25475', '1079', '1', 'Lycksele Kommun', 'SE.23.2481', 'ASCII:Lycksele Kommun;ID:2693346', '23598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23598', '112', '25475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25476', '1079', '1', 'Lunds Kommun', 'SE.27.1281', 'ASCII:Lunds Kommun;ID:2693555', '23599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23599', '112', '25476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25477', '1079', '1', 'Ludvika Kommun', 'SE.10.2085', 'ASCII:Ludvika Kommun;ID:2693757', '23600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23600', '112', '25477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25478', '1079', '1', 'Lomma Kommun', 'SE.27.1262', 'ASCII:Lomma Kommun;ID:2694260', '23601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23601', '112', '25478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25479', '1079', '1', 'Ljusnarsbergs Kommun', 'SE.15.1864', 'ASCII:Ljusnarsbergs Kommun;ID:2694483', '23602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23602', '112', '25479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25480', '1079', '1', 'Ljusdals Kommun', 'SE.03.2161', 'ASCII:Ljusdals Kommun;ID:2694502', '23603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23603', '112', '25480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.03.2161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25481', '1079', '1', 'Ljungby Kommun', 'SE.12.0781', 'ASCII:Ljungby Kommun;ID:2694551', '23604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23604', '112', '25481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.12.0781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25482', '1079', '1', 'Linköpings Kommun', 'SE.16.0580', 'ASCII:Linkopings Kommun;ID:2694759', '23605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23605', '112', '25482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25483', '1079', '1', 'Lindesbergs Kommun', 'SE.15.1885', 'ASCII:Lindesbergs Kommun;ID:2694892', '23606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23606', '112', '25483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25484', '1079', '1', 'Lilla Edets Kommun', 'SE.28.1462', 'ASCII:Lilla Edets Kommun;ID:2696058', '23607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23607', '112', '25484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25485', '1079', '1', 'Lidköpings Kommun', 'SE.28.1494', 'ASCII:Lidkopings Kommun;ID:2696328', '23608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23608', '112', '25485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25486', '1079', '1', 'Lidingö Kommun', 'SE.26.0186', 'ASCII:Lidingo Kommun;ID:2696332', '23609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23609', '112', '25486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25487', '1079', '1', 'Lessebo Kommun', 'SE.12.0761', 'ASCII:Lessebo Kommun;ID:2696471', '23610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23610', '112', '25487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.12.0761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25488', '1079', '1', 'Lerums Kommun', 'SE.28.1441', 'ASCII:Lerums Kommun;ID:2696500', '23611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23611', '112', '25488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25489', '1079', '1', 'Leksands Kommun', 'SE.10.2029', 'ASCII:Leksands Kommun;ID:2696649', '23612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23612', '112', '25489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25490', '1079', '1', 'Laxå Kommun', 'SE.15.1860', 'ASCII:Laxa Kommun;ID:2696803', '23613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23613', '112', '25490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25491', '1079', '1', 'Landskrona Kommun', 'SE.27.1282', 'ASCII:Landskrona Kommun;ID:2697719', '23614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23614', '112', '25491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25492', '1079', '1', 'Laholms Kommun', 'SE.06.1381', 'ASCII:Laholms Kommun;ID:2697859', '23615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23615', '112', '25492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.06.1381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25493', '1079', '1', 'Kungsörs Kommun', 'SE.25.1960', 'ASCII:Kungsors Kommun;ID:2698680', '23616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23616', '112', '25493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.25.1960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25494', '1079', '1', 'Kungsbacka Kommun', 'SE.06.1384', 'ASCII:Kungsbacka Kommun;ID:2698726', '23617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23617', '112', '25494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.06.1384» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25495', '1079', '1', 'Kungälvs Kommun', 'SE.28.1482', 'ASCII:Kungalvs Kommun;ID:2698738', '23618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23618', '112', '25495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25496', '1079', '1', 'Kumla Kommun', 'SE.15.1881', 'ASCII:Kumla Kommun;ID:2698753', '23619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23619', '112', '25496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25497', '1079', '1', 'Krokoms Kommun', 'SE.07.2309', 'ASCII:Krokoms Kommun;ID:2699175', '23620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23620', '112', '25497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.07.2309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25498', '1079', '1', 'Kristinehamns Kommun', 'SE.22.1781', 'ASCII:Kristinehamns Kommun;ID:2699281', '23621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23621', '112', '25498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25499', '1079', '1', 'Kristianstads Kommun', 'SE.27.1290', 'ASCII:Kristianstads Kommun;ID:2699308', '23622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23622', '112', '25499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1290» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25500', '1079', '1', 'Kramfors Kommun', 'SE.24.2282', 'ASCII:Kramfors Kommun;ID:2699393', '23623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23623', '112', '25500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.24.2282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25501', '1079', '1', 'Köpings Kommun', 'SE.25.1983', 'ASCII:Kopings Kommun;ID:2699780', '23624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23624', '112', '25501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.25.1983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25502', '1079', '1', 'Klippans Kommun', 'SE.27.1276', 'ASCII:Klippans Kommun;ID:2700483', '23625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23625', '112', '25502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25503', '1079', '1', 'Kiruna Kommun', 'SE.14.2584', 'ASCII:Kiruna Kommun;ID:2700801', '23626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23626', '112', '25503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25504', '1079', '1', 'Kinda Kommun', 'SE.16.0513', 'ASCII:Kinda Kommun;ID:2700854', '23627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23627', '112', '25504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25505', '1079', '1', 'Kils Kommun', 'SE.22.1715', 'ASCII:Kils Kommun;ID:2700878', '23628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23628', '112', '25505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25506', '1079', '1', 'Kävlinge Kommun', 'SE.27.1261', 'ASCII:Kavlinge Kommun;ID:2701094', '23629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23629', '112', '25506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25507', '1079', '1', 'Katrineholms Kommun', 'SE.18.0483', 'ASCII:Katrineholms Kommun;ID:2701221', '23630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23630', '112', '25507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.18.0483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25508', '1079', '1', 'Karlstads Kommun', 'SE.22.1780', 'ASCII:Karlstads Kommun;ID:2701679', '23631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23631', '112', '25508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1780» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25509', '1079', '1', 'Karlskrona Kommun', 'SE.02.1080', 'ASCII:Karlskrona Kommun;ID:2701712', '23632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23632', '112', '25509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.02.1080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25510', '1079', '1', 'Karlskoga Kommun', 'SE.15.1883', 'ASCII:Karlskoga Kommun;ID:2701714', '23633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23633', '112', '25510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25511', '1079', '1', 'Karlshamns Kommun', 'SE.02.1082', 'ASCII:Karlshamns Kommun;ID:2701725', '23634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23634', '112', '25511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.02.1082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25512', '1079', '1', 'Karlsborgs Kommun', 'SE.28.1446', 'ASCII:Karlsborgs Kommun;ID:2701754', '23635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23635', '112', '25512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25513', '1079', '1', 'Kalmar Kommun', 'SE.09.0880', 'ASCII:Kalmar Kommun;ID:2702260', '23636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23636', '112', '25513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25514', '1079', '1', 'Jönköpings Kommun', 'SE.08.0680', 'ASCII:Jonkopings Kommun;ID:2702977', '23637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23637', '112', '25514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25515', '1079', '1', 'Jokkmokks Kommun', 'SE.14.2510', 'ASCII:Jokkmokks Kommun;ID:2702996', '23638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23638', '112', '25515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25516', '1079', '1', 'Järfälla Kommun', 'SE.26.0123', 'ASCII:Jarfalla Kommun;ID:2703292', '23639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23639', '112', '25516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25517', '1079', '1', 'Hylte Kommun', 'SE.06.1315', 'ASCII:Hylte Kommun;ID:2704007', '23640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23640', '112', '25517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.06.1315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25518', '1079', '1', 'Hultsfreds Kommun', 'SE.09.0860', 'ASCII:Hultsfreds Kommun;ID:2704397', '23641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23641', '112', '25518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25519', '1079', '1', 'Hudiksvalls Kommun', 'SE.03.2184', 'ASCII:Hudiksvalls Kommun;ID:2704611', '23642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23642', '112', '25519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.03.2184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25520', '1079', '1', 'Huddinge Kommun', 'SE.26.0126', 'ASCII:Huddinge Kommun;ID:2704619', '23643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23643', '112', '25520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0126» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25521', '1079', '1', 'Hörby Kommun', 'SE.27.1266', 'ASCII:Horby Kommun;ID:2705046', '23644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23644', '112', '25521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25522', '1079', '1', 'Höörs Kommun', 'SE.27.1267', 'ASCII:Hoors Kommun;ID:2705054', '23645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23645', '112', '25522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25523', '1079', '1', 'Högsby Kommun', 'SE.09.0821', 'ASCII:Hogsby Kommun;ID:2705716', '23646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23646', '112', '25523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25524', '1079', '1', 'Höganäs Kommun', 'SE.27.1284', 'ASCII:Hoganas Kommun;ID:2706001', '23647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23647', '112', '25524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25525', '1079', '1', 'Hofors Kommun', 'SE.03.2104', 'ASCII:Hofors Kommun;ID:2706055', '23648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23648', '112', '25525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.03.2104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25526', '1079', '1', 'Hjo Kommun', 'SE.28.1497', 'ASCII:Hjo Kommun;ID:2706183', '23649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23649', '112', '25526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25527', '1079', '1', 'Herrljunga Kommun', 'SE.28.1466', 'ASCII:Herrljunga Kommun;ID:2706522', '23650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23650', '112', '25527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25528', '1079', '1', 'Helsingborgs Kommun', 'SE.27.1283', 'ASCII:Helsingborgs Kommun;ID:2706766', '23651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23651', '112', '25528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25529', '1079', '1', 'Hedemora Kommun', 'SE.10.2083', 'ASCII:Hedemora Kommun;ID:2706981', '23652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23652', '112', '25529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25530', '1079', '1', 'Heby Kommun', 'SE.21.1917', 'ASCII:Heby Kommun;ID:2707055', '23653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23653', '112', '25530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.21.1917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25531', '1079', '1', 'Hässleholms Kommun', 'SE.27.1293', 'ASCII:Hassleholms Kommun;ID:2707396', '23654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23654', '112', '25531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25532', '1079', '1', 'Härryda Kommun', 'SE.28.1401', 'ASCII:Harryda Kommun;ID:2707608', '23655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23655', '112', '25532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25533', '1079', '1', 'Härnösands Kommun', 'SE.24.2280', 'ASCII:Harnosands Kommun;ID:2707682', '23656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23656', '112', '25533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.24.2280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25534', '1079', '1', 'Härjedalens Kommun', 'SE.07.2361', 'ASCII:Harjedalens Kommun;ID:2707737', '23657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23657', '112', '25534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.07.2361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25535', '1079', '1', 'Haninge Kommun', 'SE.26.0136', 'ASCII:Haninge Kommun;ID:2707952', '23658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23658', '112', '25535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25536', '1079', '1', 'Hammarö Kommun', 'SE.22.1761', 'ASCII:Hammaro Kommun;ID:2708180', '23659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23659', '112', '25536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25537', '1079', '1', 'Halmstads Kommun', 'SE.06.1380', 'ASCII:Halmstads Kommun;ID:2708363', '23660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23660', '112', '25537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.06.1380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25538', '1079', '1', 'Hallstahammars Kommun', 'SE.25.1961', 'ASCII:Hallstahammars Kommun;ID:2708428', '23661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23661', '112', '25538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.25.1961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25539', '1079', '1', 'Hallsbergs Kommun', 'SE.15.1861', 'ASCII:Hallsbergs Kommun;ID:2708508', '23662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23662', '112', '25539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25540', '1079', '1', 'Hällefors Kommun', 'SE.15.1863', 'ASCII:Hallefors Kommun;ID:2708664', '23663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23663', '112', '25540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25541', '1079', '1', 'Hagfors Kommun', 'SE.22.1783', 'ASCII:Hagfors Kommun;ID:2709213', '23664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23664', '112', '25541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1783» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25542', '1079', '1', 'Håbo Kommun', 'SE.21.0305', 'ASCII:Habo Kommun;ID:2709491', '23665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23665', '112', '25542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.21.0305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25543', '1079', '1', 'Habo Kommun', 'SE.08.0643', 'ASCII:Habo Kommun;ID:2709492', '23666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23666', '112', '25543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0643» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25544', '1079', '1', 'Gullspångs Kommun', 'SE.28.1447', 'ASCII:Gullspangs Kommun;ID:2709910', '23667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23667', '112', '25544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25545', '1079', '1', 'Grums Kommun', 'SE.22.1764', 'ASCII:Grums Kommun;ID:2710341', '23668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23668', '112', '25545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25546', '1079', '1', 'Grästorps Kommun', 'SE.28.1444', 'ASCII:Grastorps Kommun;ID:2710884', '23669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23669', '112', '25546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25547', '1079', '1', 'Gotlands Kommun', 'SE.05.0980', 'ASCII:Gotlands Kommun;ID:2711509', '23670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23670', '112', '25547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.05.0980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25548', '1079', '1', 'Götene Kommun', 'SE.28.1471', 'ASCII:Gotene Kommun;ID:2711525', '23671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23671', '112', '25548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25549', '1079', '1', 'Göteborgs Kommun', 'SE.28.1480', 'ASCII:Goteborgs Kommun;ID:2711533', '23672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23672', '112', '25549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25550', '1079', '1', 'Gnosjö Kommun', 'SE.08.0617', 'ASCII:Gnosjo Kommun;ID:2711789', '23673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23673', '112', '25550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25551', '1079', '1', 'Gislaveds Kommun', 'SE.08.0662', 'ASCII:Gislaveds Kommun;ID:2712044', '23674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23674', '112', '25551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25552', '1079', '1', 'Gävle Kommun', 'SE.03.2180', 'ASCII:Gavle Kommun;ID:2712409', '23675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23675', '112', '25552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.03.2180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25553', '1079', '1', 'Gagnefs Kommun', 'SE.10.2026', 'ASCII:Gagnefs Kommun;ID:2713217', '23676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23676', '112', '25553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25554', '1079', '1', 'Forshaga Kommun', 'SE.22.1763', 'ASCII:Forshaga Kommun;ID:2713969', '23677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23677', '112', '25554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25555', '1079', '1', 'Flens Kommun', 'SE.18.0482', 'ASCII:Flens Kommun;ID:2714388', '23678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23678', '112', '25555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.18.0482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25556', '1079', '1', 'Finspångs Kommun', 'SE.16.0562', 'ASCII:Finspangs Kommun;ID:2714901', '23679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23679', '112', '25556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25557', '1079', '1', 'Filipstads Kommun', 'SE.22.1782', 'ASCII:Filipstads Kommun;ID:2715080', '23680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23680', '112', '25557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25558', '1079', '1', 'Färgelanda Kommun', 'SE.28.1439', 'ASCII:Fargelanda Kommun;ID:2715350', '23681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23681', '112', '25558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25559', '1079', '1', 'Faluns Kommun', 'SE.10.2080', 'ASCII:Faluns Kommun;ID:2715458', '23682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23682', '112', '25559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25560', '1079', '1', 'Falköpings Kommun', 'SE.28.1499', 'ASCII:Falkopings Kommun;ID:2715566', '23683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23683', '112', '25560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25561', '1079', '1', 'Falkenbergs Kommun', 'SE.06.1382', 'ASCII:Falkenbergs Kommun;ID:2715572', '23684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23684', '112', '25561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.06.1382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25562', '1079', '1', 'Fagersta Kommun', 'SE.25.1982', 'ASCII:Fagersta Kommun;ID:2715650', '23685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23685', '112', '25562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.25.1982» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25563', '1079', '1', 'Essunga Kommun', 'SE.28.1445', 'ASCII:Essunga Kommun;ID:2715929', '23686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23686', '112', '25563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25564', '1079', '1', 'Eslövs Kommun', 'SE.27.1285', 'ASCII:Eslovs Kommun;ID:2715945', '23687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23687', '112', '25564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25565', '1079', '1', 'Eskilstuna Kommun', 'SE.18.0484', 'ASCII:Eskilstuna Kommun;ID:2715951', '23688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23688', '112', '25565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.18.0484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25566', '1079', '1', 'Enköpings Kommun', 'SE.21.0381', 'ASCII:Enkopings Kommun;ID:2716165', '23689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23689', '112', '25566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.21.0381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25567', '1079', '1', 'Emmaboda Kommun', 'SE.09.0862', 'ASCII:Emmaboda Kommun;ID:2716280', '23690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23690', '112', '25567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0862» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25568', '1079', '1', 'Eksjö Kommun', 'SE.08.0686', 'ASCII:Eksjo Kommun;ID:2716433', '23691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23691', '112', '25568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0686» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25569', '1079', '1', 'Ekerö Kommun', 'SE.26.0125', 'ASCII:Ekero Kommun;ID:2716579', '23692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23692', '112', '25569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25570', '1079', '1', 'Eda Kommun', 'SE.22.1730', 'ASCII:Eda Kommun;ID:2716958', '23693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23693', '112', '25570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25571', '1079', '1', 'Dorotea Kommun', 'SE.23.2425', 'ASCII:Dorotea Kommun;ID:2717400', '23694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23694', '112', '25571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25572', '1079', '1', 'Degerfors Kommun', 'SE.15.1862', 'ASCII:Degerfors Kommun;ID:2717881', '23695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23695', '112', '25572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1862» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25573', '1079', '1', 'Danderyds Kommun', 'SE.26.0162', 'ASCII:Danderyds Kommun;ID:2717999', '23696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23696', '112', '25573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0162» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25574', '1079', '1', 'Dals-Ed Kommun', 'SE.28.1438', 'ASCII:Dals-Ed Kommun;ID:2718152', '23697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23697', '112', '25574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25575', '1079', '1', 'Burlövs Kommun', 'SE.27.1231', 'ASCII:Burlovs Kommun;ID:2718706', '23698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23698', '112', '25575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25576', '1079', '1', 'Bromölla Kommun', 'SE.27.1272', 'ASCII:Bromolla Kommun;ID:2719105', '23699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23699', '112', '25576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25577', '1079', '1', 'Bräcke Kommun', 'SE.07.2305', 'ASCII:Bracke Kommun;ID:2720000', '23700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23700', '112', '25577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.07.2305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25578', '1079', '1', 'Boxholms Kommun', 'SE.16.0560', 'ASCII:Boxholms Kommun;ID:2720036', '23701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23701', '112', '25578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25579', '1079', '1', 'Botkyrka Kommun', 'SE.26.0127', 'ASCII:Botkyrka Kommun;ID:2720114', '23702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23702', '112', '25579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25580', '1079', '1', 'Borlänge Kommun', 'SE.10.2081', 'ASCII:Borlange Kommun;ID:2720382', '23703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23703', '112', '25580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25581', '1079', '1', 'Borgholms Kommun', 'SE.09.0885', 'ASCII:Borgholms Kommun;ID:2720436', '23704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23704', '112', '25581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.09.0885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25582', '1079', '1', 'Borås Kommun', 'SE.28.1490', 'ASCII:Boras Kommun;ID:2720496', '23705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23705', '112', '25582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25583', '1079', '1', 'Bollnäs Kommun', 'SE.03.2183', 'ASCII:Bollnas Kommun;ID:2720678', '23706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23706', '112', '25583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.03.2183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25584', '1079', '1', 'Bjuvs Kommun', 'SE.27.1260', 'ASCII:Bjuvs Kommun;ID:2721533', '23707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23707', '112', '25584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25585', '1079', '1', 'Bjurholms Kommun', 'SE.23.2403', 'ASCII:Bjurholms Kommun;ID:2721584', '23708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23708', '112', '25585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25586', '1079', '1', 'Bergs Kommun', 'SE.07.2326', 'ASCII:Bergs Kommun;ID:2722709', '23709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23709', '112', '25586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.07.2326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25587', '1079', '1', 'Bengtsfors Kommun', 'SE.28.1460', 'ASCII:Bengtsfors Kommun;ID:2723078', '23710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23710', '112', '25587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1460» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25588', '1079', '1', 'Båstads Kommun', 'SE.27.1278', 'ASCII:Bastads Kommun;ID:2723286', '23711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23711', '112', '25588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25589', '1079', '1', 'Avesta Kommun', 'SE.10.2084', 'ASCII:Avesta Kommun;ID:2724230', '23712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23712', '112', '25589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25590', '1079', '1', 'Åtvidabergs Kommun', 'SE.16.0561', 'ASCII:Atvidabergs Kommun;ID:2724320', '23713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23713', '112', '25590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.16.0561» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25591', '1079', '1', 'Åstorps Kommun', 'SE.27.1277', 'ASCII:Astorps Kommun;ID:2724424', '23714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23714', '112', '25591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25592', '1079', '1', 'Askersunds Kommun', 'SE.15.1882', 'ASCII:Askersunds Kommun;ID:2724776', '23715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23715', '112', '25592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25593', '1079', '1', 'Åsele Kommun', 'SE.23.2463', 'ASCII:Asele Kommun;ID:2724956', '23716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23716', '112', '25593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.23.2463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25594', '1079', '1', 'Arvika Kommun', 'SE.22.1784', 'ASCII:Arvika Kommun;ID:2725122', '23717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23717', '112', '25594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1784» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25595', '1079', '1', 'Arvidsjaurs Kommun', 'SE.14.2505', 'ASCII:Arvidsjaurs Kommun;ID:2725134', '23718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23718', '112', '25595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25596', '1079', '1', 'Arjeplogs Kommun', 'SE.14.2506', 'ASCII:Arjeplogs Kommun;ID:2725371', '23719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23719', '112', '25596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.14.2506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25597', '1079', '1', 'Årjängs Kommun', 'SE.22.1765', 'ASCII:Arjangs Kommun;ID:2725378', '23720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23720', '112', '25597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.22.1765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25598', '1079', '1', 'Åre Kommun', 'SE.07.2321', 'ASCII:Are Kommun;ID:2725422', '23721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23721', '112', '25598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.07.2321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25599', '1079', '1', 'Arboga Kommun', 'SE.25.1984', 'ASCII:Arboga Kommun;ID:2725469', '23722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23722', '112', '25599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.25.1984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25600', '1079', '1', 'Ängelholms Kommun', 'SE.27.1292', 'ASCII:Angelholms Kommun;ID:2725898', '23723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23723', '112', '25600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.27.1292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25601', '1079', '1', 'Ånge Kommun', 'SE.24.2260', 'ASCII:Ange Kommun;ID:2725906', '23724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23724', '112', '25601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.24.2260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25602', '1079', '1', 'Aneby Kommun', 'SE.08.0604', 'ASCII:Aneby Kommun;ID:2726004', '23725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23725', '112', '25602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.08.0604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25603', '1079', '1', 'Åmåls Kommun', 'SE.28.1492', 'ASCII:Amals Kommun;ID:2726237', '23726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23726', '112', '25603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25604', '1079', '1', 'Älvkarleby Kommun', 'SE.21.0319', 'ASCII:Alvkarleby Kommun;ID:2726284', '23727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23727', '112', '25604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.21.0319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25605', '1079', '1', 'Alvesta Kommun', 'SE.12.0764', 'ASCII:Alvesta Kommun;ID:2726306', '23728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23728', '112', '25605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.12.0764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25606', '1079', '1', 'Älvdalens Kommun', 'SE.10.2039', 'ASCII:Alvdalens Kommun;ID:2726330', '23729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23729', '112', '25606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.10.2039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25607', '1079', '1', 'Älmhults Kommun', 'SE.12.0765', 'ASCII:Almhults Kommun;ID:2726568', '23730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23730', '112', '25607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.12.0765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25608', '1079', '1', 'Alingsås Kommun', 'SE.28.1489', 'ASCII:Alingsas Kommun;ID:2726755', '23731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23731', '112', '25608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25609', '1079', '1', 'Ale Kommun', 'SE.28.1440', 'ASCII:Ale Kommun;ID:2726973', '23732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23732', '112', '25609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25610', '1079', '1', 'Gnesta Kommun', 'SE.18.0461', 'ASCII:Gnesta Kommun;ID:3315140', '23733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23733', '112', '25610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.18.0461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25611', '1079', '1', 'Trosa Kommun', 'SE.18.0488', 'ASCII:Trosa Kommun;ID:3315141', '23734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23734', '112', '25611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.18.0488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25612', '1079', '1', 'Knivsta Kommun', 'SE.21.0330', 'ASCII:Knivsta Kommun;ID:3337384', '23735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23735', '112', '25612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.21.0330» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25613', '1079', '1', 'Bollebygds Kommun', 'SE.28.1443', 'ASCII:Bollebygds Kommun;ID:3337401', '23736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23736', '112', '25613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.28.1443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25614', '1079', '1', 'Lekebergs Kommun', 'SE.15.1814', 'ASCII:Lekebergs Kommun;ID:3337402', '23737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23737', '112', '25614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.15.1814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25615', '1079', '1', 'Nykvarns Kommun', 'SE.26.0140', 'ASCII:Nykvarns Kommun;ID:3337442', '23738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23738', '112', '25615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SE.26.0140» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25616', '1079', '1', 'Opština [historical] Ravne na Koroškem', 'SI.K6.3191838', 'ASCII:Opstina [historical] Ravne na Koroskem;ID:3191838', '23739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23739', '112', '25616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SI.K6.3191838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25617', '1079', '1', 'Opština [historical] Ljubljana-Vič-Rudnik', 'SI.09.3196350', 'ASCII:Opstina [historical] Ljubljana-Vic-Rudnik;ID:3196350', '23740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23740', '112', '25617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SI.09.3196350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25618', '1079', '1', 'Opština [historical] Ljubljana-Šiška', 'SI.71.3196352', 'ASCII:Opstina [historical] Ljubljana-Siska;ID:3196352', '23741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23741', '112', '25618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SI.71.3196352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25619', '1079', '1', 'Opština [historical] Ljubljana-Moste-Polje', 'SI.61.3196355', 'ASCII:Opstina [historical] Ljubljana-Moste-Polje;ID:3196355', '23742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23742', '112', '25619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SI.61.3196355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25620', '1079', '1', 'Opština [historical] Ljubljana-Center', 'SI.61.3196356', 'ASCII:Opstina [historical] Ljubljana-Center;ID:3196356', '23743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23743', '112', '25620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SI.61.3196356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25621', '1079', '1', 'Opčina [historical] Ljubljana-Bežigrad', 'SI.00.3196357', 'ASCII:Opcina [historical] Ljubljana-Bezigrad;ID:3196357', '23744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23744', '112', '25621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SI.00.3196357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25622', '1079', '1', 'Opština [historical] Maribor-Tabor', 'SI.00.3239217', 'ASCII:Opstina [historical] Maribor-Tabor;ID:3239217', '23745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23745', '112', '25622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SI.00.3239217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25623', '1079', '1', 'Opština [historical] Maribor-Rotovže', 'SI.J2.3239219', 'ASCII:Opstina [historical] Maribor-Rotovze;ID:3239219', '23746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23746', '112', '25623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SI.J2.3239219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25624', '1079', '1', 'Opština [historical] Maribor-Tezno', 'SI.00.3239222', 'ASCII:Opstina [historical] Maribor-Tezno;ID:3239222', '23747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23747', '112', '25624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SI.00.3239222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25625', '1079', '1', 'Východoslovenský Kraj', 'SK.00.723184', 'ASCII:Vychodoslovensky Kraj;ID:723184', '23748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23748', '112', '25625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.00.723184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25626', '1079', '1', 'Okres Vranov nad Topľou', 'SK.05.723194', 'ASCII:Okres Vranov nad Topl''ou;ID:723194', '23749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23749', '112', '25626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.05.723194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25627', '1079', '1', 'Okres Trebišov', 'SK.03.723357', 'ASCII:Okres Trebisov;ID:723357', '23750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23750', '112', '25627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.03.723357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25628', '1079', '1', 'Okres Svidník', 'SK.05.723416', 'ASCII:Okres Svidnik;ID:723416', '23751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23751', '112', '25628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.05.723416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25629', '1079', '1', 'Okres Stará Ĺubovňa', 'SK.05.723504', 'ASCII:Okres Stara Lubovna;ID:723504', '23752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23752', '112', '25629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.05.723504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25630', '1079', '1', 'Okres Spišská Nová Ves', 'SK.03.723525', 'ASCII:Okres Spisska Nova Ves;ID:723525', '23753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23753', '112', '25630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.03.723525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25631', '1079', '1', 'Okres Rožňava', 'SK.03.723712', 'ASCII:Okres Roznava;ID:723712', '23754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23754', '112', '25631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.03.723712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25632', '1079', '1', 'Okres Rimavská Sobota', 'SK.01.723735', 'ASCII:Okres Rimavska Sobota;ID:723735', '23755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23755', '112', '25632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.01.723735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25633', '1079', '1', 'Okres Prešov', 'SK.05.723818', 'ASCII:Okres Presov;ID:723818', '23756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23756', '112', '25633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.05.723818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25634', '1079', '1', 'Okres Poprad', 'SK.05.723844', 'ASCII:Poprad;ID:723844', '23757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23757', '112', '25634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.05.723844» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25635', '1079', '1', 'Okres Michalovce', 'SK.03.724143', 'ASCII:Okres Michalovce;ID:724143', '23758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23758', '112', '25635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.03.724143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25636', '1079', '1', 'Okres Humenné', 'SK.05.724626', 'ASCII:Okres Humenne;ID:724626', '23759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23759', '112', '25636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.05.724626» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25637', '1079', '1', 'Okres Bardejov', 'SK.05.725167', 'ASCII:Okres Bardejov;ID:725167', '23760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23760', '112', '25637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.05.725167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25638', '1079', '1', 'Okres Zvolen', 'SK.01.3056458', 'ASCII:Okres Zvolen;ID:3056458', '23761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23761', '112', '25638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.01.3056458» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25639', '1079', '1', 'Okres Žilina', 'SK.08.3056507', 'ASCII:Okres Zilina;ID:3056507', '23762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23762', '112', '25639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.08.3056507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25640', '1079', '1', 'Okres Žiar nad Hronom', 'SK.01.3056522', 'ASCII:Okres Ziar nad Hronom;ID:3056522', '23763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23763', '112', '25640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.01.3056522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25641', '1079', '1', 'Západoslovenský Kraj', 'SK.00.3056593', 'ASCII:Zapadoslovensky Kraj;ID:3056593', '23764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23764', '112', '25641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.00.3056593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25642', '1079', '1', 'Okres Veľký Krtíš', 'SK.01.3056824', 'ASCII:Okres Vel''ky Krtis;ID:3056824', '23765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23765', '112', '25642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.01.3056824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25643', '1079', '1', 'Okres Trnava', 'SK.07.3057122', 'ASCII:Okres Trnava;ID:3057122', '23766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23766', '112', '25643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.07.3057122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25644', '1079', '1', 'Okres Trenčín', 'SK.06.3057139', 'ASCII:Trencin District;ID:3057139', '23767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23767', '112', '25644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.06.3057139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25645', '1079', '1', 'Okres Topoľčany', 'SK.04.3057173', 'ASCII:Okres Topol''cany;ID:3057173', '23768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23768', '112', '25645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.04.3057173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25646', '1079', '1', 'Stredoslovenský Kraj', 'SK.00.3057404', 'ASCII:Stredoslovensky Kraj;ID:3057404', '23769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23769', '112', '25646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.00.3057404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25647', '1079', '1', 'Okres Skalica', 'SK.07.3057629', 'ASCII:Skalica District;ID:3057629', '23770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23770', '112', '25647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.07.3057629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25648', '1079', '1', 'Okres Senica', 'SK.07.3057689', 'ASCII:Okres Senica;ID:3057689', '23771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23771', '112', '25648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.07.3057689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25649', '1079', '1', 'Okres Prievidza', 'SK.06.3057999', 'ASCII:Okres Prievidza;ID:3057999', '23772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23772', '112', '25649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.06.3057999» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25650', '1079', '1', 'Okres Považská Bystrica', 'SK.06.3058059', 'ASCII:Okres Povazska Bystrica;ID:3058059', '23773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23773', '112', '25650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.06.3058059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25651', '1079', '1', 'Okres Nové Zámky', 'SK.04.3058471', 'ASCII:Okres Nove Zamky;ID:3058471', '23774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23774', '112', '25651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.04.3058471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25652', '1079', '1', 'Okres Nové Mesto nad Váhom', 'SK.06.3058476', 'ASCII:Nove Mesto nad Vahom District;ID:3058476', '23775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23775', '112', '25652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.06.3058476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25653', '1079', '1', 'Okres Nitra', 'SK.04.3058529', 'ASCII:Okres Nitra;ID:3058529', '23776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23776', '112', '25653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.04.3058529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25654', '1079', '1', 'Okres Myjava', 'SK.06.3058609', 'ASCII:Okres Myjava;ID:3058609', '23777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23777', '112', '25654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.06.3058609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25655', '1079', '1', 'Okres Martin', 'SK.08.3058779', 'ASCII:Martin;ID:3058779', '23778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23778', '112', '25655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.08.3058779» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25656', '1079', '1', 'Okres Lučenec', 'SK.01.3058984', 'ASCII:Okres Lucenec;ID:3058984', '23779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23779', '112', '25656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.01.3058984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25657', '1079', '1', 'Okres Liptovský Mikuláš', 'SK.08.3059049', 'ASCII:Okres Liptovsky Mikulas;ID:3059049', '23780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23780', '112', '25657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.08.3059049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25658', '1079', '1', 'Okres Levice', 'SK.04.3059100', 'ASCII:Okres Levice;ID:3059100', '23781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23781', '112', '25658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.04.3059100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25659', '1079', '1', 'Okres Komárno', 'SK.04.3059432', 'ASCII:Okres Komarno;ID:3059432', '23782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23782', '112', '25659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.04.3059432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25660', '1079', '1', 'Okres Hlohovec', 'SK.07.3060093', 'ASCII:Hlohovec District;ID:3060093', '23783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23783', '112', '25660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.07.3060093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25661', '1079', '1', 'Okres Galanta', 'SK.07.3060218', 'ASCII:Okres Galanta;ID:3060218', '23784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23784', '112', '25661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.07.3060218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25662', '1079', '1', 'Okres Dunajská Streda', 'SK.07.3060307', 'ASCII:Okres Dunajska Streda;ID:3060307', '23785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23785', '112', '25662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.07.3060307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25663', '1079', '1', 'Okres Dolný Kubín', 'SK.08.3060404', 'ASCII:Okres Dolny Kubin;ID:3060404', '23786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23786', '112', '25663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.08.3060404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25664', '1079', '1', 'Okres Čadca', 'SK.08.3060834', 'ASCII:Okres Cadca;ID:3060834', '23787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23787', '112', '25664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.08.3060834» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25665', '1079', '1', 'Okres Brezno', 'SK.01.3060949', 'ASCII:Brezno District;ID:3060949', '23788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23788', '112', '25665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.01.3060949» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25666', '1079', '1', 'Hlavné Mesto Bratislava', 'SK.02.3060971', 'ASCII:Hlavne Mesto Bratislava;ID:3060971', '23789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23789', '112', '25666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.02.3060971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25667', '1079', '1', 'Okres Banská Bystrica', 'SK.01.3061185', 'ASCII:Banska Bystrica District;ID:3061185', '23790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23790', '112', '25667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK.01.3061185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25668', '1079', '1', 'Okres Namestovo', 'SK..6692651', 'ASCII:Okres Namestovo;ID:6692651', '23791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23791', '112', '25668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SK..6692651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25669', '1079', '1', 'Tonkolili District', 'SL.02.2403287', 'ASCII:Tonkolili District;ID:2403287', '23792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23792', '112', '25669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.02.2403287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25670', '1079', '1', 'Pujehun District', 'SL.03.2404399', 'ASCII:Pujehun District;ID:2404399', '23793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23793', '112', '25670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.03.2404399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25671', '1079', '1', 'Port Loko District', 'SL.02.2404431', 'ASCII:Port Loko District;ID:2404431', '23794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23794', '112', '25671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.02.2404431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25672', '1079', '1', 'Moyamba District', 'SL.03.2405008', 'ASCII:Moyamba District;ID:2405008', '23795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23795', '112', '25672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.03.2405008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25673', '1079', '1', 'Kono District', 'SL.01.2407469', 'ASCII:Kono District;ID:2407469', '23796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23796', '112', '25673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.01.2407469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25674', '1079', '1', 'Koinadugu District', 'SL.02.2407650', 'ASCII:Koinadugu District;ID:2407650', '23797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23797', '112', '25674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.02.2407650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25675', '1079', '1', 'Kenema District', 'SL.01.2407781', 'ASCII:Kenema District;ID:2407781', '23798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23798', '112', '25675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.01.2407781» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25676', '1079', '1', 'Kambia District', 'SL.02.2408083', 'ASCII:Kambia District;ID:2408083', '23799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23799', '112', '25676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.02.2408083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25677', '1079', '1', 'Kailahun District', 'SL.01.2408249', 'ASCII:Kailahun District;ID:2408249', '23800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23800', '112', '25677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.01.2408249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25678', '1079', '1', 'Bonthe District', 'SL.03.2409913', 'ASCII:Bonthe District;ID:2409913', '23801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23801', '112', '25678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.03.2409913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25679', '1079', '1', 'Bombali District', 'SL.02.2409983', 'ASCII:Bombali District;ID:2409983', '23802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23802', '112', '25679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.02.2409983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25680', '1079', '1', 'Bo District', 'SL.03.2410021', 'ASCII:Bo District;ID:2410021', '23803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23803', '112', '25680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SL.03.2410021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25681', '1079', '1', 'Ziguinchor', 'SN.12.2243943', 'ASCII:Ziguinchor;ID:2243943', '23804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23804', '112', '25681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.12.2243943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25682', '1079', '1', 'Vélingara', 'SN.11.2244181', 'ASCII:Velingara;ID:2244181', '23805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23805', '112', '25682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.11.2244181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25683', '1079', '1', 'Tivaouane', 'SN.07.2244388', 'ASCII:Tivaouane;ID:2244388', '23806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23806', '112', '25683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.07.2244388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25684', '1079', '1', 'Thiès', 'SN.07.2244804', 'ASCII:Thies;ID:2244804', '23807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23807', '112', '25684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.07.2244804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25685', '1079', '1', 'Tambacounda', 'SN.05.2244993', 'ASCII:Tambacounda;ID:2244993', '23808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23808', '112', '25685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.05.2244993» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25686', '1079', '1', 'Sédhiou', 'SN.11.2245705', 'ASCII:Sedhiou;ID:2245705', '23809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23809', '112', '25686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.11.2245705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25687', '1079', '1', 'Podor', 'SN.14.2246656', 'ASCII:Podor;ID:2246656', '23810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23810', '112', '25687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.14.2246656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25688', '1079', '1', 'Oussouye', 'SN.12.2246902', 'ASCII:Oussouye;ID:2246902', '23811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23811', '112', '25688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.12.2246902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25689', '1079', '1', 'Nioro du Rip', 'SN.09.2247158', 'ASCII:Nioro du Rip;ID:2247158', '23812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23812', '112', '25689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.09.2247158» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25690', '1079', '1', 'Mbour', 'SN.07.2248478', 'ASCII:Mbour;ID:2248478', '23813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23813', '112', '25690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.07.2248478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25691', '1079', '1', 'Mbaké', 'SN.03.2248699', 'ASCII:Mbake;ID:2248699', '23814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23814', '112', '25691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.03.2248699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25692', '1079', '1', 'Louga', 'SN.13.2249224', 'ASCII:Louga;ID:2249224', '23815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23815', '112', '25692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.13.2249224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25693', '1079', '1', 'Linguère', 'SN.03.2249283', 'ASCII:Linguere;ID:2249283', '23816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23816', '112', '25693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.03.2249283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25694', '1079', '1', 'Kédougou', 'SN.05.2250648', 'ASCII:Kedougou;ID:2250648', '23817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23817', '112', '25694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.05.2250648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25695', '1079', '1', 'Kébémer', 'SN.13.2250660', 'ASCII:Kebemer;ID:2250660', '23818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23818', '112', '25695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.13.2250660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25696', '1079', '1', 'Kaolack', 'SN.10.2250807', 'ASCII:Kaolack;ID:2250807', '23819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23819', '112', '25696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.10.2250807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25697', '1079', '1', 'Kaffrine', 'SN.10.2251008', 'ASCII:Kaffrine;ID:2251008', '23820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23820', '112', '25697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.10.2251008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25698', '1079', '1', 'Gossas', 'SN.09.2251492', 'ASCII:Gossas;ID:2251492', '23821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23821', '112', '25698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.09.2251492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25699', '1079', '1', 'Foundiougne', 'SN.09.2251792', 'ASCII:Foundiougne;ID:2251792', '23822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23822', '112', '25699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.09.2251792» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25700', '1079', '1', 'Diourbel', 'SN.03.2252312', 'ASCII:Diourbel;ID:2252312', '23823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23823', '112', '25700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.03.2252312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25701', '1079', '1', 'Dagana', 'SN.14.2253376', 'ASCII:Dagana;ID:2253376', '23824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23824', '112', '25701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.14.2253376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25702', '1079', '1', 'Bignona', 'SN.12.2253903', 'ASCII:Bignona;ID:2253903', '23825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23825', '112', '25702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.12.2253903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25703', '1079', '1', 'Bambey', 'SN.03.2254315', 'ASCII:Bambey;ID:2254315', '23826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23826', '112', '25703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.03.2254315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25704', '1079', '1', 'Bakel', 'SN.05.2254443', 'ASCII:Bakel;ID:2254443', '23827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23827', '112', '25704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SN.05.2254443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25705', '1079', '1', 'Degmada Badhaadhe', 'SO.09.65061', 'ASCII:Degmada Badhaadhe;ID:65061', '23828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23828', '112', '25705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SO.09.65061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25706', '1079', '1', 'Distrito de Zacatecoluca', 'SV.06.3582804', 'ASCII:Distrito de Zacatecoluca;ID:3582804', '23829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23829', '112', '25706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.06.3582804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25707', '1079', '1', 'Distrito de Usulután', 'SV.14.3582881', 'ASCII:Distrito de Usulutan;ID:3582881', '23830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23830', '112', '25707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.14.3582881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25708', '1079', '1', 'Distrito de Tonacatepeque', 'SV.10.3582917', 'ASCII:Distrito de Tonacatepeque;ID:3582917', '23831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23831', '112', '25708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.10.3582917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25709', '1079', '1', 'Distrito de Tejutla', 'SV.03.3582991', 'ASCII:Distrito de Tejutla;ID:3582991', '23832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23832', '112', '25709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.03.3582991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25710', '1079', '1', 'Distrito de Suchitoto', 'SV.04.3583089', 'ASCII:Distrito de Suchitoto;ID:3583089', '23833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23833', '112', '25710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.04.3583089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25711', '1079', '1', 'Distrito de Sonsonate', 'SV.13.3583100', 'ASCII:Distrito de Sonsonate;ID:3583100', '23834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23834', '112', '25711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.13.3583100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25712', '1079', '1', 'Distrito de Sesori', 'SV.09.3583154', 'ASCII:Distrito de Sesori;ID:3583154', '23835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23835', '112', '25712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.09.3583154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25713', '1079', '1', 'Distrito de Sensuntepeque', 'SV.02.3583157', 'ASCII:Distrito de Sensuntepeque;ID:3583157', '23836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23836', '112', '25713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.02.3583157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25714', '1079', '1', 'Distrito de San Vicente', 'SV.12.3583175', 'ASCII:Distrito de San Vicente;ID:3583175', '23837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23837', '112', '25714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.12.3583175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25715', '1079', '1', 'Distrito de Santo Tomás', 'SV.10.3583181', 'ASCII:Distrito de Santo Tomas;ID:3583181', '23838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23838', '112', '25715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.10.3583181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25716', '1079', '1', 'Distrito de Santiago de María', 'SV.14.3583198', 'ASCII:Distrito de Santiago de Maria;ID:3583198', '23839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23839', '112', '25716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.14.3583198» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25717', '1079', '1', 'Distrito de Santa Rosa de Lima', 'SV.07.3583213', 'ASCII:Distrito de Santa Rosa de Lima;ID:3583213', '23840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23840', '112', '25717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.07.3583213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25718', '1079', '1', 'Distrito de Santa Ana', 'SV.11.3583331', 'ASCII:Distrito de Santa Ana;ID:3583331', '23841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23841', '112', '25718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.11.3583331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25719', '1079', '1', 'Distrito de San Sebastián', 'SV.12.3583346', 'ASCII:Distrito de San Sebastian;ID:3583346', '23842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23842', '112', '25719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.12.3583346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25720', '1079', '1', 'Distrito de San Salvador', 'SV.10.3583359', 'ASCII:Distrito de San Salvador;ID:3583359', '23843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23843', '112', '25720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.10.3583359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25721', '1079', '1', 'Distrito de San Pedro Nonualco', 'SV.06.3583403', 'ASCII:Distrito de San Pedro Nonualco;ID:3583403', '23844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23844', '112', '25721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.06.3583403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25722', '1079', '1', 'Distrito de San Pedro Masahuat', 'SV.06.3583406', 'ASCII:Distrito de San Pedro Masahuat;ID:3583406', '23845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23845', '112', '25722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.06.3583406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25723', '1079', '1', 'Distrito de San Miguel', 'SV.09.3583461', 'ASCII:Distrito de San Miguel;ID:3583461', '23846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23846', '112', '25723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.09.3583461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25724', '1079', '1', 'Distrito de San Juan Opico', 'SV.05.3583530', 'ASCII:Distrito de San Juan Opico;ID:3583530', '23847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23847', '112', '25724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.05.3583530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25725', '1079', '1', 'Distrito de San Francisco', 'SV.08.3583738', 'ASCII:Distrito de San Francisco;ID:3583738', '23848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23848', '112', '25725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.08.3583738» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25726', '1079', '1', 'Distrito de Quezaltepeque', 'SV.05.3583980', 'ASCII:Distrito de Quezaltepeque;ID:3583980', '23849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23849', '112', '25726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.05.3583980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25727', '1079', '1', 'Distrito de Osicala', 'SV.08.3584196', 'ASCII:Distrito de Osicala;ID:3584196', '23850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23850', '112', '25727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.08.3584196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25728', '1079', '1', 'Distrito de Olocuilta', 'SV.06.3584211', 'ASCII:Distrito de Olocuilta;ID:3584211', '23851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23851', '112', '25728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.06.3584211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25729', '1079', '1', 'Distrito de Nueva San Salvador', 'SV.05.3584256', 'ASCII:Distrito de Nueva San Salvador;ID:3584256', '23852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23852', '112', '25729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.05.3584256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25730', '1079', '1', 'Distrito de Metapán', 'SV.11.3584383', 'ASCII:Distrito de Metapan;ID:3584383', '23853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23853', '112', '25730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.11.3584383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25731', '1079', '1', 'Distrito de La Unión', 'SV.07.3584766', 'ASCII:Distrito de La Union;ID:3584766', '23854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23854', '112', '25731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.07.3584766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25732', '1079', '1', 'Distrito de Jucuapa', 'SV.14.3585397', 'ASCII:Distrito de Jucuapa;ID:3585397', '23855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23855', '112', '25732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.14.3585397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25733', '1079', '1', 'Distrito de Juayúa', 'SV.13.3585400', 'ASCII:Distrito de Juayua;ID:3585400', '23856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23856', '112', '25733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.13.3585400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25734', '1079', '1', 'Distrito de Jocoaitique', 'SV.08.3585430', 'ASCII:Distrito de Jocoaitique;ID:3585430', '23857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23857', '112', '25734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.08.3585430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25735', '1079', '1', 'Distrito de Izalco', 'SV.13.3585472', 'ASCII:Distrito de Izalco;ID:3585472', '23858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23858', '112', '25735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.13.3585472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25736', '1079', '1', 'Distrito de Ilobasco', 'SV.02.3585486', 'ASCII:Distrito de Ilobasco;ID:3585486', '23859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23859', '112', '25736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.02.3585486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25737', '1079', '1', 'Distrito de Dulce Nombre de María', 'SV.03.3586797', 'ASCII:Distrito de Dulce Nombre de Maria;ID:3586797', '23860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23860', '112', '25737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.03.3586797» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25738', '1079', '1', 'Distrito de Cojutepeque', 'SV.04.3586976', 'ASCII:Distrito de Cojutepeque;ID:3586976', '23861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23861', '112', '25738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.04.3586976» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25739', '1079', '1', 'Distrito de Chinameca', 'SV.09.3587036', 'ASCII:Distrito de Chinameca;ID:3587036', '23862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23862', '112', '25739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.09.3587036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25740', '1079', '1', 'Distrito de Chalchuapa', 'SV.11.3587085', 'ASCII:Distrito de Chalchuapa;ID:3587085', '23863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23863', '112', '25740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.11.3587085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25741', '1079', '1', 'Distrito de Chalatenango', 'SV.03.3587089', 'ASCII:Distrito de Chalatenango;ID:3587089', '23864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23864', '112', '25741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.03.3587089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25742', '1079', '1', 'Distrito de Berlín', 'SV.14.3587265', 'ASCII:Distrito de Berlin;ID:3587265', '23865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23865', '112', '25742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.14.3587265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25743', '1079', '1', 'Distrito de Atiquizaya', 'SV.01.3587316', 'ASCII:Distrito de Atiquizaya;ID:3587316', '23866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23866', '112', '25743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.01.3587316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25744', '1079', '1', 'Distrito de Ahuachapán', 'SV.01.3587424', 'ASCII:Distrito de Ahuachapan;ID:3587424', '23867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23867', '112', '25744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SV.01.3587424» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25745', '1079', '1', 'Minţaqat Ţarţūs', 'SY.14.163343', 'ASCII:Mintaqat Tartus;ID:163343', '23868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23868', '112', '25745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.14.163343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25746', '1079', '1', 'Minţaqat Tall Kalakh', 'SY.11.163532', 'ASCII:Mintaqat Tall Kalakh;ID:163532', '23869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23869', '112', '25746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.11.163532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25747', '1079', '1', 'Minţaqat Shahbā''', 'SY.05.164625', 'ASCII:Mintaqat Shahba'';ID:164625', '23870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23870', '112', '25747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.05.164625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25748', '1079', '1', 'Minţaqat Şalkhad', 'SY.05.164916', 'ASCII:Mintaqat Salkhad;ID:164916', '23871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23871', '112', '25748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.05.164916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25749', '1079', '1', 'Minţaqat Salamīyah', 'SY.10.164946', 'ASCII:Mintaqat Salamiyah;ID:164946', '23872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23872', '112', '25749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.10.164946» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25750', '1079', '1', 'Minţaqat Şāfītā', 'SY.14.165059', 'ASCII:Mintaqat Safita;ID:165059', '23873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23873', '112', '25750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.14.165059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25751', '1079', '1', 'Minţaqat Qaţanā', 'SY.08.165928', 'ASCII:Mintaqat Qatana;ID:165928', '23874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23874', '112', '25751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.08.165928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25752', '1079', '1', 'Minţaqat Maşyāf', 'SY.10.167044', 'ASCII:Mintaqat Masyaf;ID:167044', '23875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23875', '112', '25752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.10.167044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25753', '1079', '1', 'Minţaqat Manbij', 'SY.09.167355', 'ASCII:Mintaqat Manbij;ID:167355', '23876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23876', '112', '25753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.09.167355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25754', '1079', '1', 'Minţaqat Ma`arrat an Nu`mān', 'SY.12.167610', 'ASCII:Mintaqat Ma`arrat an Nu`man;ID:167610', '23877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23877', '112', '25754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.12.167610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25755', '1079', '1', 'Minţaqat Jisr ash Shughūr', 'SY.12.169022', 'ASCII:Mintaqat Jisr ash Shughur;ID:169022', '23878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23878', '112', '25755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.12.169022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25756', '1079', '1', 'Minţaqat Jarābulus', 'SY.09.169178', 'ASCII:Mintaqat Jarabulus;ID:169178', '23879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23879', '112', '25756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.09.169178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25757', '1079', '1', 'Minţaqat Jablah', 'SY.02.169303', 'ASCII:Mintaqat Jablah;ID:169303', '23880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23880', '112', '25757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.02.169303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25758', '1079', '1', 'Minţaqat Jabal Sim`ān', 'SY.09.169326', 'ASCII:Mintaqat Jabal Sim`an;ID:169326', '23881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23881', '112', '25758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.09.169326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25759', '1079', '1', 'Minţaqat Izra`', 'SY.06.169339', 'ASCII:Mintaqat Izra`;ID:169339', '23882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23882', '112', '25759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.06.169339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25760', '1079', '1', 'Minţaqat Idlib', 'SY.12.169388', 'ASCII:Mintaqat Idlib;ID:169388', '23883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23883', '112', '25760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.12.169388» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25761', '1079', '1', 'Minţaqat Ḩimş', 'SY.11.169576', 'ASCII:Mintaqat Hims;ID:169576', '23884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23884', '112', '25761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.11.169576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25762', '1079', '1', 'Minţaqat Ḩārim', 'SY.12.169865', 'ASCII:Mintaqat Harim;ID:169865', '23885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23885', '112', '25762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.12.169865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25763', '1079', '1', 'Minţaqat Ḩamāh', 'SY.10.170016', 'ASCII:Mintaqat Hamah;ID:170016', '23886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23886', '112', '25763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.10.170016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25764', '1079', '1', 'Minţaqat Dūmā', 'SY.08.170590', 'ASCII:Mintaqat Duma;ID:170590', '23887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23887', '112', '25764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.08.170590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25765', '1079', '1', 'Minţaqat Dimashq', 'SY.08.170653', 'ASCII:Mintaqat Dimashq;ID:170653', '23888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23888', '112', '25765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.08.170653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25766', '1079', '1', 'Minţaqat Dijlah', 'SY.01.170665', 'ASCII:Mintaqat Dijlah;ID:170665', '23889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23889', '112', '25766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.01.170665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25767', '1079', '1', 'Minţaqat Dayr az Zawr', 'SY.07.170793', 'ASCII:Mintaqat Dayr az Zawr;ID:170793', '23890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23890', '112', '25767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.07.170793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25768', '1079', '1', 'Minţaqat Dar`ā', 'SY.06.170904', 'ASCII:Mintaqat Dar`a;ID:170904', '23891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23891', '112', '25768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.06.170904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25769', '1079', '1', 'Minţaqat Bāniyās', 'SY.14.171829', 'ASCII:Mintaqat Baniyas;ID:171829', '23892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23892', '112', '25769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.14.171829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25770', '1079', '1', 'Minţaqat az Zawīyah', 'SY.03.172039', 'ASCII:Mintaqat az Zawiyah;ID:172039', '23893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23893', '112', '25770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.03.172039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25771', '1079', '1', 'Minţaqat az Zabadān', 'SY.08.172060', 'ASCII:Mintaqat az Zabadan;ID:172060', '23894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23894', '112', '25771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.08.172060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25772', '1079', '1', 'Minţaqat A`zāz', 'SY.09.172081', 'ASCII:Mintaqat A`zaz;ID:172081', '23895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23895', '112', '25772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.09.172081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25773', '1079', '1', 'Minţaqat `Ayn al `Arab', 'SY.09.172255', 'ASCII:Mintaqat `Ayn al `Arab;ID:172255', '23896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23896', '112', '25773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.09.172255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25774', '1079', '1', 'Minţaqat at Tall', 'SY.08.172350', 'ASCII:Mintaqat at Tall;ID:172350', '23897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23897', '112', '25774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.08.172350» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25775', '1079', '1', 'Minţaqat as Suwaydā''', 'SY.05.172409', 'ASCII:Mintaqat as Suwayda'';ID:172409', '23898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23898', '112', '25775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.05.172409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25776', '1079', '1', 'Minţaqat ar Rastan', 'SY.11.172947', 'ASCII:Mintaqat ar Rastan;ID:172947', '23899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23899', '112', '25776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.11.172947» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25777', '1079', '1', 'Minţaqat ar Raqqah', 'SY.04.172956', 'ASCII:Mintaqat ar Raqqah;ID:172956', '23900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23900', '112', '25777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.04.172956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25778', '1079', '1', 'Minţaqat an Nabk', 'SY.08.173194', 'ASCII:Mintaqat an Nabk;ID:173194', '23901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23901', '112', '25778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.08.173194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25779', '1079', '1', 'Minţaqat al Quţayfah', 'SY.08.173313', 'ASCII:Mintaqat al Qutayfah;ID:173313', '23902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23902', '112', '25779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.08.173313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25780', '1079', '1', 'Minţaqat al Quşayr', 'SY.11.173324', 'ASCII:Mintaqat al Qusayr;ID:173324', '23903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23903', '112', '25780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.11.173324» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25781', '1079', '1', 'Minţaqat al Qunayţirah', 'SY.03.173335', 'ASCII:Mintaqat al Qunaytirah;ID:173335', '23904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23904', '112', '25781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.03.173335» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25782', '1079', '1', 'Minţaqat al Qardāḩah', 'SY.02.173365', 'ASCII:Mintaqat al Qardahah;ID:173365', '23905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23905', '112', '25782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.02.173365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25783', '1079', '1', 'Minţaqat al Qāmishl', 'SY.01.173378', 'ASCII:Mintaqat al Qamishl;ID:173378', '23906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23906', '112', '25783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.01.173378» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25784', '1079', '1', 'Minţaqat al Mukharram', 'SY.11.173435', 'ASCII:Mintaqat al Mukharram;ID:173435', '23907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23907', '112', '25784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.11.173435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25785', '1079', '1', 'Minţaqat al Mayādīn', 'SY.07.173481', 'ASCII:Mintaqat al Mayadin;ID:173481', '23908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23908', '112', '25785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.07.173481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25786', '1079', '1', 'Minţaqat al Lādhiqīyah', 'SY.02.173577', 'ASCII:Mintaqat al Ladhiqiyah;ID:173577', '23909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23909', '112', '25786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.02.173577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25787', '1079', '1', 'Minţaqat al Ḩasakah', 'SY.01.173812', 'ASCII:Mintaqat al Hasakah;ID:173812', '23910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23910', '112', '25787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.01.173812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25788', '1079', '1', 'Minţaqat al Ḩaffah', 'SY.02.173857', 'ASCII:Mintaqat al Haffah;ID:173857', '23911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23911', '112', '25788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.02.173857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25789', '1079', '1', 'Minţaqat al Ghāb', 'SY.10.173885', 'ASCII:Mintaqat al Ghab;ID:173885', '23912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23912', '112', '25789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.10.173885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25790', '1079', '1', 'Minţaqat al Bāb', 'SY.09.174019', 'ASCII:Mintaqat al Bab;ID:174019', '23913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23913', '112', '25790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.09.174019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25791', '1079', '1', 'Minţaqat `Afrīn', 'SY.09.174184', 'ASCII:Mintaqat `Afrin;ID:174184', '23914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23914', '112', '25791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.09.174184» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25792', '1079', '1', 'Minţaqat Abū Kamāl', 'SY.07.174447', 'ASCII:Mintaqat Abu Kamal;ID:174447', '23915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23915', '112', '25792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «SY.07.174447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25793', '1079', '1', 'Tromelin Island', 'TF.05.TE', 'ASCII:Tromelin Island;ID:933908', '23916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23916', '112', '25793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TF.05.TE» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25794', '1079', '1', 'Europa Island', 'TF.05.EU', 'ASCII:Europa Island;ID:933910', '23917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23917', '112', '25794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TF.05.EU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25795', '1079', '1', 'Bassas da India', 'TF.05.BS', 'ASCII:Bassas da India;ID:936202', '23918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23918', '112', '25795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TF.05.BS» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25796', '1079', '1', 'Juan de Nova Island', 'TF.05.JU', 'ASCII:Juan de Nova Island;ID:1024029', '23919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23919', '112', '25796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TF.05.JU» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25797', '1079', '1', 'Glorioso Islands', 'TF.05.GO', 'ASCII:Glorioso Islands;ID:1024037', '23920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23920', '112', '25797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TF.05.GO» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25798', '1079', '1', 'Préfecture de Vo', 'TG.24.2363489', 'ASCII:Prefecture de Vo;ID:2363489', '23921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23921', '112', '25798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.24.2363489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25799', '1079', '1', 'Préfecture du Zio', 'TG.24.2363533', 'ASCII:Prefecture du Zio;ID:2363533', '23922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23922', '112', '25799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.24.2363533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25800', '1079', '1', 'Préfecture de Tchaoudjo', 'TG.22.2363892', 'ASCII:Prefecture de Tchaoudjo;ID:2363892', '23923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23923', '112', '25800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.22.2363892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25801', '1079', '1', 'Préfecture de Tchamba', 'TG.22.2363907', 'ASCII:Prefecture de Tchamba;ID:2363907', '23924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23924', '112', '25801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.22.2363907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25802', '1079', '1', 'Préfecture de Yoto', 'TG.24.2364040', 'ASCII:Prefecture de Yoto;ID:2364040', '23925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23925', '112', '25802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.24.2364040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25803', '1079', '1', 'Préfecture de Sotouboua', 'TG.22.2364078', 'ASCII:Prefecture de Sotouboua;ID:2364078', '23926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23926', '112', '25803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.22.2364078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25804', '1079', '1', 'Préfecture du Haho', 'TG.25.2364751', 'ASCII:Prefecture du Haho;ID:2364751', '23927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23927', '112', '25804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.25.2364751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25805', '1079', '1', 'Préfecture de Doufelgou', 'TG.23.2364811', 'ASCII:Prefecture de Doufelgou;ID:2364811', '23928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23928', '112', '25805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.23.2364811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25806', '1079', '1', 'Préfecture de l'' Oti', 'TG.26.2365189', 'ASCII:Prefecture de l'' Oti;ID:2365189', '23929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23929', '112', '25806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.26.2365189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25807', '1079', '1', 'Préfecture du Golfe', 'TG.24.2365263', 'ASCII:Prefecture du Golfe;ID:2365263', '23930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23930', '112', '25807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.24.2365263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25808', '1079', '1', 'Préfecture de la Kozah', 'TG.23.2365382', 'ASCII:Prefecture de la Kozah;ID:2365382', '23931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23931', '112', '25808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.23.2365382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25809', '1079', '1', 'Préfecture de la Binah', 'TG.23.2365570', 'ASCII:Prefecture de la Binah;ID:2365570', '23932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23932', '112', '25809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.23.2365570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25810', '1079', '1', 'Préfecture du Kloto', 'TG.25.2365976', 'ASCII:Prefecture du Kloto;ID:2365976', '23933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23933', '112', '25810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.25.2365976» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25811', '1079', '1', 'Préfecture de Kéran', 'TG.23.2366167', 'ASCII:Prefecture de Keran;ID:2366167', '23934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23934', '112', '25811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.23.2366167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25812', '1079', '1', 'Préfecture de Tone', 'TG.26.2367163', 'ASCII:Prefecture de Tone;ID:2367163', '23935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23935', '112', '25812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.26.2367163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25813', '1079', '1', 'Préfecture de Bassar', 'TG.23.2367567', 'ASCII:Prefecture de Bassar;ID:2367567', '23936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23936', '112', '25813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.23.2367567» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25814', '1079', '1', 'Préfecture d'' Assoli', 'TG.23.2367655', 'ASCII:Prefecture d'' Assoli;ID:2367655', '23937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23937', '112', '25814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.23.2367655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25815', '1079', '1', 'Préfecture de Wawa', 'TG.25.2367659', 'ASCII:Prefecture de Wawa;ID:2367659', '23938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23938', '112', '25815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.25.2367659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25816', '1079', '1', 'Préfecture de l'' Ogou', 'TG.25.2367885', 'ASCII:Prefecture de l'' Ogou;ID:2367885', '23939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23939', '112', '25816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.25.2367885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25817', '1079', '1', 'Préfecture des Lacs', 'TG.24.2367989', 'ASCII:Prefecture des Lacs;ID:2367989', '23940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23940', '112', '25817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.24.2367989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25818', '1079', '1', 'Préfecture d'' Amou', 'TG.25.2368034', 'ASCII:Prefecture d'' Amou;ID:2368034', '23941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23941', '112', '25818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.25.2368034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25819', '1079', '1', 'Préfecture de l'' Avé', 'TG.24.2597440', 'ASCII:Prefecture de l'' Ave;ID:2597440', '23942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23942', '112', '25819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.24.2597440» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25820', '1079', '1', 'Préfecture d'' Agou', 'TG.25.2597441', 'ASCII:Prefecture d'' Agou;ID:2597441', '23943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23943', '112', '25820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.25.2597441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25821', '1079', '1', 'Préfecture d'' Est-Mono', 'TG.25.2597442', 'ASCII:Prefecture d'' Est-Mono;ID:2597442', '23944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23944', '112', '25821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.25.2597442» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25822', '1079', '1', 'Préfecture du Moyen-Mono', 'TG.25.2597443', 'ASCII:Prefecture du Moyen-Mono;ID:2597443', '23945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23945', '112', '25822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.25.2597443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25823', '1079', '1', 'Préfecture de Danyi', 'TG.25.2597444', 'ASCII:Prefecture de Danyi;ID:2597444', '23946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23946', '112', '25823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.25.2597444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25824', '1079', '1', 'Préfecture de Blitta', 'TG.22.2597445', 'ASCII:Prefecture de Blitta;ID:2597445', '23947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23947', '112', '25824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.22.2597445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25825', '1079', '1', 'Préfecture de Dankpen', 'TG.23.2597446', 'ASCII:Prefecture de Dankpen;ID:2597446', '23948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23948', '112', '25825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.23.2597446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25826', '1079', '1', 'Préfecture de Kpendjal', 'TG.26.2597447', 'ASCII:Prefecture de Kpendjal;ID:2597447', '23949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23949', '112', '25826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.26.2597447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25827', '1079', '1', 'Préfecture de Tandjouaré', 'TG.26.2597448', 'ASCII:Prefecture de Tandjouare;ID:2597448', '23950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23950', '112', '25827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TG.26.2597448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25828', '1079', '1', 'Amphoe Muang Ratchaburi', 'TH.52.1151981', 'ASCII:Amphoe Muang Ratchaburi;ID:1151981', '23951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23951', '112', '25828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.52.1151981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25829', '1079', '1', 'Amphoe Khlong Khlung', 'TH.11.1152853', 'ASCII:Amphoe Khlong Khlung;ID:1152853', '23952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23952', '112', '25829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.11.1152853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25830', '1079', '1', 'Amphoe Ban Rai', 'TH.15.1155055', 'ASCII:Amphoe Ban Rai;ID:1155055', '23953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23953', '112', '25830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.15.1155055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25831', '1079', '1', 'Khet Thon Buri', 'TH.40.1605402', 'ASCII:Khet Thon Buri;ID:1605402', '23954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23954', '112', '25831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1605402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25832', '1079', '1', 'King Amphoe Tha Khantho', 'TH.23.1605637', 'ASCII:King Amphoe Tha Khantho;ID:1605637', '23955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23955', '112', '25832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.23.1605637» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25833', '1079', '1', 'Amphoe Tha Bo', 'TH.17.1605676', 'ASCII:Amphoe Tha Bo;ID:1605676', '23956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23956', '112', '25833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.17.1605676» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25834', '1079', '1', 'Khet Taling Chan', 'TH.00.1605842', 'ASCII:Khet Taling Chan;ID:1605842', '23957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23957', '112', '25834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.00.1605842» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25835', '1079', '1', 'Amphoe Si Chiang Mai', 'TH.17.1606315', 'ASCII:Amphoe Si Chiang Mai;ID:1606315', '23958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23958', '112', '25835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.17.1606315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25836', '1079', '1', 'Amphoe Sawang Daen Din', 'TH.20.1606349', 'ASCII:Amphoe Sawang Daen Din;ID:1606349', '23959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23959', '112', '25836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.20.1606349» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25837', '1079', '1', 'Khet Samphanthawong', 'TH.40.1606639', 'ASCII:Khet Samphanthawong;ID:1606639', '23960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23960', '112', '25837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1606639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25838', '1079', '1', 'Amphoe Sai Noi', 'TH.38.1606836', 'ASCII:Amphoe Sai Noi;ID:1606836', '23961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23961', '112', '25838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.38.1606836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25839', '1079', '1', 'Khet Rat Burana', 'TH.40.1607054', 'ASCII:Khet Rat Burana;ID:1607054', '23962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23962', '112', '25839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1607054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25840', '1079', '1', 'Khet Pom Prap Sattru Phai', 'TH.40.1607326', 'ASCII:Khet Pom Prap Sattru Phai;ID:1607326', '23963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23963', '112', '25840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1607326» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25841', '1079', '1', 'Amphoe Phra Pradaeng', 'TH.42.1607507', 'ASCII:Amphoe Phra Pradaeng;ID:1607507', '23964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23964', '112', '25841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.42.1607507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25842', '1079', '1', 'Amphoe Phra Nakhon', 'TH.00.1607534', 'ASCII:Amphoe Phra Nakhon;ID:1607534', '23965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23965', '112', '25842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.00.1607534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25843', '1079', '1', 'Khet Phra Khanong', 'TH.40.1607541', 'ASCII:Khet Phra Khanong;ID:1607541', '23966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23966', '112', '25843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1607541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25844', '1079', '1', 'Amphoe Phen', 'TH.19.1607740', 'ASCII:Amphoe Phen;ID:1607740', '23967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23967', '112', '25844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.19.1607740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25845', '1079', '1', 'Khet Phaya Thai', 'TH.40.1607755', 'ASCII:Khet Phaya Thai;ID:1607755', '23968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23968', '112', '25845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1607755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25846', '1079', '1', 'Khet Pathum Wan', 'TH.40.1607981', 'ASCII:Khet Pathum Wan;ID:1607981', '23969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23969', '112', '25846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1607981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25847', '1079', '1', 'Amphoe Pak Thong Chai', 'TH.27.1608018', 'ASCII:Amphoe Pak Thong Chai;ID:1608018', '23970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23970', '112', '25847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.27.1608018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25848', '1079', '1', 'Amphoe Pak Kret', 'TH.38.1608047', 'ASCII:Amphoe Pak Kret;ID:1608047', '23971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23971', '112', '25848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.38.1608047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25849', '1079', '1', 'Amphoe Non Thai', 'TH.27.1608130', 'ASCII:Amphoe Non Thai;ID:1608130', '23972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23972', '112', '25849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.27.1608130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25850', '1079', '1', 'Amphoe Nong Han', 'TH.19.1608250', 'ASCII:Amphoe Nong Han;ID:1608250', '23973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23973', '112', '25850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.19.1608250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25851', '1079', '1', 'Amphoe Nong Bua Lamphu', 'TH.79.1608268', 'ASCII:Amphoe Nong Bua Lamphu;ID:1608268', '23974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23974', '112', '25851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.79.1608268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25852', '1079', '1', 'Amphoe Muang Udon Thani', 'TH.19.1608608', 'ASCII:Amphoe Muang Udon Thani;ID:1608608', '23975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23975', '112', '25852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.19.1608608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25853', '1079', '1', 'Amphoe Muang Samut Prakan', 'TH.42.1608623', 'ASCII:Amphoe Muang Samut Prakan;ID:1608623', '23976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23976', '112', '25853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.42.1608623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25854', '1079', '1', 'Amphoe Mueang Nonthaburi', 'TH.38.1608640', 'ASCII:Amphoe Mueang Nonthaburi;ID:1608640', '23977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23977', '112', '25854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.38.1608640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25855', '1079', '1', 'Khet Min Buri', 'TH.40.1608717', 'ASCII:Khet Min Buri;ID:1608717', '23978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23978', '112', '25855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1608717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25856', '1079', '1', 'Amphoe Lam Luk Ka', 'TH.39.1609218', 'ASCII:Amphoe Lam Luk Ka;ID:1609218', '23979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23979', '112', '25856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.39.1609218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25857', '1079', '1', 'Amphoe Kumphawapi', 'TH.19.1609335', 'ASCII:Amphoe Kumphawapi;ID:1609335', '23980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23980', '112', '25857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.19.1609335» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25858', '1079', '1', 'Khet Khlong San', 'TH.40.1609878', 'ASCII:Khet Khlong San;ID:1609878', '23981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23981', '112', '25858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1609878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25859', '1079', '1', 'Khet Dusit', 'TH.40.1610857', 'ASCII:Khet Dusit;ID:1610857', '23982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23982', '112', '25859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1610857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25860', '1079', '1', 'Amphoe Dan Khun Thot', 'TH.27.1610962', 'ASCII:Amphoe Dan Khun Thot;ID:1610962', '23983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23983', '112', '25860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.27.1610962» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25861', '1079', '1', 'Amphoe Chonnabot', 'TH.22.1611077', 'ASCII:Amphoe Chonnabot;ID:1611077', '23984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23984', '112', '25861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.22.1611077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25862', '1079', '1', 'Amphoe Chai Badan', 'TH.34.1611423', 'ASCII:Amphoe Chai Badan;ID:1611423', '23985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23985', '112', '25862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.34.1611423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25863', '1079', '1', 'Amphoe Ban Phu', 'TH.19.1614048', 'ASCII:Amphoe Ban Phu;ID:1614048', '23986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23986', '112', '25863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.19.1614048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25864', '1079', '1', 'Amphoe Ban Khwao', 'TH.26.1617623', 'ASCII:Amphoe Ban Khwao;ID:1617623', '23987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23987', '112', '25864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.26.1617623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25865', '1079', '1', 'Amphoe Bang Yai', 'TH.38.1619197', 'ASCII:Amphoe Bang Yai;ID:1619197', '23988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23988', '112', '25865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.38.1619197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25866', '1079', '1', 'Khet Bang Rak', 'TH.40.1619277', 'ASCII:Khet Bang Rak;ID:1619277', '23989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23989', '112', '25866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1619277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25867', '1079', '1', 'Amphoe Bang Phli', 'TH.42.1619346', 'ASCII:Amphoe Bang Phli;ID:1619346', '23990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23990', '112', '25867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.42.1619346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25868', '1079', '1', 'Khet Bangkok Noi', 'TH.40.1619459', 'ASCII:Khet Bangkok Noi;ID:1619459', '23991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23991', '112', '25868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1619459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25869', '1079', '1', 'Khet Bang Khen', 'TH.40.1619505', 'ASCII:Khet Bang Khen;ID:1619505', '23992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23992', '112', '25869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1619505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25870', '1079', '1', 'Khet Bang Kapi', 'TH.40.1619530', 'ASCII:Khet Bang Kapi;ID:1619530', '23993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23993', '112', '25870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.1619530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25871', '1079', '1', 'Amphoe Bang Bua Thong', 'TH.38.1619601', 'ASCII:Amphoe Bang Bua Thong;ID:1619601', '23994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23994', '112', '25871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.38.1619601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25872', '1079', '1', 'Amphoe Ta Phraya', 'TH.80.1949382', 'ASCII:Amphoe Ta Phraya;ID:1949382', '23995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23995', '112', '25872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.80.1949382» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25873', '1079', '1', 'Amphoe Bo Rai', 'TH.49.1949480', 'ASCII:Amphoe Bo Rai;ID:1949480', '23996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23996', '112', '25873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.49.1949480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25874', '1079', '1', 'Khet Yan Nawa', 'TH.40.6698709', 'ASCII:Khet Yan Nawa;ID:6698709', '23997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23997', '112', '25874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6698709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25875', '1079', '1', 'Amphoe Mueang Songkha', 'TH.68.6790731', 'ASCII:Amphoe Mueang Songkha;ID:6790731', '23998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23998', '112', '25875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.68.6790731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25876', '1079', '1', 'Amphoe Singhanakhon', 'TH.68.6791114', 'ASCII:Amphoe Singhanakhon;ID:6791114', '23999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('23999', '112', '25876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.68.6791114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25877', '1079', '1', 'Khet Ratchathewi', 'TH.40.6845022', 'ASCII:Khet Ratchathewi;ID:6845022', '24000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24000', '112', '25877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25878', '1079', '1', 'Khet Din Daeng', 'TH.40.6845107', 'ASCII:Khet Din Daeng;ID:6845107', '24001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24001', '112', '25878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25879', '1079', '1', 'Khet Saphan Sung', 'TH.40.6845108', 'ASCII:Khet Saphan Sung;ID:6845108', '24002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24002', '112', '25879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25880', '1079', '1', 'Khet Huai Khwang', 'TH.40.6845149', 'ASCII:Khet Huai Khwang;ID:6845149', '24003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24003', '112', '25880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25881', '1079', '1', 'Khet Bueng Kum', 'TH.40.6845216', 'ASCII:Khet Bueng Kum;ID:6845216', '24004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24004', '112', '25881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25882', '1079', '1', 'Khet Wang Thonglang', 'TH.40.6845218', 'ASCII:Khet Wang Thonglang;ID:6845218', '24005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24005', '112', '25882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25883', '1079', '1', 'Khet Bang Phlat', 'TH.40.6845259', 'ASCII:Khet Bang Phlat;ID:6845259', '24006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24006', '112', '25883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25884', '1079', '1', 'Khet Lat Phrao', 'TH.40.6845305', 'ASCII:Khet Lat Phrao;ID:6845305', '24007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24007', '112', '25884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25885', '1079', '1', 'Khet Bang Sue', 'TH.40.6845329', 'ASCII:Khet Bang Sue;ID:6845329', '24008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24008', '112', '25885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25886', '1079', '1', 'Khet Khan Na Yao', 'TH.40.6845386', 'ASCII:Khet Khan Na Yao;ID:6845386', '24009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24009', '112', '25886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25887', '1079', '1', 'Khet Khlong Sam Wa', 'TH.40.6845423', 'ASCII:Khet Khlong Sam Wa;ID:6845423', '24010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24010', '112', '25887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25888', '1079', '1', 'Khet Lak Si', 'TH.40.6845541', 'ASCII:Khet Lak Si;ID:6845541', '24011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24011', '112', '25888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25889', '1079', '1', 'Khet Don Mueang', 'TH.40.6845590', 'ASCII:Khet Don Mueang;ID:6845590', '24012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24012', '112', '25889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25890', '1079', '1', 'Khet Chatuchak', 'TH.40.6845605', 'ASCII:Khet Chatuchak;ID:6845605', '24013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24013', '112', '25890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25891', '1079', '1', 'Khet Sai Mai', 'TH.40.6845608', 'ASCII:Khet Sai Mai;ID:6845608', '24014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24014', '112', '25891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6845608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25892', '1079', '1', 'Khet Thawi Watthana', 'TH.40.6865728', 'ASCII:Khet Thawi Watthana;ID:6865728', '24015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24015', '112', '25892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6865728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25893', '1079', '1', 'Amphoe Phutthamonthon', 'TH.53.6865782', 'ASCII:Amphoe Phutthamonthon;ID:6865782', '24016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24016', '112', '25893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.53.6865782» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25894', '1079', '1', 'Amphoe Phra Samut Chedi', 'TH.42.6907984', 'ASCII:Amphoe Phra Samut Chedi;ID:6907984', '24017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24017', '112', '25894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.42.6907984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25895', '1079', '1', 'Khet Thung Khru', 'TH.40.6908219', 'ASCII:Khet Thung Khru;ID:6908219', '24018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24018', '112', '25895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6908219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25896', '1079', '1', 'Khet Bang Na', 'TH.40.6908403', 'ASCII:Khet Bang Na;ID:6908403', '24019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24019', '112', '25896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6908403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25897', '1079', '1', 'Khet Bang Kho Laem', 'TH.40.6908544', 'ASCII:Khet Bang Kho Laem;ID:6908544', '24020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24020', '112', '25897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6908544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25898', '1079', '1', 'Khet Khlong Toei', 'TH.40.6908641', 'ASCII:Khet Khlong Toei;ID:6908641', '24021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24021', '112', '25898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6908641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25899', '1079', '1', 'Khet Sathon', 'TH.40.6908643', 'ASCII:Khet Sathon;ID:6908643', '24022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24022', '112', '25899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6908643» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25900', '1079', '1', 'Khet Prawet', 'TH.40.6908736', 'ASCII:Khet Prawet;ID:6908736', '24023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24023', '112', '25900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6908736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25901', '1079', '1', 'Khet Watthana', 'TH.40.6908860', 'ASCII:Khet Watthana;ID:6908860', '24024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24024', '112', '25901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6908860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25902', '1079', '1', 'Khet Suan Luang', 'TH.40.6908863', 'ASCII:Khet Suan Luang;ID:6908863', '24025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24025', '112', '25902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TH.40.6908863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25903', '1079', '1', 'Zheleznodorozhnyy Rayon', 'TJ.00.1220048', 'ASCII:Zheleznodorozhnyy Rayon;ID:1220048', '24026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24026', '112', '25903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1220048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25904', '1079', '1', 'Tsentral''nyy Rayon', 'TJ.00.1220319', 'ASCII:Tsentral''nyy Rayon;ID:1220319', '24027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24027', '112', '25904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1220319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25905', '1079', '1', 'Kofarnikhonskiy Rayon', 'TJ.00.1220854', 'ASCII:Kofarnikhonskiy Rayon;ID:1220854', '24028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24028', '112', '25905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1220854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25906', '1079', '1', 'Oktyabr''skiy Rayon', 'TJ.00.1220859', 'ASCII:Oktyabr''skiy Rayon;ID:1220859', '24029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24029', '112', '25906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1220859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25907', '1079', '1', 'Leninskiy Rayon', 'TJ.00.1221088', 'ASCII:Leninskiy Rayon;ID:1221088', '24030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24030', '112', '25907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1221088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25908', '1079', '1', 'Muminobodskiy Rayon', 'TJ.00.1221090', 'ASCII:Muminobodskiy Rayon;ID:1221090', '24031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24031', '112', '25908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1221090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25909', '1079', '1', 'Komsomolabadskiy Rayon', 'TJ.00.1221249', 'ASCII:Komsomolabadskiy Rayon;ID:1221249', '24032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24032', '112', '25909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1221249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25910', '1079', '1', 'Bokhtarskiy Rayon', 'TJ.00.1221253', 'ASCII:Bokhtarskiy Rayon;ID:1221253', '24033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24033', '112', '25910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1221253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25911', '1079', '1', 'Darvozskiy Rayon', 'TJ.00.1221558', 'ASCII:Darvozskiy Rayon;ID:1221558', '24034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24034', '112', '25911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1221558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25912', '1079', '1', 'Gozimalikskiy Rayon', 'TJ.00.1221646', 'ASCII:Gozimalikskiy Rayon;ID:1221646', '24035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24035', '112', '25912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1221646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25913', '1079', '1', 'Gissarskiy Rayon', 'TJ.00.1221707', 'ASCII:Gissarskiy Rayon;ID:1221707', '24036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24036', '112', '25913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1221707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25914', '1079', '1', 'Fayzabadskiy Rayon', 'TJ.00.1221772', 'ASCII:Fayzabadskiy Rayon;ID:1221772', '24037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24037', '112', '25914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1221772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25915', '1079', '1', 'Gorod Dushanbe', 'TJ.00.1221873', 'ASCII:Gorod Dushanbe;ID:1221873', '24038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24038', '112', '25915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TJ.00.1221873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25916', '1079', '1', 'Aşgabat Şäheri', 'TM.01.162182', 'ASCII:Asgabat Saheri;ID:162182', '24039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24039', '112', '25916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TM.01.162182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25917', '1079', '1', 'Mu`tamadīyat Zaghwān', 'TN.37.2464039', 'ASCII:Mu`tamadiyat Zaghwan;ID:2464039', '24040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24040', '112', '25917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.37.2464039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25918', '1079', '1', 'Mu`tamadīyat Tūnis', 'TN.00.2464465', 'ASCII:Mu`tamadiyat Tunis;ID:2464465', '24041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24041', '112', '25918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.00.2464465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25919', '1079', '1', 'Mu`tamadīyat Tawzar', 'TN.35.2464646', 'ASCII:Mu`tamadiyat Tawzar;ID:2464646', '24042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24042', '112', '25919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.35.2464646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25920', '1079', '1', 'Mu`tamadīyat Taţāwīn', 'TN.34.2464700', 'ASCII:Mu`tamadiyat Tatawin;ID:2464700', '24043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24043', '112', '25920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.34.2464700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25921', '1079', '1', 'Mu`tamadīyat Sūsah', 'TN.16.2464914', 'ASCII:Mu`tamadiyat Susah;ID:2464914', '24044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24044', '112', '25921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.16.2464914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25922', '1079', '1', 'Délégation de Siliana', 'TN.22.2465029', 'ASCII:Delegation de Siliana;ID:2465029', '24045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24045', '112', '25922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.22.2465029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25923', '1079', '1', 'Wilāyat Sīdī Bū Zayd', 'TN.33.2465836', 'ASCII:Wilayat Sidi Bu Zayd;ID:2465836', '24046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24046', '112', '25923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.33.2465836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25924', '1079', '1', 'Mu`tamadīyat Shurbān', 'TN.15.2466895', 'ASCII:Mu`tamadiyat Shurban;ID:2466895', '24047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24047', '112', '25924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.15.2466895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25925', '1079', '1', 'Mu`tamadīyat as Sawāsī', 'TN.15.2467180', 'ASCII:Mu`tamadiyat as Sawasi;ID:2467180', '24048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24048', '112', '25925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.15.2467180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25926', '1079', '1', 'Mu`tamadīyat Şafāqis', 'TN.32.2467453', 'ASCII:Mu`tamadiyat Safaqis;ID:2467453', '24049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24049', '112', '25926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.32.2467453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25927', '1079', '1', 'Mu`tamadīyat Qibilī', 'TN.31.2468016', 'ASCII:Mu`tamadiyat Qibili;ID:2468016', '24050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24050', '112', '25927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.31.2468016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25928', '1079', '1', 'Mu`tamadīyat Qafşah', 'TN.30.2468352', 'ASCII:Mu`tamadiyat Qafsah;ID:2468352', '24051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24051', '112', '25928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.30.2468352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25929', '1079', '1', 'Mu`tamadīyat Qābis', 'TN.29.2468367', 'ASCII:Mu`tamadiyat Qabis;ID:2468367', '24052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24052', '112', '25929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.29.2468367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25930', '1079', '1', 'Mu`tamadīyat Nābul', 'TN.00.2468577', 'ASCII:Mu`tamadiyat Nabul;ID:2468577', '24053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24053', '112', '25930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.00.2468577» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25931', '1079', '1', 'Mu`tamadīyat Madanī', 'TN.28.2469474', 'ASCII:Mu`tamadiyat Madani;ID:2469474', '24054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24054', '112', '25931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.28.2469474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25932', '1079', '1', 'Mu`tamadīyat Jundūbah', 'TN.00.2470086', 'ASCII:Mu`tamadiyat Jundubah;ID:2470086', '24055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24055', '112', '25932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.00.2470086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25933', '1079', '1', 'Mu`tamadīyat Ḩammām al Anf', 'TN.00.2470587', 'ASCII:Mu`tamadiyat Hammam al Anf;ID:2470587', '24056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24056', '112', '25933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.00.2470587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25934', '1079', '1', 'Mu`tamadīyat Banzart', 'TN.00.2472701', 'ASCII:Mu`tamadiyat Banzart;ID:2472701', '24057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24057', '112', '25934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.00.2472701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25935', '1079', '1', 'Mu`tamadīyat Bājah', 'TN.00.2472772', 'ASCII:Mu`tamadiyat Bajah;ID:2472772', '24058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24058', '112', '25935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.00.2472772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25936', '1079', '1', ' Délégation de Oueslatia', 'TN.03.2473418', 'ASCII: Delegation de Oueslatia;ID:2473418', '24059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24059', '112', '25936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.03.2473418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25937', '1079', '1', 'Mu`tamadīyat al Qayrawān', 'TN.03.2473450', 'ASCII:Mu`tamadiyat al Qayrawan;ID:2473450', '24060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24060', '112', '25937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.03.2473450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25938', '1079', '1', 'Mu`tamadīyat al Qaşrayn', 'TN.02.2473459', 'ASCII:Mu`tamadiyat al Qasrayn;ID:2473459', '24061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24061', '112', '25938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.02.2473459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25939', '1079', '1', 'Mu`tamadīyat al Munastīr', 'TN.16.2473494', 'ASCII:Mu`tamadiyat al Munastir;ID:2473494', '24062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24062', '112', '25939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.16.2473494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25940', '1079', '1', 'Mu`tamadīyat al Maţwīyah', 'TN.29.2473532', 'ASCII:Mu`tamadiyat al Matwiyah;ID:2473532', '24063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24063', '112', '25940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.29.2473532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25941', '1079', '1', 'Mu`tamadīyat al Maḩras', 'TN.32.2473571', 'ASCII:Mu`tamadiyat al Mahras;ID:2473571', '24064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24064', '112', '25941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.32.2473571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25942', '1079', '1', 'Mu`tamadīyat al Mahdīyah', 'TN.16.2473573', 'ASCII:Mu`tamadiyat al Mahdiyah;ID:2473573', '24065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24065', '112', '25942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.16.2473573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25943', '1079', '1', 'Mu`tamadīyat al Kāf', 'TN.00.2473636', 'ASCII:Mu`tamadiyat al Kaf;ID:2473636', '24066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24066', '112', '25943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.00.2473636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25944', '1079', '1', 'Mu`tamadīyat al Jamm', 'TN.15.2473655', 'ASCII:Mu`tamadiyat al Jamm;ID:2473655', '24067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24067', '112', '25944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.15.2473655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25945', '1079', '1', 'Mu`tamadīyat al Jabal al Abyaḑ', 'TN.00.2473663', 'ASCII:Mu`tamadiyat al Jabal al Abyad;ID:2473663', '24068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24068', '112', '25945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.00.2473663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25946', '1079', '1', 'Mu`tamadīyat al Ḩammāmāt', 'TN.00.2473745', 'ASCII:Mu`tamadiyat al Hammamat;ID:2473745', '24069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24069', '112', '25946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TN.00.2473745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25947', '1079', '1', 'Karkamış İlçesi', 'TR.83.436186', 'ASCII:Karkamis Ilcesi;ID:436186', '24070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24070', '112', '25947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.83.436186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25948', '1079', '1', 'Oğuzeli İlçesi', 'TR.83.436187', 'ASCII:Oguzeli Ilcesi;ID:436187', '24071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24071', '112', '25948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.83.436187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25949', '1079', '1', 'Akçakale İlçesi', 'TR.63.436459', 'ASCII:Akcakale Ilcesi;ID:436459', '24072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24072', '112', '25949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.63.436459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25950', '1079', '1', 'Erzin İlçesi', 'TR.31.436926', 'ASCII:Erzin Ilcesi;ID:436926', '24073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24073', '112', '25950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.436926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25951', '1079', '1', 'Dörtyol İlçesi', 'TR.31.436927', 'ASCII:Dortyol Ilcesi;ID:436927', '24074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24074', '112', '25951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.436927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25952', '1079', '1', 'Hassa İlçesi', 'TR.31.436928', 'ASCII:Hassa Ilcesi;ID:436928', '24075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24075', '112', '25952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.436928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25953', '1079', '1', 'Kumlu', 'TR.31.437215', 'ASCII:Kumlu;ID:437215', '24076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24076', '112', '25953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.437215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25954', '1079', '1', 'Musabeyli İlçesi', 'TR.90.437251', 'ASCII:Musabeyli Ilcesi;ID:437251', '24077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24077', '112', '25954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.90.437251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25955', '1079', '1', 'İslahiye İlçesi', 'TR.83.437252', 'ASCII:Islahiye Ilcesi;ID:437252', '24078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24078', '112', '25955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.83.437252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25956', '1079', '1', 'Polateli İlçesi', 'TR.90.437627', 'ASCII:Polateli Ilcesi;ID:437627', '24079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24079', '112', '25956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.90.437627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25957', '1079', '1', 'Kilis İlçesi', 'TR.90.437628', 'ASCII:Kilis Ilcesi;ID:437628', '24080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24080', '112', '25957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.90.437628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25958', '1079', '1', 'Elbeyli İlçesi', 'TR.90.437629', 'ASCII:Elbeyli Ilcesi;ID:437629', '24081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24081', '112', '25958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.90.437629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25959', '1079', '1', 'Şahinbey İlçesi', 'TR.83.437630', 'ASCII:Sahinbey Ilcesi;ID:437630', '24082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24082', '112', '25959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.83.437630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25960', '1079', '1', 'İskenderun İlçesi', 'TR.31.437928', 'ASCII:Iskenderun Ilcesi;ID:437928', '24083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24083', '112', '25960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.437928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25961', '1079', '1', 'Kırıkhan İlçesi', 'TR.31.437929', 'ASCII:Kirikhan Ilcesi;ID:437929', '24084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24084', '112', '25961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.437929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25962', '1079', '1', 'Belen İlçesi', 'TR.31.437930', 'ASCII:Belen Ilcesi;ID:437930', '24085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24085', '112', '25962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.437930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25963', '1079', '1', 'Antakya İlçesi', 'TR.31.438417', 'ASCII:Antakya Ilcesi;ID:438417', '24086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24086', '112', '25963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.438417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25964', '1079', '1', 'Altınözü İlçesi', 'TR.31.438418', 'ASCII:Altinozu Ilcesi;ID:438418', '24087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24087', '112', '25964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.438418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25965', '1079', '1', 'Yayladağı İlçesi', 'TR.31.438427', 'ASCII:Yayladagi Ilcesi;ID:438427', '24088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24088', '112', '25965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.438427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25966', '1079', '1', 'Reyhanlı İlçesi', 'TR.31.438432', 'ASCII:Reyhanli Ilcesi;ID:438432', '24089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24089', '112', '25966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.31.438432» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25967', '1079', '1', 'Aydınlar İlçesi', 'TR.74.438519', 'ASCII:Aydinlar Ilcesi;ID:438519', '24090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24090', '112', '25967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.74.438519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25968', '1079', '1', 'Pervari İlçesi', 'TR.74.438624', 'ASCII:Pervari Ilcesi;ID:438624', '24091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24091', '112', '25968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.74.438624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25969', '1079', '1', 'Çatak İlçesi', 'TR.65.438700', 'ASCII:Catak Ilcesi;ID:438700', '24092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24092', '112', '25969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.65.438700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25970', '1079', '1', 'Şırnak İlçesi', 'TR.80.438773', 'ASCII:Sirnak Ilcesi;ID:438773', '24093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24093', '112', '25970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.80.438773» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25971', '1079', '1', 'Cizre İlçesi', 'TR.80.438774', 'ASCII:Cizre Ilcesi;ID:438774', '24094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24094', '112', '25971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.80.438774» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25972', '1079', '1', 'Uludere İlçesi', 'TR.80.438878', 'ASCII:Uludere Ilcesi;ID:438878', '24095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24095', '112', '25972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.80.438878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25973', '1079', '1', 'Beytüşşebap İlçesi', 'TR.80.438958', 'ASCII:Beytussebap Ilcesi;ID:438958', '24096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24096', '112', '25973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.80.438958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25974', '1079', '1', 'Silopi İlçesi', 'TR.80.438989', 'ASCII:Silopi Ilcesi;ID:438989', '24097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24097', '112', '25974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.80.438989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25975', '1079', '1', 'Harran İlçe', 'TR.63.439166', 'ASCII:Harran Ilce;ID:439166', '24098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24098', '112', '25975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.63.439166» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25976', '1079', '1', 'Ceylanpınar İlçe', 'TR.63.439201', 'ASCII:Ceylanpinar Ilce;ID:439201', '24099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24099', '112', '25976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.63.439201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25977', '1079', '1', 'Bismil İlçesi', 'TR.21.439825', 'ASCII:Bismil Ilcesi;ID:439825', '24100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24100', '112', '25977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.21.439825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25978', '1079', '1', 'Batman İlçesi', 'TR.76.440475', 'ASCII:Batman Ilcesi;ID:440475', '24101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24101', '112', '25978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.76.440475» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25979', '1079', '1', 'Beşiri İlçesi', 'TR.76.440476', 'ASCII:Besiri Ilcesi;ID:440476', '24102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24102', '112', '25979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.76.440476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25980', '1079', '1', 'Hasankeyf İlçesi', 'TR.76.440905', 'ASCII:Hasankeyf Ilcesi;ID:440905', '24103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24103', '112', '25980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.76.440905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25981', '1079', '1', 'Kurtalan İlçesi', 'TR.74.440906', 'ASCII:Kurtalan Ilcesi;ID:440906', '24104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24104', '112', '25981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.74.440906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25982', '1079', '1', 'Siirt İlçesi', 'TR.74.440907', 'ASCII:Siirt Ilcesi;ID:440907', '24105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24105', '112', '25982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.74.440907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25983', '1079', '1', 'Savur İlçesi', 'TR.72.441186', 'ASCII:Savur Ilcesi;ID:441186', '24106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24106', '112', '25983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.72.441186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25984', '1079', '1', 'Yeşilli İlçesi', 'TR.72.441187', 'ASCII:Yesilli Ilcesi;ID:441187', '24107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24107', '112', '25984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.72.441187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25985', '1079', '1', 'Ömerli İlçe', 'TR.72.441188', 'ASCII:Omerli Ilce;ID:441188', '24108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24108', '112', '25985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.72.441188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25986', '1079', '1', 'Gercüş İlçesi', 'TR.76.441468', 'ASCII:Gercus Ilcesi;ID:441468', '24109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24109', '112', '25986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.76.441468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25987', '1079', '1', 'Midyat İlçesi', 'TR.72.441469', 'ASCII:Midyat Ilcesi;ID:441469', '24110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24110', '112', '25987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.72.441469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25988', '1079', '1', 'Güçlükonak İlçesi', 'TR.80.441645', 'ASCII:Guclukonak Ilcesi;ID:441645', '24111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24111', '112', '25988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.80.441645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25989', '1079', '1', 'Dargeçit İlçesi', 'TR.72.441646', 'ASCII:Dargecit Ilcesi;ID:441646', '24112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24112', '112', '25989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.72.441646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25990', '1079', '1', 'Mardin İlçesi', 'TR.72.441866', 'ASCII:Mardin Ilcesi;ID:441866', '24113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24113', '112', '25990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.72.441866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25991', '1079', '1', 'Nusaybin İlçesi', 'TR.72.441966', 'ASCII:Nusaybin Ilcesi;ID:441966', '24114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24114', '112', '25991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.72.441966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25992', '1079', '1', 'İdil İlçesi', 'TR.80.442034', 'ASCII:Idil Ilcesi;ID:442034', '24115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24115', '112', '25992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.80.442034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25993', '1079', '1', 'Karakoçan / Elazığ', 'TR.23.6544214', 'ASCII:Karakocan / Elazig;ID:6544214', '24116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24116', '112', '25993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.23.6544214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25994', '1079', '1', 'Karakoçan', 'TR.23.6544215', 'ASCII:Karakocan;ID:6544215', '24117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24117', '112', '25994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TR.23.6544215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25995', '1079', '1', 'Ward of Valencia', 'TT.06.3573559', 'ASCII:Ward of Valencia;ID:3573559', '24118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24118', '112', '25995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.06.3573559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25996', '1079', '1', 'Ward of Turure', 'TT.06.3573575', 'ASCII:Ward of Turure;ID:3573575', '24119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24119', '112', '25996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.06.3573575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25997', '1079', '1', 'Ward of Trinity', 'TT.03.3573589', 'ASCII:Ward of Trinity;ID:3573589', '24120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24120', '112', '25997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.03.3573589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25998', '1079', '1', 'Ward of Toco', 'TT.07.3573603', 'ASCII:Ward of Toco;ID:3573603', '24121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24121', '112', '25998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.07.3573603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('25999', '1079', '1', 'Ward of Tamana', 'TT.06.3573635', 'ASCII:Ward of Tamana;ID:3573635', '24122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24122', '112', '25999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.06.3573635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26000', '1079', '1', 'Ward of Tacarigua', 'TT.08.3573642', 'ASCII:Ward of Tacarigua;ID:3573642', '24123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24123', '112', '26000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.08.3573642» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26001', '1079', '1', 'Ward of Siparia', 'TT.09.3573680', 'ASCII:Ward of Siparia;ID:3573680', '24124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24124', '112', '26001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.09.3573680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26002', '1079', '1', 'Ward of Savana Grande', 'TT.12.3573709', 'ASCII:Ward of Savana Grande;ID:3573709', '24125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24125', '112', '26002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.12.3573709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26003', '1079', '1', 'Ward of San Rafael', 'TT.08.3573722', 'ASCII:Ward of San Rafael;ID:3573722', '24126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24126', '112', '26003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.08.3573722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26004', '1079', '1', 'Saint Paul', 'TT.11.3573759', 'ASCII:Saint Paul;ID:3573759', '24127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24127', '112', '26004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.11.3573759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26005', '1079', '1', 'Saint Patrick', 'TT.11.3573761', 'ASCII:Saint Patrick;ID:3573761', '24128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24128', '112', '26005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.11.3573761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26006', '1079', '1', 'Saint Mary', 'TT.11.3573766', 'ASCII:Saint Mary;ID:3573766', '24129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24129', '112', '26006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.11.3573766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26007', '1079', '1', 'Saint John', 'TT.11.3573778', 'ASCII:Saint John;ID:3573778', '24130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24130', '112', '26007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.11.3573778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26008', '1079', '1', 'Saint George', 'TT.11.3573784', 'ASCII:Saint George;ID:3573784', '24131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24131', '112', '26008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.11.3573784» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26009', '1079', '1', 'Saint David', 'TT.11.3573793', 'ASCII:Saint David;ID:3573793', '24132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24132', '112', '26009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.11.3573793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26010', '1079', '1', 'Ward of Saint Ann''s', 'TT.08.3573800', 'ASCII:Ward of Saint Ann''s;ID:3573800', '24133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24133', '112', '26010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.08.3573800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26011', '1079', '1', 'Saint Andrew', 'TT.11.3573805', 'ASCII:Saint Andrew;ID:3573805', '24134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24134', '112', '26011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.11.3573805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26012', '1079', '1', 'Ward of Pointe-à-Pierre', 'TT.12.3573901', 'ASCII:Ward of Pointe-a-Pierre;ID:3573901', '24135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24135', '112', '26012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.12.3573901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26013', '1079', '1', 'Ward of Ortoire', 'TT.12.3574008', 'ASCII:Ward of Ortoire;ID:3574008', '24136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24136', '112', '26013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.12.3574008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26014', '1079', '1', 'Ward of Naparima', 'TT.12.3574064', 'ASCII:Ward of Naparima;ID:3574064', '24137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24137', '112', '26014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.12.3574064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26015', '1079', '1', 'Ward of Moruga', 'TT.12.3574086', 'ASCII:Ward of Moruga;ID:3574086', '24138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24138', '112', '26015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.12.3574086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26016', '1079', '1', 'Ward of Montserrat', 'TT.02.3574111', 'ASCII:Ward of Montserrat;ID:3574111', '24139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24139', '112', '26016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.02.3574111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26017', '1079', '1', 'Ward of Matura', 'TT.06.3574167', 'ASCII:Ward of Matura;ID:3574167', '24140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24140', '112', '26017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.06.3574167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26018', '1079', '1', 'Ward of Manzanilla', 'TT.06.3574201', 'ASCII:Ward of Manzanilla;ID:3574201', '24141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24141', '112', '26018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.06.3574201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26019', '1079', '1', 'Ward of La Brea', 'TT.09.3574352', 'ASCII:Ward of La Brea;ID:3574352', '24142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24142', '112', '26019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.09.3574352» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26020', '1079', '1', 'Ward of Guayaguayare', 'TT.03.3574434', 'ASCII:Ward of Guayaguayare;ID:3574434', '24143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24143', '112', '26020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.03.3574434» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26021', '1079', '1', 'Ward of Erin', 'TT.09.3574590', 'ASCII:Ward of Erin;ID:3574590', '24144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24144', '112', '26021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.09.3574590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26022', '1079', '1', 'Ward of Diego Martin', 'TT.08.3574635', 'ASCII:Ward of Diego Martin;ID:3574635', '24145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24145', '112', '26022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.08.3574635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26023', '1079', '1', 'Ward of Cunupia', 'TT.02.3574679', 'ASCII:Ward of Cunupia;ID:3574679', '24146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24146', '112', '26023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.02.3574679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26024', '1079', '1', 'Ward of Couva', 'TT.02.3574723', 'ASCII:Ward of Couva;ID:3574723', '24147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24147', '112', '26024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.02.3574723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26025', '1079', '1', 'Ward of Cocal', 'TT.04.3574768', 'ASCII:Ward of Cocal;ID:3574768', '24148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24148', '112', '26025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.04.3574768» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26026', '1079', '1', 'Ward of Charuma', 'TT.04.3574796', 'ASCII:Ward of Charuma;ID:3574796', '24149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24149', '112', '26026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.04.3574796» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26027', '1079', '1', 'Ward of Chaguanas', 'TT.02.3574809', 'ASCII:Ward of Chaguanas;ID:3574809', '24150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24150', '112', '26027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.02.3574809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26028', '1079', '1', 'Ward of Cedros', 'TT.09.3574824', 'ASCII:Ward of Cedros;ID:3574824', '24151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24151', '112', '26028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.09.3574824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26029', '1079', '1', 'Ward of Blanchisseuse', 'TT.08.3574971', 'ASCII:Ward of Blanchisseuse;ID:3574971', '24152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24152', '112', '26029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.08.3574971» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26030', '1079', '1', 'Ward of Arima', 'TT.01.3575050', 'ASCII:Ward of Arima;ID:3575050', '24153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24153', '112', '26030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TT.01.3575050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26031', '1079', '1', 'Wete District', 'TZ.00.148839', 'ASCII:Wete District;ID:148839', '24154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24154', '112', '26031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.148839» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26032', '1079', '1', 'Wete Area', 'TZ.00.148841', 'ASCII:Wete Area;ID:148841', '24155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24155', '112', '26032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.148841» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26033', '1079', '1', 'Urambo District', 'TZ.00.149171', 'ASCII:Urambo District;ID:149171', '24156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24156', '112', '26033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.149171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26034', '1079', '1', 'Ulanga District', 'TZ.00.149252', 'ASCII:Ulanga District;ID:149252', '24157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24157', '112', '26034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.149252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26035', '1079', '1', 'Ukerewe District', 'TZ.00.149294', 'ASCII:Ukerewe District;ID:149294', '24158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24158', '112', '26035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.149294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26036', '1079', '1', 'Temeke District', 'TZ.00.149542', 'ASCII:Temeke District;ID:149542', '24159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24159', '112', '26036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.149542» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26037', '1079', '1', 'Tarime District', 'TZ.00.149579', 'ASCII:Tarime District;ID:149579', '24160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24160', '112', '26037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.149579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26038', '1079', '1', 'Tanga District', 'TZ.00.149601', 'ASCII:Tanga District;ID:149601', '24161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24161', '112', '26038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.149601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26039', '1079', '1', 'Tabora District', 'TZ.00.149654', 'ASCII:Tabora District;ID:149654', '24162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24162', '112', '26039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.149654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26040', '1079', '1', 'Sumbawanga District', 'TZ.00.149702', 'ASCII:Sumbawanga District;ID:149702', '24163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24163', '112', '26040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.149702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26041', '1079', '1', 'South Area', 'TZ.00.149753', 'ASCII:South Area;ID:149753', '24164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24164', '112', '26041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.149753» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26042', '1079', '1', 'Singida District', 'TZ.00.149877', 'ASCII:Singida District;ID:149877', '24165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24165', '112', '26042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.149877» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26043', '1079', '1', 'Shinyanga District', 'TZ.00.150005', 'ASCII:Shinyanga District;ID:150005', '24166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24166', '112', '26043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.150005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26044', '1079', '1', 'Serengeti District', 'TZ.00.150095', 'ASCII:Serengeti District;ID:150095', '24167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24167', '112', '26044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.150095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26045', '1079', '1', 'Sengerema District', 'TZ.00.150102', 'ASCII:Sengerema District;ID:150102', '24168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24168', '112', '26045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.150102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26046', '1079', '1', 'Same District', 'TZ.00.150275', 'ASCII:Same District;ID:150275', '24169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24169', '112', '26046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.150275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26047', '1079', '1', 'Rungwe District', 'TZ.00.150412', 'ASCII:Rungwe District;ID:150412', '24170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24170', '112', '26047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.150412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26048', '1079', '1', 'Rufiji District', 'TZ.00.150487', 'ASCII:Rufiji District;ID:150487', '24171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24171', '112', '26048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.150487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26049', '1079', '1', 'Rombo District', 'TZ.00.150555', 'ASCII:Rombo District;ID:150555', '24172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24172', '112', '26049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.150555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26050', '1079', '1', 'Pangani District', 'TZ.00.150788', 'ASCII:Pangani District;ID:150788', '24173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24173', '112', '26050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.150788» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26051', '1079', '1', 'Nzega District', 'TZ.00.150929', 'ASCII:Nzega District;ID:150929', '24174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24174', '112', '26051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.150929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26052', '1079', '1', 'Northern Mudiria', 'TZ.00.151390', 'ASCII:Northern Mudiria;ID:151390', '24175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24175', '112', '26052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.151390» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26053', '1079', '1', 'Nkansi District', 'TZ.00.151459', 'ASCII:Nkansi District;ID:151459', '24176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24176', '112', '26053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.151459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26054', '1079', '1', 'Njombe District', 'TZ.00.151477', 'ASCII:Njombe District;ID:151477', '24177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24177', '112', '26054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.151477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26055', '1079', '1', 'Ngorongoro District', 'TZ.00.151607', 'ASCII:Ngorongoro District;ID:151607', '24178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24178', '112', '26055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.151607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26056', '1079', '1', 'Ngara District', 'TZ.00.151710', 'ASCII:Ngara District;ID:151710', '24179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24179', '112', '26056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.151710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26057', '1079', '1', 'Mwanza District', 'TZ.00.152223', 'ASCII:Mwanza District;ID:152223', '24180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24180', '112', '26057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.152223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26058', '1079', '1', 'Mwanga District', 'TZ.00.152262', 'ASCII:Mwanga District;ID:152262', '24181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24181', '112', '26058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.152262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26059', '1079', '1', 'Musoma District', 'TZ.00.152450', 'ASCII:Musoma District;ID:152450', '24182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24182', '112', '26059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.152450» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26060', '1079', '1', 'Muleba District', 'TZ.00.152569', 'ASCII:Muleba District;ID:152569', '24183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24183', '112', '26060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.152569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26061', '1079', '1', 'Muheza District', 'TZ.00.152629', 'ASCII:Muheza District;ID:152629', '24184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24184', '112', '26061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.152629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26062', '1079', '1', 'Mufindi District', 'TZ.00.152698', 'ASCII:Mufindi District;ID:152698', '24185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24185', '112', '26062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.152698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26063', '1079', '1', 'Mpwapwa District', 'TZ.00.153093', 'ASCII:Mpwapwa District;ID:153093', '24186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24186', '112', '26063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.153093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26064', '1079', '1', 'Mpanda District', 'TZ.00.153173', 'ASCII:Mpanda District;ID:153173', '24187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24187', '112', '26064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.153173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26065', '1079', '1', 'Moshi District', 'TZ.00.153208', 'ASCII:Moshi District;ID:153208', '24188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24188', '112', '26065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.153208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26066', '1079', '1', 'Morogoro District', 'TZ.00.153216', 'ASCII:Morogoro District;ID:153216', '24189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24189', '112', '26066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.153216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26067', '1079', '1', 'Monduli District', 'TZ.00.153246', 'ASCII:Monduli District;ID:153246', '24190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24190', '112', '26067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.153246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26068', '1079', '1', 'Mkoani District', 'TZ.00.153597', 'ASCII:Mkoani District;ID:153597', '24191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24191', '112', '26068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.153597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26069', '1079', '1', 'Mkoani Area', 'TZ.00.153599', 'ASCII:Mkoani Area;ID:153599', '24192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24192', '112', '26069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.153599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26070', '1079', '1', 'Mbulu District', 'TZ.00.154311', 'ASCII:Mbulu District;ID:154311', '24193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24193', '112', '26070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.154311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26071', '1079', '1', 'Mbozi District', 'TZ.00.154331', 'ASCII:Mbozi District;ID:154331', '24194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24194', '112', '26071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.154331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26072', '1079', '1', 'Mbeya District', 'TZ.00.154379', 'ASCII:Mbeya District;ID:154379', '24195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24195', '112', '26072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.154379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26073', '1079', '1', 'Maswa District', 'TZ.00.154646', 'ASCII:Maswa District;ID:154646', '24196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24196', '112', '26073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.154646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26074', '1079', '1', 'Manyoni District', 'TZ.00.154836', 'ASCII:Manyoni District;ID:154836', '24197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24197', '112', '26074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.154836» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26075', '1079', '1', 'Makete District', 'TZ.00.155165', 'ASCII:Makete District;ID:155165', '24198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24198', '112', '26075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.155165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26076', '1079', '1', 'Magu District', 'TZ.00.155313', 'ASCII:Magu District;ID:155313', '24199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24199', '112', '26076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.155313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26077', '1079', '1', 'Magharib Mudiria', 'TZ.00.155356', 'ASCII:Magharib Mudiria;ID:155356', '24200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24200', '112', '26077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.155356» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26078', '1079', '1', 'Mafia District', 'TZ.00.155411', 'ASCII:Mafia District;ID:155411', '24201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24201', '112', '26078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.155411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26079', '1079', '1', 'Lushoto District', 'TZ.00.155568', 'ASCII:Lushoto District;ID:155568', '24202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24202', '112', '26079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.155568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26080', '1079', '1', 'Liwale District', 'TZ.00.155918', 'ASCII:Liwale District;ID:155918', '24203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24203', '112', '26080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.155918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26081', '1079', '1', 'Kyela District', 'TZ.00.156110', 'ASCII:Kyela District;ID:156110', '24204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24204', '112', '26081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.156110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26082', '1079', '1', 'Kwimba District', 'TZ.00.156136', 'ASCII:Kwimba District;ID:156136', '24205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24205', '112', '26082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.156136» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26083', '1079', '1', 'Korogwe District', 'TZ.00.156478', 'ASCII:Korogwe District;ID:156478', '24206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24206', '112', '26083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.156478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26084', '1079', '1', 'Kondoa District', 'TZ.00.156509', 'ASCII:Kondoa District;ID:156509', '24207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24207', '112', '26084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.156509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26085', '1079', '1', 'Konde District', 'TZ.00.156511', 'ASCII:Konde District;ID:156511', '24208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24208', '112', '26085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.156511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26086', '1079', '1', 'Konde Area', 'TZ.00.156512', 'ASCII:Konde Area;ID:156512', '24209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24209', '112', '26086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.156512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26087', '1079', '1', 'Kiteto District', 'TZ.00.156810', 'ASCII:Kiteto District;ID:156810', '24210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24210', '112', '26087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.156810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26088', '1079', '1', 'Kisarawe District', 'TZ.00.156995', 'ASCII:Kisarawe District;ID:156995', '24211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24211', '112', '26088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.156995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26089', '1079', '1', 'Kinondoni District', 'TZ.00.157253', 'ASCII:Kinondoni District;ID:157253', '24212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24212', '112', '26089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.157253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26090', '1079', '1', 'Kilwa District', 'TZ.00.157383', 'ASCII:Kilwa District;ID:157383', '24213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24213', '112', '26090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.157383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26091', '1079', '1', 'Kilosa District', 'TZ.00.157402', 'ASCII:Kilosa District;ID:157402', '24214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24214', '112', '26091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.157402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26092', '1079', '1', 'Kilombero District', 'TZ.00.157408', 'ASCII:Kilombero District;ID:157408', '24215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24215', '112', '26092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.157408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26093', '1079', '1', 'Kigoma District', 'TZ.00.157736', 'ASCII:Kigoma District;ID:157736', '24216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24216', '112', '26093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.157736» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26094', '1079', '1', 'Kibondo District', 'TZ.00.157958', 'ASCII:Kibondo District;ID:157958', '24217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24217', '112', '26094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.157958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26095', '1079', '1', 'Kasulu District', 'TZ.00.158213', 'ASCII:Kasulu District;ID:158213', '24218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24218', '112', '26095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.158213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26096', '1079', '1', 'Karagwe District', 'TZ.00.158337', 'ASCII:Karagwe District;ID:158337', '24219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24219', '112', '26096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.158337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26097', '1079', '1', 'Kahama District', 'TZ.00.158596', 'ASCII:Kahama District;ID:158596', '24220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24220', '112', '26097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.158596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26098', '1079', '1', 'Iringa District', 'TZ.00.159070', 'ASCII:Iringa District;ID:159070', '24221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24221', '112', '26098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.159070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26099', '1079', '1', 'Iramba District', 'TZ.00.159085', 'ASCII:Iramba District;ID:159085', '24222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24222', '112', '26099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.159085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26100', '1079', '1', 'Ileje District', 'TZ.00.159221', 'ASCII:Ileje District;ID:159221', '24223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24223', '112', '26100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.159221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26101', '1079', '1', 'Ilala District', 'TZ.00.159239', 'ASCII:Ilala District;ID:159239', '24224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24224', '112', '26101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.159239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26102', '1079', '1', 'Igunga District', 'TZ.00.159384', 'ASCII:Igunga District;ID:159384', '24225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24225', '112', '26102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.159384» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26103', '1079', '1', 'Handeni District', 'TZ.00.159673', 'ASCII:Handeni District;ID:159673', '24226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24226', '112', '26103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.159673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26104', '1079', '1', 'Hanang District', 'TZ.00.159684', 'ASCII:Hanang District;ID:159684', '24227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24227', '112', '26104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.159684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26105', '1079', '1', 'Hai District', 'TZ.00.159711', 'ASCII:Hai District;ID:159711', '24228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24228', '112', '26105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.159711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26106', '1079', '1', 'Geita District', 'TZ.00.159907', 'ASCII:Geita District;ID:159907', '24229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24229', '112', '26106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.159907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26107', '1079', '1', 'Dodoma District', 'TZ.00.160193', 'ASCII:Dodoma District;ID:160193', '24230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24230', '112', '26107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.160193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26108', '1079', '1', 'Chunya District', 'TZ.00.160321', 'ASCII:Chunya District;ID:160321', '24231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24231', '112', '26108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.160321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26109', '1079', '1', 'Chake Chake Mudiria', 'TZ.00.160674', 'ASCII:Chake Chake Mudiria;ID:160674', '24232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24232', '112', '26109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.160674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26110', '1079', '1', 'Chake Chake District', 'TZ.00.160675', 'ASCII:Chake Chake District;ID:160675', '24233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24233', '112', '26110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.160675» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26111', '1079', '1', 'Central Area', 'TZ.00.160706', 'ASCII:Central Area;ID:160706', '24234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24234', '112', '26111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.160706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26112', '1079', '1', 'Bunda District', 'TZ.00.160891', 'ASCII:Bunda District;ID:160891', '24235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24235', '112', '26112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.160891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26113', '1079', '1', 'Bukoba District', 'TZ.00.160960', 'ASCII:Bukoba District;ID:160960', '24236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24236', '112', '26113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.160960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26114', '1079', '1', 'Biharamulo District', 'TZ.00.161153', 'ASCII:Biharamulo District;ID:161153', '24237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24237', '112', '26114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.161153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26115', '1079', '1', 'Bariadi District', 'TZ.00.161217', 'ASCII:Bariadi District;ID:161217', '24238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24238', '112', '26115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.161217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26116', '1079', '1', 'Bagamoyo District', 'TZ.00.161288', 'ASCII:Bagamoyo District;ID:161288', '24239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24239', '112', '26116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.161288» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26117', '1079', '1', 'Aru Meru District', 'TZ.00.161327', 'ASCII:Aru Meru District;ID:161327', '24240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24240', '112', '26117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.161327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26118', '1079', '1', 'Tunduru District', 'TZ.00.877377', 'ASCII:Tunduru District;ID:877377', '24241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24241', '112', '26118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.877377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26119', '1079', '1', 'Songea District', 'TZ.00.877400', 'ASCII:Songea District;ID:877400', '24242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24242', '112', '26119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.877400» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26120', '1079', '1', 'Newala District', 'TZ.00.877533', 'ASCII:Newala District;ID:877533', '24243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24243', '112', '26120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.877533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26121', '1079', '1', 'Nachingwea District', 'TZ.00.877701', 'ASCII:Nachingwea District;ID:877701', '24244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24244', '112', '26121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.877701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26122', '1079', '1', 'Mtwara District', 'TZ.00.877745', 'ASCII:Mtwara District;ID:877745', '24245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24245', '112', '26122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.877745» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26123', '1079', '1', 'Mbinga District', 'TZ.00.877996', 'ASCII:Mbinga District;ID:877996', '24246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24246', '112', '26123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.877996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26124', '1079', '1', 'Masasi District', 'TZ.00.878057', 'ASCII:Masasi District;ID:878057', '24247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24247', '112', '26124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.878057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26125', '1079', '1', 'Ludewa District', 'TZ.00.878221', 'ASCII:Ludewa District;ID:878221', '24248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24248', '112', '26125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.878221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26126', '1079', '1', 'Lindi District', 'TZ.00.878280', 'ASCII:Lindi District;ID:878280', '24249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24249', '112', '26126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «TZ.00.878280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26127', '1079', '1', 'Vladimirskaya Oblast''', 'UA.00.689380', 'ASCII:Vladimirskaya Oblast'';ID:689380', '24250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24250', '112', '26127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.00.689380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26128', '1079', '1', 'Velykomykhaylivs''kyy Rayon', 'UA.17.690076', 'ASCII:Velykomykhaylivs''kyy Rayon;ID:690076', '24251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24251', '112', '26128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.17.690076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26129', '1079', '1', 'Tarutyns''kyy Rayon', 'UA.17.691821', 'ASCII:Tarutyns''kyy Rayon;ID:691821', '24252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24252', '112', '26129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.17.691821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26130', '1079', '1', 'Sarats''kyy Rayon', 'UA.17.694810', 'ASCII:Sarats''kyy Rayon;ID:694810', '24253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24253', '112', '26130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.17.694810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26131', '1079', '1', 'Kotovs''kyy Rayon', 'UA.17.704677', 'ASCII:Kotovs''kyy Rayon;ID:704677', '24254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24254', '112', '26131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.17.704677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26132', '1079', '1', 'Kodyms''kyy Rayon', 'UA.17.705489', 'ASCII:Kodyms''kyy Rayon;ID:705489', '24255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24255', '112', '26132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.17.705489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26133', '1079', '1', 'Horodots''kyy Rayon', 'UA.09.707751', 'ASCII:Horodots''kyy Rayon;ID:707751', '24256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24256', '112', '26133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.09.707751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26134', '1079', '1', 'Chemerovets''kyy Rayon', 'UA.09.710863', 'ASCII:Chemerovets''kyy Rayon;ID:710863', '24257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24257', '112', '26134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.09.710863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26135', '1079', '1', 'Balts''kyy Rayon', 'UA.17.712882', 'ASCII:Balts''kyy Rayon;ID:712882', '24258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24258', '112', '26135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.17.712882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26136', '1079', '1', 'Antratsytivs''kyy Rayon', 'UA.14.713257', 'ASCII:Antratsytivs''kyy Rayon;ID:713257', '24259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24259', '112', '26136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.14.713257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26137', '1079', '1', 'Tursunzadevskiy Rayon', 'UA.00.1282600', 'ASCII:Tursunzadevskiy Rayon;ID:1282600', '24260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24260', '112', '26137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UA.00.1282600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26138', '1079', '1', 'West Acholi District', 'UG.00.225874', 'ASCII:West Acholi District;ID:225874', '24261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24261', '112', '26138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UG.00.225874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26139', '1079', '1', 'Toro District', 'UG.00.226116', 'ASCII:Toro District;ID:226116', '24262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24262', '112', '26139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UG.00.226116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26140', '1079', '1', 'Sebei District', 'UG.00.226376', 'ASCII:Sebei District;ID:226376', '24263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24263', '112', '26140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UG.00.226376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26141', '1079', '1', 'Mubende District', 'UG.00.228969', 'ASCII:Mubende District;ID:228969', '24264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24264', '112', '26141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UG.00.228969» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26142', '1079', '1', 'Madi District', 'UG.00.229550', 'ASCII:Madi District;ID:229550', '24265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24265', '112', '26142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UG.00.229550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26143', '1079', '1', 'East Acholi District', 'UG.00.233536', 'ASCII:East Acholi District;ID:233536', '24266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24266', '112', '26143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UG.00.233536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26144', '1079', '1', 'Bukedi District', 'UG.00.234410', 'ASCII:Bukedi District;ID:234410', '24267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24267', '112', '26144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UG.00.234410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26145', '1079', '1', 'Bugisu District', 'UG.00.234558', 'ASCII:Bugisu District;ID:234558', '24268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24268', '112', '26145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UG.00.234558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26146', '1079', '1', 'Russell County', 'US.AL.113', 'ASCII:Russell County;ID:4047434', '24269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24269', '112', '26146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26147', '1079', '1', 'Long County', 'US.GA.183', 'ASCII:Long County;ID:4048080', '24270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24270', '112', '26147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26148', '1079', '1', 'Boone County', 'US.KY.015', 'ASCII:Boone County;ID:4048522', '24271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24271', '112', '26148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26149', '1079', '1', 'Rowan County', 'US.KY.205', 'ASCII:Rowan County;ID:4048572', '24272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24272', '112', '26149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26150', '1079', '1', 'Bibb County', 'US.AL.007', 'ASCII:Bibb County;ID:4049189', '24273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24273', '112', '26150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26151', '1079', '1', 'Campbell County', 'US.TN.013', 'ASCII:Campbell County;ID:4050506', '24274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24274', '112', '26151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26152', '1079', '1', 'Blount County', 'US.AL.009', 'ASCII:Blount County;ID:4050633', '24275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24275', '112', '26152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26153', '1079', '1', 'Bullock County', 'US.AL.011', 'ASCII:Bullock County;ID:4052497', '24276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24276', '112', '26153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26154', '1079', '1', 'Butler County', 'US.AL.013', 'ASCII:Butler County;ID:4052744', '24277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24277', '112', '26154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26155', '1079', '1', 'Calhoun County', 'US.AL.015', 'ASCII:Calhoun County;ID:4053062', '24278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24278', '112', '26155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26156', '1079', '1', 'Chambers County', 'US.AL.017', 'ASCII:Chambers County;ID:4054621', '24279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24279', '112', '26156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26157', '1079', '1', 'Cherokee County', 'US.AL.019', 'ASCII:Cherokee County;ID:4054880', '24280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24280', '112', '26157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26158', '1079', '1', 'Chilton County', 'US.AL.021', 'ASCII:Chilton County;ID:4055067', '24281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24281', '112', '26158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26159', '1079', '1', 'Choctaw County', 'US.AL.023', 'ASCII:Choctaw County;ID:4055170', '24282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24282', '112', '26159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26160', '1079', '1', 'Clarke County', 'US.AL.025', 'ASCII:Clarke County;ID:4055624', '24283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24283', '112', '26160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26161', '1079', '1', 'Clay County', 'US.AL.027', 'ASCII:Clay County;ID:4055660', '24284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24284', '112', '26161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26162', '1079', '1', 'Cleburne County', 'US.AL.029', 'ASCII:Cleburne County;ID:4055785', '24285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24285', '112', '26162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26163', '1079', '1', 'Coffee County', 'US.AL.031', 'ASCII:Coffee County;ID:4056099', '24286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24286', '112', '26163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26164', '1079', '1', 'Colbert County', 'US.AL.033', 'ASCII:Colbert County;ID:4056165', '24287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24287', '112', '26164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26165', '1079', '1', 'Conecuh County', 'US.AL.035', 'ASCII:Conecuh County;ID:4056592', '24288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24288', '112', '26165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26166', '1079', '1', 'Coosa County', 'US.AL.037', 'ASCII:Coosa County;ID:4056809', '24289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24289', '112', '26166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26167', '1079', '1', 'Covington County', 'US.AL.039', 'ASCII:Covington County;ID:4057296', '24290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24290', '112', '26167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26168', '1079', '1', 'Crenshaw County', 'US.AL.041', 'ASCII:Crenshaw County;ID:4057517', '24291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24291', '112', '26168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26169', '1079', '1', 'Cullman County', 'US.AL.043', 'ASCII:Cullman County;ID:4057837', '24292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24292', '112', '26169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26170', '1079', '1', 'Dale County', 'US.AL.045', 'ASCII:Dale County;ID:4058052', '24293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24293', '112', '26170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26171', '1079', '1', 'Dallas County', 'US.AL.047', 'ASCII:Dallas County;ID:4058076', '24294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24294', '112', '26171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26172', '1079', '1', 'DeKalb County', 'US.AL.049', 'ASCII:DeKalb County;ID:4058479', '24295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24295', '112', '26172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26173', '1079', '1', 'Elmore County', 'US.AL.051', 'ASCII:Elmore County;ID:4060563', '24296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24296', '112', '26173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26174', '1079', '1', 'Escambia County', 'US.AL.053', 'ASCII:Escambia County;ID:4060870', '24297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24297', '112', '26174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26175', '1079', '1', 'Etowah County', 'US.AL.055', 'ASCII:Etowah County;ID:4060938', '24298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24298', '112', '26175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26176', '1079', '1', 'Fayette County', 'US.AL.057', 'ASCII:Fayette County;ID:4061590', '24299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24299', '112', '26176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26177', '1079', '1', 'Franklin County', 'US.AL.059', 'ASCII:Franklin County;ID:4063130', '24300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24300', '112', '26177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26178', '1079', '1', 'Geneva County', 'US.AL.061', 'ASCII:Geneva County;ID:4063931', '24301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24301', '112', '26178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26179', '1079', '1', 'Greene County', 'US.AL.063', 'ASCII:Greene County;ID:4065243', '24302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24302', '112', '26179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26180', '1079', '1', 'Hale County', 'US.AL.065', 'ASCII:Hale County;ID:4065796', '24303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24303', '112', '26180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26181', '1079', '1', 'Henry County', 'US.AL.067', 'ASCII:Henry County;ID:4066911', '24304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24304', '112', '26181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26182', '1079', '1', 'Houston County', 'US.AL.069', 'ASCII:Houston County;ID:4068296', '24305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24305', '112', '26182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26183', '1079', '1', 'Jackson County', 'US.AL.071', 'ASCII:Jackson County;ID:4069472', '24306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24306', '112', '26183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26184', '1079', '1', 'Jefferson County', 'US.AL.073', 'ASCII:Jefferson County;ID:4069696', '24307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24307', '112', '26184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26185', '1079', '1', 'Lamar County', 'US.AL.075', 'ASCII:Lamar County;ID:4071676', '24308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24308', '112', '26185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26186', '1079', '1', 'Lauderdale County', 'US.AL.077', 'ASCII:Lauderdale County;ID:4071898', '24309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24309', '112', '26186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26187', '1079', '1', 'Lawrence County', 'US.AL.079', 'ASCII:Lawrence County;ID:4071959', '24310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24310', '112', '26187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26188', '1079', '1', 'Lee County', 'US.AL.081', 'ASCII:Lee County;ID:4072098', '24311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24311', '112', '26188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26189', '1079', '1', 'Limestone County', 'US.AL.083', 'ASCII:Limestone County;ID:4072707', '24312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24312', '112', '26189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26190', '1079', '1', 'Lowndes County', 'US.AL.085', 'ASCII:Lowndes County;ID:4073885', '24313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24313', '112', '26190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26191', '1079', '1', 'Macon County', 'US.AL.087', 'ASCII:Macon County;ID:4074246', '24314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24314', '112', '26191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26192', '1079', '1', 'Madison County', 'US.AL.089', 'ASCII:Madison County;ID:4074277', '24315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24315', '112', '26192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26193', '1079', '1', 'Marengo County', 'US.AL.091', 'ASCII:Marengo County;ID:4074590', '24316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24316', '112', '26193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26194', '1079', '1', 'Marion County', 'US.AL.093', 'ASCII:Marion County;ID:4074636', '24317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24317', '112', '26194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26195', '1079', '1', 'Marshall County', 'US.AL.095', 'ASCII:Marshall County;ID:4074736', '24318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24318', '112', '26195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26196', '1079', '1', 'Mobile County', 'US.AL.097', 'ASCII:Mobile County;ID:4076607', '24319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24319', '112', '26196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26197', '1079', '1', 'Monroe County', 'US.AL.099', 'ASCII:Monroe County;ID:4076706', '24320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24320', '112', '26197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26198', '1079', '1', 'Montgomery County', 'US.AL.101', 'ASCII:Montgomery County;ID:4076795', '24321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24321', '112', '26198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26199', '1079', '1', 'Morgan County', 'US.AL.103', 'ASCII:Morgan County;ID:4077029', '24322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24322', '112', '26199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26200', '1079', '1', 'Perry County', 'US.AL.105', 'ASCII:Perry County;ID:4082741', '24323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24323', '112', '26200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26201', '1079', '1', 'Pickens County', 'US.AL.107', 'ASCII:Pickens County;ID:4082974', '24324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24324', '112', '26201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26202', '1079', '1', 'Pike County', 'US.AL.109', 'ASCII:Pike County;ID:4083063', '24325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24325', '112', '26202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26203', '1079', '1', 'Randolph County', 'US.AL.111', 'ASCII:Randolph County;ID:4085418', '24326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24326', '112', '26203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26204', '1079', '1', 'Saint Clair County', 'US.AL.115', 'ASCII:Saint Clair County;ID:4087481', '24327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24327', '112', '26204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26205', '1079', '1', 'Shelby County', 'US.AL.117', 'ASCII:Shelby County;ID:4089551', '24328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24328', '112', '26205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26206', '1079', '1', 'Sumter County', 'US.AL.119', 'ASCII:Sumter County;ID:4092386', '24329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24329', '112', '26206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26207', '1079', '1', 'Talladega County', 'US.AL.121', 'ASCII:Talladega County;ID:4092795', '24330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24330', '112', '26207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26208', '1079', '1', 'Tallapoosa County', 'US.AL.123', 'ASCII:Tallapoosa County;ID:4092827', '24331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24331', '112', '26208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26209', '1079', '1', 'Tuscaloosa County', 'US.AL.125', 'ASCII:Tuscaloosa County;ID:4094463', '24332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24332', '112', '26209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26210', '1079', '1', 'Walker County', 'US.AL.127', 'ASCII:Walker County;ID:4096107', '24333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24333', '112', '26210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26211', '1079', '1', 'Washington County', 'US.AL.129', 'ASCII:Washington County;ID:4096449', '24334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24334', '112', '26211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26212', '1079', '1', 'Wilcox County', 'US.AL.131', 'ASCII:Wilcox County;ID:4097694', '24335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24335', '112', '26212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26213', '1079', '1', 'Winston County', 'US.AL.133', 'ASCII:Winston County;ID:4098200', '24336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24336', '112', '26213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26214', '1079', '1', 'Arkansas County', 'US.AR.001', 'ASCII:Arkansas County;ID:4099679', '24337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24337', '112', '26214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26215', '1079', '1', 'Ashley County', 'US.AR.003', 'ASCII:Ashley County;ID:4099869', '24338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24338', '112', '26215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26216', '1079', '1', 'Baxter County', 'US.AR.005', 'ASCII:Baxter County;ID:4100581', '24339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24339', '112', '26216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26217', '1079', '1', 'Benton County', 'US.AR.007', 'ASCII:Benton County;ID:4101244', '24340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24340', '112', '26217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26218', '1079', '1', 'Boone County', 'US.AR.009', 'ASCII:Boone County;ID:4102608', '24341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24341', '112', '26218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26219', '1079', '1', 'Bradley County', 'US.AR.011', 'ASCII:Bradley County;ID:4102799', '24342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24342', '112', '26219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26220', '1079', '1', 'Calhoun County', 'US.AR.013', 'ASCII:Calhoun County;ID:4104063', '24343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24343', '112', '26220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26221', '1079', '1', 'Carroll County', 'US.AR.015', 'ASCII:Carroll County;ID:4104658', '24344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24344', '112', '26221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26222', '1079', '1', 'Chicot County', 'US.AR.017', 'ASCII:Chicot County;ID:4105506', '24345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24345', '112', '26222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26223', '1079', '1', 'Clark County', 'US.AR.019', 'ASCII:Clark County;ID:4105838', '24346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24346', '112', '26223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26224', '1079', '1', 'Clay County', 'US.AR.021', 'ASCII:Clay County;ID:4105899', '24347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24347', '112', '26224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26225', '1079', '1', 'Cleburne County', 'US.AR.023', 'ASCII:Cleburne County;ID:4106009', '24348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24348', '112', '26225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26226', '1079', '1', 'Cleveland County', 'US.AR.025', 'ASCII:Cleveland County;ID:4106032', '24349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24349', '112', '26226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26227', '1079', '1', 'Columbia County', 'US.AR.027', 'ASCII:Columbia County;ID:4106339', '24350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24350', '112', '26227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26228', '1079', '1', 'Conway County', 'US.AR.029', 'ASCII:Conway County;ID:4106460', '24351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24351', '112', '26228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26229', '1079', '1', 'Craighead County', 'US.AR.031', 'ASCII:Craighead County;ID:4106979', '24352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24352', '112', '26229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26230', '1079', '1', 'Crawford County', 'US.AR.033', 'ASCII:Crawford County;ID:4107027', '24353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24353', '112', '26230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26231', '1079', '1', 'Crittenden County', 'US.AR.035', 'ASCII:Crittenden County;ID:4107079', '24354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24354', '112', '26231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26232', '1079', '1', 'Cross County', 'US.AR.037', 'ASCII:Cross County;ID:4107139', '24355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24355', '112', '26232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26233', '1079', '1', 'Dallas County', 'US.AR.039', 'ASCII:Dallas County;ID:4107572', '24356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24356', '112', '26233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26234', '1079', '1', 'Desha County', 'US.AR.041', 'ASCII:Desha County;ID:4108100', '24357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24357', '112', '26234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26235', '1079', '1', 'Drew County', 'US.AR.043', 'ASCII:Drew County;ID:4108996', '24358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24358', '112', '26235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26236', '1079', '1', 'Faulkner County', 'US.AR.045', 'ASCII:Faulkner County;ID:4110465', '24359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24359', '112', '26236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26237', '1079', '1', 'Franklin County', 'US.AR.047', 'ASCII:Franklin County;ID:4111593', '24360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24360', '112', '26237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26238', '1079', '1', 'Fulton County', 'US.AR.049', 'ASCII:Fulton County;ID:4111857', '24361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24361', '112', '26238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26239', '1079', '1', 'Garland County', 'US.AR.051', 'ASCII:Garland County;ID:4112045', '24362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24362', '112', '26239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26240', '1079', '1', 'Grant County', 'US.AR.053', 'ASCII:Grant County;ID:4112780', '24363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24363', '112', '26240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26241', '1079', '1', 'Greene County', 'US.AR.055', 'ASCII:Greene County;ID:4113088', '24364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24364', '112', '26241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26242', '1079', '1', 'Hempstead County', 'US.AR.057', 'ASCII:Hempstead County;ID:4114303', '24365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24365', '112', '26242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26243', '1079', '1', 'Hot Spring County', 'US.AR.059', 'ASCII:Hot Spring County;ID:4115406', '24366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24366', '112', '26243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26244', '1079', '1', 'Howard County', 'US.AR.061', 'ASCII:Howard County;ID:4115463', '24367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24367', '112', '26244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26245', '1079', '1', 'Independence County', 'US.AR.063', 'ASCII:Independence County;ID:4115832', '24368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24368', '112', '26245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26246', '1079', '1', 'Izard County', 'US.AR.065', 'ASCII:Izard County;ID:4116178', '24369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24369', '112', '26246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26247', '1079', '1', 'Jackson County', 'US.AR.067', 'ASCII:Jackson County;ID:4116263', '24370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24370', '112', '26247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26248', '1079', '1', 'Jefferson County', 'US.AR.069', 'ASCII:Jefferson County;ID:4116433', '24371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24371', '112', '26248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26249', '1079', '1', 'Johnson County', 'US.AR.071', 'ASCII:Johnson County;ID:4116689', '24372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24372', '112', '26249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26250', '1079', '1', 'Lafayette County', 'US.AR.073', 'ASCII:Lafayette County;ID:4117774', '24373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24373', '112', '26250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26251', '1079', '1', 'Lawrence County', 'US.AR.075', 'ASCII:Lawrence County;ID:4118467', '24374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24374', '112', '26251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26252', '1079', '1', 'Lee County', 'US.AR.077', 'ASCII:Lee County;ID:4118578', '24375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24375', '112', '26252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26253', '1079', '1', 'Lincoln County', 'US.AR.079', 'ASCII:Lincoln County;ID:4118984', '24376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24376', '112', '26253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26254', '1079', '1', 'Little River County', 'US.AR.081', 'ASCII:Little River County;ID:4119374', '24377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24377', '112', '26254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26255', '1079', '1', 'Logan County', 'US.AR.083', 'ASCII:Logan County;ID:4119581', '24378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24378', '112', '26255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26256', '1079', '1', 'Lonoke County', 'US.AR.085', 'ASCII:Lonoke County;ID:4119825', '24379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24379', '112', '26256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26257', '1079', '1', 'Madison County', 'US.AR.087', 'ASCII:Madison County;ID:4120275', '24380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24380', '112', '26257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26258', '1079', '1', 'Marion County', 'US.AR.089', 'ASCII:Marion County;ID:4120525', '24381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24381', '112', '26258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26259', '1079', '1', 'Miller County', 'US.AR.091', 'ASCII:Miller County;ID:4121680', '24382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24382', '112', '26259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26260', '1079', '1', 'Mississippi County', 'US.AR.093', 'ASCII:Mississippi County;ID:4121839', '24383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24383', '112', '26260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26261', '1079', '1', 'Monroe County', 'US.AR.095', 'ASCII:Monroe County;ID:4121968', '24384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24384', '112', '26261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26262', '1079', '1', 'Montgomery County', 'US.AR.097', 'ASCII:Montgomery County;ID:4121992', '24385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24385', '112', '26262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26263', '1079', '1', 'Nevada County', 'US.AR.099', 'ASCII:Nevada County;ID:4123415', '24386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24386', '112', '26263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26264', '1079', '1', 'Newton County', 'US.AR.101', 'ASCII:Newton County;ID:4123857', '24387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24387', '112', '26264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26265', '1079', '1', 'Ouachita County', 'US.AR.103', 'ASCII:Ouachita County;ID:4125059', '24388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24388', '112', '26265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26266', '1079', '1', 'Perry County', 'US.AR.105', 'ASCII:Perry County;ID:4125858', '24389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24389', '112', '26266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26267', '1079', '1', 'Phillips County', 'US.AR.107', 'ASCII:Phillips County;ID:4126012', '24390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24390', '112', '26267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26268', '1079', '1', 'Pike County', 'US.AR.109', 'ASCII:Pike County;ID:4126123', '24391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24391', '112', '26268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26269', '1079', '1', 'Poinsett County', 'US.AR.111', 'ASCII:Poinsett County;ID:4126942', '24392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24392', '112', '26269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26270', '1079', '1', 'Polk County', 'US.AR.113', 'ASCII:Polk County;ID:4127017', '24393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24393', '112', '26270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26271', '1079', '1', 'Pope County', 'US.AR.115', 'ASCII:Pope County;ID:4127100', '24394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24394', '112', '26271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26272', '1079', '1', 'Prairie County', 'US.AR.117', 'ASCII:Prairie County;ID:4127330', '24395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24395', '112', '26272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26273', '1079', '1', 'Pulaski County', 'US.AR.119', 'ASCII:Pulaski County;ID:4127619', '24396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24396', '112', '26273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26274', '1079', '1', 'Randolph County', 'US.AR.121', 'ASCII:Randolph County;ID:4127846', '24397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24397', '112', '26274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26275', '1079', '1', 'Saint Francis County', 'US.AR.123', 'ASCII:Saint Francis County;ID:4129533', '24398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24398', '112', '26275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26276', '1079', '1', 'Saline County', 'US.AR.125', 'ASCII:Saline County;ID:4130035', '24399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24399', '112', '26276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26277', '1079', '1', 'Scott County', 'US.AR.127', 'ASCII:Scott County;ID:4130373', '24400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24400', '112', '26277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26278', '1079', '1', 'Searcy County', 'US.AR.129', 'ASCII:Searcy County;ID:4130432', '24401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24401', '112', '26278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26279', '1079', '1', 'Sebastian County', 'US.AR.131', 'ASCII:Sebastian County;ID:4130449', '24402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24402', '112', '26279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26280', '1079', '1', 'Sevier County', 'US.AR.133', 'ASCII:Sevier County;ID:4130562', '24403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24403', '112', '26280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26281', '1079', '1', 'Sharp County', 'US.AR.135', 'ASCII:Sharp County;ID:4130730', '24404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24404', '112', '26281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26282', '1079', '1', 'Stone County', 'US.AR.137', 'ASCII:Stone County;ID:4132456', '24405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24405', '112', '26282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26283', '1079', '1', 'Union County', 'US.AR.139', 'ASCII:Union County;ID:4134330', '24406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24406', '112', '26283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26284', '1079', '1', 'Van Buren County', 'US.AR.141', 'ASCII:Van Buren County;ID:4134690', '24407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24407', '112', '26284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26285', '1079', '1', 'Washington County', 'US.AR.143', 'ASCII:Washington County;ID:4135394', '24408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24408', '112', '26285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26286', '1079', '1', 'White County', 'US.AR.145', 'ASCII:White County;ID:4136143', '24409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24409', '112', '26286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26287', '1079', '1', 'Woodruff County', 'US.AR.147', 'ASCII:Woodruff County;ID:4137047', '24410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24410', '112', '26287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26288', '1079', '1', 'Yell County', 'US.AR.149', 'ASCII:Yell County;ID:4137268', '24411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24411', '112', '26288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AR.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26289', '1079', '1', 'Kent County', 'US.DE.001', 'ASCII:Kent County;ID:4143221', '24412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24412', '112', '26289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.DE.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26290', '1079', '1', 'New Castle County', 'US.DE.003', 'ASCII:New Castle County;ID:4143835', '24413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24413', '112', '26290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.DE.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26291', '1079', '1', 'Sussex County', 'US.DE.005', 'ASCII:Sussex County;ID:4144895', '24414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24414', '112', '26291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.DE.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26292', '1079', '1', 'Alachua County', 'US.FL.001', 'ASCII:Alachua County;ID:4145709', '24415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24415', '112', '26292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26293', '1079', '1', 'Baker County', 'US.FL.003', 'ASCII:Baker County;ID:4146548', '24416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24416', '112', '26293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26294', '1079', '1', 'Bay County', 'US.FL.005', 'ASCII:Bay County;ID:4146810', '24417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24417', '112', '26294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26295', '1079', '1', 'Bradford County', 'US.FL.007', 'ASCII:Bradford County;ID:4148735', '24418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24418', '112', '26295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26296', '1079', '1', 'Brevard County', 'US.FL.009', 'ASCII:Brevard County;ID:4148826', '24419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24419', '112', '26296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26297', '1079', '1', 'Broward County', 'US.FL.011', 'ASCII:Broward County;ID:4149007', '24420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24420', '112', '26297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26298', '1079', '1', 'Calhoun County', 'US.FL.013', 'ASCII:Calhoun County;ID:4149608', '24421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24421', '112', '26298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26299', '1079', '1', 'Charlotte County', 'US.FL.015', 'ASCII:Charlotte County;ID:4150627', '24422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24422', '112', '26299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26300', '1079', '1', 'Citrus County', 'US.FL.017', 'ASCII:Citrus County;ID:4151140', '24423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24423', '112', '26300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26301', '1079', '1', 'Clay County', 'US.FL.019', 'ASCII:Clay County;ID:4151245', '24424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24424', '112', '26301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26302', '1079', '1', 'Collier County', 'US.FL.021', 'ASCII:Collier County;ID:4151550', '24425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24425', '112', '26302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26303', '1079', '1', 'Columbia County', 'US.FL.023', 'ASCII:Columbia County;ID:4151595', '24426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24426', '112', '26303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26304', '1079', '1', 'DeSoto County', 'US.FL.027', 'ASCII:DeSoto County;ID:4152927', '24427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24427', '112', '26304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26305', '1079', '1', 'Dixie County', 'US.FL.029', 'ASCII:Dixie County;ID:4153352', '24428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24428', '112', '26305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26306', '1079', '1', 'Duval County', 'US.FL.031', 'ASCII:Duval County;ID:4153840', '24429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24429', '112', '26306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26307', '1079', '1', 'Escambia County', 'US.FL.033', 'ASCII:Escambia County;ID:4154550', '24430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24430', '112', '26307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26308', '1079', '1', 'Flagler County', 'US.FL.035', 'ASCII:Flagler County;ID:4155535', '24431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24431', '112', '26308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26309', '1079', '1', 'Franklin County', 'US.FL.037', 'ASCII:Franklin County;ID:4156210', '24432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24432', '112', '26309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26310', '1079', '1', 'Gadsden County', 'US.FL.039', 'ASCII:Gadsden County;ID:4156394', '24433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24433', '112', '26310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26311', '1079', '1', 'Gilchrist County', 'US.FL.041', 'ASCII:Gilchrist County;ID:4156770', '24434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24434', '112', '26311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26312', '1079', '1', 'Glades County', 'US.FL.043', 'ASCII:Glades County;ID:4156815', '24435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24435', '112', '26312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26313', '1079', '1', 'Gulf County', 'US.FL.045', 'ASCII:Gulf County;ID:4157652', '24436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24436', '112', '26313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26314', '1079', '1', 'Hamilton County', 'US.FL.047', 'ASCII:Hamilton County;ID:4157924', '24437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24437', '112', '26314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26315', '1079', '1', 'Hardee County', 'US.FL.049', 'ASCII:Hardee County;ID:4158068', '24438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24438', '112', '26315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26316', '1079', '1', 'Hendry County', 'US.FL.051', 'ASCII:Hendry County;ID:4158392', '24439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24439', '112', '26316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26317', '1079', '1', 'Hernando County', 'US.FL.053', 'ASCII:Hernando County;ID:4158449', '24440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24440', '112', '26317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26318', '1079', '1', 'Highlands County', 'US.FL.055', 'ASCII:Highlands County;ID:4158643', '24441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24441', '112', '26318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26319', '1079', '1', 'Hillsborough County', 'US.FL.057', 'ASCII:Hillsborough County;ID:4158712', '24442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24442', '112', '26319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26320', '1079', '1', 'Holmes County', 'US.FL.059', 'ASCII:Holmes County;ID:4158961', '24443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24443', '112', '26320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26321', '1079', '1', 'Indian River County', 'US.FL.061', 'ASCII:Indian River County;ID:4159657', '24444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24444', '112', '26321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26322', '1079', '1', 'Jackson County', 'US.FL.063', 'ASCII:Jackson County;ID:4159990', '24445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24445', '112', '26322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26323', '1079', '1', 'Jefferson County', 'US.FL.065', 'ASCII:Jefferson County;ID:4160118', '24446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24446', '112', '26323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26324', '1079', '1', 'Lafayette County', 'US.FL.067', 'ASCII:Lafayette County;ID:4161127', '24447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24447', '112', '26324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26325', '1079', '1', 'Lake County', 'US.FL.069', 'ASCII:Lake County;ID:4161204', '24448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24448', '112', '26325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26326', '1079', '1', 'Lee County', 'US.FL.071', 'ASCII:Lee County;ID:4161743', '24449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24449', '112', '26326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26327', '1079', '1', 'Leon County', 'US.FL.073', 'ASCII:Leon County;ID:4161831', '24450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24450', '112', '26327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26328', '1079', '1', 'Levy County', 'US.FL.075', 'ASCII:Levy County;ID:4161891', '24451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24451', '112', '26328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26329', '1079', '1', 'Liberty County', 'US.FL.077', 'ASCII:Liberty County;ID:4161925', '24452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24452', '112', '26329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26330', '1079', '1', 'Madison County', 'US.FL.079', 'ASCII:Madison County;ID:4163142', '24453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24453', '112', '26330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26331', '1079', '1', 'Manatee County', 'US.FL.081', 'ASCII:Manatee County;ID:4163277', '24454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24454', '112', '26331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26332', '1079', '1', 'Marion County', 'US.FL.083', 'ASCII:Marion County;ID:4163456', '24455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24455', '112', '26332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26333', '1079', '1', 'Martin County', 'US.FL.085', 'ASCII:Martin County;ID:4163566', '24456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24456', '112', '26333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26334', '1079', '1', 'Miami-Dade County', 'US.FL.086', 'ASCII:Miami-Dade;ID:4164238', '24457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24457', '112', '26334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26335', '1079', '1', 'Monroe County', 'US.FL.087', 'ASCII:Monroe County;ID:4164762', '24458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24458', '112', '26335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26336', '1079', '1', 'Nassau County', 'US.FL.089', 'ASCII:Nassau County;ID:4165603', '24459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24459', '112', '26336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26337', '1079', '1', 'Okaloosa County', 'US.FL.091', 'ASCII:Okaloosa County;ID:4166818', '24460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24460', '112', '26337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26338', '1079', '1', 'Okeechobee County', 'US.FL.093', 'ASCII:Okeechobee County;ID:4166825', '24461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24461', '112', '26338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26339', '1079', '1', 'Orange County', 'US.FL.095', 'ASCII:Orange County;ID:4167060', '24462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24462', '112', '26339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26340', '1079', '1', 'Osceola County', 'US.FL.097', 'ASCII:Osceola County;ID:4167218', '24463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24463', '112', '26340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26341', '1079', '1', 'Palm Beach County', 'US.FL.099', 'ASCII:Palm Beach;ID:4167510', '24464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24464', '112', '26341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26342', '1079', '1', 'Pasco County', 'US.FL.101', 'ASCII:Pasco County;ID:4167895', '24465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24465', '112', '26342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26343', '1079', '1', 'Pinellas County', 'US.FL.103', 'ASCII:Pinellas County;ID:4168618', '24466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24466', '112', '26343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26344', '1079', '1', 'Polk County', 'US.FL.105', 'ASCII:Polk County;ID:4168988', '24467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24467', '112', '26344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26345', '1079', '1', 'Putnam County', 'US.FL.107', 'ASCII:Putnam County;ID:4169471', '24468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24468', '112', '26345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26346', '1079', '1', 'Saint Johns County', 'US.FL.109', 'ASCII:Saint Johns County;ID:4171153', '24469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24469', '112', '26346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26347', '1079', '1', 'Saint Lucie County', 'US.FL.111', 'ASCII:Saint Lucie County;ID:4171260', '24470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24470', '112', '26347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26348', '1079', '1', 'Santa Rosa County', 'US.FL.113', 'ASCII:Santa Rosa County;ID:4172096', '24471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24471', '112', '26348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26349', '1079', '1', 'Sarasota County', 'US.FL.115', 'ASCII:Sarasota County;ID:4172139', '24472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24472', '112', '26349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26350', '1079', '1', 'Seminole County', 'US.FL.117', 'ASCII:Seminole County;ID:4172445', '24473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24473', '112', '26350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26351', '1079', '1', 'Sumter County', 'US.FL.119', 'ASCII:Sumter County;ID:4174301', '24474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24474', '112', '26351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26352', '1079', '1', 'Suwannee County', 'US.FL.121', 'ASCII:Suwannee County;ID:4174543', '24475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24475', '112', '26352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26353', '1079', '1', 'Taylor County', 'US.FL.123', 'ASCII:Taylor County;ID:4174886', '24476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24476', '112', '26353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26354', '1079', '1', 'Union County', 'US.FL.125', 'ASCII:Union County;ID:4176099', '24477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24477', '112', '26354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26355', '1079', '1', 'Volusia County', 'US.FL.127', 'ASCII:Volusia County;ID:4176559', '24478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24478', '112', '26355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26356', '1079', '1', 'Wakulla County', 'US.FL.129', 'ASCII:Wakulla County;ID:4177321', '24479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24479', '112', '26356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26357', '1079', '1', 'Walton County', 'US.FL.131', 'ASCII:Walton County;ID:4177409', '24480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24480', '112', '26357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26358', '1079', '1', 'Washington County', 'US.FL.133', 'ASCII:Washington County;ID:4177485', '24481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24481', '112', '26358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.FL.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26359', '1079', '1', 'Appling County', 'US.GA.001', 'ASCII:Appling County;ID:4180088', '24482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24482', '112', '26359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26360', '1079', '1', 'Atkinson County', 'US.GA.003', 'ASCII:Atkinson County;ID:4180432', '24483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24483', '112', '26360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26361', '1079', '1', 'Bacon County', 'US.GA.005', 'ASCII:Bacon County;ID:4180711', '24484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24484', '112', '26361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26362', '1079', '1', 'Baker County', 'US.GA.007', 'ASCII:Baker County;ID:4180816', '24485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24485', '112', '26362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26363', '1079', '1', 'Baldwin County', 'US.GA.009', 'ASCII:Baldwin County;ID:4180872', '24486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24486', '112', '26363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26364', '1079', '1', 'Banks County', 'US.GA.011', 'ASCII:Banks County;ID:4180965', '24487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24487', '112', '26364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26365', '1079', '1', 'Barrow County', 'US.GA.013', 'ASCII:Barrow County;ID:4181182', '24488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24488', '112', '26365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26366', '1079', '1', 'Bartow County', 'US.GA.015', 'ASCII:Bartow County;ID:4181218', '24489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24489', '112', '26366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26367', '1079', '1', 'Ben Hill County', 'US.GA.017', 'ASCII:Ben Hill County;ID:4181955', '24490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24490', '112', '26367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26368', '1079', '1', 'Berrien County', 'US.GA.019', 'ASCII:Berrien County;ID:4182126', '24491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24491', '112', '26368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26369', '1079', '1', 'Bibb County', 'US.GA.021', 'ASCII:Bibb County;ID:4182755', '24492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24492', '112', '26369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26370', '1079', '1', 'Bleckley County', 'US.GA.023', 'ASCII:Bleckley County;ID:4183415', '24493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24493', '112', '26370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26371', '1079', '1', 'Brantley County', 'US.GA.025', 'ASCII:Brantley County;ID:4184153', '24494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24494', '112', '26371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26372', '1079', '1', 'Brooks County', 'US.GA.027', 'ASCII:Brooks County;ID:4184557', '24495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24495', '112', '26372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26373', '1079', '1', 'Bryan County', 'US.GA.029', 'ASCII:Bryan County;ID:4184899', '24496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24496', '112', '26373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26374', '1079', '1', 'Bulloch County', 'US.GA.031', 'ASCII:Bulloch County;ID:4185202', '24497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24497', '112', '26374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26375', '1079', '1', 'Burke County', 'US.GA.033', 'ASCII:Burke County;ID:4185265', '24498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24498', '112', '26375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26376', '1079', '1', 'Butts County', 'US.GA.035', 'ASCII:Butts County;ID:4185484', '24499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24499', '112', '26376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26377', '1079', '1', 'Calhoun County', 'US.GA.037', 'ASCII:Calhoun County;ID:4185662', '24500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24500', '112', '26377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26378', '1079', '1', 'Camden County', 'US.GA.039', 'ASCII:Camden County;ID:4185838', '24501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24501', '112', '26378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26379', '1079', '1', 'Candler County', 'US.GA.043', 'ASCII:Candler County;ID:4186104', '24502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24502', '112', '26379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26380', '1079', '1', 'Carroll County', 'US.GA.045', 'ASCII:Carroll County;ID:4186396', '24503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24503', '112', '26380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26381', '1079', '1', 'Catoosa County', 'US.GA.047', 'ASCII:Catoosa County;ID:4186713', '24504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24504', '112', '26381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26382', '1079', '1', 'Charlton County', 'US.GA.049', 'ASCII:Charlton County;ID:4187348', '24505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24505', '112', '26382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26383', '1079', '1', 'Chatham County', 'US.GA.051', 'ASCII:Chatham County;ID:4187390', '24506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24506', '112', '26383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26384', '1079', '1', 'Chattahoochee County', 'US.GA.053', 'ASCII:Chattahoochee County;ID:4187416', '24507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24507', '112', '26384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26385', '1079', '1', 'Chattooga County', 'US.GA.055', 'ASCII:Chattooga County;ID:4187459', '24508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24508', '112', '26385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26386', '1079', '1', 'Cherokee County', 'US.GA.057', 'ASCII:Cherokee County;ID:4187535', '24509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24509', '112', '26386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26387', '1079', '1', 'Clarke County', 'US.GA.059', 'ASCII:Clarke County;ID:4188191', '24510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24510', '112', '26387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26388', '1079', '1', 'Clay County', 'US.GA.061', 'ASCII:Clay County;ID:4188258', '24511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24511', '112', '26388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26389', '1079', '1', 'Clayton County', 'US.GA.063', 'ASCII:Clayton County;ID:4188291', '24512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24512', '112', '26389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26390', '1079', '1', 'Clinch County', 'US.GA.065', 'ASCII:Clinch County;ID:4188433', '24513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24513', '112', '26390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26391', '1079', '1', 'Cobb County', 'US.GA.067', 'ASCII:Cobb County;ID:4188547', '24514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24514', '112', '26391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26392', '1079', '1', 'Coffee County', 'US.GA.069', 'ASCII:Coffee County;ID:4188653', '24515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24515', '112', '26392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26393', '1079', '1', 'Colquitt County', 'US.GA.071', 'ASCII:Colquitt County;ID:4188937', '24516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24516', '112', '26393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26394', '1079', '1', 'Columbia County', 'US.GA.073', 'ASCII:Columbia County;ID:4188957', '24517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24517', '112', '26394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26395', '1079', '1', 'Cook County', 'US.GA.075', 'ASCII:Cook County;ID:4189236', '24518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24518', '112', '26395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26396', '1079', '1', 'Coweta County', 'US.GA.077', 'ASCII:Coweta County;ID:4189828', '24519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24519', '112', '26396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26397', '1079', '1', 'Crawford County', 'US.GA.079', 'ASCII:Crawford County;ID:4189924', '24520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24520', '112', '26397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26398', '1079', '1', 'Crisp County', 'US.GA.081', 'ASCII:Crisp County;ID:4190062', '24521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24521', '112', '26398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26399', '1079', '1', 'Dade County', 'US.GA.083', 'ASCII:Dade County;ID:4190530', '24522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24522', '112', '26399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26400', '1079', '1', 'Dawson County', 'US.GA.085', 'ASCII:Dawson County;ID:4190959', '24523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24523', '112', '26400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26401', '1079', '1', 'DeKalb County', 'US.GA.089', 'ASCII:DeKalb County;ID:4191014', '24524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24524', '112', '26401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26402', '1079', '1', 'Decatur County', 'US.GA.087', 'ASCII:Decatur County;ID:4191127', '24525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24525', '112', '26402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26403', '1079', '1', 'Dodge County', 'US.GA.091', 'ASCII:Dodge County;ID:4191654', '24526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24526', '112', '26403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26404', '1079', '1', 'Dooly County', 'US.GA.093', 'ASCII:Dooly County;ID:4191760', '24527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24527', '112', '26404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26405', '1079', '1', 'Dougherty County', 'US.GA.095', 'ASCII:Dougherty County;ID:4191903', '24528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24528', '112', '26405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26406', '1079', '1', 'Douglas County', 'US.GA.097', 'ASCII:Douglas County;ID:4191928', '24529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24529', '112', '26406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26407', '1079', '1', 'Early County', 'US.GA.099', 'ASCII:Early County;ID:4192532', '24530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24530', '112', '26407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26408', '1079', '1', 'Echols County', 'US.GA.101', 'ASCII:Echols County;ID:4192932', '24531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24531', '112', '26408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26409', '1079', '1', 'Effingham County', 'US.GA.103', 'ASCII:Effingham County;ID:4193042', '24532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24532', '112', '26409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26410', '1079', '1', 'Elbert County', 'US.GA.105', 'ASCII:Elbert County;ID:4193088', '24533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24533', '112', '26410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26411', '1079', '1', 'Emanuel County', 'US.GA.107', 'ASCII:Emanuel County;ID:4193335', '24534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24534', '112', '26411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26412', '1079', '1', 'Evans County', 'US.GA.109', 'ASCII:Evans County;ID:4193705', '24535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24535', '112', '26412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26413', '1079', '1', 'Fannin County', 'US.GA.111', 'ASCII:Fannin County;ID:4194387', '24536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24536', '112', '26413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26414', '1079', '1', 'Fayette County', 'US.GA.113', 'ASCII:Fayette County;ID:4194465', '24537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24537', '112', '26414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26415', '1079', '1', 'Floyd County', 'US.GA.115', 'ASCII:Floyd County;ID:4195536', '24538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24538', '112', '26415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26416', '1079', '1', 'Forsyth County', 'US.GA.117', 'ASCII:Forsyth County;ID:4195777', '24539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24539', '112', '26416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26417', '1079', '1', 'Franklin County', 'US.GA.119', 'ASCII:Franklin County;ID:4196096', '24540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24540', '112', '26417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26418', '1079', '1', 'Fulton County', 'US.GA.121', 'ASCII:Fulton County;ID:4196508', '24541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24541', '112', '26418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26419', '1079', '1', 'Gilmer County', 'US.GA.123', 'ASCII:Gilmer County;ID:4197146', '24542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24542', '112', '26419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26420', '1079', '1', 'Glascock County', 'US.GA.125', 'ASCII:Glascock County;ID:4197240', '24543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24543', '112', '26420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26421', '1079', '1', 'Glynn County', 'US.GA.127', 'ASCII:Glynn County;ID:4197388', '24544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24544', '112', '26421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26422', '1079', '1', 'Gordon County', 'US.GA.129', 'ASCII:Gordon County;ID:4197608', '24545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24545', '112', '26422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26423', '1079', '1', 'Grady County', 'US.GA.131', 'ASCII:Grady County;ID:4197807', '24546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24546', '112', '26423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26424', '1079', '1', 'Greene County', 'US.GA.133', 'ASCII:Greene County;ID:4198160', '24547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24547', '112', '26424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26425', '1079', '1', 'Gwinnett County', 'US.GA.135', 'ASCII:Gwinnett County;ID:4198645', '24548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24548', '112', '26425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26426', '1079', '1', 'Habersham County', 'US.GA.137', 'ASCII:Habersham County;ID:4198688', '24549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24549', '112', '26426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26427', '1079', '1', 'Hall County', 'US.GA.139', 'ASCII:Hall County;ID:4198821', '24550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24550', '112', '26427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26428', '1079', '1', 'Hancock County', 'US.GA.141', 'ASCII:Hancock County;ID:4198997', '24551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24551', '112', '26428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26429', '1079', '1', 'Haralson County', 'US.GA.143', 'ASCII:Haralson County;ID:4199102', '24552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24552', '112', '26429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26430', '1079', '1', 'Harris County', 'US.GA.145', 'ASCII:Harris County;ID:4199416', '24553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24553', '112', '26430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26431', '1079', '1', 'Hart County', 'US.GA.147', 'ASCII:Hart County;ID:4199517', '24554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24554', '112', '26431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26432', '1079', '1', 'Heard County', 'US.GA.149', 'ASCII:Heard County;ID:4199820', '24555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24555', '112', '26432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26433', '1079', '1', 'Henry County', 'US.GA.151', 'ASCII:Henry County;ID:4200051', '24556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24556', '112', '26433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26434', '1079', '1', 'Houston County', 'US.GA.153', 'ASCII:Houston County;ID:4201512', '24557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24557', '112', '26434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26435', '1079', '1', 'Irwin County', 'US.GA.155', 'ASCII:Irwin County;ID:4202266', '24558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24558', '112', '26435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26436', '1079', '1', 'Jackson County', 'US.GA.157', 'ASCII:Jackson County;ID:4202453', '24559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24559', '112', '26436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26437', '1079', '1', 'Jasper County', 'US.GA.159', 'ASCII:Jasper County;ID:4202638', '24560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24560', '112', '26437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26438', '1079', '1', 'Jeff Davis County', 'US.GA.161', 'ASCII:Jeff Davis County;ID:4202662', '24561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24561', '112', '26438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26439', '1079', '1', 'Jefferson County', 'US.GA.163', 'ASCII:Jefferson County;ID:4202678', '24562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24562', '112', '26439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26440', '1079', '1', 'Jenkins County', 'US.GA.165', 'ASCII:Jenkins County;ID:4202750', '24563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24563', '112', '26440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26441', '1079', '1', 'Johnson County', 'US.GA.167', 'ASCII:Johnson County;ID:4202983', '24564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24564', '112', '26441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26442', '1079', '1', 'Jones County', 'US.GA.169', 'ASCII:Jones County;ID:4203171', '24565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24565', '112', '26442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26443', '1079', '1', 'Lamar County', 'US.GA.171', 'ASCII:Lamar County;ID:4204869', '24566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24566', '112', '26443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26444', '1079', '1', 'Lanier County', 'US.GA.173', 'ASCII:Lanier County;ID:4205013', '24567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24567', '112', '26444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26445', '1079', '1', 'Laurens County', 'US.GA.175', 'ASCII:Laurens County;ID:4205152', '24568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24568', '112', '26445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26446', '1079', '1', 'Lee County', 'US.GA.177', 'ASCII:Lee County;ID:4205331', '24569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24569', '112', '26446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26447', '1079', '1', 'Liberty County', 'US.GA.179', 'ASCII:Liberty County;ID:4205615', '24570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24570', '112', '26447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26448', '1079', '1', 'Lincoln County', 'US.GA.181', 'ASCII:Lincoln County;ID:4205780', '24571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24571', '112', '26448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26449', '1079', '1', 'Lowndes County', 'US.GA.185', 'ASCII:Lowndes County;ID:4207045', '24572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24572', '112', '26449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26450', '1079', '1', 'Lumpkin County', 'US.GA.187', 'ASCII:Lumpkin County;ID:4207132', '24573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24573', '112', '26450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26451', '1079', '1', 'Macon County', 'US.GA.193', 'ASCII:Macon County;ID:4207403', '24574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24574', '112', '26451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26452', '1079', '1', 'Madison County', 'US.GA.195', 'ASCII:Madison County;ID:4207451', '24575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24575', '112', '26452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26453', '1079', '1', 'Marion County', 'US.GA.197', 'ASCII:Marion County;ID:4207805', '24576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24576', '112', '26453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26454', '1079', '1', 'McDuffie County', 'US.GA.189', 'ASCII:McDuffie County;ID:4208454', '24577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24577', '112', '26454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26455', '1079', '1', 'McIntosh County', 'US.GA.191', 'ASCII:McIntosh County;ID:4208544', '24578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24578', '112', '26455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26456', '1079', '1', 'Meriwether County', 'US.GA.199', 'ASCII:Meriwether County;ID:4208945', '24579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24579', '112', '26456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26457', '1079', '1', 'Miller County', 'US.GA.201', 'ASCII:Miller County;ID:4209479', '24580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24580', '112', '26457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26458', '1079', '1', 'Mitchell County', 'US.GA.205', 'ASCII:Mitchell County;ID:4209744', '24581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24581', '112', '26458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26459', '1079', '1', 'Monroe County', 'US.GA.207', 'ASCII:Monroe County;ID:4209889', '24582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24582', '112', '26459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26460', '1079', '1', 'Montgomery County', 'US.GA.209', 'ASCII:Montgomery County;ID:4209939', '24583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24583', '112', '26460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26461', '1079', '1', 'Morgan County', 'US.GA.211', 'ASCII:Morgan County;ID:4210114', '24584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24584', '112', '26461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26462', '1079', '1', 'Murray County', 'US.GA.213', 'ASCII:Murray County;ID:4211691', '24585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24585', '112', '26462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26463', '1079', '1', 'Muscogee County', 'US.GA.215', 'ASCII:Muscogee County;ID:4211716', '24586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24586', '112', '26463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26464', '1079', '1', 'Newton County', 'US.GA.217', 'ASCII:Newton County;ID:4212736', '24587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24587', '112', '26464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26465', '1079', '1', 'Oconee County', 'US.GA.219', 'ASCII:Oconee County;ID:4213838', '24588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24588', '112', '26465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26466', '1079', '1', 'Oglethorpe County', 'US.GA.221', 'ASCII:Oglethorpe County;ID:4213930', '24589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24589', '112', '26466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26467', '1079', '1', 'Paulding County', 'US.GA.223', 'ASCII:Paulding County;ID:4214993', '24590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24590', '112', '26467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26468', '1079', '1', 'Peach County', 'US.GA.225', 'ASCII:Peach County;ID:4215089', '24591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24591', '112', '26468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26469', '1079', '1', 'Pickens County', 'US.GA.227', 'ASCII:Pickens County;ID:4215637', '24592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24592', '112', '26469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26470', '1079', '1', 'Pierce County', 'US.GA.229', 'ASCII:Pierce County;ID:4215697', '24593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24593', '112', '26470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26471', '1079', '1', 'Pike County', 'US.GA.231', 'ASCII:Pike County;ID:4215755', '24594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24594', '112', '26471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26472', '1079', '1', 'Polk County', 'US.GA.233', 'ASCII:Polk County;ID:4216880', '24595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24595', '112', '26472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26473', '1079', '1', 'Pulaski County', 'US.GA.235', 'ASCII:Pulaski County;ID:4217563', '24596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24596', '112', '26473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26474', '1079', '1', 'Putnam County', 'US.GA.237', 'ASCII:Putnam County;ID:4217625', '24597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24597', '112', '26474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26475', '1079', '1', 'Quitman County', 'US.GA.239', 'ASCII:Quitman County;ID:4217715', '24598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24598', '112', '26475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26476', '1079', '1', 'Rabun County', 'US.GA.241', 'ASCII:Rabun County;ID:4217747', '24599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24599', '112', '26476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26477', '1079', '1', 'Randolph County', 'US.GA.243', 'ASCII:Randolph County;ID:4217909', '24600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24600', '112', '26477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26478', '1079', '1', 'Richmond County', 'US.GA.245', 'ASCII:Richmond County;ID:4218744', '24601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24601', '112', '26478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26479', '1079', '1', 'Rockdale County', 'US.GA.247', 'ASCII:Rockdale County;ID:4219431', '24602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24602', '112', '26479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26480', '1079', '1', 'Schley County', 'US.GA.249', 'ASCII:Schley County;ID:4221659', '24603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24603', '112', '26480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26481', '1079', '1', 'Screven County', 'US.GA.251', 'ASCII:Screven County;ID:4221757', '24604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24604', '112', '26481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26482', '1079', '1', 'Seminole County', 'US.GA.253', 'ASCII:Seminole County;ID:4221942', '24605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24605', '112', '26482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26483', '1079', '1', 'Spalding County', 'US.GA.255', 'ASCII:Spalding County;ID:4223848', '24606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24606', '112', '26483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26484', '1079', '1', 'Stephens County', 'US.GA.257', 'ASCII:Stephens County;ID:4224510', '24607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24607', '112', '26484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26485', '1079', '1', 'Stewart County', 'US.GA.259', 'ASCII:Stewart County;ID:4224592', '24608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24608', '112', '26485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26486', '1079', '1', 'Sumter County', 'US.GA.261', 'ASCII:Sumter County;ID:4225168', '24609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24609', '112', '26486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26487', '1079', '1', 'Talbot County', 'US.GA.263', 'ASCII:Talbot County;ID:4225609', '24610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24610', '112', '26487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26488', '1079', '1', 'Taliaferro County', 'US.GA.265', 'ASCII:Taliaferro County;ID:4225621', '24611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24611', '112', '26488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26489', '1079', '1', 'Tattnall County', 'US.GA.267', 'ASCII:Tattnall County;ID:4225814', '24612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24612', '112', '26489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26490', '1079', '1', 'Taylor County', 'US.GA.269', 'ASCII:Taylor County;ID:4225854', '24613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24613', '112', '26490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26491', '1079', '1', 'Telfair County', 'US.GA.271', 'ASCII:Telfair County;ID:4225944', '24614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24614', '112', '26491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26492', '1079', '1', 'Terrell County', 'US.GA.273', 'ASCII:Terrell County;ID:4226051', '24615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24615', '112', '26492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26493', '1079', '1', 'Thomas County', 'US.GA.275', 'ASCII:Thomas County;ID:4226286', '24616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24616', '112', '26493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26494', '1079', '1', 'Tift County', 'US.GA.277', 'ASCII:Tift County;ID:4226538', '24617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24617', '112', '26494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26495', '1079', '1', 'Toombs County', 'US.GA.279', 'ASCII:Toombs County;ID:4226802', '24618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24618', '112', '26495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26496', '1079', '1', 'Towns County', 'US.GA.281', 'ASCII:Towns County;ID:4226924', '24619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24619', '112', '26496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26497', '1079', '1', 'Treutlen County', 'US.GA.283', 'ASCII:Treutlen County;ID:4227019', '24620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24620', '112', '26497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26498', '1079', '1', 'Troup County', 'US.GA.285', 'ASCII:Troup County;ID:4227166', '24621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24621', '112', '26498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26499', '1079', '1', 'Turner County', 'US.GA.287', 'ASCII:Turner County;ID:4227392', '24622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24622', '112', '26499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26500', '1079', '1', 'Twiggs County', 'US.GA.289', 'ASCII:Twiggs County;ID:4227499', '24623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24623', '112', '26500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26501', '1079', '1', 'Union County', 'US.GA.291', 'ASCII:Union County;ID:4227781', '24624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24624', '112', '26501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26502', '1079', '1', 'Upson County', 'US.GA.293', 'ASCII:Upson County;ID:4228098', '24625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24625', '112', '26502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26503', '1079', '1', 'Walker County', 'US.GA.295', 'ASCII:Walker County;ID:4229163', '24626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24626', '112', '26503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.295» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26504', '1079', '1', 'Walton County', 'US.GA.297', 'ASCII:Walton County;ID:4229371', '24627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24627', '112', '26504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26505', '1079', '1', 'Ware County', 'US.GA.299', 'ASCII:Ware County;ID:4229446', '24628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24628', '112', '26505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.299» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26506', '1079', '1', 'Warren County', 'US.GA.301', 'ASCII:Warren County;ID:4229498', '24629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24629', '112', '26506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26507', '1079', '1', 'Washington County', 'US.GA.303', 'ASCII:Washington County;ID:4229557', '24630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24630', '112', '26507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26508', '1079', '1', 'Wayne County', 'US.GA.305', 'ASCII:Wayne County;ID:4229782', '24631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24631', '112', '26508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26509', '1079', '1', 'Webster County', 'US.GA.307', 'ASCII:Webster County;ID:4229882', '24632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24632', '112', '26509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26510', '1079', '1', 'Wheeler County', 'US.GA.309', 'ASCII:Wheeler County;ID:4230492', '24633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24633', '112', '26510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26511', '1079', '1', 'White County', 'US.GA.311', 'ASCII:White County;ID:4230595', '24634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24634', '112', '26511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26512', '1079', '1', 'Whitfield County', 'US.GA.313', 'ASCII:Whitfield County;ID:4230822', '24635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24635', '112', '26512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26513', '1079', '1', 'Wilcox County', 'US.GA.315', 'ASCII:Wilcox County;ID:4230919', '24636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24636', '112', '26513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26514', '1079', '1', 'Wilkes County', 'US.GA.317', 'ASCII:Wilkes County;ID:4231029', '24637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24637', '112', '26514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26515', '1079', '1', 'Wilkinson County', 'US.GA.319', 'ASCII:Wilkinson County;ID:4231046', '24638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24638', '112', '26515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26516', '1079', '1', 'Worth County', 'US.GA.321', 'ASCII:Worth County;ID:4231976', '24639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24639', '112', '26516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.GA.321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26517', '1079', '1', 'Adams County', 'US.IL.001', 'ASCII:Adams County;ID:4232512', '24640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24640', '112', '26517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26518', '1079', '1', 'Alexander County', 'US.IL.003', 'ASCII:Alexander County;ID:4232592', '24641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24641', '112', '26518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26519', '1079', '1', 'Bond County', 'US.IL.005', 'ASCII:Bond County;ID:4234184', '24642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24642', '112', '26519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26520', '1079', '1', 'Brown County', 'US.IL.009', 'ASCII:Brown County;ID:4234528', '24643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24643', '112', '26520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26521', '1079', '1', 'Calhoun County', 'US.IL.013', 'ASCII:Calhoun County;ID:4235018', '24644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24644', '112', '26521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26522', '1079', '1', 'Cass County', 'US.IL.017', 'ASCII:Cass County;ID:4235369', '24645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24645', '112', '26522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26523', '1079', '1', 'Christian County', 'US.IL.021', 'ASCII:Christian County;ID:4235793', '24646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24646', '112', '26523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26524', '1079', '1', 'Clark County', 'US.IL.023', 'ASCII:Clark County;ID:4235954', '24647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24647', '112', '26524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26525', '1079', '1', 'Clay County', 'US.IL.025', 'ASCII:Clay County;ID:4235992', '24648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24648', '112', '26525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26526', '1079', '1', 'Clinton County', 'US.IL.027', 'ASCII:Clinton County;ID:4236063', '24649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24649', '112', '26526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26527', '1079', '1', 'Coles County', 'US.IL.029', 'ASCII:Coles County;ID:4236157', '24650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24650', '112', '26527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26528', '1079', '1', 'Crawford County', 'US.IL.033', 'ASCII:Crawford County;ID:4236576', '24651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24651', '112', '26528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26529', '1079', '1', 'Cumberland County', 'US.IL.035', 'ASCII:Cumberland County;ID:4236738', '24652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24652', '112', '26529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26530', '1079', '1', 'Douglas County', 'US.IL.041', 'ASCII:Douglas County;ID:4237204', '24653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24653', '112', '26530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26531', '1079', '1', 'Edgar County', 'US.IL.045', 'ASCII:Edgar County;ID:4237672', '24654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24654', '112', '26531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26532', '1079', '1', 'Edwards County', 'US.IL.047', 'ASCII:Edwards County;ID:4237705', '24655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24655', '112', '26532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26533', '1079', '1', 'Effingham County', 'US.IL.049', 'ASCII:Effingham County;ID:4237730', '24656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24656', '112', '26533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26534', '1079', '1', 'Fayette County', 'US.IL.051', 'ASCII:Fayette County;ID:4238245', '24657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24657', '112', '26534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26535', '1079', '1', 'Franklin County', 'US.IL.055', 'ASCII:Franklin County;ID:4238982', '24658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24658', '112', '26535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26536', '1079', '1', 'Gallatin County', 'US.IL.059', 'ASCII:Gallatin County;ID:4239230', '24659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24659', '112', '26536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26537', '1079', '1', 'Greene County', 'US.IL.061', 'ASCII:Greene County;ID:4239836', '24660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24660', '112', '26537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26538', '1079', '1', 'Hamilton County', 'US.IL.065', 'ASCII:Hamilton County;ID:4240145', '24661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24661', '112', '26538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26539', '1079', '1', 'Hardin County', 'US.IL.069', 'ASCII:Hardin County;ID:4240212', '24662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24662', '112', '26539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26540', '1079', '1', 'Jackson County', 'US.IL.077', 'ASCII:Jackson County;ID:4241687', '24663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24663', '112', '26540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26541', '1079', '1', 'Jasper County', 'US.IL.079', 'ASCII:Jasper County;ID:4241756', '24664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24664', '112', '26541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26542', '1079', '1', 'Jefferson County', 'US.IL.081', 'ASCII:Jefferson County;ID:4241773', '24665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24665', '112', '26542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26543', '1079', '1', 'Jersey County', 'US.IL.083', 'ASCII:Jersey County;ID:4241818', '24666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24666', '112', '26543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26544', '1079', '1', 'Johnson County', 'US.IL.087', 'ASCII:Johnson County;ID:4241904', '24667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24667', '112', '26544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26545', '1079', '1', 'Lawrence County', 'US.IL.101', 'ASCII:Lawrence County;ID:4242758', '24668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24668', '112', '26545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26546', '1079', '1', 'Macon County', 'US.IL.115', 'ASCII:Macon County;ID:4243719', '24669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24669', '112', '26546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26547', '1079', '1', 'Macoupin County', 'US.IL.117', 'ASCII:Macoupin County;ID:4243727', '24670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24670', '112', '26547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26548', '1079', '1', 'Madison County', 'US.IL.119', 'ASCII:Madison County;ID:4243743', '24671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24671', '112', '26548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26549', '1079', '1', 'Marion County', 'US.IL.121', 'ASCII:Marion County;ID:4243907', '24672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24672', '112', '26549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26550', '1079', '1', 'Massac County', 'US.IL.127', 'ASCII:Massac County;ID:4244065', '24673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24673', '112', '26550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26551', '1079', '1', 'Monroe County', 'US.IL.133', 'ASCII:Monroe County;ID:4244752', '24674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24674', '112', '26551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26552', '1079', '1', 'Montgomery County', 'US.IL.135', 'ASCII:Montgomery County;ID:4244772', '24675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24675', '112', '26552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26553', '1079', '1', 'Morgan County', 'US.IL.137', 'ASCII:Morgan County;ID:4244840', '24676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24676', '112', '26553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26554', '1079', '1', 'Moultrie County', 'US.IL.139', 'ASCII:Moultrie County;ID:4244913', '24677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24677', '112', '26554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26555', '1079', '1', 'Perry County', 'US.IL.145', 'ASCII:Perry County;ID:4246841', '24678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24678', '112', '26555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26556', '1079', '1', 'Pike County', 'US.IL.149', 'ASCII:Pike County;ID:4246953', '24679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24679', '112', '26556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26557', '1079', '1', 'Pope County', 'US.IL.151', 'ASCII:Pope County;ID:4247387', '24680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24680', '112', '26557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26558', '1079', '1', 'Pulaski County', 'US.IL.153', 'ASCII:Pulaski County;ID:4247655', '24681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24681', '112', '26558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26559', '1079', '1', 'Randolph County', 'US.IL.157', 'ASCII:Randolph County;ID:4247802', '24682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24682', '112', '26559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26560', '1079', '1', 'Richland County', 'US.IL.159', 'ASCII:Richland County;ID:4248062', '24683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24683', '112', '26560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26561', '1079', '1', 'Saint Clair County', 'US.IL.163', 'ASCII:Saint Clair County;ID:4248751', '24684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24684', '112', '26561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26562', '1079', '1', 'Saline County', 'US.IL.165', 'ASCII:Saline County;ID:4249341', '24685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24685', '112', '26562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26563', '1079', '1', 'Sangamon County', 'US.IL.167', 'ASCII:Sangamon County;ID:4249472', '24686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24686', '112', '26563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26564', '1079', '1', 'Scott County', 'US.IL.171', 'ASCII:Scott County;ID:4249615', '24687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24687', '112', '26564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26565', '1079', '1', 'Shelby County', 'US.IL.173', 'ASCII:Shelby County;ID:4249847', '24688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24688', '112', '26565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26566', '1079', '1', 'Union County', 'US.IL.181', 'ASCII:Union County;ID:4251707', '24689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24689', '112', '26566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26567', '1079', '1', 'Wabash County', 'US.IL.185', 'ASCII:Wabash County;ID:4252248', '24690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24690', '112', '26567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26568', '1079', '1', 'Washington County', 'US.IL.189', 'ASCII:Washington County;ID:4252486', '24691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24691', '112', '26568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26569', '1079', '1', 'Wayne County', 'US.IL.191', 'ASCII:Wayne County;ID:4252607', '24692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24692', '112', '26569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26570', '1079', '1', 'White County', 'US.IL.193', 'ASCII:White County;ID:4252955', '24693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24693', '112', '26570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26571', '1079', '1', 'Williamson County', 'US.IL.199', 'ASCII:Williamson County;ID:4253173', '24694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24694', '112', '26571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26572', '1079', '1', 'Bartholomew County', 'US.IN.005', 'ASCII:Bartholomew County;ID:4254165', '24695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24695', '112', '26572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26573', '1079', '1', 'Brown County', 'US.IN.013', 'ASCII:Brown County;ID:4255024', '24696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24696', '112', '26573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26574', '1079', '1', 'Clark County', 'US.IN.019', 'ASCII:Clark County;ID:4255818', '24697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24697', '112', '26574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26575', '1079', '1', 'Clay County', 'US.IN.021', 'ASCII:Clay County;ID:4255843', '24698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24698', '112', '26575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26576', '1079', '1', 'Crawford County', 'US.IN.025', 'ASCII:Crawford County;ID:4256259', '24699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24699', '112', '26576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26577', '1079', '1', 'Daviess County', 'US.IN.027', 'ASCII:Daviess County;ID:4256468', '24700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24700', '112', '26577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26578', '1079', '1', 'Decatur County', 'US.IN.031', 'ASCII:Decatur County;ID:4256516', '24701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24701', '112', '26578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26579', '1079', '1', 'Dearborn County', 'US.IN.029', 'ASCII:Dearborn County;ID:4256524', '24702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24702', '112', '26579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26580', '1079', '1', 'Dubois County', 'US.IN.037', 'ASCII:Dubois County;ID:4256808', '24703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24703', '112', '26580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26581', '1079', '1', 'Fayette County', 'US.IN.041', 'ASCII:Fayette County;ID:4257390', '24704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24704', '112', '26581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26582', '1079', '1', 'Floyd County', 'US.IN.043', 'ASCII:Floyd County;ID:4257565', '24705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24705', '112', '26582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26583', '1079', '1', 'Franklin County', 'US.IN.047', 'ASCII:Franklin County;ID:4257700', '24706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24706', '112', '26583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26584', '1079', '1', 'Gibson County', 'US.IN.051', 'ASCII:Gibson County;ID:4257948', '24707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24707', '112', '26584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26585', '1079', '1', 'Greene County', 'US.IN.055', 'ASCII:Greene County;ID:4258280', '24708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24708', '112', '26585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26586', '1079', '1', 'Hancock County', 'US.IN.059', 'ASCII:Hancock County;ID:4258477', '24709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24709', '112', '26586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26587', '1079', '1', 'Harrison County', 'US.IN.061', 'ASCII:Harrison County;ID:4258587', '24710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24710', '112', '26587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26588', '1079', '1', 'Hendricks County', 'US.IN.063', 'ASCII:Hendricks County;ID:4258778', '24711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24711', '112', '26588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26589', '1079', '1', 'Henry County', 'US.IN.065', 'ASCII:Henry County;ID:4258792', '24712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24712', '112', '26589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26590', '1079', '1', 'Jackson County', 'US.IN.071', 'ASCII:Jackson County;ID:4259572', '24713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24713', '112', '26590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26591', '1079', '1', 'Jefferson County', 'US.IN.077', 'ASCII:Jefferson County;ID:4259654', '24714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24714', '112', '26591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26592', '1079', '1', 'Jennings County', 'US.IN.079', 'ASCII:Jennings County;ID:4259679', '24715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24715', '112', '26592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26593', '1079', '1', 'Johnson County', 'US.IN.081', 'ASCII:Johnson County;ID:4259727', '24716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24716', '112', '26593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26594', '1079', '1', 'Knox County', 'US.IN.083', 'ASCII:Knox County;ID:4259986', '24717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24717', '112', '26594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26595', '1079', '1', 'Lawrence County', 'US.IN.093', 'ASCII:Lawrence County;ID:4260213', '24718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24718', '112', '26595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26596', '1079', '1', 'Marion County', 'US.IN.097', 'ASCII:Marion County;ID:4260977', '24719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24719', '112', '26596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26597', '1079', '1', 'Martin County', 'US.IN.101', 'ASCII:Martin County;ID:4261020', '24720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24720', '112', '26597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26598', '1079', '1', 'Monroe County', 'US.IN.105', 'ASCII:Monroe County;ID:4261526', '24721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24721', '112', '26598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26599', '1079', '1', 'Morgan County', 'US.IN.109', 'ASCII:Morgan County;ID:4261598', '24722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24722', '112', '26599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26600', '1079', '1', 'Ohio County', 'US.IN.115', 'ASCII:Ohio County;ID:4262462', '24723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24723', '112', '26600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26601', '1079', '1', 'Orange County', 'US.IN.117', 'ASCII:Orange County;ID:4262595', '24724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24724', '112', '26601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26602', '1079', '1', 'Owen County', 'US.IN.119', 'ASCII:Owen County;ID:4262691', '24725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24725', '112', '26602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26603', '1079', '1', 'Parke County', 'US.IN.121', 'ASCII:Parke County;ID:4262785', '24726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24726', '112', '26603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26604', '1079', '1', 'Perry County', 'US.IN.123', 'ASCII:Perry County;ID:4262934', '24727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24727', '112', '26604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26605', '1079', '1', 'Pike County', 'US.IN.125', 'ASCII:Pike County;ID:4263024', '24728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24728', '112', '26605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26606', '1079', '1', 'Posey County', 'US.IN.129', 'ASCII:Posey County;ID:4263298', '24729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24729', '112', '26606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26607', '1079', '1', 'Putnam County', 'US.IN.133', 'ASCII:Putnam County;ID:4263451', '24730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24730', '112', '26607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26608', '1079', '1', 'Ripley County', 'US.IN.137', 'ASCII:Ripley County;ID:4263732', '24731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24731', '112', '26608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26609', '1079', '1', 'Rush County', 'US.IN.139', 'ASCII:Rush County;ID:4263953', '24732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24732', '112', '26609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26610', '1079', '1', 'Scott County', 'US.IN.143', 'ASCII:Scott County;ID:4264540', '24733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24733', '112', '26610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26611', '1079', '1', 'Shelby County', 'US.IN.145', 'ASCII:Shelby County;ID:4264684', '24734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24734', '112', '26611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26612', '1079', '1', 'Spencer County', 'US.IN.147', 'ASCII:Spencer County;ID:4265152', '24735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24735', '112', '26612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26613', '1079', '1', 'Sullivan County', 'US.IN.153', 'ASCII:Sullivan County;ID:4265509', '24736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24736', '112', '26613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26614', '1079', '1', 'Switzerland County', 'US.IN.155', 'ASCII:Switzerland County;ID:4265618', '24737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24737', '112', '26614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26615', '1079', '1', 'Union County', 'US.IN.161', 'ASCII:Union County;ID:4266110', '24738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24738', '112', '26615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26616', '1079', '1', 'Vanderburgh County', 'US.IN.163', 'ASCII:Vanderburgh County;ID:4266235', '24739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24739', '112', '26616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26617', '1079', '1', 'Vermillion County', 'US.IN.165', 'ASCII:Vermillion County;ID:4266252', '24740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24740', '112', '26617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26618', '1079', '1', 'Vigo County', 'US.IN.167', 'ASCII:Vigo County;ID:4266295', '24741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24741', '112', '26618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26619', '1079', '1', 'Warrick County', 'US.IN.173', 'ASCII:Warrick County;ID:4266579', '24742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24742', '112', '26619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26620', '1079', '1', 'Washington County', 'US.IN.175', 'ASCII:Washington County;ID:4266588', '24743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24743', '112', '26620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26621', '1079', '1', 'Wayne County', 'US.IN.177', 'ASCII:Wayne County;ID:4266673', '24744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24744', '112', '26621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26622', '1079', '1', 'Allen County', 'US.KS.001', 'ASCII:Allen County;ID:4267492', '24745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24745', '112', '26622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26623', '1079', '1', 'Anderson County', 'US.KS.003', 'ASCII:Anderson County;ID:4267572', '24746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24746', '112', '26623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26624', '1079', '1', 'Atchison County', 'US.KS.005', 'ASCII:Atchison County;ID:4267734', '24747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24747', '112', '26624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26625', '1079', '1', 'Barber County', 'US.KS.007', 'ASCII:Barber County;ID:4267902', '24748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24748', '112', '26625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26626', '1079', '1', 'Barton County', 'US.KS.009', 'ASCII:Barton County;ID:4267938', '24749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24749', '112', '26626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26627', '1079', '1', 'Bourbon County', 'US.KS.011', 'ASCII:Bourbon County;ID:4268552', '24750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24750', '112', '26627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26628', '1079', '1', 'Brown County', 'US.KS.013', 'ASCII:Brown County;ID:4268687', '24751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24751', '112', '26628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26629', '1079', '1', 'Butler County', 'US.KS.015', 'ASCII:Butler County;ID:4268899', '24752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24752', '112', '26629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26630', '1079', '1', 'Chase County', 'US.KS.017', 'ASCII:Chase County;ID:4269424', '24753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24753', '112', '26630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26631', '1079', '1', 'Chautauqua County', 'US.KS.019', 'ASCII:Chautauqua County;ID:4269433', '24754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24754', '112', '26631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26632', '1079', '1', 'Cherokee County', 'US.KS.021', 'ASCII:Cherokee County;ID:4269459', '24755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24755', '112', '26632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26633', '1079', '1', 'Clark County', 'US.KS.025', 'ASCII:Clark County;ID:4269620', '24756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24756', '112', '26633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26634', '1079', '1', 'Clay County', 'US.KS.027', 'ASCII:Clay County;ID:4269648', '24757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24757', '112', '26634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26635', '1079', '1', 'Cloud County', 'US.KS.029', 'ASCII:Cloud County;ID:4269744', '24758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24758', '112', '26635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26636', '1079', '1', 'Coffey County', 'US.KS.031', 'ASCII:Coffey County;ID:4269788', '24759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24759', '112', '26636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26637', '1079', '1', 'Comanche County', 'US.KS.033', 'ASCII:Comanche County;ID:4269851', '24760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24760', '112', '26637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26638', '1079', '1', 'Cowley County', 'US.KS.035', 'ASCII:Cowley County;ID:4270053', '24761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24761', '112', '26638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26639', '1079', '1', 'Crawford County', 'US.KS.037', 'ASCII:Crawford County;ID:4270088', '24762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24762', '112', '26639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26640', '1079', '1', 'Dickinson County', 'US.KS.041', 'ASCII:Dickinson County;ID:4270394', '24763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24763', '112', '26640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26641', '1079', '1', 'Doniphan County', 'US.KS.043', 'ASCII:Doniphan County;ID:4270436', '24764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24764', '112', '26641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26642', '1079', '1', 'Douglas County', 'US.KS.045', 'ASCII:Douglas County;ID:4270450', '24765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24765', '112', '26642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26643', '1079', '1', 'Edwards County', 'US.KS.047', 'ASCII:Edwards County;ID:4270841', '24766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24766', '112', '26643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26644', '1079', '1', 'Elk County', 'US.KS.049', 'ASCII:Elk County;ID:4270898', '24767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24767', '112', '26644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26645', '1079', '1', 'Ellis County', 'US.KS.051', 'ASCII:Ellis County;ID:4270937', '24768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24768', '112', '26645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26646', '1079', '1', 'Ellsworth County', 'US.KS.053', 'ASCII:Ellsworth County;ID:4270946', '24769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24769', '112', '26646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26647', '1079', '1', 'Ford County', 'US.KS.057', 'ASCII:Ford County;ID:4271650', '24770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24770', '112', '26647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26648', '1079', '1', 'Franklin County', 'US.KS.059', 'ASCII:Franklin County;ID:4271771', '24771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24771', '112', '26648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26649', '1079', '1', 'Geary County', 'US.KS.061', 'ASCII:Geary County;ID:4272003', '24772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24772', '112', '26649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26650', '1079', '1', 'Graham County', 'US.KS.065', 'ASCII:Graham County;ID:4272234', '24773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24773', '112', '26650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26651', '1079', '1', 'Greenwood County', 'US.KS.073', 'ASCII:Greenwood County;ID:4272434', '24774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24774', '112', '26651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26652', '1079', '1', 'Harper County', 'US.KS.077', 'ASCII:Harper County;ID:4272662', '24775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24775', '112', '26652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26653', '1079', '1', 'Harvey County', 'US.KS.079', 'ASCII:Harvey County;ID:4272705', '24776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24776', '112', '26653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26654', '1079', '1', 'Hodgeman County', 'US.KS.083', 'ASCII:Hodgeman County;ID:4273049', '24777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24777', '112', '26654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26655', '1079', '1', 'Jackson County', 'US.KS.085', 'ASCII:Jackson County;ID:4273514', '24778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24778', '112', '26655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26656', '1079', '1', 'Jefferson County', 'US.KS.087', 'ASCII:Jefferson County;ID:4273563', '24779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24779', '112', '26656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26657', '1079', '1', 'Jewell County', 'US.KS.089', 'ASCII:Jewell County;ID:4273605', '24780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24780', '112', '26657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26658', '1079', '1', 'Johnson County', 'US.KS.091', 'ASCII:Johnson County;ID:4273638', '24781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24781', '112', '26658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26659', '1079', '1', 'Kingman County', 'US.KS.095', 'ASCII:Kingman County;ID:4273980', '24782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24782', '112', '26659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26660', '1079', '1', 'Kiowa County', 'US.KS.097', 'ASCII:Kiowa County;ID:4274001', '24783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24783', '112', '26660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26661', '1079', '1', 'Labette County', 'US.KS.099', 'ASCII:Labette County;ID:4274089', '24784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24784', '112', '26661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26662', '1079', '1', 'Leavenworth County', 'US.KS.103', 'ASCII:Leavenworth County;ID:4274307', '24785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24785', '112', '26662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26663', '1079', '1', 'Lincoln County', 'US.KS.105', 'ASCII:Lincoln County;ID:4274455', '24786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24786', '112', '26663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26664', '1079', '1', 'Linn County', 'US.KS.107', 'ASCII:Linn County;ID:4274536', '24787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24787', '112', '26664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26665', '1079', '1', 'Lyon County', 'US.KS.111', 'ASCII:Lyon County;ID:4274916', '24788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24788', '112', '26665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26666', '1079', '1', 'Marion County', 'US.KS.115', 'ASCII:Marion County;ID:4275073', '24789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24789', '112', '26666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26667', '1079', '1', 'Marshall County', 'US.KS.117', 'ASCII:Marshall County;ID:4275111', '24790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24790', '112', '26667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26668', '1079', '1', 'McPherson County', 'US.KS.113', 'ASCII:McPherson County;ID:4275266', '24791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24791', '112', '26668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26669', '1079', '1', 'Miami County', 'US.KS.121', 'ASCII:Miami County;ID:4275428', '24792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24792', '112', '26669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26670', '1079', '1', 'Mitchell County', 'US.KS.123', 'ASCII:Mitchell County;ID:4275635', '24793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24793', '112', '26670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26671', '1079', '1', 'Montgomery County', 'US.KS.125', 'ASCII:Montgomery County;ID:4275684', '24794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24794', '112', '26671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26672', '1079', '1', 'Morris County', 'US.KS.127', 'ASCII:Morris County;ID:4275742', '24795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24795', '112', '26672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26673', '1079', '1', 'Nemaha County', 'US.KS.131', 'ASCII:Nemaha County;ID:4276120', '24796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24796', '112', '26673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26674', '1079', '1', 'Neosho County', 'US.KS.133', 'ASCII:Neosho County;ID:4276136', '24797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24797', '112', '26674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26675', '1079', '1', 'Ness County', 'US.KS.135', 'ASCII:Ness County;ID:4276164', '24798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24798', '112', '26675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26676', '1079', '1', 'Norton County', 'US.KS.137', 'ASCII:Norton County;ID:4276454', '24799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24799', '112', '26676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26677', '1079', '1', 'Osage County', 'US.KS.139', 'ASCII:Osage County;ID:4276754', '24800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24800', '112', '26677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26678', '1079', '1', 'Osborne County', 'US.KS.141', 'ASCII:Osborne County;ID:4276786', '24801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24801', '112', '26678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26679', '1079', '1', 'Ottawa County', 'US.KS.143', 'ASCII:Ottawa County;ID:4276817', '24802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24802', '112', '26679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26680', '1079', '1', 'Pawnee County', 'US.KS.145', 'ASCII:Pawnee County;ID:4277045', '24803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24803', '112', '26680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26681', '1079', '1', 'Phillips County', 'US.KS.147', 'ASCII:Phillips County;ID:4277173', '24804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24804', '112', '26681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26682', '1079', '1', 'Pottawatomie County', 'US.KS.149', 'ASCII:Pottawatomie County;ID:4277604', '24805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24805', '112', '26682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26683', '1079', '1', 'Pratt County', 'US.KS.151', 'ASCII:Pratt County;ID:4277733', '24806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24806', '112', '26683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26684', '1079', '1', 'Reno County', 'US.KS.155', 'ASCII:Reno County;ID:4277972', '24807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24807', '112', '26684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26685', '1079', '1', 'Republic County', 'US.KS.157', 'ASCII:Republic County;ID:4277976', '24808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24808', '112', '26685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26686', '1079', '1', 'Rice County', 'US.KS.159', 'ASCII:Rice County;ID:4277995', '24809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24809', '112', '26686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26687', '1079', '1', 'Riley County', 'US.KS.161', 'ASCII:Riley County;ID:4278061', '24810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24810', '112', '26687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26688', '1079', '1', 'Rooks County', 'US.KS.163', 'ASCII:Rooks County;ID:4278304', '24811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24811', '112', '26688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26689', '1079', '1', 'Rush County', 'US.KS.165', 'ASCII:Rush County;ID:4278457', '24812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24812', '112', '26689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26690', '1079', '1', 'Russell County', 'US.KS.167', 'ASCII:Russell County;ID:4278472', '24813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24813', '112', '26690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26691', '1079', '1', 'Saline County', 'US.KS.169', 'ASCII:Saline County;ID:4278895', '24814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24814', '112', '26691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26692', '1079', '1', 'Sedgwick County', 'US.KS.173', 'ASCII:Sedgwick County;ID:4279155', '24815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24815', '112', '26692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26693', '1079', '1', 'Shawnee County', 'US.KS.177', 'ASCII:Shawnee County;ID:4279253', '24816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24816', '112', '26693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26694', '1079', '1', 'Smith County', 'US.KS.183', 'ASCII:Smith County;ID:4279478', '24817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24817', '112', '26694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26695', '1079', '1', 'Stafford County', 'US.KS.185', 'ASCII:Stafford County;ID:4279904', '24818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24818', '112', '26695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26696', '1079', '1', 'Sumner County', 'US.KS.191', 'ASCII:Sumner County;ID:4280143', '24819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24819', '112', '26696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26697', '1079', '1', 'Trego County', 'US.KS.195', 'ASCII:Trego County;ID:4280609', '24820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24820', '112', '26697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26698', '1079', '1', 'Wabaunsee County', 'US.KS.197', 'ASCII:Wabaunsee County;ID:4281087', '24821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24821', '112', '26698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26699', '1079', '1', 'Washington County', 'US.KS.201', 'ASCII:Washington County;ID:4281258', '24822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24822', '112', '26699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26700', '1079', '1', 'Wilson County', 'US.KS.205', 'ASCII:Wilson County;ID:4281852', '24823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24823', '112', '26700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26701', '1079', '1', 'Woodson County', 'US.KS.207', 'ASCII:Woodson County;ID:4282006', '24824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24824', '112', '26701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26702', '1079', '1', 'Wyandotte County', 'US.KS.209', 'ASCII:Wyandotte County;ID:4282035', '24825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24825', '112', '26702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26703', '1079', '1', 'Adair County', 'US.KY.001', 'ASCII:Adair County;ID:4282211', '24826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24826', '112', '26703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26704', '1079', '1', 'Allen County', 'US.KY.003', 'ASCII:Allen County;ID:4282393', '24827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24827', '112', '26704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26705', '1079', '1', 'Anderson County', 'US.KY.005', 'ASCII:Anderson County;ID:4282511', '24828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24828', '112', '26705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26706', '1079', '1', 'Ballard County', 'US.KY.007', 'ASCII:Ballard County;ID:4283067', '24829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24829', '112', '26706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26707', '1079', '1', 'Barren County', 'US.KY.009', 'ASCII:Barren County;ID:4283268', '24830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24830', '112', '26707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26708', '1079', '1', 'Bath County', 'US.KY.011', 'ASCII:Bath County;ID:4283333', '24831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24831', '112', '26708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26709', '1079', '1', 'Bell County', 'US.KY.013', 'ASCII:Bell County;ID:4283814', '24832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24832', '112', '26709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26710', '1079', '1', 'Bourbon County', 'US.KY.017', 'ASCII:Bourbon County;ID:4285233', '24833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24833', '112', '26710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26711', '1079', '1', 'Boyd County', 'US.KY.019', 'ASCII:Boyd County;ID:4285302', '24834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24834', '112', '26711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26712', '1079', '1', 'Boyle County', 'US.KY.021', 'ASCII:Boyle County;ID:4285317', '24835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24835', '112', '26712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26713', '1079', '1', 'Bracken County', 'US.KY.023', 'ASCII:Bracken County;ID:4285325', '24836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24836', '112', '26713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26714', '1079', '1', 'Breathitt County', 'US.KY.025', 'ASCII:Breathitt County;ID:4285423', '24837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24837', '112', '26714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26715', '1079', '1', 'Breckinridge County', 'US.KY.027', 'ASCII:Breckinridge County;ID:4285428', '24838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24838', '112', '26715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26716', '1079', '1', 'Bullitt County', 'US.KY.029', 'ASCII:Bullitt County;ID:4286176', '24839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24839', '112', '26716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26717', '1079', '1', 'Butler County', 'US.KY.031', 'ASCII:Butler County;ID:4286382', '24840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24840', '112', '26717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26718', '1079', '1', 'Caldwell County', 'US.KY.033', 'ASCII:Caldwell County;ID:4286500', '24841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24841', '112', '26718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26719', '1079', '1', 'Calloway County', 'US.KY.035', 'ASCII:Calloway County;ID:4286549', '24842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24842', '112', '26719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26720', '1079', '1', 'Campbell County', 'US.KY.037', 'ASCII:Campbell County;ID:4286705', '24843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24843', '112', '26720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26721', '1079', '1', 'Carlisle County', 'US.KY.039', 'ASCII:Carlisle County;ID:4286990', '24844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24844', '112', '26721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26722', '1079', '1', 'Carroll County', 'US.KY.041', 'ASCII:Carroll County;ID:4287048', '24845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24845', '112', '26722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26723', '1079', '1', 'Carter County', 'US.KY.043', 'ASCII:Carter County;ID:4287080', '24846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24846', '112', '26723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26724', '1079', '1', 'Casey County', 'US.KY.045', 'ASCII:Casey County;ID:4287126', '24847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24847', '112', '26724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26725', '1079', '1', 'Christian County', 'US.KY.047', 'ASCII:Christian County;ID:4287749', '24848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24848', '112', '26725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26726', '1079', '1', 'Clark County', 'US.KY.049', 'ASCII:Clark County;ID:4287837', '24849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24849', '112', '26726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26727', '1079', '1', 'Clay County', 'US.KY.051', 'ASCII:Clay County;ID:4287883', '24850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24850', '112', '26727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26728', '1079', '1', 'Clinton County', 'US.KY.053', 'ASCII:Clinton County;ID:4288063', '24851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24851', '112', '26728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26729', '1079', '1', 'Crittenden County', 'US.KY.055', 'ASCII:Crittenden County;ID:4289074', '24852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24852', '112', '26729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26730', '1079', '1', 'Cumberland County', 'US.KY.057', 'ASCII:Cumberland County;ID:4289242', '24853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24853', '112', '26730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26731', '1079', '1', 'Daviess County', 'US.KY.059', 'ASCII:Daviess County;ID:4289518', '24854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24854', '112', '26731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26732', '1079', '1', 'Edmonson County', 'US.KY.061', 'ASCII:Edmonson County;ID:4290885', '24855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24855', '112', '26732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26733', '1079', '1', 'Elliott County', 'US.KY.063', 'ASCII:Elliott County;ID:4291095', '24856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24856', '112', '26733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26734', '1079', '1', 'Estill County', 'US.KY.065', 'ASCII:Estill County;ID:4291280', '24857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24857', '112', '26734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26735', '1079', '1', 'Fayette County', 'US.KY.067', 'ASCII:Fayette County;ID:4291564', '24858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24858', '112', '26735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26736', '1079', '1', 'Fleming County', 'US.KY.069', 'ASCII:Fleming County;ID:4291901', '24859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24859', '112', '26736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26737', '1079', '1', 'Floyd County', 'US.KY.071', 'ASCII:Floyd County;ID:4291960', '24860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24860', '112', '26737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26738', '1079', '1', 'Franklin County', 'US.KY.073', 'ASCII:Franklin County;ID:4292202', '24861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24861', '112', '26738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26739', '1079', '1', 'Fulton County', 'US.KY.075', 'ASCII:Fulton County;ID:4292427', '24862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24862', '112', '26739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26740', '1079', '1', 'Gallatin County', 'US.KY.077', 'ASCII:Gallatin County;ID:4292492', '24863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24863', '112', '26740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26741', '1079', '1', 'Garrard County', 'US.KY.079', 'ASCII:Garrard County;ID:4292570', '24864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24864', '112', '26741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26742', '1079', '1', 'Grant County', 'US.KY.081', 'ASCII:Grant County;ID:4293148', '24865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24865', '112', '26742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26743', '1079', '1', 'Graves County', 'US.KY.083', 'ASCII:Graves County;ID:4293245', '24866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24866', '112', '26743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26744', '1079', '1', 'Grayson County', 'US.KY.085', 'ASCII:Grayson County;ID:4293301', '24867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24867', '112', '26744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26745', '1079', '1', 'Green County', 'US.KY.087', 'ASCII:Green County;ID:4293371', '24868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24868', '112', '26745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26746', '1079', '1', 'Greenup County', 'US.KY.089', 'ASCII:Greenup County;ID:4293471', '24869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24869', '112', '26746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26747', '1079', '1', 'Hancock County', 'US.KY.091', 'ASCII:Hancock County;ID:4293950', '24870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24870', '112', '26747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26748', '1079', '1', 'Hardin County', 'US.KY.093', 'ASCII:Hardin County;ID:4294031', '24871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24871', '112', '26748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26749', '1079', '1', 'Harlan County', 'US.KY.095', 'ASCII:Harlan County;ID:4294084', '24872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24872', '112', '26749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26750', '1079', '1', 'Harrison County', 'US.KY.097', 'ASCII:Harrison County;ID:4294160', '24873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24873', '112', '26750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26751', '1079', '1', 'Hart County', 'US.KY.099', 'ASCII:Hart County;ID:4294190', '24874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24874', '112', '26751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26752', '1079', '1', 'Henderson County', 'US.KY.101', 'ASCII:Henderson County;ID:4294512', '24875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24875', '112', '26752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26753', '1079', '1', 'Henry County', 'US.KY.103', 'ASCII:Henry County;ID:4294546', '24876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24876', '112', '26753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26754', '1079', '1', 'Hickman County', 'US.KY.105', 'ASCII:Hickman County;ID:4294628', '24877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24877', '112', '26754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26755', '1079', '1', 'Hopkins County', 'US.KY.107', 'ASCII:Hopkins County;ID:4295247', '24878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24878', '112', '26755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26756', '1079', '1', 'Jackson County', 'US.KY.109', 'ASCII:Jackson County;ID:4296106', '24879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24879', '112', '26756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26757', '1079', '1', 'Jefferson County', 'US.KY.111', 'ASCII:Jefferson County;ID:4296212', '24880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24880', '112', '26757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26758', '1079', '1', 'Jessamine County', 'US.KY.113', 'ASCII:Jessamine County;ID:4296292', '24881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24881', '112', '26758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26759', '1079', '1', 'Johnson County', 'US.KY.115', 'ASCII:Johnson County;ID:4296508', '24882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24882', '112', '26759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26760', '1079', '1', 'Kenton County', 'US.KY.117', 'ASCII:Kenton County;ID:4296902', '24883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24883', '112', '26760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26761', '1079', '1', 'Knott County', 'US.KY.119', 'ASCII:Knott County;ID:4297180', '24884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24884', '112', '26761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26762', '1079', '1', 'Knox County', 'US.KY.121', 'ASCII:Knox County;ID:4297187', '24885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24885', '112', '26762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26763', '1079', '1', 'Larue County', 'US.KY.123', 'ASCII:Larue County;ID:4297424', '24886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24886', '112', '26763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26764', '1079', '1', 'Laurel County', 'US.KY.125', 'ASCII:Laurel County;ID:4297480', '24887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24887', '112', '26764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26765', '1079', '1', 'Lawrence County', 'US.KY.127', 'ASCII:Lawrence County;ID:4297576', '24888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24888', '112', '26765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26766', '1079', '1', 'Lee County', 'US.KY.129', 'ASCII:Lee County;ID:4297704', '24889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24889', '112', '26766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26767', '1079', '1', 'Leslie County', 'US.KY.131', 'ASCII:Leslie County;ID:4297902', '24890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24890', '112', '26767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26768', '1079', '1', 'Letcher County', 'US.KY.133', 'ASCII:Letcher County;ID:4297909', '24891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24891', '112', '26768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26769', '1079', '1', 'Lewis County', 'US.KY.135', 'ASCII:Lewis County;ID:4297955', '24892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24892', '112', '26769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26770', '1079', '1', 'Lincoln County', 'US.KY.137', 'ASCII:Lincoln County;ID:4298293', '24893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24893', '112', '26770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26771', '1079', '1', 'Livingston County', 'US.KY.139', 'ASCII:Livingston County;ID:4298811', '24894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24894', '112', '26771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26772', '1079', '1', 'Logan County', 'US.KY.141', 'ASCII:Logan County;ID:4298932', '24895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24895', '112', '26772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26773', '1079', '1', 'Lyon County', 'US.KY.143', 'ASCII:Lyon County;ID:4299595', '24896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24896', '112', '26773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26774', '1079', '1', 'Madison County', 'US.KY.151', 'ASCII:Madison County;ID:4299665', '24897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24897', '112', '26774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26775', '1079', '1', 'Magoffin County', 'US.KY.153', 'ASCII:Magoffin County;ID:4299695', '24898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24898', '112', '26775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26776', '1079', '1', 'Marion County', 'US.KY.155', 'ASCII:Marion County;ID:4299849', '24899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24899', '112', '26776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26777', '1079', '1', 'Marshall County', 'US.KY.157', 'ASCII:Marshall County;ID:4299896', '24900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24900', '112', '26777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26778', '1079', '1', 'Martin County', 'US.KY.159', 'ASCII:Martin County;ID:4299939', '24901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24901', '112', '26778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26779', '1079', '1', 'Mason County', 'US.KY.161', 'ASCII:Mason County;ID:4300012', '24902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24902', '112', '26779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26780', '1079', '1', 'McCracken County', 'US.KY.145', 'ASCII:McCracken County;ID:4300244', '24903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24903', '112', '26780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26781', '1079', '1', 'McCreary County', 'US.KY.147', 'ASCII:McCreary County;ID:4300249', '24904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24904', '112', '26781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26782', '1079', '1', 'McLean County', 'US.KY.149', 'ASCII:McLean County;ID:4300401', '24905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24905', '112', '26782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26783', '1079', '1', 'Meade County', 'US.KY.163', 'ASCII:Meade County;ID:4300426', '24906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24906', '112', '26783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26784', '1079', '1', 'Menifee County', 'US.KY.165', 'ASCII:Menifee County;ID:4300562', '24907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24907', '112', '26784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26785', '1079', '1', 'Mercer County', 'US.KY.167', 'ASCII:Mercer County;ID:4300572', '24908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24908', '112', '26785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26786', '1079', '1', 'Metcalfe County', 'US.KY.169', 'ASCII:Metcalfe County;ID:4300606', '24909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24909', '112', '26786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26787', '1079', '1', 'Monroe County', 'US.KY.171', 'ASCII:Monroe County;ID:4301192', '24910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24910', '112', '26787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26788', '1079', '1', 'Montgomery County', 'US.KY.173', 'ASCII:Montgomery County;ID:4301216', '24911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24911', '112', '26788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26789', '1079', '1', 'Morgan County', 'US.KY.175', 'ASCII:Morgan County;ID:4301333', '24912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24912', '112', '26789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26790', '1079', '1', 'Muhlenberg County', 'US.KY.177', 'ASCII:Muhlenberg County;ID:4301955', '24913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24913', '112', '26790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26791', '1079', '1', 'Nelson County', 'US.KY.179', 'ASCII:Nelson County;ID:4302277', '24914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24914', '112', '26791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26792', '1079', '1', 'Nicholas County', 'US.KY.181', 'ASCII:Nicholas County;ID:4302564', '24915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24915', '112', '26792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26793', '1079', '1', 'Ohio County', 'US.KY.183', 'ASCII:Ohio County;ID:4302977', '24916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24916', '112', '26793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26794', '1079', '1', 'Oldham County', 'US.KY.185', 'ASCII:Oldham County;ID:4303164', '24917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24917', '112', '26794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26795', '1079', '1', 'Owen County', 'US.KY.187', 'ASCII:Owen County;ID:4303402', '24918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24918', '112', '26795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26796', '1079', '1', 'Owsley County', 'US.KY.189', 'ASCII:Owsley County;ID:4303455', '24919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24919', '112', '26796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26797', '1079', '1', 'Pendleton County', 'US.KY.191', 'ASCII:Pendleton County;ID:4303870', '24920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24920', '112', '26797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26798', '1079', '1', 'Perry County', 'US.KY.193', 'ASCII:Perry County;ID:4303951', '24921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24921', '112', '26798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26799', '1079', '1', 'Pike County', 'US.KY.195', 'ASCII:Pike County;ID:4304226', '24922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24922', '112', '26799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26800', '1079', '1', 'Powell County', 'US.KY.197', 'ASCII:Powell County;ID:4305121', '24923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24923', '112', '26800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26801', '1079', '1', 'Pulaski County', 'US.KY.199', 'ASCII:Pulaski County;ID:4305364', '24924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24924', '112', '26801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26802', '1079', '1', 'Robertson County', 'US.KY.201', 'ASCII:Robertson County;ID:4306340', '24925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24925', '112', '26802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26803', '1079', '1', 'Rockcastle County', 'US.KY.203', 'ASCII:Rockcastle County;ID:4306470', '24926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24926', '112', '26803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26804', '1079', '1', 'Russell County', 'US.KY.207', 'ASCII:Russell County;ID:4306996', '24927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24927', '112', '26804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26805', '1079', '1', 'Scott County', 'US.KY.209', 'ASCII:Scott County;ID:4307808', '24928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24928', '112', '26805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26806', '1079', '1', 'Shelby County', 'US.KY.211', 'ASCII:Shelby County;ID:4308112', '24929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24929', '112', '26806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26807', '1079', '1', 'Simpson County', 'US.KY.213', 'ASCII:Simpson County;ID:4308447', '24930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24930', '112', '26807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26808', '1079', '1', 'Spencer County', 'US.KY.215', 'ASCII:Spencer County;ID:4309179', '24931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24931', '112', '26808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26809', '1079', '1', 'Taylor County', 'US.KY.217', 'ASCII:Taylor County;ID:4310601', '24932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24932', '112', '26809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26810', '1079', '1', 'Todd County', 'US.KY.219', 'ASCII:Todd County;ID:4310988', '24933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24933', '112', '26810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26811', '1079', '1', 'Trigg County', 'US.KY.221', 'ASCII:Trigg County;ID:4311258', '24934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24934', '112', '26811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26812', '1079', '1', 'Trimble County', 'US.KY.223', 'ASCII:Trimble County;ID:4311266', '24935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24935', '112', '26812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26813', '1079', '1', 'Union County', 'US.KY.225', 'ASCII:Union County;ID:4311683', '24936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24936', '112', '26813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26814', '1079', '1', 'Warren County', 'US.KY.227', 'ASCII:Warren County;ID:4312732', '24937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24937', '112', '26814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26815', '1079', '1', 'Washington County', 'US.KY.229', 'ASCII:Washington County;ID:4312745', '24938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24938', '112', '26815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26816', '1079', '1', 'Wayne County', 'US.KY.231', 'ASCII:Wayne County;ID:4312835', '24939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24939', '112', '26816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26817', '1079', '1', 'Webster County', 'US.KY.233', 'ASCII:Webster County;ID:4312885', '24940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24940', '112', '26817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26818', '1079', '1', 'Whitley County', 'US.KY.235', 'ASCII:Whitley County;ID:4313367', '24941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24941', '112', '26818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26819', '1079', '1', 'Wolfe County', 'US.KY.237', 'ASCII:Wolfe County;ID:4313865', '24942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24942', '112', '26819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26820', '1079', '1', 'Woodford County', 'US.KY.239', 'ASCII:Woodford County;ID:4313946', '24943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24943', '112', '26820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KY.239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26821', '1079', '1', 'Acadia Parish', 'US.LA.001', 'ASCII:Acadia Parish;ID:4314344', '24944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24944', '112', '26821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26822', '1079', '1', 'Allen Parish', 'US.LA.003', 'ASCII:Allen Parish;ID:4314607', '24945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24945', '112', '26822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26823', '1079', '1', 'Ascension Parish', 'US.LA.005', 'ASCII:Ascension Parish;ID:4315067', '24946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24946', '112', '26823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26824', '1079', '1', 'Assumption Parish', 'US.LA.007', 'ASCII:Assumption Parish;ID:4315120', '24947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24947', '112', '26824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26825', '1079', '1', 'Avoyelles Parish', 'US.LA.009', 'ASCII:Avoyelles Parish;ID:4315243', '24948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24948', '112', '26825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26826', '1079', '1', 'Beauregard Parish', 'US.LA.011', 'ASCII:Beauregard Parish;ID:4316112', '24949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24949', '112', '26826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26827', '1079', '1', 'Bienville Parish', 'US.LA.013', 'ASCII:Bienville Parish;ID:4316721', '24950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24950', '112', '26827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26828', '1079', '1', 'Bossier Parish', 'US.LA.015', 'ASCII:Bossier Parish;ID:4317649', '24951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24951', '112', '26828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26829', '1079', '1', 'Caddo Parish', 'US.LA.017', 'ASCII:Caddo Parish;ID:4318532', '24952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24952', '112', '26829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26830', '1079', '1', 'Calcasieu Parish', 'US.LA.019', 'ASCII:Calcasieu Parish;ID:4318583', '24953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24953', '112', '26830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26831', '1079', '1', 'Caldwell Parish', 'US.LA.021', 'ASCII:Caldwell Parish;ID:4318597', '24954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24954', '112', '26831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26832', '1079', '1', 'Cameron Parish', 'US.LA.023', 'ASCII:Cameron Parish;ID:4318690', '24955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24955', '112', '26832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26833', '1079', '1', 'Catahoula Parish', 'US.LA.025', 'ASCII:Catahoula Parish;ID:4319276', '24956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24956', '112', '26833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26834', '1079', '1', 'Claiborne Parish', 'US.LA.027', 'ASCII:Claiborne Parish;ID:4320117', '24957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24957', '112', '26834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26835', '1079', '1', 'Concordia Parish', 'US.LA.029', 'ASCII:Concordia Parish;ID:4320594', '24958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24958', '112', '26835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26836', '1079', '1', 'De Soto Parish', 'US.LA.031', 'ASCII:De Soto Parish;ID:4321759', '24959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24959', '112', '26836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26837', '1079', '1', 'East Baton Rouge Parish', 'US.LA.033', 'ASCII:East Baton Rouge Parish;ID:4323288', '24960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24960', '112', '26837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26838', '1079', '1', 'East Carroll Parish', 'US.LA.035', 'ASCII:East Carroll Parish;ID:4323316', '24961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24961', '112', '26838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26839', '1079', '1', 'East Feliciana Parish', 'US.LA.037', 'ASCII:East Feliciana Parish;ID:4323332', '24962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24962', '112', '26839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26840', '1079', '1', 'Evangeline Parish', 'US.LA.039', 'ASCII:Evangeline Parish;ID:4323933', '24963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24963', '112', '26840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26841', '1079', '1', 'Franklin Parish', 'US.LA.041', 'ASCII:Franklin Parish;ID:4325158', '24964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24964', '112', '26841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26842', '1079', '1', 'Grant Parish', 'US.LA.043', 'ASCII:Grant Parish;ID:4326254', '24965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24965', '112', '26842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26843', '1079', '1', 'Iberia Parish', 'US.LA.045', 'ASCII:Iberia Parish;ID:4328254', '24966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24966', '112', '26843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26844', '1079', '1', 'Iberville Parish', 'US.LA.047', 'ASCII:Iberville Parish;ID:4328261', '24967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24967', '112', '26844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26845', '1079', '1', 'Jackson Parish', 'US.LA.049', 'ASCII:Jackson Parish;ID:4328854', '24968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24968', '112', '26845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26846', '1079', '1', 'Jefferson Davis Parish', 'US.LA.053', 'ASCII:Jefferson Davis Parish;ID:4328965', '24969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24969', '112', '26846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26847', '1079', '1', 'Jefferson Parish', 'US.LA.051', 'ASCII:Jefferson Parish;ID:4328978', '24970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24970', '112', '26847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26848', '1079', '1', 'La Salle Parish', 'US.LA.059', 'ASCII:La Salle Parish;ID:4330078', '24971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24971', '112', '26848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26849', '1079', '1', 'Lafayette Parish', 'US.LA.055', 'ASCII:Lafayette Parish;ID:4330160', '24972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24972', '112', '26849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26850', '1079', '1', 'Lafourche Parish', 'US.LA.057', 'ASCII:Lafourche Parish;ID:4330185', '24973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24973', '112', '26850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26851', '1079', '1', 'Lincoln Parish', 'US.LA.061', 'ASCII:Lincoln Parish;ID:4330983', '24974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24974', '112', '26851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26852', '1079', '1', 'Livingston Parish', 'US.LA.063', 'ASCII:Livingston Parish;ID:4331488', '24975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24975', '112', '26852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26853', '1079', '1', 'Madison Parish', 'US.LA.065', 'ASCII:Madison Parish;ID:4332258', '24976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24976', '112', '26853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26854', '1079', '1', 'Morehouse Parish', 'US.LA.067', 'ASCII:Morehouse Parish;ID:4333789', '24977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24977', '112', '26854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26855', '1079', '1', 'Natchitoches Parish', 'US.LA.069', 'ASCII:Natchitoches Parish;ID:4334734', '24978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24978', '112', '26855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26856', '1079', '1', 'Orleans Parish', 'US.LA.071', 'ASCII:Orleans Parish;ID:4336191', '24979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24979', '112', '26856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26857', '1079', '1', 'Ouachita Parish', 'US.LA.073', 'ASCII:Ouachita Parish;ID:4336232', '24980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24980', '112', '26857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26858', '1079', '1', 'Plaquemines Parish', 'US.LA.075', 'ASCII:Plaquemines Parish;ID:4337452', '24981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24981', '112', '26858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26859', '1079', '1', 'Pointe Coupee Parish', 'US.LA.077', 'ASCII:Pointe Coupee Parish;ID:4337708', '24982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24982', '112', '26859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26860', '1079', '1', 'Rapides Parish', 'US.LA.079', 'ASCII:Rapides Parish;ID:4338356', '24983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24983', '112', '26860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26861', '1079', '1', 'Red River Parish', 'US.LA.081', 'ASCII:Red River Parish;ID:4338489', '24984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24984', '112', '26861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26862', '1079', '1', 'Richland Parish', 'US.LA.083', 'ASCII:Richland Parish;ID:4338711', '24985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24985', '112', '26862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26863', '1079', '1', 'Sabine Parish', 'US.LA.085', 'ASCII:Sabine Parish;ID:4339354', '24986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24986', '112', '26863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26864', '1079', '1', 'Saint Bernard Parish', 'US.LA.087', 'ASCII:Saint Bernard Parish;ID:4339526', '24987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24987', '112', '26864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26865', '1079', '1', 'Saint Charles Parish', 'US.LA.089', 'ASCII:Saint Charles Parish;ID:4339583', '24988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24988', '112', '26865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26866', '1079', '1', 'Saint Helena Parish', 'US.LA.091', 'ASCII:Saint Helena Parish;ID:4339724', '24989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24989', '112', '26866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26867', '1079', '1', 'Saint James Parish', 'US.LA.093', 'ASCII:Saint James Parish;ID:4339793', '24990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24990', '112', '26867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26868', '1079', '1', 'Saint John the Baptist Parish', 'US.LA.095', 'ASCII:Saint John the Baptist Parish;ID:4339881', '24991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24991', '112', '26868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26869', '1079', '1', 'Saint Landry Parish', 'US.LA.097', 'ASCII:Saint Landry Parish;ID:4340045', '24992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24992', '112', '26869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26870', '1079', '1', 'Saint Martin Parish', 'US.LA.099', 'ASCII:Saint Martin Parish;ID:4340186', '24993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24993', '112', '26870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26871', '1079', '1', 'Saint Mary Parish', 'US.LA.101', 'ASCII:Saint Mary Parish;ID:4340232', '24994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24994', '112', '26871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26872', '1079', '1', 'Saint Tammany Parish', 'US.LA.103', 'ASCII:Saint Tammany Parish;ID:4340579', '24995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24995', '112', '26872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26873', '1079', '1', 'Tangipahoa Parish', 'US.LA.105', 'ASCII:Tangipahoa Parish;ID:4343122', '24996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24996', '112', '26873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26874', '1079', '1', 'Tensas Parish', 'US.LA.107', 'ASCII:Tensas Parish;ID:4343280', '24997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24997', '112', '26874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26875', '1079', '1', 'Terrebonne Parish', 'US.LA.109', 'ASCII:Terrebonne Parish;ID:4343313', '24998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24998', '112', '26875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26876', '1079', '1', 'Union Parish', 'US.LA.111', 'ASCII:Union Parish;ID:4344274', '24999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('24999', '112', '26876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26877', '1079', '1', 'Vermilion Parish', 'US.LA.113', 'ASCII:Vermilion Parish;ID:4344530', '25000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25000', '112', '26877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26878', '1079', '1', 'Vernon Parish', 'US.LA.115', 'ASCII:Vernon Parish;ID:4344544', '25001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25001', '112', '26878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26879', '1079', '1', 'Washington Parish', 'US.LA.117', 'ASCII:Washington Parish;ID:4345509', '25002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25002', '112', '26879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26880', '1079', '1', 'Webster Parish', 'US.LA.119', 'ASCII:Webster Parish;ID:4345618', '25003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25003', '112', '26880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26881', '1079', '1', 'West Baton Rouge Parish', 'US.LA.121', 'ASCII:West Baton Rouge Parish;ID:4345713', '25004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25004', '112', '26881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26882', '1079', '1', 'West Carroll Parish', 'US.LA.123', 'ASCII:West Carroll Parish;ID:4345740', '25005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25005', '112', '26882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26883', '1079', '1', 'West Feliciana Parish', 'US.LA.125', 'ASCII:West Feliciana Parish;ID:4345778', '25006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25006', '112', '26883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26884', '1079', '1', 'Winn Parish', 'US.LA.127', 'ASCII:Winn Parish;ID:4346451', '25007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25007', '112', '26884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.LA.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26885', '1079', '1', 'Allegany County', 'US.MD.001', 'ASCII:Allegany County;ID:4347094', '25008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25008', '112', '26885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26886', '1079', '1', 'Anne Arundel County', 'US.MD.003', 'ASCII:Anne Arundel County;ID:4347283', '25009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25009', '112', '26886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26887', '1079', '1', 'Baltimore County', 'US.MD.005', 'ASCII:Baltimore County;ID:4347790', '25010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25010', '112', '26887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26888', '1079', '1', 'City of Baltimore', 'US.MD.510', 'ASCII:City of Baltimore;ID:4347820', '25011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25011', '112', '26888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26889', '1079', '1', 'Calvert County', 'US.MD.009', 'ASCII:Calvert County;ID:4350123', '25012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25012', '112', '26889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26890', '1079', '1', 'Caroline County', 'US.MD.011', 'ASCII:Caroline County;ID:4350425', '25013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25013', '112', '26890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26891', '1079', '1', 'Carroll County', 'US.MD.013', 'ASCII:Carroll County;ID:4350461', '25014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25014', '112', '26891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26892', '1079', '1', 'Cecil County', 'US.MD.015', 'ASCII:Cecil County;ID:4350685', '25015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25015', '112', '26892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26893', '1079', '1', 'Charles County', 'US.MD.017', 'ASCII:Charles County;ID:4351021', '25016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25016', '112', '26893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26894', '1079', '1', 'Dorchester County', 'US.MD.019', 'ASCII:Dorchester County;ID:4353543', '25017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25017', '112', '26894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26895', '1079', '1', 'Frederick County', 'US.MD.021', 'ASCII:Frederick County;ID:4355594', '25018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25018', '112', '26895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26896', '1079', '1', 'Garrett County', 'US.MD.023', 'ASCII:Garrett County;ID:4355939', '25019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25019', '112', '26896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26897', '1079', '1', 'Harford County', 'US.MD.025', 'ASCII:Harford County;ID:4357407', '25020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25020', '112', '26897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26898', '1079', '1', 'Howard County', 'US.MD.027', 'ASCII:Howard County;ID:4358598', '25021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25021', '112', '26898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26899', '1079', '1', 'Kent County', 'US.MD.029', 'ASCII:Kent County;ID:4359780', '25022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25022', '112', '26899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26900', '1079', '1', 'Montgomery County', 'US.MD.031', 'ASCII:Montgomery County;ID:4362716', '25023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25023', '112', '26900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26901', '1079', '1', 'Prince George''s County', 'US.MD.033', 'ASCII:Prince George''s County;ID:4366164', '25024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25024', '112', '26901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26902', '1079', '1', 'Queen Anne''s County', 'US.MD.035', 'ASCII:Queen Anne''s County;ID:4366351', '25025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25025', '112', '26902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26903', '1079', '1', 'Saint Mary''s County', 'US.MD.037', 'ASCII:Saint Mary''s County;ID:4368320', '25026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25026', '112', '26903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26904', '1079', '1', 'Somerset County', 'US.MD.039', 'ASCII:Somerset County;ID:4369894', '25027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25027', '112', '26904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26905', '1079', '1', 'Talbot County', 'US.MD.041', 'ASCII:Talbot County;ID:4370904', '25028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25028', '112', '26905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26906', '1079', '1', 'Washington County', 'US.MD.043', 'ASCII:Washington County;ID:4372777', '25029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25029', '112', '26906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26907', '1079', '1', 'Wicomico County', 'US.MD.045', 'ASCII:Wicomico County;ID:4373554', '25030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25030', '112', '26907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26908', '1079', '1', 'Worcester County', 'US.MD.047', 'ASCII:Worcester County;ID:4374180', '25031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25031', '112', '26908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MD.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26909', '1079', '1', 'Andrew County', 'US.MO.003', 'ASCII:Andrew County;ID:4374849', '25032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25032', '112', '26909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26910', '1079', '1', 'Audrain County', 'US.MO.007', 'ASCII:Audrain County;ID:4375346', '25033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25033', '112', '26910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26911', '1079', '1', 'Barry County', 'US.MO.009', 'ASCII:Barry County;ID:4375882', '25034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25034', '112', '26911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26912', '1079', '1', 'Barton County', 'US.MO.011', 'ASCII:Barton County;ID:4375904', '25035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25035', '112', '26912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26913', '1079', '1', 'Bates County', 'US.MO.013', 'ASCII:Bates County;ID:4375954', '25036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25036', '112', '26913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26914', '1079', '1', 'Benton County', 'US.MO.015', 'ASCII:Benton County;ID:4376578', '25037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25037', '112', '26914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26915', '1079', '1', 'Bollinger County', 'US.MO.017', 'ASCII:Bollinger County;ID:4377844', '25038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25038', '112', '26915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26916', '1079', '1', 'Boone County', 'US.MO.019', 'ASCII:Boone County;ID:4377925', '25039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25039', '112', '26916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26917', '1079', '1', 'Buchanan County', 'US.MO.021', 'ASCII:Buchanan County;ID:4378897', '25040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25040', '112', '26917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26918', '1079', '1', 'Butler County', 'US.MO.023', 'ASCII:Butler County;ID:4379332', '25041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25041', '112', '26918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26919', '1079', '1', 'Caldwell County', 'US.MO.025', 'ASCII:Caldwell County;ID:4379520', '25042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25042', '112', '26919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26920', '1079', '1', 'Callaway County', 'US.MO.027', 'ASCII:Callaway County;ID:4379567', '25043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25043', '112', '26920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26921', '1079', '1', 'Camden County', 'US.MO.029', 'ASCII:Camden County;ID:4379625', '25044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25044', '112', '26921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26922', '1079', '1', 'Cape Girardeau County', 'US.MO.031', 'ASCII:Cape Girardeau County;ID:4379968', '25045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25045', '112', '26922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26923', '1079', '1', 'Carroll County', 'US.MO.033', 'ASCII:Carroll County;ID:4380138', '25046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25046', '112', '26923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26924', '1079', '1', 'Carter County', 'US.MO.035', 'ASCII:Carter County;ID:4380170', '25047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25047', '112', '26924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26925', '1079', '1', 'Cass County', 'US.MO.037', 'ASCII:Cass County;ID:4380266', '25048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25048', '112', '26925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26926', '1079', '1', 'Cedar County', 'US.MO.039', 'ASCII:Cedar County;ID:4380498', '25049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25049', '112', '26926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26927', '1079', '1', 'Chariton County', 'US.MO.041', 'ASCII:Chariton County;ID:4380961', '25050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25050', '112', '26927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26928', '1079', '1', 'Christian County', 'US.MO.043', 'ASCII:Christian County;ID:4381179', '25051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25051', '112', '26928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26929', '1079', '1', 'Clay County', 'US.MO.047', 'ASCII:Clay County;ID:4381444', '25052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25052', '112', '26929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26930', '1079', '1', 'Clinton County', 'US.MO.049', 'ASCII:Clinton County;ID:4381646', '25053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25053', '112', '26930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26931', '1079', '1', 'Cole County', 'US.MO.051', 'ASCII:Cole County;ID:4381866', '25054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25054', '112', '26931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26932', '1079', '1', 'Cooper County', 'US.MO.053', 'ASCII:Cooper County;ID:4382297', '25055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25055', '112', '26932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26933', '1079', '1', 'Crawford County', 'US.MO.055', 'ASCII:Crawford County;ID:4382777', '25056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25056', '112', '26933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26934', '1079', '1', 'Dade County', 'US.MO.057', 'ASCII:Dade County;ID:4383206', '25057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25057', '112', '26934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26935', '1079', '1', 'Dallas County', 'US.MO.059', 'ASCII:Dallas County;ID:4383238', '25058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25058', '112', '26935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26936', '1079', '1', 'Daviess County', 'US.MO.061', 'ASCII:Daviess County;ID:4383368', '25059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25059', '112', '26936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26937', '1079', '1', 'DeKalb County', 'US.MO.063', 'ASCII:DeKalb County;ID:4383515', '25060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25060', '112', '26937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26938', '1079', '1', 'Dent County', 'US.MO.065', 'ASCII:Dent County;ID:4383752', '25061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25061', '112', '26938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26939', '1079', '1', 'Douglas County', 'US.MO.067', 'ASCII:Douglas County;ID:4384356', '25062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25062', '112', '26939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26940', '1079', '1', 'Dunklin County', 'US.MO.069', 'ASCII:Dunklin County;ID:4384778', '25063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25063', '112', '26940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26941', '1079', '1', 'Franklin County', 'US.MO.071', 'ASCII:Franklin County;ID:4387172', '25064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25064', '112', '26941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26942', '1079', '1', 'Gasconade County', 'US.MO.073', 'ASCII:Gasconade County;ID:4387701', '25065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25065', '112', '26942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26943', '1079', '1', 'Greene County', 'US.MO.077', 'ASCII:Greene County;ID:4388781', '25066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25066', '112', '26943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26944', '1079', '1', 'Henry County', 'US.MO.083', 'ASCII:Henry County;ID:4390169', '25067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25067', '112', '26944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26945', '1079', '1', 'Hickory County', 'US.MO.085', 'ASCII:Hickory County;ID:4390327', '25068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25068', '112', '26945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26946', '1079', '1', 'Howard County', 'US.MO.089', 'ASCII:Howard County;ID:4391383', '25069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25069', '112', '26946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26947', '1079', '1', 'Howell County', 'US.MO.091', 'ASCII:Howell County;ID:4391410', '25070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25070', '112', '26947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26948', '1079', '1', 'Iron County', 'US.MO.093', 'ASCII:Iron County;ID:4392025', '25071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25071', '112', '26948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26949', '1079', '1', 'Jackson County', 'US.MO.095', 'ASCII:Jackson County;ID:4392183', '25072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25072', '112', '26949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26950', '1079', '1', 'Jasper County', 'US.MO.097', 'ASCII:Jasper County;ID:4392354', '25073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25073', '112', '26950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26951', '1079', '1', 'Jefferson County', 'US.MO.099', 'ASCII:Jefferson County;ID:4392394', '25074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25074', '112', '26951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26952', '1079', '1', 'Johnson County', 'US.MO.101', 'ASCII:Johnson County;ID:4392606', '25075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25075', '112', '26952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26953', '1079', '1', 'Laclede County', 'US.MO.105', 'ASCII:Laclede County;ID:4394029', '25076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25076', '112', '26953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26954', '1079', '1', 'Lafayette County', 'US.MO.107', 'ASCII:Lafayette County;ID:4394055', '25077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25077', '112', '26954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26955', '1079', '1', 'Lawrence County', 'US.MO.109', 'ASCII:Lawrence County;ID:4394702', '25078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25078', '112', '26955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26956', '1079', '1', 'Lincoln County', 'US.MO.113', 'ASCII:Lincoln County;ID:4395330', '25079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25079', '112', '26956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26957', '1079', '1', 'Linn County', 'US.MO.115', 'ASCII:Linn County;ID:4395428', '25080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25080', '112', '26957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26958', '1079', '1', 'Livingston County', 'US.MO.117', 'ASCII:Livingston County;ID:4395900', '25081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25081', '112', '26958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26959', '1079', '1', 'Macon County', 'US.MO.121', 'ASCII:Macon County;ID:4396768', '25082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25082', '112', '26959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26960', '1079', '1', 'Madison County', 'US.MO.123', 'ASCII:Madison County;ID:4396798', '25083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25083', '112', '26960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26961', '1079', '1', 'Maries County', 'US.MO.125', 'ASCII:Maries County;ID:4397100', '25084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25084', '112', '26961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26962', '1079', '1', 'Marion County', 'US.MO.127', 'ASCII:Marion County;ID:4397108', '25085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25085', '112', '26962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26963', '1079', '1', 'McDonald County', 'US.MO.119', 'ASCII:McDonald County;ID:4397698', '25086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25086', '112', '26963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26964', '1079', '1', 'Miller County', 'US.MO.131', 'ASCII:Miller County;ID:4398373', '25087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25087', '112', '26964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26965', '1079', '1', 'Mississippi County', 'US.MO.133', 'ASCII:Mississippi County;ID:4398638', '25088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25088', '112', '26965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26966', '1079', '1', 'Moniteau County', 'US.MO.135', 'ASCII:Moniteau County;ID:4398787', '25089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25089', '112', '26966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26967', '1079', '1', 'Monroe County', 'US.MO.137', 'ASCII:Monroe County;ID:4398864', '25090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25090', '112', '26967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26968', '1079', '1', 'Montgomery County', 'US.MO.139', 'ASCII:Montgomery County;ID:4398895', '25091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25091', '112', '26968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26969', '1079', '1', 'Morgan County', 'US.MO.141', 'ASCII:Morgan County;ID:4399052', '25092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25092', '112', '26969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26970', '1079', '1', 'New Madrid County', 'US.MO.143', 'ASCII:New Madrid County;ID:4400430', '25093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25093', '112', '26970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26971', '1079', '1', 'Newton County', 'US.MO.145', 'ASCII:Newton County;ID:4400561', '25094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25094', '112', '26971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26972', '1079', '1', 'Oregon County', 'US.MO.149', 'ASCII:Oregon County;ID:4402012', '25095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25095', '112', '26972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26973', '1079', '1', 'Osage County', 'US.MO.151', 'ASCII:Osage County;ID:4402051', '25096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25096', '112', '26973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26974', '1079', '1', 'Ozark County', 'US.MO.153', 'ASCII:Ozark County;ID:4402255', '25097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25097', '112', '26974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26975', '1079', '1', 'Pemiscot County', 'US.MO.155', 'ASCII:Pemiscot County;ID:4402864', '25098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25098', '112', '26975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26976', '1079', '1', 'Perry County', 'US.MO.157', 'ASCII:Perry County;ID:4402984', '25099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25099', '112', '26976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26977', '1079', '1', 'Pettis County', 'US.MO.159', 'ASCII:Pettis County;ID:4403095', '25100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25100', '112', '26977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26978', '1079', '1', 'Phelps County', 'US.MO.161', 'ASCII:Phelps County;ID:4403116', '25101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25101', '112', '26978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26979', '1079', '1', 'Pike County', 'US.MO.163', 'ASCII:Pike County;ID:4403228', '25102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25102', '112', '26979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26980', '1079', '1', 'Platte County', 'US.MO.165', 'ASCII:Platte County;ID:4403600', '25103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25103', '112', '26980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26981', '1079', '1', 'Polk County', 'US.MO.167', 'ASCII:Polk County;ID:4404128', '25104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25104', '112', '26981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26982', '1079', '1', 'Pulaski County', 'US.MO.169', 'ASCII:Pulaski County;ID:4404807', '25105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25105', '112', '26982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26983', '1079', '1', 'Ralls County', 'US.MO.173', 'ASCII:Ralls County;ID:4405038', '25106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25106', '112', '26983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26984', '1079', '1', 'Randolph County', 'US.MO.175', 'ASCII:Randolph County;ID:4405082', '25107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25107', '112', '26984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26985', '1079', '1', 'Ray County', 'US.MO.177', 'ASCII:Ray County;ID:4405143', '25108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25108', '112', '26985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26986', '1079', '1', 'Reynolds County', 'US.MO.179', 'ASCII:Reynolds County;ID:4405470', '25109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25109', '112', '26986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26987', '1079', '1', 'Ripley County', 'US.MO.181', 'ASCII:Ripley County;ID:4405720', '25110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25110', '112', '26987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26988', '1079', '1', 'Saint Charles County', 'US.MO.183', 'ASCII:Saint Charles County;ID:4406835', '25111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25111', '112', '26988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26989', '1079', '1', 'Saint Clair County', 'US.MO.185', 'ASCII:Saint Clair County;ID:4406842', '25112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25112', '112', '26989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26990', '1079', '1', 'Saint Francois County', 'US.MO.187', 'ASCII:Saint Francois County;ID:4406884', '25113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25113', '112', '26990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26991', '1079', '1', 'Saint Louis County', 'US.MO.189', 'ASCII:Saint Louis County;ID:4407074', '25114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25114', '112', '26991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26992', '1079', '1', 'City of Saint Louis', 'US.MO.510', 'ASCII:City of Saint Louis;ID:4407084', '25115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25115', '112', '26992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26993', '1079', '1', 'Sainte Genevieve County', 'US.MO.186', 'ASCII:Sainte Genevieve County;ID:4407295', '25116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25116', '112', '26993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26994', '1079', '1', 'Saline County', 'US.MO.195', 'ASCII:Saline County;ID:4407376', '25117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25117', '112', '26994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26995', '1079', '1', 'Scott County', 'US.MO.201', 'ASCII:Scott County;ID:4407901', '25118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25118', '112', '26995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26996', '1079', '1', 'Shannon County', 'US.MO.203', 'ASCII:Shannon County;ID:4408228', '25119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25119', '112', '26996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26997', '1079', '1', 'Shelby County', 'US.MO.205', 'ASCII:Shelby County;ID:4408345', '25120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25120', '112', '26997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26998', '1079', '1', 'Stoddard County', 'US.MO.207', 'ASCII:Stoddard County;ID:4410296', '25121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25121', '112', '26998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('26999', '1079', '1', 'Stone County', 'US.MO.209', 'ASCII:Stone County;ID:4410325', '25122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25122', '112', '26999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27000', '1079', '1', 'Taney County', 'US.MO.213', 'ASCII:Taney County;ID:4411205', '25123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25123', '112', '27000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27001', '1079', '1', 'Texas County', 'US.MO.215', 'ASCII:Texas County;ID:4411468', '25124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25124', '112', '27001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27002', '1079', '1', 'Vernon County', 'US.MO.217', 'ASCII:Vernon County;ID:4413006', '25125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25125', '112', '27002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27003', '1079', '1', 'Warren County', 'US.MO.219', 'ASCII:Warren County;ID:4413583', '25126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25126', '112', '27003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27004', '1079', '1', 'Washington County', 'US.MO.221', 'ASCII:Washington County;ID:4413630', '25127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25127', '112', '27004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27005', '1079', '1', 'Wayne County', 'US.MO.223', 'ASCII:Wayne County;ID:4413797', '25128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25128', '112', '27005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27006', '1079', '1', 'Webster County', 'US.MO.225', 'ASCII:Webster County;ID:4413870', '25129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25129', '112', '27006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27007', '1079', '1', 'Wright County', 'US.MO.229', 'ASCII:Wright County;ID:4415503', '25130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25130', '112', '27007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27008', '1079', '1', 'Adams County', 'US.MS.001', 'ASCII:Adams County;ID:4415912', '25131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25131', '112', '27008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27009', '1079', '1', 'Alcorn County', 'US.MS.003', 'ASCII:Alcorn County;ID:4416012', '25132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25132', '112', '27009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27010', '1079', '1', 'Amite County', 'US.MS.005', 'ASCII:Amite County;ID:4416182', '25133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25133', '112', '27010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27011', '1079', '1', 'Attala County', 'US.MS.007', 'ASCII:Attala County;ID:4416669', '25134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25134', '112', '27011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27012', '1079', '1', 'Benton County', 'US.MS.009', 'ASCII:Benton County;ID:4417738', '25135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25135', '112', '27012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27013', '1079', '1', 'Bolivar County', 'US.MS.011', 'ASCII:Bolivar County;ID:4419012', '25136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25136', '112', '27013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27014', '1079', '1', 'Calhoun County', 'US.MS.013', 'ASCII:Calhoun County;ID:4420309', '25137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25137', '112', '27014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27015', '1079', '1', 'Carroll County', 'US.MS.015', 'ASCII:Carroll County;ID:4420741', '25138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25138', '112', '27015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27016', '1079', '1', 'Chickasaw County', 'US.MS.017', 'ASCII:Chickasaw County;ID:4421449', '25139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25139', '112', '27016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27017', '1079', '1', 'Choctaw County', 'US.MS.019', 'ASCII:Choctaw County;ID:4421547', '25140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25140', '112', '27017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27018', '1079', '1', 'Claiborne County', 'US.MS.021', 'ASCII:Claiborne County;ID:4421859', '25141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25141', '112', '27018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27019', '1079', '1', 'Clarke County', 'US.MS.023', 'ASCII:Clarke County;ID:4421913', '25142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25142', '112', '27019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27020', '1079', '1', 'Clay County', 'US.MS.025', 'ASCII:Clay County;ID:4421964', '25143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25143', '112', '27020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27021', '1079', '1', 'Coahoma County', 'US.MS.027', 'ASCII:Coahoma County;ID:4422178', '25144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25144', '112', '27021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27022', '1079', '1', 'Copiah County', 'US.MS.029', 'ASCII:Copiah County;ID:4422700', '25145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25145', '112', '27022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27023', '1079', '1', 'Covington County', 'US.MS.031', 'ASCII:Covington County;ID:4422907', '25146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25146', '112', '27023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27024', '1079', '1', 'DeSoto County', 'US.MS.033', 'ASCII:DeSoto County;ID:4423655', '25147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25147', '112', '27024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27025', '1079', '1', 'Forrest County', 'US.MS.035', 'ASCII:Forrest County;ID:4426954', '25148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25148', '112', '27025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27026', '1079', '1', 'Franklin County', 'US.MS.037', 'ASCII:Franklin County;ID:4427119', '25149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25149', '112', '27026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27027', '1079', '1', 'George County', 'US.MS.039', 'ASCII:George County;ID:4427592', '25150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25150', '112', '27027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27028', '1079', '1', 'Greene County', 'US.MS.041', 'ASCII:Greene County;ID:4428420', '25151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25151', '112', '27028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27029', '1079', '1', 'Grenada County', 'US.MS.043', 'ASCII:Grenada County;ID:4428541', '25152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25152', '112', '27029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27030', '1079', '1', 'Hancock County', 'US.MS.045', 'ASCII:Hancock County;ID:4428961', '25153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25153', '112', '27030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27031', '1079', '1', 'Harrison County', 'US.MS.047', 'ASCII:Harrison County;ID:4429197', '25154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25154', '112', '27031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27032', '1079', '1', 'Hinds County', 'US.MS.049', 'ASCII:Hinds County;ID:4429877', '25155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25155', '112', '27032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27033', '1079', '1', 'Holmes County', 'US.MS.051', 'ASCII:Holmes County;ID:4430142', '25156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25156', '112', '27033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27034', '1079', '1', 'Humphreys County', 'US.MS.053', 'ASCII:Humphreys County;ID:4430705', '25157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25157', '112', '27034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27035', '1079', '1', 'Issaquena County', 'US.MS.055', 'ASCII:Issaquena County;ID:4431269', '25158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25158', '112', '27035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27036', '1079', '1', 'Itawamba County', 'US.MS.057', 'ASCII:Itawamba County;ID:4431274', '25159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25159', '112', '27036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27037', '1079', '1', 'Jackson County', 'US.MS.059', 'ASCII:Jackson County;ID:4431425', '25160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25160', '112', '27037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27038', '1079', '1', 'Jasper County', 'US.MS.061', 'ASCII:Jasper County;ID:4431565', '25161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25161', '112', '27038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27039', '1079', '1', 'Jefferson County', 'US.MS.063', 'ASCII:Jefferson County;ID:4431608', '25162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25162', '112', '27039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27040', '1079', '1', 'Jefferson Davis County', 'US.MS.065', 'ASCII:Jefferson Davis County;ID:4431611', '25163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25163', '112', '27040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27041', '1079', '1', 'Jones County', 'US.MS.067', 'ASCII:Jones County;ID:4431982', '25164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25164', '112', '27041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27042', '1079', '1', 'Kemper County', 'US.MS.069', 'ASCII:Kemper County;ID:4432218', '25165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25165', '112', '27042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27043', '1079', '1', 'Lafayette County', 'US.MS.071', 'ASCII:Lafayette County;ID:4432670', '25166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25166', '112', '27043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27044', '1079', '1', 'Lamar County', 'US.MS.073', 'ASCII:Lamar County;ID:4432922', '25167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25167', '112', '27044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27045', '1079', '1', 'Lauderdale County', 'US.MS.075', 'ASCII:Lauderdale County;ID:4433028', '25168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25168', '112', '27045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27046', '1079', '1', 'Lawrence County', 'US.MS.077', 'ASCII:Lawrence County;ID:4433059', '25169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25169', '112', '27046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27047', '1079', '1', 'Leake County', 'US.MS.079', 'ASCII:Leake County;ID:4433110', '25170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25170', '112', '27047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27048', '1079', '1', 'Lee County', 'US.MS.081', 'ASCII:Lee County;ID:4433190', '25171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25171', '112', '27048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27049', '1079', '1', 'Leflore County', 'US.MS.083', 'ASCII:Leflore County;ID:4433243', '25172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25172', '112', '27049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27050', '1079', '1', 'Lincoln County', 'US.MS.085', 'ASCII:Lincoln County;ID:4433521', '25173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25173', '112', '27050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27051', '1079', '1', 'Lowndes County', 'US.MS.087', 'ASCII:Lowndes County;ID:4434357', '25174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25174', '112', '27051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27052', '1079', '1', 'Madison County', 'US.MS.089', 'ASCII:Madison County;ID:4434666', '25175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25175', '112', '27052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27053', '1079', '1', 'Marion County', 'US.MS.091', 'ASCII:Marion County;ID:4434905', '25176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25176', '112', '27053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27054', '1079', '1', 'Marshall County', 'US.MS.093', 'ASCII:Marshall County;ID:4434977', '25177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25177', '112', '27054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27055', '1079', '1', 'Montgomery County', 'US.MS.097', 'ASCII:Montgomery County;ID:4436434', '25178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25178', '112', '27055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27056', '1079', '1', 'Monroe County', 'US.MS.095', 'ASCII:Monroe County;ID:4436465', '25179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25179', '112', '27056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27057', '1079', '1', 'Neshoba County', 'US.MS.099', 'ASCII:Neshoba County;ID:4438104', '25180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25180', '112', '27057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27058', '1079', '1', 'Newton County', 'US.MS.101', 'ASCII:Newton County;ID:4438827', '25181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25181', '112', '27058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27059', '1079', '1', 'Noxubee County', 'US.MS.103', 'ASCII:Noxubee County;ID:4439115', '25182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25182', '112', '27059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27060', '1079', '1', 'Oktibbeha County', 'US.MS.105', 'ASCII:Oktibbeha County;ID:4439581', '25183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25183', '112', '27060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27061', '1079', '1', 'Panola County', 'US.MS.107', 'ASCII:Panola County;ID:4440232', '25184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25184', '112', '27061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27062', '1079', '1', 'Pearl River County', 'US.MS.109', 'ASCII:Pearl River County;ID:4440578', '25185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25185', '112', '27062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27063', '1079', '1', 'Perry County', 'US.MS.111', 'ASCII:Perry County;ID:4440794', '25186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25186', '112', '27063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27064', '1079', '1', 'Pike County', 'US.MS.113', 'ASCII:Pike County;ID:4441053', '25187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25187', '112', '27064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27065', '1079', '1', 'Pontotoc County', 'US.MS.115', 'ASCII:Pontotoc County;ID:4442070', '25188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25188', '112', '27065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27066', '1079', '1', 'Prentiss County', 'US.MS.117', 'ASCII:Prentiss County;ID:4442374', '25189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25189', '112', '27066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27067', '1079', '1', 'Quitman County', 'US.MS.119', 'ASCII:Quitman County;ID:4442697', '25190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25190', '112', '27067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27068', '1079', '1', 'Rankin County', 'US.MS.121', 'ASCII:Rankin County;ID:4442841', '25191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25191', '112', '27068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27069', '1079', '1', 'Scott County', 'US.MS.123', 'ASCII:Scott County;ID:4445321', '25192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25192', '112', '27069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27070', '1079', '1', 'Sharkey County', 'US.MS.125', 'ASCII:Sharkey County;ID:4445678', '25193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25193', '112', '27070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27071', '1079', '1', 'Simpson County', 'US.MS.127', 'ASCII:Simpson County;ID:4446158', '25194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25194', '112', '27071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27072', '1079', '1', 'Smith County', 'US.MS.129', 'ASCII:Smith County;ID:4446378', '25195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25195', '112', '27072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27073', '1079', '1', 'Stone County', 'US.MS.131', 'ASCII:Stone County;ID:4447325', '25196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25196', '112', '27073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27074', '1079', '1', 'Sunflower County', 'US.MS.133', 'ASCII:Sunflower County;ID:4447584', '25197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25197', '112', '27074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27075', '1079', '1', 'Tallahatchie County', 'US.MS.135', 'ASCII:Tallahatchie County;ID:4447911', '25198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25198', '112', '27075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27076', '1079', '1', 'Tate County', 'US.MS.137', 'ASCII:Tate County;ID:4447998', '25199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25199', '112', '27076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27077', '1079', '1', 'Tippah County', 'US.MS.139', 'ASCII:Tippah County;ID:4448467', '25200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25200', '112', '27077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27078', '1079', '1', 'Tishomingo County', 'US.MS.141', 'ASCII:Tishomingo County;ID:4448508', '25201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25201', '112', '27078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27079', '1079', '1', 'Tunica County', 'US.MS.143', 'ASCII:Tunica County;ID:4448921', '25202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25202', '112', '27079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27080', '1079', '1', 'Union County', 'US.MS.145', 'ASCII:Union County;ID:4449240', '25203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25203', '112', '27080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27081', '1079', '1', 'Walthall County', 'US.MS.147', 'ASCII:Walthall County;ID:4450205', '25204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25204', '112', '27081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27082', '1079', '1', 'Warren County', 'US.MS.149', 'ASCII:Warren County;ID:4450285', '25205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25205', '112', '27082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27083', '1079', '1', 'Washington County', 'US.MS.151', 'ASCII:Washington County;ID:4450315', '25206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25206', '112', '27083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27084', '1079', '1', 'Wayne County', 'US.MS.153', 'ASCII:Wayne County;ID:4450432', '25207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25207', '112', '27084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27085', '1079', '1', 'Webster County', 'US.MS.155', 'ASCII:Webster County;ID:4450493', '25208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25208', '112', '27085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27086', '1079', '1', 'Wilkinson County', 'US.MS.157', 'ASCII:Wilkinson County;ID:4451213', '25209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25209', '112', '27086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27087', '1079', '1', 'Winston County', 'US.MS.159', 'ASCII:Winston County;ID:4451480', '25210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25210', '112', '27087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27088', '1079', '1', 'Yalobusha County', 'US.MS.161', 'ASCII:Yalobusha County;ID:4451779', '25211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25211', '112', '27088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27089', '1079', '1', 'Yazoo County', 'US.MS.163', 'ASCII:Yazoo County;ID:4451815', '25212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25212', '112', '27089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MS.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27090', '1079', '1', 'Alamance County', 'US.NC.001', 'ASCII:Alamance County;ID:4452290', '25213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25213', '112', '27090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27091', '1079', '1', 'Alexander County', 'US.NC.003', 'ASCII:Alexander County;ID:4452352', '25214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25214', '112', '27091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27092', '1079', '1', 'Alleghany County', 'US.NC.005', 'ASCII:Alleghany County;ID:4452391', '25215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25215', '112', '27092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27093', '1079', '1', 'Anson County', 'US.NC.007', 'ASCII:Anson County;ID:4452708', '25216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25216', '112', '27093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27094', '1079', '1', 'Ashe County', 'US.NC.009', 'ASCII:Ashe County;ID:4453028', '25217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25217', '112', '27094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27095', '1079', '1', 'Avery County', 'US.NC.011', 'ASCII:Avery County;ID:4453232', '25218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25218', '112', '27095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27096', '1079', '1', 'Beaufort County', 'US.NC.013', 'ASCII:Beaufort County;ID:4454373', '25219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25219', '112', '27096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27097', '1079', '1', 'Bertie County', 'US.NC.015', 'ASCII:Bertie County;ID:4455071', '25220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25220', '112', '27097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27098', '1079', '1', 'Bladen County', 'US.NC.017', 'ASCII:Bladen County;ID:4456243', '25221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25221', '112', '27098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27099', '1079', '1', 'Brunswick County', 'US.NC.019', 'ASCII:Brunswick County;ID:4457580', '25222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25222', '112', '27099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27100', '1079', '1', 'Buncombe County', 'US.NC.021', 'ASCII:Buncombe County;ID:4458155', '25223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25223', '112', '27100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27101', '1079', '1', 'Burke County', 'US.NC.023', 'ASCII:Burke County;ID:4458194', '25224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25224', '112', '27101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27102', '1079', '1', 'Cabarrus County', 'US.NC.025', 'ASCII:Cabarrus County;ID:4458491', '25225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25225', '112', '27102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27103', '1079', '1', 'Caldwell County', 'US.NC.027', 'ASCII:Caldwell County;ID:4458601', '25226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25226', '112', '27103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27104', '1079', '1', 'Camden County', 'US.NC.029', 'ASCII:Camden County;ID:4458740', '25227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25227', '112', '27104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27105', '1079', '1', 'Carteret County', 'US.NC.031', 'ASCII:Carteret County;ID:4459410', '25228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25228', '112', '27105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27106', '1079', '1', 'Caswell County', 'US.NC.033', 'ASCII:Caswell County;ID:4459547', '25229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25229', '112', '27106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27107', '1079', '1', 'Catawba County', 'US.NC.035', 'ASCII:Catawba County;ID:4459575', '25230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25230', '112', '27107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27108', '1079', '1', 'Chatham County', 'US.NC.037', 'ASCII:Chatham County;ID:4460324', '25231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25231', '112', '27108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27109', '1079', '1', 'Cherokee County', 'US.NC.039', 'ASCII:Cherokee County;ID:4460366', '25232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25232', '112', '27109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27110', '1079', '1', 'Chowan County', 'US.NC.041', 'ASCII:Chowan County;ID:4460702', '25233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25233', '112', '27110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27111', '1079', '1', 'Clay County', 'US.NC.043', 'ASCII:Clay County;ID:4460927', '25234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25234', '112', '27111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27112', '1079', '1', 'Cleveland County', 'US.NC.045', 'ASCII:Cleveland County;ID:4461030', '25235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25235', '112', '27112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27113', '1079', '1', 'Columbus County', 'US.NC.047', 'ASCII:Columbus County;ID:4461503', '25236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25236', '112', '27113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27114', '1079', '1', 'Craven County', 'US.NC.049', 'ASCII:Craven County;ID:4462398', '25237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25237', '112', '27114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27115', '1079', '1', 'Cumberland County', 'US.NC.051', 'ASCII:Cumberland County;ID:4462716', '25238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25238', '112', '27115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27116', '1079', '1', 'Currituck County', 'US.NC.053', 'ASCII:Currituck County;ID:4462764', '25239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25239', '112', '27116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27117', '1079', '1', 'Dare County', 'US.NC.055', 'ASCII:Dare County;ID:4462997', '25240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25240', '112', '27117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27118', '1079', '1', 'Davidson County', 'US.NC.057', 'ASCII:Davidson County;ID:4463056', '25241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25241', '112', '27118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27119', '1079', '1', 'Davie County', 'US.NC.059', 'ASCII:Davie County;ID:4463078', '25242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25242', '112', '27119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27120', '1079', '1', 'Duplin County', 'US.NC.061', 'ASCII:Duplin County;ID:4464351', '25243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25243', '112', '27120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27121', '1079', '1', 'Durham County', 'US.NC.063', 'ASCII:Durham County;ID:4464374', '25244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25244', '112', '27121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27122', '1079', '1', 'Edgecombe County', 'US.NC.065', 'ASCII:Edgecombe County;ID:4464909', '25245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25245', '112', '27122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27123', '1079', '1', 'Forsyth County', 'US.NC.067', 'ASCII:Forsyth County;ID:4466900', '25246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25246', '112', '27123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27124', '1079', '1', 'Franklin County', 'US.NC.069', 'ASCII:Franklin County;ID:4467141', '25247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25247', '112', '27124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27125', '1079', '1', 'Gaston County', 'US.NC.071', 'ASCII:Gaston County;ID:4467717', '25248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25248', '112', '27125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27126', '1079', '1', 'Gates County', 'US.NC.073', 'ASCII:Gates County;ID:4467741', '25249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25249', '112', '27126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27127', '1079', '1', 'Graham County', 'US.NC.075', 'ASCII:Graham County;ID:4468538', '25250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25250', '112', '27127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27128', '1079', '1', 'Granville County', 'US.NC.077', 'ASCII:Granville County;ID:4468623', '25251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25251', '112', '27128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27129', '1079', '1', 'Greene County', 'US.NC.079', 'ASCII:Greene County;ID:4469093', '25252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25252', '112', '27129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27130', '1079', '1', 'Guilford County', 'US.NC.081', 'ASCII:Guilford County;ID:4469393', '25253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25253', '112', '27130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27131', '1079', '1', 'Halifax County', 'US.NC.083', 'ASCII:Halifax County;ID:4469619', '25254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25254', '112', '27131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27132', '1079', '1', 'Harnett County', 'US.NC.085', 'ASCII:Harnett County;ID:4470002', '25255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25255', '112', '27132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27133', '1079', '1', 'Haywood County', 'US.NC.087', 'ASCII:Haywood County;ID:4470398', '25256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25256', '112', '27133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27134', '1079', '1', 'Henderson County', 'US.NC.089', 'ASCII:Henderson County;ID:4470576', '25257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25257', '112', '27134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27135', '1079', '1', 'Hertford County', 'US.NC.091', 'ASCII:Hertford County;ID:4470729', '25258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25258', '112', '27135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27136', '1079', '1', 'Hoke County', 'US.NC.093', 'ASCII:Hoke County;ID:4471487', '25259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25259', '112', '27136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27137', '1079', '1', 'Hyde County', 'US.NC.095', 'ASCII:Hyde County;ID:4472505', '25260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25260', '112', '27137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27138', '1079', '1', 'Iredell County', 'US.NC.097', 'ASCII:Iredell County;ID:4472769', '25261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25261', '112', '27138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27139', '1079', '1', 'Jackson County', 'US.NC.099', 'ASCII:Jackson County;ID:4473029', '25262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25262', '112', '27139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27140', '1079', '1', 'Johnston County', 'US.NC.101', 'ASCII:Johnston County;ID:4473631', '25263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25263', '112', '27140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27141', '1079', '1', 'Jones County', 'US.NC.103', 'ASCII:Jones County;ID:4473713', '25264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25264', '112', '27141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27142', '1079', '1', 'Lee County', 'US.NC.105', 'ASCII:Lee County;ID:4475520', '25265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25265', '112', '27142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27143', '1079', '1', 'Lenoir County', 'US.NC.107', 'ASCII:Lenoir County;ID:4475647', '25266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25266', '112', '27143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27144', '1079', '1', 'Lincoln County', 'US.NC.109', 'ASCII:Lincoln County;ID:4475969', '25267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25267', '112', '27144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27145', '1079', '1', 'Macon County', 'US.NC.113', 'ASCII:Macon County;ID:4477724', '25268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25268', '112', '27145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27146', '1079', '1', 'Madison County', 'US.NC.115', 'ASCII:Madison County;ID:4477734', '25269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25269', '112', '27146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27147', '1079', '1', 'Martin County', 'US.NC.117', 'ASCII:Martin County;ID:4478142', '25270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25270', '112', '27147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27148', '1079', '1', 'McDowell County', 'US.NC.111', 'ASCII:McDowell County;ID:4478581', '25271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25271', '112', '27148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27149', '1079', '1', 'Mecklenburg County', 'US.NC.119', 'ASCII:Mecklenburg County;ID:4478884', '25272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25272', '112', '27149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27150', '1079', '1', 'Mitchell County', 'US.NC.121', 'ASCII:Mitchell County;ID:4479817', '25273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25273', '112', '27150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27151', '1079', '1', 'Montgomery County', 'US.NC.123', 'ASCII:Montgomery County;ID:4479988', '25274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25274', '112', '27151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27152', '1079', '1', 'Moore County', 'US.NC.125', 'ASCII:Moore County;ID:4480053', '25275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25275', '112', '27152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27153', '1079', '1', 'Nash County', 'US.NC.127', 'ASCII:Nash County;ID:4481511', '25276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25276', '112', '27153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27154', '1079', '1', 'New Hanover County', 'US.NC.129', 'ASCII:New Hanover County;ID:4481757', '25277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25277', '112', '27154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27155', '1079', '1', 'Northampton County', 'US.NC.131', 'ASCII:Northampton County;ID:4482584', '25278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25278', '112', '27155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27156', '1079', '1', 'Onslow County', 'US.NC.133', 'ASCII:Onslow County;ID:4483494', '25279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25279', '112', '27156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27157', '1079', '1', 'Orange County', 'US.NC.135', 'ASCII:Orange County;ID:4483525', '25280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25280', '112', '27157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27158', '1079', '1', 'Pamlico County', 'US.NC.137', 'ASCII:Pamlico County;ID:4483897', '25281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25281', '112', '27158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27159', '1079', '1', 'Pasquotank County', 'US.NC.139', 'ASCII:Pasquotank County;ID:4484186', '25282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25282', '112', '27159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27160', '1079', '1', 'Pender County', 'US.NC.141', 'ASCII:Pender County;ID:4484498', '25283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25283', '112', '27160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27161', '1079', '1', 'Perquimans County', 'US.NC.143', 'ASCII:Perquimans County;ID:4484605', '25284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25284', '112', '27161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27162', '1079', '1', 'Person County', 'US.NC.145', 'ASCII:Person County;ID:4484671', '25285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25285', '112', '27162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27163', '1079', '1', 'Pitt County', 'US.NC.147', 'ASCII:Pitt County;ID:4485631', '25286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25286', '112', '27163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27164', '1079', '1', 'Polk County', 'US.NC.149', 'ASCII:Polk County;ID:4486072', '25287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25287', '112', '27164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27165', '1079', '1', 'Randolph County', 'US.NC.151', 'ASCII:Randolph County;ID:4487127', '25288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25288', '112', '27165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27166', '1079', '1', 'Richmond County', 'US.NC.153', 'ASCII:Richmond County;ID:4487947', '25289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25289', '112', '27166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27167', '1079', '1', 'Robeson County', 'US.NC.155', 'ASCII:Robeson County;ID:4488351', '25290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25290', '112', '27167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27168', '1079', '1', 'Rockingham County', 'US.NC.157', 'ASCII:Rockingham County;ID:4488575', '25291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25291', '112', '27168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27169', '1079', '1', 'Rowan County', 'US.NC.159', 'ASCII:Rowan County;ID:4489163', '25292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25292', '112', '27169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27170', '1079', '1', 'Rutherford County', 'US.NC.161', 'ASCII:Rutherford County;ID:4489357', '25293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25293', '112', '27170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27171', '1079', '1', 'Sampson County', 'US.NC.163', 'ASCII:Sampson County;ID:4490053', '25294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25294', '112', '27171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27172', '1079', '1', 'Scotland County', 'US.NC.165', 'ASCII:Scotland County;ID:4490602', '25295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25295', '112', '27172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27173', '1079', '1', 'Stanly County', 'US.NC.167', 'ASCII:Stanly County;ID:4493238', '25296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25296', '112', '27173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27174', '1079', '1', 'Stokes County', 'US.NC.169', 'ASCII:Stokes County;ID:4493539', '25297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25297', '112', '27174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27175', '1079', '1', 'Surry County', 'US.NC.171', 'ASCII:Surry County;ID:4494132', '25298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25298', '112', '27175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27176', '1079', '1', 'Swain County', 'US.NC.173', 'ASCII:Swain County;ID:4494189', '25299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25299', '112', '27176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27177', '1079', '1', 'Transylvania County', 'US.NC.175', 'ASCII:Transylvania County;ID:4495544', '25300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25300', '112', '27177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27178', '1079', '1', 'Tyrrell County', 'US.NC.177', 'ASCII:Tyrrell County;ID:4496070', '25301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25301', '112', '27178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27179', '1079', '1', 'Union County', 'US.NC.179', 'ASCII:Union County;ID:4496196', '25302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25302', '112', '27179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27180', '1079', '1', 'Vance County', 'US.NC.181', 'ASCII:Vance County;ID:4496539', '25303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25303', '112', '27180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27181', '1079', '1', 'Wake County', 'US.NC.183', 'ASCII:Wake County;ID:4497286', '25304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25304', '112', '27181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27182', '1079', '1', 'Warren County', 'US.NC.185', 'ASCII:Warren County;ID:4497598', '25305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25305', '112', '27182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27183', '1079', '1', 'Washington County', 'US.NC.187', 'ASCII:Washington County;ID:4497673', '25306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25306', '112', '27183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27184', '1079', '1', 'Watauga County', 'US.NC.189', 'ASCII:Watauga County;ID:4497707', '25307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25307', '112', '27184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27185', '1079', '1', 'Wayne County', 'US.NC.191', 'ASCII:Wayne County;ID:4497859', '25308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25308', '112', '27185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27186', '1079', '1', 'Wilkes County', 'US.NC.193', 'ASCII:Wilkes County;ID:4499127', '25309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25309', '112', '27186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27187', '1079', '1', 'Wilson County', 'US.NC.195', 'ASCII:Wilson County;ID:4499428', '25310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25310', '112', '27187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27188', '1079', '1', 'Yadkin County', 'US.NC.197', 'ASCII:Yadkin County;ID:4500134', '25311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25311', '112', '27188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27189', '1079', '1', 'Yancey County', 'US.NC.199', 'ASCII:Yancey County;ID:4500160', '25312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25312', '112', '27189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NC.199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27190', '1079', '1', 'Atlantic County', 'US.NJ.001', 'ASCII:Atlantic County;ID:4500561', '25313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25313', '112', '27190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27191', '1079', '1', 'Burlington County', 'US.NJ.005', 'ASCII:Burlington County;ID:4500994', '25314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25314', '112', '27191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27192', '1079', '1', 'Camden County', 'US.NJ.007', 'ASCII:Camden County;ID:4501019', '25315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25315', '112', '27192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27193', '1079', '1', 'Cape May County', 'US.NJ.009', 'ASCII:Cape May County;ID:4501053', '25316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25316', '112', '27193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27194', '1079', '1', 'Cumberland County', 'US.NJ.011', 'ASCII:Cumberland County;ID:4501427', '25317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25317', '112', '27194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27195', '1079', '1', 'Gloucester County', 'US.NJ.015', 'ASCII:Gloucester County;ID:4501944', '25318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25318', '112', '27195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27196', '1079', '1', 'Ocean County', 'US.NJ.029', 'ASCII:Ocean County;ID:4503355', '25319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25319', '112', '27196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27197', '1079', '1', 'Salem County', 'US.NJ.033', 'ASCII:Salem County;ID:4503949', '25320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25320', '112', '27197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27198', '1079', '1', 'Adams County', 'US.OH.001', 'ASCII:Adams County;ID:4505006', '25321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25321', '112', '27198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27199', '1079', '1', 'Athens County', 'US.OH.009', 'ASCII:Athens County;ID:4505546', '25322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25322', '112', '27199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27200', '1079', '1', 'Brown County', 'US.OH.015', 'ASCII:Brown County;ID:4507215', '25323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25323', '112', '27200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27201', '1079', '1', 'Butler County', 'US.OH.017', 'ASCII:Butler County;ID:4507568', '25324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25324', '112', '27201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27202', '1079', '1', 'Clark County', 'US.OH.023', 'ASCII:Clark County;ID:4508810', '25325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25325', '112', '27202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27203', '1079', '1', 'Clermont County', 'US.OH.025', 'ASCII:Clermont County;ID:4508924', '25326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25326', '112', '27203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27204', '1079', '1', 'Clinton County', 'US.OH.027', 'ASCII:Clinton County;ID:4508988', '25327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25327', '112', '27204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27205', '1079', '1', 'Fairfield County', 'US.OH.045', 'ASCII:Fairfield County;ID:4511295', '25328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25328', '112', '27205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27206', '1079', '1', 'Fayette County', 'US.OH.047', 'ASCII:Fayette County;ID:4511521', '25329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25329', '112', '27206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27207', '1079', '1', 'Franklin County', 'US.OH.049', 'ASCII:Franklin County;ID:4512214', '25330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25330', '112', '27207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27208', '1079', '1', 'Gallia County', 'US.OH.053', 'ASCII:Gallia County;ID:4512438', '25331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25331', '112', '27208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27209', '1079', '1', 'Greene County', 'US.OH.057', 'ASCII:Greene County;ID:4513280', '25332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25332', '112', '27209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27210', '1079', '1', 'Hamilton County', 'US.OH.061', 'ASCII:Hamilton County;ID:4513583', '25333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25333', '112', '27210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27211', '1079', '1', 'Highland County', 'US.OH.071', 'ASCII:Highland County;ID:4514204', '25334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25334', '112', '27211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27212', '1079', '1', 'Hocking County', 'US.OH.073', 'ASCII:Hocking County;ID:4514358', '25335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25335', '112', '27212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27213', '1079', '1', 'Jackson County', 'US.OH.079', 'ASCII:Jackson County;ID:4515328', '25336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25336', '112', '27213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27214', '1079', '1', 'Lawrence County', 'US.OH.087', 'ASCII:Lawrence County;ID:4516351', '25337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25337', '112', '27214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27215', '1079', '1', 'Madison County', 'US.OH.097', 'ASCII:Madison County;ID:4517365', '25338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25338', '112', '27215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27216', '1079', '1', 'Meigs County', 'US.OH.105', 'ASCII:Meigs County;ID:4518038', '25339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25339', '112', '27216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27217', '1079', '1', 'Monroe County', 'US.OH.111', 'ASCII:Monroe County;ID:4518563', '25340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25340', '112', '27217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27218', '1079', '1', 'Montgomery County', 'US.OH.113', 'ASCII:Montgomery County;ID:4518598', '25341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25341', '112', '27218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27219', '1079', '1', 'Morgan County', 'US.OH.115', 'ASCII:Morgan County;ID:4518677', '25342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25342', '112', '27219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27220', '1079', '1', 'Muskingum County', 'US.OH.119', 'ASCII:Muskingum County;ID:4519300', '25343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25343', '112', '27220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27221', '1079', '1', 'Noble County', 'US.OH.121', 'ASCII:Noble County;ID:4519808', '25344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25344', '112', '27221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27222', '1079', '1', 'Perry County', 'US.OH.127', 'ASCII:Perry County;ID:4521093', '25345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25345', '112', '27222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27223', '1079', '1', 'Pickaway County', 'US.OH.129', 'ASCII:Pickaway County;ID:4521196', '25346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25346', '112', '27223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27224', '1079', '1', 'Pike County', 'US.OH.131', 'ASCII:Pike County;ID:4521245', '25347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25347', '112', '27224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27225', '1079', '1', 'Preble County', 'US.OH.135', 'ASCII:Preble County;ID:4521907', '25348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25348', '112', '27225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27226', '1079', '1', 'Ross County', 'US.OH.141', 'ASCII:Ross County;ID:4522889', '25349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25349', '112', '27226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27227', '1079', '1', 'Scioto County', 'US.OH.145', 'ASCII:Scioto County;ID:4524221', '25350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25350', '112', '27227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27228', '1079', '1', 'Vinton County', 'US.OH.163', 'ASCII:Vinton County;ID:4527250', '25351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25351', '112', '27228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27229', '1079', '1', 'Warren County', 'US.OH.165', 'ASCII:Warren County;ID:4527624', '25352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25352', '112', '27229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27230', '1079', '1', 'Washington County', 'US.OH.167', 'ASCII:Washington County;ID:4527654', '25353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25353', '112', '27230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27231', '1079', '1', 'Adair County', 'US.OK.001', 'ASCII:Adair County;ID:4529106', '25354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25354', '112', '27231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27232', '1079', '1', 'Alfalfa County', 'US.OK.003', 'ASCII:Alfalfa County;ID:4529227', '25355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25355', '112', '27232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27233', '1079', '1', 'Atoka County', 'US.OK.005', 'ASCII:Atoka County;ID:4529605', '25356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25356', '112', '27233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27234', '1079', '1', 'Beckham County', 'US.OK.009', 'ASCII:Beckham County;ID:4530237', '25357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25357', '112', '27234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27235', '1079', '1', 'Blaine County', 'US.OK.011', 'ASCII:Blaine County;ID:4530876', '25358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25358', '112', '27235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27236', '1079', '1', 'Bryan County', 'US.OK.013', 'ASCII:Bryan County;ID:4531565', '25359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25359', '112', '27236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27237', '1079', '1', 'Caddo County', 'US.OK.015', 'ASCII:Caddo County;ID:4531901', '25360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25360', '112', '27237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27238', '1079', '1', 'Canadian County', 'US.OK.017', 'ASCII:Canadian County;ID:4532136', '25361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25361', '112', '27238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27239', '1079', '1', 'Carter County', 'US.OK.019', 'ASCII:Carter County;ID:4532398', '25362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25362', '112', '27239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27240', '1079', '1', 'Cherokee County', 'US.OK.021', 'ASCII:Cherokee County;ID:4532932', '25363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25363', '112', '27240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27241', '1079', '1', 'Choctaw County', 'US.OK.023', 'ASCII:Choctaw County;ID:4533135', '25364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25364', '112', '27241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27242', '1079', '1', 'Cleveland County', 'US.OK.027', 'ASCII:Cleveland County;ID:4533690', '25365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25365', '112', '27242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27243', '1079', '1', 'Coal County', 'US.OK.029', 'ASCII:Coal County;ID:4533759', '25366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25366', '112', '27243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27244', '1079', '1', 'Comanche County', 'US.OK.031', 'ASCII:Comanche County;ID:4533932', '25367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25367', '112', '27244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27245', '1079', '1', 'Cotton County', 'US.OK.033', 'ASCII:Cotton County;ID:4534159', '25368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25368', '112', '27245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27246', '1079', '1', 'Craig County', 'US.OK.035', 'ASCII:Craig County;ID:4534416', '25369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25369', '112', '27246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27247', '1079', '1', 'Creek County', 'US.OK.037', 'ASCII:Creek County;ID:4534444', '25370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25370', '112', '27247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27248', '1079', '1', 'Custer County', 'US.OK.039', 'ASCII:Custer County;ID:4534674', '25371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25371', '112', '27248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27249', '1079', '1', 'Delaware County', 'US.OK.041', 'ASCII:Delaware County;ID:4534948', '25372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25372', '112', '27249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27250', '1079', '1', 'Dewey County', 'US.OK.043', 'ASCII:Dewey County;ID:4535054', '25373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25373', '112', '27250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27251', '1079', '1', 'Ellis County', 'US.OK.045', 'ASCII:Ellis County;ID:4535845', '25374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25374', '112', '27251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27252', '1079', '1', 'Garfield County', 'US.OK.047', 'ASCII:Garfield County;ID:4537472', '25375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25375', '112', '27252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27253', '1079', '1', 'Garvin County', 'US.OK.049', 'ASCII:Garvin County;ID:4537513', '25376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25376', '112', '27253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27254', '1079', '1', 'Grady County', 'US.OK.051', 'ASCII:Grady County;ID:4537854', '25377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25377', '112', '27254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27255', '1079', '1', 'Grant County', 'US.OK.053', 'ASCII:Grant County;ID:4537914', '25378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25378', '112', '27255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27256', '1079', '1', 'Greer County', 'US.OK.055', 'ASCII:Greer County;ID:4538074', '25379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25379', '112', '27256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27257', '1079', '1', 'Harmon County', 'US.OK.057', 'ASCII:Harmon County;ID:4538322', '25380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25380', '112', '27257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27258', '1079', '1', 'Harper County', 'US.OK.059', 'ASCII:Harper County;ID:4538342', '25381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25381', '112', '27258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27259', '1079', '1', 'Haskell County', 'US.OK.061', 'ASCII:Haskell County;ID:4538431', '25382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25382', '112', '27259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27260', '1079', '1', 'Hughes County', 'US.OK.063', 'ASCII:Hughes County;ID:4539140', '25383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25383', '112', '27260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27261', '1079', '1', 'Jackson County', 'US.OK.065', 'ASCII:Jackson County;ID:4539499', '25384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25384', '112', '27261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27262', '1079', '1', 'Jefferson County', 'US.OK.067', 'ASCII:Jefferson County;ID:4539571', '25385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25385', '112', '27262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27263', '1079', '1', 'Johnston County', 'US.OK.069', 'ASCII:Johnston County;ID:4539716', '25386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25386', '112', '27263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27264', '1079', '1', 'Kay County', 'US.OK.071', 'ASCII:Kay County;ID:4540074', '25387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25387', '112', '27264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27265', '1079', '1', 'Kingfisher County', 'US.OK.073', 'ASCII:Kingfisher County;ID:4540316', '25388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25388', '112', '27265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27266', '1079', '1', 'Kiowa County', 'US.OK.075', 'ASCII:Kiowa County;ID:4540342', '25389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25389', '112', '27266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27267', '1079', '1', 'Latimer County', 'US.OK.077', 'ASCII:Latimer County;ID:4540696', '25390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25390', '112', '27267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27268', '1079', '1', 'Le Flore County', 'US.OK.079', 'ASCII:Le Flore County;ID:4540759', '25391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25391', '112', '27268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27269', '1079', '1', 'Lincoln County', 'US.OK.081', 'ASCII:Lincoln County;ID:4541067', '25392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25392', '112', '27269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27270', '1079', '1', 'Logan County', 'US.OK.083', 'ASCII:Logan County;ID:4541599', '25393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25393', '112', '27270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27271', '1079', '1', 'Love County', 'US.OK.085', 'ASCII:Love County;ID:4541812', '25394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25394', '112', '27271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27272', '1079', '1', 'Major County', 'US.OK.093', 'ASCII:Major County;ID:4542080', '25395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25395', '112', '27272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27273', '1079', '1', 'Marshall County', 'US.OK.095', 'ASCII:Marshall County;ID:4542194', '25396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25396', '112', '27273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27274', '1079', '1', 'Mayes County', 'US.OK.097', 'ASCII:Mayes County;ID:4542291', '25397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25397', '112', '27274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27275', '1079', '1', 'McClain County', 'US.OK.087', 'ASCII:McClain County;ID:4542393', '25398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25398', '112', '27275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27276', '1079', '1', 'McCurtain County', 'US.OK.089', 'ASCII:McCurtain County;ID:4542417', '25399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25399', '112', '27276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27277', '1079', '1', 'McIntosh County', 'US.OK.091', 'ASCII:McIntosh County;ID:4542456', '25400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25400', '112', '27277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27278', '1079', '1', 'Murray County', 'US.OK.099', 'ASCII:Murray County;ID:4543314', '25401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25401', '112', '27278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27279', '1079', '1', 'Muskogee County', 'US.OK.101', 'ASCII:Muskogee County;ID:4543342', '25402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25402', '112', '27279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27280', '1079', '1', 'Noble County', 'US.OK.103', 'ASCII:Noble County;ID:4543736', '25403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25403', '112', '27280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27281', '1079', '1', 'Nowata County', 'US.OK.105', 'ASCII:Nowata County;ID:4544026', '25404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25404', '112', '27281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27282', '1079', '1', 'Okfuskee County', 'US.OK.107', 'ASCII:Okfuskee County;ID:4544284', '25405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25405', '112', '27282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27283', '1079', '1', 'Oklahoma County', 'US.OK.109', 'ASCII:Oklahoma County;ID:4544356', '25406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25406', '112', '27283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27284', '1079', '1', 'Okmulgee County', 'US.OK.111', 'ASCII:Okmulgee County;ID:4544386', '25407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25407', '112', '27284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27285', '1079', '1', 'Osage County', 'US.OK.113', 'ASCII:Osage County;ID:4547304', '25408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25408', '112', '27285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27286', '1079', '1', 'Ottawa County', 'US.OK.115', 'ASCII:Ottawa County;ID:4547357', '25409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25409', '112', '27286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27287', '1079', '1', 'Pawnee County', 'US.OK.117', 'ASCII:Pawnee County;ID:4547688', '25410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25410', '112', '27287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27288', '1079', '1', 'Payne County', 'US.OK.119', 'ASCII:Payne County;ID:4547701', '25411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25411', '112', '27288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27289', '1079', '1', 'Pittsburg County', 'US.OK.121', 'ASCII:Pittsburg County;ID:4548102', '25412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25412', '112', '27289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27290', '1079', '1', 'Pontotoc County', 'US.OK.123', 'ASCII:Pontotoc County;ID:4548292', '25413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25413', '112', '27290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27291', '1079', '1', 'Pottawatomie County', 'US.OK.125', 'ASCII:Pottawatomie County;ID:4548371', '25414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25414', '112', '27291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27292', '1079', '1', 'Pushmataha County', 'US.OK.127', 'ASCII:Pushmataha County;ID:4548586', '25415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25415', '112', '27292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27293', '1079', '1', 'Roger Mills County', 'US.OK.129', 'ASCII:Roger Mills County;ID:4549635', '25416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25416', '112', '27293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27294', '1079', '1', 'Rogers County', 'US.OK.131', 'ASCII:Rogers County;ID:4549638', '25417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25417', '112', '27294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27295', '1079', '1', 'Seminole County', 'US.OK.133', 'ASCII:Seminole County;ID:4551046', '25418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25418', '112', '27295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27296', '1079', '1', 'Sequoyah County', 'US.OK.135', 'ASCII:Sequoyah County;ID:4551067', '25419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25419', '112', '27296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27297', '1079', '1', 'Stephens County', 'US.OK.137', 'ASCII:Stephens County;ID:4552182', '25420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25420', '112', '27297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27298', '1079', '1', 'Tillman County', 'US.OK.141', 'ASCII:Tillman County;ID:4553073', '25421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25421', '112', '27298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27299', '1079', '1', 'Tulsa County', 'US.OK.143', 'ASCII:Tulsa County;ID:4553440', '25422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25422', '112', '27299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27300', '1079', '1', 'Wagoner County', 'US.OK.145', 'ASCII:Wagoner County;ID:4554551', '25423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25423', '112', '27300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27301', '1079', '1', 'Washington County', 'US.OK.147', 'ASCII:Washington County;ID:4554708', '25424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25424', '112', '27301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27302', '1079', '1', 'Washita County', 'US.OK.149', 'ASCII:Washita County;ID:4554753', '25425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25425', '112', '27302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27303', '1079', '1', 'Woods County', 'US.OK.151', 'ASCII:Woods County;ID:4556038', '25426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25426', '112', '27303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27304', '1079', '1', 'Woodward County', 'US.OK.153', 'ASCII:Woodward County;ID:4556051', '25427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25427', '112', '27304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27305', '1079', '1', 'Adams County', 'US.PA.001', 'ASCII:Adams County;ID:4556228', '25428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25428', '112', '27305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27306', '1079', '1', 'Abbeville County', 'US.SC.001', 'ASCII:Abbeville County;ID:4568959', '25429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25429', '112', '27306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27307', '1079', '1', 'Aiken County', 'US.SC.003', 'ASCII:Aiken County;ID:4569073', '25430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25430', '112', '27307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27308', '1079', '1', 'Allendale County', 'US.SC.005', 'ASCII:Allendale County;ID:4569210', '25431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25431', '112', '27308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27309', '1079', '1', 'Anderson County', 'US.SC.007', 'ASCII:Anderson County;ID:4569313', '25432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25432', '112', '27309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27310', '1079', '1', 'Bamberg County', 'US.SC.009', 'ASCII:Bamberg County;ID:4569930', '25433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25433', '112', '27310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27311', '1079', '1', 'Barnwell County', 'US.SC.011', 'ASCII:Barnwell County;ID:4570020', '25434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25434', '112', '27311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27312', '1079', '1', 'Beaufort County', 'US.SC.013', 'ASCII:Beaufort County;ID:4570292', '25435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25435', '112', '27312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27313', '1079', '1', 'Berkeley County', 'US.SC.015', 'ASCII:Berkeley County;ID:4570707', '25436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25436', '112', '27313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27314', '1079', '1', 'Calhoun County', 'US.SC.017', 'ASCII:Calhoun County;ID:4573075', '25437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25437', '112', '27314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27315', '1079', '1', 'Charleston County', 'US.SC.019', 'ASCII:Charleston County;ID:4574328', '25438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25438', '112', '27315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27316', '1079', '1', 'Cherokee County', 'US.SC.021', 'ASCII:Cherokee County;ID:4574428', '25439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25439', '112', '27316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27317', '1079', '1', 'Chester County', 'US.SC.023', 'ASCII:Chester County;ID:4574531', '25440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25440', '112', '27317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27318', '1079', '1', 'Chesterfield County', 'US.SC.025', 'ASCII:Chesterfield County;ID:4574554', '25441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25441', '112', '27318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27319', '1079', '1', 'Clarendon County', 'US.SC.027', 'ASCII:Clarendon County;ID:4574857', '25442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25442', '112', '27319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27320', '1079', '1', 'Colleton County', 'US.SC.029', 'ASCII:Colleton County;ID:4575230', '25443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25443', '112', '27320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27321', '1079', '1', 'Darlington County', 'US.SC.031', 'ASCII:Darlington County;ID:4576323', '25444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25444', '112', '27321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27322', '1079', '1', 'Dillon County', 'US.SC.033', 'ASCII:Dillon County;ID:4576657', '25445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25445', '112', '27322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27323', '1079', '1', 'Dorchester County', 'US.SC.035', 'ASCII:Dorchester County;ID:4576822', '25446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25446', '112', '27323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27324', '1079', '1', 'Edgefield County', 'US.SC.037', 'ASCII:Edgefield County;ID:4577533', '25447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25447', '112', '27324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27325', '1079', '1', 'Fairfield County', 'US.SC.039', 'ASCII:Fairfield County;ID:4578064', '25448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25448', '112', '27325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27326', '1079', '1', 'Florence County', 'US.SC.041', 'ASCII:Florence County;ID:4578745', '25449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25449', '112', '27326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27327', '1079', '1', 'Georgetown County', 'US.SC.043', 'ASCII:Georgetown County;ID:4579666', '25450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25450', '112', '27327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27328', '1079', '1', 'Greenville County', 'US.SC.045', 'ASCII:Greenville County;ID:4580549', '25451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25451', '112', '27328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27329', '1079', '1', 'Greenwood County', 'US.SC.047', 'ASCII:Greenwood County;ID:4580575', '25452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25452', '112', '27329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27330', '1079', '1', 'Hampton County', 'US.SC.049', 'ASCII:Hampton County;ID:4580988', '25453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25453', '112', '27330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27331', '1079', '1', 'Horry County', 'US.SC.051', 'ASCII:Horry County;ID:4582287', '25454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25454', '112', '27331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27332', '1079', '1', 'Jasper County', 'US.SC.053', 'ASCII:Jasper County;ID:4583318', '25455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25455', '112', '27332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27333', '1079', '1', 'Kershaw County', 'US.SC.055', 'ASCII:Kershaw County;ID:4583989', '25456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25456', '112', '27333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27334', '1079', '1', 'Lancaster County', 'US.SC.057', 'ASCII:Lancaster County;ID:4584561', '25457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25457', '112', '27334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27335', '1079', '1', 'Laurens County', 'US.SC.059', 'ASCII:Laurens County;ID:4584742', '25458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25458', '112', '27335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27336', '1079', '1', 'Lee County', 'US.SC.061', 'ASCII:Lee County;ID:4584845', '25459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25459', '112', '27336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27337', '1079', '1', 'Lexington County', 'US.SC.063', 'ASCII:Lexington County;ID:4585002', '25460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25460', '112', '27337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27338', '1079', '1', 'Marion County', 'US.SC.067', 'ASCII:Marion County;ID:4586272', '25461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25461', '112', '27338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27339', '1079', '1', 'Marlboro County', 'US.SC.069', 'ASCII:Marlboro County;ID:4586301', '25462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25462', '112', '27339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27340', '1079', '1', 'McCormick County', 'US.SC.065', 'ASCII:McCormick County;ID:4586645', '25463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25463', '112', '27340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27341', '1079', '1', 'Newberry County', 'US.SC.071', 'ASCII:Newberry County;ID:4589213', '25464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25464', '112', '27341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27342', '1079', '1', 'Oconee County', 'US.SC.073', 'ASCII:Oconee County;ID:4589892', '25465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25465', '112', '27342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27343', '1079', '1', 'Orangeburg County', 'US.SC.075', 'ASCII:Orangeburg County;ID:4590186', '25466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25466', '112', '27343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27344', '1079', '1', 'Pickens County', 'US.SC.077', 'ASCII:Pickens County;ID:4590954', '25467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25467', '112', '27344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27345', '1079', '1', 'Richland County', 'US.SC.079', 'ASCII:Richland County;ID:4592843', '25468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25468', '112', '27345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27346', '1079', '1', 'Saluda County', 'US.SC.081', 'ASCII:Saluda County;ID:4594698', '25469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25469', '112', '27346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27347', '1079', '1', 'Spartanburg County', 'US.SC.083', 'ASCII:Spartanburg County;ID:4597204', '25470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25470', '112', '27347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27348', '1079', '1', 'Sumter County', 'US.SC.085', 'ASCII:Sumter County;ID:4597954', '25471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25471', '112', '27348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27349', '1079', '1', 'Union County', 'US.SC.087', 'ASCII:Union County;ID:4599283', '25472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25472', '112', '27349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27350', '1079', '1', 'Williamsburg County', 'US.SC.089', 'ASCII:Williamsburg County;ID:4601150', '25473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25473', '112', '27350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27351', '1079', '1', 'York County', 'US.SC.091', 'ASCII:York County;ID:4601709', '25474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25474', '112', '27351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SC.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27352', '1079', '1', 'Anderson County', 'US.TN.001', 'ASCII:Anderson County;ID:4602643', '25475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25475', '112', '27352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27353', '1079', '1', 'Benton County', 'US.TN.005', 'ASCII:Benton County;ID:4605583', '25476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25476', '112', '27353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27354', '1079', '1', 'Bledsoe County', 'US.TN.007', 'ASCII:Bledsoe County;ID:4607097', '25477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25477', '112', '27354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27355', '1079', '1', 'Blount County', 'US.TN.009', 'ASCII:Blount County;ID:4607192', '25478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25478', '112', '27355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27356', '1079', '1', 'Bradley County', 'US.TN.011', 'ASCII:Bradley County;ID:4608185', '25479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25479', '112', '27356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27357', '1079', '1', 'Cannon County', 'US.TN.015', 'ASCII:Cannon County;ID:4611179', '25480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25480', '112', '27357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27358', '1079', '1', 'Carroll County', 'US.TN.017', 'ASCII:Carroll County;ID:4611490', '25481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25481', '112', '27358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27359', '1079', '1', 'Carter County', 'US.TN.019', 'ASCII:Carter County;ID:4611599', '25482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25482', '112', '27359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27360', '1079', '1', 'Cheatham County', 'US.TN.021', 'ASCII:Cheatham County;ID:4612891', '25483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25483', '112', '27360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27361', '1079', '1', 'Chester County', 'US.TN.023', 'ASCII:Chester County;ID:4613057', '25484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25484', '112', '27361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27362', '1079', '1', 'Claiborne County', 'US.TN.025', 'ASCII:Claiborne County;ID:4613750', '25485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25485', '112', '27362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27363', '1079', '1', 'Clay County', 'US.TN.027', 'ASCII:Clay County;ID:4613912', '25486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25486', '112', '27363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27364', '1079', '1', 'Cocke County', 'US.TN.029', 'ASCII:Cocke County;ID:4614441', '25487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25487', '112', '27364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27365', '1079', '1', 'Coffee County', 'US.TN.031', 'ASCII:Coffee County;ID:4614466', '25488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25488', '112', '27365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27366', '1079', '1', 'Crockett County', 'US.TN.033', 'ASCII:Crockett County;ID:4616263', '25489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25489', '112', '27366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27367', '1079', '1', 'Cumberland County', 'US.TN.035', 'ASCII:Cumberland County;ID:4616678', '25490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25490', '112', '27367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27368', '1079', '1', 'Davidson County', 'US.TN.037', 'ASCII:Davidson County;ID:4617305', '25491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25491', '112', '27368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27369', '1079', '1', 'DeKalb County', 'US.TN.041', 'ASCII:DeKalb County;ID:4617573', '25492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25492', '112', '27369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27370', '1079', '1', 'Decatur County', 'US.TN.039', 'ASCII:Decatur County;ID:4617654', '25493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25493', '112', '27370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27371', '1079', '1', 'Dickson County', 'US.TN.043', 'ASCII:Dickson County;ID:4618068', '25494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25494', '112', '27371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27372', '1079', '1', 'Dyer County', 'US.TN.045', 'ASCII:Dyer County;ID:4619773', '25495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25495', '112', '27372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27373', '1079', '1', 'Fayette County', 'US.TN.047', 'ASCII:Fayette County;ID:4621908', '25496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25496', '112', '27373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27374', '1079', '1', 'Fentress County', 'US.TN.049', 'ASCII:Fentress County;ID:4621984', '25497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25497', '112', '27374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27375', '1079', '1', 'Franklin County', 'US.TN.051', 'ASCII:Franklin County;ID:4623574', '25498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25498', '112', '27375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27376', '1079', '1', 'Gibson County', 'US.TN.053', 'ASCII:Gibson County;ID:4624666', '25499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25499', '112', '27376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27377', '1079', '1', 'Giles County', 'US.TN.055', 'ASCII:Giles County;ID:4624737', '25500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25500', '112', '27377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27378', '1079', '1', 'Grainger County', 'US.TN.057', 'ASCII:Grainger County;ID:4625620', '25501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25501', '112', '27378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27379', '1079', '1', 'Greene County', 'US.TN.059', 'ASCII:Greene County;ID:4626324', '25502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25502', '112', '27379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27380', '1079', '1', 'Grundy County', 'US.TN.061', 'ASCII:Grundy County;ID:4626743', '25503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25503', '112', '27380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27381', '1079', '1', 'Hamblen County', 'US.TN.063', 'ASCII:Hamblen County;ID:4627251', '25504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25504', '112', '27381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27382', '1079', '1', 'Hamilton County', 'US.TN.065', 'ASCII:Hamilton County;ID:4627306', '25505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25505', '112', '27382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27383', '1079', '1', 'Hancock County', 'US.TN.067', 'ASCII:Hancock County;ID:4627427', '25506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25506', '112', '27383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27384', '1079', '1', 'Hardeman County', 'US.TN.069', 'ASCII:Hardeman County;ID:4627590', '25507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25507', '112', '27384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27385', '1079', '1', 'Hardin County', 'US.TN.071', 'ASCII:Hardin County;ID:4627625', '25508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25508', '112', '27385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27386', '1079', '1', 'Hawkins County', 'US.TN.073', 'ASCII:Hawkins County;ID:4628325', '25509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25509', '112', '27386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27387', '1079', '1', 'Haywood County', 'US.TN.075', 'ASCII:Haywood County;ID:4628456', '25510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25510', '112', '27387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27388', '1079', '1', 'Henderson County', 'US.TN.077', 'ASCII:Henderson County;ID:4628715', '25511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25511', '112', '27388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27389', '1079', '1', 'Henry County', 'US.TN.079', 'ASCII:Henry County;ID:4628829', '25512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25512', '112', '27389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27390', '1079', '1', 'Hickman County', 'US.TN.081', 'ASCII:Hickman County;ID:4629047', '25513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25513', '112', '27390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27391', '1079', '1', 'Houston County', 'US.TN.083', 'ASCII:Houston County;ID:4630950', '25514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25514', '112', '27391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27392', '1079', '1', 'Humphreys County', 'US.TN.085', 'ASCII:Humphreys County;ID:4631309', '25515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25515', '112', '27392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27393', '1079', '1', 'Jackson County', 'US.TN.087', 'ASCII:Jackson County;ID:4632660', '25516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25516', '112', '27393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27394', '1079', '1', 'Jefferson County', 'US.TN.089', 'ASCII:Jefferson County;ID:4632934', '25517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25517', '112', '27394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27395', '1079', '1', 'Johnson County', 'US.TN.091', 'ASCII:Johnson County;ID:4633430', '25518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25518', '112', '27395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27396', '1079', '1', 'Knox County', 'US.TN.093', 'ASCII:Knox County;ID:4634931', '25519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25519', '112', '27396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27397', '1079', '1', 'Lake County', 'US.TN.095', 'ASCII:Lake County;ID:4635138', '25520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25520', '112', '27397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27398', '1079', '1', 'Lauderdale County', 'US.TN.097', 'ASCII:Lauderdale County;ID:4635615', '25521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25521', '112', '27398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27399', '1079', '1', 'Lawrence County', 'US.TN.099', 'ASCII:Lawrence County;ID:4635830', '25522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25522', '112', '27399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27400', '1079', '1', 'Lewis County', 'US.TN.101', 'ASCII:Lewis County;ID:4636403', '25523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25523', '112', '27400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27401', '1079', '1', 'Lincoln County', 'US.TN.103', 'ASCII:Lincoln County;ID:4636884', '25524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25524', '112', '27401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27402', '1079', '1', 'Loudon County', 'US.TN.105', 'ASCII:Loudon County;ID:4638283', '25525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25525', '112', '27402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27403', '1079', '1', 'Macon County', 'US.TN.111', 'ASCII:Macon County;ID:4638991', '25526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25526', '112', '27403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27404', '1079', '1', 'Madison County', 'US.TN.113', 'ASCII:Madison County;ID:4639045', '25527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25527', '112', '27404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27405', '1079', '1', 'Marion County', 'US.TN.115', 'ASCII:Marion County;ID:4639514', '25528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25528', '112', '27405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27406', '1079', '1', 'Marshall County', 'US.TN.117', 'ASCII:Marshall County;ID:4639630', '25529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25529', '112', '27406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27407', '1079', '1', 'Maury County', 'US.TN.119', 'ASCII:Maury County;ID:4640041', '25530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25530', '112', '27407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27408', '1079', '1', 'McMinn County', 'US.TN.107', 'ASCII:McMinn County;ID:4640873', '25531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25531', '112', '27408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27409', '1079', '1', 'McNairy County', 'US.TN.109', 'ASCII:McNairy County;ID:4640921', '25532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25532', '112', '27409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27410', '1079', '1', 'Meigs County', 'US.TN.121', 'ASCII:Meigs County;ID:4641148', '25533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25533', '112', '27410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27411', '1079', '1', 'Monroe County', 'US.TN.123', 'ASCII:Monroe County;ID:4642365', '25534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25534', '112', '27411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27412', '1079', '1', 'Montgomery County', 'US.TN.125', 'ASCII:Montgomery County;ID:4642445', '25535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25535', '112', '27412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27413', '1079', '1', 'Moore County', 'US.TN.127', 'ASCII:Moore County;ID:4642600', '25536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25536', '112', '27413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27414', '1079', '1', 'Morgan County', 'US.TN.129', 'ASCII:Morgan County;ID:4642752', '25537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25537', '112', '27414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27415', '1079', '1', 'Obion County', 'US.TN.131', 'ASCII:Obion County;ID:4646779', '25538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25538', '112', '27415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27416', '1079', '1', 'Overton County', 'US.TN.133', 'ASCII:Overton County;ID:4647552', '25539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25539', '112', '27416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27417', '1079', '1', 'Perry County', 'US.TN.135', 'ASCII:Perry County;ID:4648830', '25540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25540', '112', '27417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27418', '1079', '1', 'Pickett County', 'US.TN.137', 'ASCII:Pickett County;ID:4649175', '25541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25541', '112', '27418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27419', '1079', '1', 'Polk County', 'US.TN.139', 'ASCII:Polk County;ID:4650495', '25542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25542', '112', '27419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27420', '1079', '1', 'Putnam County', 'US.TN.141', 'ASCII:Putnam County;ID:4651744', '25543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25543', '112', '27420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27421', '1079', '1', 'Rhea County', 'US.TN.143', 'ASCII:Rhea County;ID:4652809', '25544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25544', '112', '27421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27422', '1079', '1', 'Roane County', 'US.TN.145', 'ASCII:Roane County;ID:4653455', '25545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25545', '112', '27422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27423', '1079', '1', 'Robertson County', 'US.TN.147', 'ASCII:Robertson County;ID:4653638', '25546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25546', '112', '27423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27424', '1079', '1', 'Rutherford County', 'US.TN.149', 'ASCII:Rutherford County;ID:4654962', '25547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25547', '112', '27424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27425', '1079', '1', 'Scott County', 'US.TN.151', 'ASCII:Scott County;ID:4656214', '25548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25548', '112', '27425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27426', '1079', '1', 'Sequatchie County', 'US.TN.153', 'ASCII:Sequatchie County;ID:4656461', '25549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25549', '112', '27426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27427', '1079', '1', 'Sevier County', 'US.TN.155', 'ASCII:Sevier County;ID:4656568', '25550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25550', '112', '27427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27428', '1079', '1', 'Shelby County', 'US.TN.157', 'ASCII:Shelby County;ID:4657046', '25551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25551', '112', '27428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27429', '1079', '1', 'Smith County', 'US.TN.159', 'ASCII:Smith County;ID:4658423', '25552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25552', '112', '27429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27430', '1079', '1', 'Stewart County', 'US.TN.161', 'ASCII:Stewart County;ID:4660056', '25553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25553', '112', '27430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27431', '1079', '1', 'Sullivan County', 'US.TN.163', 'ASCII:Sullivan County;ID:4660813', '25554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25554', '112', '27431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27432', '1079', '1', 'Sumner County', 'US.TN.165', 'ASCII:Sumner County;ID:4661017', '25555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25555', '112', '27432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27433', '1079', '1', 'Tipton County', 'US.TN.167', 'ASCII:Tipton County;ID:4662784', '25556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25556', '112', '27433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27434', '1079', '1', 'Trousdale County', 'US.TN.169', 'ASCII:Trousdale County;ID:4663355', '25557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25557', '112', '27434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27435', '1079', '1', 'Unicoi County', 'US.TN.171', 'ASCII:Unicoi County;ID:4663934', '25558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25558', '112', '27435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27436', '1079', '1', 'Union County', 'US.TN.173', 'ASCII:Union County;ID:4664043', '25559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25559', '112', '27436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27437', '1079', '1', 'Van Buren County', 'US.TN.175', 'ASCII:Van Buren County;ID:4664489', '25560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25560', '112', '27437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27438', '1079', '1', 'Warren County', 'US.TN.177', 'ASCII:Warren County;ID:4665884', '25561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25561', '112', '27438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27439', '1079', '1', 'Washington County', 'US.TN.179', 'ASCII:Washington County;ID:4665975', '25562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25562', '112', '27439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27440', '1079', '1', 'Wayne County', 'US.TN.181', 'ASCII:Wayne County;ID:4666233', '25563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25563', '112', '27440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27441', '1079', '1', 'Weakley County', 'US.TN.183', 'ASCII:Weakley County;ID:4666265', '25564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25564', '112', '27441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27442', '1079', '1', 'White County', 'US.TN.185', 'ASCII:White County;ID:4667226', '25565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25565', '112', '27442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27443', '1079', '1', 'Williamson County', 'US.TN.187', 'ASCII:Williamson County;ID:4668054', '25566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25566', '112', '27443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27444', '1079', '1', 'Wilson County', 'US.TN.189', 'ASCII:Wilson County;ID:4668271', '25567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25567', '112', '27444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27445', '1079', '1', 'Anderson County', 'US.TX.001', 'ASCII:Anderson County;ID:4670756', '25568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25568', '112', '27445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27446', '1079', '1', 'Angelina County', 'US.TX.005', 'ASCII:Angelina County;ID:4670841', '25569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25569', '112', '27446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27447', '1079', '1', 'Aransas County', 'US.TX.007', 'ASCII:Aransas County;ID:4671133', '25570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25570', '112', '27447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27448', '1079', '1', 'Archer County', 'US.TX.009', 'ASCII:Archer County;ID:4671180', '25571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25571', '112', '27448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27449', '1079', '1', 'Atascosa County', 'US.TX.013', 'ASCII:Atascosa County;ID:4671531', '25572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25572', '112', '27449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27450', '1079', '1', 'Austin County', 'US.TX.015', 'ASCII:Austin County;ID:4671673', '25573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25573', '112', '27450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27451', '1079', '1', 'Bandera County', 'US.TX.019', 'ASCII:Bandera County;ID:4672172', '25574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25574', '112', '27451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27452', '1079', '1', 'Bastrop County', 'US.TX.021', 'ASCII:Bastrop County;ID:4672581', '25575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25575', '112', '27452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27453', '1079', '1', 'Baylor County', 'US.TX.023', 'ASCII:Baylor County;ID:4672691', '25576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25576', '112', '27453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27454', '1079', '1', 'Bee County', 'US.TX.025', 'ASCII:Bee County;ID:4673147', '25577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25577', '112', '27454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27455', '1079', '1', 'Bell County', 'US.TX.027', 'ASCII:Bell County;ID:4673310', '25578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25578', '112', '27455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27456', '1079', '1', 'Bexar County', 'US.TX.029', 'ASCII:Bexar County;ID:4674023', '25579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25579', '112', '27456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27457', '1079', '1', 'Blanco County', 'US.TX.031', 'ASCII:Blanco County;ID:4674915', '25580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25580', '112', '27457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27458', '1079', '1', 'Bosque County', 'US.TX.035', 'ASCII:Bosque County;ID:4675728', '25581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25581', '112', '27458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27459', '1079', '1', 'Bowie County', 'US.TX.037', 'ASCII:Bowie County;ID:4675805', '25582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25582', '112', '27459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27460', '1079', '1', 'Brazoria County', 'US.TX.039', 'ASCII:Brazoria County;ID:4676137', '25583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25583', '112', '27460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27461', '1079', '1', 'Brazos County', 'US.TX.041', 'ASCII:Brazos County;ID:4676153', '25584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25584', '112', '27461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27462', '1079', '1', 'Brooks County', 'US.TX.047', 'ASCII:Brooks County;ID:4676547', '25585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25585', '112', '27462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27463', '1079', '1', 'Brown County', 'US.TX.049', 'ASCII:Brown County;ID:4676632', '25586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25586', '112', '27463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27464', '1079', '1', 'Burleson County', 'US.TX.051', 'ASCII:Burleson County;ID:4677558', '25587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25587', '112', '27464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27465', '1079', '1', 'Burnet County', 'US.TX.053', 'ASCII:Burnet County;ID:4677612', '25588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25588', '112', '27465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27466', '1079', '1', 'Caldwell County', 'US.TX.055', 'ASCII:Caldwell County;ID:4678113', '25589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25589', '112', '27466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27467', '1079', '1', 'Calhoun County', 'US.TX.057', 'ASCII:Calhoun County;ID:4678165', '25590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25590', '112', '27467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27468', '1079', '1', 'Callahan County', 'US.TX.059', 'ASCII:Callahan County;ID:4678206', '25591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25591', '112', '27468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27469', '1079', '1', 'Cameron County', 'US.TX.061', 'ASCII:Cameron County;ID:4678364', '25592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25592', '112', '27469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27470', '1079', '1', 'Camp County', 'US.TX.063', 'ASCII:Camp County;ID:4678446', '25593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25593', '112', '27470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27471', '1079', '1', 'Cass County', 'US.TX.067', 'ASCII:Cass County;ID:4679435', '25594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25594', '112', '27471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27472', '1079', '1', 'Chambers County', 'US.TX.071', 'ASCII:Chambers County;ID:4680335', '25595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25595', '112', '27472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27473', '1079', '1', 'Cherokee County', 'US.TX.073', 'ASCII:Cherokee County;ID:4680611', '25596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25596', '112', '27473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27474', '1079', '1', 'Clay County', 'US.TX.077', 'ASCII:Clay County;ID:4681782', '25597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25597', '112', '27474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27475', '1079', '1', 'Coleman County', 'US.TX.083', 'ASCII:Coleman County;ID:4682392', '25598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25598', '112', '27475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27476', '1079', '1', 'Collin County', 'US.TX.085', 'ASCII:Collin County;ID:4682500', '25599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25599', '112', '27476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27477', '1079', '1', 'Colorado County', 'US.TX.089', 'ASCII:Colorado County;ID:4682626', '25600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25600', '112', '27477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27478', '1079', '1', 'Comal County', 'US.TX.091', 'ASCII:Comal County;ID:4682688', '25601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25601', '112', '27478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27479', '1079', '1', 'Comanche County', 'US.TX.093', 'ASCII:Comanche County;ID:4682707', '25602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25602', '112', '27479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27480', '1079', '1', 'Concho County', 'US.TX.095', 'ASCII:Concho County;ID:4682862', '25603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25603', '112', '27480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27481', '1079', '1', 'Cooke County', 'US.TX.097', 'ASCII:Cooke County;ID:4683066', '25604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25604', '112', '27481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27482', '1079', '1', 'Coryell County', 'US.TX.099', 'ASCII:Coryell County;ID:4683477', '25605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25605', '112', '27482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27483', '1079', '1', 'Dallas County', 'US.TX.113', 'ASCII:Dallas County;ID:4684904', '25606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25606', '112', '27483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27484', '1079', '1', 'DeWitt County', 'US.TX.123', 'ASCII:DeWitt County;ID:4685527', '25607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25607', '112', '27484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27485', '1079', '1', 'Delta County', 'US.TX.119', 'ASCII:Delta County;ID:4685841', '25608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25608', '112', '27485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27486', '1079', '1', 'Denton County', 'US.TX.121', 'ASCII:Denton County;ID:4685912', '25609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25609', '112', '27486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27487', '1079', '1', 'Dimmit County', 'US.TX.127', 'ASCII:Dimmit County;ID:4686231', '25610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25610', '112', '27487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27488', '1079', '1', 'Duval County', 'US.TX.131', 'ASCII:Duval County;ID:4687437', '25611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25611', '112', '27488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27489', '1079', '1', 'Eastland County', 'US.TX.133', 'ASCII:Eastland County;ID:4688072', '25612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25612', '112', '27489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27490', '1079', '1', 'Ellis County', 'US.TX.139', 'ASCII:Ellis County;ID:4688864', '25613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25613', '112', '27490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27491', '1079', '1', 'Erath County', 'US.TX.143', 'ASCII:Erath County;ID:4689391', '25614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25614', '112', '27491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27492', '1079', '1', 'Falls County', 'US.TX.145', 'ASCII:Falls County;ID:4690103', '25615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25615', '112', '27492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27493', '1079', '1', 'Fannin County', 'US.TX.147', 'ASCII:Fannin County;ID:4690140', '25616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25616', '112', '27493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27494', '1079', '1', 'Fayette County', 'US.TX.149', 'ASCII:Fayette County;ID:4690287', '25617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25617', '112', '27494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27495', '1079', '1', 'Foard County', 'US.TX.155', 'ASCII:Foard County;ID:4691668', '25618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25618', '112', '27495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27496', '1079', '1', 'Fort Bend County', 'US.TX.157', 'ASCII:Fort Bend County;ID:4691851', '25619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25619', '112', '27496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27497', '1079', '1', 'Franklin County', 'US.TX.159', 'ASCII:Franklin County;ID:4692203', '25620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25620', '112', '27497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27498', '1079', '1', 'Freestone County', 'US.TX.161', 'ASCII:Freestone County;ID:4692377', '25621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25621', '112', '27498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27499', '1079', '1', 'Frio County', 'US.TX.163', 'ASCII:Frio County;ID:4692545', '25622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25622', '112', '27499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27500', '1079', '1', 'Galveston County', 'US.TX.167', 'ASCII:Galveston County;ID:4692856', '25623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25623', '112', '27500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27501', '1079', '1', 'Gillespie County', 'US.TX.171', 'ASCII:Gillespie County;ID:4693544', '25624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25624', '112', '27501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27502', '1079', '1', 'Goliad County', 'US.TX.175', 'ASCII:Goliad County;ID:4693922', '25625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25625', '112', '27502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27503', '1079', '1', 'Gonzales County', 'US.TX.177', 'ASCII:Gonzales County;ID:4693951', '25626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25626', '112', '27503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27504', '1079', '1', 'Grayson County', 'US.TX.181', 'ASCII:Grayson County;ID:4694710', '25627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25627', '112', '27504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27505', '1079', '1', 'Gregg County', 'US.TX.183', 'ASCII:Gregg County;ID:4695143', '25628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25628', '112', '27505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27506', '1079', '1', 'Grimes County', 'US.TX.185', 'ASCII:Grimes County;ID:4695236', '25629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25629', '112', '27506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27507', '1079', '1', 'Guadalupe County', 'US.TX.187', 'ASCII:Guadalupe County;ID:4695361', '25630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25630', '112', '27507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27508', '1079', '1', 'Hamilton County', 'US.TX.193', 'ASCII:Hamilton County;ID:4695945', '25631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25631', '112', '27508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27509', '1079', '1', 'Hardeman County', 'US.TX.197', 'ASCII:Hardeman County;ID:4696131', '25632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25632', '112', '27509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27510', '1079', '1', 'Hardin County', 'US.TX.199', 'ASCII:Hardin County;ID:4696143', '25633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25633', '112', '27510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27511', '1079', '1', 'Harris County', 'US.TX.201', 'ASCII:Harris County;ID:4696376', '25634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25634', '112', '27511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27512', '1079', '1', 'Harrison County', 'US.TX.203', 'ASCII:Harrison County;ID:4696450', '25635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25635', '112', '27512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27513', '1079', '1', 'Haskell County', 'US.TX.207', 'ASCII:Haskell County;ID:4696596', '25636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25636', '112', '27513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27514', '1079', '1', 'Hays County', 'US.TX.209', 'ASCII:Hays County;ID:4696788', '25637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25637', '112', '27514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27515', '1079', '1', 'Henderson County', 'US.TX.213', 'ASCII:Henderson County;ID:4697070', '25638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25638', '112', '27515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27516', '1079', '1', 'Hidalgo County', 'US.TX.215', 'ASCII:Hidalgo County;ID:4697444', '25639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25639', '112', '27516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27517', '1079', '1', 'Hill County', 'US.TX.217', 'ASCII:Hill County;ID:4697746', '25640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25640', '112', '27517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27518', '1079', '1', 'Hood County', 'US.TX.221', 'ASCII:Hood County;ID:4698632', '25641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25641', '112', '27518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27519', '1079', '1', 'Hopkins County', 'US.TX.223', 'ASCII:Hopkins County;ID:4698747', '25642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25642', '112', '27519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27520', '1079', '1', 'Houston County', 'US.TX.225', 'ASCII:Houston County;ID:4699084', '25643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25643', '112', '27520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27521', '1079', '1', 'Hunt County', 'US.TX.231', 'ASCII:Hunt County;ID:4699487', '25644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25644', '112', '27521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27522', '1079', '1', 'Jack County', 'US.TX.237', 'ASCII:Jack County;ID:4700414', '25645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25645', '112', '27522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27523', '1079', '1', 'Jackson County', 'US.TX.239', 'ASCII:Jackson County;ID:4700488', '25646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25646', '112', '27523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27524', '1079', '1', 'Jasper County', 'US.TX.241', 'ASCII:Jasper County;ID:4700729', '25647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25647', '112', '27524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27525', '1079', '1', 'Jefferson County', 'US.TX.245', 'ASCII:Jefferson County;ID:4700821', '25648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25648', '112', '27525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27526', '1079', '1', 'Jim Hogg County', 'US.TX.247', 'ASCII:Jim Hogg County;ID:4701059', '25649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25649', '112', '27526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27527', '1079', '1', 'Jim Wells County', 'US.TX.249', 'ASCII:Jim Wells County;ID:4701084', '25650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25650', '112', '27527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27528', '1079', '1', 'Johnson County', 'US.TX.251', 'ASCII:Johnson County;ID:4701348', '25651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25651', '112', '27528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27529', '1079', '1', 'Jones County', 'US.TX.253', 'ASCII:Jones County;ID:4701505', '25652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25652', '112', '27529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27530', '1079', '1', 'Karnes County', 'US.TX.255', 'ASCII:Karnes County;ID:4702669', '25653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25653', '112', '27530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27531', '1079', '1', 'Kaufman County', 'US.TX.257', 'ASCII:Kaufman County;ID:4702735', '25654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25654', '112', '27531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27532', '1079', '1', 'Kendall County', 'US.TX.259', 'ASCII:Kendall County;ID:4702947', '25655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25655', '112', '27532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27533', '1079', '1', 'Kenedy County', 'US.TX.261', 'ASCII:Kenedy County;ID:4702968', '25656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25656', '112', '27533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27534', '1079', '1', 'Kerr County', 'US.TX.265', 'ASCII:Kerr County;ID:4703071', '25657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25657', '112', '27534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27535', '1079', '1', 'Kimble County', 'US.TX.267', 'ASCII:Kimble County;ID:4703256', '25658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25658', '112', '27535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.267» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27536', '1079', '1', 'Kleberg County', 'US.TX.273', 'ASCII:Kleberg County;ID:4703486', '25659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25659', '112', '27536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27537', '1079', '1', 'Knox County', 'US.TX.275', 'ASCII:Knox County;ID:4703582', '25660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25660', '112', '27537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27538', '1079', '1', 'La Salle County', 'US.TX.283', 'ASCII:La Salle County;ID:4704157', '25661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25661', '112', '27538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27539', '1079', '1', 'Lamar County', 'US.TX.277', 'ASCII:Lamar County;ID:4705086', '25662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25662', '112', '27539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27540', '1079', '1', 'Lampasas County', 'US.TX.281', 'ASCII:Lampasas County;ID:4705179', '25663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25663', '112', '27540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27541', '1079', '1', 'Lavaca County', 'US.TX.285', 'ASCII:Lavaca County;ID:4705575', '25664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25664', '112', '27541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27542', '1079', '1', 'Lee County', 'US.TX.287', 'ASCII:Lee County;ID:4705758', '25665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25665', '112', '27542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.287» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27543', '1079', '1', 'Leon County', 'US.TX.289', 'ASCII:Leon County;ID:4705899', '25666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25666', '112', '27543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27544', '1079', '1', 'Liberty County', 'US.TX.291', 'ASCII:Liberty County;ID:4706143', '25667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25667', '112', '27544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27545', '1079', '1', 'Limestone County', 'US.TX.293', 'ASCII:Limestone County;ID:4706335', '25668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25668', '112', '27545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27546', '1079', '1', 'Live Oak County', 'US.TX.297', 'ASCII:Live Oak County;ID:4707076', '25669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25669', '112', '27546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27547', '1079', '1', 'Llano County', 'US.TX.299', 'ASCII:Llano County;ID:4707196', '25670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25670', '112', '27547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.299» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27548', '1079', '1', 'Madison County', 'US.TX.313', 'ASCII:Madison County;ID:4708691', '25671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25671', '112', '27548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27549', '1079', '1', 'Marion County', 'US.TX.315', 'ASCII:Marion County;ID:4709165', '25672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25672', '112', '27549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27550', '1079', '1', 'Mason County', 'US.TX.319', 'ASCII:Mason County;ID:4709509', '25673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25673', '112', '27550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.319» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27551', '1079', '1', 'Matagorda County', 'US.TX.321', 'ASCII:Matagorda County;ID:4709580', '25674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25674', '112', '27551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27552', '1079', '1', 'McCulloch County', 'US.TX.307', 'ASCII:McCulloch County;ID:4709977', '25675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25675', '112', '27552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27553', '1079', '1', 'McLennan County', 'US.TX.309', 'ASCII:McLennan County;ID:4710229', '25676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25676', '112', '27553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27554', '1079', '1', 'McMullen County', 'US.TX.311', 'ASCII:McMullen County;ID:4710259', '25677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25677', '112', '27554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27555', '1079', '1', 'Medina County', 'US.TX.325', 'ASCII:Medina County;ID:4710490', '25678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25678', '112', '27555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.325» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27556', '1079', '1', 'Menard County', 'US.TX.327', 'ASCII:Menard County;ID:4710698', '25679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25679', '112', '27556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27557', '1079', '1', 'Milam County', 'US.TX.331', 'ASCII:Milam County;ID:4711286', '25680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25680', '112', '27557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.331» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27558', '1079', '1', 'Mills County', 'US.TX.333', 'ASCII:Mills County;ID:4711560', '25681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25681', '112', '27558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.333» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27559', '1079', '1', 'Montague County', 'US.TX.337', 'ASCII:Montague County;ID:4711974', '25682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25682', '112', '27559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27560', '1079', '1', 'Montgomery County', 'US.TX.339', 'ASCII:Montgomery County;ID:4712041', '25683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25683', '112', '27560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27561', '1079', '1', 'Morris County', 'US.TX.343', 'ASCII:Morris County;ID:4712390', '25684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25684', '112', '27561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.343» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27562', '1079', '1', 'Nacogdoches County', 'US.TX.347', 'ASCII:Nacogdoches County;ID:4713738', '25685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25685', '112', '27562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27563', '1079', '1', 'Navarro County', 'US.TX.349', 'ASCII:Navarro County;ID:4713849', '25686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25686', '112', '27563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.349» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27564', '1079', '1', 'Newton County', 'US.TX.351', 'ASCII:Newton County;ID:4714720', '25687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25687', '112', '27564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.351» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27565', '1079', '1', 'Nueces County', 'US.TX.355', 'ASCII:Nueces County;ID:4715635', '25688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25688', '112', '27565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.355» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27566', '1079', '1', 'Orange County', 'US.TX.361', 'ASCII:Orange County;ID:4716826', '25689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25689', '112', '27566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27567', '1079', '1', 'Palo Pinto County', 'US.TX.363', 'ASCII:Palo Pinto County;ID:4717377', '25690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25690', '112', '27567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.363» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27568', '1079', '1', 'Panola County', 'US.TX.365', 'ASCII:Panola County;ID:4717434', '25691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25691', '112', '27568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.365» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27569', '1079', '1', 'Parker County', 'US.TX.367', 'ASCII:Parker County;ID:4717644', '25692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25692', '112', '27569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27570', '1079', '1', 'Polk County', 'US.TX.373', 'ASCII:Polk County;ID:4719903', '25693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25693', '112', '27570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.373» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27571', '1079', '1', 'Rains County', 'US.TX.379', 'ASCII:Rains County;ID:4721307', '25694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25694', '112', '27571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.379» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27572', '1079', '1', 'Real County', 'US.TX.385', 'ASCII:Real County;ID:4721747', '25695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25695', '112', '27572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27573', '1079', '1', 'Red River County', 'US.TX.387', 'ASCII:Red River County;ID:4721949', '25696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25696', '112', '27573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.387» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27574', '1079', '1', 'Refugio County', 'US.TX.391', 'ASCII:Refugio County;ID:4722147', '25697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25697', '112', '27574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27575', '1079', '1', 'Robertson County', 'US.TX.395', 'ASCII:Robertson County;ID:4723147', '25698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25698', '112', '27575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.395» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27576', '1079', '1', 'Rockwall County', 'US.TX.397', 'ASCII:Rockwall County;ID:4723410', '25699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25699', '112', '27576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27577', '1079', '1', 'Runnels County', 'US.TX.399', 'ASCII:Runnels County;ID:4724312', '25700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25700', '112', '27577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27578', '1079', '1', 'Rusk County', 'US.TX.401', 'ASCII:Rusk County;ID:4724363', '25701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25701', '112', '27578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27579', '1079', '1', 'Sabine County', 'US.TX.403', 'ASCII:Sabine County;ID:4724540', '25702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25702', '112', '27579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27580', '1079', '1', 'San Augustine County', 'US.TX.405', 'ASCII:San Augustine County;ID:4726259', '25703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25703', '112', '27580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27581', '1079', '1', 'San Jacinto County', 'US.TX.407', 'ASCII:San Jacinto County;ID:4726377', '25704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25704', '112', '27581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27582', '1079', '1', 'San Patricio County', 'US.TX.409', 'ASCII:San Patricio County;ID:4726521', '25705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25705', '112', '27582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27583', '1079', '1', 'San Saba County', 'US.TX.411', 'ASCII:San Saba County;ID:4726585', '25706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25706', '112', '27583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27584', '1079', '1', 'Shackelford County', 'US.TX.417', 'ASCII:Shackelford County;ID:4727962', '25707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25707', '112', '27584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27585', '1079', '1', 'Shelby County', 'US.TX.419', 'ASCII:Shelby County;ID:4728231', '25708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25708', '112', '27585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27586', '1079', '1', 'Smith County', 'US.TX.423', 'ASCII:Smith County;ID:4729130', '25709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25709', '112', '27586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.423» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27587', '1079', '1', 'Somervell County', 'US.TX.425', 'ASCII:Somervell County;ID:4732807', '25710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25710', '112', '27587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.425» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27588', '1079', '1', 'Starr County', 'US.TX.427', 'ASCII:Starr County;ID:4734150', '25711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25711', '112', '27588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.427» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27589', '1079', '1', 'Stephens County', 'US.TX.429', 'ASCII:Stephens County;ID:4734326', '25712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25712', '112', '27589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27590', '1079', '1', 'Tarrant County', 'US.TX.439', 'ASCII:Tarrant County;ID:4735638', '25713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25713', '112', '27590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27591', '1079', '1', 'Taylor County', 'US.TX.441', 'ASCII:Taylor County;ID:4735729', '25714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25714', '112', '27591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27592', '1079', '1', 'Throckmorton County', 'US.TX.447', 'ASCII:Throckmorton County;ID:4736742', '25715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25715', '112', '27592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27593', '1079', '1', 'Titus County', 'US.TX.449', 'ASCII:Titus County;ID:4736982', '25716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25716', '112', '27593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.449» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27594', '1079', '1', 'Travis County', 'US.TX.453', 'ASCII:Travis County;ID:4737316', '25717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25717', '112', '27594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.453» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27595', '1079', '1', 'Trinity County', 'US.TX.455', 'ASCII:Trinity County;ID:4737562', '25718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25718', '112', '27595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27596', '1079', '1', 'Tyler County', 'US.TX.457', 'ASCII:Tyler County;ID:4738216', '25719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25719', '112', '27596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27597', '1079', '1', 'Upshur County', 'US.TX.459', 'ASCII:Upshur County;ID:4738689', '25720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25720', '112', '27597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27598', '1079', '1', 'Uvalde County', 'US.TX.463', 'ASCII:Uvalde County;ID:4738723', '25721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25721', '112', '27598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27599', '1079', '1', 'Van Zandt County', 'US.TX.467', 'ASCII:Van Zandt County;ID:4738915', '25722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25722', '112', '27599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27600', '1079', '1', 'Victoria County', 'US.TX.469', 'ASCII:Victoria County;ID:4739167', '25723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25723', '112', '27600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27601', '1079', '1', 'Walker County', 'US.TX.471', 'ASCII:Walker County;ID:4739690', '25724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25724', '112', '27601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27602', '1079', '1', 'Waller County', 'US.TX.473', 'ASCII:Waller County;ID:4739804', '25725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25725', '112', '27602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27603', '1079', '1', 'Washington County', 'US.TX.477', 'ASCII:Washington County;ID:4740157', '25726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25726', '112', '27603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27604', '1079', '1', 'Webb County', 'US.TX.479', 'ASCII:Webb County;ID:4740399', '25727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25727', '112', '27604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27605', '1079', '1', 'Wharton County', 'US.TX.481', 'ASCII:Wharton County;ID:4741328', '25728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25728', '112', '27605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27606', '1079', '1', 'Wichita County', 'US.TX.485', 'ASCII:Wichita County;ID:4741751', '25729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25729', '112', '27606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27607', '1079', '1', 'Wilbarger County', 'US.TX.487', 'ASCII:Wilbarger County;ID:4741797', '25730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25730', '112', '27607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27608', '1079', '1', 'Willacy County', 'US.TX.489', 'ASCII:Willacy County;ID:4741939', '25731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25731', '112', '27608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27609', '1079', '1', 'Williamson County', 'US.TX.491', 'ASCII:Williamson County;ID:4742143', '25732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25732', '112', '27609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27610', '1079', '1', 'Wilson County', 'US.TX.493', 'ASCII:Wilson County;ID:4742425', '25733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25733', '112', '27610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27611', '1079', '1', 'Wise County', 'US.TX.497', 'ASCII:Wise County;ID:4742676', '25734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25734', '112', '27611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27612', '1079', '1', 'Wood County', 'US.TX.499', 'ASCII:Wood County;ID:4742850', '25735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25735', '112', '27612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27613', '1079', '1', 'Young County', 'US.TX.503', 'ASCII:Young County;ID:4743474', '25736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25736', '112', '27613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27614', '1079', '1', 'Zapata County', 'US.TX.505', 'ASCII:Zapata County;ID:4743577', '25737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25737', '112', '27614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27615', '1079', '1', 'Zavala County', 'US.TX.507', 'ASCII:Zavala County;ID:4743595', '25738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25738', '112', '27615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27616', '1079', '1', 'Accomack County', 'US.VA.001', 'ASCII:Accomack County;ID:4743865', '25739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25739', '112', '27616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27617', '1079', '1', 'Albemarle County', 'US.VA.003', 'ASCII:Albemarle County;ID:4744031', '25740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25740', '112', '27617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27618', '1079', '1', 'City of Alexandria', 'US.VA.510', 'ASCII:City of Alexandria;ID:4744106', '25741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25741', '112', '27618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27619', '1079', '1', 'Alleghany County', 'US.VA.005', 'ASCII:Alleghany County;ID:4744139', '25742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25742', '112', '27619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27620', '1079', '1', 'Amelia County', 'US.VA.007', 'ASCII:Amelia County;ID:4744308', '25743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25743', '112', '27620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27621', '1079', '1', 'Amherst County', 'US.VA.009', 'ASCII:Amherst County;ID:4744328', '25744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25744', '112', '27621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27622', '1079', '1', 'Appomattox County', 'US.VA.011', 'ASCII:Appomattox County;ID:4744616', '25745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25745', '112', '27622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27623', '1079', '1', 'Arlington County', 'US.VA.013', 'ASCII:Arlington County;ID:4744725', '25746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25746', '112', '27623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27624', '1079', '1', 'Augusta County', 'US.VA.015', 'ASCII:Augusta County;ID:4745015', '25747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25747', '112', '27624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27625', '1079', '1', 'Bath County', 'US.VA.017', 'ASCII:Bath County;ID:4745776', '25748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25748', '112', '27625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27626', '1079', '1', 'Bedford County', 'US.VA.019', 'ASCII:Bedford County;ID:4746270', '25749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25749', '112', '27626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27627', '1079', '1', 'City of Bedford', 'US.VA.515', 'ASCII:City of Bedford;ID:4746289', '25750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25750', '112', '27627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27628', '1079', '1', 'Bland County', 'US.VA.021', 'ASCII:Bland County;ID:4747931', '25751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25751', '112', '27628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27629', '1079', '1', 'Botetourt County', 'US.VA.023', 'ASCII:Botetourt County;ID:4748452', '25752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25752', '112', '27629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27630', '1079', '1', 'City of Bristol', 'US.VA.520', 'ASCII:City of Bristol;ID:4749005', '25753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25753', '112', '27630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27631', '1079', '1', 'Brunswick County', 'US.VA.025', 'ASCII:Brunswick County;ID:4749396', '25754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25754', '112', '27631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27632', '1079', '1', 'Buchanan County', 'US.VA.027', 'ASCII:Buchanan County;ID:4749535', '25755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25755', '112', '27632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27633', '1079', '1', 'Buckingham County', 'US.VA.029', 'ASCII:Buckingham County;ID:4749657', '25756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25756', '112', '27633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27634', '1079', '1', 'City of Buena Vista', 'US.VA.530', 'ASCII:City of Buena Vista;ID:4749725', '25757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25757', '112', '27634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27635', '1079', '1', 'Campbell County', 'US.VA.031', 'ASCII:Campbell County;ID:4750738', '25758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25758', '112', '27635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27636', '1079', '1', 'Caroline County', 'US.VA.033', 'ASCII:Caroline County;ID:4751013', '25759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25759', '112', '27636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27637', '1079', '1', 'Carroll County', 'US.VA.035', 'ASCII:Carroll County;ID:4751058', '25760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25760', '112', '27637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27638', '1079', '1', 'Charles City County', 'US.VA.036', 'ASCII:Charles City County;ID:4752002', '25761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25761', '112', '27638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27639', '1079', '1', 'Charlotte County', 'US.VA.037', 'ASCII:Charlotte County;ID:4752025', '25762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25762', '112', '27639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27640', '1079', '1', 'City of Charlottesville', 'US.VA.540', 'ASCII:City of Charlottesville;ID:4752046', '25763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25763', '112', '27640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27641', '1079', '1', 'City of Chesapeake', 'US.VA.550', 'ASCII:City of Chesapeake;ID:4752215', '25764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25764', '112', '27641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27642', '1079', '1', 'Chesterfield County', 'US.VA.041', 'ASCII:Chesterfield County;ID:4752255', '25765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25765', '112', '27642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27643', '1079', '1', 'Clarke County', 'US.VA.043', 'ASCII:Clarke County;ID:4752978', '25766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25766', '112', '27643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27644', '1079', '1', 'City of Colonial Heights', 'US.VA.570', 'ASCII:City of Colonial Heights;ID:4753684', '25767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25767', '112', '27644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27645', '1079', '1', 'City of Covington', 'US.VA.580', 'ASCII:City of Covington;ID:4754373', '25768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25768', '112', '27645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27646', '1079', '1', 'Craig County', 'US.VA.045', 'ASCII:Craig County;ID:4754544', '25769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25769', '112', '27646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27647', '1079', '1', 'Culpeper County', 'US.VA.047', 'ASCII:Culpeper County;ID:4754972', '25770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25770', '112', '27647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27648', '1079', '1', 'Cumberland County', 'US.VA.049', 'ASCII:Cumberland County;ID:4754992', '25771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25771', '112', '27648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27649', '1079', '1', 'City of Danville', 'US.VA.590', 'ASCII:City of Danville;ID:4755298', '25772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25772', '112', '27649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27650', '1079', '1', 'Dickenson County', 'US.VA.051', 'ASCII:Dickenson County;ID:4755865', '25773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25773', '112', '27650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27651', '1079', '1', 'Dinwiddie County', 'US.VA.053', 'ASCII:Dinwiddie County;ID:4755976', '25774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25774', '112', '27651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27652', '1079', '1', 'City of Emporia', 'US.VA.595', 'ASCII:City of Emporia;ID:4757688', '25775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25775', '112', '27652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27653', '1079', '1', 'Essex County', 'US.VA.057', 'ASCII:Essex County;ID:4757844', '25776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25776', '112', '27653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27654', '1079', '1', 'Fairfax County', 'US.VA.059', 'ASCII:Fairfax County;ID:4758041', '25777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25777', '112', '27654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27655', '1079', '1', 'City of Fairfax', 'US.VA.600', 'ASCII:City of Fairfax;ID:4758109', '25778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25778', '112', '27655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27656', '1079', '1', 'City of Falls Church', 'US.VA.610', 'ASCII:City of Falls Church;ID:4758398', '25779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25779', '112', '27656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27657', '1079', '1', 'Fauquier County', 'US.VA.061', 'ASCII:Fauquier County;ID:4758541', '25780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25780', '112', '27657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27658', '1079', '1', 'Floyd County', 'US.VA.063', 'ASCII:Floyd County;ID:4759449', '25781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25781', '112', '27658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27659', '1079', '1', 'Fluvanna County', 'US.VA.065', 'ASCII:Fluvanna County;ID:4759468', '25782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25782', '112', '27659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27660', '1079', '1', 'Franklin County', 'US.VA.067', 'ASCII:Franklin County;ID:4759996', '25783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25783', '112', '27660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27661', '1079', '1', 'City of Franklin', 'US.VA.620', 'ASCII:City of Franklin;ID:4760031', '25784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25784', '112', '27661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27662', '1079', '1', 'Frederick County', 'US.VA.069', 'ASCII:Frederick County;ID:4760052', '25785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25785', '112', '27662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27663', '1079', '1', 'City of Fredericksburg', 'US.VA.630', 'ASCII:City of Fredericksburg;ID:4760084', '25786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25786', '112', '27663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27664', '1079', '1', 'City of Galax', 'US.VA.640', 'ASCII:City of Galax;ID:4760382', '25787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25787', '112', '27664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27665', '1079', '1', 'Giles County', 'US.VA.071', 'ASCII:Giles County;ID:4760832', '25788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25788', '112', '27665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27666', '1079', '1', 'Gloucester County', 'US.VA.073', 'ASCII:Gloucester County;ID:4761164', '25789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25789', '112', '27666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27667', '1079', '1', 'Goochland County', 'US.VA.075', 'ASCII:Goochland County;ID:4761280', '25790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25790', '112', '27667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27668', '1079', '1', 'Grayson County', 'US.VA.077', 'ASCII:Grayson County;ID:4761913', '25791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25791', '112', '27668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27669', '1079', '1', 'Greene County', 'US.VA.079', 'ASCII:Greene County;ID:4762187', '25792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25792', '112', '27669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27670', '1079', '1', 'Greensville County', 'US.VA.081', 'ASCII:Greensville County;ID:4762246', '25793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25793', '112', '27670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27671', '1079', '1', 'Halifax County', 'US.VA.083', 'ASCII:Halifax County;ID:4762757', '25794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25794', '112', '27671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27672', '1079', '1', 'City of Hampton', 'US.VA.650', 'ASCII:City of Hampton;ID:4762929', '25795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25795', '112', '27672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27673', '1079', '1', 'Hanover County', 'US.VA.085', 'ASCII:Hanover County;ID:4762988', '25796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25796', '112', '27673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27674', '1079', '1', 'City of Harrisonburg', 'US.VA.660', 'ASCII:City of Harrisonburg;ID:4763237', '25797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25797', '112', '27674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27675', '1079', '1', 'Henrico County', 'US.VA.087', 'ASCII:Henrico County;ID:4763688', '25798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25798', '112', '27675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27676', '1079', '1', 'Henry County', 'US.VA.089', 'ASCII:Henry County;ID:4763710', '25799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25799', '112', '27676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27677', '1079', '1', 'Highland County', 'US.VA.091', 'ASCII:Highland County;ID:4764100', '25800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25800', '112', '27677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27678', '1079', '1', 'City of Hopewell', 'US.VA.670', 'ASCII:City of Hopewell;ID:4764849', '25801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25801', '112', '27678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27679', '1079', '1', 'Isle of Wight County', 'US.VA.093', 'ASCII:Isle of Wight County;ID:4766205', '25802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25802', '112', '27679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27680', '1079', '1', 'James City County', 'US.VA.095', 'ASCII:James City County;ID:4766447', '25803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25803', '112', '27680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27681', '1079', '1', 'King George County', 'US.VA.099', 'ASCII:King George County;ID:4767772', '25804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25804', '112', '27681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27682', '1079', '1', 'King William County', 'US.VA.101', 'ASCII:King William County;ID:4767790', '25805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25805', '112', '27682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27683', '1079', '1', 'King and Queen County', 'US.VA.097', 'ASCII:King and Queen County;ID:4767793', '25806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25806', '112', '27683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27684', '1079', '1', 'Lancaster County', 'US.VA.103', 'ASCII:Lancaster County;ID:4768515', '25807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25807', '112', '27684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27685', '1079', '1', 'Lee County', 'US.VA.105', 'ASCII:Lee County;ID:4769028', '25808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25808', '112', '27685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27686', '1079', '1', 'City of Lexington', 'US.VA.678', 'ASCII:City of Lexington;ID:4769352', '25809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25809', '112', '27686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.678» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27687', '1079', '1', 'Loudoun County', 'US.VA.107', 'ASCII:Loudoun County;ID:4770746', '25810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25810', '112', '27687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27688', '1079', '1', 'Louisa County', 'US.VA.109', 'ASCII:Louisa County;ID:4770767', '25811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25811', '112', '27688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27689', '1079', '1', 'Lunenburg County', 'US.VA.111', 'ASCII:Lunenburg County;ID:4771000', '25812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25812', '112', '27689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27690', '1079', '1', 'City of Lynchburg', 'US.VA.680', 'ASCII:City of Lynchburg;ID:4771099', '25813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25813', '112', '27690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27691', '1079', '1', 'Madison County', 'US.VA.113', 'ASCII:Madison County;ID:4771240', '25814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25814', '112', '27691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27692', '1079', '1', 'City of Manassas Park', 'US.VA.685', 'ASCII:City of Manassas Park;ID:4771421', '25815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25815', '112', '27692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27693', '1079', '1', 'City of Manassas', 'US.VA.683', 'ASCII:City of Manassas;ID:4771426', '25816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25816', '112', '27693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27694', '1079', '1', 'City of Martinsville', 'US.VA.690', 'ASCII:City of Martinsville;ID:4771819', '25817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25817', '112', '27694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27695', '1079', '1', 'Mathews County', 'US.VA.115', 'ASCII:Mathews County;ID:4771977', '25818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25818', '112', '27695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27696', '1079', '1', 'Mecklenburg County', 'US.VA.117', 'ASCII:Mecklenburg County;ID:4772586', '25819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25819', '112', '27696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27697', '1079', '1', 'Middlesex County', 'US.VA.119', 'ASCII:Middlesex County;ID:4772915', '25820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25820', '112', '27697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27698', '1079', '1', 'Montgomery County', 'US.VA.121', 'ASCII:Montgomery County;ID:4773711', '25821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25821', '112', '27698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27699', '1079', '1', 'Nelson County', 'US.VA.125', 'ASCII:Nelson County;ID:4775610', '25822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25822', '112', '27699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27700', '1079', '1', 'New Kent County', 'US.VA.127', 'ASCII:New Kent County;ID:4775834', '25823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25823', '112', '27700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27701', '1079', '1', 'City of Newport News', 'US.VA.700', 'ASCII:City of Newport News;ID:4776037', '25824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25824', '112', '27701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27702', '1079', '1', 'City of Norfolk', 'US.VA.710', 'ASCII:City of Norfolk;ID:4776242', '25825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25825', '112', '27702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27703', '1079', '1', 'Northampton County', 'US.VA.131', 'ASCII:Northampton County;ID:4776500', '25826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25826', '112', '27703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27704', '1079', '1', 'Northumberland County', 'US.VA.133', 'ASCII:Northumberland County;ID:4776564', '25827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25827', '112', '27704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27705', '1079', '1', 'City of Norton', 'US.VA.720', 'ASCII:City of Norton;ID:4776591', '25828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25828', '112', '27705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27706', '1079', '1', 'Nottoway County', 'US.VA.135', 'ASCII:Nottoway County;ID:4776629', '25829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25829', '112', '27706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27707', '1079', '1', 'Orange County', 'US.VA.137', 'ASCII:Orange County;ID:4777457', '25830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25830', '112', '27707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27708', '1079', '1', 'Page County', 'US.VA.139', 'ASCII:Page County;ID:4777756', '25831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25831', '112', '27708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27709', '1079', '1', 'Patrick County', 'US.VA.141', 'ASCII:Patrick County;ID:4778096', '25832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25832', '112', '27709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27710', '1079', '1', 'City of Petersburg', 'US.VA.730', 'ASCII:City of Petersburg;ID:4778642', '25833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25833', '112', '27710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27711', '1079', '1', 'Pittsylvania County', 'US.VA.143', 'ASCII:Pittsylvania County;ID:4779336', '25834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25834', '112', '27711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27712', '1079', '1', 'City of Poquoson', 'US.VA.735', 'ASCII:City of Poquoson;ID:4779934', '25835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25835', '112', '27712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.735» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27713', '1079', '1', 'City of Portsmouth', 'US.VA.740', 'ASCII:City of Portsmouth;ID:4780019', '25836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25836', '112', '27713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27714', '1079', '1', 'Powhatan County', 'US.VA.145', 'ASCII:Powhatan County;ID:4780225', '25837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25837', '112', '27714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27715', '1079', '1', 'Prince Edward County', 'US.VA.147', 'ASCII:Prince Edward County;ID:4780362', '25838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25838', '112', '27715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27716', '1079', '1', 'Prince George County', 'US.VA.149', 'ASCII:Prince George County;ID:4780374', '25839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25839', '112', '27716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27717', '1079', '1', 'Prince William County', 'US.VA.153', 'ASCII:Prince William County;ID:4780384', '25840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25840', '112', '27717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27718', '1079', '1', 'Pulaski County', 'US.VA.155', 'ASCII:Pulaski County;ID:4780581', '25841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25841', '112', '27718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27719', '1079', '1', 'City of Radford', 'US.VA.750', 'ASCII:City of Radford;ID:4780851', '25842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25842', '112', '27719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.750» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27720', '1079', '1', 'Rappahannock County', 'US.VA.157', 'ASCII:Rappahannock County;ID:4781039', '25843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25843', '112', '27720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27721', '1079', '1', 'Richmond County', 'US.VA.159', 'ASCII:Richmond County;ID:4781725', '25844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25844', '112', '27721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27722', '1079', '1', 'City of Richmond', 'US.VA.760', 'ASCII:City of Richmond;ID:4781756', '25845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25845', '112', '27722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27723', '1079', '1', 'Roanoke County', 'US.VA.161', 'ASCII:Roanoke County;ID:4782181', '25846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25846', '112', '27723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27724', '1079', '1', 'City of Roanoke', 'US.VA.770', 'ASCII:City of Roanoke;ID:4782241', '25847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25847', '112', '27724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.770» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27725', '1079', '1', 'Rockbridge County', 'US.VA.163', 'ASCII:Rockbridge County;ID:4782531', '25848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25848', '112', '27725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27726', '1079', '1', 'Rockingham County', 'US.VA.165', 'ASCII:Rockingham County;ID:4782579', '25849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25849', '112', '27726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27727', '1079', '1', 'Russell County', 'US.VA.167', 'ASCII:Russell County;ID:4783267', '25850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25850', '112', '27727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27728', '1079', '1', 'City of Salem', 'US.VA.775', 'ASCII:City of Salem;ID:4784205', '25851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25851', '112', '27728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.775» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27729', '1079', '1', 'Scott County', 'US.VA.169', 'ASCII:Scott County;ID:4784660', '25852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25852', '112', '27729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27730', '1079', '1', 'Shenandoah County', 'US.VA.171', 'ASCII:Shenandoah County;ID:4785252', '25853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25853', '112', '27730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27731', '1079', '1', 'Smyth County', 'US.VA.173', 'ASCII:Smyth County;ID:4786352', '25854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25854', '112', '27731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27732', '1079', '1', 'Southampton County', 'US.VA.175', 'ASCII:Southampton County;ID:4786735', '25855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25855', '112', '27732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27733', '1079', '1', 'Spotsylvania County', 'US.VA.177', 'ASCII:Spotsylvania County;ID:4786949', '25856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25856', '112', '27733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27734', '1079', '1', 'Stafford County', 'US.VA.179', 'ASCII:Stafford County;ID:4787248', '25857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25857', '112', '27734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27735', '1079', '1', 'City of Staunton', 'US.VA.790', 'ASCII:City of Staunton;ID:4787467', '25858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25858', '112', '27735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.790» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27736', '1079', '1', 'City of Suffolk', 'US.VA.800', 'ASCII:City of Suffolk;ID:4788160', '25859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25859', '112', '27736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.800» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27737', '1079', '1', 'Surry County', 'US.VA.181', 'ASCII:Surry County;ID:4788433', '25860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25860', '112', '27737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27738', '1079', '1', 'Sussex County', 'US.VA.183', 'ASCII:Sussex County;ID:4788448', '25861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25861', '112', '27738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27739', '1079', '1', 'Tazewell County', 'US.VA.185', 'ASCII:Tazewell County;ID:4788970', '25862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25862', '112', '27739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27740', '1079', '1', 'City of Virginia Beach', 'US.VA.810', 'ASCII:City of Virginia Beach;ID:4791271', '25863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25863', '112', '27740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27741', '1079', '1', 'Warren County', 'US.VA.187', 'ASCII:Warren County;ID:4792238', '25864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25864', '112', '27741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27742', '1079', '1', 'Washington County', 'US.VA.191', 'ASCII:Washington County;ID:4792315', '25865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25865', '112', '27742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27743', '1079', '1', 'City of Waynesboro', 'US.VA.820', 'ASCII:City of Waynesboro;ID:4792534', '25866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25866', '112', '27743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27744', '1079', '1', 'Westmoreland County', 'US.VA.193', 'ASCII:Westmoreland County;ID:4793032', '25867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25867', '112', '27744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27745', '1079', '1', 'City of Williamsburg', 'US.VA.830', 'ASCII:City of Williamsburg;ID:4793872', '25868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25868', '112', '27745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27746', '1079', '1', 'City of Winchester', 'US.VA.840', 'ASCII:City of Winchester;ID:4794134', '25869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25869', '112', '27746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.840» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27747', '1079', '1', 'Wise County', 'US.VA.195', 'ASCII:Wise County;ID:4794277', '25870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25870', '112', '27747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27748', '1079', '1', 'Wythe County', 'US.VA.197', 'ASCII:Wythe County;ID:4794827', '25871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25871', '112', '27748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27749', '1079', '1', 'York County', 'US.VA.199', 'ASCII:York County;ID:4794943', '25872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25872', '112', '27749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VA.199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27750', '1079', '1', 'Barbour County', 'US.WV.001', 'ASCII:Barbour County;ID:4797875', '25873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25873', '112', '27750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27751', '1079', '1', 'Berkeley County', 'US.WV.003', 'ASCII:Berkeley County;ID:4798686', '25874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25874', '112', '27751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27752', '1079', '1', 'Boone County', 'US.WV.005', 'ASCII:Boone County;ID:4799815', '25875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25875', '112', '27752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27753', '1079', '1', 'Braxton County', 'US.WV.007', 'ASCII:Braxton County;ID:4800020', '25876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25876', '112', '27753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27754', '1079', '1', 'Cabell County', 'US.WV.011', 'ASCII:Cabell County;ID:4800996', '25877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25877', '112', '27754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27755', '1079', '1', 'Calhoun County', 'US.WV.013', 'ASCII:Calhoun County;ID:4801086', '25878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25878', '112', '27755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27756', '1079', '1', 'Clay County', 'US.WV.015', 'ASCII:Clay County;ID:4802346', '25879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25879', '112', '27756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27757', '1079', '1', 'Doddridge County', 'US.WV.017', 'ASCII:Doddridge County;ID:4804155', '25880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25880', '112', '27757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27758', '1079', '1', 'Fayette County', 'US.WV.019', 'ASCII:Fayette County;ID:4805678', '25881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25881', '112', '27758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27759', '1079', '1', 'Gilmer County', 'US.WV.021', 'ASCII:Gilmer County;ID:4806966', '25882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25882', '112', '27759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27760', '1079', '1', 'Grant County', 'US.WV.023', 'ASCII:Grant County;ID:4807365', '25883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25883', '112', '27760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27761', '1079', '1', 'Greenbrier County', 'US.WV.025', 'ASCII:Greenbrier County;ID:4807600', '25884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25884', '112', '27761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27762', '1079', '1', 'Hampshire County', 'US.WV.027', 'ASCII:Hampshire County;ID:4807996', '25885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25885', '112', '27762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27763', '1079', '1', 'Hardy County', 'US.WV.031', 'ASCII:Hardy County;ID:4808124', '25886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25886', '112', '27763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27764', '1079', '1', 'Harrison County', 'US.WV.033', 'ASCII:Harrison County;ID:4808274', '25887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25887', '112', '27764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27765', '1079', '1', 'Jackson County', 'US.WV.035', 'ASCII:Jackson County;ID:4810022', '25888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25888', '112', '27765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27766', '1079', '1', 'Jefferson County', 'US.WV.037', 'ASCII:Jefferson County;ID:4810162', '25889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25889', '112', '27766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27767', '1079', '1', 'Kanawha County', 'US.WV.039', 'ASCII:Kanawha County;ID:4810630', '25890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25890', '112', '27767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27768', '1079', '1', 'Lewis County', 'US.WV.041', 'ASCII:Lewis County;ID:4811999', '25891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25891', '112', '27768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27769', '1079', '1', 'Lincoln County', 'US.WV.043', 'ASCII:Lincoln County;ID:4812303', '25892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25892', '112', '27769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27770', '1079', '1', 'Logan County', 'US.WV.045', 'ASCII:Logan County;ID:4812863', '25893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25893', '112', '27770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27771', '1079', '1', 'Marion County', 'US.WV.049', 'ASCII:Marion County;ID:4813754', '25894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25894', '112', '27771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27772', '1079', '1', 'Marshall County', 'US.WV.051', 'ASCII:Marshall County;ID:4813820', '25895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25895', '112', '27772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27773', '1079', '1', 'Mason County', 'US.WV.053', 'ASCII:Mason County;ID:4813934', '25896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25896', '112', '27773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27774', '1079', '1', 'McDowell County', 'US.WV.047', 'ASCII:McDowell County;ID:4814188', '25897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25897', '112', '27774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27775', '1079', '1', 'Mercer County', 'US.WV.055', 'ASCII:Mercer County;ID:4814465', '25898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25898', '112', '27775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27776', '1079', '1', 'Mineral County', 'US.WV.057', 'ASCII:Mineral County;ID:4815060', '25899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25899', '112', '27776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27777', '1079', '1', 'Mingo County', 'US.WV.059', 'ASCII:Mingo County;ID:4815072', '25900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25900', '112', '27777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27778', '1079', '1', 'Monongalia County', 'US.WV.061', 'ASCII:Monongalia County;ID:4815207', '25901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25901', '112', '27778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27779', '1079', '1', 'Monroe County', 'US.WV.063', 'ASCII:Monroe County;ID:4815213', '25902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25902', '112', '27779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27780', '1079', '1', 'Morgan County', 'US.WV.065', 'ASCII:Morgan County;ID:4815321', '25903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25903', '112', '27780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27781', '1079', '1', 'Nicholas County', 'US.WV.067', 'ASCII:Nicholas County;ID:4816620', '25904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25904', '112', '27781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27782', '1079', '1', 'Pendleton County', 'US.WV.071', 'ASCII:Pendleton County;ID:4817892', '25905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25905', '112', '27782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27783', '1079', '1', 'Pleasants County', 'US.WV.073', 'ASCII:Pleasants County;ID:4818649', '25906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25906', '112', '27783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27784', '1079', '1', 'Pocahontas County', 'US.WV.075', 'ASCII:Pocahontas County;ID:4818700', '25907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25907', '112', '27784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27785', '1079', '1', 'Preston County', 'US.WV.077', 'ASCII:Preston County;ID:4819019', '25908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25908', '112', '27785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27786', '1079', '1', 'Putnam County', 'US.WV.079', 'ASCII:Putnam County;ID:4819197', '25909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25909', '112', '27786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27787', '1079', '1', 'Raleigh County', 'US.WV.081', 'ASCII:Raleigh County;ID:4819310', '25910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25910', '112', '27787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27788', '1079', '1', 'Randolph County', 'US.WV.083', 'ASCII:Randolph County;ID:4819366', '25911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25911', '112', '27788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27789', '1079', '1', 'Ritchie County', 'US.WV.085', 'ASCII:Ritchie County;ID:4820055', '25912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25912', '112', '27789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27790', '1079', '1', 'Roane County', 'US.WV.087', 'ASCII:Roane County;ID:4820200', '25913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25913', '112', '27790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27791', '1079', '1', 'Summers County', 'US.WV.089', 'ASCII:Summers County;ID:4823985', '25914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25914', '112', '27791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27792', '1079', '1', 'Taylor County', 'US.WV.091', 'ASCII:Taylor County;ID:4824403', '25915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25915', '112', '27792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27793', '1079', '1', 'Tucker County', 'US.WV.093', 'ASCII:Tucker County;ID:4825147', '25916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25916', '112', '27793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27794', '1079', '1', 'Tyler County', 'US.WV.095', 'ASCII:Tyler County;ID:4825407', '25917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25917', '112', '27794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27795', '1079', '1', 'Upshur County', 'US.WV.097', 'ASCII:Upshur County;ID:4825733', '25918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25918', '112', '27795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27796', '1079', '1', 'Wayne County', 'US.WV.099', 'ASCII:Wayne County;ID:4826596', '25919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25919', '112', '27796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27797', '1079', '1', 'Webster County', 'US.WV.101', 'ASCII:Webster County;ID:4826636', '25920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25920', '112', '27797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27798', '1079', '1', 'Wetzel County', 'US.WV.103', 'ASCII:Wetzel County;ID:4826911', '25921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25921', '112', '27798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27799', '1079', '1', 'Wirt County', 'US.WV.105', 'ASCII:Wirt County;ID:4827540', '25922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25922', '112', '27799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27800', '1079', '1', 'Wood County', 'US.WV.107', 'ASCII:Wood County;ID:4827706', '25923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25923', '112', '27800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27801', '1079', '1', 'Wyoming County', 'US.WV.109', 'ASCII:Wyoming County;ID:4827881', '25924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25924', '112', '27801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27802', '1079', '1', 'Bedford County', 'US.TN.003', 'ASCII:Bedford County;ID:4829092', '25925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25925', '112', '27802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TN.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27803', '1079', '1', 'Autauga County', 'US.AL.001', 'ASCII:Autauga County;ID:4830868', '25926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25926', '112', '27803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27804', '1079', '1', 'Baldwin County', 'US.AL.003', 'ASCII:Baldwin County;ID:4831207', '25927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25927', '112', '27804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27805', '1079', '1', 'Barbour County', 'US.AL.005', 'ASCII:Barbour County;ID:4831351', '25928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25928', '112', '27805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AL.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27806', '1079', '1', 'Iowa County', 'US.IA.095', 'ASCII:Iowa County;ID:4831820', '25929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25929', '112', '27806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27807', '1079', '1', 'Fairfield County', 'US.CT.001', 'ASCII:Fairfield County;ID:4834162', '25930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25930', '112', '27807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CT.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27808', '1079', '1', 'Hartford County', 'US.CT.003', 'ASCII:Hartford County;ID:4835806', '25931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25931', '112', '27808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CT.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27809', '1079', '1', 'Litchfield County', 'US.CT.005', 'ASCII:Litchfield County;ID:4837802', '25932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25932', '112', '27809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CT.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27810', '1079', '1', 'Middlesex County', 'US.CT.007', 'ASCII:Middlesex County;ID:4838627', '25933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25933', '112', '27810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CT.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27811', '1079', '1', 'New Haven County', 'US.CT.009', 'ASCII:New Haven County;ID:4839373', '25934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25934', '112', '27811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CT.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27812', '1079', '1', 'New London County', 'US.CT.011', 'ASCII:New London County;ID:4839420', '25935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25935', '112', '27812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CT.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27813', '1079', '1', 'Tolland County', 'US.CT.013', 'ASCII:Tolland County;ID:4844275', '25936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25936', '112', '27813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CT.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27814', '1079', '1', 'Windham County', 'US.CT.015', 'ASCII:Windham County;ID:4845904', '25937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25937', '112', '27814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CT.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27815', '1079', '1', 'Adair County', 'US.IA.001', 'ASCII:Adair County;ID:4846344', '25938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25938', '112', '27815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27816', '1079', '1', 'Adams County', 'US.IA.003', 'ASCII:Adams County;ID:4846362', '25939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25939', '112', '27816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27817', '1079', '1', 'Allamakee County', 'US.IA.005', 'ASCII:Allamakee County;ID:4846643', '25940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25940', '112', '27817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27818', '1079', '1', 'Appanoose County', 'US.IA.007', 'ASCII:Appanoose County;ID:4847063', '25941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25941', '112', '27818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27819', '1079', '1', 'Audubon County', 'US.IA.009', 'ASCII:Audubon County;ID:4847428', '25942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25942', '112', '27819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27820', '1079', '1', 'Benton County', 'US.IA.011', 'ASCII:Benton County;ID:4848237', '25943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25943', '112', '27820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27821', '1079', '1', 'Black Hawk County', 'US.IA.013', 'ASCII:Black Hawk County;ID:4848699', '25944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25944', '112', '27821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27822', '1079', '1', 'Boone County', 'US.IA.015', 'ASCII:Boone County;ID:4849058', '25945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25945', '112', '27822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27823', '1079', '1', 'Bremer County', 'US.IA.017', 'ASCII:Bremer County;ID:4849288', '25946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25946', '112', '27823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27824', '1079', '1', 'Buchanan County', 'US.IA.019', 'ASCII:Buchanan County;ID:4849598', '25947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25947', '112', '27824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27825', '1079', '1', 'Buena Vista County', 'US.IA.021', 'ASCII:Buena Vista County;ID:4849689', '25948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25948', '112', '27825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27826', '1079', '1', 'Butler County', 'US.IA.023', 'ASCII:Butler County;ID:4849935', '25949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25949', '112', '27826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27827', '1079', '1', 'Calhoun County', 'US.IA.025', 'ASCII:Calhoun County;ID:4850031', '25950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25950', '112', '27827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27828', '1079', '1', 'Carroll County', 'US.IA.027', 'ASCII:Carroll County;ID:4850488', '25951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25951', '112', '27828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27829', '1079', '1', 'Cass County', 'US.IA.029', 'ASCII:Cass County;ID:4850583', '25952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25952', '112', '27829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27830', '1079', '1', 'Cedar County', 'US.IA.031', 'ASCII:Cedar County;ID:4850676', '25953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25953', '112', '27830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27831', '1079', '1', 'Cerro Gordo County', 'US.IA.033', 'ASCII:Cerro Gordo County;ID:4851093', '25954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25954', '112', '27831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27832', '1079', '1', 'Cherokee County', 'US.IA.035', 'ASCII:Cherokee County;ID:4851249', '25955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25955', '112', '27832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27833', '1079', '1', 'Chickasaw County', 'US.IA.037', 'ASCII:Chickasaw County;ID:4851303', '25956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25956', '112', '27833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27834', '1079', '1', 'Clarke County', 'US.IA.039', 'ASCII:Clarke County;ID:4851832', '25957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25957', '112', '27834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27835', '1079', '1', 'Clay County', 'US.IA.041', 'ASCII:Clay County;ID:4851866', '25958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25958', '112', '27835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27836', '1079', '1', 'Clayton County', 'US.IA.043', 'ASCII:Clayton County;ID:4851902', '25959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25959', '112', '27836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27837', '1079', '1', 'Clinton County', 'US.IA.045', 'ASCII:Clinton County;ID:4852032', '25960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25960', '112', '27837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27838', '1079', '1', 'Crawford County', 'US.IA.047', 'ASCII:Crawford County;ID:4853012', '25961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25961', '112', '27838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27839', '1079', '1', 'Dallas County', 'US.IA.049', 'ASCII:Dallas County;ID:4853335', '25962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25962', '112', '27839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27840', '1079', '1', 'Davis County', 'US.IA.051', 'ASCII:Davis County;ID:4853465', '25963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25963', '112', '27840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27841', '1079', '1', 'Decatur County', 'US.IA.053', 'ASCII:Decatur County;ID:4853590', '25964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25964', '112', '27841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27842', '1079', '1', 'Delaware County', 'US.IA.055', 'ASCII:Delaware County;ID:4853709', '25965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25965', '112', '27842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27843', '1079', '1', 'Des Moines County', 'US.IA.057', 'ASCII:Des Moines County;ID:4853838', '25966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25966', '112', '27843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27844', '1079', '1', 'Dickinson County', 'US.IA.059', 'ASCII:Dickinson County;ID:4853961', '25967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25967', '112', '27844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27845', '1079', '1', 'Dubuque County', 'US.IA.061', 'ASCII:Dubuque County;ID:4854534', '25968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25968', '112', '27845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27846', '1079', '1', 'Emmet County', 'US.IA.063', 'ASCII:Emmet County;ID:4855587', '25969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25969', '112', '27846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27847', '1079', '1', 'Fayette County', 'US.IA.065', 'ASCII:Fayette County;ID:4856473', '25970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25970', '112', '27847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27848', '1079', '1', 'Floyd County', 'US.IA.067', 'ASCII:Floyd County;ID:4857314', '25971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25971', '112', '27848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27849', '1079', '1', 'Franklin County', 'US.IA.069', 'ASCII:Franklin County;ID:4857648', '25972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25972', '112', '27849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27850', '1079', '1', 'Fremont County', 'US.IA.071', 'ASCII:Fremont County;ID:4857806', '25973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25973', '112', '27850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27851', '1079', '1', 'Greene County', 'US.IA.073', 'ASCII:Greene County;ID:4859214', '25974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25974', '112', '27851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27852', '1079', '1', 'Grundy County', 'US.IA.075', 'ASCII:Grundy County;ID:4859441', '25975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25975', '112', '27852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27853', '1079', '1', 'Guthrie County', 'US.IA.077', 'ASCII:Guthrie County;ID:4859502', '25976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25976', '112', '27853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27854', '1079', '1', 'Hamilton County', 'US.IA.079', 'ASCII:Hamilton County;ID:4859624', '25977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25977', '112', '27854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27855', '1079', '1', 'Hancock County', 'US.IA.081', 'ASCII:Hancock County;ID:4859678', '25978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25978', '112', '27855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27856', '1079', '1', 'Hardin County', 'US.IA.083', 'ASCII:Hardin County;ID:4859771', '25979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25979', '112', '27856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27857', '1079', '1', 'Harrison County', 'US.IA.085', 'ASCII:Harrison County;ID:4859901', '25980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25980', '112', '27857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27858', '1079', '1', 'Henry County', 'US.IA.087', 'ASCII:Henry County;ID:4860353', '25981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25981', '112', '27858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27859', '1079', '1', 'Howard County', 'US.IA.089', 'ASCII:Howard County;ID:4861232', '25982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25982', '112', '27859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27860', '1079', '1', 'Humboldt County', 'US.IA.091', 'ASCII:Humboldt County;ID:4861343', '25983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25983', '112', '27860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27861', '1079', '1', 'Ida County', 'US.IA.093', 'ASCII:Ida County;ID:4861459', '25984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25984', '112', '27861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27862', '1079', '1', 'Jackson County', 'US.IA.097', 'ASCII:Jackson County;ID:4862320', '25985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25985', '112', '27862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27863', '1079', '1', 'Jasper County', 'US.IA.099', 'ASCII:Jasper County;ID:4862456', '25986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25986', '112', '27863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27864', '1079', '1', 'Jefferson County', 'US.IA.101', 'ASCII:Jefferson County;ID:4862494', '25987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25987', '112', '27864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27865', '1079', '1', 'Johnson County', 'US.IA.103', 'ASCII:Johnson County;ID:4862732', '25988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25988', '112', '27865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27866', '1079', '1', 'Jones County', 'US.IA.105', 'ASCII:Jones County;ID:4862800', '25989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25989', '112', '27866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27867', '1079', '1', 'Keokuk County', 'US.IA.107', 'ASCII:Keokuk County;ID:4863357', '25990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25990', '112', '27867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27868', '1079', '1', 'Kossuth County', 'US.IA.109', 'ASCII:Kossuth County;ID:4863753', '25991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25991', '112', '27868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27869', '1079', '1', 'Lee County', 'US.IA.111', 'ASCII:Lee County;ID:4864395', '25992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25992', '112', '27869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27870', '1079', '1', 'Linn County', 'US.IA.113', 'ASCII:Linn County;ID:4864924', '25993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25993', '112', '27870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27871', '1079', '1', 'Louisa County', 'US.IA.115', 'ASCII:Louisa County;ID:4865506', '25994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25994', '112', '27871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27872', '1079', '1', 'Lucas County', 'US.IA.117', 'ASCII:Lucas County;ID:4865617', '25995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25995', '112', '27872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27873', '1079', '1', 'Lyon County', 'US.IA.119', 'ASCII:Lyon County;ID:4865744', '25996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25996', '112', '27873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27874', '1079', '1', 'Madison County', 'US.IA.121', 'ASCII:Madison County;ID:4865839', '25997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25997', '112', '27874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27875', '1079', '1', 'Mahaska County', 'US.IA.123', 'ASCII:Mahaska County;ID:4865894', '25998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25998', '112', '27875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27876', '1079', '1', 'Marion County', 'US.IA.125', 'ASCII:Marion County;ID:4866274', '25999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('25999', '112', '27876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27877', '1079', '1', 'Marshall County', 'US.IA.127', 'ASCII:Marshall County;ID:4866360', '26000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26000', '112', '27877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27878', '1079', '1', 'Mills County', 'US.IA.129', 'ASCII:Mills County;ID:4867477', '26001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26001', '112', '27878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27879', '1079', '1', 'Mitchell County', 'US.IA.131', 'ASCII:Mitchell County;ID:4867612', '26002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26002', '112', '27879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27880', '1079', '1', 'Monona County', 'US.IA.133', 'ASCII:Monona County;ID:4867704', '26003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26003', '112', '27880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27881', '1079', '1', 'Monroe County', 'US.IA.135', 'ASCII:Monroe County;ID:4867729', '26004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26004', '112', '27881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27882', '1079', '1', 'Montgomery County', 'US.IA.137', 'ASCII:Montgomery County;ID:4867788', '26005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26005', '112', '27882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27883', '1079', '1', 'Muscatine County', 'US.IA.139', 'ASCII:Muscatine County;ID:4868410', '26006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26006', '112', '27883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27884', '1079', '1', 'O''Brien County', 'US.IA.141', 'ASCII:O''Brien County;ID:4869475', '26007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26007', '112', '27884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27885', '1079', '1', 'Osceola County', 'US.IA.143', 'ASCII:Osceola County;ID:4870217', '26008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26008', '112', '27885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27886', '1079', '1', 'Page County', 'US.IA.145', 'ASCII:Page County;ID:4870567', '26009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26009', '112', '27886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27887', '1079', '1', 'Palo Alto County', 'US.IA.147', 'ASCII:Palo Alto County;ID:4870630', '26010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26010', '112', '27887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27888', '1079', '1', 'Plymouth County', 'US.IA.149', 'ASCII:Plymouth County;ID:4871708', '26011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26011', '112', '27888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27889', '1079', '1', 'Pocahontas County', 'US.IA.151', 'ASCII:Pocahontas County;ID:4871736', '26012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26012', '112', '27889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27890', '1079', '1', 'Polk County', 'US.IA.153', 'ASCII:Polk County;ID:4871782', '26013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26013', '112', '27890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27891', '1079', '1', 'Pottawattamie County', 'US.IA.155', 'ASCII:Pottawattamie County;ID:4871894', '26014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26014', '112', '27891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27892', '1079', '1', 'Poweshiek County', 'US.IA.157', 'ASCII:Poweshiek County;ID:4871919', '26015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26015', '112', '27892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27893', '1079', '1', 'Ringgold County', 'US.IA.159', 'ASCII:Ringgold County;ID:4873016', '26016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26016', '112', '27893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27894', '1079', '1', 'Sac County', 'US.IA.161', 'ASCII:Sac County;ID:4873899', '26017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26017', '112', '27894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27895', '1079', '1', 'Scott County', 'US.IA.163', 'ASCII:Scott County;ID:4875785', '26018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26018', '112', '27895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27896', '1079', '1', 'Shelby County', 'US.IA.165', 'ASCII:Shelby County;ID:4876117', '26019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26019', '112', '27896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27897', '1079', '1', 'Sioux County', 'US.IA.167', 'ASCII:Sioux County;ID:4876545', '26020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26020', '112', '27897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27898', '1079', '1', 'Story County', 'US.IA.169', 'ASCII:Story County;ID:4877685', '26021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26021', '112', '27898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27899', '1079', '1', 'Tama County', 'US.IA.171', 'ASCII:Tama County;ID:4878233', '26022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26022', '112', '27899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27900', '1079', '1', 'Taylor County', 'US.IA.173', 'ASCII:Taylor County;ID:4878273', '26023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26023', '112', '27900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27901', '1079', '1', 'Union County', 'US.IA.175', 'ASCII:Union County;ID:4879340', '26024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26024', '112', '27901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27902', '1079', '1', 'Van Buren County', 'US.IA.177', 'ASCII:Van Buren County;ID:4879999', '26025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26025', '112', '27902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27903', '1079', '1', 'Wapello County', 'US.IA.179', 'ASCII:Wapello County;ID:4880625', '26026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26026', '112', '27903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27904', '1079', '1', 'Warren County', 'US.IA.181', 'ASCII:Warren County;ID:4880695', '26027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26027', '112', '27904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27905', '1079', '1', 'Washington County', 'US.IA.183', 'ASCII:Washington County;ID:4880748', '26028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26028', '112', '27905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27906', '1079', '1', 'Wayne County', 'US.IA.185', 'ASCII:Wayne County;ID:4881059', '26029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26029', '112', '27906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27907', '1079', '1', 'Webster County', 'US.IA.187', 'ASCII:Webster County;ID:4881109', '26030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26030', '112', '27907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27908', '1079', '1', 'Winnebago County', 'US.IA.189', 'ASCII:Winnebago County;ID:4882231', '26031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26031', '112', '27908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27909', '1079', '1', 'Winneshiek County', 'US.IA.191', 'ASCII:Winneshiek County;ID:4882242', '26032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26032', '112', '27909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27910', '1079', '1', 'Woodbury County', 'US.IA.193', 'ASCII:Woodbury County;ID:4882396', '26033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26033', '112', '27910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27911', '1079', '1', 'Wright County', 'US.IA.197', 'ASCII:Wright County;ID:4882529', '26034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26034', '112', '27911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27912', '1079', '1', 'Worth County', 'US.IA.195', 'ASCII:Worth County;ID:4882561', '26035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26035', '112', '27912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IA.195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27913', '1079', '1', 'Boone County', 'US.IL.007', 'ASCII:Boone County;ID:4885392', '26036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26036', '112', '27913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27914', '1079', '1', 'Bureau County', 'US.IL.011', 'ASCII:Bureau County;ID:4885994', '26037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26037', '112', '27914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27915', '1079', '1', 'Carroll County', 'US.IL.015', 'ASCII:Carroll County;ID:4886694', '26038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26038', '112', '27915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27916', '1079', '1', 'Champaign County', 'US.IL.019', 'ASCII:Champaign County;ID:4887163', '26039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26039', '112', '27916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27917', '1079', '1', 'Cook County', 'US.IL.031', 'ASCII:Cook County;ID:4888671', '26040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26040', '112', '27917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27918', '1079', '1', 'De Witt County', 'US.IL.039', 'ASCII:De Witt County;ID:4889548', '26041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26041', '112', '27918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27919', '1079', '1', 'DeKalb County', 'US.IL.037', 'ASCII:DeKalb County;ID:4889554', '26042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26042', '112', '27919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27920', '1079', '1', 'DuPage County', 'US.IL.043', 'ASCII:DuPage County;ID:4890213', '26043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26043', '112', '27920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27921', '1079', '1', 'Ford County', 'US.IL.053', 'ASCII:Ford County;ID:4892729', '26044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26044', '112', '27921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27922', '1079', '1', 'Fulton County', 'US.IL.057', 'ASCII:Fulton County;ID:4893313', '26045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26045', '112', '27922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27923', '1079', '1', 'Grundy County', 'US.IL.063', 'ASCII:Grundy County;ID:4894828', '26046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26046', '112', '27923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27924', '1079', '1', 'Hancock County', 'US.IL.067', 'ASCII:Hancock County;ID:4895035', '26047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26047', '112', '27924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27925', '1079', '1', 'Henderson County', 'US.IL.071', 'ASCII:Henderson County;ID:4895552', '26048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26048', '112', '27925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27926', '1079', '1', 'Henry County', 'US.IL.073', 'ASCII:Henry County;ID:4895598', '26049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26049', '112', '27926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27927', '1079', '1', 'Iroquois County', 'US.IL.075', 'ASCII:Iroquois County;ID:4897521', '26050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26050', '112', '27927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27928', '1079', '1', 'Jo Daviess County', 'US.IL.085', 'ASCII:Jo Daviess County;ID:4897897', '26051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26051', '112', '27928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27929', '1079', '1', 'Kane County', 'US.IL.089', 'ASCII:Kane County;ID:4898166', '26052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26052', '112', '27929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27930', '1079', '1', 'Kankakee County', 'US.IL.091', 'ASCII:Kankakee County;ID:4898188', '26053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26053', '112', '27930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27931', '1079', '1', 'Kendall County', 'US.IL.093', 'ASCII:Kendall County;ID:4898342', '26054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26054', '112', '27931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27932', '1079', '1', 'Knox County', 'US.IL.095', 'ASCII:Knox County;ID:4898722', '26055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26055', '112', '27932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27933', '1079', '1', 'La Salle County', 'US.IL.099', 'ASCII:La Salle County;ID:4898878', '26056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26056', '112', '27933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27934', '1079', '1', 'Lake County', 'US.IL.097', 'ASCII:Lake County;ID:4898998', '26057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26057', '112', '27934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27935', '1079', '1', 'Lee County', 'US.IL.103', 'ASCII:Lee County;ID:4899519', '26058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26058', '112', '27935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27936', '1079', '1', 'Livingston County', 'US.IL.105', 'ASCII:Livingston County;ID:4900233', '26059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26059', '112', '27936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27937', '1079', '1', 'Logan County', 'US.IL.107', 'ASCII:Logan County;ID:4900338', '26060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26060', '112', '27937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27938', '1079', '1', 'Marshall County', 'US.IL.123', 'ASCII:Marshall County;ID:4901299', '26061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26061', '112', '27938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27939', '1079', '1', 'Mason County', 'US.IL.125', 'ASCII:Mason County;ID:4901395', '26062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26062', '112', '27939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27940', '1079', '1', 'McDonough County', 'US.IL.109', 'ASCII:McDonough County;ID:4901622', '26063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26063', '112', '27940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27941', '1079', '1', 'McHenry County', 'US.IL.111', 'ASCII:McHenry County;ID:4901666', '26064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26064', '112', '27941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27942', '1079', '1', 'McLean County', 'US.IL.113', 'ASCII:McLean County;ID:4901730', '26065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26065', '112', '27942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27943', '1079', '1', 'Menard County', 'US.IL.129', 'ASCII:Menard County;ID:4901936', '26066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26066', '112', '27943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27944', '1079', '1', 'Mercer County', 'US.IL.131', 'ASCII:Mercer County;ID:4901976', '26067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26067', '112', '27944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27945', '1079', '1', 'Ogle County', 'US.IL.141', 'ASCII:Ogle County;ID:4904601', '26068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26068', '112', '27945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27946', '1079', '1', 'Peoria County', 'US.IL.143', 'ASCII:Peoria County;ID:4905697', '26069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26069', '112', '27946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27947', '1079', '1', 'Piatt County', 'US.IL.147', 'ASCII:Piatt County;ID:4905877', '26070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26070', '112', '27947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27948', '1079', '1', 'Putnam County', 'US.IL.155', 'ASCII:Putnam County;ID:4906962', '26071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26071', '112', '27948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27949', '1079', '1', 'Rock Island County', 'US.IL.161', 'ASCII:Rock Island County;ID:4907910', '26072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26072', '112', '27949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27950', '1079', '1', 'Schuyler County', 'US.IL.169', 'ASCII:Schuyler County;ID:4910877', '26073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26073', '112', '27950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27951', '1079', '1', 'Stark County', 'US.IL.175', 'ASCII:Stark County;ID:4912398', '26074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26074', '112', '27951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27952', '1079', '1', 'Stephenson County', 'US.IL.177', 'ASCII:Stephenson County;ID:4912492', '26075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26075', '112', '27952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27953', '1079', '1', 'Tazewell County', 'US.IL.179', 'ASCII:Tazewell County;ID:4913271', '26076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26076', '112', '27953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27954', '1079', '1', 'Vermilion County', 'US.IL.183', 'ASCII:Vermilion County;ID:4914710', '26077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26077', '112', '27954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27955', '1079', '1', 'Warren County', 'US.IL.187', 'ASCII:Warren County;ID:4915502', '26078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26078', '112', '27955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27956', '1079', '1', 'Whiteside County', 'US.IL.195', 'ASCII:Whiteside County;ID:4916434', '26079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26079', '112', '27956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27957', '1079', '1', 'Will County', 'US.IL.197', 'ASCII:Will County;ID:4916565', '26080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26080', '112', '27957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27958', '1079', '1', 'Winnebago County', 'US.IL.201', 'ASCII:Winnebago County;ID:4916845', '26081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26081', '112', '27958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27959', '1079', '1', 'Woodford County', 'US.IL.203', 'ASCII:Woodford County;ID:4917010', '26082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26082', '112', '27959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IL.203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27960', '1079', '1', 'Adams County', 'US.IN.001', 'ASCII:Adams County;ID:4917487', '26083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26083', '112', '27960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27961', '1079', '1', 'Allen County', 'US.IN.003', 'ASCII:Allen County;ID:4917555', '26084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26084', '112', '27961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27962', '1079', '1', 'Benton County', 'US.IN.007', 'ASCII:Benton County;ID:4917993', '26085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26085', '112', '27962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27963', '1079', '1', 'Blackford County', 'US.IN.009', 'ASCII:Blackford County;ID:4918181', '26086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26086', '112', '27963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27964', '1079', '1', 'Boone County', 'US.IN.011', 'ASCII:Boone County;ID:4918273', '26087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26087', '112', '27964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27965', '1079', '1', 'Carroll County', 'US.IN.015', 'ASCII:Carroll County;ID:4918765', '26088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26088', '112', '27965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27966', '1079', '1', 'Cass County', 'US.IN.017', 'ASCII:Cass County;ID:4918771', '26089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26089', '112', '27966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27967', '1079', '1', 'Clinton County', 'US.IN.023', 'ASCII:Clinton County;ID:4919127', '26090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26090', '112', '27967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27968', '1079', '1', 'DeKalb County', 'US.IN.033', 'ASCII:DeKalb County;ID:4919554', '26091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26091', '112', '27968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27969', '1079', '1', 'Delaware County', 'US.IN.035', 'ASCII:Delaware County;ID:4919615', '26092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26092', '112', '27969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27970', '1079', '1', 'Elkhart County', 'US.IN.039', 'ASCII:Elkhart County;ID:4919988', '26093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26093', '112', '27970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27971', '1079', '1', 'Fountain County', 'US.IN.045', 'ASCII:Fountain County;ID:4920444', '26094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26094', '112', '27971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27972', '1079', '1', 'Fulton County', 'US.IN.049', 'ASCII:Fulton County;ID:4920550', '26095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26095', '112', '27972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27973', '1079', '1', 'Grant County', 'US.IN.053', 'ASCII:Grant County;ID:4920875', '26096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26096', '112', '27973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27974', '1079', '1', 'Hamilton County', 'US.IN.057', 'ASCII:Hamilton County;ID:4921085', '26097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26097', '112', '27974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27975', '1079', '1', 'Howard County', 'US.IN.067', 'ASCII:Howard County;ID:4921670', '26098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26098', '112', '27975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27976', '1079', '1', 'Huntington County', 'US.IN.069', 'ASCII:Huntington County;ID:4921729', '26099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26099', '112', '27976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27977', '1079', '1', 'Jasper County', 'US.IN.073', 'ASCII:Jasper County;ID:4922007', '26100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26100', '112', '27977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27978', '1079', '1', 'Jay County', 'US.IN.075', 'ASCII:Jay County;ID:4922013', '26101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26101', '112', '27978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27979', '1079', '1', 'Kosciusko County', 'US.IN.085', 'ASCII:Kosciusko County;ID:4922408', '26102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26102', '112', '27979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27980', '1079', '1', 'LaGrange County', 'US.IN.087', 'ASCII:LaGrange County;ID:4922458', '26103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26103', '112', '27980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27981', '1079', '1', 'LaPorte County', 'US.IN.091', 'ASCII:LaPorte County;ID:4922460', '26104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26104', '112', '27981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27982', '1079', '1', 'Lake County', 'US.IN.089', 'ASCII:Lake County;ID:4922493', '26105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26105', '112', '27982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27983', '1079', '1', 'Madison County', 'US.IN.095', 'ASCII:Madison County;ID:4923124', '26106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26106', '112', '27983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27984', '1079', '1', 'Marshall County', 'US.IN.099', 'ASCII:Marshall County;ID:4923252', '26107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26107', '112', '27984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27985', '1079', '1', 'Miami County', 'US.IN.103', 'ASCII:Miami County;ID:4923517', '26108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26108', '112', '27985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27986', '1079', '1', 'Montgomery County', 'US.IN.107', 'ASCII:Montgomery County;ID:4923741', '26109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26109', '112', '27986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27987', '1079', '1', 'Newton County', 'US.IN.111', 'ASCII:Newton County;ID:4924165', '26110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26110', '112', '27987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27988', '1079', '1', 'Noble County', 'US.IN.113', 'ASCII:Noble County;ID:4924192', '26111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26111', '112', '27988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27989', '1079', '1', 'Porter County', 'US.IN.127', 'ASCII:Porter County;ID:4925020', '26112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26112', '112', '27989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27990', '1079', '1', 'Pulaski County', 'US.IN.131', 'ASCII:Pulaski County;ID:4925155', '26113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26113', '112', '27990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27991', '1079', '1', 'Randolph County', 'US.IN.135', 'ASCII:Randolph County;ID:4925224', '26114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26114', '112', '27991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27992', '1079', '1', 'Saint Joseph County', 'US.IN.141', 'ASCII:Saint Joseph County;ID:4925848', '26115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26115', '112', '27992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27993', '1079', '1', 'Starke County', 'US.IN.149', 'ASCII:Starke County;ID:4926760', '26116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26116', '112', '27993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27994', '1079', '1', 'Steuben County', 'US.IN.151', 'ASCII:Steuben County;ID:4926796', '26117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26117', '112', '27994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27995', '1079', '1', 'Tippecanoe County', 'US.IN.157', 'ASCII:Tippecanoe County;ID:4927230', '26118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26118', '112', '27995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27996', '1079', '1', 'Tipton County', 'US.IN.159', 'ASCII:Tipton County;ID:4927243', '26119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26119', '112', '27996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27997', '1079', '1', 'Wabash County', 'US.IN.169', 'ASCII:Wabash County;ID:4927751', '26120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26120', '112', '27997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27998', '1079', '1', 'Warren County', 'US.IN.171', 'ASCII:Warren County;ID:4927846', '26121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26121', '112', '27998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('27999', '1079', '1', 'Wells County', 'US.IN.179', 'ASCII:Wells County;ID:4928008', '26122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26122', '112', '27999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28000', '1079', '1', 'White County', 'US.IN.181', 'ASCII:White County;ID:4928184', '26123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26123', '112', '28000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28001', '1079', '1', 'Whitley County', 'US.IN.183', 'ASCII:Whitley County;ID:4928215', '26124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26124', '112', '28001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.IN.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28002', '1079', '1', 'Barnstable County', 'US.MA.001', 'ASCII:Cape Cod;ID:4929772', '26125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26125', '112', '28002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28003', '1079', '1', 'Berkshire County', 'US.MA.003', 'ASCII:Berkshire County;ID:4930396', '26126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26126', '112', '28003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28004', '1079', '1', 'Bristol County', 'US.MA.005', 'ASCII:Bristol County;ID:4931378', '26127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26127', '112', '28004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28005', '1079', '1', 'Dukes County', 'US.MA.007', 'ASCII:Dukes County;ID:4935156', '26128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26128', '112', '28005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28006', '1079', '1', 'Essex County', 'US.MA.009', 'ASCII:Essex County;ID:4935951', '26129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26129', '112', '28006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28007', '1079', '1', 'Franklin County', 'US.MA.011', 'ASCII:Franklin County;ID:4937280', '26130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26130', '112', '28007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28008', '1079', '1', 'Hampden County', 'US.MA.013', 'ASCII:Hampden County;ID:4938741', '26131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26131', '112', '28008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28009', '1079', '1', 'Hampshire County', 'US.MA.015', 'ASCII:Hampshire County;ID:4938757', '26132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26132', '112', '28009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28010', '1079', '1', 'Middlesex County', 'US.MA.017', 'ASCII:Middlesex County;ID:4943909', '26133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26133', '112', '28010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28011', '1079', '1', 'Nantucket County', 'US.MA.019', 'ASCII:Nantucket County;ID:4944911', '26134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26134', '112', '28011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28012', '1079', '1', 'Norfolk County', 'US.MA.021', 'ASCII:Norfolk County;ID:4945455', '26135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26135', '112', '28012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28013', '1079', '1', 'Plymouth County', 'US.MA.023', 'ASCII:Plymouth County;ID:4947607', '26136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26136', '112', '28013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28014', '1079', '1', 'Suffolk County', 'US.MA.025', 'ASCII:Suffolk County;ID:4952349', '26137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26137', '112', '28014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28015', '1079', '1', 'Worcester County', 'US.MA.027', 'ASCII:Worcester County;ID:4956199', '26138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26138', '112', '28015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MA.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28016', '1079', '1', 'Androscoggin County', 'US.ME.001', 'ASCII:Androscoggin County;ID:4956755', '26139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26139', '112', '28016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28017', '1079', '1', 'Aroostook County', 'US.ME.003', 'ASCII:Aroostook County;ID:4956873', '26140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26140', '112', '28017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28018', '1079', '1', 'Cumberland County', 'US.ME.005', 'ASCII:Cumberland County;ID:4961900', '26141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26141', '112', '28018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28019', '1079', '1', 'Franklin County', 'US.ME.007', 'ASCII:Franklin County;ID:4964821', '26142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26142', '112', '28019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28020', '1079', '1', 'Hancock County', 'US.ME.009', 'ASCII:Hancock County;ID:4966407', '26143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26143', '112', '28020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28021', '1079', '1', 'Kennebec County', 'US.ME.011', 'ASCII:Kennebec County;ID:4968714', '26144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26144', '112', '28021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28022', '1079', '1', 'Knox County', 'US.ME.013', 'ASCII:Knox County;ID:4968996', '26145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26145', '112', '28022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28023', '1079', '1', 'Lincoln County', 'US.ME.015', 'ASCII:Lincoln County;ID:4969555', '26146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26146', '112', '28023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28024', '1079', '1', 'Oxford County', 'US.ME.017', 'ASCII:Oxford County;ID:4974522', '26147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26147', '112', '28024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28025', '1079', '1', 'Penobscot County', 'US.ME.019', 'ASCII:Penobscot County;ID:4974977', '26148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26148', '112', '28025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28026', '1079', '1', 'Piscataquis County', 'US.ME.021', 'ASCII:Piscataquis County;ID:4975418', '26149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26149', '112', '28026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28027', '1079', '1', 'Sagadahoc County', 'US.ME.023', 'ASCII:Sagadahoc County;ID:4977278', '26150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26150', '112', '28027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28028', '1079', '1', 'Somerset County', 'US.ME.025', 'ASCII:Somerset County;ID:4978972', '26151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26151', '112', '28028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28029', '1079', '1', 'Waldo County', 'US.ME.027', 'ASCII:Waldo County;ID:4982040', '26152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26152', '112', '28029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28030', '1079', '1', 'Washington County', 'US.ME.029', 'ASCII:Washington County;ID:4982182', '26153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26153', '112', '28030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28031', '1079', '1', 'York County', 'US.ME.031', 'ASCII:York County;ID:4983621', '26154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26154', '112', '28031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ME.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28032', '1079', '1', 'Alcona County', 'US.MI.001', 'ASCII:Alcona County;ID:4983917', '26155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26155', '112', '28032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28033', '1079', '1', 'Alger County', 'US.MI.003', 'ASCII:Alger County;ID:4983956', '26156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26156', '112', '28033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28034', '1079', '1', 'Allegan County', 'US.MI.005', 'ASCII:Allegan County;ID:4983990', '26157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26157', '112', '28034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28035', '1079', '1', 'Alpena County', 'US.MI.007', 'ASCII:Alpena County;ID:4984076', '26158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26158', '112', '28035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28036', '1079', '1', 'Antrim County', 'US.MI.009', 'ASCII:Antrim County;ID:4984284', '26159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26159', '112', '28036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28037', '1079', '1', 'Arenac County', 'US.MI.011', 'ASCII:Arenac County;ID:4984356', '26160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26160', '112', '28037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28038', '1079', '1', 'Baraga County', 'US.MI.013', 'ASCII:Baraga County;ID:4984903', '26161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26161', '112', '28038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28039', '1079', '1', 'Barry County', 'US.MI.015', 'ASCII:Barry County;ID:4985016', '26162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26162', '112', '28039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28040', '1079', '1', 'Bay County', 'US.MI.017', 'ASCII:Bay County;ID:4985190', '26163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26163', '112', '28040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28041', '1079', '1', 'Benzie County', 'US.MI.019', 'ASCII:Benzie County;ID:4985733', '26164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26164', '112', '28041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28042', '1079', '1', 'Berrien County', 'US.MI.021', 'ASCII:Berrien County;ID:4985760', '26165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26165', '112', '28042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28043', '1079', '1', 'Branch County', 'US.MI.023', 'ASCII:Branch County;ID:4986828', '26166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26166', '112', '28043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28044', '1079', '1', 'Calhoun County', 'US.MI.025', 'ASCII:Calhoun County;ID:4987673', '26167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26167', '112', '28044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28045', '1079', '1', 'Cass County', 'US.MI.027', 'ASCII:Cass County;ID:4988216', '26168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26168', '112', '28045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28046', '1079', '1', 'Charlevoix County', 'US.MI.029', 'ASCII:Charlevoix County;ID:4988577', '26169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26169', '112', '28046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28047', '1079', '1', 'Cheboygan County', 'US.MI.031', 'ASCII:Cheboygan County;ID:4988619', '26170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26170', '112', '28047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28048', '1079', '1', 'Chippewa County', 'US.MI.033', 'ASCII:Chippewa County;ID:4988755', '26171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26171', '112', '28048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28049', '1079', '1', 'Clare County', 'US.MI.035', 'ASCII:Clare County;ID:4988934', '26172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26172', '112', '28049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28050', '1079', '1', 'Clinton County', 'US.MI.037', 'ASCII:Clinton County;ID:4989135', '26173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26173', '112', '28050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28051', '1079', '1', 'Crawford County', 'US.MI.039', 'ASCII:Crawford County;ID:4989916', '26174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26174', '112', '28051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28052', '1079', '1', 'Delta County', 'US.MI.041', 'ASCII:Delta County;ID:4990662', '26175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26175', '112', '28052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28053', '1079', '1', 'Dickinson County', 'US.MI.043', 'ASCII:Dickinson County;ID:4990845', '26176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26176', '112', '28053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28054', '1079', '1', 'Eaton County', 'US.MI.045', 'ASCII:Eaton County;ID:4991746', '26177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26177', '112', '28054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28055', '1079', '1', 'Emmet County', 'US.MI.047', 'ASCII:Emmet County;ID:4992137', '26178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26178', '112', '28055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28056', '1079', '1', 'Genesee County', 'US.MI.049', 'ASCII:Genesee County;ID:4993785', '26179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26179', '112', '28056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28057', '1079', '1', 'Gladwin County', 'US.MI.051', 'ASCII:Gladwin County;ID:4993986', '26180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26180', '112', '28057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28058', '1079', '1', 'Gogebic County', 'US.MI.053', 'ASCII:Gogebic County;ID:4994090', '26181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26181', '112', '28058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28059', '1079', '1', 'Grand Traverse County', 'US.MI.055', 'ASCII:Grand Traverse County;ID:4994374', '26182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26182', '112', '28059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28060', '1079', '1', 'Gratiot County', 'US.MI.057', 'ASCII:Gratiot County;ID:4994537', '26183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26183', '112', '28060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28061', '1079', '1', 'Hillsdale County', 'US.MI.059', 'ASCII:Hillsdale County;ID:4996110', '26184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26184', '112', '28061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28062', '1079', '1', 'Houghton County', 'US.MI.061', 'ASCII:Houghton County;ID:4996573', '26185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26185', '112', '28062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28063', '1079', '1', 'Huron County', 'US.MI.063', 'ASCII:Huron County;ID:4996859', '26186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26186', '112', '28063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28064', '1079', '1', 'Ingham County', 'US.MI.065', 'ASCII:Ingham County;ID:4997130', '26187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26187', '112', '28064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28065', '1079', '1', 'Ionia County', 'US.MI.067', 'ASCII:Ionia County;ID:4997193', '26188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26188', '112', '28065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28066', '1079', '1', 'Iosco County', 'US.MI.069', 'ASCII:Iosco County;ID:4997201', '26189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26189', '112', '28066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28067', '1079', '1', 'Iron County', 'US.MI.071', 'ASCII:Iron County;ID:4997220', '26190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26190', '112', '28067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28068', '1079', '1', 'Isabella County', 'US.MI.073', 'ASCII:Isabella County;ID:4997272', '26191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26191', '112', '28068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28069', '1079', '1', 'Jackson County', 'US.MI.075', 'ASCII:Jackson County;ID:4997389', '26192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26192', '112', '28069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28070', '1079', '1', 'Kalamazoo County', 'US.MI.077', 'ASCII:Kalamazoo County;ID:4997791', '26193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26193', '112', '28070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28071', '1079', '1', 'Kalkaska County', 'US.MI.079', 'ASCII:Kalkaska County;ID:4997807', '26194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26194', '112', '28071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28072', '1079', '1', 'Kent County', 'US.MI.081', 'ASCII:Kent County;ID:4998005', '26195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26195', '112', '28072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28073', '1079', '1', 'Keweenaw County', 'US.MI.083', 'ASCII:Keweenaw County;ID:4998067', '26196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26196', '112', '28073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28074', '1079', '1', 'Lake County', 'US.MI.085', 'ASCII:Lake County;ID:4998535', '26197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26197', '112', '28074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28075', '1079', '1', 'Lapeer County', 'US.MI.087', 'ASCII:Lapeer County;ID:4998845', '26198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26198', '112', '28075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28076', '1079', '1', 'Leelanau County', 'US.MI.089', 'ASCII:Leelanau County;ID:4999022', '26199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26199', '112', '28076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28077', '1079', '1', 'Lenawee County', 'US.MI.091', 'ASCII:Lenawee County;ID:4999081', '26200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26200', '112', '28077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28078', '1079', '1', 'Livingston County', 'US.MI.093', 'ASCII:Livingston County;ID:4999829', '26201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26201', '112', '28078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28079', '1079', '1', 'Luce County', 'US.MI.095', 'ASCII:Luce County;ID:5000297', '26202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26202', '112', '28079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28080', '1079', '1', 'Mackinac County', 'US.MI.097', 'ASCII:Mackinac County;ID:5000447', '26203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26203', '112', '28080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28081', '1079', '1', 'Macomb County', 'US.MI.099', 'ASCII:Macomb County;ID:5000477', '26204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26204', '112', '28081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28082', '1079', '1', 'Manistee County', 'US.MI.101', 'ASCII:Manistee County;ID:5000612', '26205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26205', '112', '28082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28083', '1079', '1', 'Marquette County', 'US.MI.103', 'ASCII:Marquette County;ID:5000950', '26206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26206', '112', '28083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28084', '1079', '1', 'Mason County', 'US.MI.105', 'ASCII:Mason County;ID:5001099', '26207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26207', '112', '28084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28085', '1079', '1', 'Mecosta County', 'US.MI.107', 'ASCII:Mecosta County;ID:5001594', '26208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26208', '112', '28085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28086', '1079', '1', 'Menominee County', 'US.MI.109', 'ASCII:Menominee County;ID:5001670', '26209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26209', '112', '28086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28087', '1079', '1', 'Midland County', 'US.MI.111', 'ASCII:Midland County;ID:5001932', '26210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26210', '112', '28087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28088', '1079', '1', 'Missaukee County', 'US.MI.113', 'ASCII:Missaukee County;ID:5002231', '26211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26211', '112', '28088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28089', '1079', '1', 'Monroe County', 'US.MI.115', 'ASCII:Monroe County;ID:5002348', '26212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26212', '112', '28089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28090', '1079', '1', 'Montcalm County', 'US.MI.117', 'ASCII:Montcalm County;ID:5002390', '26213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26213', '112', '28090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28091', '1079', '1', 'Montmorency County', 'US.MI.119', 'ASCII:Montmorency County;ID:5002394', '26214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26214', '112', '28091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28092', '1079', '1', 'Muskegon County', 'US.MI.121', 'ASCII:Muskegon County;ID:5003136', '26215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26215', '112', '28092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28093', '1079', '1', 'Newaygo County', 'US.MI.123', 'ASCII:Newaygo County;ID:5003426', '26216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26216', '112', '28093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28094', '1079', '1', 'Oakland County', 'US.MI.125', 'ASCII:Oakland County;ID:5004223', '26217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26217', '112', '28094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28095', '1079', '1', 'Oceana County', 'US.MI.127', 'ASCII:Oceana County;ID:5004294', '26218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26218', '112', '28095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28096', '1079', '1', 'Ogemaw County', 'US.MI.129', 'ASCII:Ogemaw County;ID:5004326', '26219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26219', '112', '28096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28097', '1079', '1', 'Ontonagon County', 'US.MI.131', 'ASCII:Ontonagon County;ID:5004521', '26220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26220', '112', '28097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28098', '1079', '1', 'Osceola County', 'US.MI.133', 'ASCII:Osceola County;ID:5004611', '26221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26221', '112', '28098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28099', '1079', '1', 'Oscoda County', 'US.MI.135', 'ASCII:Oscoda County;ID:5004616', '26222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26222', '112', '28099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28100', '1079', '1', 'Otsego County', 'US.MI.137', 'ASCII:Otsego County;ID:5004659', '26223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26223', '112', '28100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28101', '1079', '1', 'Ottawa County', 'US.MI.139', 'ASCII:Ottawa County;ID:5004681', '26224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26224', '112', '28101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28102', '1079', '1', 'Presque Isle County', 'US.MI.141', 'ASCII:Presque Isle County;ID:5006470', '26225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26225', '112', '28102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28103', '1079', '1', 'Roscommon County', 'US.MI.143', 'ASCII:Roscommon County;ID:5007587', '26226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26226', '112', '28103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28104', '1079', '1', 'Saginaw County', 'US.MI.145', 'ASCII:Saginaw County;ID:5007996', '26227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26227', '112', '28104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28105', '1079', '1', 'Saint Clair County', 'US.MI.147', 'ASCII:Saint Clair County;ID:5008112', '26228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26228', '112', '28105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28106', '1079', '1', 'Saint Joseph County', 'US.MI.149', 'ASCII:Saint Joseph County;ID:5008347', '26229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26229', '112', '28106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28107', '1079', '1', 'Sanilac County', 'US.MI.151', 'ASCII:Sanilac County;ID:5008950', '26230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26230', '112', '28107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28108', '1079', '1', 'Schoolcraft County', 'US.MI.153', 'ASCII:Schoolcraft County;ID:5009187', '26231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26231', '112', '28108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28109', '1079', '1', 'Shiawassee County', 'US.MI.155', 'ASCII:Shiawassee County;ID:5009706', '26232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26232', '112', '28109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28110', '1079', '1', 'Tuscola County', 'US.MI.157', 'ASCII:Tuscola County;ID:5012748', '26233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26233', '112', '28110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28111', '1079', '1', 'Van Buren County', 'US.MI.159', 'ASCII:Van Buren County;ID:5013104', '26234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26234', '112', '28111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28112', '1079', '1', 'Washtenaw County', 'US.MI.161', 'ASCII:Washtenaw County;ID:5014120', '26235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26235', '112', '28112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28113', '1079', '1', 'Wayne County', 'US.MI.163', 'ASCII:Wayne County;ID:5014227', '26236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26236', '112', '28113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28114', '1079', '1', 'Wexford County', 'US.MI.165', 'ASCII:Wexford County;ID:5014729', '26237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26237', '112', '28114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MI.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28115', '1079', '1', 'Aitkin County', 'US.MN.001', 'ASCII:Aitkin County;ID:5015979', '26238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26238', '112', '28115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28116', '1079', '1', 'Anoka County', 'US.MN.003', 'ASCII:Anoka County;ID:5016452', '26239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26239', '112', '28116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28117', '1079', '1', 'Becker County', 'US.MN.005', 'ASCII:Becker County;ID:5017670', '26240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26240', '112', '28117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28118', '1079', '1', 'Beltrami County', 'US.MN.007', 'ASCII:Beltrami County;ID:5017805', '26241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26241', '112', '28118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28119', '1079', '1', 'Benton County', 'US.MN.009', 'ASCII:Benton County;ID:5017916', '26242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26242', '112', '28119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28120', '1079', '1', 'Big Stone County', 'US.MN.011', 'ASCII:Big Stone County;ID:5018364', '26243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26243', '112', '28120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28121', '1079', '1', 'Blue Earth County', 'US.MN.013', 'ASCII:Blue Earth County;ID:5018756', '26244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26244', '112', '28121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28122', '1079', '1', 'Brown County', 'US.MN.015', 'ASCII:Brown County;ID:5019385', '26245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26245', '112', '28122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28123', '1079', '1', 'Carlton County', 'US.MN.017', 'ASCII:Carlton County;ID:5020429', '26246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26246', '112', '28123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28124', '1079', '1', 'Carver County', 'US.MN.019', 'ASCII:Carver County;ID:5020499', '26247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26247', '112', '28124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28125', '1079', '1', 'Cass County', 'US.MN.021', 'ASCII:Cass County;ID:5020546', '26248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26248', '112', '28125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28126', '1079', '1', 'Chippewa County', 'US.MN.023', 'ASCII:Chippewa County;ID:5021038', '26249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26249', '112', '28126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28127', '1079', '1', 'Chisago County', 'US.MN.025', 'ASCII:Chisago County;ID:5021070', '26250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26250', '112', '28127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28128', '1079', '1', 'Clay County', 'US.MN.027', 'ASCII:Clay County;ID:5021444', '26251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26251', '112', '28128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28129', '1079', '1', 'Clearwater County', 'US.MN.029', 'ASCII:Clearwater County;ID:5021535', '26252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26252', '112', '28129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28130', '1079', '1', 'Cook County', 'US.MN.031', 'ASCII:Cook County;ID:5021977', '26253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26253', '112', '28130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28131', '1079', '1', 'Cottonwood County', 'US.MN.033', 'ASCII:Cottonwood County;ID:5022154', '26254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26254', '112', '28131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28132', '1079', '1', 'Crow Wing County', 'US.MN.035', 'ASCII:Crow Wing County;ID:5023545', '26255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26255', '112', '28132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28133', '1079', '1', 'Dakota County', 'US.MN.037', 'ASCII:Dakota County;ID:5023752', '26256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26256', '112', '28133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28134', '1079', '1', 'Dodge County', 'US.MN.039', 'ASCII:Dodge County;ID:5024432', '26257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26257', '112', '28134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28135', '1079', '1', 'Douglas County', 'US.MN.041', 'ASCII:Douglas County;ID:5024544', '26258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26258', '112', '28135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28136', '1079', '1', 'Faribault County', 'US.MN.043', 'ASCII:Faribault County;ID:5026292', '26259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26259', '112', '28136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28137', '1079', '1', 'Fillmore County', 'US.MN.045', 'ASCII:Fillmore County;ID:5026478', '26260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26260', '112', '28137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28138', '1079', '1', 'Freeborn County', 'US.MN.047', 'ASCII:Freeborn County;ID:5027399', '26261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26261', '112', '28138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28139', '1079', '1', 'Goodhue County', 'US.MN.049', 'ASCII:Goodhue County;ID:5028232', '26262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26262', '112', '28139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28140', '1079', '1', 'Grant County', 'US.MN.051', 'ASCII:Grant County;ID:5028615', '26263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26263', '112', '28140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28141', '1079', '1', 'Hennepin County', 'US.MN.053', 'ASCII:Hennepin County;ID:5029877', '26264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26264', '112', '28141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28142', '1079', '1', 'Houston County', 'US.MN.055', 'ASCII:Houston County;ID:5030806', '26265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26265', '112', '28142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28143', '1079', '1', 'Hubbard County', 'US.MN.057', 'ASCII:Hubbard County;ID:5030862', '26266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26266', '112', '28143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28144', '1079', '1', 'Isanti County', 'US.MN.059', 'ASCII:Isanti County;ID:5031493', '26267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26267', '112', '28144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28145', '1079', '1', 'Itasca County', 'US.MN.061', 'ASCII:Itasca County;ID:5031616', '26268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26268', '112', '28145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28146', '1079', '1', 'Jackson County', 'US.MN.063', 'ASCII:Jackson County;ID:5031682', '26269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26269', '112', '28146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28147', '1079', '1', 'Kanabec County', 'US.MN.065', 'ASCII:Kanabec County;ID:5032855', '26270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26270', '112', '28147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28148', '1079', '1', 'Kandiyohi County', 'US.MN.067', 'ASCII:Kandiyohi County;ID:5032867', '26271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26271', '112', '28148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28149', '1079', '1', 'Kittson County', 'US.MN.069', 'ASCII:Kittson County;ID:5033353', '26272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26272', '112', '28149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28150', '1079', '1', 'Koochiching County', 'US.MN.071', 'ASCII:Koochiching County;ID:5033463', '26273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26273', '112', '28150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28151', '1079', '1', 'Lac qui Parle County', 'US.MN.073', 'ASCII:Lac qui Parle County;ID:5033637', '26274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26274', '112', '28151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28152', '1079', '1', 'Lake County', 'US.MN.075', 'ASCII:Lake County;ID:5033738', '26275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26275', '112', '28152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28153', '1079', '1', 'Lake of the Woods County', 'US.MN.077', 'ASCII:Lake of the Woods County;ID:5033955', '26276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26276', '112', '28153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28154', '1079', '1', 'Le Sueur County', 'US.MN.079', 'ASCII:Le Sueur County;ID:5034327', '26277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26277', '112', '28154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28155', '1079', '1', 'Lincoln County', 'US.MN.081', 'ASCII:Lincoln County;ID:5034652', '26278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26278', '112', '28155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28156', '1079', '1', 'Lyon County', 'US.MN.083', 'ASCII:Lyon County;ID:5036131', '26279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26279', '112', '28156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28157', '1079', '1', 'Mahnomen County', 'US.MN.087', 'ASCII:Mahnomen County;ID:5036279', '26280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26280', '112', '28157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28158', '1079', '1', 'Marshall County', 'US.MN.089', 'ASCII:Marshall County;ID:5036734', '26281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26281', '112', '28158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28159', '1079', '1', 'Martin County', 'US.MN.091', 'ASCII:Martin County;ID:5036797', '26282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26282', '112', '28159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28160', '1079', '1', 'McLeod County', 'US.MN.085', 'ASCII:McLeod County;ID:5037083', '26283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26283', '112', '28160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28161', '1079', '1', 'Meeker County', 'US.MN.093', 'ASCII:Meeker County;ID:5037200', '26284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26284', '112', '28161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28162', '1079', '1', 'Mille Lacs County', 'US.MN.095', 'ASCII:Mille Lacs County;ID:5037515', '26285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26285', '112', '28162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28163', '1079', '1', 'Morrison County', 'US.MN.097', 'ASCII:Morrison County;ID:5038318', '26286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26286', '112', '28163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28164', '1079', '1', 'Mower County', 'US.MN.099', 'ASCII:Mower County;ID:5038458', '26287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26287', '112', '28164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28165', '1079', '1', 'Murray County', 'US.MN.101', 'ASCII:Murray County;ID:5038801', '26288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26288', '112', '28165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28166', '1079', '1', 'Nicollet County', 'US.MN.103', 'ASCII:Nicollet County;ID:5039249', '26289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26289', '112', '28166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28167', '1079', '1', 'Nobles County', 'US.MN.105', 'ASCII:Nobles County;ID:5039323', '26290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26290', '112', '28167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28168', '1079', '1', 'Norman County', 'US.MN.107', 'ASCII:Norman County;ID:5039381', '26291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26291', '112', '28168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28169', '1079', '1', 'Olmsted County', 'US.MN.109', 'ASCII:Olmsted County;ID:5040211', '26292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26292', '112', '28169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28170', '1079', '1', 'Otter Tail County', 'US.MN.111', 'ASCII:Otter Tail County;ID:5040515', '26293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26293', '112', '28170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28171', '1079', '1', 'Pennington County', 'US.MN.113', 'ASCII:Pennington County;ID:5041121', '26294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26294', '112', '28171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28172', '1079', '1', 'Pine County', 'US.MN.115', 'ASCII:Pine County;ID:5041542', '26295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26295', '112', '28172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28173', '1079', '1', 'Pipestone County', 'US.MN.117', 'ASCII:Pipestone County;ID:5041756', '26296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26296', '112', '28173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28174', '1079', '1', 'Polk County', 'US.MN.119', 'ASCII:Polk County;ID:5041970', '26297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26297', '112', '28174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28175', '1079', '1', 'Pope County', 'US.MN.121', 'ASCII:Pope County;ID:5042066', '26298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26298', '112', '28175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28176', '1079', '1', 'Ramsey County', 'US.MN.123', 'ASCII:Ramsey County;ID:5042563', '26299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26299', '112', '28176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28177', '1079', '1', 'Red Lake County', 'US.MN.125', 'ASCII:Red Lake County;ID:5042730', '26300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26300', '112', '28177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28178', '1079', '1', 'Redwood County', 'US.MN.127', 'ASCII:Redwood County;ID:5042847', '26301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26301', '112', '28178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28179', '1079', '1', 'Renville County', 'US.MN.129', 'ASCII:Renville County;ID:5042928', '26302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26302', '112', '28179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28180', '1079', '1', 'Rice County', 'US.MN.131', 'ASCII:Rice County;ID:5043007', '26303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26303', '112', '28180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28181', '1079', '1', 'Rock County', 'US.MN.133', 'ASCII:Rock County;ID:5043502', '26304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26304', '112', '28181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28182', '1079', '1', 'Roseau County', 'US.MN.135', 'ASCII:Roseau County;ID:5043753', '26305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26305', '112', '28182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28183', '1079', '1', 'Saint Louis County', 'US.MN.137', 'ASCII:Saint Louis County;ID:5045020', '26306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26306', '112', '28183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28184', '1079', '1', 'Scott County', 'US.MN.139', 'ASCII:Scott County;ID:5046749', '26307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26307', '112', '28184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28185', '1079', '1', 'Sherburne County', 'US.MN.141', 'ASCII:Sherburne County;ID:5047121', '26308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26308', '112', '28185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28186', '1079', '1', 'Sibley County', 'US.MN.143', 'ASCII:Sibley County;ID:5047260', '26309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26309', '112', '28186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28187', '1079', '1', 'Stearns County', 'US.MN.145', 'ASCII:Stearns County;ID:5048685', '26310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26310', '112', '28187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28188', '1079', '1', 'Steele County', 'US.MN.147', 'ASCII:Steele County;ID:5048696', '26311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26311', '112', '28188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28189', '1079', '1', 'Stevens County', 'US.MN.149', 'ASCII:Stevens County;ID:5048759', '26312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26312', '112', '28189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28190', '1079', '1', 'Swift County', 'US.MN.151', 'ASCII:Swift County;ID:5049534', '26313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26313', '112', '28190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28191', '1079', '1', 'Todd County', 'US.MN.153', 'ASCII:Todd County;ID:5050162', '26314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26314', '112', '28191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28192', '1079', '1', 'Traverse County', 'US.MN.155', 'ASCII:Traverse County;ID:5050331', '26315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26315', '112', '28192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28193', '1079', '1', 'Wabasha County', 'US.MN.157', 'ASCII:Wabasha County;ID:5051601', '26316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26316', '112', '28193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28194', '1079', '1', 'Wadena County', 'US.MN.159', 'ASCII:Wadena County;ID:5051662', '26317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26317', '112', '28194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28195', '1079', '1', 'Waseca County', 'US.MN.161', 'ASCII:Waseca County;ID:5051907', '26318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26318', '112', '28195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28196', '1079', '1', 'Washington County', 'US.MN.163', 'ASCII:Washington County;ID:5051936', '26319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26319', '112', '28196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28197', '1079', '1', 'Watonwan County', 'US.MN.165', 'ASCII:Watonwan County;ID:5052059', '26320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26320', '112', '28197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28198', '1079', '1', 'Wilkin County', 'US.MN.167', 'ASCII:Wilkin County;ID:5052862', '26321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26321', '112', '28198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28199', '1079', '1', 'Winona County', 'US.MN.169', 'ASCII:Winona County;ID:5053164', '26322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26322', '112', '28199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28200', '1079', '1', 'Wright County', 'US.MN.171', 'ASCII:Wright County;ID:5053485', '26323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26323', '112', '28200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28201', '1079', '1', 'Yellow Medicine County', 'US.MN.173', 'ASCII:Yellow Medicine County;ID:5053562', '26324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26324', '112', '28201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MN.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28202', '1079', '1', 'Adair County', 'US.MO.001', 'ASCII:Adair County;ID:5053853', '26325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26325', '112', '28202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28203', '1079', '1', 'Atchison County', 'US.MO.005', 'ASCII:Atchison County;ID:5053940', '26326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26326', '112', '28203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28204', '1079', '1', 'Clark County', 'US.MO.045', 'ASCII:Clark County;ID:5054481', '26327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26327', '112', '28204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28205', '1079', '1', 'Gentry County', 'US.MO.075', 'ASCII:Gentry County;ID:5055119', '26328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26328', '112', '28205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28206', '1079', '1', 'Grundy County', 'US.MO.079', 'ASCII:Grundy County;ID:5055285', '26329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26329', '112', '28206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28207', '1079', '1', 'Harrison County', 'US.MO.081', 'ASCII:Harrison County;ID:5055359', '26330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26330', '112', '28207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28208', '1079', '1', 'Holt County', 'US.MO.087', 'ASCII:Holt County;ID:5055521', '26331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26331', '112', '28208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28209', '1079', '1', 'Knox County', 'US.MO.103', 'ASCII:Knox County;ID:5055806', '26332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26332', '112', '28209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28210', '1079', '1', 'Lewis County', 'US.MO.111', 'ASCII:Lewis County;ID:5055902', '26333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26333', '112', '28210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28211', '1079', '1', 'Mercer County', 'US.MO.129', 'ASCII:Mercer County;ID:5056253', '26334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26334', '112', '28211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28212', '1079', '1', 'Nodaway County', 'US.MO.147', 'ASCII:Nodaway County;ID:5056549', '26335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26335', '112', '28212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28213', '1079', '1', 'Putnam County', 'US.MO.171', 'ASCII:Putnam County;ID:5056963', '26336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26336', '112', '28213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28214', '1079', '1', 'Schuyler County', 'US.MO.197', 'ASCII:Schuyler County;ID:5057186', '26337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26337', '112', '28214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28215', '1079', '1', 'Scotland County', 'US.MO.199', 'ASCII:Scotland County;ID:5057190', '26338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26338', '112', '28215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28216', '1079', '1', 'Sullivan County', 'US.MO.211', 'ASCII:Sullivan County;ID:5057455', '26339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26339', '112', '28216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28217', '1079', '1', 'Worth County', 'US.MO.227', 'ASCII:Worth County;ID:5057952', '26340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26340', '112', '28217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MO.227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28218', '1079', '1', 'Barnes County', 'US.ND.003', 'ASCII:Barnes County;ID:5058187', '26341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26341', '112', '28218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28219', '1079', '1', 'Benson County', 'US.ND.005', 'ASCII:Benson County;ID:5058251', '26342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26342', '112', '28219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28220', '1079', '1', 'Cass County', 'US.ND.017', 'ASCII:Cass County;ID:5058559', '26343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26343', '112', '28220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28221', '1079', '1', 'Cavalier County', 'US.ND.019', 'ASCII:Cavalier County;ID:5058571', '26344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26344', '112', '28221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28222', '1079', '1', 'Dickey County', 'US.ND.021', 'ASCII:Dickey County;ID:5058882', '26345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26345', '112', '28222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28223', '1079', '1', 'Eddy County', 'US.ND.027', 'ASCII:Eddy County;ID:5058990', '26346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26346', '112', '28223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28224', '1079', '1', 'Foster County', 'US.ND.031', 'ASCII:Foster County;ID:5059254', '26347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26347', '112', '28224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28225', '1079', '1', 'Grand Forks County', 'US.ND.035', 'ASCII:Grand Forks County;ID:5059430', '26348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26348', '112', '28225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28226', '1079', '1', 'Griggs County', 'US.ND.039', 'ASCII:Griggs County;ID:5059489', '26349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26349', '112', '28226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28227', '1079', '1', 'Kidder County', 'US.ND.043', 'ASCII:Kidder County;ID:5059961', '26350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26350', '112', '28227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28228', '1079', '1', 'LaMoure County', 'US.ND.045', 'ASCII:LaMoure County;ID:5060009', '26351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26351', '112', '28228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28229', '1079', '1', 'Logan County', 'US.ND.047', 'ASCII:Logan County;ID:5060192', '26352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26352', '112', '28229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28230', '1079', '1', 'McIntosh County', 'US.ND.051', 'ASCII:McIntosh County;ID:5060360', '26353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26353', '112', '28230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28231', '1079', '1', 'Nelson County', 'US.ND.063', 'ASCII:Nelson County;ID:5060593', '26354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26354', '112', '28231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28232', '1079', '1', 'Pembina County', 'US.ND.067', 'ASCII:Pembina County;ID:5060890', '26355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26355', '112', '28232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28233', '1079', '1', 'Ramsey County', 'US.ND.071', 'ASCII:Ramsey County;ID:5061063', '26356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26356', '112', '28233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28234', '1079', '1', 'Ransom County', 'US.ND.073', 'ASCII:Ransom County;ID:5061068', '26357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26357', '112', '28234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28235', '1079', '1', 'Richland County', 'US.ND.077', 'ASCII:Richland County;ID:5061114', '26358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26358', '112', '28235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28236', '1079', '1', 'Rolette County', 'US.ND.079', 'ASCII:Rolette County;ID:5061157', '26359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26359', '112', '28236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28237', '1079', '1', 'Sargent County', 'US.ND.081', 'ASCII:Sargent County;ID:5061439', '26360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26360', '112', '28237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28238', '1079', '1', 'Steele County', 'US.ND.091', 'ASCII:Steele County;ID:5062037', '26361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26361', '112', '28238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28239', '1079', '1', 'Stutsman County', 'US.ND.093', 'ASCII:Stutsman County;ID:5062096', '26362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26362', '112', '28239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28240', '1079', '1', 'Towner County', 'US.ND.095', 'ASCII:Towner County;ID:5062209', '26363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26363', '112', '28240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28241', '1079', '1', 'Traill County', 'US.ND.097', 'ASCII:Traill County;ID:5062211', '26364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26364', '112', '28241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28242', '1079', '1', 'Walsh County', 'US.ND.099', 'ASCII:Walsh County;ID:5062384', '26365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26365', '112', '28242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28243', '1079', '1', 'Wells County', 'US.ND.103', 'ASCII:Wells County;ID:5062441', '26366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26366', '112', '28243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28244', '1079', '1', 'Adams County', 'US.NE.001', 'ASCII:Adams County;ID:5062699', '26367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26367', '112', '28244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28245', '1079', '1', 'Antelope County', 'US.NE.003', 'ASCII:Antelope County;ID:5063023', '26368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26368', '112', '28245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28246', '1079', '1', 'Blaine County', 'US.NE.009', 'ASCII:Blaine County;ID:5064222', '26369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26369', '112', '28246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28247', '1079', '1', 'Boone County', 'US.NE.011', 'ASCII:Boone County;ID:5064432', '26370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26370', '112', '28247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28248', '1079', '1', 'Boyd County', 'US.NE.015', 'ASCII:Boyd County;ID:5064500', '26371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26371', '112', '28248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28249', '1079', '1', 'Brown County', 'US.NE.017', 'ASCII:Brown County;ID:5064663', '26372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26372', '112', '28249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28250', '1079', '1', 'Buffalo County', 'US.NE.019', 'ASCII:Buffalo County;ID:5064837', '26373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26373', '112', '28250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28251', '1079', '1', 'Burt County', 'US.NE.021', 'ASCII:Burt County;ID:5064925', '26374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26374', '112', '28251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28252', '1079', '1', 'Butler County', 'US.NE.023', 'ASCII:Butler County;ID:5064961', '26375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26375', '112', '28252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28253', '1079', '1', 'Cass County', 'US.NE.025', 'ASCII:Cass County;ID:5065267', '26376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26376', '112', '28253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28254', '1079', '1', 'Cedar County', 'US.NE.027', 'ASCII:Cedar County;ID:5065306', '26377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26377', '112', '28254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28255', '1079', '1', 'Clay County', 'US.NE.035', 'ASCII:Clay County;ID:5065828', '26378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26378', '112', '28255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28256', '1079', '1', 'Colfax County', 'US.NE.037', 'ASCII:Colfax County;ID:5065953', '26379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26379', '112', '28256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28257', '1079', '1', 'Cuming County', 'US.NE.039', 'ASCII:Cuming County;ID:5066574', '26380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26380', '112', '28257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28258', '1079', '1', 'Custer County', 'US.NE.041', 'ASCII:Custer County;ID:5066605', '26381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26381', '112', '28258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28259', '1079', '1', 'Dakota County', 'US.NE.043', 'ASCII:Dakota County;ID:5066642', '26382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26382', '112', '28259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28260', '1079', '1', 'Dawson County', 'US.NE.047', 'ASCII:Dawson County;ID:5066750', '26383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26383', '112', '28260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28261', '1079', '1', 'Dixon County', 'US.NE.051', 'ASCII:Dixon County;ID:5067019', '26384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26384', '112', '28261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28262', '1079', '1', 'Dodge County', 'US.NE.053', 'ASCII:Dodge County;ID:5067039', '26385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26385', '112', '28262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28263', '1079', '1', 'Douglas County', 'US.NE.055', 'ASCII:Douglas County;ID:5067114', '26386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26386', '112', '28263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28264', '1079', '1', 'Fillmore County', 'US.NE.059', 'ASCII:Fillmore County;ID:5068222', '26387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26387', '112', '28264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28265', '1079', '1', 'Franklin County', 'US.NE.061', 'ASCII:Franklin County;ID:5068649', '26388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26388', '112', '28265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28266', '1079', '1', 'Furnas County', 'US.NE.065', 'ASCII:Furnas County;ID:5068841', '26389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26389', '112', '28266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28267', '1079', '1', 'Gage County', 'US.NE.067', 'ASCII:Gage County;ID:5068853', '26390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26390', '112', '28267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28268', '1079', '1', 'Garfield County', 'US.NE.071', 'ASCII:Garfield County;ID:5068888', '26391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26391', '112', '28268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28269', '1079', '1', 'Gosper County', 'US.NE.073', 'ASCII:Gosper County;ID:5069211', '26392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26392', '112', '28269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28270', '1079', '1', 'Greeley County', 'US.NE.077', 'ASCII:Greeley County;ID:5069397', '26393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26393', '112', '28270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28271', '1079', '1', 'Hall County', 'US.NE.079', 'ASCII:Hall County;ID:5069587', '26394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26394', '112', '28271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28272', '1079', '1', 'Hamilton County', 'US.NE.081', 'ASCII:Hamilton County;ID:5069604', '26395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26395', '112', '28272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28273', '1079', '1', 'Harlan County', 'US.NE.083', 'ASCII:Harlan County;ID:5069693', '26396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26396', '112', '28273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28274', '1079', '1', 'Holt County', 'US.NE.089', 'ASCII:Holt County;ID:5070270', '26397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26397', '112', '28274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28275', '1079', '1', 'Howard County', 'US.NE.093', 'ASCII:Howard County;ID:5070443', '26398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26398', '112', '28275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28276', '1079', '1', 'Jefferson County', 'US.NE.095', 'ASCII:Jefferson County;ID:5070975', '26399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26399', '112', '28276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28277', '1079', '1', 'Johnson County', 'US.NE.097', 'ASCII:Johnson County;ID:5071072', '26400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26400', '112', '28277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28278', '1079', '1', 'Kearney County', 'US.NE.099', 'ASCII:Kearney County;ID:5071364', '26401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26401', '112', '28278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28279', '1079', '1', 'Knox County', 'US.NE.107', 'ASCII:Knox County;ID:5071580', '26402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26402', '112', '28279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28280', '1079', '1', 'Lancaster County', 'US.NE.109', 'ASCII:Lancaster County;ID:5071741', '26403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26403', '112', '28280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28281', '1079', '1', 'Loup County', 'US.NE.115', 'ASCII:Loup County;ID:5072388', '26404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26404', '112', '28281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28282', '1079', '1', 'Madison County', 'US.NE.119', 'ASCII:Madison County;ID:5072535', '26405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26405', '112', '28282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28283', '1079', '1', 'Merrick County', 'US.NE.121', 'ASCII:Merrick County;ID:5072973', '26406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26406', '112', '28283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28284', '1079', '1', 'Nance County', 'US.NE.125', 'ASCII:Nance County;ID:5073611', '26407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26407', '112', '28284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28285', '1079', '1', 'Nemaha County', 'US.NE.127', 'ASCII:Nemaha County;ID:5073780', '26408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26408', '112', '28285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28286', '1079', '1', 'Nuckolls County', 'US.NE.129', 'ASCII:Nuckolls County;ID:5074208', '26409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26409', '112', '28286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28287', '1079', '1', 'Otoe County', 'US.NE.131', 'ASCII:Otoe County;ID:5074642', '26410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26410', '112', '28287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28288', '1079', '1', 'Pawnee County', 'US.NE.133', 'ASCII:Pawnee County;ID:5074895', '26411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26411', '112', '28288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28289', '1079', '1', 'Phelps County', 'US.NE.137', 'ASCII:Phelps County;ID:5075078', '26412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26412', '112', '28289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28290', '1079', '1', 'Pierce County', 'US.NE.139', 'ASCII:Pierce County;ID:5075153', '26413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26413', '112', '28290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28291', '1079', '1', 'Platte County', 'US.NE.141', 'ASCII:Platte County;ID:5075315', '26414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26414', '112', '28291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28292', '1079', '1', 'Polk County', 'US.NE.143', 'ASCII:Polk County;ID:5075605', '26415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26415', '112', '28292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28293', '1079', '1', 'Richardson County', 'US.NE.147', 'ASCII:Richardson County;ID:5076190', '26416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26416', '112', '28293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28294', '1079', '1', 'Rock County', 'US.NE.149', 'ASCII:Rock County;ID:5076351', '26417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26417', '112', '28294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28295', '1079', '1', 'Saline County', 'US.NE.151', 'ASCII:Saline County;ID:5077506', '26418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26418', '112', '28295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28296', '1079', '1', 'Sarpy County', 'US.NE.153', 'ASCII:Sarpy County;ID:5077695', '26419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26419', '112', '28296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28297', '1079', '1', 'Saunders County', 'US.NE.155', 'ASCII:Saunders County;ID:5077708', '26420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26420', '112', '28297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28298', '1079', '1', 'Seward County', 'US.NE.159', 'ASCII:Seward County;ID:5078798', '26421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26421', '112', '28298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28299', '1079', '1', 'Sherman County', 'US.NE.163', 'ASCII:Sherman County;ID:5078904', '26422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26422', '112', '28299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28300', '1079', '1', 'Stanton County', 'US.NE.167', 'ASCII:Stanton County;ID:5079543', '26423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26423', '112', '28300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.167» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28301', '1079', '1', 'Thayer County', 'US.NE.169', 'ASCII:Thayer County;ID:5080164', '26424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26424', '112', '28301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28302', '1079', '1', 'Thurston County', 'US.NE.173', 'ASCII:Thurston County;ID:5080274', '26425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26425', '112', '28302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28303', '1079', '1', 'Valley County', 'US.NE.175', 'ASCII:Valley County;ID:5081000', '26426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26426', '112', '28303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28304', '1079', '1', 'Washington County', 'US.NE.177', 'ASCII:Washington County;ID:5081383', '26427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26427', '112', '28304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.177» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28305', '1079', '1', 'Wayne County', 'US.NE.179', 'ASCII:Wayne County;ID:5081458', '26428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26428', '112', '28305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28306', '1079', '1', 'Webster County', 'US.NE.181', 'ASCII:Webster County;ID:5081496', '26429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26429', '112', '28306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28307', '1079', '1', 'Wheeler County', 'US.NE.183', 'ASCII:Wheeler County;ID:5081776', '26430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26430', '112', '28307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28308', '1079', '1', 'York County', 'US.NE.185', 'ASCII:York County;ID:5082335', '26431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26431', '112', '28308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28309', '1079', '1', 'Belknap County', 'US.NH.001', 'ASCII:Belknap County;ID:5083273', '26432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26432', '112', '28309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NH.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28310', '1079', '1', 'Carroll County', 'US.NH.003', 'ASCII:Carroll County;ID:5084247', '26433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26433', '112', '28310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NH.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28311', '1079', '1', 'Cheshire County', 'US.NH.005', 'ASCII:Cheshire County;ID:5084505', '26434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26434', '112', '28311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NH.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28312', '1079', '1', 'Coos County', 'US.NH.007', 'ASCII:Coos County;ID:5084973', '26435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26435', '112', '28312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NH.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28313', '1079', '1', 'Grafton County', 'US.NH.009', 'ASCII:Grafton County;ID:5086767', '26436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26436', '112', '28313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NH.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28314', '1079', '1', 'Hillsborough County', 'US.NH.011', 'ASCII:Hillsborough County;ID:5087463', '26437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26437', '112', '28314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NH.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28315', '1079', '1', 'Merrimack County', 'US.NH.013', 'ASCII:Merrimack County;ID:5089480', '26438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26438', '112', '28315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NH.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28316', '1079', '1', 'Rockingham County', 'US.NH.015', 'ASCII:Rockingham County;ID:5091860', '26439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26439', '112', '28316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NH.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28317', '1079', '1', 'Strafford County', 'US.NH.017', 'ASCII:Strafford County;ID:5093237', '26440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26440', '112', '28317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NH.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28318', '1079', '1', 'Sullivan County', 'US.NH.019', 'ASCII:Sullivan County;ID:5093334', '26441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26441', '112', '28318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NH.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28319', '1079', '1', 'Bergen County', 'US.NJ.003', 'ASCII:Bergen County;ID:5095598', '26442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26442', '112', '28319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28320', '1079', '1', 'Essex County', 'US.NJ.013', 'ASCII:Essex County;ID:5097707', '26443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26443', '112', '28320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28321', '1079', '1', 'Hudson County', 'US.NJ.017', 'ASCII:Hudson County;ID:5099357', '26444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26444', '112', '28321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28322', '1079', '1', 'Hunterdon County', 'US.NJ.019', 'ASCII:Hunterdon County;ID:5099381', '26445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26445', '112', '28322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28323', '1079', '1', 'Mercer County', 'US.NJ.021', 'ASCII:Mercer County;ID:5101090', '26446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26446', '112', '28323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28324', '1079', '1', 'Middlesex County', 'US.NJ.023', 'ASCII:Middlesex County;ID:5101160', '26447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26447', '112', '28324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28325', '1079', '1', 'Monmouth County', 'US.NJ.025', 'ASCII:Monmouth County;ID:5101305', '26448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26448', '112', '28325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28326', '1079', '1', 'Morris County', 'US.NJ.027', 'ASCII:Morris County;ID:5101405', '26449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26449', '112', '28326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28327', '1079', '1', 'Passaic County', 'US.NJ.031', 'ASCII:Passaic County;ID:5102445', '26450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26450', '112', '28327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28328', '1079', '1', 'Somerset County', 'US.NJ.035', 'ASCII:Somerset County;ID:5104759', '26451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26451', '112', '28328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28329', '1079', '1', 'Sussex County', 'US.NJ.037', 'ASCII:Sussex County;ID:5105168', '26452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26452', '112', '28329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28330', '1079', '1', 'Union County', 'US.NJ.039', 'ASCII:Union County;ID:5105640', '26453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26453', '112', '28330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28331', '1079', '1', 'Warren County', 'US.NJ.041', 'ASCII:Warren County;ID:5106044', '26454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26454', '112', '28331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NJ.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28332', '1079', '1', 'Albany County', 'US.NY.001', 'ASCII:Albany County;ID:5106841', '26455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26455', '112', '28332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28333', '1079', '1', 'Allegany County', 'US.NY.003', 'ASCII:Allegany County;ID:5106997', '26456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26456', '112', '28333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28334', '1079', '1', 'Bronx', 'US.NY.005', 'ASCII:Bronx County;ID:5110253', '26457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26457', '112', '28334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28335', '1079', '1', 'Broome County', 'US.NY.007', 'ASCII:Broome County;ID:5110365', '26458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26458', '112', '28335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28336', '1079', '1', 'Cattaraugus County', 'US.NY.009', 'ASCII:Cattaraugus County;ID:5111846', '26459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26459', '112', '28336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28337', '1079', '1', 'Cayuga County', 'US.NY.011', 'ASCII:Cayuga County;ID:5111868', '26460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26460', '112', '28337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28338', '1079', '1', 'Chautauqua County', 'US.NY.013', 'ASCII:Chautauqua County;ID:5112358', '26461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26461', '112', '28338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28339', '1079', '1', 'Chemung County', 'US.NY.015', 'ASCII:Chemung County;ID:5112392', '26462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26462', '112', '28339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28340', '1079', '1', 'Chenango County', 'US.NY.017', 'ASCII:Chenango County;ID:5112398', '26463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26463', '112', '28340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28341', '1079', '1', 'Clinton County', 'US.NY.019', 'ASCII:Clinton County;ID:5112977', '26464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26464', '112', '28341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28342', '1079', '1', 'Columbia County', 'US.NY.021', 'ASCII:Columbia County;ID:5113366', '26465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26465', '112', '28342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28343', '1079', '1', 'Cortland County', 'US.NY.023', 'ASCII:Cortland County;ID:5113792', '26466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26466', '112', '28343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28344', '1079', '1', 'Delaware County', 'US.NY.025', 'ASCII:Delaware County;ID:5114810', '26467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26467', '112', '28344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28345', '1079', '1', 'Dutchess County', 'US.NY.027', 'ASCII:Dutchess County;ID:5115580', '26468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26468', '112', '28345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28346', '1079', '1', 'Erie County', 'US.NY.029', 'ASCII:Erie County;ID:5116642', '26469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26469', '112', '28346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28347', '1079', '1', 'Essex County', 'US.NY.031', 'ASCII:Essex County;ID:5116680', '26470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26470', '112', '28347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28348', '1079', '1', 'Franklin County', 'US.NY.033', 'ASCII:Franklin County;ID:5117867', '26471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26471', '112', '28348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28349', '1079', '1', 'Fulton County', 'US.NY.035', 'ASCII:Fulton County;ID:5118116', '26472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26472', '112', '28349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28350', '1079', '1', 'Genesee County', 'US.NY.037', 'ASCII:Genesee County;ID:5118380', '26473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26473', '112', '28350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28351', '1079', '1', 'Greene County', 'US.NY.039', 'ASCII:Greene County;ID:5119355', '26474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26474', '112', '28351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28352', '1079', '1', 'Hamilton County', 'US.NY.041', 'ASCII:Hamilton County;ID:5119847', '26475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26475', '112', '28352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28353', '1079', '1', 'Herkimer County', 'US.NY.043', 'ASCII:Herkimer County;ID:5120548', '26476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26476', '112', '28353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28354', '1079', '1', 'Jefferson County', 'US.NY.045', 'ASCII:Jefferson County;ID:5122581', '26477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26477', '112', '28354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28355', '1079', '1', 'Lewis County', 'US.NY.049', 'ASCII:Lewis County;ID:5124290', '26478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26478', '112', '28355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28356', '1079', '1', 'Livingston County', 'US.NY.051', 'ASCII:Livingston County;ID:5124928', '26479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26479', '112', '28356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28357', '1079', '1', 'Madison County', 'US.NY.053', 'ASCII:Madison County;ID:5125630', '26480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26480', '112', '28357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28358', '1079', '1', 'Monroe County', 'US.NY.055', 'ASCII:Monroe County;ID:5127305', '26481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26481', '112', '28358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28359', '1079', '1', 'Montgomery County', 'US.NY.057', 'ASCII:Montgomery County;ID:5127354', '26482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26482', '112', '28359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28360', '1079', '1', 'Nassau County', 'US.NY.059', 'ASCII:Nassau County;ID:5128316', '26483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26483', '112', '28360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28361', '1079', '1', 'New York County', 'US.NY.061', 'ASCII:New York County;ID:5128594', '26484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26484', '112', '28361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28362', '1079', '1', 'Niagara County', 'US.NY.063', 'ASCII:Niagara County;ID:5128734', '26485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26485', '112', '28362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28363', '1079', '1', 'Oneida County', 'US.NY.065', 'ASCII:Oneida County;ID:5129832', '26486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26486', '112', '28363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28364', '1079', '1', 'Onondaga County', 'US.NY.067', 'ASCII:Onondaga County;ID:5129867', '26487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26487', '112', '28364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28365', '1079', '1', 'Ontario County', 'US.NY.069', 'ASCII:Ontario County;ID:5129891', '26488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26488', '112', '28365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28366', '1079', '1', 'Orange County', 'US.NY.071', 'ASCII:Orange County;ID:5129915', '26489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26489', '112', '28366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28367', '1079', '1', 'Orleans County', 'US.NY.073', 'ASCII:Orleans County;ID:5129995', '26490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26490', '112', '28367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28368', '1079', '1', 'Oswego County', 'US.NY.075', 'ASCII:Oswego County;ID:5130076', '26491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26491', '112', '28368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28369', '1079', '1', 'Otsego County', 'US.NY.077', 'ASCII:Otsego County;ID:5130111', '26492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26492', '112', '28369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28370', '1079', '1', 'Putnam County', 'US.NY.079', 'ASCII:Putnam County;ID:5133166', '26493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26493', '112', '28370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28371', '1079', '1', 'Queens County', 'US.NY.081', 'ASCII:Queens County;ID:5133268', '26494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26494', '112', '28371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28372', '1079', '1', 'Rensselaer County', 'US.NY.083', 'ASCII:Rensselaer County;ID:5133668', '26495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26495', '112', '28372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28373', '1079', '1', 'Rockland County', 'US.NY.087', 'ASCII:Rockland County;ID:5134189', '26496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26496', '112', '28373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28374', '1079', '1', 'St. Lawrence County', 'US.NY.089', 'ASCII:St. Lawrence County;ID:5135484', '26497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26497', '112', '28374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28375', '1079', '1', 'Saratoga County', 'US.NY.091', 'ASCII:Saratoga County;ID:5136325', '26498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26498', '112', '28375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28376', '1079', '1', 'Schenectady County', 'US.NY.093', 'ASCII:Schenectady County;ID:5136456', '26499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26499', '112', '28376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28377', '1079', '1', 'Schoharie County', 'US.NY.095', 'ASCII:Schoharie County;ID:5136495', '26500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26500', '112', '28377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28378', '1079', '1', 'Schuyler County', 'US.NY.097', 'ASCII:Schuyler County;ID:5137368', '26501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26501', '112', '28378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28379', '1079', '1', 'Seneca County', 'US.NY.099', 'ASCII:Seneca County;ID:5137620', '26502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26502', '112', '28379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28380', '1079', '1', 'Richmond County', 'US.NY.085', 'ASCII:Richmond County;ID:5139559', '26503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26503', '112', '28380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28381', '1079', '1', 'Steuben County', 'US.NY.101', 'ASCII:Steuben County;ID:5139656', '26504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26504', '112', '28381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28382', '1079', '1', 'Suffolk County', 'US.NY.103', 'ASCII:Suffolk County;ID:5140076', '26505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26505', '112', '28382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28383', '1079', '1', 'Sullivan County', 'US.NY.105', 'ASCII:Sullivan County;ID:5140135', '26506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26506', '112', '28383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28384', '1079', '1', 'Tioga County', 'US.NY.107', 'ASCII:Tioga County;ID:5141045', '26507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26507', '112', '28384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28385', '1079', '1', 'Tompkins County', 'US.NY.109', 'ASCII:Tompkins County;ID:5141153', '26508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26508', '112', '28385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28386', '1079', '1', 'Ulster County', 'US.NY.111', 'ASCII:Ulster County;ID:5141784', '26509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26509', '112', '28386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28387', '1079', '1', 'Warren County', 'US.NY.113', 'ASCII:Warren County;ID:5143268', '26510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26510', '112', '28387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28388', '1079', '1', 'Washington County', 'US.NY.115', 'ASCII:Washington County;ID:5143303', '26511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26511', '112', '28388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28389', '1079', '1', 'Wayne County', 'US.NY.117', 'ASCII:Wayne County;ID:5143455', '26512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26512', '112', '28389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28390', '1079', '1', 'Westchester County', 'US.NY.119', 'ASCII:Westchester County;ID:5144050', '26513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26513', '112', '28390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28391', '1079', '1', 'Wyoming County', 'US.NY.121', 'ASCII:Wyoming County;ID:5145163', '26514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26514', '112', '28391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28392', '1079', '1', 'Yates County', 'US.NY.123', 'ASCII:Yates County;ID:5145190', '26515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26515', '112', '28392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28393', '1079', '1', 'Allen County', 'US.OH.003', 'ASCII:Allen County;ID:5145576', '26516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26516', '112', '28393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28394', '1079', '1', 'Ashland County', 'US.OH.005', 'ASCII:Ashland County;ID:5146062', '26517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26517', '112', '28394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28395', '1079', '1', 'Ashtabula County', 'US.OH.007', 'ASCII:Ashtabula County;ID:5146092', '26518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26518', '112', '28395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28396', '1079', '1', 'Auglaize County', 'US.OH.011', 'ASCII:Auglaize County;ID:5146199', '26519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26519', '112', '28396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28397', '1079', '1', 'Belmont County', 'US.OH.013', 'ASCII:Belmont County;ID:5147012', '26520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26520', '112', '28397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28398', '1079', '1', 'Carroll County', 'US.OH.019', 'ASCII:Carroll County;ID:5149311', '26521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26521', '112', '28398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28399', '1079', '1', 'Champaign County', 'US.OH.021', 'ASCII:Champaign County;ID:5149757', '26522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26522', '112', '28399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28400', '1079', '1', 'Columbiana County', 'US.OH.029', 'ASCII:Columbiana County;ID:5150853', '26523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26523', '112', '28400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28401', '1079', '1', 'Coshocton County', 'US.OH.031', 'ASCII:Coshocton County;ID:5151190', '26524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26524', '112', '28401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28402', '1079', '1', 'Crawford County', 'US.OH.033', 'ASCII:Crawford County;ID:5151374', '26525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26525', '112', '28402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28403', '1079', '1', 'Cuyahoga County', 'US.OH.035', 'ASCII:Cuyahoga County;ID:5151606', '26526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26526', '112', '28403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28404', '1079', '1', 'Darke County', 'US.OH.037', 'ASCII:Darke County;ID:5151705', '26527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26527', '112', '28404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28405', '1079', '1', 'Defiance County', 'US.OH.039', 'ASCII:Defiance County;ID:5151865', '26528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26528', '112', '28405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28406', '1079', '1', 'Delaware County', 'US.OH.041', 'ASCII:Delaware County;ID:5151896', '26529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26529', '112', '28406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28407', '1079', '1', 'Erie County', 'US.OH.043', 'ASCII:Erie County;ID:5153362', '26530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26530', '112', '28407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28408', '1079', '1', 'Fulton County', 'US.OH.051', 'ASCII:Fulton County;ID:5155347', '26531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26531', '112', '28408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28409', '1079', '1', 'Geauga County', 'US.OH.055', 'ASCII:Geauga County;ID:5155556', '26532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26532', '112', '28409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28410', '1079', '1', 'Guernsey County', 'US.OH.059', 'ASCII:Guernsey County;ID:5156615', '26533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26533', '112', '28410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28411', '1079', '1', 'Hancock County', 'US.OH.063', 'ASCII:Hancock County;ID:5156770', '26534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26534', '112', '28411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28412', '1079', '1', 'Hardin County', 'US.OH.065', 'ASCII:Hardin County;ID:5156844', '26535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26535', '112', '28412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28413', '1079', '1', 'Harrison County', 'US.OH.067', 'ASCII:Harrison County;ID:5156975', '26536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26536', '112', '28413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28414', '1079', '1', 'Henry County', 'US.OH.069', 'ASCII:Henry County;ID:5157338', '26537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26537', '112', '28414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28415', '1079', '1', 'Holmes County', 'US.OH.075', 'ASCII:Holmes County;ID:5157783', '26538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26538', '112', '28415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28416', '1079', '1', 'Huron County', 'US.OH.077', 'ASCII:Huron County;ID:5158275', '26539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26539', '112', '28416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28417', '1079', '1', 'Jefferson County', 'US.OH.081', 'ASCII:Jefferson County;ID:5159079', '26540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26540', '112', '28417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28418', '1079', '1', 'Knox County', 'US.OH.083', 'ASCII:Knox County;ID:5159891', '26541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26541', '112', '28418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28419', '1079', '1', 'Lake County', 'US.OH.085', 'ASCII:Lake County;ID:5160090', '26542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26542', '112', '28419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28420', '1079', '1', 'Licking County', 'US.OH.089', 'ASCII:Licking County;ID:5160740', '26543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26543', '112', '28420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28421', '1079', '1', 'Logan County', 'US.OH.091', 'ASCII:Logan County;ID:5161156', '26544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26544', '112', '28421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28422', '1079', '1', 'Lorain County', 'US.OH.093', 'ASCII:Lorain County;ID:5161272', '26545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26545', '112', '28422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28423', '1079', '1', 'Lucas County', 'US.OH.095', 'ASCII:Lucas County;ID:5161413', '26546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26546', '112', '28423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28424', '1079', '1', 'Mahoning County', 'US.OH.099', 'ASCII:Mahoning County;ID:5161640', '26547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26547', '112', '28424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28425', '1079', '1', 'Marion County', 'US.OH.101', 'ASCII:Marion County;ID:5161911', '26548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26548', '112', '28425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28426', '1079', '1', 'Medina County', 'US.OH.103', 'ASCII:Medina County;ID:5162517', '26549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26549', '112', '28426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28427', '1079', '1', 'Mercer County', 'US.OH.107', 'ASCII:Mercer County;ID:5162679', '26550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26550', '112', '28427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28428', '1079', '1', 'Miami County', 'US.OH.109', 'ASCII:Miami County;ID:5162774', '26551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26551', '112', '28428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28429', '1079', '1', 'Morrow County', 'US.OH.117', 'ASCII:Morrow County;ID:5163509', '26552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26552', '112', '28429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28430', '1079', '1', 'Ottawa County', 'US.OH.123', 'ASCII:Ottawa County;ID:5165803', '26553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26553', '112', '28430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28431', '1079', '1', 'Paulding County', 'US.OH.125', 'ASCII:Paulding County;ID:5166256', '26554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26554', '112', '28431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28432', '1079', '1', 'Portage County', 'US.OH.133', 'ASCII:Portage County;ID:5167284', '26555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26555', '112', '28432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28433', '1079', '1', 'Putnam County', 'US.OH.137', 'ASCII:Putnam County;ID:5167574', '26556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26556', '112', '28433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28434', '1079', '1', 'Richland County', 'US.OH.139', 'ASCII:Richland County;ID:5168041', '26557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26557', '112', '28434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28435', '1079', '1', 'Sandusky County', 'US.OH.143', 'ASCII:Sandusky County;ID:5170698', '26558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26558', '112', '28435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28436', '1079', '1', 'Seneca County', 'US.OH.147', 'ASCII:Seneca County;ID:5171643', '26559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26559', '112', '28436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.147» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28437', '1079', '1', 'Shelby County', 'US.OH.149', 'ASCII:Shelby County;ID:5171871', '26560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26560', '112', '28437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.149» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28438', '1079', '1', 'Stark County', 'US.OH.151', 'ASCII:Stark County;ID:5172936', '26561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26561', '112', '28438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28439', '1079', '1', 'Summit County', 'US.OH.153', 'ASCII:Summit County;ID:5173386', '26562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26562', '112', '28439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28440', '1079', '1', 'Trumbull County', 'US.OH.155', 'ASCII:Trumbull County;ID:5174418', '26563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26563', '112', '28440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.155» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28441', '1079', '1', 'Tuscarawas County', 'US.OH.157', 'ASCII:Tuscarawas County;ID:5174499', '26564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26564', '112', '28441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28442', '1079', '1', 'Union County', 'US.OH.159', 'ASCII:Union County;ID:5174669', '26565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26565', '112', '28442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.159» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28443', '1079', '1', 'Van Wert County', 'US.OH.161', 'ASCII:Van Wert County;ID:5175012', '26566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26566', '112', '28443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28444', '1079', '1', 'Wayne County', 'US.OH.169', 'ASCII:Wayne County;ID:5175898', '26567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26567', '112', '28444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28445', '1079', '1', 'Williams County', 'US.OH.171', 'ASCII:Williams County;ID:5176872', '26568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26568', '112', '28445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28446', '1079', '1', 'Wood County', 'US.OH.173', 'ASCII:Wood County;ID:5177229', '26569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26569', '112', '28446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28447', '1079', '1', 'Wyandot County', 'US.OH.175', 'ASCII:Wyandot County;ID:5177434', '26570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26570', '112', '28447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OH.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28448', '1079', '1', 'Allegheny County', 'US.PA.003', 'ASCII:Allegheny County;ID:5178040', '26571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26571', '112', '28448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28449', '1079', '1', 'Armstrong County', 'US.PA.005', 'ASCII:Armstrong County;ID:5178515', '26572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26572', '112', '28449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28450', '1079', '1', 'Beaver County', 'US.PA.007', 'ASCII:Beaver County;ID:5179454', '26573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26573', '112', '28450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28451', '1079', '1', 'Bedford County', 'US.PA.009', 'ASCII:Bedford County;ID:5179633', '26574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26574', '112', '28451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28452', '1079', '1', 'Berks County', 'US.PA.011', 'ASCII:Berks County;ID:5180052', '26575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26575', '112', '28452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28453', '1079', '1', 'Blair County', 'US.PA.013', 'ASCII:Blair County;ID:5180809', '26576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26576', '112', '28453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28454', '1079', '1', 'Bradford County', 'US.PA.015', 'ASCII:Bradford County;ID:5181416', '26577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26577', '112', '28454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28455', '1079', '1', 'Bucks County', 'US.PA.017', 'ASCII:Bucks County;ID:5182201', '26578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26578', '112', '28455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28456', '1079', '1', 'Butler County', 'US.PA.019', 'ASCII:Butler County;ID:5182539', '26579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26579', '112', '28456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28457', '1079', '1', 'Cambria County', 'US.PA.021', 'ASCII:Cambria County;ID:5182829', '26580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26580', '112', '28457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28458', '1079', '1', 'Cameron County', 'US.PA.023', 'ASCII:Cameron County;ID:5182858', '26581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26581', '112', '28458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28459', '1079', '1', 'Carbon County', 'US.PA.025', 'ASCII:Carbon County;ID:5183193', '26582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26582', '112', '28459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28460', '1079', '1', 'Centre County', 'US.PA.027', 'ASCII:Centre County;ID:5183763', '26583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26583', '112', '28460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28461', '1079', '1', 'Chester County', 'US.PA.029', 'ASCII:Chester County;ID:5184079', '26584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26584', '112', '28461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28462', '1079', '1', 'Clarion County', 'US.PA.031', 'ASCII:Clarion County;ID:5184423', '26585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26585', '112', '28462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28463', '1079', '1', 'Clearfield County', 'US.PA.033', 'ASCII:Clearfield County;ID:5184546', '26586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26586', '112', '28463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28464', '1079', '1', 'Clinton County', 'US.PA.035', 'ASCII:Clinton County;ID:5184630', '26587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26587', '112', '28464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28465', '1079', '1', 'Columbia County', 'US.PA.037', 'ASCII:Columbia County;ID:5185032', '26588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26588', '112', '28465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28466', '1079', '1', 'Crawford County', 'US.PA.039', 'ASCII:Crawford County;ID:5185801', '26589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26589', '112', '28466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28467', '1079', '1', 'Cumberland County', 'US.PA.041', 'ASCII:Cumberland County;ID:5186106', '26590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26590', '112', '28467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28468', '1079', '1', 'Dauphin County', 'US.PA.043', 'ASCII:Dauphin County;ID:5186395', '26591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26591', '112', '28468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28469', '1079', '1', 'Delaware County', 'US.PA.045', 'ASCII:Delaware County;ID:5186677', '26592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26592', '112', '28469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28470', '1079', '1', 'Elk County', 'US.PA.047', 'ASCII:Elk County;ID:5188486', '26593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26593', '112', '28470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28471', '1079', '1', 'Erie County', 'US.PA.049', 'ASCII:Erie County;ID:5188847', '26594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26594', '112', '28471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28472', '1079', '1', 'Fayette County', 'US.PA.051', 'ASCII:Fayette County;ID:5189414', '26595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26595', '112', '28472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28473', '1079', '1', 'Forest County', 'US.PA.053', 'ASCII:Forest County;ID:5189967', '26596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26596', '112', '28473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28474', '1079', '1', 'Franklin County', 'US.PA.055', 'ASCII:Franklin County;ID:5190337', '26597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26597', '112', '28474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28475', '1079', '1', 'Fulton County', 'US.PA.057', 'ASCII:Fulton County;ID:5190669', '26598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26598', '112', '28475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28476', '1079', '1', 'Greene County', 'US.PA.059', 'ASCII:Greene County;ID:5191994', '26599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26599', '112', '28476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28477', '1079', '1', 'Huntingdon County', 'US.PA.061', 'ASCII:Huntingdon County;ID:5194592', '26600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26600', '112', '28477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28478', '1079', '1', 'Indiana County', 'US.PA.063', 'ASCII:Indiana County;ID:5194872', '26601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26601', '112', '28478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28479', '1079', '1', 'Jefferson County', 'US.PA.065', 'ASCII:Jefferson County;ID:5195307', '26602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26602', '112', '28479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28480', '1079', '1', 'Juniata County', 'US.PA.067', 'ASCII:Juniata County;ID:5195677', '26603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26603', '112', '28480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28481', '1079', '1', 'Lackawanna County', 'US.PA.069', 'ASCII:Lackawanna County;ID:5196674', '26604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26604', '112', '28481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28482', '1079', '1', 'Lancaster County', 'US.PA.071', 'ASCII:Lancaster County;ID:5197085', '26605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26605', '112', '28482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28483', '1079', '1', 'Lawrence County', 'US.PA.073', 'ASCII:Lawrence County;ID:5197440', '26606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26606', '112', '28483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28484', '1079', '1', 'Lebanon County', 'US.PA.075', 'ASCII:Lebanon County;ID:5197522', '26607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26607', '112', '28484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28485', '1079', '1', 'Lehigh County', 'US.PA.077', 'ASCII:Lehigh County;ID:5197646', '26608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26608', '112', '28485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28486', '1079', '1', 'Luzerne County', 'US.PA.079', 'ASCII:Luzerne County;ID:5199309', '26609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26609', '112', '28486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28487', '1079', '1', 'Lycoming County', 'US.PA.081', 'ASCII:Lycoming County;ID:5199318', '26610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26610', '112', '28487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28488', '1079', '1', 'McKean County', 'US.PA.083', 'ASCII:McKean County;ID:5200448', '26611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26611', '112', '28488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28489', '1079', '1', 'Mercer County', 'US.PA.085', 'ASCII:Mercer County;ID:5200801', '26612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26612', '112', '28489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28490', '1079', '1', 'Mifflin County', 'US.PA.087', 'ASCII:Mifflin County;ID:5201068', '26613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26613', '112', '28490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28491', '1079', '1', 'Monroe County', 'US.PA.089', 'ASCII:Monroe County;ID:5201707', '26614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26614', '112', '28491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28492', '1079', '1', 'Montgomery County', 'US.PA.091', 'ASCII:Montgomery County;ID:5201756', '26615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26615', '112', '28492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28493', '1079', '1', 'Montour County', 'US.PA.093', 'ASCII:Montour County;ID:5201786', '26616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26616', '112', '28493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28494', '1079', '1', 'Northampton County', 'US.PA.095', 'ASCII:Northampton County;ID:5203809', '26617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26617', '112', '28494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28495', '1079', '1', 'Northumberland County', 'US.PA.097', 'ASCII:Northumberland County;ID:5203860', '26618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26618', '112', '28495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28496', '1079', '1', 'Perry County', 'US.PA.099', 'ASCII:Perry County;ID:5205669', '26619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26619', '112', '28496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28497', '1079', '1', 'Philadelphia County', 'US.PA.101', 'ASCII:Philadelphia County;ID:5205788', '26620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26620', '112', '28497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28498', '1079', '1', 'Pike County', 'US.PA.103', 'ASCII:Pike County;ID:5205930', '26621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26621', '112', '28498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28499', '1079', '1', 'Potter County', 'US.PA.105', 'ASCII:Potter County;ID:5207042', '26622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26622', '112', '28499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28500', '1079', '1', 'Schuylkill County', 'US.PA.107', 'ASCII:Schuylkill County;ID:5211208', '26623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26623', '112', '28500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28501', '1079', '1', 'Snyder County', 'US.PA.109', 'ASCII:Snyder County;ID:5212772', '26624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26624', '112', '28501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28502', '1079', '1', 'Somerset County', 'US.PA.111', 'ASCII:Somerset County;ID:5212857', '26625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26625', '112', '28502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28503', '1079', '1', 'Sullivan County', 'US.PA.113', 'ASCII:Sullivan County;ID:5214721', '26626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26626', '112', '28503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28504', '1079', '1', 'Susquehanna County', 'US.PA.115', 'ASCII:Susquehanna County;ID:5214915', '26627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26627', '112', '28504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28505', '1079', '1', 'Tioga County', 'US.PA.117', 'ASCII:Tioga County;ID:5215684', '26628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26628', '112', '28505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28506', '1079', '1', 'Union County', 'US.PA.119', 'ASCII:Union County;ID:5216649', '26629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26629', '112', '28506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28507', '1079', '1', 'Venango County', 'US.PA.121', 'ASCII:Venango County;ID:5217142', '26630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26630', '112', '28507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28508', '1079', '1', 'Warren County', 'US.PA.123', 'ASCII:Warren County;ID:5217991', '26631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26631', '112', '28508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28509', '1079', '1', 'Washington County', 'US.PA.125', 'ASCII:Washington County;ID:5218076', '26632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26632', '112', '28509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28510', '1079', '1', 'Wayne County', 'US.PA.127', 'ASCII:Wayne County;ID:5218273', '26633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26633', '112', '28510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28511', '1079', '1', 'Westmoreland County', 'US.PA.129', 'ASCII:Westmoreland County;ID:5219013', '26634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26634', '112', '28511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28512', '1079', '1', 'Wyoming County', 'US.PA.131', 'ASCII:Wyoming County;ID:5220239', '26635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26635', '112', '28512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28513', '1079', '1', 'York County', 'US.PA.133', 'ASCII:York County;ID:5220355', '26636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26636', '112', '28513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.PA.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28514', '1079', '1', 'Bristol County', 'US.RI.001', 'ASCII:Bristol County;ID:5221078', '26637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26637', '112', '28514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.RI.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28515', '1079', '1', 'Kent County', 'US.RI.003', 'ASCII:Kent County;ID:5222961', '26638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26638', '112', '28515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.RI.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28516', '1079', '1', 'Newport County', 'US.RI.005', 'ASCII:Newport County;ID:5223601', '26639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26639', '112', '28516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.RI.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28517', '1079', '1', 'Providence County', 'US.RI.007', 'ASCII:Providence County;ID:5224162', '26640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26640', '112', '28517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.RI.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28518', '1079', '1', 'Washington County', 'US.RI.009', 'ASCII:Washington County;ID:5225535', '26641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26641', '112', '28518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.RI.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28519', '1079', '1', 'Aurora County', 'US.SD.003', 'ASCII:Aurora County;ID:5226093', '26642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26642', '112', '28519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28520', '1079', '1', 'Beadle County', 'US.SD.005', 'ASCII:Beadle County;ID:5226183', '26643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26643', '112', '28520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28521', '1079', '1', 'Bon Homme County', 'US.SD.009', 'ASCII:Bon Homme County;ID:5226441', '26644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26644', '112', '28521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28522', '1079', '1', 'Brookings County', 'US.SD.011', 'ASCII:Brookings County;ID:5226536', '26645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26645', '112', '28522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28523', '1079', '1', 'Brown County', 'US.SD.013', 'ASCII:Brown County;ID:5226553', '26646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26646', '112', '28523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28524', '1079', '1', 'Brule County', 'US.SD.015', 'ASCII:Brule County;ID:5226565', '26647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26647', '112', '28524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28525', '1079', '1', 'Buffalo County', 'US.SD.017', 'ASCII:Buffalo County;ID:5226588', '26648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26648', '112', '28525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28526', '1079', '1', 'Charles Mix County', 'US.SD.023', 'ASCII:Charles Mix County;ID:5226849', '26649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26649', '112', '28526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28527', '1079', '1', 'Clark County', 'US.SD.025', 'ASCII:Clark County;ID:5226904', '26650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26650', '112', '28527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28528', '1079', '1', 'Codington County', 'US.SD.029', 'ASCII:Codington County;ID:5226970', '26651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26651', '112', '28528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28529', '1079', '1', 'Clay County', 'US.SD.027', 'ASCII:Clay County;ID:5226973', '26652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26652', '112', '28529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28530', '1079', '1', 'Davison County', 'US.SD.035', 'ASCII:Davison County;ID:5227222', '26653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26653', '112', '28530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28531', '1079', '1', 'Day County', 'US.SD.037', 'ASCII:Day County;ID:5227240', '26654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26654', '112', '28531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28532', '1079', '1', 'Deuel County', 'US.SD.039', 'ASCII:Deuel County;ID:5227295', '26655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26655', '112', '28532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28533', '1079', '1', 'Douglas County', 'US.SD.043', 'ASCII:Douglas County;ID:5227372', '26656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26656', '112', '28533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28534', '1079', '1', 'Edmunds County', 'US.SD.045', 'ASCII:Edmunds County;ID:5227535', '26657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26657', '112', '28534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28535', '1079', '1', 'Faulk County', 'US.SD.049', 'ASCII:Faulk County;ID:5227752', '26658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26658', '112', '28535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28536', '1079', '1', 'Grant County', 'US.SD.051', 'ASCII:Grant County;ID:5228179', '26659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26659', '112', '28536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28537', '1079', '1', 'Gregory County', 'US.SD.053', 'ASCII:Gregory County;ID:5228223', '26660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26660', '112', '28537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28538', '1079', '1', 'Hamlin County', 'US.SD.057', 'ASCII:Hamlin County;ID:5228291', '26661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26661', '112', '28538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28539', '1079', '1', 'Hand County', 'US.SD.059', 'ASCII:Hand County;ID:5228302', '26662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26662', '112', '28539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28540', '1079', '1', 'Hanson County', 'US.SD.061', 'ASCII:Hanson County;ID:5228308', '26663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26663', '112', '28540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28541', '1079', '1', 'Hughes County', 'US.SD.065', 'ASCII:Hughes County;ID:5228654', '26664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26664', '112', '28541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28542', '1079', '1', 'Hutchinson County', 'US.SD.067', 'ASCII:Hutchinson County;ID:5228688', '26665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26665', '112', '28542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28543', '1079', '1', 'Hyde County', 'US.SD.069', 'ASCII:Hyde County;ID:5228693', '26666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26666', '112', '28543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28544', '1079', '1', 'Jerauld County', 'US.SD.073', 'ASCII:Jerauld County;ID:5228817', '26667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26667', '112', '28544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28545', '1079', '1', 'Kingsbury County', 'US.SD.077', 'ASCII:Kingsbury County;ID:5228997', '26668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26668', '112', '28545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28546', '1079', '1', 'Lake County', 'US.SD.079', 'ASCII:Lake County;ID:5229128', '26669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26669', '112', '28546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28547', '1079', '1', 'Lincoln County', 'US.SD.083', 'ASCII:Lincoln County;ID:5229313', '26670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26670', '112', '28547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28548', '1079', '1', 'Lyman County', 'US.SD.085', 'ASCII:Lyman County;ID:5229494', '26671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26671', '112', '28548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28549', '1079', '1', 'Marshall County', 'US.SD.091', 'ASCII:Marshall County;ID:5229574', '26672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26672', '112', '28549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28550', '1079', '1', 'McCook County', 'US.SD.087', 'ASCII:McCook County;ID:5229622', '26673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26673', '112', '28550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28551', '1079', '1', 'McPherson County', 'US.SD.089', 'ASCII:McPherson County;ID:5229653', '26674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26674', '112', '28551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28552', '1079', '1', 'Miner County', 'US.SD.097', 'ASCII:Miner County;ID:5229775', '26675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26675', '112', '28552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28553', '1079', '1', 'Minnehaha County', 'US.SD.099', 'ASCII:Minnehaha County;ID:5229782', '26676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26676', '112', '28553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28554', '1079', '1', 'Moody County', 'US.SD.101', 'ASCII:Moody County;ID:5229837', '26677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26677', '112', '28554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28555', '1079', '1', 'Potter County', 'US.SD.107', 'ASCII:Potter County;ID:5230591', '26678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26678', '112', '28555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28556', '1079', '1', 'Roberts County', 'US.SD.109', 'ASCII:Roberts County;ID:5230872', '26679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26679', '112', '28556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28557', '1079', '1', 'Sanborn County', 'US.SD.111', 'ASCII:Sanborn County;ID:5231251', '26680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26680', '112', '28557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28558', '1079', '1', 'Spink County', 'US.SD.115', 'ASCII:Spink County;ID:5231992', '26681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26681', '112', '28558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28559', '1079', '1', 'Tripp County', 'US.SD.123', 'ASCII:Tripp County;ID:5232417', '26682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26682', '112', '28559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28560', '1079', '1', 'Turner County', 'US.SD.125', 'ASCII:Turner County;ID:5232458', '26683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26683', '112', '28560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28561', '1079', '1', 'Union County', 'US.SD.127', 'ASCII:Union County;ID:5232511', '26684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26684', '112', '28561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28562', '1079', '1', 'Walworth County', 'US.SD.129', 'ASCII:Walworth County;ID:5232702', '26685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26685', '112', '28562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28563', '1079', '1', 'Yankton County', 'US.SD.135', 'ASCII:Yankton County;ID:5233056', '26686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26686', '112', '28563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28564', '1079', '1', 'Addison County', 'US.VT.001', 'ASCII:Addison County;ID:5233146', '26687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26687', '112', '28564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28565', '1079', '1', 'Bennington County', 'US.VT.003', 'ASCII:Bennington County;ID:5233748', '26688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26688', '112', '28565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28566', '1079', '1', 'Caledonia County', 'US.VT.005', 'ASCII:Caledonia County;ID:5234484', '26689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26689', '112', '28566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28567', '1079', '1', 'Chittenden County', 'US.VT.007', 'ASCII:Chittenden County;ID:5234861', '26690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26690', '112', '28567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28568', '1079', '1', 'Essex County', 'US.VT.009', 'ASCII:Essex County;ID:5235945', '26691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26691', '112', '28568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28569', '1079', '1', 'Franklin County', 'US.VT.011', 'ASCII:Franklin County;ID:5236279', '26692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26692', '112', '28569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28570', '1079', '1', 'Grand Isle County', 'US.VT.013', 'ASCII:Grand Isle County;ID:5236542', '26693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26693', '112', '28570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28571', '1079', '1', 'Lamoille County', 'US.VT.015', 'ASCII:Lamoille County;ID:5237839', '26694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26694', '112', '28571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28572', '1079', '1', 'Orange County', 'US.VT.017', 'ASCII:Orange County;ID:5239504', '26695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26695', '112', '28572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28573', '1079', '1', 'Orleans County', 'US.VT.019', 'ASCII:Orleans County;ID:5239520', '26696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26696', '112', '28573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28574', '1079', '1', 'Rutland County', 'US.VT.021', 'ASCII:Rutland County;ID:5240516', '26697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26697', '112', '28574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28575', '1079', '1', 'Washington County', 'US.VT.023', 'ASCII:Washington County;ID:5242529', '26698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26698', '112', '28575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28576', '1079', '1', 'Windham County', 'US.VT.025', 'ASCII:Windham County;ID:5243051', '26699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26699', '112', '28576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28577', '1079', '1', 'Windsor County', 'US.VT.027', 'ASCII:Windsor County;ID:5243062', '26700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26700', '112', '28577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.VT.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28578', '1079', '1', 'Adams County', 'US.WI.001', 'ASCII:Adams County;ID:5243559', '26701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26701', '112', '28578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28579', '1079', '1', 'Ashland County', 'US.WI.003', 'ASCII:Ashland County;ID:5244249', '26702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26702', '112', '28579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28580', '1079', '1', 'Barron County', 'US.WI.005', 'ASCII:Barron County;ID:5244742', '26703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26703', '112', '28580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28581', '1079', '1', 'Bayfield County', 'US.WI.007', 'ASCII:Bayfield County;ID:5244967', '26704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26704', '112', '28581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28582', '1079', '1', 'Brown County', 'US.WI.009', 'ASCII:Brown County;ID:5246898', '26705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26705', '112', '28582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28583', '1079', '1', 'Buffalo County', 'US.WI.011', 'ASCII:Buffalo County;ID:5247108', '26706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26706', '112', '28583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28584', '1079', '1', 'Burnett County', 'US.WI.013', 'ASCII:Burnett County;ID:5247230', '26707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26707', '112', '28584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28585', '1079', '1', 'Calumet County', 'US.WI.015', 'ASCII:Calumet County;ID:5247444', '26708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26708', '112', '28585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28586', '1079', '1', 'Chippewa County', 'US.WI.017', 'ASCII:Chippewa County;ID:5248507', '26709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26709', '112', '28586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28587', '1079', '1', 'Clark County', 'US.WI.019', 'ASCII:Clark County;ID:5248812', '26710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26710', '112', '28587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28588', '1079', '1', 'Columbia County', 'US.WI.021', 'ASCII:Columbia County;ID:5249193', '26711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26711', '112', '28588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28589', '1079', '1', 'Crawford County', 'US.WI.023', 'ASCII:Crawford County;ID:5249701', '26712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26712', '112', '28589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28590', '1079', '1', 'Dane County', 'US.WI.025', 'ASCII:Dane County;ID:5250074', '26713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26713', '112', '28590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28591', '1079', '1', 'Dodge County', 'US.WI.027', 'ASCII:Dodge County;ID:5250710', '26714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26714', '112', '28591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28592', '1079', '1', 'Door County', 'US.WI.029', 'ASCII:Door County;ID:5250768', '26715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26715', '112', '28592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28593', '1079', '1', 'Douglas County', 'US.WI.031', 'ASCII:Douglas County;ID:5250831', '26716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26716', '112', '28593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28594', '1079', '1', 'Dunn County', 'US.WI.033', 'ASCII:Dunn County;ID:5251040', '26717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26717', '112', '28594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28595', '1079', '1', 'Eau Claire County', 'US.WI.035', 'ASCII:Eau Claire County;ID:5251439', '26718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26718', '112', '28595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28596', '1079', '1', 'Florence County', 'US.WI.037', 'ASCII:Florence County;ID:5253306', '26719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26719', '112', '28596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28597', '1079', '1', 'Fond du Lac County', 'US.WI.039', 'ASCII:Fond du Lac County;ID:5253356', '26720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26720', '112', '28597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28598', '1079', '1', 'Forest County', 'US.WI.041', 'ASCII:Forest County;ID:5253400', '26721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26721', '112', '28598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28599', '1079', '1', 'Grant County', 'US.WI.043', 'ASCII:Grant County;ID:5254832', '26722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26722', '112', '28599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28600', '1079', '1', 'Green County', 'US.WI.045', 'ASCII:Green County;ID:5254978', '26723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26723', '112', '28600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28601', '1079', '1', 'Green Lake County', 'US.WI.047', 'ASCII:Green Lake County;ID:5255015', '26724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26724', '112', '28601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28602', '1079', '1', 'Iowa County', 'US.WI.049', 'ASCII:Iowa County;ID:5257509', '26725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26725', '112', '28602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28603', '1079', '1', 'Iron County', 'US.WI.051', 'ASCII:Iron County;ID:5257533', '26726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26726', '112', '28603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28604', '1079', '1', 'Jackson County', 'US.WI.053', 'ASCII:Jackson County;ID:5257673', '26727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26727', '112', '28604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28605', '1079', '1', 'Jefferson County', 'US.WI.055', 'ASCII:Jefferson County;ID:5257788', '26728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26728', '112', '28605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28606', '1079', '1', 'Juneau County', 'US.WI.057', 'ASCII:Juneau County;ID:5258193', '26729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26729', '112', '28606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28607', '1079', '1', 'Kenosha County', 'US.WI.059', 'ASCII:Kenosha County;ID:5258396', '26730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26730', '112', '28607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28608', '1079', '1', 'Kewaunee County', 'US.WI.061', 'ASCII:Kewaunee County;ID:5258491', '26731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26731', '112', '28608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28609', '1079', '1', 'La Crosse County', 'US.WI.063', 'ASCII:La Crosse County;ID:5258961', '26732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26732', '112', '28609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28610', '1079', '1', 'Lafayette County', 'US.WI.065', 'ASCII:Lafayette County;ID:5259061', '26733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26733', '112', '28610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28611', '1079', '1', 'Langlade County', 'US.WI.067', 'ASCII:Langlade County;ID:5259487', '26734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26734', '112', '28611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28612', '1079', '1', 'Lincoln County', 'US.WI.069', 'ASCII:Lincoln County;ID:5259991', '26735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26735', '112', '28612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28613', '1079', '1', 'Manitowoc County', 'US.WI.071', 'ASCII:Manitowoc County;ID:5261587', '26736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26736', '112', '28613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28614', '1079', '1', 'Marathon County', 'US.WI.073', 'ASCII:Marathon County;ID:5261790', '26737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26737', '112', '28614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28615', '1079', '1', 'Marinette County', 'US.WI.075', 'ASCII:Marinette County;ID:5261856', '26738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26738', '112', '28615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28616', '1079', '1', 'Marquette County', 'US.WI.077', 'ASCII:Marquette County;ID:5261914', '26739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26739', '112', '28616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28617', '1079', '1', 'Menominee County', 'US.WI.078', 'ASCII:Menominee County;ID:5262622', '26740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26740', '112', '28617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28618', '1079', '1', 'Milwaukee County', 'US.WI.079', 'ASCII:Milwaukee County;ID:5263058', '26741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26741', '112', '28618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28619', '1079', '1', 'Monroe County', 'US.WI.081', 'ASCII:Monroe County;ID:5263335', '26742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26742', '112', '28619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28620', '1079', '1', 'Oconto County', 'US.WI.083', 'ASCII:Oconto County;ID:5265518', '26743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26743', '112', '28620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28621', '1079', '1', 'Oneida County', 'US.WI.085', 'ASCII:Oneida County;ID:5265726', '26744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26744', '112', '28621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28622', '1079', '1', 'Outagamie County', 'US.WI.087', 'ASCII:Outagamie County;ID:5266044', '26745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26745', '112', '28622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28623', '1079', '1', 'Ozaukee County', 'US.WI.089', 'ASCII:Ozaukee County;ID:5266102', '26746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26746', '112', '28623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28624', '1079', '1', 'Pepin County', 'US.WI.091', 'ASCII:Pepin County;ID:5266547', '26747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26747', '112', '28624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28625', '1079', '1', 'Pierce County', 'US.WI.093', 'ASCII:Pierce County;ID:5266878', '26748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26748', '112', '28625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28626', '1079', '1', 'Polk County', 'US.WI.095', 'ASCII:Polk County;ID:5267654', '26749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26749', '112', '28626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28627', '1079', '1', 'Portage County', 'US.WI.097', 'ASCII:Portage County;ID:5267787', '26750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26750', '112', '28627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28628', '1079', '1', 'Price County', 'US.WI.099', 'ASCII:Price County;ID:5268067', '26751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26751', '112', '28628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28629', '1079', '1', 'Racine County', 'US.WI.101', 'ASCII:Racine County;ID:5268253', '26752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26752', '112', '28629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28630', '1079', '1', 'Richland County', 'US.WI.103', 'ASCII:Richland County;ID:5268859', '26753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26753', '112', '28630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28631', '1079', '1', 'Rock County', 'US.WI.105', 'ASCII:Rock County;ID:5269209', '26754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26754', '112', '28631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28632', '1079', '1', 'Rusk County', 'US.WI.107', 'ASCII:Rusk County;ID:5269777', '26755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26755', '112', '28632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28633', '1079', '1', 'Saint Croix County', 'US.WI.109', 'ASCII:Saint Croix County;ID:5270199', '26756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26756', '112', '28633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28634', '1079', '1', 'Sauk County', 'US.WI.111', 'ASCII:Sauk County;ID:5272232', '26757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26757', '112', '28634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28635', '1079', '1', 'Sawyer County', 'US.WI.113', 'ASCII:Sawyer County;ID:5272272', '26758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26758', '112', '28635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28636', '1079', '1', 'Shawano County', 'US.WI.115', 'ASCII:Shawano County;ID:5272875', '26759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26759', '112', '28636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28637', '1079', '1', 'Sheboygan County', 'US.WI.117', 'ASCII:Sheboygan County;ID:5272899', '26760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26760', '112', '28637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28638', '1079', '1', 'Taylor County', 'US.WI.119', 'ASCII:Taylor County;ID:5275451', '26761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26761', '112', '28638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28639', '1079', '1', 'Trempealeau County', 'US.WI.121', 'ASCII:Trempealeau County;ID:5276086', '26762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26762', '112', '28639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28640', '1079', '1', 'Vernon County', 'US.WI.123', 'ASCII:Vernon County;ID:5277134', '26763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26763', '112', '28640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28641', '1079', '1', 'Vilas County', 'US.WI.125', 'ASCII:Vilas County;ID:5277222', '26764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26764', '112', '28641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28642', '1079', '1', 'Walworth County', 'US.WI.127', 'ASCII:Walworth County;ID:5277773', '26765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26765', '112', '28642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28643', '1079', '1', 'Washburn County', 'US.WI.129', 'ASCII:Washburn County;ID:5277858', '26766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26766', '112', '28643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28644', '1079', '1', 'Washington County', 'US.WI.131', 'ASCII:Washington County;ID:5277887', '26767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26767', '112', '28644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28645', '1079', '1', 'Waukesha County', 'US.WI.133', 'ASCII:Waukesha County;ID:5278054', '26768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26768', '112', '28645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28646', '1079', '1', 'Waupaca County', 'US.WI.135', 'ASCII:Waupaca County;ID:5278089', '26769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26769', '112', '28646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28647', '1079', '1', 'Waushara County', 'US.WI.137', 'ASCII:Waushara County;ID:5278147', '26770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26770', '112', '28647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28648', '1079', '1', 'Winnebago County', 'US.WI.139', 'ASCII:Winnebago County;ID:5279387', '26771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26771', '112', '28648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28649', '1079', '1', 'Wood County', 'US.WI.141', 'ASCII:Wood County;ID:5279557', '26772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26772', '112', '28649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WI.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28650', '1079', '1', 'Brooke County', 'US.WV.009', 'ASCII:Brooke County;ID:5280114', '26773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26773', '112', '28650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28651', '1079', '1', 'Hancock County', 'US.WV.029', 'ASCII:Hancock County;ID:5280351', '26774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26774', '112', '28651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28652', '1079', '1', 'Ohio County', 'US.WV.069', 'ASCII:Ohio County;ID:5280563', '26775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26775', '112', '28652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WV.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28653', '1079', '1', 'Cochise County', 'US.AZ.003', 'ASCII:Cochise County;ID:5290270', '26776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26776', '112', '28653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28654', '1079', '1', 'Coconino County', 'US.AZ.005', 'ASCII:Coconino County;ID:5290307', '26777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26777', '112', '28654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28655', '1079', '1', 'Gila County', 'US.AZ.007', 'ASCII:Gila County;ID:5295877', '26778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26778', '112', '28655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28656', '1079', '1', 'Graham County', 'US.AZ.009', 'ASCII:Graham County;ID:5296368', '26779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26779', '112', '28656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28657', '1079', '1', 'Greenlee County', 'US.AZ.011', 'ASCII:Greenlee County;ID:5296837', '26780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26780', '112', '28657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28658', '1079', '1', 'La Paz County', 'US.AZ.012', 'ASCII:La Paz County;ID:5301323', '26781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26781', '112', '28658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28659', '1079', '1', 'Maricopa County', 'US.AZ.013', 'ASCII:Maricopa County;ID:5303754', '26782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26782', '112', '28659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28660', '1079', '1', 'Mohave County', 'US.AZ.015', 'ASCII:Mohave County;ID:5305206', '26783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26783', '112', '28660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28661', '1079', '1', 'Navajo County', 'US.AZ.017', 'ASCII:Navajo County;ID:5306233', '26784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26784', '112', '28661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28662', '1079', '1', 'Pima County', 'US.AZ.019', 'ASCII:Pima County;ID:5308878', '26785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26785', '112', '28662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28663', '1079', '1', 'Pinal County', 'US.AZ.021', 'ASCII:Pinal County;ID:5308916', '26786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26786', '112', '28663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28664', '1079', '1', 'Santa Cruz County', 'US.AZ.023', 'ASCII:Santa Cruz County;ID:5313135', '26787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26787', '112', '28664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28665', '1079', '1', 'Yavapai County', 'US.AZ.025', 'ASCII:Yavapai County;ID:5321860', '26788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26788', '112', '28665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28666', '1079', '1', 'Yuma County', 'US.AZ.027', 'ASCII:Yuma County;ID:5322057', '26789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26789', '112', '28666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28667', '1079', '1', 'Alameda County', 'US.CA.001', 'ASCII:Alameda County;ID:5322745', '26790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26790', '112', '28667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28668', '1079', '1', 'Alpine County', 'US.CA.003', 'ASCII:Alpine County;ID:5323414', '26791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26791', '112', '28668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28669', '1079', '1', 'Amador County', 'US.CA.005', 'ASCII:Amador County;ID:5323622', '26792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26792', '112', '28669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28670', '1079', '1', 'Butte County', 'US.CA.007', 'ASCII:Butte County;ID:5332191', '26793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26793', '112', '28670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28671', '1079', '1', 'Calaveras County', 'US.CA.009', 'ASCII:Calaveras County;ID:5332628', '26794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26794', '112', '28671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28672', '1079', '1', 'Colusa County', 'US.CA.011', 'ASCII:Colusa County;ID:5338872', '26795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26795', '112', '28672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28673', '1079', '1', 'Contra Costa County', 'US.CA.013', 'ASCII:Contra Costa County;ID:5339268', '26796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26796', '112', '28673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28674', '1079', '1', 'El Dorado County', 'US.CA.017', 'ASCII:El Dorado County;ID:5345659', '26797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26797', '112', '28674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28675', '1079', '1', 'Fresno County', 'US.CA.019', 'ASCII:Fresno County;ID:5350964', '26798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26798', '112', '28675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28676', '1079', '1', 'Glenn County', 'US.CA.021', 'ASCII:Glenn County;ID:5352462', '26799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26799', '112', '28676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28677', '1079', '1', 'Imperial County', 'US.CA.025', 'ASCII:Imperial County;ID:5359067', '26800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26800', '112', '28677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28678', '1079', '1', 'Inyo County', 'US.CA.027', 'ASCII:Inyo County;ID:5359604', '26801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26801', '112', '28678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28679', '1079', '1', 'Kern County', 'US.CA.029', 'ASCII:Kern County;ID:5362932', '26802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26802', '112', '28679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28680', '1079', '1', 'Kings County', 'US.CA.031', 'ASCII:Kings County;ID:5363385', '26803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26803', '112', '28680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28681', '1079', '1', 'Lake County', 'US.CA.033', 'ASCII:Lake County;ID:5364466', '26804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26804', '112', '28681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28682', '1079', '1', 'Los Angeles County', 'US.CA.037', 'ASCII:Los Angeles County;ID:5368381', '26805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26805', '112', '28682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28683', '1079', '1', 'Madera County', 'US.CA.039', 'ASCII:Madera County;ID:5369578', '26806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26806', '112', '28683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28684', '1079', '1', 'Marin County', 'US.CA.041', 'ASCII:Marin County;ID:5370468', '26807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26807', '112', '28684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28685', '1079', '1', 'Mariposa County', 'US.CA.043', 'ASCII:Mariposa County;ID:5370594', '26808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26808', '112', '28685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28686', '1079', '1', 'Mendocino County', 'US.CA.045', 'ASCII:Mendocino County;ID:5372163', '26809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26809', '112', '28686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28687', '1079', '1', 'Merced County', 'US.CA.047', 'ASCII:Merced County;ID:5372259', '26810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26810', '112', '28687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28688', '1079', '1', 'Mono County', 'US.CA.051', 'ASCII:Mono County;ID:5374091', '26811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26811', '112', '28688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28689', '1079', '1', 'Monterey County', 'US.CA.053', 'ASCII:Monterey County;ID:5374376', '26812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26812', '112', '28689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28690', '1079', '1', 'Napa County', 'US.CA.055', 'ASCII:Napa County;ID:5376101', '26813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26813', '112', '28690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28691', '1079', '1', 'Nevada County', 'US.CA.057', 'ASCII:Nevada County;ID:5376509', '26814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26814', '112', '28691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28692', '1079', '1', 'Orange County', 'US.CA.059', 'ASCII:Orange County;ID:5379524', '26815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26815', '112', '28692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28693', '1079', '1', 'Placer County', 'US.CA.061', 'ASCII:Placer County;ID:5383537', '26816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26816', '112', '28693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28694', '1079', '1', 'Plumas County', 'US.CA.063', 'ASCII:Plumas County;ID:5383832', '26817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26817', '112', '28694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28695', '1079', '1', 'Riverside County', 'US.CA.065', 'ASCII:Riverside County;ID:5387890', '26818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26818', '112', '28695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28696', '1079', '1', 'Sacramento County', 'US.CA.067', 'ASCII:Sacramento County;ID:5389519', '26819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26819', '112', '28696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28697', '1079', '1', 'San Benito County', 'US.CA.069', 'ASCII:San Benito County;ID:5391692', '26820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26820', '112', '28697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28698', '1079', '1', 'San Bernardino County', 'US.CA.071', 'ASCII:San Bernardino County;ID:5391726', '26821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26821', '112', '28698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28699', '1079', '1', 'San Diego County', 'US.CA.073', 'ASCII:San Diego County;ID:5391832', '26822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26822', '112', '28699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28700', '1079', '1', 'San Francisco County', 'US.CA.075', 'ASCII:San Francisco County;ID:5391997', '26823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26823', '112', '28700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28701', '1079', '1', 'San Joaquin County', 'US.CA.077', 'ASCII:San Joaquin County;ID:5392126', '26824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26824', '112', '28701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28702', '1079', '1', 'San Luis Obispo County', 'US.CA.079', 'ASCII:San Luis Obispo County;ID:5392329', '26825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26825', '112', '28702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28703', '1079', '1', 'San Mateo County', 'US.CA.081', 'ASCII:San Mateo County;ID:5392427', '26826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26826', '112', '28703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28704', '1079', '1', 'Santa Barbara County', 'US.CA.083', 'ASCII:Santa Barbara County;ID:5392967', '26827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26827', '112', '28704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28705', '1079', '1', 'Santa Clara County', 'US.CA.085', 'ASCII:Santa Clara County;ID:5393021', '26828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26828', '112', '28705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28706', '1079', '1', 'Santa Cruz County', 'US.CA.087', 'ASCII:Santa Cruz County;ID:5393068', '26829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26829', '112', '28706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28707', '1079', '1', 'Sierra County', 'US.CA.091', 'ASCII:Sierra County;ID:5395582', '26830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26830', '112', '28707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28708', '1079', '1', 'Solano County', 'US.CA.095', 'ASCII:Solano County;ID:5396987', '26831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26831', '112', '28708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28709', '1079', '1', 'Sonoma County', 'US.CA.097', 'ASCII:Sonoma County;ID:5397100', '26832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26832', '112', '28709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28710', '1079', '1', 'Stanislaus County', 'US.CA.099', 'ASCII:Stanislaus County;ID:5398597', '26833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26833', '112', '28710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28711', '1079', '1', 'Sutter County', 'US.CA.101', 'ASCII:Sutter County;ID:5400390', '26834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26834', '112', '28711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28712', '1079', '1', 'Tulare County', 'US.CA.107', 'ASCII:Tulare County;ID:5403789', '26835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26835', '112', '28712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28713', '1079', '1', 'Tuolumne County', 'US.CA.109', 'ASCII:Tuolumne County;ID:5403973', '26836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26836', '112', '28713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28714', '1079', '1', 'Ventura County', 'US.CA.111', 'ASCII:Ventura County;ID:5405889', '26837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26837', '112', '28714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28715', '1079', '1', 'Yolo County', 'US.CA.113', 'ASCII:Yolo County;ID:5410882', '26838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26838', '112', '28715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28716', '1079', '1', 'Yuba County', 'US.CA.115', 'ASCII:Yuba County;ID:5411026', '26839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26839', '112', '28716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28717', '1079', '1', 'Adams County', 'US.CO.001', 'ASCII:Adams County;ID:5411363', '26840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26840', '112', '28717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28718', '1079', '1', 'Arapahoe County', 'US.CO.005', 'ASCII:Arapahoe County;ID:5412056', '26841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26841', '112', '28718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28719', '1079', '1', 'Archuleta County', 'US.CO.007', 'ASCII:Archuleta County;ID:5412082', '26842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26842', '112', '28719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28720', '1079', '1', 'Baca County', 'US.CO.009', 'ASCII:Baca County;ID:5412453', '26843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26843', '112', '28720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28721', '1079', '1', 'Bent County', 'US.CO.011', 'ASCII:Bent County;ID:5413481', '26844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26844', '112', '28721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28722', '1079', '1', 'Broomfield County', 'US.CO.014', 'ASCII:Broomfield County;ID:5415040', '26845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26845', '112', '28722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28723', '1079', '1', 'Chaffee County', 'US.CO.015', 'ASCII:Chaffee County;ID:5416621', '26846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26846', '112', '28723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28724', '1079', '1', 'Cheyenne County', 'US.CO.017', 'ASCII:Cheyenne County;ID:5416840', '26847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26847', '112', '28724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28725', '1079', '1', 'Clear Creek County', 'US.CO.019', 'ASCII:Clear Creek County;ID:5417183', '26848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26848', '112', '28725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28726', '1079', '1', 'Conejos County', 'US.CO.021', 'ASCII:Conejos County;ID:5417799', '26849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26849', '112', '28726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28727', '1079', '1', 'Costilla County', 'US.CO.023', 'ASCII:Costilla County;ID:5418130', '26850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26850', '112', '28727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28728', '1079', '1', 'Crowley County', 'US.CO.025', 'ASCII:Crowley County;ID:5418687', '26851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26851', '112', '28728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28729', '1079', '1', 'Custer County', 'US.CO.027', 'ASCII:Custer County;ID:5418854', '26852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26852', '112', '28729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28730', '1079', '1', 'Delta County', 'US.CO.029', 'ASCII:Delta County;ID:5419338', '26853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26853', '112', '28730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28731', '1079', '1', 'Denver County', 'US.CO.031', 'ASCII:Denver County;ID:5419396', '26854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26854', '112', '28731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28732', '1079', '1', 'Dolores County', 'US.CO.033', 'ASCII:Dolores County;ID:5419761', '26855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26855', '112', '28732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28733', '1079', '1', 'Douglas County', 'US.CO.035', 'ASCII:Douglas County;ID:5419891', '26856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26856', '112', '28733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28734', '1079', '1', 'Eagle County', 'US.CO.037', 'ASCII:Eagle County;ID:5420332', '26857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26857', '112', '28734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28735', '1079', '1', 'El Paso County', 'US.CO.041', 'ASCII:El Paso County;ID:5420926', '26858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26858', '112', '28735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28736', '1079', '1', 'Elbert County', 'US.CO.039', 'ASCII:Elbert County;ID:5420936', '26859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26859', '112', '28736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28737', '1079', '1', 'Fremont County', 'US.CO.043', 'ASCII:Fremont County;ID:5422448', '26860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26860', '112', '28737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28738', '1079', '1', 'Garfield County', 'US.CO.045', 'ASCII:Garfield County;ID:5422751', '26861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26861', '112', '28738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28739', '1079', '1', 'Gilpin County', 'US.CO.047', 'ASCII:Gilpin County;ID:5422987', '26862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26862', '112', '28739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28740', '1079', '1', 'Gunnison County', 'US.CO.051', 'ASCII:Gunnison County;ID:5424092', '26863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26863', '112', '28740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28741', '1079', '1', 'Hinsdale County', 'US.CO.053', 'ASCII:Hinsdale County;ID:5425136', '26864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26864', '112', '28741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28742', '1079', '1', 'Huerfano County', 'US.CO.055', 'ASCII:Huerfano County;ID:5425737', '26865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26865', '112', '28742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28743', '1079', '1', 'Jefferson County', 'US.CO.059', 'ASCII:Jefferson County;ID:5426503', '26866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26866', '112', '28743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28744', '1079', '1', 'Kiowa County', 'US.CO.061', 'ASCII:Kiowa County;ID:5427500', '26867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26867', '112', '28744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28745', '1079', '1', 'Kit Carson County', 'US.CO.063', 'ASCII:Kit Carson County;ID:5427526', '26868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26868', '112', '28745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28746', '1079', '1', 'La Plata County', 'US.CO.067', 'ASCII:La Plata County;ID:5427717', '26869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26869', '112', '28746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28747', '1079', '1', 'Lake County', 'US.CO.065', 'ASCII:Lake County;ID:5427799', '26870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26870', '112', '28747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28748', '1079', '1', 'Las Animas County', 'US.CO.071', 'ASCII:Las Animas County;ID:5428059', '26871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26871', '112', '28748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28749', '1079', '1', 'Lincoln County', 'US.CO.073', 'ASCII:Lincoln County;ID:5428518', '26872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26872', '112', '28749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28750', '1079', '1', 'Mesa County', 'US.CO.077', 'ASCII:Mesa County;ID:5430806', '26873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26873', '112', '28750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28751', '1079', '1', 'Mineral County', 'US.CO.079', 'ASCII:Mineral County;ID:5431333', '26874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26874', '112', '28751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28752', '1079', '1', 'Montezuma County', 'US.CO.083', 'ASCII:Montezuma County;ID:5431680', '26875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26875', '112', '28752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28753', '1079', '1', 'Montrose County', 'US.CO.085', 'ASCII:Montrose County;ID:5431716', '26876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26876', '112', '28753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28754', '1079', '1', 'Otero County', 'US.CO.089', 'ASCII:Otero County;ID:5433658', '26877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26877', '112', '28754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28755', '1079', '1', 'Ouray County', 'US.CO.091', 'ASCII:Ouray County;ID:5433677', '26878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26878', '112', '28755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28756', '1079', '1', 'Park County', 'US.CO.093', 'ASCII:Park County;ID:5433959', '26879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26879', '112', '28756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28757', '1079', '1', 'Pitkin County', 'US.CO.097', 'ASCII:Pitkin County;ID:5434773', '26880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26880', '112', '28757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28758', '1079', '1', 'Prowers County', 'US.CO.099', 'ASCII:Prowers County;ID:5435436', '26881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26881', '112', '28758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28759', '1079', '1', 'Pueblo County', 'US.CO.101', 'ASCII:Pueblo County;ID:5435465', '26882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26882', '112', '28759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28760', '1079', '1', 'Rio Blanco County', 'US.CO.103', 'ASCII:Rio Blanco County;ID:5436472', '26883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26883', '112', '28760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28761', '1079', '1', 'Rio Grande County', 'US.CO.105', 'ASCII:Rio Grande County;ID:5436477', '26884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26884', '112', '28761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28762', '1079', '1', 'Saguache County', 'US.CO.109', 'ASCII:Saguache County;ID:5437350', '26885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26885', '112', '28762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28763', '1079', '1', 'San Juan County', 'US.CO.111', 'ASCII:San Juan County;ID:5437668', '26886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26886', '112', '28763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28764', '1079', '1', 'San Miguel County', 'US.CO.113', 'ASCII:San Miguel County;ID:5437707', '26887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26887', '112', '28764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28765', '1079', '1', 'Summit County', 'US.CO.117', 'ASCII:Summit County;ID:5440680', '26888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26888', '112', '28765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28766', '1079', '1', 'Teller County', 'US.CO.119', 'ASCII:Teller County;ID:5441188', '26889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26889', '112', '28766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28767', '1079', '1', 'Washington County', 'US.CO.121', 'ASCII:Washington County;ID:5443305', '26890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26890', '112', '28767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28768', '1079', '1', 'Yuma County', 'US.CO.125', 'ASCII:Yuma County;ID:5444907', '26891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26891', '112', '28768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28769', '1079', '1', 'Cheyenne County', 'US.KS.023', 'ASCII:Cheyenne County;ID:5445155', '26892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26892', '112', '28769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28770', '1079', '1', 'Decatur County', 'US.KS.039', 'ASCII:Decatur County;ID:5445268', '26893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26893', '112', '28770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28771', '1079', '1', 'Finney County', 'US.KS.055', 'ASCII:Finney County;ID:5445392', '26894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26894', '112', '28771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28772', '1079', '1', 'Gove County', 'US.KS.063', 'ASCII:Gove County;ID:5445489', '26895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26895', '112', '28772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28773', '1079', '1', 'Grant County', 'US.KS.067', 'ASCII:Grant County;ID:5445505', '26896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26896', '112', '28773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28774', '1079', '1', 'Gray County', 'US.KS.069', 'ASCII:Gray County;ID:5445511', '26897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26897', '112', '28774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28775', '1079', '1', 'Greeley County', 'US.KS.071', 'ASCII:Greeley County;ID:5445516', '26898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26898', '112', '28775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28776', '1079', '1', 'Hamilton County', 'US.KS.075', 'ASCII:Hamilton County;ID:5445544', '26899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26899', '112', '28776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28777', '1079', '1', 'Haskell County', 'US.KS.081', 'ASCII:Haskell County;ID:5445570', '26900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26900', '112', '28777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28778', '1079', '1', 'Kearny County', 'US.KS.093', 'ASCII:Kearny County;ID:5445733', '26901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26901', '112', '28778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28779', '1079', '1', 'Lane County', 'US.KS.101', 'ASCII:Lane County;ID:5445806', '26902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26902', '112', '28779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28780', '1079', '1', 'Logan County', 'US.KS.109', 'ASCII:Logan County;ID:5445855', '26903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26903', '112', '28780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28781', '1079', '1', 'Meade County', 'US.KS.119', 'ASCII:Meade County;ID:5445955', '26904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26904', '112', '28781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28782', '1079', '1', 'Morton County', 'US.KS.129', 'ASCII:Morton County;ID:5446023', '26905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26905', '112', '28782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28783', '1079', '1', 'Rawlins County', 'US.KS.153', 'ASCII:Rawlins County;ID:5446276', '26906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26906', '112', '28783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28784', '1079', '1', 'Scott County', 'US.KS.171', 'ASCII:Scott County;ID:5446427', '26907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26907', '112', '28784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28785', '1079', '1', 'Seward County', 'US.KS.175', 'ASCII:Seward County;ID:5446445', '26908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26908', '112', '28785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.175» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28786', '1079', '1', 'Sheridan County', 'US.KS.179', 'ASCII:Sheridan County;ID:5446459', '26909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26909', '112', '28786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28787', '1079', '1', 'Sherman County', 'US.KS.181', 'ASCII:Sherman County;ID:5446470', '26910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26910', '112', '28787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.181» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28788', '1079', '1', 'Stanton County', 'US.KS.187', 'ASCII:Stanton County;ID:5446561', '26911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26911', '112', '28788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.187» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28789', '1079', '1', 'Stevens County', 'US.KS.189', 'ASCII:Stevens County;ID:5446576', '26912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26912', '112', '28789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28790', '1079', '1', 'Thomas County', 'US.KS.193', 'ASCII:Thomas County;ID:5446632', '26913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26913', '112', '28790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28791', '1079', '1', 'Wallace County', 'US.KS.199', 'ASCII:Wallace County;ID:5446712', '26914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26914', '112', '28791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28792', '1079', '1', 'Wichita County', 'US.KS.203', 'ASCII:Wichita County;ID:5446780', '26915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26915', '112', '28792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.KS.203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28793', '1079', '1', 'Bernalillo County', 'US.NM.001', 'ASCII:Bernalillo County;ID:5457180', '26916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26916', '112', '28793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28794', '1079', '1', 'Catron County', 'US.NM.003', 'ASCII:Catron County;ID:5460788', '26917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26917', '112', '28794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28795', '1079', '1', 'Chaves County', 'US.NM.005', 'ASCII:Chaves County;ID:5461428', '26918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26918', '112', '28795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28796', '1079', '1', 'Cibola County', 'US.NM.006', 'ASCII:Cibola County;ID:5462019', '26919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26919', '112', '28796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28797', '1079', '1', 'Colfax County', 'US.NM.007', 'ASCII:Colfax County;ID:5462567', '26920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26920', '112', '28797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28798', '1079', '1', 'Curry County', 'US.NM.009', 'ASCII:Curry County;ID:5464151', '26921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26921', '112', '28798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28799', '1079', '1', 'DeBaca County', 'US.NM.011', 'ASCII:DeBaca County;ID:5464477', '26922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26922', '112', '28799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28800', '1079', '1', 'Doña Ana County', 'US.NM.013', 'ASCII:Dona Ana County;ID:5465283', '26923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26923', '112', '28800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28801', '1079', '1', 'Eddy County', 'US.NM.015', 'ASCII:Eddy County;ID:5466318', '26924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26924', '112', '28801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28802', '1079', '1', 'Grant County', 'US.NM.017', 'ASCII:Grant County;ID:5469835', '26925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26925', '112', '28802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28803', '1079', '1', 'Guadalupe County', 'US.NM.019', 'ASCII:Guadalupe County;ID:5470197', '26926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26926', '112', '28803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28804', '1079', '1', 'Harding County', 'US.NM.021', 'ASCII:Harding County;ID:5470675', '26927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26927', '112', '28804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28805', '1079', '1', 'Hidalgo County', 'US.NM.023', 'ASCII:Hidalgo County;ID:5471293', '26928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26928', '112', '28805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28806', '1079', '1', 'Lea County', 'US.NM.025', 'ASCII:Lea County;ID:5475594', '26929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26929', '112', '28806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28807', '1079', '1', 'Lincoln County', 'US.NM.027', 'ASCII:Lincoln County;ID:5475934', '26930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26930', '112', '28807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28808', '1079', '1', 'Los Alamos County', 'US.NM.028', 'ASCII:Los Alamos County;ID:5476834', '26931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26931', '112', '28808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28809', '1079', '1', 'Luna County', 'US.NM.029', 'ASCII:Luna County;ID:5477433', '26932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26932', '112', '28809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28810', '1079', '1', 'McKinley County', 'US.NM.031', 'ASCII:McKinley County;ID:5478585', '26933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26933', '112', '28810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28811', '1079', '1', 'Mora County', 'US.NM.033', 'ASCII:Mora County;ID:5480123', '26934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26934', '112', '28811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28812', '1079', '1', 'Otero County', 'US.NM.035', 'ASCII:Otero County;ID:5482932', '26935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26935', '112', '28812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28813', '1079', '1', 'Quay County', 'US.NM.037', 'ASCII:Quay County;ID:5485605', '26936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26936', '112', '28813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28814', '1079', '1', 'Rio Arriba County', 'US.NM.039', 'ASCII:Rio Arriba County;ID:5487732', '26937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26937', '112', '28814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28815', '1079', '1', 'Roosevelt County', 'US.NM.041', 'ASCII:Roosevelt County;ID:5488372', '26938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26938', '112', '28815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28816', '1079', '1', 'San Juan County', 'US.NM.045', 'ASCII:San Juan County;ID:5489698', '26939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26939', '112', '28816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28817', '1079', '1', 'San Miguel County', 'US.NM.047', 'ASCII:San Miguel County;ID:5489818', '26940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26940', '112', '28817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28818', '1079', '1', 'Sandoval County', 'US.NM.043', 'ASCII:Sandoval County;ID:5490135', '26941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26941', '112', '28818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28819', '1079', '1', 'Santa Fe County', 'US.NM.049', 'ASCII:Santa Fe County;ID:5490272', '26942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26942', '112', '28819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28820', '1079', '1', 'Sierra County', 'US.NM.051', 'ASCII:Sierra County;ID:5491395', '26943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26943', '112', '28820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28821', '1079', '1', 'Socorro County', 'US.NM.053', 'ASCII:Socorro County;ID:5492031', '26944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26944', '112', '28821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28822', '1079', '1', 'Taos County', 'US.NM.055', 'ASCII:Taos County;ID:5493780', '26945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26945', '112', '28822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28823', '1079', '1', 'Torrance County', 'US.NM.057', 'ASCII:Torrance County;ID:5494881', '26946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26946', '112', '28823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28824', '1079', '1', 'Union County', 'US.NM.059', 'ASCII:Union County;ID:5495841', '26947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26947', '112', '28824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28825', '1079', '1', 'Valencia County', 'US.NM.061', 'ASCII:Valencia County;ID:5496319', '26948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26948', '112', '28825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NM.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28826', '1079', '1', 'City of Carson City', 'US.NV.510', 'ASCII:City of Carson City;ID:5501350', '26949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26949', '112', '28826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28827', '1079', '1', 'Churchill County', 'US.NV.001', 'ASCII:Churchill County;ID:5501785', '26950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26950', '112', '28827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28828', '1079', '1', 'Clark County', 'US.NV.003', 'ASCII:Clark County;ID:5501879', '26951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26951', '112', '28828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28829', '1079', '1', 'Douglas County', 'US.NV.005', 'ASCII:Douglas County;ID:5503178', '26952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26952', '112', '28829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28830', '1079', '1', 'Esmeralda County', 'US.NV.009', 'ASCII:Esmeralda County;ID:5503780', '26953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26953', '112', '28830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28831', '1079', '1', 'Lander County', 'US.NV.015', 'ASCII:Lander County;ID:5506935', '26954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26954', '112', '28831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28832', '1079', '1', 'Lincoln County', 'US.NV.017', 'ASCII:Lincoln County;ID:5507189', '26955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26955', '112', '28832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28833', '1079', '1', 'Lyon County', 'US.NV.019', 'ASCII:Lyon County;ID:5507669', '26956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26956', '112', '28833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28834', '1079', '1', 'Mineral County', 'US.NV.021', 'ASCII:Mineral County;ID:5508393', '26957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26957', '112', '28834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28835', '1079', '1', 'Nye County', 'US.NV.023', 'ASCII:Nye County;ID:5509519', '26958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26958', '112', '28835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28836', '1079', '1', 'Storey County', 'US.NV.029', 'ASCII:Storey County;ID:5513171', '26959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26959', '112', '28836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28837', '1079', '1', 'White Pine County', 'US.NV.033', 'ASCII:White Pine County;ID:5514990', '26960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26960', '112', '28837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28838', '1079', '1', 'Beaver County', 'US.OK.007', 'ASCII:Beaver County;ID:5515593', '26961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26961', '112', '28838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28839', '1079', '1', 'Cimarron County', 'US.OK.025', 'ASCII:Cimarron County;ID:5515651', '26962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26962', '112', '28839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28840', '1079', '1', 'Texas County', 'US.OK.139', 'ASCII:Texas County;ID:5515937', '26963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26963', '112', '28840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OK.139» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28841', '1079', '1', 'Andrews County', 'US.TX.003', 'ASCII:Andrews County;ID:5516292', '26964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26964', '112', '28841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28842', '1079', '1', 'Armstrong County', 'US.TX.011', 'ASCII:Armstrong County;ID:5516441', '26965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26965', '112', '28842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28843', '1079', '1', 'Bailey County', 'US.TX.017', 'ASCII:Bailey County;ID:5516581', '26966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26966', '112', '28843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28844', '1079', '1', 'Borden County', 'US.TX.033', 'ASCII:Borden County;ID:5517459', '26967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26967', '112', '28844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28845', '1079', '1', 'Brewster County', 'US.TX.043', 'ASCII:Brewster County;ID:5517580', '26968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26968', '112', '28845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28846', '1079', '1', 'Briscoe County', 'US.TX.045', 'ASCII:Briscoe County;ID:5517598', '26969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26969', '112', '28846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28847', '1079', '1', 'Carson County', 'US.TX.065', 'ASCII:Carson County;ID:5518353', '26970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26970', '112', '28847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28848', '1079', '1', 'Castro County', 'US.TX.069', 'ASCII:Castro County;ID:5518431', '26971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26971', '112', '28848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28849', '1079', '1', 'Childress County', 'US.TX.075', 'ASCII:Childress County;ID:5518760', '26972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26972', '112', '28849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28850', '1079', '1', 'Cochran County', 'US.TX.079', 'ASCII:Cochran County;ID:5519156', '26973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26973', '112', '28850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28851', '1079', '1', 'Coke County', 'US.TX.081', 'ASCII:Coke County;ID:5519174', '26974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26974', '112', '28851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28852', '1079', '1', 'Collingsworth County', 'US.TX.087', 'ASCII:Collingsworth County;ID:5519229', '26975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26975', '112', '28852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28853', '1079', '1', 'Cottle County', 'US.TX.101', 'ASCII:Cottle County;ID:5519440', '26976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26976', '112', '28853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28854', '1079', '1', 'Crane County', 'US.TX.103', 'ASCII:Crane County;ID:5519649', '26977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26977', '112', '28854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28855', '1079', '1', 'Crockett County', 'US.TX.105', 'ASCII:Crockett County;ID:5519699', '26978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26978', '112', '28855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28856', '1079', '1', 'Crosby County', 'US.TX.107', 'ASCII:Crosby County;ID:5519715', '26979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26979', '112', '28856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28857', '1079', '1', 'Culberson County', 'US.TX.109', 'ASCII:Culberson County;ID:5519788', '26980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26980', '112', '28857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28858', '1079', '1', 'Dallam County', 'US.TX.111', 'ASCII:Dallam County;ID:5519868', '26981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26981', '112', '28858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28859', '1079', '1', 'Dawson County', 'US.TX.115', 'ASCII:Dawson County;ID:5519946', '26982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26982', '112', '28859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28860', '1079', '1', 'Deaf Smith County', 'US.TX.117', 'ASCII:Deaf Smith County;ID:5520004', '26983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26983', '112', '28860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28861', '1079', '1', 'Dickens County', 'US.TX.125', 'ASCII:Dickens County;ID:5520187', '26984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26984', '112', '28861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28862', '1079', '1', 'Donley County', 'US.TX.129', 'ASCII:Donley County;ID:5520330', '26985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26985', '112', '28862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28863', '1079', '1', 'Ector County', 'US.TX.135', 'ASCII:Ector County;ID:5520910', '26986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26986', '112', '28863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28864', '1079', '1', 'Edwards County', 'US.TX.137', 'ASCII:Edwards County;ID:5520940', '26987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26987', '112', '28864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28865', '1079', '1', 'El Paso County', 'US.TX.141', 'ASCII:El Paso County;ID:5521001', '26988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26988', '112', '28865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.141» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28866', '1079', '1', 'Fisher County', 'US.TX.151', 'ASCII:Fisher County;ID:5521544', '26989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26989', '112', '28866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.151» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28867', '1079', '1', 'Floyd County', 'US.TX.153', 'ASCII:Floyd County;ID:5521640', '26990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26990', '112', '28867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.153» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28868', '1079', '1', 'Gaines County', 'US.TX.165', 'ASCII:Gaines County;ID:5521974', '26991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26991', '112', '28868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28869', '1079', '1', 'Garza County', 'US.TX.169', 'ASCII:Garza County;ID:5522043', '26992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26992', '112', '28869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28870', '1079', '1', 'Glasscock County', 'US.TX.173', 'ASCII:Glasscock County;ID:5522162', '26993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26993', '112', '28870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.173» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28871', '1079', '1', 'Gray County', 'US.TX.179', 'ASCII:Gray County;ID:5522430', '26994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26994', '112', '28871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28872', '1079', '1', 'Hale County', 'US.TX.189', 'ASCII:Hale County;ID:5522717', '26995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26995', '112', '28872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.189» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28873', '1079', '1', 'Hall County', 'US.TX.191', 'ASCII:Hall County;ID:5522740', '26996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26996', '112', '28873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28874', '1079', '1', 'Hansford County', 'US.TX.195', 'ASCII:Hansford County;ID:5522806', '26997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26997', '112', '28874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28875', '1079', '1', 'Hartley County', 'US.TX.205', 'ASCII:Hartley County;ID:5522887', '26998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26998', '112', '28875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28876', '1079', '1', 'Hemphill County', 'US.TX.211', 'ASCII:Hemphill County;ID:5523019', '26999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('26999', '112', '28876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28877', '1079', '1', 'Hockley County', 'US.TX.219', 'ASCII:Hockley County;ID:5523240', '27000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27000', '112', '28877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28878', '1079', '1', 'Howard County', 'US.TX.227', 'ASCII:Howard County;ID:5523520', '27001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27001', '112', '28878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28879', '1079', '1', 'Hudspeth County', 'US.TX.229', 'ASCII:Hudspeth County;ID:5523551', '27002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27002', '112', '28879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28880', '1079', '1', 'Hutchinson County', 'US.TX.233', 'ASCII:Hutchinson County;ID:5523630', '27003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27003', '112', '28880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28881', '1079', '1', 'Irion County', 'US.TX.235', 'ASCII:Irion County;ID:5523809', '27004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27004', '112', '28881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28882', '1079', '1', 'Jeff Davis County', 'US.TX.243', 'ASCII:Jeff Davis County;ID:5523967', '27005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27005', '112', '28882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28883', '1079', '1', 'Kent County', 'US.TX.263', 'ASCII:Kent County;ID:5524519', '27006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27006', '112', '28883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.263» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28884', '1079', '1', 'King County', 'US.TX.269', 'ASCII:King County;ID:5524574', '27007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27007', '112', '28884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28885', '1079', '1', 'Kinney County', 'US.TX.271', 'ASCII:Kinney County;ID:5524590', '27008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27008', '112', '28885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.271» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28886', '1079', '1', 'Lamb County', 'US.TX.279', 'ASCII:Lamb County;ID:5524844', '27009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27009', '112', '28886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.279» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28887', '1079', '1', 'Lipscomb County', 'US.TX.295', 'ASCII:Lipscomb County;ID:5525131', '27010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27010', '112', '28887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.295» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28888', '1079', '1', 'Loving County', 'US.TX.301', 'ASCII:Loving County;ID:5525514', '27011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27011', '112', '28888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28889', '1079', '1', 'Lubbock County', 'US.TX.303', 'ASCII:Lubbock County;ID:5525584', '27012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27012', '112', '28889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28890', '1079', '1', 'Lynn County', 'US.TX.305', 'ASCII:Lynn County;ID:5525637', '27013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27013', '112', '28890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28891', '1079', '1', 'Martin County', 'US.TX.317', 'ASCII:Martin County;ID:5525816', '27014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27014', '112', '28891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.317» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28892', '1079', '1', 'Maverick County', 'US.TX.323', 'ASCII:Maverick County;ID:5525886', '27015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27015', '112', '28892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.323» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28893', '1079', '1', 'Midland County', 'US.TX.329', 'ASCII:Midland County;ID:5526341', '27016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27016', '112', '28893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28894', '1079', '1', 'Mitchell County', 'US.TX.335', 'ASCII:Mitchell County;ID:5526473', '27017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27017', '112', '28894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.335» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28895', '1079', '1', 'Moore County', 'US.TX.341', 'ASCII:Moore County;ID:5526589', '27018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27018', '112', '28895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28896', '1079', '1', 'Motley County', 'US.TX.345', 'ASCII:Motley County;ID:5526681', '27019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27019', '112', '28896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.345» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28897', '1079', '1', 'Nolan County', 'US.TX.353', 'ASCII:Nolan County;ID:5527151', '27020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27020', '112', '28897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.353» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28898', '1079', '1', 'Ochiltree County', 'US.TX.357', 'ASCII:Ochiltree County;ID:5527543', '27021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27021', '112', '28898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.357» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28899', '1079', '1', 'Oldham County', 'US.TX.359', 'ASCII:Oldham County;ID:5527746', '27022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27022', '112', '28899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.359» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28900', '1079', '1', 'Parmer County', 'US.TX.369', 'ASCII:Parmer County;ID:5528077', '27023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27023', '112', '28900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.369» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28901', '1079', '1', 'Pecos County', 'US.TX.371', 'ASCII:Pecos County;ID:5528185', '27024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27024', '112', '28901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.371» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28902', '1079', '1', 'Potter County', 'US.TX.375', 'ASCII:Potter County;ID:5528613', '27025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27025', '112', '28902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.375» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28903', '1079', '1', 'Presidio County', 'US.TX.377', 'ASCII:Presidio County;ID:5528673', '27026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27026', '112', '28903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.377» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28904', '1079', '1', 'Randall County', 'US.TX.381', 'ASCII:Randall County;ID:5528909', '27027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27027', '112', '28904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.381» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28905', '1079', '1', 'Reagan County', 'US.TX.383', 'ASCII:Reagan County;ID:5528987', '27028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27028', '112', '28905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28906', '1079', '1', 'Reeves County', 'US.TX.389', 'ASCII:Reeves County;ID:5529174', '27029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27029', '112', '28906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28907', '1079', '1', 'Roberts County', 'US.TX.393', 'ASCII:Roberts County;ID:5529403', '27030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27030', '112', '28907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.393» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28908', '1079', '1', 'Schleicher County', 'US.TX.413', 'ASCII:Schleicher County;ID:5530333', '27031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27031', '112', '28908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28909', '1079', '1', 'Scurry County', 'US.TX.415', 'ASCII:Scurry County;ID:5530399', '27032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27032', '112', '28909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28910', '1079', '1', 'Sherman County', 'US.TX.421', 'ASCII:Sherman County;ID:5530618', '27033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27033', '112', '28910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.421» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28911', '1079', '1', 'Sterling County', 'US.TX.431', 'ASCII:Sterling County;ID:5531748', '27034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27034', '112', '28911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.431» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28912', '1079', '1', 'Stonewall County', 'US.TX.433', 'ASCII:Stonewall County;ID:5531802', '27035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27035', '112', '28912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28913', '1079', '1', 'Sutton County', 'US.TX.435', 'ASCII:Sutton County;ID:5531955', '27036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27036', '112', '28913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.435» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28914', '1079', '1', 'Swisher County', 'US.TX.437', 'ASCII:Swisher County;ID:5531988', '27037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27037', '112', '28914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28915', '1079', '1', 'Terrell County', 'US.TX.443', 'ASCII:Terrell County;ID:5532186', '27038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27038', '112', '28915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28916', '1079', '1', 'Terry County', 'US.TX.445', 'ASCII:Terry County;ID:5532197', '27039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27039', '112', '28916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28917', '1079', '1', 'Tom Green County', 'US.TX.451', 'ASCII:Tom Green County;ID:5532405', '27040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27040', '112', '28917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28918', '1079', '1', 'Upton County', 'US.TX.461', 'ASCII:Upton County;ID:5532876', '27041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27041', '112', '28918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.461» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28919', '1079', '1', 'Val Verde County', 'US.TX.465', 'ASCII:Val Verde County;ID:5532889', '27042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27042', '112', '28919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28920', '1079', '1', 'Ward County', 'US.TX.475', 'ASCII:Ward County;ID:5533109', '27043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27043', '112', '28920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.475» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28921', '1079', '1', 'Wheeler County', 'US.TX.483', 'ASCII:Wheeler County;ID:5533544', '27044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27044', '112', '28921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28922', '1079', '1', 'Winkler County', 'US.TX.495', 'ASCII:Winkler County;ID:5534055', '27045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27045', '112', '28922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28923', '1079', '1', 'Yoakum County', 'US.TX.501', 'ASCII:Yoakum County;ID:5534225', '27046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27046', '112', '28923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.TX.501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28924', '1079', '1', 'Beaver County', 'US.UT.001', 'ASCII:Beaver County;ID:5534886', '27047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27047', '112', '28924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28925', '1079', '1', 'Carbon County', 'US.UT.007', 'ASCII:Carbon County;ID:5536454', '27048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27048', '112', '28925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28926', '1079', '1', 'Emery County', 'US.UT.015', 'ASCII:Emery County;ID:5538893', '27049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27049', '112', '28926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28927', '1079', '1', 'Garfield County', 'US.UT.017', 'ASCII:Garfield County;ID:5539525', '27050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27050', '112', '28927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28928', '1079', '1', 'Grand County', 'US.UT.019', 'ASCII:Grand County;ID:5539784', '27051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27051', '112', '28928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28929', '1079', '1', 'Iron County', 'US.UT.021', 'ASCII:Iron County;ID:5541004', '27052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27052', '112', '28929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28930', '1079', '1', 'Juab County', 'US.UT.023', 'ASCII:Juab County;ID:5541372', '27053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27053', '112', '28930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28931', '1079', '1', 'Kane County', 'US.UT.025', 'ASCII:Kane County;ID:5541473', '27054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27054', '112', '28931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28932', '1079', '1', 'Millard County', 'US.UT.027', 'ASCII:Millard County;ID:5543199', '27055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27055', '112', '28932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28933', '1079', '1', 'Piute County', 'US.UT.031', 'ASCII:Piute County;ID:5545027', '27056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27056', '112', '28933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28934', '1079', '1', 'San Juan County', 'US.UT.037', 'ASCII:San Juan County;ID:5546337', '27057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27057', '112', '28934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28935', '1079', '1', 'Sanpete County', 'US.UT.039', 'ASCII:Sanpete County;ID:5546434', '27058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27058', '112', '28935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28936', '1079', '1', 'Sevier County', 'US.UT.041', 'ASCII:Sevier County;ID:5546669', '27059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27059', '112', '28936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28937', '1079', '1', 'Washington County', 'US.UT.053', 'ASCII:Washington County;ID:5549225', '27060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27060', '112', '28937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28938', '1079', '1', 'Wayne County', 'US.UT.055', 'ASCII:Wayne County;ID:5549318', '27061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27061', '112', '28938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28939', '1079', '1', 'Alamosa County', 'US.CO.003', 'ASCII:Alamosa County;ID:5550375', '27062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27062', '112', '28939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28940', '1079', '1', 'Apache County', 'US.AZ.001', 'ASCII:Apache County;ID:5551519', '27063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27063', '112', '28940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AZ.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28941', '1079', '1', 'Trinity County', 'US.CA.105', 'ASCII:Trinity County;ID:5553701', '27064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27064', '112', '28941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28942', '1079', '1', 'Juneau City and Borough', 'US.AK.110', 'ASCII:Juneau City and Borough;ID:5554074', '27065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27065', '112', '28942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28943', '1079', '1', 'Ketchikan Gateway Borough', 'US.AK.130', 'ASCII:Ketchikan Gateway Borough;ID:5554432', '27066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27066', '112', '28943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28944', '1079', '1', 'Prince of Wales-Outer Ketchikan Census Area', 'US.AK.201', 'ASCII:Prince of Wales-Outer Ketchikan Census Area;ID:5556541', '27067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27067', '112', '28944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28945', '1079', '1', 'Sitka City and Borough', 'US.AK.220', 'ASCII:Sitka City and Borough;ID:5557295', '27068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27068', '112', '28945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.220» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28946', '1079', '1', 'Skagway-Hoonah-Angoon Census Area', 'US.AK.232', 'ASCII:Skagway-Hoonah-Angoon Census Area;ID:5557321', '27069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27069', '112', '28946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.232» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28947', '1079', '1', 'Wrangell-Petersburg Census Area', 'US.AK.280', 'ASCII:Wrangell-Petersburg Census Area;ID:5558599', '27070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27070', '112', '28947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.280» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28948', '1079', '1', 'Yakutat City and Borough', 'US.AK.282', 'ASCII:Yakutat City and Borough;ID:5558618', '27071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27071', '112', '28948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28949', '1079', '1', 'Del Norte County', 'US.CA.015', 'ASCII:Del Norte County;ID:5562484', '27072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27072', '112', '28949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28950', '1079', '1', 'Humboldt County', 'US.CA.023', 'ASCII:Humboldt County;ID:5565500', '27073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27073', '112', '28950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28951', '1079', '1', 'Lassen County', 'US.CA.035', 'ASCII:Lassen County;ID:5566544', '27074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27074', '112', '28951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28952', '1079', '1', 'Modoc County', 'US.CA.049', 'ASCII:Modoc County;ID:5568120', '27075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27075', '112', '28952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28953', '1079', '1', 'Shasta County', 'US.CA.089', 'ASCII:Shasta County;ID:5571096', '27076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27076', '112', '28953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28954', '1079', '1', 'Siskiyou County', 'US.CA.093', 'ASCII:Siskiyou County;ID:5571369', '27077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27077', '112', '28954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28955', '1079', '1', 'Tehama County', 'US.CA.103', 'ASCII:Tehama County;ID:5572575', '27078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27078', '112', '28955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CA.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28956', '1079', '1', 'Boulder County', 'US.CO.013', 'ASCII:Boulder County;ID:5574999', '27079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27079', '112', '28956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28957', '1079', '1', 'Grand County', 'US.CO.049', 'ASCII:Grand County;ID:5577529', '27080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27080', '112', '28957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28958', '1079', '1', 'Jackson County', 'US.CO.057', 'ASCII:Jackson County;ID:5578418', '27081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27081', '112', '28958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28959', '1079', '1', 'Larimer County', 'US.CO.069', 'ASCII:Larimer County;ID:5578884', '27082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27082', '112', '28959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28960', '1079', '1', 'Logan County', 'US.CO.075', 'ASCII:Logan County;ID:5579185', '27083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27083', '112', '28960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28961', '1079', '1', 'Moffat County', 'US.CO.081', 'ASCII:Moffat County;ID:5579973', '27084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27084', '112', '28961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28962', '1079', '1', 'Morgan County', 'US.CO.087', 'ASCII:Morgan County;ID:5580055', '27085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27085', '112', '28962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28963', '1079', '1', 'Phillips County', 'US.CO.095', 'ASCII:Phillips County;ID:5580855', '27086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27086', '112', '28963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28964', '1079', '1', 'Routt County', 'US.CO.107', 'ASCII:Routt County;ID:5581553', '27087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27087', '112', '28964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28965', '1079', '1', 'Sedgwick County', 'US.CO.115', 'ASCII:Sedgwick County;ID:5581788', '27088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27088', '112', '28965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28966', '1079', '1', 'Weld County', 'US.CO.123', 'ASCII:Weld County;ID:5583239', '27089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27089', '112', '28966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.CO.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28967', '1079', '1', 'Ada County', 'US.ID.001', 'ASCII:Ada County;ID:5583739', '27090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27090', '112', '28967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28968', '1079', '1', 'Adams County', 'US.ID.003', 'ASCII:Adams County;ID:5583743', '27091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27091', '112', '28968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28969', '1079', '1', 'Bannock County', 'US.ID.005', 'ASCII:Bannock County;ID:5584639', '27092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27092', '112', '28969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28970', '1079', '1', 'Bear Lake County', 'US.ID.007', 'ASCII:Bear Lake County;ID:5585000', '27093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27093', '112', '28970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28971', '1079', '1', 'Benewah County', 'US.ID.009', 'ASCII:Benewah County;ID:5585304', '27094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27094', '112', '28971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28972', '1079', '1', 'Bingham County', 'US.ID.011', 'ASCII:Bingham County;ID:5585826', '27095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27095', '112', '28972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28973', '1079', '1', 'Blaine County', 'US.ID.013', 'ASCII:Blaine County;ID:5586170', '27096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27096', '112', '28973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28974', '1079', '1', 'Boise County', 'US.ID.015', 'ASCII:Boise County;ID:5586445', '27097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27097', '112', '28974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28975', '1079', '1', 'Bonner County', 'US.ID.017', 'ASCII:Bonner County;ID:5586489', '27098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27098', '112', '28975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28976', '1079', '1', 'Bonneville County', 'US.ID.019', 'ASCII:Bonneville County;ID:5586500', '27099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27099', '112', '28976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28977', '1079', '1', 'Boundary County', 'US.ID.021', 'ASCII:Boundary County;ID:5586641', '27100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27100', '112', '28977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28978', '1079', '1', 'Butte County', 'US.ID.023', 'ASCII:Butte County;ID:5587504', '27101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27101', '112', '28978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28979', '1079', '1', 'Camas County', 'US.ID.025', 'ASCII:Camas County;ID:5587757', '27102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27102', '112', '28979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28980', '1079', '1', 'Canyon County', 'US.ID.027', 'ASCII:Canyon County;ID:5587975', '27103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27103', '112', '28980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28981', '1079', '1', 'Caribou County', 'US.ID.029', 'ASCII:Caribou County;ID:5588082', '27104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27104', '112', '28981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28982', '1079', '1', 'Cassia County', 'US.ID.031', 'ASCII:Cassia County;ID:5588204', '27105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27105', '112', '28982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28983', '1079', '1', 'Clark County', 'US.ID.033', 'ASCII:Clark County;ID:5588908', '27106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27106', '112', '28983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28984', '1079', '1', 'Clearwater County', 'US.ID.035', 'ASCII:Clearwater County;ID:5589005', '27107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27107', '112', '28984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28985', '1079', '1', 'Custer County', 'US.ID.037', 'ASCII:Custer County;ID:5590383', '27108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27108', '112', '28985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28986', '1079', '1', 'Elmore County', 'US.ID.039', 'ASCII:Elmore County;ID:5592510', '27109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27109', '112', '28986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28987', '1079', '1', 'Franklin County', 'US.ID.041', 'ASCII:Franklin County;ID:5593547', '27110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27110', '112', '28987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28988', '1079', '1', 'Fremont County', 'US.ID.043', 'ASCII:Fremont County;ID:5593620', '27111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27111', '112', '28988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28989', '1079', '1', 'Gem County', 'US.ID.045', 'ASCII:Gem County;ID:5593925', '27112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27112', '112', '28989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28990', '1079', '1', 'Gooding County', 'US.ID.047', 'ASCII:Gooding County;ID:5594311', '27113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27113', '112', '28990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28991', '1079', '1', 'Idaho County', 'US.ID.049', 'ASCII:Idaho County;ID:5596467', '27114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27114', '112', '28991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28992', '1079', '1', 'Jefferson County', 'US.ID.051', 'ASCII:Jefferson County;ID:5596986', '27115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27115', '112', '28992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28993', '1079', '1', 'Jerome County', 'US.ID.053', 'ASCII:Jerome County;ID:5597037', '27116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27116', '112', '28993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28994', '1079', '1', 'Kootenai County', 'US.ID.055', 'ASCII:Kootenai County;ID:5597922', '27117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27117', '112', '28994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28995', '1079', '1', 'Latah County', 'US.ID.057', 'ASCII:Latah County;ID:5598264', '27118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27118', '112', '28995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28996', '1079', '1', 'Lemhi County', 'US.ID.059', 'ASCII:Lemhi County;ID:5598464', '27119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27119', '112', '28996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28997', '1079', '1', 'Lewis County', 'US.ID.061', 'ASCII:Lewis County;ID:5598527', '27120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27120', '112', '28997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28998', '1079', '1', 'Lincoln County', 'US.ID.063', 'ASCII:Lincoln County;ID:5598678', '27121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27121', '112', '28998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('28999', '1079', '1', 'Madison County', 'US.ID.065', 'ASCII:Madison County;ID:5599930', '27122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27122', '112', '28999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29000', '1079', '1', 'Minidoka County', 'US.ID.067', 'ASCII:Minidoka County;ID:5601141', '27123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27123', '112', '29000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29001', '1079', '1', 'Nez Perce County', 'US.ID.069', 'ASCII:Nez Perce County;ID:5602115', '27124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27124', '112', '29001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29002', '1079', '1', 'Oneida County', 'US.ID.071', 'ASCII:Oneida County;ID:5602844', '27125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27125', '112', '29002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29003', '1079', '1', 'Owyhee County', 'US.ID.073', 'ASCII:Owyhee County;ID:5603018', '27126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27126', '112', '29003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29004', '1079', '1', 'Payette County', 'US.ID.075', 'ASCII:Payette County;ID:5603395', '27127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27127', '112', '29004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29005', '1079', '1', 'Power County', 'US.ID.077', 'ASCII:Power County;ID:5604439', '27128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27128', '112', '29005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29006', '1079', '1', 'Shoshone County', 'US.ID.079', 'ASCII:Shoshone County;ID:5607202', '27129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27129', '112', '29006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29007', '1079', '1', 'Teton County', 'US.ID.081', 'ASCII:Teton County;ID:5609855', '27130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27130', '112', '29007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29008', '1079', '1', 'Twin Falls County', 'US.ID.083', 'ASCII:Twin Falls County;ID:5610815', '27131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27131', '112', '29008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29009', '1079', '1', 'Valley County', 'US.ID.085', 'ASCII:Valley County;ID:5611156', '27132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27132', '112', '29009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29010', '1079', '1', 'Washington County', 'US.ID.087', 'ASCII:Washington County;ID:5611570', '27133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27133', '112', '29010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ID.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29011', '1079', '1', 'Beaverhead County', 'US.MT.001', 'ASCII:Beaverhead County;ID:5639238', '27134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27134', '112', '29011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29012', '1079', '1', 'Big Horn County', 'US.MT.003', 'ASCII:Big Horn County;ID:5639974', '27135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27135', '112', '29012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29013', '1079', '1', 'Blaine County', 'US.MT.005', 'ASCII:Blaine County;ID:5640934', '27136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27136', '112', '29013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29014', '1079', '1', 'Broadwater County', 'US.MT.007', 'ASCII:Broadwater County;ID:5642059', '27137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27137', '112', '29014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29015', '1079', '1', 'Carbon County', 'US.MT.009', 'ASCII:Carbon County;ID:5643686', '27138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27138', '112', '29015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29016', '1079', '1', 'Carter County', 'US.MT.011', 'ASCII:Carter County;ID:5643864', '27139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27139', '112', '29016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29017', '1079', '1', 'Cascade County', 'US.MT.013', 'ASCII:Cascade County;ID:5643929', '27140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27140', '112', '29017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29018', '1079', '1', 'Chouteau County', 'US.MT.015', 'ASCII:Chouteau County;ID:5644870', '27141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27141', '112', '29018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29019', '1079', '1', 'Custer County', 'US.MT.017', 'ASCII:Custer County;ID:5647449', '27142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27142', '112', '29019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29020', '1079', '1', 'Daniels County', 'US.MT.019', 'ASCII:Daniels County;ID:5647744', '27143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27143', '112', '29020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29021', '1079', '1', 'Dawson County', 'US.MT.021', 'ASCII:Dawson County;ID:5647905', '27144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27144', '112', '29021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29022', '1079', '1', 'Deer Lodge County', 'US.MT.023', 'ASCII:Deer Lodge County;ID:5648270', '27145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27145', '112', '29022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29023', '1079', '1', 'Fallon County', 'US.MT.025', 'ASCII:Fallon County;ID:5651490', '27146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27146', '112', '29023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29024', '1079', '1', 'Fergus County', 'US.MT.027', 'ASCII:Fergus County;ID:5651735', '27147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27147', '112', '29024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29025', '1079', '1', 'Flathead County', 'US.MT.029', 'ASCII:Flathead County;ID:5652361', '27148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27148', '112', '29025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29026', '1079', '1', 'Gallatin County', 'US.MT.031', 'ASCII:Gallatin County;ID:5653656', '27149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27149', '112', '29026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29027', '1079', '1', 'Garfield County', 'US.MT.033', 'ASCII:Garfield County;ID:5653782', '27150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27150', '112', '29027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29028', '1079', '1', 'Glacier County', 'US.MT.035', 'ASCII:Glacier County;ID:5654267', '27151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27151', '112', '29028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29029', '1079', '1', 'Golden Valley County', 'US.MT.037', 'ASCII:Golden Valley County;ID:5654674', '27152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27152', '112', '29029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29030', '1079', '1', 'Granite County', 'US.MT.039', 'ASCII:Granite County;ID:5654985', '27153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27153', '112', '29030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29031', '1079', '1', 'Hill County', 'US.MT.041', 'ASCII:Hill County;ID:5657400', '27154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27154', '112', '29031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29032', '1079', '1', 'Jefferson County', 'US.MT.043', 'ASCII:Jefferson County;ID:5659534', '27155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27155', '112', '29032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29033', '1079', '1', 'Judith Basin County', 'US.MT.045', 'ASCII:Judith Basin County;ID:5660055', '27156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27156', '112', '29033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29034', '1079', '1', 'Lake County', 'US.MT.047', 'ASCII:Lake County;ID:5661385', '27157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27157', '112', '29034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29035', '1079', '1', 'Lewis and Clark County', 'US.MT.049', 'ASCII:Lewis and Clark County;ID:5662129', '27158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27158', '112', '29035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29036', '1079', '1', 'Liberty County', 'US.MT.051', 'ASCII:Liberty County;ID:5662222', '27159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27159', '112', '29036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29037', '1079', '1', 'Lincoln County', 'US.MT.053', 'ASCII:Lincoln County;ID:5662406', '27160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27160', '112', '29037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29038', '1079', '1', 'Madison County', 'US.MT.057', 'ASCII:Madison County;ID:5664295', '27161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27161', '112', '29038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29039', '1079', '1', 'McCone County', 'US.MT.055', 'ASCII:McCone County;ID:5665177', '27162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27162', '112', '29039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29040', '1079', '1', 'Meagher County', 'US.MT.059', 'ASCII:Meagher County;ID:5665612', '27163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27163', '112', '29040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29041', '1079', '1', 'Mineral County', 'US.MT.061', 'ASCII:Mineral County;ID:5666480', '27164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27164', '112', '29041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29042', '1079', '1', 'Missoula County', 'US.MT.063', 'ASCII:Missoula County;ID:5666648', '27165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27165', '112', '29042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29043', '1079', '1', 'Musselshell County', 'US.MT.065', 'ASCII:Musselshell County;ID:5667879', '27166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27166', '112', '29043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29044', '1079', '1', 'Park County', 'US.MT.067', 'ASCII:Park County;ID:5670652', '27167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27167', '112', '29044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29045', '1079', '1', 'Petroleum County', 'US.MT.069', 'ASCII:Petroleum County;ID:5671200', '27168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27168', '112', '29045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29046', '1079', '1', 'Phillips County', 'US.MT.071', 'ASCII:Phillips County;ID:5671269', '27169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27169', '112', '29046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29047', '1079', '1', 'Pondera County', 'US.MT.073', 'ASCII:Pondera County;ID:5672061', '27170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27170', '112', '29047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29048', '1079', '1', 'Powder River County', 'US.MT.075', 'ASCII:Powder River County;ID:5672326', '27171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27171', '112', '29048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29049', '1079', '1', 'Powell County', 'US.MT.077', 'ASCII:Powell County;ID:5672344', '27172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27172', '112', '29049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29050', '1079', '1', 'Prairie County', 'US.MT.079', 'ASCII:Prairie County;ID:5672408', '27173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27173', '112', '29050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29051', '1079', '1', 'Ravalli County', 'US.MT.081', 'ASCII:Ravalli County;ID:5673204', '27174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27174', '112', '29051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29052', '1079', '1', 'Richland County', 'US.MT.083', 'ASCII:Richland County;ID:5673849', '27175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27175', '112', '29052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29053', '1079', '1', 'Roosevelt County', 'US.MT.085', 'ASCII:Roosevelt County;ID:5674655', '27176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27176', '112', '29053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29054', '1079', '1', 'Rosebud County', 'US.MT.087', 'ASCII:Rosebud County;ID:5674707', '27177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27177', '112', '29054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29055', '1079', '1', 'Sanders County', 'US.MT.089', 'ASCII:Sanders County;ID:5676299', '27178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27178', '112', '29055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29056', '1079', '1', 'Sheridan County', 'US.MT.091', 'ASCII:Sheridan County;ID:5677503', '27179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27179', '112', '29056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29057', '1079', '1', 'Silver Bow County', 'US.MT.093', 'ASCII:Silver Bow County;ID:5677822', '27180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27180', '112', '29057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29058', '1079', '1', 'Stillwater County', 'US.MT.095', 'ASCII:Stillwater County;ID:5680538', '27181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27181', '112', '29058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29059', '1079', '1', 'Sweet Grass County', 'US.MT.097', 'ASCII:Sweet Grass County;ID:5681435', '27182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27182', '112', '29059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29060', '1079', '1', 'Teton County', 'US.MT.099', 'ASCII:Teton County;ID:5681965', '27183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27183', '112', '29060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29061', '1079', '1', 'Toole County', 'US.MT.101', 'ASCII:Toole County;ID:5682810', '27184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27184', '112', '29061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29062', '1079', '1', 'Treasure County', 'US.MT.103', 'ASCII:Treasure County;ID:5683061', '27185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27185', '112', '29062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29063', '1079', '1', 'Valley County', 'US.MT.105', 'ASCII:Valley County;ID:5684246', '27186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27186', '112', '29063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29064', '1079', '1', 'Wheatland County', 'US.MT.107', 'ASCII:Wheatland County;ID:5685886', '27187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27187', '112', '29064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29065', '1079', '1', 'Wibaux County', 'US.MT.109', 'ASCII:Wibaux County;ID:5686294', '27188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27188', '112', '29065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29066', '1079', '1', 'Yellowstone County', 'US.MT.111', 'ASCII:Yellowstone County;ID:5687489', '27189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27189', '112', '29066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.MT.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29067', '1079', '1', 'Adams County', 'US.ND.001', 'ASCII:Adams County;ID:5687646', '27190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27190', '112', '29067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29068', '1079', '1', 'Billings County', 'US.ND.007', 'ASCII:Billings County;ID:5688020', '27191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27191', '112', '29068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29069', '1079', '1', 'Bottineau County', 'US.ND.009', 'ASCII:Bottineau County;ID:5688108', '27192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27192', '112', '29069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29070', '1079', '1', 'Bowman County', 'US.ND.011', 'ASCII:Bowman County;ID:5688138', '27193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27193', '112', '29070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29071', '1079', '1', 'Burke County', 'US.ND.013', 'ASCII:Burke County;ID:5688254', '27194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27194', '112', '29071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29072', '1079', '1', 'Burleigh County', 'US.ND.015', 'ASCII:Burleigh County;ID:5688266', '27195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27195', '112', '29072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29073', '1079', '1', 'Divide County', 'US.ND.023', 'ASCII:Divide County;ID:5688792', '27196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27196', '112', '29073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29074', '1079', '1', 'Dunn County', 'US.ND.025', 'ASCII:Dunn County;ID:5688859', '27197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27197', '112', '29074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29075', '1079', '1', 'Emmons County', 'US.ND.029', 'ASCII:Emmons County;ID:5689006', '27198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27198', '112', '29075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29076', '1079', '1', 'Golden Valley County', 'US.ND.033', 'ASCII:Golden Valley County;ID:5689315', '27199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27199', '112', '29076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29077', '1079', '1', 'Grant County', 'US.ND.037', 'ASCII:Grant County;ID:5689375', '27200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27200', '112', '29077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29078', '1079', '1', 'Hettinger County', 'US.ND.041', 'ASCII:Hettinger County;ID:5689621', '27201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27201', '112', '29078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29079', '1079', '1', 'McHenry County', 'US.ND.049', 'ASCII:McHenry County;ID:5690436', '27202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27202', '112', '29079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29080', '1079', '1', 'McKenzie County', 'US.ND.053', 'ASCII:McKenzie County;ID:5690440', '27203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27203', '112', '29080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29081', '1079', '1', 'McLean County', 'US.ND.055', 'ASCII:McLean County;ID:5690448', '27204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27204', '112', '29081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29082', '1079', '1', 'Mercer County', 'US.ND.057', 'ASCII:Mercer County;ID:5690489', '27205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27205', '112', '29082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29083', '1079', '1', 'Morton County', 'US.ND.059', 'ASCII:Morton County;ID:5690583', '27206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27206', '112', '29083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29084', '1079', '1', 'Mountrail County', 'US.ND.061', 'ASCII:Mountrail County;ID:5690614', '27207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27207', '112', '29084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29085', '1079', '1', 'Oliver County', 'US.ND.065', 'ASCII:Oliver County;ID:5690889', '27208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27208', '112', '29085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29086', '1079', '1', 'Pierce County', 'US.ND.069', 'ASCII:Pierce County;ID:5691033', '27209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27209', '112', '29086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29087', '1079', '1', 'Renville County', 'US.ND.075', 'ASCII:Renville County;ID:5691264', '27210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27210', '112', '29087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29088', '1079', '1', 'Sheridan County', 'US.ND.083', 'ASCII:Sheridan County;ID:5692064', '27211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27211', '112', '29088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29089', '1079', '1', 'Sioux County', 'US.ND.085', 'ASCII:Sioux County;ID:5692108', '27212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27212', '112', '29089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29090', '1079', '1', 'Slope County', 'US.ND.087', 'ASCII:Slope County;ID:5692146', '27213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27213', '112', '29090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29091', '1079', '1', 'Stark County', 'US.ND.089', 'ASCII:Stark County;ID:5692348', '27214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27214', '112', '29091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29092', '1079', '1', 'Ward County', 'US.ND.101', 'ASCII:Ward County;ID:5692798', '27215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27215', '112', '29092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29093', '1079', '1', 'Williams County', 'US.ND.105', 'ASCII:Williams County;ID:5692940', '27216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27216', '112', '29093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.ND.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29094', '1079', '1', 'Arthur County', 'US.NE.005', 'ASCII:Arthur County;ID:5693299', '27217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27217', '112', '29094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29095', '1079', '1', 'Banner County', 'US.NE.007', 'ASCII:Banner County;ID:5693402', '27218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27218', '112', '29095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29096', '1079', '1', 'Box Butte County', 'US.NE.013', 'ASCII:Box Butte County;ID:5693772', '27219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27219', '112', '29096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29097', '1079', '1', 'Chase County', 'US.NE.029', 'ASCII:Chase County;ID:5694236', '27220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27220', '112', '29097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29098', '1079', '1', 'Cherry County', 'US.NE.031', 'ASCII:Cherry County;ID:5694243', '27221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27221', '112', '29098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29099', '1079', '1', 'Cheyenne County', 'US.NE.033', 'ASCII:Cheyenne County;ID:5694258', '27222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27222', '112', '29099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29100', '1079', '1', 'Dawes County', 'US.NE.045', 'ASCII:Dawes County;ID:5694727', '27223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27223', '112', '29100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29101', '1079', '1', 'Deuel County', 'US.NE.049', 'ASCII:Deuel County;ID:5694776', '27224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27224', '112', '29101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29102', '1079', '1', 'Dundy County', 'US.NE.057', 'ASCII:Dundy County;ID:5694963', '27225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27225', '112', '29102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29103', '1079', '1', 'Frontier County', 'US.NE.063', 'ASCII:Frontier County;ID:5695504', '27226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27226', '112', '29103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29104', '1079', '1', 'Garden County', 'US.NE.069', 'ASCII:Garden County;ID:5695559', '27227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27227', '112', '29104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29105', '1079', '1', 'Grant County', 'US.NE.075', 'ASCII:Grant County;ID:5695796', '27228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27228', '112', '29105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29106', '1079', '1', 'Hayes County', 'US.NE.085', 'ASCII:Hayes County;ID:5696051', '27229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27229', '112', '29106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29107', '1079', '1', 'Hitchcock County', 'US.NE.087', 'ASCII:Hitchcock County;ID:5696203', '27230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27230', '112', '29107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29108', '1079', '1', 'Hooker County', 'US.NE.091', 'ASCII:Hooker County;ID:5696254', '27231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27231', '112', '29108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29109', '1079', '1', 'Keith County', 'US.NE.101', 'ASCII:Keith County;ID:5696644', '27232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27232', '112', '29109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29110', '1079', '1', 'Keya Paha County', 'US.NE.103', 'ASCII:Keya Paha County;ID:5696690', '27233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27233', '112', '29110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29111', '1079', '1', 'Kimball County', 'US.NE.105', 'ASCII:Kimball County;ID:5696719', '27234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27234', '112', '29111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29112', '1079', '1', 'Lincoln County', 'US.NE.111', 'ASCII:Lincoln County;ID:5697026', '27235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27235', '112', '29112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29113', '1079', '1', 'Logan County', 'US.NE.113', 'ASCII:Logan County;ID:5697135', '27236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27236', '112', '29113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29114', '1079', '1', 'McPherson County', 'US.NE.117', 'ASCII:McPherson County;ID:5697457', '27237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27237', '112', '29114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29115', '1079', '1', 'Morrill County', 'US.NE.123', 'ASCII:Morrill County;ID:5697710', '27238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27238', '112', '29115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29116', '1079', '1', 'Perkins County', 'US.NE.135', 'ASCII:Perkins County;ID:5698262', '27239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27239', '112', '29116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29117', '1079', '1', 'Red Willow County', 'US.NE.145', 'ASCII:Red Willow County;ID:5698593', '27240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27240', '112', '29117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.145» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29118', '1079', '1', 'Scotts Bluff County', 'US.NE.157', 'ASCII:Scotts Bluff County;ID:5699397', '27241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27241', '112', '29118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.157» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29119', '1079', '1', 'Sheridan County', 'US.NE.161', 'ASCII:Sheridan County;ID:5699519', '27242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27242', '112', '29119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.161» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29120', '1079', '1', 'Sioux County', 'US.NE.165', 'ASCII:Sioux County;ID:5699598', '27243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27243', '112', '29120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.165» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29121', '1079', '1', 'Thomas County', 'US.NE.171', 'ASCII:Thomas County;ID:5700112', '27244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27244', '112', '29121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NE.171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29122', '1079', '1', 'Elko County', 'US.NV.007', 'ASCII:Elko County;ID:5703673', '27245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27245', '112', '29122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29123', '1079', '1', 'Eureka County', 'US.NV.011', 'ASCII:Eureka County;ID:5703766', '27246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27246', '112', '29123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29124', '1079', '1', 'Humboldt County', 'US.NV.013', 'ASCII:Humboldt County;ID:5704974', '27247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27247', '112', '29124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29125', '1079', '1', 'Pershing County', 'US.NV.027', 'ASCII:Pershing County;ID:5707263', '27248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27248', '112', '29125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29126', '1079', '1', 'Washoe County', 'US.NV.031', 'ASCII:Washoe County;ID:5709906', '27249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27249', '112', '29126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NV.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29127', '1079', '1', 'Baker County', 'US.OR.001', 'ASCII:Baker County;ID:5712180', '27250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27250', '112', '29127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29128', '1079', '1', 'Benton County', 'US.OR.003', 'ASCII:Benton County;ID:5713677', '27251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27251', '112', '29128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29129', '1079', '1', 'Clackamas County', 'US.OR.005', 'ASCII:Clackamas County;ID:5719297', '27252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27252', '112', '29129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29130', '1079', '1', 'Clatsop County', 'US.OR.007', 'ASCII:Clatsop County;ID:5719408', '27253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27253', '112', '29130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29131', '1079', '1', 'Columbia County', 'US.OR.009', 'ASCII:Columbia County;ID:5720173', '27254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27254', '112', '29131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29132', '1079', '1', 'Coos County', 'US.OR.011', 'ASCII:Coos County;ID:5720502', '27255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27255', '112', '29132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29133', '1079', '1', 'Crook County', 'US.OR.013', 'ASCII:Crook County;ID:5721611', '27256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27256', '112', '29133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29134', '1079', '1', 'Curry County', 'US.OR.015', 'ASCII:Curry County;ID:5721936', '27257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27257', '112', '29134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29135', '1079', '1', 'Deschutes County', 'US.OR.017', 'ASCII:Deschutes County;ID:5722958', '27258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27258', '112', '29135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29136', '1079', '1', 'Douglas County', 'US.OR.019', 'ASCII:Douglas County;ID:5723759', '27259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27259', '112', '29136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29137', '1079', '1', 'Gilliam County', 'US.OR.021', 'ASCII:Gilliam County;ID:5728364', '27260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27260', '112', '29137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29138', '1079', '1', 'Grant County', 'US.OR.023', 'ASCII:Grant County;ID:5729054', '27261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27261', '112', '29138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29139', '1079', '1', 'Harney County', 'US.OR.025', 'ASCII:Harney County;ID:5730293', '27262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27262', '112', '29139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29140', '1079', '1', 'Hood River County', 'US.OR.027', 'ASCII:Hood River County;ID:5731767', '27263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27263', '112', '29140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29141', '1079', '1', 'Jackson County', 'US.OR.029', 'ASCII:Jackson County;ID:5733351', '27264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27264', '112', '29141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29142', '1079', '1', 'Jefferson County', 'US.OR.031', 'ASCII:Jefferson County;ID:5733534', '27265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27265', '112', '29142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29143', '1079', '1', 'Josephine County', 'US.OR.033', 'ASCII:Josephine County;ID:5734120', '27266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27266', '112', '29143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29144', '1079', '1', 'Klamath County', 'US.OR.035', 'ASCII:Klamath County;ID:5735237', '27267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27267', '112', '29144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29145', '1079', '1', 'Lake County', 'US.OR.037', 'ASCII:Lake County;ID:5735647', '27268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27268', '112', '29145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29146', '1079', '1', 'Lane County', 'US.OR.039', 'ASCII:Lane County;ID:5735869', '27269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27269', '112', '29146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29147', '1079', '1', 'Lincoln County', 'US.OR.041', 'ASCII:Lincoln County;ID:5736643', '27270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27270', '112', '29147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29148', '1079', '1', 'Linn County', 'US.OR.043', 'ASCII:Linn County;ID:5736713', '27271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27271', '112', '29148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29149', '1079', '1', 'Malheur County', 'US.OR.045', 'ASCII:Malheur County;ID:5738839', '27272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27272', '112', '29149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29150', '1079', '1', 'Marion County', 'US.OR.047', 'ASCII:Marion County;ID:5739051', '27273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27273', '112', '29150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29151', '1079', '1', 'Morrow County', 'US.OR.049', 'ASCII:Morrow County;ID:5741531', '27274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27274', '112', '29151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29152', '1079', '1', 'Multnomah County', 'US.OR.051', 'ASCII:Multnomah County;ID:5742126', '27275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27275', '112', '29152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29153', '1079', '1', 'Polk County', 'US.OR.053', 'ASCII:Polk County;ID:5746351', '27276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27276', '112', '29153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29154', '1079', '1', 'Sherman County', 'US.OR.055', 'ASCII:Sherman County;ID:5751614', '27277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27277', '112', '29154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29155', '1079', '1', 'Tillamook County', 'US.OR.057', 'ASCII:Tillamook County;ID:5756780', '27278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27278', '112', '29155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29156', '1079', '1', 'Umatilla County', 'US.OR.059', 'ASCII:Umatilla County;ID:5758058', '27279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27279', '112', '29156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29157', '1079', '1', 'Union County', 'US.OR.061', 'ASCII:Union County;ID:5758120', '27280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27280', '112', '29157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29158', '1079', '1', 'Wallowa County', 'US.OR.063', 'ASCII:Wallowa County;ID:5759046', '27281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27281', '112', '29158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29159', '1079', '1', 'Wasco County', 'US.OR.065', 'ASCII:Wasco County;ID:5759298', '27282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27282', '112', '29159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29160', '1079', '1', 'Washington County', 'US.OR.067', 'ASCII:Washington County;ID:5759333', '27283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27283', '112', '29160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29161', '1079', '1', 'Wheeler County', 'US.OR.069', 'ASCII:Wheeler County;ID:5760229', '27284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27284', '112', '29161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29162', '1079', '1', 'Yamhill County', 'US.OR.071', 'ASCII:Yamhill County;ID:5761960', '27285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27285', '112', '29162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.OR.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29163', '1079', '1', 'Bennett County', 'US.SD.007', 'ASCII:Bennett County;ID:5762756', '27286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27286', '112', '29163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29164', '1079', '1', 'Butte County', 'US.SD.019', 'ASCII:Butte County;ID:5763234', '27287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27287', '112', '29164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29165', '1079', '1', 'Campbell County', 'US.SD.021', 'ASCII:Campbell County;ID:5763333', '27288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27288', '112', '29165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29166', '1079', '1', 'Corson County', 'US.SD.031', 'ASCII:Corson County;ID:5763761', '27289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27289', '112', '29166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29167', '1079', '1', 'Custer County', 'US.SD.033', 'ASCII:Custer County;ID:5763916', '27290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27290', '112', '29167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29168', '1079', '1', 'Dewey County', 'US.SD.041', 'ASCII:Dewey County;ID:5764119', '27291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27291', '112', '29168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29169', '1079', '1', 'Fall River County', 'US.SD.047', 'ASCII:Fall River County;ID:5764690', '27292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27292', '112', '29169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29170', '1079', '1', 'Haakon County', 'US.SD.055', 'ASCII:Haakon County;ID:5765294', '27293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27293', '112', '29170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29171', '1079', '1', 'Harding County', 'US.SD.063', 'ASCII:Harding County;ID:5765341', '27294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27294', '112', '29171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29172', '1079', '1', 'Jackson County', 'US.SD.071', 'ASCII:Jackson County;ID:5765964', '27295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27295', '112', '29172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29173', '1079', '1', 'Jones County', 'US.SD.075', 'ASCII:Jones County;ID:5766096', '27296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27296', '112', '29173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29174', '1079', '1', 'Lawrence County', 'US.SD.081', 'ASCII:Lawrence County;ID:5766411', '27297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27297', '112', '29174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29175', '1079', '1', 'Meade County', 'US.SD.093', 'ASCII:Meade County;ID:5767000', '27298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27298', '112', '29175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29176', '1079', '1', 'Mellette County', 'US.SD.095', 'ASCII:Mellette County;ID:5767033', '27299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27299', '112', '29176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29177', '1079', '1', 'Pennington County', 'US.SD.103', 'ASCII:Pennington County;ID:5767840', '27300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27300', '112', '29177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29178', '1079', '1', 'Perkins County', 'US.SD.105', 'ASCII:Perkins County;ID:5767864', '27301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27301', '112', '29178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29179', '1079', '1', 'Shannon County', 'US.SD.113', 'ASCII:Shannon County;ID:5768976', '27302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27302', '112', '29179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29180', '1079', '1', 'Stanley County', 'US.SD.117', 'ASCII:Stanley County;ID:5769386', '27303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27303', '112', '29180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29181', '1079', '1', 'Sully County', 'US.SD.119', 'ASCII:Sully County;ID:5769502', '27304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27304', '112', '29181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29182', '1079', '1', 'Todd County', 'US.SD.121', 'ASCII:Todd County;ID:5769778', '27305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27305', '112', '29182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29183', '1079', '1', 'Ziebach County', 'US.SD.137', 'ASCII:Ziebach County;ID:5770576', '27306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27306', '112', '29183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.SD.137» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29184', '1079', '1', 'Box Elder County', 'US.UT.003', 'ASCII:Box Elder County;ID:5771875', '27307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27307', '112', '29184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29185', '1079', '1', 'Cache County', 'US.UT.005', 'ASCII:Cache County;ID:5772317', '27308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27308', '112', '29185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29186', '1079', '1', 'Daggett County', 'US.UT.009', 'ASCII:Daggett County;ID:5773608', '27309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27309', '112', '29186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29187', '1079', '1', 'Davis County', 'US.UT.011', 'ASCII:Davis County;ID:5773664', '27310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27310', '112', '29187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29188', '1079', '1', 'Duchesne County', 'US.UT.013', 'ASCII:Duchesne County;ID:5774137', '27311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27311', '112', '29188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29189', '1079', '1', 'Morgan County', 'US.UT.029', 'ASCII:Morgan County;ID:5778525', '27312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27312', '112', '29189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29190', '1079', '1', 'Rich County', 'US.UT.033', 'ASCII:Rich County;ID:5780377', '27313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27313', '112', '29190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29191', '1079', '1', 'Salt Lake County', 'US.UT.035', 'ASCII:Salt Lake County;ID:5781004', '27314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27314', '112', '29191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29192', '1079', '1', 'Summit County', 'US.UT.043', 'ASCII:Summit County;ID:5782267', '27315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27315', '112', '29192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29193', '1079', '1', 'Tooele County', 'US.UT.045', 'ASCII:Tooele County;ID:5783699', '27316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27316', '112', '29193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29194', '1079', '1', 'Uintah County', 'US.UT.047', 'ASCII:Uintah County;ID:5783919', '27317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27317', '112', '29194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29195', '1079', '1', 'Utah County', 'US.UT.049', 'ASCII:Utah County;ID:5784025', '27318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27318', '112', '29195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29196', '1079', '1', 'Wasatch County', 'US.UT.051', 'ASCII:Wasatch County;ID:5784339', '27319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27319', '112', '29196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29197', '1079', '1', 'Weber County', 'US.UT.057', 'ASCII:Weber County;ID:5784440', '27320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27320', '112', '29197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.UT.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29198', '1079', '1', 'Adams County', 'US.WA.001', 'ASCII:Adams County;ID:5785282', '27321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27321', '112', '29198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29199', '1079', '1', 'Asotin County', 'US.WA.003', 'ASCII:Asotin County;ID:5785935', '27322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27322', '112', '29199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29200', '1079', '1', 'Benton County', 'US.WA.005', 'ASCII:Benton County;ID:5786991', '27323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27323', '112', '29200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29201', '1079', '1', 'Chelan County', 'US.WA.007', 'ASCII:Chelan County;ID:5789829', '27324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27324', '112', '29201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29202', '1079', '1', 'Clallam County', 'US.WA.009', 'ASCII:Clallam County;ID:5790164', '27325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27325', '112', '29202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29203', '1079', '1', 'Clark County', 'US.WA.011', 'ASCII:Clark County;ID:5790179', '27326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27326', '112', '29203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29204', '1079', '1', 'Columbia County', 'US.WA.013', 'ASCII:Columbia County;ID:5790614', '27327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27327', '112', '29204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29205', '1079', '1', 'Cowlitz County', 'US.WA.015', 'ASCII:Cowlitz County;ID:5791206', '27328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27328', '112', '29205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29206', '1079', '1', 'Douglas County', 'US.WA.017', 'ASCII:Douglas County;ID:5792681', '27329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27329', '112', '29206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29207', '1079', '1', 'Ferry County', 'US.WA.019', 'ASCII:Ferry County;ID:5794294', '27330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27330', '112', '29207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29208', '1079', '1', 'Franklin County', 'US.WA.021', 'ASCII:Franklin County;ID:5794976', '27331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27331', '112', '29208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29209', '1079', '1', 'Garfield County', 'US.WA.023', 'ASCII:Garfield County;ID:5795265', '27332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27332', '112', '29209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29210', '1079', '1', 'Grant County', 'US.WA.025', 'ASCII:Grant County;ID:5796034', '27333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27333', '112', '29210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29211', '1079', '1', 'Grays Harbor County', 'US.WA.027', 'ASCII:Grays Harbor County;ID:5796126', '27334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27334', '112', '29211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29212', '1079', '1', 'Island County', 'US.WA.029', 'ASCII:Island County;ID:5798453', '27335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27335', '112', '29212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29213', '1079', '1', 'Jefferson County', 'US.WA.031', 'ASCII:Jefferson County;ID:5798663', '27336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27336', '112', '29213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29214', '1079', '1', 'King County', 'US.WA.033', 'ASCII:King County;ID:5799783', '27337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27337', '112', '29214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29215', '1079', '1', 'Kitsap County', 'US.WA.035', 'ASCII:Kitsap County;ID:5799853', '27338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27338', '112', '29215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29216', '1079', '1', 'Kittitas County', 'US.WA.037', 'ASCII:Kittitas County;ID:5799889', '27339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27339', '112', '29216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29217', '1079', '1', 'Klickitat County', 'US.WA.039', 'ASCII:Klickitat County;ID:5799909', '27340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27340', '112', '29217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29218', '1079', '1', 'Lewis County', 'US.WA.041', 'ASCII:Lewis County;ID:5800813', '27341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27341', '112', '29218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29219', '1079', '1', 'Lincoln County', 'US.WA.043', 'ASCII:Lincoln County;ID:5800965', '27342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27342', '112', '29219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29220', '1079', '1', 'Mason County', 'US.WA.045', 'ASCII:Mason County;ID:5802584', '27343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27343', '112', '29220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29221', '1079', '1', 'Okanogan County', 'US.WA.047', 'ASCII:Okanogan County;ID:5805553', '27344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27344', '112', '29221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29222', '1079', '1', 'Pacific County', 'US.WA.049', 'ASCII:Pacific County;ID:5806002', '27345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27345', '112', '29222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29223', '1079', '1', 'Pend Oreille County', 'US.WA.051', 'ASCII:Pend Oreille County;ID:5806491', '27346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27346', '112', '29223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29224', '1079', '1', 'Pierce County', 'US.WA.053', 'ASCII:Pierce County;ID:5806769', '27347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27347', '112', '29224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29225', '1079', '1', 'San Juan County', 'US.WA.055', 'ASCII:San Juan County;ID:5809422', '27348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27348', '112', '29225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29226', '1079', '1', 'Skagit County', 'US.WA.057', 'ASCII:Skagit County;ID:5810608', '27349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27349', '112', '29226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29227', '1079', '1', 'Skamania County', 'US.WA.059', 'ASCII:Skamania County;ID:5810628', '27350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27350', '112', '29227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29228', '1079', '1', 'Snohomish County', 'US.WA.061', 'ASCII:Snohomish County;ID:5810982', '27351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27351', '112', '29228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29229', '1079', '1', 'Spokane County', 'US.WA.063', 'ASCII:Spokane County;ID:5811704', '27352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27352', '112', '29229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29230', '1079', '1', 'Stevens County', 'US.WA.065', 'ASCII:Stevens County;ID:5812148', '27353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27353', '112', '29230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29231', '1079', '1', 'Thurston County', 'US.WA.067', 'ASCII:Thurston County;ID:5813521', '27354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27354', '112', '29231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29232', '1079', '1', 'Wahkiakum County', 'US.WA.069', 'ASCII:Wahkiakum County;ID:5814851', '27355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27355', '112', '29232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29233', '1079', '1', 'Walla Walla County', 'US.WA.071', 'ASCII:Walla Walla County;ID:5814921', '27356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27356', '112', '29233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29234', '1079', '1', 'Whatcom County', 'US.WA.073', 'ASCII:Whatcom County;ID:5815675', '27357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27357', '112', '29234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29235', '1079', '1', 'Whitman County', 'US.WA.075', 'ASCII:Whitman County;ID:5815891', '27358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27358', '112', '29235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29236', '1079', '1', 'Yakima County', 'US.WA.077', 'ASCII:Yakima County;ID:5816597', '27359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27359', '112', '29236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WA.077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29237', '1079', '1', 'Albany County', 'US.WY.001', 'ASCII:Albany County;ID:5816904', '27360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27360', '112', '29237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29238', '1079', '1', 'Big Horn County', 'US.WY.003', 'ASCII:Big Horn County;ID:5818658', '27361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27361', '112', '29238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29239', '1079', '1', 'Campbell County', 'US.WY.005', 'ASCII:Campbell County;ID:5820441', '27362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27362', '112', '29239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29240', '1079', '1', 'Carbon County', 'US.WY.007', 'ASCII:Carbon County;ID:5820552', '27363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27363', '112', '29240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29241', '1079', '1', 'Converse County', 'US.WY.009', 'ASCII:Converse County;ID:5821791', '27364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27364', '112', '29241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29242', '1079', '1', 'Crook County', 'US.WY.011', 'ASCII:Crook County;ID:5822351', '27365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27365', '112', '29242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29243', '1079', '1', 'Fremont County', 'US.WY.013', 'ASCII:Fremont County;ID:5825643', '27366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27366', '112', '29243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29244', '1079', '1', 'Goshen County', 'US.WY.015', 'ASCII:Goshen County;ID:5826220', '27367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27367', '112', '29244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29245', '1079', '1', 'Hot Springs County', 'US.WY.017', 'ASCII:Hot Springs County;ID:5828054', '27368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27368', '112', '29245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29246', '1079', '1', 'Johnson County', 'US.WY.019', 'ASCII:Johnson County;ID:5828957', '27369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27369', '112', '29246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29247', '1079', '1', 'Laramie County', 'US.WY.021', 'ASCII:Laramie County;ID:5830051', '27370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27370', '112', '29247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29248', '1079', '1', 'Lincoln County', 'US.WY.023', 'ASCII:Lincoln County;ID:5830383', '27371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27371', '112', '29248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29249', '1079', '1', 'Natrona County', 'US.WY.025', 'ASCII:Natrona County;ID:5833224', '27372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27372', '112', '29249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29250', '1079', '1', 'Niobrara County', 'US.WY.027', 'ASCII:Niobrara County;ID:5833446', '27373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27373', '112', '29250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29251', '1079', '1', 'Park County', 'US.WY.029', 'ASCII:Park County;ID:5834587', '27374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27374', '112', '29251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29252', '1079', '1', 'Platte County', 'US.WY.031', 'ASCII:Platte County;ID:5835308', '27375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27375', '112', '29252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29253', '1079', '1', 'Sheridan County', 'US.WY.033', 'ASCII:Sheridan County;ID:5838199', '27376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27376', '112', '29253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29254', '1079', '1', 'Sublette County', 'US.WY.035', 'ASCII:Sublette County;ID:5840177', '27377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27377', '112', '29254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29255', '1079', '1', 'Sweetwater County', 'US.WY.037', 'ASCII:Sweetwater County;ID:5840426', '27378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27378', '112', '29255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29256', '1079', '1', 'Teton County', 'US.WY.039', 'ASCII:Teton County;ID:5840786', '27379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27379', '112', '29256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29257', '1079', '1', 'Uinta County', 'US.WY.041', 'ASCII:Uinta County;ID:5841693', '27380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27380', '112', '29257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29258', '1079', '1', 'Washakie County', 'US.WY.043', 'ASCII:Washakie County;ID:5842257', '27381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27381', '112', '29258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29259', '1079', '1', 'Weston County', 'US.WY.045', 'ASCII:Weston County;ID:5842707', '27382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27382', '112', '29259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.WY.045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29260', '1079', '1', 'Haines Borough', 'US.AK.100', 'ASCII:Haines Borough;ID:5846893', '27383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27383', '112', '29260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29261', '1079', '1', 'Kalawao County', 'US.HI.005', 'ASCII:Kalawao County;ID:5847795', '27384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27384', '112', '29261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.HI.005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29262', '1079', '1', 'Kauai County', 'US.HI.007', 'ASCII:Kauai County;ID:5848514', '27385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27385', '112', '29262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.HI.007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29263', '1079', '1', 'Maui County', 'US.HI.009', 'ASCII:Maui;ID:5850871', '27386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27386', '112', '29263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.HI.009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29264', '1079', '1', 'Hawaii County', 'US.HI.001', 'ASCII:Hawaii County;ID:5855765', '27387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27387', '112', '29264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.HI.001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29265', '1079', '1', 'Honolulu County', 'US.HI.003', 'ASCII:Honolulu County;ID:5856194', '27388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27388', '112', '29265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.HI.003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29266', '1079', '1', 'Bristol Bay Borough', 'US.AK.060', 'ASCII:Bristol Bay Borough;ID:5858042', '27389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27389', '112', '29266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29267', '1079', '1', 'Denali Borough', 'US.AK.068', 'ASCII:Denali Borough;ID:5860541', '27390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27390', '112', '29267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29268', '1079', '1', 'Dillingham Census Area', 'US.AK.070', 'ASCII:Dillingham Census Area;ID:5860696', '27391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27391', '112', '29268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29269', '1079', '1', 'Fairbanks North Star Borough', 'US.AK.090', 'ASCII:Fairbanks North Star Borough;ID:5861900', '27392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27392', '112', '29269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29270', '1079', '1', 'Kenai Peninsula Borough', 'US.AK.122', 'ASCII:Kenai Peninsula Borough;ID:5866071', '27393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27393', '112', '29270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29271', '1079', '1', 'Kodiak Island Borough', 'US.AK.150', 'ASCII:Kodiak Island Borough;ID:5866574', '27394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27394', '112', '29271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.150» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29272', '1079', '1', 'Lake and Peninsula Borough', 'US.AK.164', 'ASCII:Lake and Peninsula Borough;ID:5867113', '27395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27395', '112', '29272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.164» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29273', '1079', '1', 'Matanuska-Susitna Borough', 'US.AK.170', 'ASCII:Matanuska-Susitna Borough;ID:5868437', '27396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27396', '112', '29273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29274', '1079', '1', 'Nome Census Area', 'US.AK.180', 'ASCII:Nome Census Area;ID:5870134', '27397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27397', '112', '29274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29275', '1079', '1', 'North Slope Borough', 'US.AK.185', 'ASCII:North Slope Borough;ID:5870308', '27398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27398', '112', '29275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.185» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29276', '1079', '1', 'Northwest Arctic Borough', 'US.AK.188', 'ASCII:Northwest Arctic Borough;ID:5870351', '27399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27399', '112', '29276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.188» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29277', '1079', '1', 'Southeast Fairbanks Census Area', 'US.AK.240', 'ASCII:Southeast Fairbanks Census Area;ID:5874863', '27400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27400', '112', '29277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29278', '1079', '1', 'Valdez-Cordova Census Area', 'US.AK.261', 'ASCII:Valdez-Cordova Census Area;ID:5877395', '27401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27401', '112', '29278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29279', '1079', '1', 'Wade Hampton Census Area', 'US.AK.270', 'ASCII:Wade Hampton Census Area;ID:5877533', '27402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27402', '112', '29279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29280', '1079', '1', 'Yukon-Koyukuk Census Area', 'US.AK.290', 'ASCII:Yukon-Koyukuk Census Area;ID:5878558', '27403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27403', '112', '29280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.290» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29281', '1079', '1', 'Aleutians West Census Area', 'US.AK.016', 'ASCII:Aleutians West Census Area;ID:5879164', '27404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27404', '112', '29281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29282', '1079', '1', 'Aleutians East Borough', 'US.AK.013', 'ASCII:Aleutians East Borough;ID:5879166', '27405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27405', '112', '29282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29283', '1079', '1', 'Anchorage Municipality', 'US.AK.020', 'ASCII:Anchorage Municipality;ID:5879348', '27406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27406', '112', '29283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29284', '1079', '1', 'Bethel Census Area', 'US.AK.050', 'ASCII:Bethel Census Area;ID:5880573', '27407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27407', '112', '29284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.AK.050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29285', '1079', '1', 'Kings County', 'US.NY.047', 'ASCII:Kings County;ID:6941775', '27408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27408', '112', '29285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «US.NY.047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29286', '1079', '1', 'Shumanay Tumani', 'UZ.09.601276', 'ASCII:Shumanay Tumani;ID:601276', '27409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27409', '112', '29286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.601276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29287', '1079', '1', 'Nukus Tumani', 'UZ.09.601292', 'ASCII:Nukus Tumani;ID:601292', '27410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27410', '112', '29287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.601292» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29288', '1079', '1', 'Mŭynoq Tumani', 'UZ.09.601301', 'ASCII:Muynoq Tumani;ID:601301', '27411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27411', '112', '29288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.601301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29289', '1079', '1', 'Qanlikŭl Tumani', 'UZ.09.601309', 'ASCII:Qanlikul Tumani;ID:601309', '27412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27412', '112', '29289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.601309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29290', '1079', '1', 'Qŭnghirot Tumani', 'UZ.09.601322', 'ASCII:Qunghirot Tumani;ID:601322', '27413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27413', '112', '29290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.601322» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29291', '1079', '1', 'Khŭjayli Tumani', 'UZ.09.601340', 'ASCII:Khujayli Tumani;ID:601340', '27414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27414', '112', '29291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.601340» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29292', '1079', '1', 'Kegayli Tumani', 'UZ.09.601347', 'ASCII:Kegayli Tumani;ID:601347', '27415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27415', '112', '29292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.601347» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29293', '1079', '1', 'Chimboy Tumani', 'UZ.09.601394', 'ASCII:Chimboy Tumani;ID:601394', '27416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27416', '112', '29293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.601394» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29294', '1079', '1', 'Bŭzatow Tumani', 'UZ.09.601398', 'ASCII:Buzatow Tumani;ID:601398', '27417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27417', '112', '29294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.601398» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29295', '1079', '1', 'Nukus Shahri', 'UZ.09.829930', 'ASCII:Nukus Shahri;ID:829930', '27418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27418', '112', '29295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.829930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29296', '1079', '1', 'Qŭnghirot Shahri', 'UZ.09.829955', 'ASCII:Qunghirot Shahri;ID:829955', '27419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27419', '112', '29296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.829955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29297', '1079', '1', 'Takhiatosh Shahri', 'UZ.09.829958', 'ASCII:Takhiatosh Shahri;ID:829958', '27420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27420', '112', '29297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.829958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29298', '1079', '1', 'Khŭjayli Shahri', 'UZ.09.829959', 'ASCII:Khujayli Shahri;ID:829959', '27421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27421', '112', '29298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.829959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29299', '1079', '1', 'Chimboy Shahri', 'UZ.09.829960', 'ASCII:Chimboy Shahri;ID:829960', '27422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27422', '112', '29299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.829960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29300', '1079', '1', 'Zomin Tumani', 'UZ.15.1215692', 'ASCII:Zomin Tumani;ID:1215692', '27423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27423', '112', '29300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1215692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29301', '1079', '1', 'Yakkabog'' Tumani', 'UZ.08.1215766', 'ASCII:Yakkabog'' Tumani;ID:1215766', '27424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27424', '112', '29301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1215766» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29302', '1079', '1', 'Wobkent Tumani', 'UZ.02.1215788', 'ASCII:Wobkent Tumani;ID:1215788', '27425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27425', '112', '29302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1215788» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29303', '1079', '1', 'Usmon Yusupow Tumani', 'UZ.08.1215811', 'ASCII:Usmon Yusupow Tumani;ID:1215811', '27426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27426', '112', '29303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1215811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29304', '1079', '1', 'Urgut Tumani', 'UZ.10.1215838', 'ASCII:Urgut Tumani;ID:1215838', '27427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27427', '112', '29304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1215838» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29305', '1079', '1', 'Kasbi Tumani', 'UZ.08.1215855', 'ASCII:Kasbi Tumani;ID:1215855', '27428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27428', '112', '29305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1215855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29306', '1079', '1', 'Termiz Tumani', 'UZ.12.1215958', 'ASCII:Termiz Tumani;ID:1215958', '27429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27429', '112', '29306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1215958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29307', '1079', '1', 'Jondor Tumani', 'UZ.02.1216048', 'ASCII:Jondor Tumani;ID:1216048', '27430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27430', '112', '29307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1216048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29308', '1079', '1', 'Nurobod Tumani', 'UZ.10.1216079', 'ASCII:Nurobod Tumani;ID:1216079', '27431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27431', '112', '29308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1216079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29309', '1079', '1', 'Sho''rchi Tumani', 'UZ.12.1216113', 'ASCII:Sho''rchi Tumani;ID:1216113', '27432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27432', '112', '29309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1216113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29310', '1079', '1', 'Sherobod Tumani', 'UZ.12.1216154', 'ASCII:Sherobod Tumani;ID:1216154', '27433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27433', '112', '29310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1216154» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29311', '1079', '1', 'Shahrisabz Tumani', 'UZ.08.1216186', 'ASCII:Shahrisabz Tumani;ID:1216186', '27434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27434', '112', '29311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1216186» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29312', '1079', '1', 'Sariosiyo Tumani', 'UZ.12.1216243', 'ASCII:Sariosiyo Tumani;ID:1216243', '27435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27435', '112', '29312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1216243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29313', '1079', '1', 'Samarqand Tumani', 'UZ.10.1216266', 'ASCII:Samarqand Tumani;ID:1216266', '27436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27436', '112', '29313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1216266» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29314', '1079', '1', 'Romiton Tumani', 'UZ.02.1216289', 'ASCII:Romiton Tumani;ID:1216289', '27437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27437', '112', '29314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1216289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29315', '1079', '1', 'Payariq Tumani', 'UZ.10.1216337', 'ASCII:Payariq Tumani;ID:1216337', '27438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27438', '112', '29315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1216337» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29316', '1079', '1', 'Pastdarg`om Tumani', 'UZ.10.1216341', 'ASCII:Pastdarg`om Tumani;ID:1216341', '27439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27439', '112', '29316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1216341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29317', '1079', '1', 'Paxtachi Tumani', 'UZ.10.1216354', 'ASCII:Paxtachi Tumani;ID:1216354', '27440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27440', '112', '29317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1216354» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29318', '1079', '1', 'Nishon Tumani', 'UZ.08.1216399', 'ASCII:Nishon Tumani;ID:1216399', '27441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27441', '112', '29318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1216399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29319', '1079', '1', 'Narpay Tumani', 'UZ.10.1216429', 'ASCII:Narpay Tumani;ID:1216429', '27442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27442', '112', '29319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1216429» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29320', '1079', '1', 'Muborak Tumani', 'UZ.08.1216474', 'ASCII:Muborak Tumani;ID:1216474', '27443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27443', '112', '29320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1216474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29321', '1079', '1', 'Qiziriq Tumani', 'UZ.12.1216571', 'ASCII:Qiziriq Tumani;ID:1216571', '27444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27444', '112', '29321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1216571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29322', '1079', '1', 'Qiziltepa Tumani', 'UZ.07.1216582', 'ASCII:Qiziltepa Tumani;ID:1216582', '27445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27445', '112', '29322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1216582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29323', '1079', '1', 'Qumqŭrghon Tumani', 'UZ.12.1216685', 'ASCII:Qumqurghon Tumani;ID:1216685', '27446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27446', '112', '29323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1216685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29324', '1079', '1', 'Kitob Tumani', 'UZ.08.1216786', 'ASCII:Kitob Tumani;ID:1216786', '27447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27447', '112', '29324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1216786» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29325', '1079', '1', 'Kattaqo`rg`on Tumani', 'UZ.10.1216987', 'ASCII:Kattaqo`rg`on Tumani;ID:1216987', '27448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27448', '112', '29325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1216987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29326', '1079', '1', 'Koson Tumani', 'UZ.08.1217005', 'ASCII:Koson Tumani;ID:1217005', '27449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27449', '112', '29326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1217005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29327', '1079', '1', 'Qarshi Tumani', 'UZ.08.1217013', 'ASCII:Qarshi Tumani;ID:1217013', '27450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27450', '112', '29327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1217013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29328', '1079', '1', 'Qorakŭl Tumani', 'UZ.02.1217081', 'ASCII:Qorakul Tumani;ID:1217081', '27451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27451', '112', '29328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1217081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29329', '1079', '1', 'Qamashi Tumani', 'UZ.08.1217142', 'ASCII:Qamashi Tumani;ID:1217142', '27452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27452', '112', '29329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1217142» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29330', '1079', '1', 'Kogon Tumani', 'UZ.02.1217179', 'ASCII:Kogon Tumani;ID:1217179', '27453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27453', '112', '29330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1217179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29331', '1079', '1', 'Ishtixon Tumani', 'UZ.10.1217214', 'ASCII:Ishtixon Tumani;ID:1217214', '27454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27454', '112', '29331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1217214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29332', '1079', '1', 'Ghuzor Tumani', 'UZ.08.1217259', 'ASCII:Ghuzor Tumani;ID:1217259', '27455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27455', '112', '29332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1217259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29333', '1079', '1', 'G`allaorol Tumani', 'UZ.15.1217334', 'ASCII:G`allaorol Tumani;ID:1217334', '27456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27456', '112', '29333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1217334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29334', '1079', '1', 'Muzrabod Tumani', 'UZ.12.1217341', 'ASCII:Muzrabod Tumani;ID:1217341', '27457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27457', '112', '29334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1217341» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29335', '1079', '1', 'Jarqo''rg''on Tumani', 'UZ.12.1217391', 'ASCII:Jarqo''rg''on Tumani;ID:1217391', '27458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27458', '112', '29335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1217391» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29336', '1079', '1', 'Jomboy Tumani', 'UZ.10.1217412', 'ASCII:Jomboy Tumani;ID:1217412', '27459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27459', '112', '29336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1217412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29337', '1079', '1', 'Denov Tumani', 'UZ.12.1217476', 'ASCII:Denov Tumani;ID:1217476', '27460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27460', '112', '29337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1217476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29338', '1079', '1', 'Dehqonobod Tumani', 'UZ.08.1217479', 'ASCII:Dehqonobod Tumani;ID:1217479', '27461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27461', '112', '29338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1217479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29339', '1079', '1', 'Chiroqchi Tumani', 'UZ.08.1217538', 'ASCII:Chiroqchi Tumani;ID:1217538', '27462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27462', '112', '29339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1217538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29340', '1079', '1', 'Bulung`ur Tumani', 'UZ.10.1217655', 'ASCII:Bulung`ur Tumani;ID:1217655', '27463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27463', '112', '29340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1217655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29341', '1079', '1', 'Bukhoro Tumani', 'UZ.02.1217663', 'ASCII:Bukhoro Tumani;ID:1217663', '27464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27464', '112', '29341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1217663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29342', '1079', '1', 'Boysun Tumani', 'UZ.12.1217733', 'ASCII:Boysun Tumani;ID:1217733', '27465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27465', '112', '29342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1217733» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29343', '1079', '1', 'Baxmal Tumani', 'UZ.15.1217778', 'ASCII:Baxmal Tumani;ID:1217778', '27466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27466', '112', '29343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1217778» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29344', '1079', '1', 'Angor Tumani', 'UZ.12.1217872', 'ASCII:Angor Tumani;ID:1217872', '27467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27467', '112', '29344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1217872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29345', '1079', '1', 'Oltinsoy Tumani', 'UZ.12.1217894', 'ASCII:Oltinsoy Tumani;ID:1217894', '27468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27468', '112', '29345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1217894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29346', '1079', '1', 'Olot Tumani', 'UZ.02.1217905', 'ASCII:Olot Tumani;ID:1217905', '27469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27469', '112', '29346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1217905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29347', '1079', '1', 'Oqdaryo Tumani', 'UZ.10.1217960', 'ASCII:Oqdaryo Tumani;ID:1217960', '27470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27470', '112', '29347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1217960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29348', '1079', '1', 'Qorovulbozor Tumani', 'UZ.02.1346433', 'ASCII:Qorovulbozor Tumani;ID:1346433', '27471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27471', '112', '29348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1346433» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29349', '1079', '1', 'Bukhoro Shahri', 'UZ.02.1346436', 'ASCII:Bukhoro Shahri;ID:1346436', '27472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27472', '112', '29349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1346436» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29350', '1079', '1', 'Kogon Shahri', 'UZ.02.1346437', 'ASCII:Kogon Shahri;ID:1346437', '27473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27473', '112', '29350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1346437» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29351', '1079', '1', 'Chelak Tumani', 'UZ.10.1346451', 'ASCII:Chelak Tumani;ID:1346451', '27474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27474', '112', '29351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1346451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29352', '1079', '1', 'Go`zalkent Tumani', 'UZ.10.1346455', 'ASCII:Go`zalkent Tumani;ID:1346455', '27475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27475', '112', '29352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1346455» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29353', '1079', '1', 'Toyloq Tumani', 'UZ.10.1346462', 'ASCII:Toyloq Tumani;ID:1346462', '27476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27476', '112', '29353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1346462» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29354', '1079', '1', 'Samarqand Shahri', 'UZ.10.1346463', 'ASCII:Samarqand Shahri;ID:1346463', '27477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27477', '112', '29354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1346463» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29355', '1079', '1', 'Oqtosh Shahri', 'UZ.10.1346465', 'ASCII:Oqtosh Shahri;ID:1346465', '27478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27478', '112', '29355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1346465» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29356', '1079', '1', 'Kattaqo`rg`on Shahri', 'UZ.10.1346466', 'ASCII:Kattaqo`rg`on Shahri;ID:1346466', '27479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27479', '112', '29356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1346466» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29357', '1079', '1', 'Urgut Shahri', 'UZ.10.1346467', 'ASCII:Urgut Shahri;ID:1346467', '27480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27480', '112', '29357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1346467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29358', '1079', '1', 'Bahoriston Tumani', 'UZ.08.1346479', 'ASCII:Bahoriston Tumani;ID:1346479', '27481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27481', '112', '29358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1346479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29359', '1079', '1', 'Qarshi Shahri', 'UZ.08.1346481', 'ASCII:Qarshi Shahri;ID:1346481', '27482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27482', '112', '29359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1346481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29360', '1079', '1', 'Shahrisabz Shahri', 'UZ.08.1346482', 'ASCII:Shahrisabz Shahri;ID:1346482', '27483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27483', '112', '29360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.08.1346482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29361', '1079', '1', 'Uzun Tumani', 'UZ.12.1346497', 'ASCII:Uzun Tumani;ID:1346497', '27484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27484', '112', '29361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1346497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29362', '1079', '1', 'Bandikhon Tumani', 'UZ.12.1346534', 'ASCII:Bandikhon Tumani;ID:1346534', '27485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27485', '112', '29362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1346534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29363', '1079', '1', 'Termiz Shahri', 'UZ.12.1346536', 'ASCII:Termiz Shahri;ID:1346536', '27486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27486', '112', '29363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1346536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29364', '1079', '1', 'Denov Shahri', 'UZ.12.1346537', 'ASCII:Denov Shahri;ID:1346537', '27487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27487', '112', '29364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1346537» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29365', '1079', '1', 'Zarbdor Tumani', 'UZ.15.1512277', 'ASCII:Zarbdor Tumani;ID:1512277', '27488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27488', '112', '29365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1512277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29366', '1079', '1', 'Mingbuloq Tumani', 'UZ.06.1512289', 'ASCII:Mingbuloq Tumani;ID:1512289', '27489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27489', '112', '29366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1512289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29367', '1079', '1', 'Yozyowon Tumani', 'UZ.03.1512318', 'ASCII:Yozyowon Tumani;ID:1512318', '27490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27490', '112', '29367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1512318» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29368', '1079', '1', 'Yangiqŭrghon Tumani', 'UZ.06.1512349', 'ASCII:Yangiqurghon Tumani;ID:1512349', '27491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27491', '112', '29368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1512349» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29369', '1079', '1', 'Yangibozor Tumani', 'UZ.05.1512360', 'ASCII:Yangibozor Tumani;ID:1512360', '27492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27492', '112', '29369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1512360» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29370', '1079', '1', 'Yangiariq Tumani', 'UZ.05.1512367', 'ASCII:Yangiariq Tumani;ID:1512367', '27493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27493', '112', '29370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1512367» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29371', '1079', '1', 'Sayhunobod Tumani', 'UZ.16.1512404', 'ASCII:Sayhunobod Tumani;ID:1512404', '27494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27494', '112', '29371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1512404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29372', '1079', '1', 'Ŭzbekiston Tumani', 'UZ.03.1512439', 'ASCII:Uzbekiston Tumani;ID:1512439', '27495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27495', '112', '29372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1512439» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29373', '1079', '1', 'Uychi Tumani', 'UZ.06.1512448', 'ASCII:Uychi Tumani;ID:1512448', '27496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27496', '112', '29373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1512448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29374', '1079', '1', 'Urganch Tumani', 'UZ.05.1512467', 'ASCII:Urganch Tumani;ID:1512467', '27497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27497', '112', '29374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1512467» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29375', '1079', '1', 'Uchqŭrghon Tumani', 'UZ.06.1512500', 'ASCII:Uchqurghon Tumani;ID:1512500', '27498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27498', '112', '29375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1512500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29376', '1079', '1', 'Uchquduq Tumani', 'UZ.07.1512504', 'ASCII:Uchquduq Tumani;ID:1512504', '27499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27499', '112', '29376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1512504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29377', '1079', '1', 'Tŭrtkŭl Tumani', 'UZ.09.1512534', 'ASCII:Turtkul Tumani;ID:1512534', '27500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27500', '112', '29377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.1512534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29378', '1079', '1', 'Tŭraqŭrghon Tumani', 'UZ.06.1512548', 'ASCII:Turaqurghon Tumani;ID:1512548', '27501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27501', '112', '29378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1512548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29379', '1079', '1', 'Toshloq Tumani', 'UZ.03.1512646', 'ASCII:Toshloq Tumani;ID:1512646', '27502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27502', '112', '29379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1512646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29380', '1079', '1', 'Toshkent Tumani', 'UZ.14.1512652', 'ASCII:Toshkent Tumani;ID:1512652', '27503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27503', '112', '29380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1512652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29381', '1079', '1', 'Tomdi Tumani', 'UZ.07.1512673', 'ASCII:Tomdi Tumani;ID:1512673', '27504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27504', '112', '29381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1512673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29382', '1079', '1', 'Takhtakŭpir Tumani', 'UZ.09.1512698', 'ASCII:Takhtakupir Tumani;ID:1512698', '27505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27505', '112', '29382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.1512698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29383', '1079', '1', 'Sirdaryo Tumani', 'UZ.16.1512717', 'ASCII:Sirdaryo Tumani;ID:1512717', '27506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27506', '112', '29383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1512717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29384', '1079', '1', 'Ŭrta Chirchiq Tumani', 'UZ.14.1512751', 'ASCII:Urta Chirchiq Tumani;ID:1512751', '27507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27507', '112', '29384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1512751» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29385', '1079', '1', 'Showot Tumani', 'UZ.05.1512818', 'ASCII:Showot Tumani;ID:1512818', '27508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27508', '112', '29385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1512818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29386', '1079', '1', 'Shofirkon Tumani', 'UZ.02.1512837', 'ASCII:Shofirkon Tumani;ID:1512837', '27509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27509', '112', '29386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1512837» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29387', '1079', '1', 'Sirgali Tumani', 'UZ.13.1512848', 'ASCII:Sirgali Tumani;ID:1512848', '27510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27510', '112', '29387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1512848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29388', '1079', '1', 'Sobir Rahimov Tumani', 'UZ.13.1512949', 'ASCII:Sobir Rahimov Tumani;ID:1512949', '27511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27511', '112', '29388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1512949» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29389', '1079', '1', 'Rishton Tumani', 'UZ.03.1512956', 'ASCII:Rishton Tumani;ID:1512956', '27512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27512', '112', '29389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1512956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29390', '1079', '1', 'Piskent Tumani', 'UZ.14.1512985', 'ASCII:Piskent Tumani;ID:1512985', '27513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27513', '112', '29390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1512985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29391', '1079', '1', 'Peshku Tumani', 'UZ.02.1513006', 'ASCII:Peshku Tumani;ID:1513006', '27514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27514', '112', '29391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1513006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29392', '1079', '1', 'Parkent Tumani', 'UZ.14.1513016', 'ASCII:Parkent Tumani;ID:1513016', '27515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27515', '112', '29392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1513016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29393', '1079', '1', 'Pop Tumani', 'UZ.06.1513021', 'ASCII:Pop Tumani;ID:1513021', '27516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27516', '112', '29393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1513021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29394', '1079', '1', 'Paxtakor Tumani', 'UZ.15.1513035', 'ASCII:Paxtakor Tumani;ID:1513035', '27517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27517', '112', '29394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1513035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29395', '1079', '1', 'Pakhtaobod Tumani', 'UZ.01.1513039', 'ASCII:Pakhtaobod Tumani;ID:1513039', '27518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27518', '112', '29395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1513039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29396', '1079', '1', 'Qibray Tumani', 'UZ.14.1513057', 'ASCII:Qibray Tumani;ID:1513057', '27519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27519', '112', '29396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1513057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29397', '1079', '1', 'Shaykhontohur Tumani', 'UZ.13.1513066', 'ASCII:Shaykhontohur Tumani;ID:1513066', '27520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27520', '112', '29397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1513066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29398', '1079', '1', 'Zafarobod Tumani', 'UZ.15.1513067', 'ASCII:Zafarobod Tumani;ID:1513067', '27521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27521', '112', '29398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1513067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29399', '1079', '1', 'Nurota Tumani', 'UZ.07.1513082', 'ASCII:Nurota Tumani;ID:1513082', '27522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27522', '112', '29399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1513082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29400', '1079', '1', 'Navoiy Tumani', 'UZ.07.1513133', 'ASCII:Navoiy Tumani;ID:1513133', '27523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27523', '112', '29400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1513133» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29401', '1079', '1', 'Navbahor Tumani', 'UZ.07.1513135', 'ASCII:Navbahor Tumani;ID:1513135', '27524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27524', '112', '29401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1513135» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29402', '1079', '1', 'Norin Tumani', 'UZ.06.1513144', 'ASCII:Norin Tumani;ID:1513144', '27525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27525', '112', '29402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1513144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29403', '1079', '1', 'Namangan Tumani', 'UZ.06.1513156', 'ASCII:Namangan Tumani;ID:1513156', '27526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27526', '112', '29403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1513156» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29404', '1079', '1', 'Shahrikhon Tumani', 'UZ.01.1513193', 'ASCII:Shahrikhon Tumani;ID:1513193', '27527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27527', '112', '29404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1513193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29405', '1079', '1', 'Mirzachŭl Tumani', 'UZ.15.1513202', 'ASCII:Mirzachul Tumani;ID:1513202', '27528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27528', '112', '29405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1513202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29406', '1079', '1', 'Marhamat Tumani', 'UZ.01.1513240', 'ASCII:Marhamat Tumani;ID:1513240', '27529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27529', '112', '29406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1513240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29407', '1079', '1', 'Mirobod Tumani', 'UZ.13.1513269', 'ASCII:Mirobod Tumani;ID:1513269', '27530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27530', '112', '29407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1513269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29408', '1079', '1', 'Asaka Tumani', 'UZ.01.1513270', 'ASCII:Asaka Tumani;ID:1513270', '27531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27531', '112', '29408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1513270» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29409', '1079', '1', 'Uchkŭprik Tumani', 'UZ.03.1513272', 'ASCII:Uchkuprik Tumani;ID:1513272', '27532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27532', '112', '29409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1513272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29410', '1079', '1', 'Mirzo Ulug`bek Tumani', 'UZ.13.1513328', 'ASCII:Mirzo Ulug`bek Tumani;ID:1513328', '27533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27533', '112', '29410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1513328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29411', '1079', '1', 'Quwa Tumani', 'UZ.03.1513329', 'ASCII:Quwa Tumani;ID:1513329', '27534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27534', '112', '29411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1513329» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29412', '1079', '1', 'Qŭrghontepa Tumani', 'UZ.01.1513363', 'ASCII:Qurghontepa Tumani;ID:1513363', '27535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27535', '112', '29412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1513363» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29413', '1079', '1', 'Qo`shrabot Tumani', 'UZ.10.1513472', 'ASCII:Qo`shrabot Tumani;ID:1513472', '27536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27536', '112', '29413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.10.1513472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29414', '1079', '1', 'Qŭshkŭpir Tumani', 'UZ.05.1513477', 'ASCII:Qushkupir Tumani;ID:1513477', '27537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27537', '112', '29414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1513477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29415', '1079', '1', 'Mirzaobod Tumani', 'UZ.16.1513490', 'ASCII:Mirzaobod Tumani;ID:1513490', '27538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27538', '112', '29415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1513490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29416', '1079', '1', 'Ulughnor Tumani', 'UZ.01.1513493', 'ASCII:Ulughnor Tumani;ID:1513493', '27539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27539', '112', '29416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1513493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29417', '1079', '1', 'Yuqori Chirchiq Tumani', 'UZ.14.1513498', 'ASCII:Yuqori Chirchiq Tumani;ID:1513498', '27540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27540', '112', '29417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1513498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29418', '1079', '1', 'Yunusobod Tumani', 'UZ.13.1513546', 'ASCII:Yunusobod Tumani;ID:1513546', '27541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27541', '112', '29418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1513546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29419', '1079', '1', 'Beshariq Tumani', 'UZ.03.1513547', 'ASCII:Beshariq Tumani;ID:1513547', '27542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27542', '112', '29419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1513547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29420', '1079', '1', 'Khŭjaobod Tumani', 'UZ.01.1513598', 'ASCII:Khujaobod Tumani;ID:1513598', '27543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27543', '112', '29420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1513598» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29421', '1079', '1', 'Khiwa Tumani', 'UZ.05.1513603', 'ASCII:Khiwa Tumani;ID:1513603', '27544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27544', '112', '29421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1513603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29422', '1079', '1', 'Hazorasp Tumani', 'UZ.05.1513610', 'ASCII:Hazorasp Tumani;ID:1513610', '27545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27545', '112', '29422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1513610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29423', '1079', '1', 'Khovos Tumani', 'UZ.16.1513618', 'ASCII:Khovos Tumani;ID:1513618', '27546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27546', '112', '29423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1513618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29424', '1079', '1', 'Xatirchi Tumani', 'UZ.07.1513622', 'ASCII:Xatirchi Tumani;ID:1513622', '27547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27547', '112', '29424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1513622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29425', '1079', '1', 'Khonqa Tumani', 'UZ.05.1513635', 'ASCII:Khonqa Tumani;ID:1513635', '27548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27548', '112', '29425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1513635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29426', '1079', '1', 'Hamza Tumani', 'UZ.13.1513648', 'ASCII:Hamza Tumani;ID:1513648', '27549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27549', '112', '29426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1513648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29427', '1079', '1', 'Kosonsoy Tumani', 'UZ.06.1513713', 'ASCII:Kosonsoy Tumani;ID:1513713', '27550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27550', '112', '29427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1513713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29428', '1079', '1', 'Qoraŭzak Tumani', 'UZ.09.1513732', 'ASCII:Qorauzak Tumani;ID:1513732', '27551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27551', '112', '29428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.1513732» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29429', '1079', '1', 'Konimex Tumani', 'UZ.07.1513830', 'ASCII:Konimex Tumani;ID:1513830', '27552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27552', '112', '29429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1513830» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29430', '1079', '1', 'Zangiota Tumani', 'UZ.14.1513860', 'ASCII:Zangiota Tumani;ID:1513860', '27553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27553', '112', '29430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1513860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29431', '1079', '1', 'Izboskan Tumani', 'UZ.01.1513888', 'ASCII:Izboskan Tumani;ID:1513888', '27554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27554', '112', '29431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1513888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29432', '1079', '1', 'Sharof-Rashidow Tumani', 'UZ.16.1513952', 'ASCII:Sharof-Rashidow Tumani;ID:1513952', '27555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27555', '112', '29432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1513952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29433', '1079', '1', 'Gurlan Tumani', 'UZ.05.1513961', 'ASCII:Gurlan Tumani;ID:1513961', '27556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27556', '112', '29433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1513961» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29434', '1079', '1', 'Guliston Tumani', 'UZ.16.1513967', 'ASCII:Guliston Tumani;ID:1513967', '27557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27557', '112', '29434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1513967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29435', '1079', '1', 'Ghijduwon Tumani', 'UZ.02.1513982', 'ASCII:Ghijduwon Tumani;ID:1513982', '27558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27558', '112', '29435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1513982» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29436', '1079', '1', 'Quyi Chirchiq Tumani', 'UZ.14.1514010', 'ASCII:Quyi Chirchiq Tumani;ID:1514010', '27559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27559', '112', '29436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1514010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29437', '1079', '1', 'Danghara Tumani', 'UZ.03.1514016', 'ASCII:Danghara Tumani;ID:1514016', '27560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27560', '112', '29437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1514016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29438', '1079', '1', 'Farghona Tumani', 'UZ.03.1514017', 'ASCII:Farghona Tumani;ID:1514017', '27561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27561', '112', '29438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1514017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29439', '1079', '1', 'Forish Tumani', 'UZ.15.1514024', 'ASCII:Forish Tumani;ID:1514024', '27562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27562', '112', '29439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1514024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29440', '1079', '1', 'Ellikqala Tumani', 'UZ.09.1514037', 'ASCII:Ellikqala Tumani;ID:1514037', '27563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27563', '112', '29440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.1514037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29441', '1079', '1', 'Jizzax Tumani', 'UZ.15.1514068', 'ASCII:Jizzax Tumani;ID:1514068', '27564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27564', '112', '29441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1514068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29442', '1079', '1', 'Jalolkuduk Tumani', 'UZ.01.1514108', 'ASCII:Jalolkuduk Tumani;ID:1514108', '27565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27565', '112', '29442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1514108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29443', '1079', '1', 'Dŭstlik Tumani', 'UZ.15.1514124', 'ASCII:Dustlik Tumani;ID:1514124', '27566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27566', '112', '29443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1514124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29444', '1079', '1', 'Chust Tumani', 'UZ.06.1514190', 'ASCII:Chust Tumani;ID:1514190', '27567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27567', '112', '29444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1514190» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29445', '1079', '1', 'Chinoz Tumani', 'UZ.14.1514214', 'ASCII:Chinoz Tumani;ID:1514214', '27568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27568', '112', '29445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1514214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29446', '1079', '1', 'Chilonzor Tumani', 'UZ.13.1514229', 'ASCII:Chilonzor Tumani;ID:1514229', '27569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27569', '112', '29446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1514229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29447', '1079', '1', 'Buwayda Tumani', 'UZ.03.1514299', 'ASCII:Buwayda Tumani;ID:1514299', '27570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27570', '112', '29447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1514299» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29448', '1079', '1', 'Bŭka Tumani', 'UZ.14.1514327', 'ASCII:Buka Tumani;ID:1514327', '27571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27571', '112', '29448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1514327» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29449', '1079', '1', 'Bŭz Tumani', 'UZ.01.1514336', 'ASCII:Buz Tumani;ID:1514336', '27572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27572', '112', '29449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1514336» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29450', '1079', '1', 'Bŭstonliq Tumani', 'UZ.14.1514338', 'ASCII:Bustonliq Tumani;ID:1514338', '27573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27573', '112', '29450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1514338» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29451', '1079', '1', 'Beruniy Tumani', 'UZ.09.1514386', 'ASCII:Beruniy Tumani;ID:1514386', '27574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27574', '112', '29451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.1514386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29452', '1079', '1', 'Bekobod Tumani', 'UZ.14.1514399', 'ASCII:Bekobod Tumani;ID:1514399', '27575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27575', '112', '29452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1514399» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29453', '1079', '1', 'Boyowut Tumani', 'UZ.16.1514430', 'ASCII:Boyowut Tumani;ID:1514430', '27576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27576', '112', '29453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1514430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29454', '1079', '1', 'Baliqchi Tumani', 'UZ.01.1514451', 'ASCII:Baliqchi Tumani;ID:1514451', '27577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27577', '112', '29454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1514451» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29455', '1079', '1', 'Baghdod Tumani', 'UZ.03.1514482', 'ASCII:Baghdod Tumani;ID:1514482', '27578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27578', '112', '29455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1514482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29456', '1079', '1', 'Boghot Tumani', 'UZ.05.1514485', 'ASCII:Boghot Tumani;ID:1514485', '27579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27579', '112', '29456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1514485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29457', '1079', '1', 'Arnasoy Tumani', 'UZ.15.1514555', 'ASCII:Arnasoy Tumani;ID:1514555', '27580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27580', '112', '29457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1514555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29458', '1079', '1', 'Andijon Tumani', 'UZ.01.1514584', 'ASCII:Andijon Tumani;ID:1514584', '27581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27581', '112', '29458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1514584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29459', '1079', '1', 'Amudaryo Tumani', 'UZ.09.1514593', 'ASCII:Amudaryo Tumani;ID:1514593', '27582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27582', '112', '29459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.1514593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29460', '1079', '1', 'Oltinkŭl Tumani', 'UZ.01.1514606', 'ASCII:Oltinkul Tumani;ID:1514606', '27583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27583', '112', '29460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1514606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29461', '1079', '1', 'Oltiariq Tumani', 'UZ.03.1514616', 'ASCII:Oltiariq Tumani;ID:1514616', '27584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27584', '112', '29461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1514616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29462', '1079', '1', 'Akmal Ikromow Tumani', 'UZ.13.1514665', 'ASCII:Akmal Ikromow Tumani;ID:1514665', '27585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27585', '112', '29462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1514665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29463', '1079', '1', 'Oqqŭrghon Tumani', 'UZ.14.1514667', 'ASCII:Oqqurghon Tumani;ID:1514667', '27586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27586', '112', '29463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1514667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29464', '1079', '1', 'Okhunboboyew Tumani', 'UZ.03.1514681', 'ASCII:Okhunboboyew Tumani;ID:1514681', '27587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27587', '112', '29464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1514681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29465', '1079', '1', 'Ohangaron Tumani', 'UZ.14.1514687', 'ASCII:Ohangaron Tumani;ID:1514687', '27588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27588', '112', '29465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1514687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29466', '1079', '1', 'Oqoltin Tumani', 'UZ.16.1514705', 'ASCII:Oqoltin Tumani;ID:1514705', '27589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27589', '112', '29466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1514705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29467', '1079', '1', 'Bektemir Tumani', 'UZ.13.1536760', 'ASCII:Bektemir Tumani;ID:1536760', '27590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27590', '112', '29467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1536760» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29468', '1079', '1', 'Yakkasaroy Tumani', 'UZ.13.1536761', 'ASCII:Yakkasaroy Tumani;ID:1536761', '27591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27591', '112', '29468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.13.1536761» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29469', '1079', '1', 'Beruniy Shahri', 'UZ.09.1538221', 'ASCII:Beruniy Shahri;ID:1538221', '27592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27592', '112', '29469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.1538221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29470', '1079', '1', 'Tŭrtkŭl Shahri', 'UZ.09.1538222', 'ASCII:Turtkul Shahri;ID:1538222', '27593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27593', '112', '29470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.09.1538222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29471', '1079', '1', 'Urganch Shahri', 'UZ.05.1538226', 'ASCII:Urganch Shahri;ID:1538226', '27594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27594', '112', '29471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1538226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29472', '1079', '1', 'Pitnak Shahri', 'UZ.05.1538227', 'ASCII:Pitnak Shahri;ID:1538227', '27595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27595', '112', '29472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1538227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29473', '1079', '1', 'Khiwa Shahri', 'UZ.05.1538228', 'ASCII:Khiwa Shahri;ID:1538228', '27596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27596', '112', '29473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.05.1538228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29474', '1079', '1', 'Navoiy Shahri', 'UZ.07.1538229', 'ASCII:Navoiy Shahri;ID:1538229', '27597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27597', '112', '29474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1538229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29475', '1079', '1', 'Zarafshon Shahri', 'UZ.07.1538230', 'ASCII:Zarafshon Shahri;ID:1538230', '27598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27598', '112', '29475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1538230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29476', '1079', '1', 'Uchquduq Shahri', 'UZ.07.1538231', 'ASCII:Uchquduq Shahri;ID:1538231', '27599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27599', '112', '29476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.07.1538231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29477', '1079', '1', 'Ghijduwon Shahri', 'UZ.02.1538236', 'ASCII:Ghijduwon Shahri;ID:1538236', '27600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27600', '112', '29477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.02.1538236» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29478', '1079', '1', 'Jizzax Shahri', 'UZ.15.1538240', 'ASCII:Jizzax Shahri;ID:1538240', '27601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27601', '112', '29478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.15.1538240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29479', '1079', '1', 'Mehnatobod Tumani', 'UZ.16.1538246', 'ASCII:Mehnatobod Tumani;ID:1538246', '27602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27602', '112', '29479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1538246» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29480', '1079', '1', 'Guliston Shahri', 'UZ.16.1538249', 'ASCII:Guliston Shahri;ID:1538249', '27603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27603', '112', '29480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1538249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29481', '1079', '1', 'Sirdaryo Shahri', 'UZ.16.1538250', 'ASCII:Sirdaryo Shahri;ID:1538250', '27604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27604', '112', '29481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1538250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29482', '1079', '1', 'Shirin Shahri', 'UZ.16.1538251', 'ASCII:Shirin Shahri;ID:1538251', '27605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27605', '112', '29482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1538251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29483', '1079', '1', 'Yangiyer Shahri', 'UZ.16.1538252', 'ASCII:Yangiyer Shahri;ID:1538252', '27606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27606', '112', '29483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1538252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29484', '1079', '1', 'Bakht Shahri', 'UZ.16.1538253', 'ASCII:Bakht Shahri;ID:1538253', '27607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27607', '112', '29484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.16.1538253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29485', '1079', '1', 'Yangiyŭl Tumani', 'UZ.12.1538254', 'ASCII:Yangiyul Tumani;ID:1538254', '27608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27608', '112', '29485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.12.1538254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29486', '1079', '1', 'Olmaliq Shahri', 'UZ.14.1538256', 'ASCII:Olmaliq Shahri;ID:1538256', '27609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27609', '112', '29486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1538256» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29487', '1079', '1', 'Angren Shahri', 'UZ.14.1538257', 'ASCII:Angren Shahri;ID:1538257', '27610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27610', '112', '29487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1538257» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29488', '1079', '1', 'Ohangaron Shahri', 'UZ.14.1538258', 'ASCII:Ohangaron Shahri;ID:1538258', '27611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27611', '112', '29488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1538258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29489', '1079', '1', 'Bekobod Shahri', 'UZ.14.1538259', 'ASCII:Bekobod Shahri;ID:1538259', '27612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27612', '112', '29489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1538259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29490', '1079', '1', 'Chirchiq Shahri', 'UZ.14.1538260', 'ASCII:Chirchiq Shahri;ID:1538260', '27613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27613', '112', '29490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1538260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29491', '1079', '1', 'Yangiobod Shahri', 'UZ.14.1538261', 'ASCII:Yangiobod Shahri;ID:1538261', '27614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27614', '112', '29491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.14.1538261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29492', '1079', '1', 'Chortoq Tumani', 'UZ.06.1538272', 'ASCII:Chortoq Tumani;ID:1538272', '27615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27615', '112', '29492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1538272» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29493', '1079', '1', 'Namangan Shahri', 'UZ.06.1538273', 'ASCII:Namangan Shahri;ID:1538273', '27616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27616', '112', '29493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1538273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29494', '1079', '1', 'Kosonsoy Shahri', 'UZ.06.1538274', 'ASCII:Kosonsoy Shahri;ID:1538274', '27617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27617', '112', '29494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1538274» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29495', '1079', '1', 'Uchqŭrghon Shahri', 'UZ.06.1538275', 'ASCII:Uchqurghon Shahri;ID:1538275', '27618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27618', '112', '29495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1538275» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29496', '1079', '1', 'Chortoq Shahri', 'UZ.06.1538276', 'ASCII:Chortoq Shahri;ID:1538276', '27619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27619', '112', '29496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1538276» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29497', '1079', '1', 'Chust Tumani', 'UZ.06.1538277', 'ASCII:Chust Tumani;ID:1538277', '27620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27620', '112', '29497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1538277» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29498', '1079', '1', 'Haqqulobod Shahri', 'UZ.06.1538278', 'ASCII:Haqqulobod Shahri;ID:1538278', '27621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27621', '112', '29498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.06.1538278» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29499', '1079', '1', 'Buloqboshi Tumani', 'UZ.01.1538281', 'ASCII:Buloqboshi Tumani;ID:1538281', '27622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27622', '112', '29499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1538281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29500', '1079', '1', 'Andijon Shahri', 'UZ.01.1538282', 'ASCII:Andijon Shahri;ID:1538282', '27623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27623', '112', '29500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1538282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29501', '1079', '1', 'Asaka Shahri', 'UZ.01.1538283', 'ASCII:Asaka Shahri;ID:1538283', '27624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27624', '112', '29501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1538283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29502', '1079', '1', 'Qorasuw Shahri', 'UZ.01.1538284', 'ASCII:Qorasuw Shahri;ID:1538284', '27625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27625', '112', '29502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1538284» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29503', '1079', '1', 'Khonobod Shahri', 'UZ.01.1538285', 'ASCII:Khonobod Shahri;ID:1538285', '27626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27626', '112', '29503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1538285» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29504', '1079', '1', 'Shahrikhon Shahri', 'UZ.01.1538286', 'ASCII:Shahrikhon Shahri;ID:1538286', '27627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27627', '112', '29504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.01.1538286» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29505', '1079', '1', 'Furqat Tumani', 'UZ.03.1538294', 'ASCII:Furqat Tumani;ID:1538294', '27628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27628', '112', '29505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1538294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29506', '1079', '1', 'Sŭkh Tumani', 'UZ.03.1538295', 'ASCII:Sukh Tumani;ID:1538295', '27629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27629', '112', '29506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1538295» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29507', '1079', '1', 'Farg`ona Shahri', 'UZ.03.1538296', 'ASCII:Farg`ona Shahri;ID:1538296', '27630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27630', '112', '29507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1538296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29508', '1079', '1', 'Qo`qon Shahri', 'UZ.03.1538297', 'ASCII:Qo`qon Shahri;ID:1538297', '27631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27631', '112', '29508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1538297» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29509', '1079', '1', 'Quva Shahri', 'UZ.03.1538298', 'ASCII:Quva Shahri;ID:1538298', '27632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27632', '112', '29509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1538298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29510', '1079', '1', 'Quvasoy Shahri', 'UZ.03.1538299', 'ASCII:Quvasoy Shahri;ID:1538299', '27633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27633', '112', '29510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1538299» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29511', '1079', '1', 'Marg`ilon Shahri', 'UZ.03.1538300', 'ASCII:Marg`ilon Shahri;ID:1538300', '27634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27634', '112', '29511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «UZ.03.1538300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29512', '1079', '1', 'Distrito Zaraza', 'VE.12.3625064', 'ASCII:Distrito Zaraza;ID:3625064', '27635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27635', '112', '29512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.12.3625064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29513', '1079', '1', 'Distrito Zamora', 'VE.11.3625121', 'ASCII:Distrito Zamora;ID:3625121', '27636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27636', '112', '29513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3625121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29514', '1079', '1', 'Distrito Zamora', 'VE.15.3625122', 'ASCII:Distrito Zamora;ID:3625122', '27637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27637', '112', '29514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3625122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29515', '1079', '1', 'Distrito Zamora', 'VE.04.3625123', 'ASCII:Distrito Zamora;ID:3625123', '27638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27638', '112', '29515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.04.3625123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29516', '1079', '1', 'Distrito Yaritagua', 'VE.22.3625206', 'ASCII:Distrito Yaritagua;ID:3625206', '27639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27639', '112', '29516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.22.3625206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29517', '1079', '1', 'Distrito Villalba', 'VE.17.3625334', 'ASCII:Distrito Villalba;ID:3625334', '27640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27640', '112', '29517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.17.3625334» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29518', '1079', '1', 'Departamento Vargas', 'VE.26.3625485', 'ASCII:Departamento Vargas;ID:3625485', '27641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27641', '112', '29518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.26.3625485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29519', '1079', '1', 'Distrito Valera', 'VE.21.3625541', 'ASCII:Distrito Valera;ID:3625541', '27642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27642', '112', '29519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.21.3625541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29520', '1079', '1', 'Distrito Valencia', 'VE.07.3625547', 'ASCII:Distrito Valencia;ID:3625547', '27643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27643', '112', '29520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.07.3625547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29521', '1079', '1', 'Distrito Uribante', 'VE.20.3625648', 'ASCII:Distrito Uribante;ID:3625648', '27644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27644', '112', '29521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3625648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29522', '1079', '1', 'Distrito Urdaneta', 'VE.13.3625657', 'ASCII:Distrito Urdaneta;ID:3625657', '27645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27645', '112', '29522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.13.3625657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29523', '1079', '1', 'Distrito Urdaneta', 'VE.23.3625658', 'ASCII:Distrito Urdaneta;ID:3625658', '27646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27646', '112', '29523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.23.3625658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29524', '1079', '1', 'Distrito Urdaneta', 'VE.15.3625659', 'ASCII:Distrito Urdaneta;ID:3625659', '27647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27647', '112', '29524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3625659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29525', '1079', '1', 'Distrito Urdaneta', 'VE.04.3625660', 'ASCII:Distrito Urdaneta;ID:3625660', '27648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27648', '112', '29525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.04.3625660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29526', '1079', '1', 'Distrito Urdaneta', 'VE.21.3625661', 'ASCII:Distrito Urdaneta;ID:3625661', '27649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27649', '112', '29526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.21.3625661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29527', '1079', '1', 'Distrito Urachiche', 'VE.22.3625695', 'ASCII:Distrito Urachiche;ID:3625695', '27650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27650', '112', '29527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.22.3625695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29528', '1079', '1', 'Distrito Turén', 'VE.18.3625845', 'ASCII:Distrito Turen;ID:3625845', '27651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27651', '112', '29528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.18.3625845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29529', '1079', '1', 'Departamento Tucupita', 'VE.09.3625927', 'ASCII:Departamento Tucupita;ID:3625927', '27652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27652', '112', '29529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.09.3625927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29530', '1079', '1', 'Distrito Tubores', 'VE.17.3625967', 'ASCII:Distrito Tubores;ID:3625967', '27653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27653', '112', '29530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.17.3625967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29531', '1079', '1', 'Distrito Trujillo', 'VE.21.3625975', 'ASCII:Distrito Trujillo;ID:3625975', '27654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27654', '112', '29531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.21.3625975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29532', '1079', '1', 'Distrito Tovar', 'VE.14.3626043', 'ASCII:Distrito Tovar;ID:3626043', '27655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27655', '112', '29532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3626043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29533', '1079', '1', 'Distrito Torres', 'VE.13.3626083', 'ASCII:Distrito Torres;ID:3626083', '27656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27656', '112', '29533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.13.3626083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29534', '1079', '1', 'Distrito Tinaco', 'VE.08.3626234', 'ASCII:Distrito Tinaco;ID:3626234', '27657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27657', '112', '29534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.08.3626234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29535', '1079', '1', 'Distrito Sucre', 'VE.15.3626656', 'ASCII:Distrito Sucre;ID:3626656', '27658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27658', '112', '29535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3626656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29536', '1079', '1', 'Distrito Sucre', 'VE.19.3626657', 'ASCII:Distrito Sucre;ID:3626657', '27659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27659', '112', '29536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3626657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29537', '1079', '1', 'Distrito Sucre', 'VE.22.3626658', 'ASCII:Distrito Sucre;ID:3626658', '27660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27660', '112', '29537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.22.3626658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29538', '1079', '1', 'Distrito Sucre', 'VE.04.3626659', 'ASCII:Distrito Sucre;ID:3626659', '27661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27661', '112', '29538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.04.3626659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29539', '1079', '1', 'Distrito Sucre', 'VE.18.3626660', 'ASCII:Distrito Sucre;ID:3626660', '27662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27662', '112', '29539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.18.3626660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29540', '1079', '1', 'Distrito Sucre', 'VE.23.3626661', 'ASCII:Distrito Sucre;ID:3626661', '27663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27663', '112', '29540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.23.3626661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29541', '1079', '1', 'Distrito Sucre', 'VE.14.3626662', 'ASCII:Distrito Sucre;ID:3626662', '27664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27664', '112', '29541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3626662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29542', '1079', '1', 'Distrito Sucre', 'VE.20.3626663', 'ASCII:Distrito Sucre;ID:3626663', '27665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27665', '112', '29542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3626663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29543', '1079', '1', 'Distrito Sucre', 'VE.06.3626664', 'ASCII:Distrito Sucre;ID:3626664', '27666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27666', '112', '29543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.06.3626664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29544', '1079', '1', 'Distrito Sotillo', 'VE.16.3626693', 'ASCII:Distrito Sotillo;ID:3626693', '27667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27667', '112', '29544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.16.3626693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29545', '1079', '1', 'Distrito Sosa', 'VE.05.3626698', 'ASCII:Distrito Sosa;ID:3626698', '27668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27668', '112', '29545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.05.3626698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29546', '1079', '1', 'Distrito Simón Rodríguez', 'VE.02.3626815', 'ASCII:Distrito Simon Rodriguez;ID:3626815', '27669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27669', '112', '29546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3626815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29547', '1079', '1', 'Distrito Simón Bolívar', 'VE.19.3626819', 'ASCII:Distrito Simon Bolivar;ID:3626819', '27670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27670', '112', '29547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3626819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29548', '1079', '1', 'Distrito Silva', 'VE.11.3626828', 'ASCII:Distrito Silva;ID:3626828', '27671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27671', '112', '29548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3626828» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29549', '1079', '1', 'Distrito San Sebastián', 'VE.04.3627638', 'ASCII:Distrito San Sebastian;ID:3627638', '27672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27672', '112', '29549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.04.3627638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29550', '1079', '1', 'Distrito San Fernando', 'VE.03.3628397', 'ASCII:Distrito San Fernando;ID:3628397', '27673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27673', '112', '29550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.03.3628397» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29551', '1079', '1', 'Distrito San Felipe', 'VE.22.3628416', 'ASCII:Distrito San Felipe;ID:3628416', '27674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27674', '112', '29551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.22.3628416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29552', '1079', '1', 'Distrito San Cristóbal', 'VE.20.3628468', 'ASCII:Distrito San Cristobal;ID:3628468', '27675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27675', '112', '29552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3628468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29553', '1079', '1', 'Distrito San Casimiro', 'VE.04.3628486', 'ASCII:Distrito San Casimiro;ID:3628486', '27676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27676', '112', '29553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.04.3628486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29554', '1079', '1', 'Distrito San Carlos', 'VE.08.3628494', 'ASCII:Distrito San Carlos;ID:3628494', '27677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27677', '112', '29554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.08.3628494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29555', '1079', '1', 'Distrito Roscio', 'VE.12.3628958', 'ASCII:Distrito Roscio;ID:3628958', '27678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27678', '112', '29555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.12.3628958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29556', '1079', '1', 'Distrito Roscio', 'VE.06.3628959', 'ASCII:Distrito Roscio;ID:3628959', '27679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27679', '112', '29556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.06.3628959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29557', '1079', '1', 'Distrito Rómulo Gallegos', 'VE.03.3628986', 'ASCII:Distrito Romulo Gallegos;ID:3628986', '27680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27680', '112', '29557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.03.3628986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29558', '1079', '1', 'Distrito Rojas', 'VE.05.3628998', 'ASCII:Distrito Rojas;ID:3628998', '27681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27681', '112', '29558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.05.3628998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29559', '1079', '1', 'Distrito Rivas Dávila', 'VE.14.3629042', 'ASCII:Distrito Rivas Davila;ID:3629042', '27682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27682', '112', '29559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3629042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29560', '1079', '1', 'Municipio Río Negro', 'VE.01.3629068', 'ASCII:Municipio Rio Negro;ID:3629068', '27683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27683', '112', '29560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.01.3629068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29561', '1079', '1', 'Distrito Ricaurte', 'VE.04.3629178', 'ASCII:Distrito Ricaurte;ID:3629178', '27684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27684', '112', '29561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.04.3629178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29562', '1079', '1', 'Distrito Ricaurte', 'VE.08.3629179', 'ASCII:Distrito Ricaurte;ID:3629179', '27685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27685', '112', '29562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.08.3629179» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29563', '1079', '1', 'Distrito Ribero', 'VE.19.3629182', 'ASCII:Distrito Ribero;ID:3629182', '27686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27686', '112', '29563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3629182» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29564', '1079', '1', 'Distrito Ribas', 'VE.12.3629183', 'ASCII:Distrito Ribas;ID:3629183', '27687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27687', '112', '29564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.12.3629183» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29565', '1079', '1', 'Distrito Rangel', 'VE.14.3629269', 'ASCII:Distrito Rangel;ID:3629269', '27688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27688', '112', '29565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3629269» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29566', '1079', '1', 'Distrito Puerto Cabello', 'VE.07.3629705', 'ASCII:Distrito Puerto Cabello;ID:3629705', '27689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27689', '112', '29566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.07.3629705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29567', '1079', '1', 'Distrito Plaza', 'VE.15.3630003', 'ASCII:Distrito Plaza;ID:3630003', '27690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27690', '112', '29567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3630003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29568', '1079', '1', 'Distrito Piar', 'VE.16.3630282', 'ASCII:Distrito Piar;ID:3630282', '27691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27691', '112', '29568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.16.3630282» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29569', '1079', '1', 'Distrito Piar', 'VE.06.3630283', 'ASCII:Distrito Piar;ID:3630283', '27692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27692', '112', '29569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.06.3630283» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29570', '1079', '1', 'Distrito Petit', 'VE.11.3630294', 'ASCII:Distrito Petit;ID:3630294', '27693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27693', '112', '29570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3630294» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29571', '1079', '1', 'Distrito Perijá', 'VE.23.3630346', 'ASCII:Distrito Perija;ID:3630346', '27694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27694', '112', '29571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.23.3630346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29572', '1079', '1', 'Distrito Península de Macanao', 'VE.17.3630389', 'ASCII:Distrito Peninsula de Macanao;ID:3630389', '27695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27695', '112', '29572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.17.3630389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29573', '1079', '1', 'Distrito Peñalver', 'VE.02.3630402', 'ASCII:Distrito Penalver;ID:3630402', '27696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27696', '112', '29573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3630402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29574', '1079', '1', 'Distrito Pedro María Ureña', 'VE.20.3630452', 'ASCII:Distrito Pedro Maria Urena;ID:3630452', '27697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27697', '112', '29574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3630452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29575', '1079', '1', 'Distrito Pedro Camejo', 'VE.03.3630456', 'ASCII:Distrito Pedro Camejo;ID:3630456', '27698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27698', '112', '29575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.03.3630456» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29576', '1079', '1', 'Distrito Pedraza', 'VE.05.3630482', 'ASCII:Distrito Pedraza;ID:3630482', '27699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27699', '112', '29576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.05.3630482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29577', '1079', '1', 'Departamento Pedernales', 'VE.09.3630486', 'ASCII:Departamento Pedernales;ID:3630486', '27700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27700', '112', '29577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.09.3630486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29578', '1079', '1', 'Distrito Paz Castillo', 'VE.15.3630495', 'ASCII:Distrito Paz Castillo;ID:3630495', '27701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27701', '112', '29578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3630495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29579', '1079', '1', 'Distrito Pao', 'VE.08.3630851', 'ASCII:Distrito Pao;ID:3630851', '27702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27702', '112', '29579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.08.3630851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29580', '1079', '1', 'Distrito Panamericano', 'VE.20.3630887', 'ASCII:Distrito Panamericano;ID:3630887', '27703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27703', '112', '29580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3630887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29581', '1079', '1', 'Distrito Palavecino', 'VE.13.3631101', 'ASCII:Distrito Palavecino;ID:3631101', '27704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27704', '112', '29581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.13.3631101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29582', '1079', '1', 'Distrito Páez', 'VE.23.3631168', 'ASCII:Distrito Paez;ID:3631168', '27705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27705', '112', '29582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.23.3631168» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29583', '1079', '1', 'Distrito Páez', 'VE.15.3631169', 'ASCII:Distrito Paez;ID:3631169', '27706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27706', '112', '29583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3631169» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29584', '1079', '1', 'Distrito Páez', 'VE.18.3631170', 'ASCII:Distrito Paez;ID:3631170', '27707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27707', '112', '29584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.18.3631170» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29585', '1079', '1', 'Distrito Páez', 'VE.03.3631171', 'ASCII:Distrito Paez;ID:3631171', '27708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27708', '112', '29585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.03.3631171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29586', '1079', '1', 'Distrito Ospino', 'VE.18.3631207', 'ASCII:Distrito Ospino;ID:3631207', '27709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27709', '112', '29586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.18.3631207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29587', '1079', '1', 'Distrito Obispos', 'VE.05.3631430', 'ASCII:Distrito Obispos;ID:3631430', '27710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27710', '112', '29587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.05.3631430» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29588', '1079', '1', 'Distrito Nirgua', 'VE.22.3631506', 'ASCII:Distrito Nirgua;ID:3631506', '27711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27711', '112', '29588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.22.3631506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29589', '1079', '1', 'Distrito Muñoz', 'VE.03.3631656', 'ASCII:Distrito Munoz;ID:3631656', '27712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27712', '112', '29589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.03.3631656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29590', '1079', '1', 'Distrito Morán', 'VE.13.3631972', 'ASCII:Distrito Moran;ID:3631972', '27713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27713', '112', '29590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.13.3631972» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29591', '1079', '1', 'Distrito Montes', 'VE.19.3632008', 'ASCII:Distrito Montes;ID:3632008', '27714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27714', '112', '29591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3632008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29592', '1079', '1', 'Distrito Montalbán', 'VE.07.3632070', 'ASCII:Distrito Montalban;ID:3632070', '27715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27715', '112', '29592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.07.3632070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29593', '1079', '1', 'Distrito Monagas', 'VE.12.3632101', 'ASCII:Distrito Monagas;ID:3632101', '27716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27716', '112', '29593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.12.3632101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29594', '1079', '1', 'Distrito Monagas', 'VE.02.3632102', 'ASCII:Distrito Monagas;ID:3632102', '27717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27717', '112', '29594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3632102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29595', '1079', '1', 'Distrito Miranda', 'VE.11.3632192', 'ASCII:Distrito Miranda;ID:3632192', '27718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27718', '112', '29595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3632192» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29596', '1079', '1', 'Distrito Miranda', 'VE.23.3632193', 'ASCII:Distrito Miranda;ID:3632193', '27719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27719', '112', '29596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.23.3632193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29597', '1079', '1', 'Distrito Miranda', 'VE.14.3632194', 'ASCII:Distrito Miranda;ID:3632194', '27720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27720', '112', '29597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3632194» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29598', '1079', '1', 'Distrito Miranda', 'VE.02.3632195', 'ASCII:Distrito Miranda;ID:3632195', '27721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27721', '112', '29598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3632195» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29599', '1079', '1', 'Distrito Miranda', 'VE.12.3632196', 'ASCII:Distrito Miranda;ID:3632196', '27722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27722', '112', '29599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.12.3632196» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29600', '1079', '1', 'Distrito Michelena', 'VE.20.3632259', 'ASCII:Distrito Michelena;ID:3632259', '27723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27723', '112', '29600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3632259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29601', '1079', '1', 'Distrito Mellado', 'VE.12.3632416', 'ASCII:Distrito Mellado;ID:3632416', '27724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27724', '112', '29601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.12.3632416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29602', '1079', '1', 'Distrito Mejía', 'VE.19.3632428', 'ASCII:Distrito Mejia;ID:3632428', '27725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27725', '112', '29602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3632428» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29603', '1079', '1', 'Distrito Mauroa', 'VE.11.3632524', 'ASCII:Distrito Mauroa;ID:3632524', '27726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27726', '112', '29603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3632524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29604', '1079', '1', 'Distrito Maturín', 'VE.16.3632537', 'ASCII:Distrito Maturin;ID:3632537', '27727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27727', '112', '29604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.16.3632537» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29605', '1079', '1', 'Distrito Mariño', 'VE.17.3632894', 'ASCII:Distrito Marino;ID:3632894', '27728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27728', '112', '29605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.17.3632894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29606', '1079', '1', 'Distrito Mariño', 'VE.19.3632895', 'ASCII:Distrito Marino;ID:3632895', '27729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27729', '112', '29606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3632895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29607', '1079', '1', 'Distrito Mariño', 'VE.04.3632896', 'ASCII:Distrito Marino;ID:3632896', '27730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27730', '112', '29607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.04.3632896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29608', '1079', '1', 'Distrito Maracaibo', 'VE.23.3633006', 'ASCII:Distrito Maracaibo;ID:3633006', '27731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27731', '112', '29608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.23.3633006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29609', '1079', '1', 'Distrito Mara', 'VE.23.3633019', 'ASCII:Distrito Mara;ID:3633019', '27732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27732', '112', '29609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.23.3633019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29610', '1079', '1', 'Distrito Maneiro', 'VE.17.3633180', 'ASCII:Distrito Maneiro;ID:3633180', '27733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27733', '112', '29610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.17.3633180» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29611', '1079', '1', 'Distrito Lobatera', 'VE.20.3634695', 'ASCII:Distrito Lobatera;ID:3634695', '27734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27734', '112', '29611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3634695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29612', '1079', '1', 'Distrito Libertador', 'VE.19.3634754', 'ASCII:Distrito Libertador;ID:3634754', '27735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27735', '112', '29612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3634754» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29613', '1079', '1', 'Distrito Libertador', 'VE.14.3634755', 'ASCII:Distrito Libertador;ID:3634755', '27736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27736', '112', '29613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3634755» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29614', '1079', '1', 'Distrito Libertador', 'VE.20.3634756', 'ASCII:Distrito Libertador;ID:3634756', '27737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27737', '112', '29614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3634756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29615', '1079', '1', 'Departamento Libertador', 'VE.25.3634757', 'ASCII:Departamento Libertador;ID:3634757', '27738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27738', '112', '29615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.25.3634757» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29616', '1079', '1', 'Distrito Libertad', 'VE.02.3634759', 'ASCII:Distrito Libertad;ID:3634759', '27739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27739', '112', '29616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3634759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29617', '1079', '1', 'Distrito Lander', 'VE.15.3637011', 'ASCII:Distrito Lander;ID:3637011', '27740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27740', '112', '29617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3637011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29618', '1079', '1', 'Distrito Justo Briceño', 'VE.14.3639053', 'ASCII:Distrito Justo Briceno;ID:3639053', '27741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27741', '112', '29618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3639053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29619', '1079', '1', 'Distrito Junín', 'VE.20.3639063', 'ASCII:Distrito Junin;ID:3639063', '27742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27742', '112', '29619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3639063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29620', '1079', '1', 'Distrito Jiménez', 'VE.13.3639197', 'ASCII:Distrito Jimenez;ID:3639197', '27743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27743', '112', '29620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.13.3639197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29621', '1079', '1', 'Distrito Jáuregui', 'VE.20.3639226', 'ASCII:Distrito Jauregui;ID:3639226', '27744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27744', '112', '29621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3639226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29622', '1079', '1', 'Distrito Iribarren', 'VE.13.3639346', 'ASCII:Distrito Iribarren;ID:3639346', '27745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27745', '112', '29622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.13.3639346» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29623', '1079', '1', 'Distrito Infante', 'VE.12.3639376', 'ASCII:Distrito Infante;ID:3639376', '27746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27746', '112', '29623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.12.3639376» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29624', '1079', '1', 'Distrito Independencia', 'VE.15.3639385', 'ASCII:Distrito Independencia;ID:3639385', '27747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27747', '112', '29624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3639385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29625', '1079', '1', 'Distrito Independencia', 'VE.02.3639386', 'ASCII:Distrito Independencia;ID:3639386', '27748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27748', '112', '29625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3639386» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29626', '1079', '1', 'Distrito Heres', 'VE.06.3639562', 'ASCII:Distrito Heres;ID:3639562', '27749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27749', '112', '29626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.06.3639562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29627', '1079', '1', 'Distrito Guanipa', 'VE.02.3640191', 'ASCII:Distrito Guanipa;ID:3640191', '27750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27750', '112', '29627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3640191» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29628', '1079', '1', 'Distrito Guanarito', 'VE.18.3640213', 'ASCII:Distrito Guanarito;ID:3640213', '27751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27751', '112', '29628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.18.3640213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29629', '1079', '1', 'Distrito Guanare', 'VE.18.3640225', 'ASCII:Distrito Guanare;ID:3640225', '27752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27752', '112', '29629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.18.3640225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29630', '1079', '1', 'Distrito Guaicaipuro', 'VE.15.3640380', 'ASCII:Distrito Guaicaipuro;ID:3640380', '27753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27753', '112', '29630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3640380» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29631', '1079', '1', 'Distrito Guacara', 'VE.07.3640464', 'ASCII:Distrito Guacara;ID:3640464', '27754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27754', '112', '29631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.07.3640464» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29632', '1079', '1', 'Distrito Gómez', 'VE.17.3640582', 'ASCII:Distrito Gomez;ID:3640582', '27755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27755', '112', '29632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.17.3640582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29633', '1079', '1', 'Distrito Girardot', 'VE.04.3640595', 'ASCII:Distrito Girardot;ID:3640595', '27756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27756', '112', '29633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.04.3640595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29634', '1079', '1', 'Distrito Girardot', 'VE.08.3640596', 'ASCII:Distrito Girardot;ID:3640596', '27757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27757', '112', '29634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.08.3640596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29635', '1079', '1', 'Distrito García de Hevia', 'VE.20.3640668', 'ASCII:Distrito Garcia de Hevia;ID:3640668', '27758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27758', '112', '29635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3640668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29636', '1079', '1', 'Distrito Freites', 'VE.02.3640765', 'ASCII:Distrito Freites;ID:3640765', '27759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27759', '112', '29636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3640765» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29637', '1079', '1', 'Distrito Federación', 'VE.11.3640848', 'ASCII:Distrito Federacion;ID:3640848', '27760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27760', '112', '29637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3640848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29638', '1079', '1', 'Falcón Distrito', 'VE.08.3640872', 'ASCII:Falcon Distrito;ID:3640872', '27761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27761', '112', '29638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.08.3640872» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29639', '1079', '1', 'Distrito Falcón', 'VE.11.3640874', 'ASCII:Distrito Falcon;ID:3640874', '27762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27762', '112', '29639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3640874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29640', '1079', '1', 'Distrito Ezequiel Zamora', 'VE.05.3640879', 'ASCII:Distrito Ezequiel Zamora;ID:3640879', '27763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27763', '112', '29640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.05.3640879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29641', '1079', '1', 'Distrito Esteller', 'VE.18.3640903', 'ASCII:Distrito Esteller;ID:3640903', '27764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27764', '112', '29641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.18.3640903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29642', '1079', '1', 'Distrito Escuque', 'VE.21.3640955', 'ASCII:Distrito Escuque;ID:3640955', '27765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27765', '112', '29642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.21.3640955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29643', '1079', '1', 'Distrito Díaz', 'VE.17.3644510', 'ASCII:Distrito Diaz;ID:3644510', '27766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27766', '112', '29643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.17.3644510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29644', '1079', '1', 'Distrito Democracia', 'VE.11.3644540', 'ASCII:Distrito Democracia;ID:3644540', '27767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27767', '112', '29644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3644540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29645', '1079', '1', 'Distrito Cristóbal Rojas', 'VE.15.3644938', 'ASCII:Distrito Cristobal Rojas;ID:3644938', '27768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27768', '112', '29645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3644938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29646', '1079', '1', 'Distrito Crespo', 'VE.13.3644947', 'ASCII:Distrito Crespo;ID:3644947', '27769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27769', '112', '29646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.13.3644947» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29647', '1079', '1', 'Distrito Córdoba', 'VE.20.3645220', 'ASCII:Distrito Cordoba;ID:3645220', '27770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27770', '112', '29647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3645220» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29648', '1079', '1', 'Distrito Colón', 'VE.23.3645361', 'ASCII:Distrito Colon;ID:3645361', '27771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27771', '112', '29648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.23.3645361» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29649', '1079', '1', 'Distrito Colina', 'VE.11.3645374', 'ASCII:Distrito Colina;ID:3645374', '27772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27772', '112', '29649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3645374» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29650', '1079', '1', 'Distrito Cedeño', 'VE.16.3646104', 'ASCII:Distrito Cedeno;ID:3646104', '27773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27773', '112', '29650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.16.3646104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29651', '1079', '1', 'Distrito Cedeño', 'VE.06.3646105', 'ASCII:Distrito Cedeno;ID:3646105', '27774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27774', '112', '29651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.06.3646105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29652', '1079', '1', 'Departamento Casiquiare', 'VE.01.3646291', 'ASCII:Departamento Casiquiare;ID:3646291', '27775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27775', '112', '29652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.01.3646291» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29653', '1079', '1', 'Distrito Caroní', 'VE.06.3646491', 'ASCII:Distrito Caroni;ID:3646491', '27776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27776', '112', '29653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.06.3646491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29654', '1079', '1', 'Distrito Carlos Arvelo', 'VE.07.3646514', 'ASCII:Distrito Carlos Arvelo;ID:3646514', '27777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27777', '112', '29654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.07.3646514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29655', '1079', '1', 'Distrito Carirubana', 'VE.11.3646527', 'ASCII:Distrito Carirubana;ID:3646527', '27778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27778', '112', '29655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3646527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29656', '1079', '1', 'Distrito Caripe', 'VE.16.3646536', 'ASCII:Distrito Caripe;ID:3646536', '27779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27779', '112', '29656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.16.3646536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29657', '1079', '1', 'Distrito Cárdenas', 'VE.20.3646610', 'ASCII:Distrito Cardenas;ID:3646610', '27780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27780', '112', '29657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3646610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29658', '1079', '1', 'Distrito Carache', 'VE.21.3646730', 'ASCII:Distrito Carache;ID:3646730', '27781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27781', '112', '29658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.21.3646730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29659', '1079', '1', 'Distrito Capacho', 'VE.20.3646848', 'ASCII:Distrito Capacho;ID:3646848', '27782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27782', '112', '29659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3646848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29660', '1079', '1', 'Distrito Campo Elías', 'VE.14.3647193', 'ASCII:Distrito Campo Elias;ID:3647193', '27783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27783', '112', '29660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3647193» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29661', '1079', '1', 'Distrito Cagigal', 'VE.19.3647550', 'ASCII:Distrito Cagigal;ID:3647550', '27784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27784', '112', '29661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3647550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29662', '1079', '1', 'Distrito Cagigal', 'VE.02.3647551', 'ASCII:Distrito Cagigal;ID:3647551', '27785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27785', '112', '29662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3647551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29663', '1079', '1', 'Distrito Buchivacoa', 'VE.11.3647886', 'ASCII:Distrito Buchivacoa;ID:3647886', '27786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27786', '112', '29663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3647886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29664', '1079', '1', 'Distrito Bruzual', 'VE.22.3647929', 'ASCII:Distrito Bruzual;ID:3647929', '27787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27787', '112', '29664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.22.3647929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29665', '1079', '1', 'Distrito Bruzual', 'VE.02.3647930', 'ASCII:Distrito Bruzual;ID:3647930', '27788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27788', '112', '29665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3647930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29666', '1079', '1', 'Distrito Brión', 'VE.15.3647945', 'ASCII:Distrito Brion;ID:3647945', '27789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27789', '112', '29666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3647945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29667', '1079', '1', 'Distrito Bolívar', 'VE.11.3648107', 'ASCII:Distrito Bolivar;ID:3648107', '27790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27790', '112', '29667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3648107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29668', '1079', '1', 'Distrito Bolívar', 'VE.22.3648108', 'ASCII:Distrito Bolivar;ID:3648108', '27791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27791', '112', '29668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.22.3648108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29669', '1079', '1', 'Distrito Bolívar', 'VE.23.3648109', 'ASCII:Distrito Bolivar;ID:3648109', '27792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27792', '112', '29669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.23.3648109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29670', '1079', '1', 'Distrito Bolívar', 'VE.02.3648110', 'ASCII:Distrito Bolivar;ID:3648110', '27793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27793', '112', '29670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3648110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29671', '1079', '1', 'Distrito Bolívar', 'VE.16.3648111', 'ASCII:Distrito Bolivar;ID:3648111', '27794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27794', '112', '29671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.16.3648111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29672', '1079', '1', 'Distrito Bolívar', 'VE.05.3648112', 'ASCII:Distrito Bolivar;ID:3648112', '27795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27795', '112', '29672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.05.3648112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29673', '1079', '1', 'Distrito Bolívar', 'VE.20.3648113', 'ASCII:Distrito Bolivar;ID:3648113', '27796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27796', '112', '29673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3648113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29674', '1079', '1', 'Distrito Boconó', 'VE.21.3648130', 'ASCII:Distrito Bocono;ID:3648130', '27797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27797', '112', '29674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.21.3648130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29675', '1079', '1', 'Distrito Betijoque', 'VE.21.3648289', 'ASCII:Distrito Betijoque;ID:3648289', '27798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27798', '112', '29675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.21.3648289» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29676', '1079', '1', 'Distrito Bermúdez', 'VE.19.3648300', 'ASCII:Distrito Bermudez;ID:3648300', '27799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27799', '112', '29676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3648300» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29677', '1079', '1', 'Distrito Benítez', 'VE.19.3648316', 'ASCII:Distrito Benitez;ID:3648316', '27800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27800', '112', '29677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3648316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29678', '1079', '1', 'Distrito Bejuma', 'VE.07.3648385', 'ASCII:Distrito Bejuma;ID:3648385', '27801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27801', '112', '29678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.07.3648385» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29679', '1079', '1', 'Distrito Barinas', 'VE.05.3648545', 'ASCII:Distrito Barinas;ID:3648545', '27802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27802', '112', '29679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.05.3648545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29680', '1079', '1', 'Distrito Baralt', 'VE.23.3648586', 'ASCII:Distrito Baralt;ID:3648586', '27803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27803', '112', '29680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.23.3648586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29681', '1079', '1', 'Distrito Ayacucho', 'VE.20.3648740', 'ASCII:Distrito Ayacucho;ID:3648740', '27804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27804', '112', '29681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.20.3648740» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29682', '1079', '1', 'Departamento Atures', 'VE.01.3648789', 'ASCII:Departamento Atures;ID:3648789', '27805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27805', '112', '29682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.01.3648789» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29683', '1079', '1', 'Departamento Atabapo', 'VE.01.3648813', 'ASCII:Departamento Atabapo;ID:3648813', '27806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27806', '112', '29683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.01.3648813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29684', '1079', '1', 'Distrito Arzobispo Chacón', 'VE.14.3648827', 'ASCII:Distrito Arzobispo Chacon;ID:3648827', '27807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27807', '112', '29684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3648827» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29685', '1079', '1', 'Distrito Arvelo Torrealba', 'VE.05.3648829', 'ASCII:Distrito Arvelo Torrealba;ID:3648829', '27808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27808', '112', '29685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.05.3648829» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29686', '1079', '1', 'Distrito Arismendi', 'VE.17.3648881', 'ASCII:Distrito Arismendi;ID:3648881', '27809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27809', '112', '29686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.17.3648881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29687', '1079', '1', 'Distrito Arismendi', 'VE.19.3648882', 'ASCII:Distrito Arismendi;ID:3648882', '27810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27810', '112', '29687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3648882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29688', '1079', '1', 'Distrito Arismendi', 'VE.05.3648883', 'ASCII:Distrito Arismendi;ID:3648883', '27811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27811', '112', '29688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.05.3648883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29689', '1079', '1', 'Distrito Araure', 'VE.18.3649016', 'ASCII:Distrito Araure;ID:3649016', '27812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27812', '112', '29689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.18.3649016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29690', '1079', '1', 'Distrito Aragua', 'VE.02.3649111', 'ASCII:Distrito Aragua;ID:3649111', '27813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27813', '112', '29690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3649111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29691', '1079', '1', 'Distrito Anzoátegui', 'VE.08.3649199', 'ASCII:Distrito Anzoategui;ID:3649199', '27814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27814', '112', '29691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.08.3649199» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29692', '1079', '1', 'Departamento Antonio Díaz', 'VE.09.3649210', 'ASCII:Departamento Antonio Diaz;ID:3649210', '27815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27815', '112', '29692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.09.3649210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29693', '1079', '1', 'Departamento Andrés Mata', 'VE.19.3649247', 'ASCII:Departamento Andres Mata;ID:3649247', '27816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27816', '112', '29693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3649247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29694', '1079', '1', 'Distrito Andrés Eloy Blanco', 'VE.19.3649248', 'ASCII:Distrito Andres Eloy Blanco;ID:3649248', '27817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27817', '112', '29694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.19.3649248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29695', '1079', '1', 'Distrito Andrés Bello', 'VE.14.3649249', 'ASCII:Distrito Andres Bello;ID:3649249', '27818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27818', '112', '29695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3649249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29696', '1079', '1', 'Distrito Anaco', 'VE.02.3649281', 'ASCII:Distrito Anaco;ID:3649281', '27819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27819', '112', '29696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.02.3649281» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29697', '1079', '1', 'Distrito Alberto Adriani', 'VE.14.3649500', 'ASCII:Distrito Alberto Adriani;ID:3649500', '27820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27820', '112', '29697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3649500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29698', '1079', '1', 'Distrito Acosta', 'VE.11.3649798', 'ASCII:Distrito Acosta;ID:3649798', '27821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27821', '112', '29698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.11.3649798» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29699', '1079', '1', 'Distrito Acosta', 'VE.16.3649799', 'ASCII:Distrito Acosta;ID:3649799', '27822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27822', '112', '29699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.16.3649799» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29700', '1079', '1', 'Distrito Achaguas', 'VE.03.3649809', 'ASCII:Distrito Achaguas;ID:3649809', '27823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27823', '112', '29700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.03.3649809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29701', '1079', '1', 'Distrito Acevedo', 'VE.15.3649812', 'ASCII:Distrito Acevedo;ID:3649812', '27824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27824', '112', '29701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.15.3649812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29702', '1079', '1', 'Distrito Colón', 'VE.14.3765772', 'ASCII:Distrito Colon;ID:3765772', '27825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27825', '112', '29702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.14.3765772» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29703', '1079', '1', 'municipio antolin del campo', 'VE.17.6693152', 'ASCII:municipio antolin del campo;ID:6693152', '27826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27826', '112', '29703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VE.17.6693152» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29704', '1079', '1', 'Huyện Thạnh Phú', 'VN.03.1904844', 'ASCII:Huyen Thanh Phu;ID:1904844', '27827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27827', '112', '29704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.03.1904844» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29705', '1079', '1', 'Huyện Mỏ Cày', 'VN.03.1904845', 'ASCII:Huyen Mo Cay;ID:1904845', '27828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27828', '112', '29705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.03.1904845» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29706', '1079', '1', 'Huyện Chợ Lách', 'VN.03.1904846', 'ASCII:Huyen Cho Lach;ID:1904846', '27829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27829', '112', '29706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.03.1904846» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29707', '1079', '1', 'Huyện Chợu Thành', 'VN.03.1904847', 'ASCII:Huyen Chou Thanh;ID:1904847', '27830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27830', '112', '29707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.03.1904847» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29708', '1079', '1', 'Huyện Giồng Trôm', 'VN.03.1904848', 'ASCII:Huyen Giong Trom;ID:1904848', '27831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27831', '112', '29708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.03.1904848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29709', '1079', '1', 'Huyện Bình Ðại', 'VN.03.1904849', 'ASCII:Huyen Binh Dai;ID:1904849', '27832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27832', '112', '29709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.03.1904849» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29710', '1079', '1', 'Huyện Ba Tri', 'VN.03.1904850', 'ASCII:Huyen Ba Tri;ID:1904850', '27833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27833', '112', '29710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.03.1904850» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29711', '1079', '1', 'Thị Xã Bến Tre', 'VN.03.1904851', 'ASCII:Thi Xa Ben Tre;ID:1904851', '27834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27834', '112', '29711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.03.1904851» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29712', '1079', '1', 'Thành Phố Mỹ Tho', 'VN.37.1904852', 'ASCII:Thanh Pho My Tho;ID:1904852', '27835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27835', '112', '29712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.37.1904852» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29713', '1079', '1', 'Thị Xã Gò Công', 'VN.37.1904853', 'ASCII:Go Cong;ID:1904853', '27836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27836', '112', '29713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.37.1904853» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29714', '1079', '1', 'Huyện Gò Công Ðông', 'VN.37.1904855', 'ASCII:Huyen Go Cong Dong;ID:1904855', '27837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27837', '112', '29714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.37.1904855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29715', '1079', '1', 'Huyện Gò Công Tây', 'VN.37.1904856', 'ASCII:Huyen Go Cong Tay;ID:1904856', '27838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27838', '112', '29715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.37.1904856» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29716', '1079', '1', 'Huyện Chợ Gạo', 'VN.37.1904857', 'ASCII:Huyen Cho Gao;ID:1904857', '27839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27839', '112', '29716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.37.1904857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29717', '1079', '1', 'Huyện ChậuThành', 'VN.37.1904858', 'ASCII:Huyen ChauThanh;ID:1904858', '27840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27840', '112', '29717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.37.1904858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29718', '1079', '1', 'Huyện Tân Phước', 'VN.37.1904859', 'ASCII:Huyen Tan Phuoc;ID:1904859', '27841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27841', '112', '29718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.37.1904859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29719', '1079', '1', 'Huyện Cai Lậy', 'VN.37.1904860', 'ASCII:Huyen Cai Lay;ID:1904860', '27842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27842', '112', '29719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.37.1904860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29720', '1079', '1', 'Huyện Cái Bé', 'VN.37.1904861', 'ASCII:Huyen Cai Be;ID:1904861', '27843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27843', '112', '29720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.37.1904861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29721', '1079', '1', 'Thành Phố Tây Ninh', 'VN.33.1904862', 'ASCII:Thanh Pho Tay Ninh;ID:1904862', '27844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27844', '112', '29721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.33.1904862» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29722', '1079', '1', 'Huyện Hòa Thành', 'VN.33.1904863', 'ASCII:Huyen Hoa Thanh;ID:1904863', '27845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27845', '112', '29722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.33.1904863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29723', '1079', '1', 'Huyện Châu Thành', 'VN.33.1904864', 'ASCII:Huyen Chau Thanh;ID:1904864', '27846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27846', '112', '29723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.33.1904864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29724', '1079', '1', 'Huyện Bến Cầu', 'VN.33.1904865', 'ASCII:Huyen Ben Cau;ID:1904865', '27847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27847', '112', '29724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.33.1904865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29725', '1079', '1', 'Huyện Gò Dầu', 'VN.33.1904866', 'ASCII:Huyen Go Dau;ID:1904866', '27848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27848', '112', '29725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.33.1904866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29726', '1079', '1', 'Huyện Trảng Bàng', 'VN.33.1904867', 'ASCII:Huyen Trang Bang;ID:1904867', '27849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27849', '112', '29726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.33.1904867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29727', '1079', '1', 'Huyện Dương Minh Châu', 'VN.33.1904868', 'ASCII:Huyen Duong Minh Chau;ID:1904868', '27850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27850', '112', '29727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.33.1904868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29728', '1079', '1', 'Huyện Tân Châu', 'VN.33.1904869', 'ASCII:Huyen Tan Chau;ID:1904869', '27851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27851', '112', '29728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.33.1904869» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29729', '1079', '1', 'Huyện Tân Biên', 'VN.33.1904870', 'ASCII:Huyen Tan Bien;ID:1904870', '27852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27852', '112', '29729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.33.1904870» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29730', '1079', '1', 'Quận Một', 'VN.20.1904873', 'ASCII:Quan Mot;ID:1904873', '27853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27853', '112', '29730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904873» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29731', '1079', '1', 'Quận Hai', 'VN.20.1904874', 'ASCII:Quan Hai;ID:1904874', '27854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27854', '112', '29731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904874» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29732', '1079', '1', 'Quận Ba', 'VN.20.1904875', 'ASCII:Quan Ba;ID:1904875', '27855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27855', '112', '29732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904875» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29733', '1079', '1', 'Quận Bốn', 'VN.20.1904876', 'ASCII:Quan Bon;ID:1904876', '27856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27856', '112', '29733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904876» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29734', '1079', '1', 'Quận Năm', 'VN.20.1904877', 'ASCII:Quan Nam;ID:1904877', '27857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27857', '112', '29734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904877» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29735', '1079', '1', 'Quận Sáu', 'VN.20.1904878', 'ASCII:Quan Sau;ID:1904878', '27858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27858', '112', '29735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904878» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29736', '1079', '1', 'Quận Bầy', 'VN.20.1904879', 'ASCII:Quan Bay;ID:1904879', '27859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27859', '112', '29736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904879» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29737', '1079', '1', 'Quận Tám', 'VN.20.1904880', 'ASCII:Quan Tam;ID:1904880', '27860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27860', '112', '29737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904880» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29738', '1079', '1', 'Quận Chín', 'VN.20.1904881', 'ASCII:Quan Chin;ID:1904881', '27861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27861', '112', '29738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904881» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29739', '1079', '1', 'Quận Mười', 'VN.20.1904882', 'ASCII:Quan Muoi;ID:1904882', '27862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27862', '112', '29739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904882» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29740', '1079', '1', 'Quận Mười một', 'VN.20.1904883', 'ASCII:Quan Muoi mot;ID:1904883', '27863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27863', '112', '29740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904883» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29741', '1079', '1', 'Quận Mười hai', 'VN.20.1904884', 'ASCII:Quan Muoi hai;ID:1904884', '27864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27864', '112', '29741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904884» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29742', '1079', '1', 'Quận Phú Nhuận', 'VN.20.1904885', 'ASCII:Quan Phu Nhuan;ID:1904885', '27865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27865', '112', '29742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904885» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29743', '1079', '1', 'Quận Tân Bình', 'VN.20.1904886', 'ASCII:Quan Tan Binh;ID:1904886', '27866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27866', '112', '29743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29744', '1079', '1', 'Quận Bình Thanh', 'VN.20.1904887', 'ASCII:Quan Binh Thanh;ID:1904887', '27867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27867', '112', '29744', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904887» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29745', '1079', '1', 'Quận Gò Vấp', 'VN.20.1904888', 'ASCII:Quan Go Vap;ID:1904888', '27868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27868', '112', '29745', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904888» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29746', '1079', '1', 'Quận Thủ Ðức', 'VN.20.1904890', 'ASCII:Quan Thu Duc;ID:1904890', '27869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27869', '112', '29746', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904890» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29747', '1079', '1', 'Huyên Hóc Môn', 'VN.20.1904891', 'ASCII:Huyen Hoc Mon;ID:1904891', '27870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27870', '112', '29747', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904891» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29748', '1079', '1', 'Huyên Củ Chi', 'VN.20.1904892', 'ASCII:Huyen Cu Chi;ID:1904892', '27871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27871', '112', '29748', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904892» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29749', '1079', '1', 'Huyên Bình Chánh', 'VN.20.1904893', 'ASCII:Huyen Binh Chanh;ID:1904893', '27872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27872', '112', '29749', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904893» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29750', '1079', '1', ' Huyên Nha Bè', 'VN.20.1904894', 'ASCII: Huyen Nha Be;ID:1904894', '27873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27873', '112', '29750', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904894» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29751', '1079', '1', 'Huyên Cần Giờ', 'VN.20.1904895', 'ASCII:Huyen Can Gio;ID:1904895', '27874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27874', '112', '29751', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.20.1904895» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29752', '1079', '1', 'Thành Phố Vũng Tàu', 'VN.45.1904896', 'ASCII:Thanh Pho Vung Tau;ID:1904896', '27875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27875', '112', '29752', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.45.1904896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29753', '1079', '1', 'Thị Xã Bà Rịa', 'VN.45.1904897', 'ASCII:Thi Xa Ba Ria;ID:1904897', '27876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27876', '112', '29753', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.45.1904897» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29754', '1079', '1', 'Huyện Tân Thành', 'VN.45.1904898', 'ASCII:Huyen Tan Thanh;ID:1904898', '27877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27877', '112', '29754', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.45.1904898» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29755', '1079', '1', 'Huyện Châu Ðức', 'VN.45.1904899', 'ASCII:Huyen Chau Duc;ID:1904899', '27878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27878', '112', '29755', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.45.1904899» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29756', '1079', '1', 'Huyện Long Ðất', 'VN.45.1904900', 'ASCII:Huyen Long Dat;ID:1904900', '27879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27879', '112', '29756', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.45.1904900» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29757', '1079', '1', 'Huyện Xuyên Mộc', 'VN.45.1904901', 'ASCII:Huyen Xuyen Moc;ID:1904901', '27880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27880', '112', '29757', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.45.1904901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29758', '1079', '1', 'Huyện Côn Ðảo', 'VN.45.1904903', 'ASCII:Huyen Con Dao;ID:1904903', '27881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27881', '112', '29758', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.45.1904903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29759', '1079', '1', 'Thị Xã Vĩnh Long', 'VN.69.1904905', 'ASCII:Thi Xa Vinh Long;ID:1904905', '27882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27882', '112', '29759', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.69.1904905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29760', '1079', '1', 'Huyện Long Hồ', 'VN.69.1904906', 'ASCII:Huyen Long Ho;ID:1904906', '27883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27883', '112', '29760', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.69.1904906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29761', '1079', '1', 'Huyện Mang Thít', 'VN.69.1904907', 'ASCII:Huyen Mang Thit;ID:1904907', '27884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27884', '112', '29761', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.69.1904907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29762', '1079', '1', 'Huyện Tam Bình', 'VN.69.1904908', 'ASCII:Huyen Tam Binh;ID:1904908', '27885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27885', '112', '29762', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.69.1904908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29763', '1079', '1', 'Huyện Bình Minh', 'VN.69.1904909', 'ASCII:Huyen Binh Minh;ID:1904909', '27886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27886', '112', '29763', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.69.1904909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29764', '1079', '1', 'Huyện Vũng Liêm', 'VN.69.1904910', 'ASCII:Huyen Vung Liem;ID:1904910', '27887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27887', '112', '29764', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.69.1904910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29765', '1079', '1', 'Huyện Trà Ôn', 'VN.69.1904911', 'ASCII:Huyen Tra On;ID:1904911', '27888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27888', '112', '29765', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.69.1904911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29766', '1079', '1', 'Thị Xã Trà Vinh', 'VN.67.1904913', 'ASCII:Thi Xa Tra Vinh;ID:1904913', '27889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27889', '112', '29766', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.67.1904913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29767', '1079', '1', 'Huyện Châu Thành', 'VN.67.1904914', 'ASCII:Huyen Chau Thanh;ID:1904914', '27890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27890', '112', '29767', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.67.1904914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29768', '1079', '1', 'Huyện Càng Long', 'VN.67.1904915', 'ASCII:Huyen Cang Long;ID:1904915', '27891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27891', '112', '29768', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.67.1904915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29769', '1079', '1', 'Huyện Cầu Ngang', 'VN.67.1904916', 'ASCII:Huyen Cau Ngang;ID:1904916', '27892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27892', '112', '29769', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.67.1904916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29770', '1079', '1', 'Huyện Cầu Kè', 'VN.67.1904917', 'ASCII:Huyen Cau Ke;ID:1904917', '27893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27893', '112', '29770', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.67.1904917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29771', '1079', '1', 'Huyện Tiểu Cần', 'VN.67.1904918', 'ASCII:Huyen Tieu Can;ID:1904918', '27894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27894', '112', '29771', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.67.1904918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29772', '1079', '1', 'Huyện Trà Cú', 'VN.67.1904919', 'ASCII:Huyen Tra Cu;ID:1904919', '27895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27895', '112', '29772', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.67.1904919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29773', '1079', '1', 'Huyện Duyên Hải', 'VN.67.1904920', 'ASCII:Huyen Duyen Hai;ID:1904920', '27896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27896', '112', '29773', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.67.1904920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29774', '1079', '1', 'Thị Xã Sóc Trăng', 'VN.65.1904921', 'ASCII:Thi Xa Soc Trang;ID:1904921', '27897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27897', '112', '29774', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.65.1904921» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29775', '1079', '1', 'Huyện Long Phú', 'VN.65.1904922', 'ASCII:Huyen Long Phu;ID:1904922', '27898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27898', '112', '29775', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.65.1904922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29776', '1079', '1', 'Huyện Kế Sách', 'VN.65.1904923', 'ASCII:Huyen Ke Sach;ID:1904923', '27899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27899', '112', '29776', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.65.1904923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29777', '1079', '1', 'Mỹ Tú Huyện', 'VN.65.1904924', 'ASCII:My Tu Huyen;ID:1904924', '27900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27900', '112', '29777', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.65.1904924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29778', '1079', '1', 'Huyện Mỹ Xuyên', 'VN.65.1904925', 'ASCII:Huyen My Xuyen;ID:1904925', '27901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27901', '112', '29778', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.65.1904925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29779', '1079', '1', 'Huyện Thạnh Trị', 'VN.65.1904926', 'ASCII:Huyen Thanh Tri;ID:1904926', '27902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27902', '112', '29779', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.65.1904926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29780', '1079', '1', 'Huyện Vĩnh Châu', 'VN.65.1904927', 'ASCII:Huyen Vinh Chau;ID:1904927', '27903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27903', '112', '29780', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.65.1904927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29781', '1079', '1', 'Thành Phố Cần Thơ', 'VN.48.1904928', 'ASCII:Thanh Pho Can Tho;ID:1904928', '27904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27904', '112', '29781', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.48.1904928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29782', '1079', '1', 'Huyện Châu Thành', 'VN.48.1904929', 'ASCII:Huyen Chau Thanh;ID:1904929', '27905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27905', '112', '29782', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.48.1904929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29783', '1079', '1', 'Huyện Ô Môn', 'VN.48.1904930', 'ASCII:Huyen O Mon;ID:1904930', '27906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27906', '112', '29783', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.48.1904930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29784', '1079', '1', 'Huyện Thốt Nốt', 'VN.48.1904931', 'ASCII:Huyen Thot Not;ID:1904931', '27907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27907', '112', '29784', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.48.1904931» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29785', '1079', '1', 'Huyện Phụng Hiệp', 'VN.48.1904932', 'ASCII:Huyen Phung Hiep;ID:1904932', '27908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27908', '112', '29785', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.48.1904932» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29786', '1079', '1', 'Huyện Vị Thanh', 'VN.48.1904933', 'ASCII:Huyen Vi Thanh;ID:1904933', '27909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27909', '112', '29786', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.48.1904933» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29787', '1079', '1', 'Huyện Long Mỹ', 'VN.48.1904934', 'ASCII:Huyen Long My;ID:1904934', '27910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27910', '112', '29787', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.48.1904934» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29788', '1079', '1', 'Thị Xã Cao Lãnh', 'VN.09.1904938', 'ASCII:Thi Xa Cao Lanh;ID:1904938', '27911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27911', '112', '29788', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904938» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29789', '1079', '1', 'Thị Xã Sa Ðé', 'VN.09.1904939', 'ASCII:Thi Xa Sa De;ID:1904939', '27912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27912', '112', '29789', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904939» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29790', '1079', '1', 'Huyện Châu Thành', 'VN.09.1904940', 'ASCII:Huyen Chau Thanh;ID:1904940', '27913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27913', '112', '29790', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904940» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29791', '1079', '1', 'Huyện Lai Vung', 'VN.09.1904941', 'ASCII:Huyen Lai Vung;ID:1904941', '27914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27914', '112', '29791', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29792', '1079', '1', 'Huyện Thạnh Hưng', 'VN.09.1904942', 'ASCII:Huyen Thanh Hung;ID:1904942', '27915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27915', '112', '29792', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904942» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29793', '1079', '1', 'Huyện Cao Lãnh', 'VN.09.1904943', 'ASCII:Huyen Cao Lanh;ID:1904943', '27916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27916', '112', '29793', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904943» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29794', '1079', '1', 'Huyện Tháp Mười', 'VN.09.1904944', 'ASCII:Huyen Thap Muoi;ID:1904944', '27917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27917', '112', '29794', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904944» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29795', '1079', '1', 'Huyện Thanh Bình', 'VN.09.1904945', 'ASCII:Huyen Thanh Binh;ID:1904945', '27918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27918', '112', '29795', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29796', '1079', '1', 'Huyện Tam Nông', 'VN.09.1904946', 'ASCII:Huyen Tam Nong;ID:1904946', '27919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27919', '112', '29796', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904946» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29797', '1079', '1', 'Huyện Hồng Ngự', 'VN.09.1904947', 'ASCII:Huyen Hong Ngu;ID:1904947', '27920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27920', '112', '29797', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904947» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29798', '1079', '1', 'Huyện Tân Hồng', 'VN.09.1904948', 'ASCII:Huyen Tan Hong;ID:1904948', '27921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27921', '112', '29798', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.09.1904948» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29799', '1079', '1', 'Thị Xã Rạch Giá', 'VN.21.1904949', 'ASCII:Thi Xa Rach Gia;ID:1904949', '27922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27922', '112', '29799', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904949» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29800', '1079', '1', 'Huyện Châu Thành', 'VN.21.1904950', 'ASCII:Huyen Chau Thanh;ID:1904950', '27923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27923', '112', '29800', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904950» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29801', '1079', '1', 'Huyện Giồng Riềng', 'VN.21.1904951', 'ASCII:Huyen Giong Rieng;ID:1904951', '27924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27924', '112', '29801', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904951» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29802', '1079', '1', 'Huyện Tân Hiêp', 'VN.21.1904952', 'ASCII:Huyen Tan Hiep;ID:1904952', '27925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27925', '112', '29802', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29803', '1079', '1', 'Huyện Gò Quao', 'VN.21.1904953', 'ASCII:Huyen Go Quao;ID:1904953', '27926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27926', '112', '29803', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29804', '1079', '1', 'Huyện An Biên', 'VN.21.1904954', 'ASCII:Huyen An Bien;ID:1904954', '27927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27927', '112', '29804', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904954» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29805', '1079', '1', 'Huyện An Minh', 'VN.21.1904955', 'ASCII:Huyen An Minh;ID:1904955', '27928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27928', '112', '29805', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904955» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29806', '1079', '1', 'Huyện Vĩnh Thuận', 'VN.21.1904956', 'ASCII:Huyen Vinh Thuan;ID:1904956', '27929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27929', '112', '29806', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29807', '1079', '1', 'Huyện Hòn Ðất', 'VN.21.1904957', 'ASCII:Huyen Hon Dat;ID:1904957', '27930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27930', '112', '29807', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904957» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29808', '1079', '1', 'Huyện Hà Tiên', 'VN.21.1904958', 'ASCII:Huyen Ha Tien;ID:1904958', '27931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27931', '112', '29808', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904958» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29809', '1079', '1', 'Huyện Kiên Hải', 'VN.21.1904959', 'ASCII:Huyen Kien Hai;ID:1904959', '27932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27932', '112', '29809', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904959» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29810', '1079', '1', 'Huyện Phú Quốc', 'VN.21.1904960', 'ASCII:Huyen Phu Quoc;ID:1904960', '27933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27933', '112', '29810', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.21.1904960» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29811', '1079', '1', 'Thị Xã Phan Rang-Tháp Chàm', 'VN.60.1904963', 'ASCII:Thi Xa Phan Rang-Thap Cham;ID:1904963', '27934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27934', '112', '29811', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.60.1904963» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29812', '1079', '1', 'Huyện Ninh Hải', 'VN.60.1904965', 'ASCII:Huyen Ninh Hai;ID:1904965', '27935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27935', '112', '29812', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.60.1904965» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29813', '1079', '1', 'Huyện Ninh Phướ', 'VN.60.1904966', 'ASCII:Huyen Ninh Phuo;ID:1904966', '27936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27936', '112', '29813', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.60.1904966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29814', '1079', '1', 'Huyện Ninh Sơn', 'VN.60.1904967', 'ASCII:Huyen Ninh Son;ID:1904967', '27937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27937', '112', '29814', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.60.1904967» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29815', '1079', '1', 'Thị Xã Pleiku', 'VN.49.1904973', 'ASCII:Thi Xa Pleiku;ID:1904973', '27938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27938', '112', '29815', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904973» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29816', '1079', '1', 'Huyện Chư Pah', 'VN.49.1904974', 'ASCII:Huyen Chu Pah;ID:1904974', '27939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27939', '112', '29816', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904974» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29817', '1079', '1', 'Huyện Ia Grai', 'VN.49.1904975', 'ASCII:Huyen Ia Grai;ID:1904975', '27940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27940', '112', '29817', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904975» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29818', '1079', '1', 'Huyện Ðức Cơ', 'VN.49.1904976', 'ASCII:Huyen Duc Co;ID:1904976', '27941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27941', '112', '29818', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904976» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29819', '1079', '1', 'Huyện Chư Prông', 'VN.49.1904977', 'ASCII:Huyen Chu Prong;ID:1904977', '27942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27942', '112', '29819', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904977» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29820', '1079', '1', 'Huyện Chư Sê', 'VN.49.1904978', 'ASCII:Huyen Chu Se;ID:1904978', '27943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27943', '112', '29820', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29821', '1079', '1', 'Huyện Krông Pa', 'VN.49.1904979', 'ASCII:Huyen Krong Pa;ID:1904979', '27944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27944', '112', '29821', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904979» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29822', '1079', '1', 'Huyện Ayun Pa', 'VN.49.1904980', 'ASCII:Huyen Ayun Pa;ID:1904980', '27945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27945', '112', '29822', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904980» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29823', '1079', '1', 'Huyện Kông Chrô', 'VN.49.1904981', 'ASCII:Huyen Kong Chro;ID:1904981', '27946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27946', '112', '29823', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29824', '1079', '1', 'Huyện An Khê', 'VN.49.1904982', 'ASCII:Huyen An Khe;ID:1904982', '27947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27947', '112', '29824', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904982» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29825', '1079', '1', 'Huyện Mang Yang', 'VN.49.1904983', 'ASCII:Huyen Mang Yang;ID:1904983', '27948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27948', '112', '29825', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904983» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29826', '1079', '1', 'Huyện K''Bang', 'VN.49.1904984', 'ASCII:Huyen K''Bang;ID:1904984', '27949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27949', '112', '29826', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.49.1904984» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29827', '1079', '1', 'Thành Phố Buôn Ma Thuột', 'VN.07.1904985', 'ASCII:Thanh Pho Buon Ma Thuot;ID:1904985', '27950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27950', '112', '29827', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.1904985» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29828', '1079', '1', 'Huyện Ðắk R''Lắp', 'VN.07.1904986', 'ASCII:Huyen Dak R''Lap;ID:1904986', '27951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27951', '112', '29828', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.1904986» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29829', '1079', '1', 'Huyện Ðắk Nông', 'VN.07.1904987', 'ASCII:Huyen Dak Nong;ID:1904987', '27952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27952', '112', '29829', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.1904987» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29830', '1079', '1', 'Huyện Krông Nô', 'VN.07.1904988', 'ASCII:Huyen Krong No;ID:1904988', '27953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27953', '112', '29830', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.1904988» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29831', '1079', '1', 'Huyện Buôn Ðôn', 'VN.07.1904989', 'ASCII:Huyen Buon Don;ID:1904989', '27954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27954', '112', '29831', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.1904989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29832', '1079', '1', 'Huyện Ea Súp', 'VN.07.1904990', 'ASCII:Huyen Ea Sup;ID:1904990', '27955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27955', '112', '29832', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.1904990» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29833', '1079', '1', 'Thị Xã Tân An', 'VN.24.1904991', 'ASCII:Thi Xa Tan An;ID:1904991', '27956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27956', '112', '29833', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1904991» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29834', '1079', '1', 'Huyện Châu Thành', 'VN.24.1904992', 'ASCII:Huyen Chau Thanh;ID:1904992', '27957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27957', '112', '29834', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1904992» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29835', '1079', '1', 'Huyện Tân Trụ', 'VN.24.1904993', 'ASCII:Huyen Tan Tru;ID:1904993', '27958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27958', '112', '29835', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1904993» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29836', '1079', '1', 'Huyện Cần Ðước', 'VN.24.1904994', 'ASCII:Huyen Can Duoc;ID:1904994', '27959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27959', '112', '29836', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1904994» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29837', '1079', '1', 'Huyện Cần Giuộc', 'VN.24.1904995', 'ASCII:Huyen Can Giuoc;ID:1904995', '27960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27960', '112', '29837', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1904995» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29838', '1079', '1', 'Huyện Bến Lức', 'VN.24.1904996', 'ASCII:Huyen Ben Luc;ID:1904996', '27961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27961', '112', '29838', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1904996» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29839', '1079', '1', 'Huyện Thủ Thừa', 'VN.24.1904997', 'ASCII:Huyen Thu Thua;ID:1904997', '27962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27962', '112', '29839', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1904997» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29840', '1079', '1', 'Huyện Thạnh Hóa', 'VN.24.1904998', 'ASCII:Huyen Thanh Hoa;ID:1904998', '27963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27963', '112', '29840', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1904998» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29841', '1079', '1', 'Huyện Ðức Huệ', 'VN.24.1904999', 'ASCII:Huyen Duc Hue;ID:1904999', '27964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27964', '112', '29841', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1904999» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29842', '1079', '1', 'Huyện Ðức Hòa', 'VN.24.1905000', 'ASCII:Huyen Duc Hoa;ID:1905000', '27965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27965', '112', '29842', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1905000» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29843', '1079', '1', 'Huyện Tân Thạnh', 'VN.24.1905001', 'ASCII:Huyen Tan Thanh;ID:1905001', '27966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27966', '112', '29843', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1905001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29844', '1079', '1', 'Huyện Mộc Hóa', 'VN.24.1905002', 'ASCII:Huyen Moc Hoa;ID:1905002', '27967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27967', '112', '29844', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1905002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29845', '1079', '1', 'Huyện Tân Hưng', 'VN.24.1905003', 'ASCII:Huyen Tan Hung;ID:1905003', '27968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27968', '112', '29845', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1905003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29846', '1079', '1', 'Huyện Vình Hưng', 'VN.24.1905004', 'ASCII:Huyen Vinh Hung;ID:1905004', '27969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27969', '112', '29846', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.24.1905004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29847', '1079', '1', 'Thị Xã Lào Cai', 'VN.56.1905005', 'ASCII:Thi Xa Lao Cai;ID:1905005', '27970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27970', '112', '29847', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.56.1905005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29848', '1079', '1', 'Thị Xã Cam Ðường', 'VN.56.1905006', 'ASCII:Thi Xa Cam Duong;ID:1905006', '27971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27971', '112', '29848', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.56.1905006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29849', '1079', '1', 'Huyện Bảo Thắng', 'VN.56.1905007', 'ASCII:Huyen Bao Thang;ID:1905007', '27972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27972', '112', '29849', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.56.1905007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29850', '1079', '1', 'Huyện Sa Pa', 'VN.56.1905008', 'ASCII:Huyen Sa Pa;ID:1905008', '27973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27973', '112', '29850', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.56.1905008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29851', '1079', '1', 'Huyện Bát Xát', 'VN.56.1905009', 'ASCII:Huyen Bat Xat;ID:1905009', '27974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27974', '112', '29851', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.56.1905009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29852', '1079', '1', 'Huyện Mường Khương', 'VN.56.1905010', 'ASCII:Huyen Muong Khuong;ID:1905010', '27975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27975', '112', '29852', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.56.1905010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29853', '1079', '1', 'Huyện Bắc Hà', 'VN.56.1905011', 'ASCII:Huyen Bac Ha;ID:1905011', '27976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27976', '112', '29853', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.56.1905011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29854', '1079', '1', 'Huyện Bảo Yên', 'VN.56.1905012', 'ASCII:Huyen Bao Yen;ID:1905012', '27977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27977', '112', '29854', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.56.1905012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29855', '1079', '1', 'Huyện Văn Bàn', 'VN.56.1905013', 'ASCII:Huyen Van Ban;ID:1905013', '27978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27978', '112', '29855', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.56.1905013» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29856', '1079', '1', 'Huyện Than Uyên', 'VN.56.1905014', 'ASCII:Huyen Than Uyen;ID:1905014', '27979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27979', '112', '29856', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.56.1905014» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29857', '1079', '1', 'Thị Xã Hòa Bình', 'VN.53.1905015', 'ASCII:Thi Xa Hoa Binh;ID:1905015', '27980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27980', '112', '29857', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.53.1905015» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29858', '1079', '1', 'Huyện Kỳ Sơn', 'VN.53.1905016', 'ASCII:Huyen Ky Son;ID:1905016', '27981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27981', '112', '29858', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.53.1905016» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29859', '1079', '1', 'Huyện Ðà Bắc', 'VN.53.1905017', 'ASCII:Huyen Da Bac;ID:1905017', '27982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27982', '112', '29859', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.53.1905017» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29860', '1079', '1', 'Huyện Mai Châu', 'VN.53.1905018', 'ASCII:Huyen Mai Chau;ID:1905018', '27983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27983', '112', '29860', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.53.1905018» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29861', '1079', '1', 'Huyện Tân Lạc', 'VN.53.1905019', 'ASCII:Huyen Tan Lac;ID:1905019', '27984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27984', '112', '29861', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.53.1905019» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29862', '1079', '1', 'Huyện Lương Sơn', 'VN.53.1905020', 'ASCII:Huyen Luong Son;ID:1905020', '27985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27985', '112', '29862', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.53.1905020» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29863', '1079', '1', 'Huyện Kim Bôi', 'VN.53.1905021', 'ASCII:Huyen Kim Boi;ID:1905021', '27986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27986', '112', '29863', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.53.1905021» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29864', '1079', '1', 'Huyện Lạc Sơn', 'VN.61.1905022', 'ASCII:Huyen Lac Son;ID:1905022', '27987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27987', '112', '29864', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.61.1905022» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29865', '1079', '1', 'Huyện Lạc Thủy', 'VN.53.1905023', 'ASCII:Huyen Lac Thuy;ID:1905023', '27988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27988', '112', '29865', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.53.1905023» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29866', '1079', '1', 'Huyện Yên Thủy', 'VN.53.1905024', 'ASCII:Huyen Yen Thuy;ID:1905024', '27989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27989', '112', '29866', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.53.1905024» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29867', '1079', '1', 'Thị Xã Hà Giang', 'VN.50.1905025', 'ASCII:Thi Xa Ha Giang;ID:1905025', '27990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27990', '112', '29867', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.50.1905025» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29868', '1079', '1', 'Huyện Vị Xuyên', 'VN.50.1905026', 'ASCII:Huyen Vi Xuyen;ID:1905026', '27991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27991', '112', '29868', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.50.1905026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29869', '1079', '1', 'Huyện Bắc Mê', 'VN.50.1905027', 'ASCII:Huyen Bac Me;ID:1905027', '27992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27992', '112', '29869', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.50.1905027» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29870', '1079', '1', 'Huyện Yên Minh', 'VN.50.1905028', 'ASCII:Huyen Yen Minh;ID:1905028', '27993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27993', '112', '29870', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.50.1905028» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29871', '1079', '1', 'Huyện Quản Bạ', 'VN.50.1905029', 'ASCII:Huyen Quan Ba;ID:1905029', '27994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27994', '112', '29871', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.50.1905029» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29872', '1079', '1', 'Huyện Ðồng Văn', 'VN.50.1905030', 'ASCII:Huyen Dong Van;ID:1905030', '27995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27995', '112', '29872', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.50.1905030» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29873', '1079', '1', 'Huyện Mèo Vạc', 'VN.50.1905031', 'ASCII:Huyen Meo Vac;ID:1905031', '27996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27996', '112', '29873', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.50.1905031» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29874', '1079', '1', 'Huyện Xín Mần', 'VN.50.1905032', 'ASCII:Huyen Xin Man;ID:1905032', '27997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27997', '112', '29874', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.50.1905032» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29875', '1079', '1', 'Huyện Hoàng Su Phì', 'VN.50.1905033', 'ASCII:Huyen Hoang Su Phi;ID:1905033', '27998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27998', '112', '29875', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.50.1905033» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29876', '1079', '1', 'Huyện Bắc Quang', 'VN.50.1905034', 'ASCII:Huyen Bac Quang;ID:1905034', '27999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('27999', '112', '29876', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.50.1905034» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29877', '1079', '1', 'Thị Xã Hà Ðông', 'VN.51.1905035', 'ASCII:Thi Xa Ha Dong;ID:1905035', '28000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28000', '112', '29877', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905035» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29878', '1079', '1', 'Thị Xã Sơn Tây', 'VN.51.1905036', 'ASCII:Thi Xa Son Tay;ID:1905036', '28001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28001', '112', '29878', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905036» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29879', '1079', '1', 'Huyện Thanh Oai', 'VN.51.1905037', 'ASCII:Huyen Thanh Oai;ID:1905037', '28002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28002', '112', '29879', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905037» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29880', '1079', '1', 'Huyện Chương Mỹ', 'VN.51.1905038', 'ASCII:Huyen Chuong My;ID:1905038', '28003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28003', '112', '29880', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905038» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29881', '1079', '1', 'Huyện Hoài Ðức', 'VN.51.1905039', 'ASCII:Huyen Hoai Duc;ID:1905039', '28004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28004', '112', '29881', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905039» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29882', '1079', '1', 'Huyện Quốc Oai', 'VN.51.1905040', 'ASCII:Huyen Quoc Oai;ID:1905040', '28005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28005', '112', '29882', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905040» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29883', '1079', '1', 'Huyện Thạch Thất', 'VN.51.1905041', 'ASCII:Huyen Thach That;ID:1905041', '28006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28006', '112', '29883', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29884', '1079', '1', 'Huyện Ðan Phượng', 'VN.51.1905042', 'ASCII:Huyen Dan Phuong;ID:1905042', '28007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28007', '112', '29884', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29885', '1079', '1', 'Huyện Phúc Thọ', 'VN.51.1905043', 'ASCII:Huyen Phuc Tho;ID:1905043', '28008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28008', '112', '29885', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905043» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29886', '1079', '1', 'Huyện Ba Vì', 'VN.51.1905044', 'ASCII:Huyen Ba Vi;ID:1905044', '28009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28009', '112', '29886', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905044» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29887', '1079', '1', 'Huyện Thương Tín', 'VN.51.1905045', 'ASCII:Huyen Thuong Tin;ID:1905045', '28010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28010', '112', '29887', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905045» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29888', '1079', '1', 'Huyện Phú Xuyên', 'VN.51.1905046', 'ASCII:Huyen Phu Xuyen;ID:1905046', '28011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28011', '112', '29888', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905046» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29889', '1079', '1', 'Huyện Ứng Hòa', 'VN.51.1905047', 'ASCII:Huyen Ung Hoa;ID:1905047', '28012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28012', '112', '29889', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905047» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29890', '1079', '1', 'Huyện Mỹ Ðức', 'VN.51.1905048', 'ASCII:Huyen My Duc;ID:1905048', '28013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28013', '112', '29890', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.51.1905048» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29891', '1079', '1', 'Thành Phố Vinh', 'VN.58.1905049', 'ASCII:Thanh Pho Vinh;ID:1905049', '28014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28014', '112', '29891', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905049» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29892', '1079', '1', 'Huyện Hưng Nguyên', 'VN.58.1905050', 'ASCII:Huyen Hung Nguyen;ID:1905050', '28015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28015', '112', '29892', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905050» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29893', '1079', '1', 'Huyện Nam Ðàn', 'VN.58.1905051', 'ASCII:Huyen Nam Dan;ID:1905051', '28016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28016', '112', '29893', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905051» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29894', '1079', '1', 'Huyện Nghi Lộc', 'VN.58.1905052', 'ASCII:Huyen Nghi Loc;ID:1905052', '28017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28017', '112', '29894', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29895', '1079', '1', 'Thị Xã Cửa Lò', 'VN.58.1905053', 'ASCII:Thi Xa Cua Lo;ID:1905053', '28018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28018', '112', '29895', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29896', '1079', '1', 'Huyện Diễn Châu', 'VN.58.1905054', 'ASCII:Huyen Dien Chau;ID:1905054', '28019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28019', '112', '29896', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905054» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29897', '1079', '1', 'Huyện Yên Thành', 'VN.58.1905055', 'ASCII:Huyen Yen Thanh;ID:1905055', '28020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28020', '112', '29897', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29898', '1079', '1', 'Huyện Ðô Lương', 'VN.58.1905056', 'ASCII:Huyen Do Luong;ID:1905056', '28021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28021', '112', '29898', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905056» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29899', '1079', '1', 'Huyện Thanh Chương', 'VN.58.1905057', 'ASCII:Huyen Thanh Chuong;ID:1905057', '28022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28022', '112', '29899', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905057» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29900', '1079', '1', 'Huyện Anh Sơn', 'VN.58.1905058', 'ASCII:Huyen Anh Son;ID:1905058', '28023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28023', '112', '29900', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905058» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29901', '1079', '1', 'Huyện Con Cuông', 'VN.58.1905059', 'ASCII:Huyen Con Cuong;ID:1905059', '28024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28024', '112', '29901', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905059» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29902', '1079', '1', 'Huyện Tân Kỳ', 'VN.58.1905060', 'ASCII:Huyen Tan Ky;ID:1905060', '28025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28025', '112', '29902', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29903', '1079', '1', 'Huyện Quỳnh Lưu', 'VN.58.1905061', 'ASCII:Huyen Quynh Luu;ID:1905061', '28026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28026', '112', '29903', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905061» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29904', '1079', '1', 'Huyện Nghĩa Ðàn', 'VN.58.1905062', 'ASCII:Huyen Nghia Dan;ID:1905062', '28027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28027', '112', '29904', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905062» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29905', '1079', '1', 'Huyện Quỳ Hơp', 'VN.58.1905063', 'ASCII:Huyen Quy Hop;ID:1905063', '28028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28028', '112', '29905', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905063» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29906', '1079', '1', 'Huyện Quỳ Châu', 'VN.58.1905064', 'ASCII:Huyen Quy Chau;ID:1905064', '28029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28029', '112', '29906', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905064» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29907', '1079', '1', 'Huyện Quế Phong', 'VN.58.1905065', 'ASCII:Huyen Que Phong;ID:1905065', '28030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28030', '112', '29907', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905065» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29908', '1079', '1', 'Huyện Tương Dương', 'VN.58.1905066', 'ASCII:Huyen Tuong Duong;ID:1905066', '28031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28031', '112', '29908', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905066» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29909', '1079', '1', 'Huyện Kỳ Sơn', 'VN.58.1905067', 'ASCII:Huyen Ky Son;ID:1905067', '28032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28032', '112', '29909', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.58.1905067» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29910', '1079', '1', 'Thị Xã Thái Bình', 'VN.35.1905068', 'ASCII:Thi Xa Thai Binh;ID:1905068', '28033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28033', '112', '29910', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.35.1905068» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29911', '1079', '1', 'Huyện Vũ Thư', 'VN.35.1905069', 'ASCII:Huyen Vu Thu;ID:1905069', '28034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28034', '112', '29911', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.35.1905069» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29912', '1079', '1', 'Huyện Ðông Hưng', 'VN.35.1905070', 'ASCII:Huyen Dong Hung;ID:1905070', '28035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28035', '112', '29912', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.35.1905070» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29913', '1079', '1', 'Huyện Kiến Xương', 'VN.35.1905071', 'ASCII:Huyen Kien Xuong;ID:1905071', '28036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28036', '112', '29913', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.35.1905071» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29914', '1079', '1', 'Huyện Tiền Hải', 'VN.35.1905072', 'ASCII:Huyen Tien Hai;ID:1905072', '28037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28037', '112', '29914', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.35.1905072» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29915', '1079', '1', 'Huyện Thái Thụy', 'VN.35.1905073', 'ASCII:Huyen Thai Thuy;ID:1905073', '28038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28038', '112', '29915', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.35.1905073» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29916', '1079', '1', 'Huyện Quỳnh Phụ', 'VN.35.1905074', 'ASCII:Huyen Quynh Phu;ID:1905074', '28039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28039', '112', '29916', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.35.1905074» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29917', '1079', '1', 'Huyện Hưng Hà', 'VN.35.1905075', 'ASCII:Huyen Hung Ha;ID:1905075', '28040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28040', '112', '29917', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.35.1905075» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29918', '1079', '1', 'Thị Xã Sơn La', 'VN.32.1905076', 'ASCII:Thi Xa Son La;ID:1905076', '28041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28041', '112', '29918', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.32.1905076» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29919', '1079', '1', 'Huyện Mường La', 'VN.32.1905077', 'ASCII:Huyen Muong La;ID:1905077', '28042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28042', '112', '29919', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.32.1905077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29920', '1079', '1', 'Huyện Quỳnh Nhai', 'VN.32.1905078', 'ASCII:Huyen Quynh Nhai;ID:1905078', '28043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28043', '112', '29920', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.32.1905078» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29921', '1079', '1', 'Huyện Thuận Châu', 'VN.32.1905079', 'ASCII:Huyen Thuan Chau;ID:1905079', '28044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28044', '112', '29921', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.32.1905079» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29922', '1079', '1', 'Huyện Sông Mã', 'VN.32.1905080', 'ASCII:Huyen Song Ma;ID:1905080', '28045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28045', '112', '29922', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.32.1905080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29923', '1079', '1', 'Huyện Mai Sơn', 'VN.32.1905081', 'ASCII:Huyen Mai Son;ID:1905081', '28046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28046', '112', '29923', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.32.1905081» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29924', '1079', '1', 'Huyện Bắc Yên', 'VN.32.1905082', 'ASCII:Huyen Bac Yen;ID:1905082', '28047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28047', '112', '29924', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.32.1905082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29925', '1079', '1', 'Huyện Yên Châu', 'VN.32.1905083', 'ASCII:Huyen Yen Chau;ID:1905083', '28048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28048', '112', '29925', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.32.1905083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29926', '1079', '1', 'Huyện Phù Yên', 'VN.32.1905084', 'ASCII:Huyen Phu Yen;ID:1905084', '28049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28049', '112', '29926', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.32.1905084» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29927', '1079', '1', 'Huyện Mộc Châu', 'VN.32.1905085', 'ASCII:Huyen Moc Chau;ID:1905085', '28050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28050', '112', '29927', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.32.1905085» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29928', '1079', '1', 'Quận Lê Chân', 'VN.13.1905086', 'ASCII:Quan Le Chan;ID:1905086', '28051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28051', '112', '29928', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905086» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29929', '1079', '1', 'Quận Ngô Quyền', 'VN.13.1905087', 'ASCII:Quan Ngo Quyen;ID:1905087', '28052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28052', '112', '29929', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905087» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29930', '1079', '1', 'Quận Kiến An', 'VN.13.1905088', 'ASCII:Quan Kien An;ID:1905088', '28053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28053', '112', '29930', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905088» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29931', '1079', '1', 'Thị Xã Ðồ Sơn', 'VN.13.1905089', 'ASCII:Thi Xa Do Son;ID:1905089', '28054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28054', '112', '29931', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905089» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29932', '1079', '1', 'Huyện An Hải', 'VN.13.1905090', 'ASCII:Huyen An Hai;ID:1905090', '28055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28055', '112', '29932', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905090» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29933', '1079', '1', 'Huyện Thủy Nguyên', 'VN.13.1905091', 'ASCII:Huyen Thuy Nguyen;ID:1905091', '28056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28056', '112', '29933', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905091» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29934', '1079', '1', 'Huyện Na Lão', 'VN.13.1905092', 'ASCII:Huyen Na Lao;ID:1905092', '28057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28057', '112', '29934', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905092» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29935', '1079', '1', 'Huyện Kiến Thụy', 'VN.13.1905093', 'ASCII:Huyen Kien Thuy;ID:1905093', '28058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28058', '112', '29935', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905093» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29936', '1079', '1', 'Huyện Tiến Lãng', 'VN.13.1905094', 'ASCII:Huyen Tien Lang;ID:1905094', '28059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28059', '112', '29936', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905094» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29937', '1079', '1', 'Huyện Vĩnh Bảo', 'VN.13.1905095', 'ASCII:Huyen Vinh Bao;ID:1905095', '28060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28060', '112', '29937', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905095» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29938', '1079', '1', 'Huyện Cát Hải', 'VN.13.1905096', 'ASCII:Huyen Cat Hai;ID:1905096', '28061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28061', '112', '29938', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905096» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29939', '1079', '1', 'Huyện Bạch Long Vỹ', 'VN.13.1905097', 'ASCII:Huyen Bach Long Vy;ID:1905097', '28062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28062', '112', '29939', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905097» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29940', '1079', '1', 'Thị Xã Diện Biên Phủ', 'VN.22.1905098', 'ASCII:Thi Xa Dien Bien Phu;ID:1905098', '28063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28063', '112', '29940', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.22.1905098» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29941', '1079', '1', 'Huyện Ðiện Biên', 'VN.22.1905099', 'ASCII:Huyen Dien Bien;ID:1905099', '28064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28064', '112', '29941', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.22.1905099» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29942', '1079', '1', 'Huyện Ðiện Biên Ðông', 'VN.22.1905100', 'ASCII:Huyen Dien Bien Dong;ID:1905100', '28065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28065', '112', '29942', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.22.1905100» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29943', '1079', '1', 'Huyện Tuần Giào', 'VN.22.1905101', 'ASCII:Huyen Tuan Giao;ID:1905101', '28066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28066', '112', '29943', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.22.1905101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29944', '1079', '1', 'Huyện Tủa Chùa', 'VN.22.1905102', 'ASCII:Huyen Tua Chua;ID:1905102', '28067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28067', '112', '29944', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.22.1905102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29945', '1079', '1', 'Huyện Mưòng Lay', 'VN.22.1905103', 'ASCII:Huyen Muong Lay;ID:1905103', '28068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28068', '112', '29945', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.22.1905103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29946', '1079', '1', 'Huyện Sin Hò', 'VN.22.1905104', 'ASCII:Huyen Sin Ho;ID:1905104', '28069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28069', '112', '29946', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.22.1905104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29947', '1079', '1', 'Thị Xã Lai Châu', 'VN.22.1905105', 'ASCII:Thi Xa Lai Chau;ID:1905105', '28070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28070', '112', '29947', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.22.1905105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29948', '1079', '1', 'Huyện Phong Thổ', 'VN.22.1905106', 'ASCII:Huyen Phong Tho;ID:1905106', '28071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28071', '112', '29948', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.22.1905106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29949', '1079', '1', 'Huyện Mưòng Tè', 'VN.22.1905107', 'ASCII:Huyen Muong Te;ID:1905107', '28072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28072', '112', '29949', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.22.1905107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29950', '1079', '1', 'Thị Xã Hạ Long', 'VN.30.1905108', 'ASCII:Thi Xa Ha Long;ID:1905108', '28073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28073', '112', '29950', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29951', '1079', '1', 'Thị Xã Cẩm Phả', 'VN.30.1905109', 'ASCII:Thi Xa Cam Pha;ID:1905109', '28074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28074', '112', '29951', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29952', '1079', '1', 'Thị Xã Uông Bí', 'VN.30.1905110', 'ASCII:Thi Xa Uong Bi;ID:1905110', '28075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28075', '112', '29952', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29953', '1079', '1', 'Huyện Ðông Triều', 'VN.30.1905111', 'ASCII:Huyen Dong Trieu;ID:1905111', '28076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28076', '112', '29953', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29954', '1079', '1', 'Huyện Yên Hưng', 'VN.30.1905112', 'ASCII:Huyen Yen Hung;ID:1905112', '28077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28077', '112', '29954', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29955', '1079', '1', 'Huyện Hoành Bồ', 'VN.30.1905113', 'ASCII:Huyen Hoanh Bo;ID:1905113', '28078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28078', '112', '29955', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29956', '1079', '1', 'Huyện Ba Chẽ', 'VN.30.1905114', 'ASCII:Huyen Ba Che;ID:1905114', '28079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28079', '112', '29956', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29957', '1079', '1', 'Huyện Tiên Yên', 'VN.30.1905115', 'ASCII:Huyen Tien Yen;ID:1905115', '28080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28080', '112', '29957', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29958', '1079', '1', 'Huyện Bình Liêu', 'VN.30.1905116', 'ASCII:Huyen Binh Lieu;ID:1905116', '28081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28081', '112', '29958', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29959', '1079', '1', 'Huyện Quảng Hà', 'VN.30.1905117', 'ASCII:Huyen Quang Ha;ID:1905117', '28082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28082', '112', '29959', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29960', '1079', '1', 'Huyện Hải Ninh', 'VN.30.1905118', 'ASCII:Huyen Hai Ninh;ID:1905118', '28083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28083', '112', '29960', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29961', '1079', '1', 'Huyện Vân Ðồn', 'VN.30.1905119', 'ASCII:Huyen Van Don;ID:1905119', '28084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28084', '112', '29961', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29962', '1079', '1', 'Huyện Cô Tô', 'VN.30.1905120', 'ASCII:Huyen Co To;ID:1905120', '28085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28085', '112', '29962', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.30.1905120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29963', '1079', '1', 'Quận Ba Ðình', 'VN.44.1905121', 'ASCII:Quan Ba Dinh;ID:1905121', '28086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28086', '112', '29963', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905121» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29964', '1079', '1', 'Quận Cầu Giấy', 'VN.44.1905122', 'ASCII:Quan Cau Giay;ID:1905122', '28087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28087', '112', '29964', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905122» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29965', '1079', '1', 'Huyện Ðông Anh', 'VN.44.1905123', 'ASCII:Huyen Dong Anh;ID:1905123', '28088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28088', '112', '29965', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905123» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29966', '1079', '1', 'Quận Ðống Ða', 'VN.44.1905124', 'ASCII:Quan Dong Da;ID:1905124', '28089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28089', '112', '29966', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905124» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29967', '1079', '1', 'Huyện Gia Lâm', 'VN.44.1905125', 'ASCII:Huyen Gia Lam;ID:1905125', '28090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28090', '112', '29967', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905125» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29968', '1079', '1', 'Quận Hai BàTrưng', 'VN.44.1905126', 'ASCII:Quan Hai BaTrung;ID:1905126', '28091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28091', '112', '29968', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905126» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29969', '1079', '1', 'Quận Hoàn Kiếm', 'VN.44.1905127', 'ASCII:Quan Hoan Kiem;ID:1905127', '28092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28092', '112', '29969', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905127» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29970', '1079', '1', 'Huyện Sóc Sơn', 'VN.44.1905128', 'ASCII:Huyen Soc Son;ID:1905128', '28093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28093', '112', '29970', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905128» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29971', '1079', '1', 'Quận Tây Hồ', 'VN.44.1905129', 'ASCII:Quan Tay Ho;ID:1905129', '28094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28094', '112', '29971', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905129» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29972', '1079', '1', 'Huyện Từ Liêm', 'VN.44.1905130', 'ASCII:Huyen Tu Liem;ID:1905130', '28095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28095', '112', '29972', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905130» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29973', '1079', '1', 'Huyện Thanh Trì', 'VN.44.1905131', 'ASCII:Huyen Thanh Tri;ID:1905131', '28096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28096', '112', '29973', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905131» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29974', '1079', '1', 'Quận Thanh Xuân', 'VN.44.1905132', 'ASCII:Quan Thanh Xuan;ID:1905132', '28097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28097', '112', '29974', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.44.1905132» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29975', '1079', '1', 'Thành Phố Ðà Lạt', 'VN.23.1905197', 'ASCII:Thanh Pho Da Lat;ID:1905197', '28098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28098', '112', '29975', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905197» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29976', '1079', '1', 'Thị Xã Bảo Lộc', 'VN.23.1905200', 'ASCII:Thi Xa Bao Loc;ID:1905200', '28099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28099', '112', '29976', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905200» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29977', '1079', '1', 'Huyện Bảo Lâm', 'VN.23.1905201', 'ASCII:Huyen Bao Lam;ID:1905201', '28100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28100', '112', '29977', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29978', '1079', '1', 'Huyện Ðạ Hu Oai', 'VN.23.1905202', 'ASCII:Huyen Da Hu Oai;ID:1905202', '28101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28101', '112', '29978', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29979', '1079', '1', 'Huyện Ðạ Tẻh', 'VN.23.1905203', 'ASCII:Huyen Da Teh;ID:1905203', '28102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28102', '112', '29979', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29980', '1079', '1', 'Huyện Cát Tiên', 'VN.23.1905204', 'ASCII:Huyen Cat Tien;ID:1905204', '28103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28103', '112', '29980', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29981', '1079', '1', 'Huyện Di Linh', 'VN.23.1905205', 'ASCII:Huyen Di Linh;ID:1905205', '28104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28104', '112', '29981', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29982', '1079', '1', 'Huyện Ðức Trọng', 'VN.23.1905206', 'ASCII:Huyen Duc Trong;ID:1905206', '28105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28105', '112', '29982', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29983', '1079', '1', 'Huyện Ðơn Dương', 'VN.23.1905207', 'ASCII:Huyen Don Duong;ID:1905207', '28106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28106', '112', '29983', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29984', '1079', '1', 'Huyện Lâm Hà', 'VN.23.1905208', 'ASCII:Huyen Lam Ha;ID:1905208', '28107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28107', '112', '29984', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29985', '1079', '1', 'Huyện Lạc Dương', 'VN.23.1905209', 'ASCII:Huyen Lac Duong;ID:1905209', '28108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28108', '112', '29985', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.23.1905209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29986', '1079', '1', 'Thị Xã Ninh Bình', 'VN.59.1905210', 'ASCII:Thi Xa Ninh Binh;ID:1905210', '28109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28109', '112', '29986', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.59.1905210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29987', '1079', '1', 'Huyện Kim Sơn', 'VN.59.1905211', 'ASCII:Huyen Kim Son;ID:1905211', '28110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28110', '112', '29987', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.59.1905211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29988', '1079', '1', 'Huyện Yên Mô', 'VN.59.1905212', 'ASCII:Huyen Yen Mo;ID:1905212', '28111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28111', '112', '29988', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.59.1905212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29989', '1079', '1', 'Huyện Yên Khánh', 'VN.59.1905213', 'ASCII:Huyen Yen Khanh;ID:1905213', '28112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28112', '112', '29989', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.59.1905213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29990', '1079', '1', 'Huyện Tam Ðiệp', 'VN.59.1905214', 'ASCII:Huyen Tam Diep;ID:1905214', '28113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28113', '112', '29990', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.59.1905214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29991', '1079', '1', 'Huyện Hoa Lư', 'VN.59.1905215', 'ASCII:Huyen Hoa Lu;ID:1905215', '28114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28114', '112', '29991', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.59.1905215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29992', '1079', '1', 'Huyện Gia Viễn', 'VN.59.1905216', 'ASCII:Huyen Gia Vien;ID:1905216', '28115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28115', '112', '29992', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.59.1905216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29993', '1079', '1', 'Huyện Nho Quan', 'VN.59.1905217', 'ASCII:Huyen Nho Quan;ID:1905217', '28116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28116', '112', '29993', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.59.1905217» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29994', '1079', '1', 'Thành Phố Thanh Hóa', 'VN.34.1905218', 'ASCII:Thanh Pho Thanh Hoa;ID:1905218', '28117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28117', '112', '29994', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905218» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29995', '1079', '1', 'Huyện Tĩnh Gia', 'VN.34.1905219', 'ASCII:Huyen Tinh Gia;ID:1905219', '28118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28118', '112', '29995', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29996', '1079', '1', 'Huyện Nông Cống', 'VN.34.1905220', 'ASCII:Huyen Nong Cong;ID:1905220', '28119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28119', '112', '29996', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905220» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29997', '1079', '1', 'Huyện Như Thanh', 'VN.34.1905221', 'ASCII:Huyen Nhu Thanh;ID:1905221', '28120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28120', '112', '29997', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905221» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29998', '1079', '1', 'Huyện Như Xuân', 'VN.34.1905222', 'ASCII:Huyen Nhu Xuan;ID:1905222', '28121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28121', '112', '29998', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905222» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('29999', '1079', '1', 'Huyện Quảng Xương', 'VN.34.1905223', 'ASCII:Huyen Quang Xuong;ID:1905223', '28122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28122', '112', '29999', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30000', '1079', '1', 'Thị Xã Sầm Sơn', 'VN.34.1905224', 'ASCII:Thi Xa Sam Son;ID:1905224', '28123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28123', '112', '30000', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905224» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30001', '1079', '1', 'Huyện Hoằng Hóa', 'VN.34.1905225', 'ASCII:Huyen Hoang Hoa;ID:1905225', '28124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28124', '112', '30001', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905225» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30002', '1079', '1', 'Huyện Ðơng Sơn', 'VN.34.1905226', 'ASCII:Huyen Dong Son;ID:1905226', '28125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28125', '112', '30002', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905226» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30003', '1079', '1', 'Huyện Thiệu Hóa', 'VN.34.1905227', 'ASCII:Huyen Thieu Hoa;ID:1905227', '28126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28126', '112', '30003', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905227» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30004', '1079', '1', 'Huyện Yên Ðịnh', 'VN.34.1905228', 'ASCII:Huyen Yen Dinh;ID:1905228', '28127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28127', '112', '30004', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905228» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30005', '1079', '1', 'Huyện Triệu Sơn', 'VN.34.1905229', 'ASCII:Huyen Trieu Son;ID:1905229', '28128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28128', '112', '30005', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905229» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30006', '1079', '1', 'Huyện Thọ Xuân', 'VN.34.1905230', 'ASCII:Huyen Tho Xuan;ID:1905230', '28129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28129', '112', '30006', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905230» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30007', '1079', '1', 'Huyện Thường Xuân', 'VN.34.1905231', 'ASCII:Huyen Thuong Xuan;ID:1905231', '28130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28130', '112', '30007', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905231» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30008', '1079', '1', 'Huyện Ngọc Lậc', 'VN.34.1905233', 'ASCII:Huyen Ngoc Lac;ID:1905233', '28131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28131', '112', '30008', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905233» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30009', '1079', '1', 'Huyện Lang Chánh', 'VN.34.1905234', 'ASCII:Huyen Lang Chanh;ID:1905234', '28132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28132', '112', '30009', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905234» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30010', '1079', '1', 'Huyện Cẩm Thủy', 'VN.34.1905235', 'ASCII:Huyen Cam Thuy;ID:1905235', '28133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28133', '112', '30010', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905235» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30011', '1079', '1', 'Huyện Vĩnh Lộc', 'VN.34.1905236', 'ASCII:Huyen Vinh Loc;ID:1905236', '28134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28134', '112', '30011', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905236» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30012', '1079', '1', 'Huyện Hậu Lộc', 'VN.34.1905237', 'ASCII:Huyen Hau Loc;ID:1905237', '28135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28135', '112', '30012', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905237» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30013', '1079', '1', 'Huyện Nga Sơn', 'VN.34.1905238', 'ASCII:Huyen Nga Son;ID:1905238', '28136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28136', '112', '30013', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30014', '1079', '1', 'Huyện Hà Trung', 'VN.34.1905239', 'ASCII:Huyen Ha Trung;ID:1905239', '28137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28137', '112', '30014', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905239» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30015', '1079', '1', 'Thị Xã Bỉm Sơn', 'VN.34.1905240', 'ASCII:Thi Xa Bim Son;ID:1905240', '28138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28138', '112', '30015', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905240» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30016', '1079', '1', 'Huyện Thạch Thành', 'VN.34.1905241', 'ASCII:Huyen Thach Thanh;ID:1905241', '28139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28139', '112', '30016', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905241» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30017', '1079', '1', 'Huyện Bá Thước', 'VN.34.1905242', 'ASCII:Huyen Ba Thuoc;ID:1905242', '28140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28140', '112', '30017', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905242» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30018', '1079', '1', 'Huyện Quan Sơn', 'VN.34.1905243', 'ASCII:Huyen Quan Son;ID:1905243', '28141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28141', '112', '30018', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905243» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30019', '1079', '1', 'Huyện Quan Hóa', 'VN.34.1905244', 'ASCII:Huyen Quan Hoa;ID:1905244', '28142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28142', '112', '30019', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30020', '1079', '1', 'Huyện Mường Lát', 'VN.34.1905245', 'ASCII:Huyen Muong Lat;ID:1905245', '28143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28143', '112', '30020', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.34.1905245» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30021', '1079', '1', 'Thị Xã Ðông Hà', 'VN.64.1905247', 'ASCII:Thi Xa Dong Ha;ID:1905247', '28144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28144', '112', '30021', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.64.1905247» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30022', '1079', '1', 'Huyện Ða Krông', 'VN.64.1905248', 'ASCII:Huyen Da Krong;ID:1905248', '28145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28145', '112', '30022', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.64.1905248» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30023', '1079', '1', 'Huyện Hướng Hóa', 'VN.64.1905249', 'ASCII:Huyen Huong Hoa;ID:1905249', '28146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28146', '112', '30023', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.64.1905249» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30024', '1079', '1', 'Huyện Hải Lăng', 'VN.64.1905250', 'ASCII:Huyen Hai Lang;ID:1905250', '28147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28147', '112', '30024', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.64.1905250» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30025', '1079', '1', 'Thị Xã Quảng Trị', 'VN.64.1905251', 'ASCII:Thi Xa Quang Tri;ID:1905251', '28148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28148', '112', '30025', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.64.1905251» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30026', '1079', '1', 'Huyện Triệu Phong', 'VN.64.1905252', 'ASCII:Huyen Trieu Phong;ID:1905252', '28149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28149', '112', '30026', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.64.1905252» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30027', '1079', '1', 'Huyện Cam Lộ', 'VN.64.1905253', 'ASCII:Huyen Cam Lo;ID:1905253', '28150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28150', '112', '30027', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.64.1905253» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30028', '1079', '1', 'Huyện Gio Linh', 'VN.64.1905254', 'ASCII:Huyen Gio Linh;ID:1905254', '28151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28151', '112', '30028', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.64.1905254» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30029', '1079', '1', 'Huyện Vĩnh Linh', 'VN.64.1905255', 'ASCII:Huyen Vinh Linh;ID:1905255', '28152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28152', '112', '30029', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.64.1905255» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30030', '1079', '1', 'Thị Xã Ðồng Hới', 'VN.62.1905258', 'ASCII:Thi Xa Dong Hoi;ID:1905258', '28153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28153', '112', '30030', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.62.1905258» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30031', '1079', '1', 'Huyện Lệ Thủy', 'VN.62.1905259', 'ASCII:Huyen Le Thuy;ID:1905259', '28154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28154', '112', '30031', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.62.1905259» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30032', '1079', '1', 'Huyện Quảng Ninh', 'VN.62.1905260', 'ASCII:Huyen Quang Ninh;ID:1905260', '28155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28155', '112', '30032', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.62.1905260» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30033', '1079', '1', 'Huyện Bố Trạch', 'VN.62.1905261', 'ASCII:Huyen Bo Trach;ID:1905261', '28156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28156', '112', '30033', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.62.1905261» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30034', '1079', '1', 'Huyện Quảng Trạch', 'VN.62.1905262', 'ASCII:Huyen Quang Trach;ID:1905262', '28157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28157', '112', '30034', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.62.1905262» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30035', '1079', '1', 'Huyện Tuyên Hóa', 'VN.62.1905264', 'ASCII:Huyen Tuyen Hoa;ID:1905264', '28158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28158', '112', '30035', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.62.1905264» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30036', '1079', '1', 'Huyện Minh Hóa', 'VN.62.1905265', 'ASCII:Huyen Minh Hoa;ID:1905265', '28159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28159', '112', '30036', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.62.1905265» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30037', '1079', '1', 'Thị Xã Bắc Ninh', 'VN.74.1905413', 'ASCII:Thi Xa Bac Ninh;ID:1905413', '28160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28160', '112', '30037', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.74.1905413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30038', '1079', '1', 'Huyện Yên Phong', 'VN.74.1905414', 'ASCII:Huyen Yen Phong;ID:1905414', '28161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28161', '112', '30038', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.74.1905414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30039', '1079', '1', 'Huyện Quế Võ', 'VN.74.1905415', 'ASCII:Huyen Que Vo;ID:1905415', '28162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28162', '112', '30039', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.74.1905415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30040', '1079', '1', 'Huyện Tiên Sơn', 'VN.74.1905416', 'ASCII:Huyen Tien Son;ID:1905416', '28163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28163', '112', '30040', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.74.1905416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30041', '1079', '1', 'Huyện Gia Lương', 'VN.74.1905417', 'ASCII:Huyen Gia Luong;ID:1905417', '28164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28164', '112', '30041', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.74.1905417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30042', '1079', '1', 'Huyện Thuân Thành', 'VN.74.1905418', 'ASCII:Huyen Thuan Thanh;ID:1905418', '28165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28165', '112', '30042', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.74.1905418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30043', '1079', '1', 'Huyện VIệt Ỵên', 'VN.71.1905434', 'ASCII:Huyen VIet Yen;ID:1905434', '28166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28166', '112', '30043', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.71.1905434» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30044', '1079', '1', 'Huyện Yên Dũng', 'VN.71.1905438', 'ASCII:Huyen Yen Dung;ID:1905438', '28167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28167', '112', '30044', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.71.1905438» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30045', '1079', '1', 'Huyện Lạng Giang', 'VN.71.1905441', 'ASCII:Huyen Lang Giang;ID:1905441', '28168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28168', '112', '30045', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.71.1905441» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30046', '1079', '1', 'Huyện Tân Yên', 'VN.71.1905443', 'ASCII:Huyen Tan Yen;ID:1905443', '28169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28169', '112', '30046', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.71.1905443» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30047', '1079', '1', 'Huyện Hiệp Hòa', 'VN.71.1905444', 'ASCII:Huyen Hiep Hoa;ID:1905444', '28170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28170', '112', '30047', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.71.1905444» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30048', '1079', '1', 'Huyện Yên Thế', 'VN.71.1905445', 'ASCII:Huyen Yen The;ID:1905445', '28171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28171', '112', '30048', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.71.1905445» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30049', '1079', '1', 'Huyện Lục Nam', 'VN.71.1905446', 'ASCII:Huyen Luc Nam;ID:1905446', '28172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28172', '112', '30049', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.71.1905446» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30050', '1079', '1', 'Huyện Lục Ngạn', 'VN.71.1905447', 'ASCII:Huyen Luc Ngan;ID:1905447', '28173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28173', '112', '30050', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.71.1905447» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30051', '1079', '1', 'Huyện Sơn Dộng', 'VN.71.1905448', 'ASCII:Huyen Son Dong;ID:1905448', '28174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28174', '112', '30051', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.71.1905448» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30052', '1079', '1', 'Quận Thanh Khê', 'VN.78.1905469', 'ASCII:Quan Thanh Khe;ID:1905469', '28175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28175', '112', '30052', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.78.1905469» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30053', '1079', '1', 'Quận Sơn Trà', 'VN.78.1905470', 'ASCII:Quan Son Tra;ID:1905470', '28176');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28176', '112', '30053', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.78.1905470» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30054', '1079', '1', 'Quận Ngũ Hành Sơn', 'VN.78.1905471', 'ASCII:Quan Ngu Hanh Son;ID:1905471', '28177');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28177', '112', '30054', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.78.1905471» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30055', '1079', '1', 'Quận Liên Chiểu', 'VN.78.1905472', 'ASCII:Quan Lien Chieu;ID:1905472', '28178');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28178', '112', '30055', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.78.1905472» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30056', '1079', '1', 'Huyện Hòa Vang', 'VN.78.1905473', 'ASCII:Huyen Hoa Vang;ID:1905473', '28179');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28179', '112', '30056', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.78.1905473» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30057', '1079', '1', 'Huyện Hoàng Sa', 'VN.78.1905474', 'ASCII:Huyen Hoang Sa;ID:1905474', '28180');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28180', '112', '30057', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.78.1905474» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30058', '1079', '1', 'Thị Xã Thủ Dầu Một', 'VN.75.1905476', 'ASCII:Thi Xa Thu Dau Mot;ID:1905476', '28181');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28181', '112', '30058', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.75.1905476» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30059', '1079', '1', 'Huyện Thuận an', 'VN.75.1905477', 'ASCII:Huyen Thuan an;ID:1905477', '28182');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28182', '112', '30059', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.75.1905477» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30060', '1079', '1', 'Huyện Tân Uyên', 'VN.75.1905478', 'ASCII:Huyen Tan Uyen;ID:1905478', '28183');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28183', '112', '30060', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.75.1905478» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30061', '1079', '1', 'Huyện Bến Cát', 'VN.75.1905479', 'ASCII:Huyen Ben Cat;ID:1905479', '28184');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28184', '112', '30061', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.75.1905479» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30062', '1079', '1', 'Huyện Ðồng Phu', 'VN.76.1905481', 'ASCII:Huyen Dong Phu;ID:1905481', '28185');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28185', '112', '30062', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.76.1905481» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30063', '1079', '1', 'Huyện Bình Long', 'VN.76.1905482', 'ASCII:Huyen Binh Long;ID:1905482', '28186');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28186', '112', '30063', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.76.1905482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30064', '1079', '1', 'Huyện Lộc Ninh', 'VN.76.1905483', 'ASCII:Huyen Loc Ninh;ID:1905483', '28187');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28187', '112', '30064', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.76.1905483» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30065', '1079', '1', 'Huyện Phơức Long', 'VN.76.1905484', 'ASCII:Huyen Phouc Long;ID:1905484', '28188');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28188', '112', '30065', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.76.1905484» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30066', '1079', '1', 'Huyện Bù Ðăng', 'VN.76.1905485', 'ASCII:Huyen Bu Dang;ID:1905485', '28189');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28189', '112', '30066', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.76.1905485» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30067', '1079', '1', 'Thị Xã Long Xuyên', 'VN.01.1905486', 'ASCII:Thi Xa Long Xuyen;ID:1905486', '28190');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28190', '112', '30067', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905486» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30068', '1079', '1', 'Thị Xã Châu Ðốc', 'VN.01.1905487', 'ASCII:Thi Xa Chau Doc;ID:1905487', '28191');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28191', '112', '30068', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905487» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30069', '1079', '1', 'Huyện Thoại Sơn', 'VN.01.1905488', 'ASCII:Huyen Thoai Son;ID:1905488', '28192');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28192', '112', '30069', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905488» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30070', '1079', '1', 'Huyện Châu Thành', 'VN.01.1905489', 'ASCII:Huyen Chau Thanh;ID:1905489', '28193');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28193', '112', '30070', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905489» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30071', '1079', '1', 'Huyện Chợ Mới', 'VN.01.1905490', 'ASCII:Huyen Cho Moi;ID:1905490', '28194');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28194', '112', '30071', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905490» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30072', '1079', '1', 'Huyện Phú Tân', 'VN.01.1905491', 'ASCII:Huyen Phu Tan;ID:1905491', '28195');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28195', '112', '30072', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905491» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30073', '1079', '1', 'Huyện Châu Phú', 'VN.01.1905492', 'ASCII:Huyen Chau Phu;ID:1905492', '28196');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28196', '112', '30073', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905492» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30074', '1079', '1', 'Huyện Tri Tôn', 'VN.01.1905493', 'ASCII:Huyen Tri Ton;ID:1905493', '28197');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28197', '112', '30074', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905493» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30075', '1079', '1', 'Huyện Tịnh Biên', 'VN.01.1905494', 'ASCII:Huyen Tinh Bien;ID:1905494', '28198');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28198', '112', '30075', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905494» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30076', '1079', '1', 'Huyện Tân Châu', 'VN.01.1905495', 'ASCII:Huyen Tan Chau;ID:1905495', '28199');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28199', '112', '30076', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905495» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30077', '1079', '1', 'Huyện An Phú', 'VN.01.1905496', 'ASCII:Huyen An Phu;ID:1905496', '28200');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28200', '112', '30077', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.01.1905496» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30078', '1079', '1', 'Thị Xã Sông Công', 'VN.85.1905498', 'ASCII:Thi Xa Song Cong;ID:1905498', '28201');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28201', '112', '30078', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.85.1905498» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30079', '1079', '1', 'Huyện Phú Bình', 'VN.85.1905499', 'ASCII:Huyen Phu Binh;ID:1905499', '28202');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28202', '112', '30079', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.85.1905499» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30080', '1079', '1', 'Huyện Phổ Yên', 'VN.85.1905500', 'ASCII:Huyen Pho Yen;ID:1905500', '28203');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28203', '112', '30080', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.85.1905500» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30081', '1079', '1', 'Huyện Ðại Từ', 'VN.85.1905501', 'ASCII:Huyen Dai Tu;ID:1905501', '28204');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28204', '112', '30081', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.85.1905501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30082', '1079', '1', 'Huyện Ðịnh Hóa', 'VN.85.1905502', 'ASCII:Huyen Dinh Hoa;ID:1905502', '28205');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28205', '112', '30082', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.85.1905502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30083', '1079', '1', 'Huyện Phú Lương', 'VN.85.1905503', 'ASCII:Huyen Phu Luong;ID:1905503', '28206');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28206', '112', '30083', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.85.1905503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30084', '1079', '1', 'Huyện Ðồng Hỷ', 'VN.85.1905504', 'ASCII:Huyen Dong Hy;ID:1905504', '28207');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28207', '112', '30084', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.85.1905504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30085', '1079', '1', 'Huyện Võ Nhai', 'VN.85.1905505', 'ASCII:Huyen Vo Nhai;ID:1905505', '28208');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28208', '112', '30085', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.85.1905505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30086', '1079', '1', 'Huyện Hòa An', 'VN.05.1905506', 'ASCII:Huyen Hoa An;ID:1905506', '28209');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28209', '112', '30086', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30087', '1079', '1', 'Huyện Trà Lĩnh', 'VN.05.1905507', 'ASCII:Huyen Tra Linh;ID:1905507', '28210');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28210', '112', '30087', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30088', '1079', '1', 'Huyện Trùng Khánh', 'VN.05.1905508', 'ASCII:Huyen Trung Khanh;ID:1905508', '28211');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28211', '112', '30088', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30089', '1079', '1', 'Huyện Hạ Lang', 'VN.05.1905509', 'ASCII:Huyen Ha Lang;ID:1905509', '28212');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28212', '112', '30089', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30090', '1079', '1', 'Huyện Quảng Hòa', 'VN.05.1905510', 'ASCII:Huyen Quang Hoa;ID:1905510', '28213');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28213', '112', '30090', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30091', '1079', '1', 'Huyện Thạch An', 'VN.05.1905511', 'ASCII:Huyen Thach An;ID:1905511', '28214');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28214', '112', '30091', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30092', '1079', '1', 'Huyện Nguyên Bình', 'VN.05.1905512', 'ASCII:Huyen Nguyen Binh;ID:1905512', '28215');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28215', '112', '30092', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30093', '1079', '1', 'Huyện Thông Nông', 'VN.05.1905513', 'ASCII:Huyen Thong Nong;ID:1905513', '28216');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28216', '112', '30093', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30094', '1079', '1', 'Huyện Hà Quảng', 'VN.05.1905514', 'ASCII:Huyen Ha Quang;ID:1905514', '28217');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28217', '112', '30094', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30095', '1079', '1', 'Huyện Bảo Lac', 'VN.05.1905515', 'ASCII:Huyen Bao Lac;ID:1905515', '28218');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28218', '112', '30095', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30096', '1079', '1', 'Thị Xã Tam Kỳ', 'VN.84.1905517', 'ASCII:Thi Xa Tam Ky;ID:1905517', '28219');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28219', '112', '30096', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30097', '1079', '1', 'Thị Xã Hôi An', 'VN.84.1905518', 'ASCII:Thi Xa Hoi An;ID:1905518', '28220');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28220', '112', '30097', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30098', '1079', '1', 'Huyện Thăng Bình', 'VN.84.1905519', 'ASCII:Huyen Thang Binh;ID:1905519', '28221');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28221', '112', '30098', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30099', '1079', '1', 'Huyện Quế Sơn', 'VN.84.1905520', 'ASCII:Huyen Que Son;ID:1905520', '28222');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28222', '112', '30099', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30100', '1079', '1', 'Huyện Duy Xuyên', 'VN.84.1905521', 'ASCII:Huyen Duy Xuyen;ID:1905521', '28223');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28223', '112', '30100', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30101', '1079', '1', 'Huyện Ðiện Bàn', 'VN.84.1905522', 'ASCII:Huyen Dien Ban;ID:1905522', '28224');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28224', '112', '30101', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30102', '1079', '1', 'Huyện Ðại Lộc', 'VN.84.1905523', 'ASCII:Huyen Dai Loc;ID:1905523', '28225');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28225', '112', '30102', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30103', '1079', '1', 'Huyện Hiên', 'VN.84.1905524', 'ASCII:Huyen Hien;ID:1905524', '28226');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28226', '112', '30103', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905524» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30104', '1079', '1', 'Huyện Giẳng', 'VN.84.1905525', 'ASCII:Huyen Giang;ID:1905525', '28227');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28227', '112', '30104', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905525» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30105', '1079', '1', 'Huyện Phước Sơn', 'VN.84.1905526', 'ASCII:Huyen Phuoc Son;ID:1905526', '28228');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28228', '112', '30105', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905526» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30106', '1079', '1', 'Huyện Hiệp Ðức', 'VN.84.1905527', 'ASCII:Huyen Hiep Duc;ID:1905527', '28229');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28229', '112', '30106', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905527» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30107', '1079', '1', 'Huyện Tiên Phước', 'VN.84.1905528', 'ASCII:Huyen Tien Phuoc;ID:1905528', '28230');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28230', '112', '30107', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905528» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30108', '1079', '1', 'Huyện Núi Thành', 'VN.84.1905529', 'ASCII:Huyen Nui Thanh;ID:1905529', '28231');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28231', '112', '30108', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905529» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30109', '1079', '1', 'Huyện Trà My', 'VN.84.1905530', 'ASCII:Huyen Tra My;ID:1905530', '28232');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28232', '112', '30109', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.84.1905530» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30110', '1079', '1', 'Thị Xã Lạng Sơn', 'VN.39.1905531', 'ASCII:Thi Xa Lang Son;ID:1905531', '28233');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28233', '112', '30110', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905531» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30111', '1079', '1', 'Huyện Văn Lãng', 'VN.39.1905532', 'ASCII:Huyen Van Lang;ID:1905532', '28234');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28234', '112', '30111', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905532» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30112', '1079', '1', 'Huyện Cao Lộc', 'VN.39.1905533', 'ASCII:Huyen Cao Loc;ID:1905533', '28235');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28235', '112', '30112', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905533» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30113', '1079', '1', 'Huyện Vặn Quan', 'VN.39.1905534', 'ASCII:Huyen Van Quan;ID:1905534', '28236');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28236', '112', '30113', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905534» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30114', '1079', '1', 'Huyện Chi Lăng', 'VN.39.1905535', 'ASCII:Huyen Chi Lang;ID:1905535', '28237');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28237', '112', '30114', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905535» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30115', '1079', '1', 'Huyện Lộc Bình', 'VN.39.1905536', 'ASCII:Huyen Loc Binh;ID:1905536', '28238');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28238', '112', '30115', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905536» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30116', '1079', '1', 'Huyện Ðình Lập', 'VN.39.1905537', 'ASCII:Huyen Dinh Lap;ID:1905537', '28239');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28239', '112', '30116', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905537» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30117', '1079', '1', 'Huyện Hũu Lũng', 'VN.39.1905538', 'ASCII:Huyen Huu Lung;ID:1905538', '28240');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28240', '112', '30117', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905538» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30118', '1079', '1', 'Huyện Bắc Sơn', 'VN.39.1905539', 'ASCII:Huyen Bac Son;ID:1905539', '28241');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28241', '112', '30118', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905539» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30119', '1079', '1', 'Huyện Bình Gia', 'VN.39.1905540', 'ASCII:Huyen Binh Gia;ID:1905540', '28242');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28242', '112', '30119', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30120', '1079', '1', 'Huyện Tràng Ðịnh', 'VN.39.1905541', 'ASCII:Huyen Trang Dinh;ID:1905541', '28243');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28243', '112', '30120', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.39.1905541» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30121', '1079', '1', 'Thành Phố Biên Hòa', 'VN.43.1905542', 'ASCII:Thanh Pho Bien Hoa;ID:1905542', '28244');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28244', '112', '30121', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.43.1905542» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30122', '1079', '1', 'Huyện Vĩnh Cửu', 'VN.43.1905543', 'ASCII:Huyen Vinh Cuu;ID:1905543', '28245');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28245', '112', '30122', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.43.1905543» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30123', '1079', '1', 'Huyện Thống Nhất', 'VN.43.1905544', 'ASCII:Huyen Thong Nhat;ID:1905544', '28246');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28246', '112', '30123', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.43.1905544» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30124', '1079', '1', 'Huyện Long Thành', 'VN.43.1905545', 'ASCII:Huyen Long Thanh;ID:1905545', '28247');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28247', '112', '30124', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.43.1905545» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30125', '1079', '1', 'Huyện Nhơn Trạch', 'VN.43.1905546', 'ASCII:Huyen Nhon Trach;ID:1905546', '28248');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28248', '112', '30125', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.43.1905546» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30126', '1079', '1', 'Huyện Long Khánh', 'VN.43.1905547', 'ASCII:Huyen Long Khanh;ID:1905547', '28249');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28249', '112', '30126', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.43.1905547» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30127', '1079', '1', 'Huyện Xuân Lộc', 'VN.43.1905548', 'ASCII:Huyen Xuan Loc;ID:1905548', '28250');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28250', '112', '30127', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.43.1905548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30128', '1079', '1', 'Huyện Ðịnh Quán', 'VN.43.1905549', 'ASCII:Huyen Dinh Quan;ID:1905549', '28251');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28251', '112', '30128', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.43.1905549» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30129', '1079', '1', 'Huyện Tân Phú', 'VN.43.1905550', 'ASCII:Huyen Tan Phu;ID:1905550', '28252');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28252', '112', '30129', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.43.1905550» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30130', '1079', '1', 'Thành Phố Quy Nhơn', 'VN.46.1905551', 'ASCII:Thanh Pho Quy Nhon;ID:1905551', '28253');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28253', '112', '30130', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905551» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30131', '1079', '1', 'Huyện Tuy Phước', 'VN.46.1905552', 'ASCII:Huyen Tuy Phuoc;ID:1905552', '28254');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28254', '112', '30131', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905552» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30132', '1079', '1', 'Huyện An Nhơn', 'VN.46.1905553', 'ASCII:Huyen An Nhon;ID:1905553', '28255');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28255', '112', '30132', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30133', '1079', '1', 'Huyện Vân Canh', 'VN.46.1905554', 'ASCII:Huyen Van Canh;ID:1905554', '28256');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28256', '112', '30133', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905554» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30134', '1079', '1', 'Huyện Tây Sơn', 'VN.46.1905555', 'ASCII:Huyen Tay Son;ID:1905555', '28257');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28257', '112', '30134', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905555» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30135', '1079', '1', 'Huyện Phù Cát', 'VN.46.1905556', 'ASCII:Huyen Phu Cat;ID:1905556', '28258');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28258', '112', '30135', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905556» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30136', '1079', '1', 'Huyện Phù Mỹ', 'VN.46.1905557', 'ASCII:Huyen Phu My;ID:1905557', '28259');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28259', '112', '30136', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905557» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30137', '1079', '1', 'Huyện Hoài Nhơn', 'VN.46.1905558', 'ASCII:Huyen Hoai Nhon;ID:1905558', '28260');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28260', '112', '30137', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905558» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30138', '1079', '1', 'Huyện Vĩnh Thạnh', 'VN.46.1905559', 'ASCII:Huyen Vinh Thanh;ID:1905559', '28261');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28261', '112', '30138', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905559» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30139', '1079', '1', 'Huyện Hoài Ân', 'VN.46.1905560', 'ASCII:Huyen Hoai An;ID:1905560', '28262');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28262', '112', '30139', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905560» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30140', '1079', '1', 'Huyện An Lão', 'VN.46.1905561', 'ASCII:Huyen An Lao;ID:1905561', '28263');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28263', '112', '30140', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.46.1905561» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30141', '1079', '1', 'Thị Xã Phan Thiết', 'VN.47.1905562', 'ASCII:Thi Xa Phan Thiet;ID:1905562', '28264');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28264', '112', '30141', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.47.1905562» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30142', '1079', '1', 'Huyện Hàm Thuận Nam', 'VN.47.1905563', 'ASCII:Huyen Ham Thuan Nam;ID:1905563', '28265');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28265', '112', '30142', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.47.1905563» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30143', '1079', '1', 'Huyện Hàm Thuận Bắc', 'VN.47.1905564', 'ASCII:Huyen Ham Thuan Bac;ID:1905564', '28266');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28266', '112', '30143', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.47.1905564» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30144', '1079', '1', 'Huyện Bắc Bình', 'VN.47.1905565', 'ASCII:Huyen Bac Binh;ID:1905565', '28267');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28267', '112', '30144', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.47.1905565» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30145', '1079', '1', 'Huyện Tuy Phong', 'VN.47.1905566', 'ASCII:Huyen Tuy Phong;ID:1905566', '28268');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28268', '112', '30145', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.47.1905566» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30146', '1079', '1', 'Huyện Hàm Tân', 'VN.47.1905567', 'ASCII:Huyen Ham Tan;ID:1905567', '28269');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28269', '112', '30146', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.47.1905567» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30147', '1079', '1', 'Huyện Tánh Linh', 'VN.47.1905568', 'ASCII:Huyen Tanh Linh;ID:1905568', '28270');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28270', '112', '30147', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.47.1905568» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30148', '1079', '1', 'Huyện Ðức Linh', 'VN.47.1905569', 'ASCII:Huyen Duc Linh;ID:1905569', '28271');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28271', '112', '30148', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.47.1905569» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30149', '1079', '1', 'Huyện Phú Quý', 'VN.47.1905570', 'ASCII:Huyen Phu Quy;ID:1905570', '28272');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28272', '112', '30149', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.47.1905570» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30150', '1079', '1', 'Thị xã Vĩnh Yên', 'VN.86.1905571', 'ASCII:Thi xa Vinh Yen;ID:1905571', '28273');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28273', '112', '30150', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.86.1905571» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30151', '1079', '1', 'Huyện Tam Ðảo', 'VN.86.1905572', 'ASCII:Huyen Tam Dao;ID:1905572', '28274');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28274', '112', '30151', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.86.1905572» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30152', '1079', '1', 'Huyện Mẻ Linh', 'VN.86.1905573', 'ASCII:Huyen Me Linh;ID:1905573', '28275');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28275', '112', '30152', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.86.1905573» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30153', '1079', '1', 'Huyện Yên Lạc', 'VN.86.1905574', 'ASCII:Huyen Yen Lac;ID:1905574', '28276');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28276', '112', '30153', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.86.1905574» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30154', '1079', '1', 'Huyện Vĩnh Tường', 'VN.86.1905575', 'ASCII:Huyen Vinh Tuong;ID:1905575', '28277');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28277', '112', '30154', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.86.1905575» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30155', '1079', '1', 'Huyện Lập Thạch', 'VN.86.1905576', 'ASCII:Huyen Lap Thach;ID:1905576', '28278');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28278', '112', '30155', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.86.1905576» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30156', '1079', '1', 'Thành phố Việt Trì', 'VN.83.1905578', 'ASCII:Thanh pho Viet Tri;ID:1905578', '28279');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28279', '112', '30156', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.83.1905578» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30157', '1079', '1', 'Thị xã Phú Thọ', 'VN.83.1905579', 'ASCII:Thi xa Phu Tho;ID:1905579', '28280');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28280', '112', '30157', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.83.1905579» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30158', '1079', '1', 'Huyện Phong Châu', 'VN.83.1905580', 'ASCII:Huyen Phong Chau;ID:1905580', '28281');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28281', '112', '30158', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.83.1905580» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30159', '1079', '1', 'Huyện Thanh Ba', 'VN.83.1905581', 'ASCII:Huyen Thanh Ba;ID:1905581', '28282');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28282', '112', '30159', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.83.1905581» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30160', '1079', '1', 'Huyện Sông Thao', 'VN.83.1905582', 'ASCII:Huyen Song Thao;ID:1905582', '28283');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28283', '112', '30160', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.83.1905582» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30161', '1079', '1', 'Huyện Tam Thanh', 'VN.83.1905583', 'ASCII:Huyen Tam Thanh;ID:1905583', '28284');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28284', '112', '30161', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.83.1905583» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30162', '1079', '1', 'Huyện Thanh Sơn', 'VN.83.1905584', 'ASCII:Huyen Thanh Son;ID:1905584', '28285');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28285', '112', '30162', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.83.1905584» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30163', '1079', '1', 'Huyện Yên Lâp', 'VN.83.1905585', 'ASCII:Huyen Yen Lap;ID:1905585', '28286');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28286', '112', '30163', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.83.1905585» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30164', '1079', '1', 'Huyện Ha Hòa', 'VN.83.1905586', 'ASCII:Huyen Ha Hoa;ID:1905586', '28287');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28287', '112', '30164', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.83.1905586» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30165', '1079', '1', 'Huyện Ðoan Hùng', 'VN.83.1905587', 'ASCII:Huyen Doan Hung;ID:1905587', '28288');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28288', '112', '30165', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.83.1905587» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30166', '1079', '1', 'Thị Xã Hà Tĩnh', 'VN.52.1905588', 'ASCII:Thi Xa Ha Tinh;ID:1905588', '28289');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28289', '112', '30166', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.52.1905588» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30167', '1079', '1', 'Huyện Cẩm Xuyên', 'VN.52.1905589', 'ASCII:Huyen Cam Xuyen;ID:1905589', '28290');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28290', '112', '30167', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.52.1905589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30168', '1079', '1', 'Huyện Kỳ Anh', 'VN.52.1905590', 'ASCII:Huyen Ky Anh;ID:1905590', '28291');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28291', '112', '30168', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.52.1905590» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30169', '1079', '1', 'Huyện Hương Khê', 'VN.52.1905591', 'ASCII:Huyen Huong Khe;ID:1905591', '28292');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28292', '112', '30169', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.52.1905591» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30170', '1079', '1', 'Huyện Thạch Hà', 'VN.52.1905592', 'ASCII:Huyen Thach Ha;ID:1905592', '28293');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28293', '112', '30170', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.52.1905592» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30171', '1079', '1', 'Huyện Can Lộc', 'VN.52.1905593', 'ASCII:Huyen Can Loc;ID:1905593', '28294');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28294', '112', '30171', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.52.1905593» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30172', '1079', '1', 'Huyện Nghi Xuân', 'VN.52.1905594', 'ASCII:Huyen Nghi Xuan;ID:1905594', '28295');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28295', '112', '30172', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.52.1905594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30173', '1079', '1', 'Thị Xã Hồng Lĩnh', 'VN.52.1905595', 'ASCII:Thi Xa Hong Linh;ID:1905595', '28296');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28296', '112', '30173', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.52.1905595» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30174', '1079', '1', 'Huyện Ðức Thọ', 'VN.52.1905596', 'ASCII:Huyen Duc Tho;ID:1905596', '28297');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28297', '112', '30174', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.52.1905596» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30175', '1079', '1', 'Huyện Hương Sơn', 'VN.52.1905597', 'ASCII:Huyen Huong Son;ID:1905597', '28298');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28298', '112', '30175', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.52.1905597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30176', '1079', '1', 'Thành Phố Nha Trang', 'VN.54.1905598', 'ASCII:Thanh Pho Nha Trang;ID:1905598', '28299');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28299', '112', '30176', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.54.1905598» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30177', '1079', '1', 'Huyện Diên Khánh', 'VN.54.1905599', 'ASCII:Huyen Dien Khanh;ID:1905599', '28300');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28300', '112', '30177', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.54.1905599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30178', '1079', '1', 'Huyện Cam Ranch', 'VN.54.1905600', 'ASCII:Huyen Cam Ranch;ID:1905600', '28301');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28301', '112', '30178', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.54.1905600» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30179', '1079', '1', 'Huyện Khánh Sơn', 'VN.54.1905601', 'ASCII:Huyen Khanh Son;ID:1905601', '28302');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28302', '112', '30179', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.54.1905601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30180', '1079', '1', 'Huyện Khánh Vĩnh', 'VN.54.1905602', 'ASCII:Huyen Khanh Vinh;ID:1905602', '28303');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28303', '112', '30180', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.54.1905602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30181', '1079', '1', 'Huyện Ninh Hòa', 'VN.54.1905603', 'ASCII:Huyen Ninh Hoa;ID:1905603', '28304');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28304', '112', '30181', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.54.1905603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30182', '1079', '1', 'Huyện Vạn Ninh', 'VN.54.1905604', 'ASCII:Huyen Van Ninh;ID:1905604', '28305');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28305', '112', '30182', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.54.1905604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30183', '1079', '1', 'Huyện Trường Sa', 'VN.54.1905605', 'ASCII:Huyen Truong Sa;ID:1905605', '28306');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28306', '112', '30183', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.54.1905605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30184', '1079', '1', 'Thị Xã Kon Tum', 'VN.55.1905606', 'ASCII:Thi Xa Kon Tum;ID:1905606', '28307');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28307', '112', '30184', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.55.1905606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30185', '1079', '1', 'Huyện Ðắk Hà', 'VN.55.1905607', 'ASCII:Huyen Dak Ha;ID:1905607', '28308');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28308', '112', '30185', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.55.1905607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30186', '1079', '1', 'Huyện Kon Plông', 'VN.55.1905608', 'ASCII:Huyen Kon Plong;ID:1905608', '28309');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28309', '112', '30186', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.55.1905608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30187', '1079', '1', 'Huyện Ðắk Tô', 'VN.55.1905609', 'ASCII:Huyen Dak To;ID:1905609', '28310');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28310', '112', '30187', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.55.1905609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30188', '1079', '1', 'Huyện Sa Thầy', 'VN.55.1905610', 'ASCII:Huyen Sa Thay;ID:1905610', '28311');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28311', '112', '30188', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.55.1905610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30189', '1079', '1', 'Huyện Ngọc Hồi', 'VN.55.1905611', 'ASCII:Huyen Ngoc Hoi;ID:1905611', '28312');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28312', '112', '30189', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.55.1905611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30190', '1079', '1', 'Huyện Ðắk Glei', 'VN.55.1905612', 'ASCII:Huyen Dak Glei;ID:1905612', '28313');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28313', '112', '30190', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.55.1905612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30191', '1079', '1', 'Thị Xã Quảng Ngãi', 'VN.63.1905613', 'ASCII:Thi Xa Quang Ngai;ID:1905613', '28314');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28314', '112', '30191', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30192', '1079', '1', 'Huyện Tư Nghĩa', 'VN.63.1905614', 'ASCII:Huyen Tu Nghia;ID:1905614', '28315');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28315', '112', '30192', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30193', '1079', '1', 'Huyện Sơn Tịnh', 'VN.63.1905615', 'ASCII:Huyen Son Tinh;ID:1905615', '28316');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28316', '112', '30193', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905615» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30194', '1079', '1', 'Huyện Bình Sơn', 'VN.63.1905616', 'ASCII:Huyen Binh Son;ID:1905616', '28317');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28317', '112', '30194', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30195', '1079', '1', 'Huyện Trà Bồng', 'VN.63.1905617', 'ASCII:Huyen Tra Bong;ID:1905617', '28318');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28318', '112', '30195', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905617» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30196', '1079', '1', 'Huyện Sơn Tây', 'VN.63.1905618', 'ASCII:Huyen Son Tay;ID:1905618', '28319');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28319', '112', '30196', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905618» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30197', '1079', '1', 'Huyện Sơn Hà', 'VN.63.1905619', 'ASCII:Huyen Son Ha;ID:1905619', '28320');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28320', '112', '30197', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905619» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30198', '1079', '1', 'Huyện Minh Long', 'VN.63.1905620', 'ASCII:Huyen Minh Long;ID:1905620', '28321');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28321', '112', '30198', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905620» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30199', '1079', '1', 'Huyện Nghĩa Hành', 'VN.63.1905621', 'ASCII:Huyen Nghia Hanh;ID:1905621', '28322');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28322', '112', '30199', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905621» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30200', '1079', '1', 'Huyện Mộ Ðức', 'VN.63.1905622', 'ASCII:Huyen Mo Duc;ID:1905622', '28323');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28323', '112', '30200', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905622» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30201', '1079', '1', 'Huyện Ba Tơ', 'VN.63.1905623', 'ASCII:Huyen Ba To;ID:1905623', '28324');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28324', '112', '30201', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30202', '1079', '1', 'Huyện Ðức Phổ', 'VN.63.1905624', 'ASCII:Huyen Duc Pho;ID:1905624', '28325');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28325', '112', '30202', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905624» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30203', '1079', '1', 'Huyện Lý Sơn', 'VN.63.1905625', 'ASCII:Huyen Ly Son;ID:1905625', '28326');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28326', '112', '30203', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.63.1905625» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30204', '1079', '1', 'Thành phố Nam Ðịnh', 'VN.82.1905627', 'ASCII:Thanh pho Nam Dinh;ID:1905627', '28327');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28327', '112', '30204', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.82.1905627» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30205', '1079', '1', 'Huyện Mỹ Lộc', 'VN.82.1905628', 'ASCII:Huyen My Loc;ID:1905628', '28328');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28328', '112', '30205', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.82.1905628» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30206', '1079', '1', 'Huyện Vụ Bản', 'VN.82.1905629', 'ASCII:Huyen Vu Ban;ID:1905629', '28329');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28329', '112', '30206', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.82.1905629» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30207', '1079', '1', 'Huyện Ý Yên', 'VN.82.1905630', 'ASCII:Huyen Y Yen;ID:1905630', '28330');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28330', '112', '30207', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.82.1905630» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30208', '1079', '1', 'Huyện Nam Trực', 'VN.82.1905631', 'ASCII:Huyen Nam Truc;ID:1905631', '28331');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28331', '112', '30208', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.82.1905631» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30209', '1079', '1', 'Huyện Trực Ninh', 'VN.82.1905632', 'ASCII:Huyen Truc Ninh;ID:1905632', '28332');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28332', '112', '30209', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.82.1905632» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30210', '1079', '1', 'Huyện Xuân Trường', 'VN.82.1905633', 'ASCII:Huyen Xuan Truong;ID:1905633', '28333');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28333', '112', '30210', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.82.1905633» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30211', '1079', '1', 'Huyện Giao Thủy', 'VN.82.1905634', 'ASCII:Huyen Giao Thuy;ID:1905634', '28334');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28334', '112', '30211', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.82.1905634» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30212', '1079', '1', 'Huyện Hải Hậu', 'VN.82.1905635', 'ASCII:Huyen Hai Hau;ID:1905635', '28335');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28335', '112', '30212', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.82.1905635» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30213', '1079', '1', 'Huyện Nghĩa Hưng', 'VN.82.1905636', 'ASCII:Huyen Nghia Hung;ID:1905636', '28336');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28336', '112', '30213', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.82.1905636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30214', '1079', '1', 'Thị xã Phủ Lý', 'VN.80.1905638', 'ASCII:Thi xa Phu Ly;ID:1905638', '28337');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28337', '112', '30214', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.80.1905638» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30215', '1079', '1', 'Huyện Duy Tiên', 'VN.80.1905639', 'ASCII:Huyen Duy Tien;ID:1905639', '28338');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28338', '112', '30215', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.80.1905639» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30216', '1079', '1', 'Huyện Kim Bảng', 'VN.80.1905640', 'ASCII:Huyen Kim Bang;ID:1905640', '28339');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28339', '112', '30216', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.80.1905640» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30217', '1079', '1', 'Huyện Thanh Liêm', 'VN.80.1905641', 'ASCII:Huyen Thanh Liem;ID:1905641', '28340');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28340', '112', '30217', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.80.1905641» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30218', '1079', '1', 'Huyện Bình Lục', 'VN.80.1905642', 'ASCII:Huyen Binh Luc;ID:1905642', '28341');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28341', '112', '30218', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.80.1905642» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30219', '1079', '1', 'Huyện Lý Lhân', 'VN.80.1905643', 'ASCII:Huyen Ly Lhan;ID:1905643', '28342');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28342', '112', '30219', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.80.1905643» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30220', '1079', '1', 'Thành Phố Huế', 'VN.66.1905644', 'ASCII:Thanh Pho Hue;ID:1905644', '28343');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28343', '112', '30220', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.66.1905644» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30221', '1079', '1', 'Huyện Hương Thủy', 'VN.66.1905645', 'ASCII:Huyen Huong Thuy;ID:1905645', '28344');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28344', '112', '30221', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.66.1905645» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30222', '1079', '1', 'Huyện Phú Vang', 'VN.66.1905646', 'ASCII:Huyen Phu Vang;ID:1905646', '28345');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28345', '112', '30222', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.66.1905646» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30223', '1079', '1', 'Huyện Quảng Ðiền', 'VN.66.1905647', 'ASCII:Huyen Quang Dien;ID:1905647', '28346');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28346', '112', '30223', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.66.1905647» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30224', '1079', '1', 'Huyện Phong Ðiền', 'VN.66.1905648', 'ASCII:Huyen Phong Dien;ID:1905648', '28347');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28347', '112', '30224', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.66.1905648» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30225', '1079', '1', 'Huyện Hương Trà', 'VN.66.1905649', 'ASCII:Huyen Huong Tra;ID:1905649', '28348');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28348', '112', '30225', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.66.1905649» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30226', '1079', '1', 'Huyện A Lưới', 'VN.66.1905650', 'ASCII:Huyen A Luoi;ID:1905650', '28349');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28349', '112', '30226', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.66.1905650» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30227', '1079', '1', 'Huyện Nam Ðông', 'VN.66.1905651', 'ASCII:Huyen Nam Dong;ID:1905651', '28350');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28350', '112', '30227', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.66.1905651» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30228', '1079', '1', 'Huyện Phú Lộc', 'VN.66.1905652', 'ASCII:Huyen Phu Loc;ID:1905652', '28351');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28351', '112', '30228', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.66.1905652» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30229', '1079', '1', 'Thị Xã Tuy Hòa', 'VN.61.1905653', 'ASCII:Thi Xa Tuy Hoa;ID:1905653', '28352');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28352', '112', '30229', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.61.1905653» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30230', '1079', '1', 'Huyện Tuy Hòa', 'VN.61.1905654', 'ASCII:Huyen Tuy Hoa;ID:1905654', '28353');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28353', '112', '30230', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.61.1905654» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30231', '1079', '1', 'Huyện Sông Hinh', 'VN.61.1905655', 'ASCII:Huyen Song Hinh;ID:1905655', '28354');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28354', '112', '30231', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.61.1905655» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30232', '1079', '1', 'Huyện Sơn Hòa', 'VN.61.1905656', 'ASCII:Huyen Son Hoa;ID:1905656', '28355');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28355', '112', '30232', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.61.1905656» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30233', '1079', '1', 'Huyện Tuy An', 'VN.61.1905657', 'ASCII:Huyen Tuy An;ID:1905657', '28356');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28356', '112', '30233', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.61.1905657» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30234', '1079', '1', 'Huyện Sông Cầu', 'VN.61.1905658', 'ASCII:Huyen Song Cau;ID:1905658', '28357');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28357', '112', '30234', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.61.1905658» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30235', '1079', '1', 'Huyện Ðồng Xuân', 'VN.61.1905659', 'ASCII:Huyen Dong Xuan;ID:1905659', '28358');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28358', '112', '30235', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.61.1905659» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30236', '1079', '1', 'Thị Xã Yên Bái', 'VN.70.1905660', 'ASCII:Thi Xa Yen Bai;ID:1905660', '28359');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28359', '112', '30236', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.70.1905660» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30237', '1079', '1', 'Thị Xã Nghĩa Lộ', 'VN.70.1905661', 'ASCII:Thi Xa Nghia Lo;ID:1905661', '28360');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28360', '112', '30237', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.70.1905661» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30238', '1079', '1', 'Huyện Trấn Yên', 'VN.70.1905662', 'ASCII:Huyen Tran Yen;ID:1905662', '28361');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28361', '112', '30238', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.70.1905662» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30239', '1079', '1', 'Huyện Văn Chấn', 'VN.70.1905663', 'ASCII:Huyen Van Chan;ID:1905663', '28362');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28362', '112', '30239', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.70.1905663» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30240', '1079', '1', 'Huyện Yên Bình', 'VN.70.1905664', 'ASCII:Huyen Yen Binh;ID:1905664', '28363');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28363', '112', '30240', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.70.1905664» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30241', '1079', '1', 'Huyện Văn Yên', 'VN.70.1905665', 'ASCII:Huyen Van Yen;ID:1905665', '28364');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28364', '112', '30241', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.70.1905665» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30242', '1079', '1', 'Huyện Lục Yên', 'VN.70.1905666', 'ASCII:Huyen Luc Yen;ID:1905666', '28365');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28365', '112', '30242', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.70.1905666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30243', '1079', '1', 'Huyện Trạm Tấu', 'VN.70.1905667', 'ASCII:Huyen Tram Tau;ID:1905667', '28366');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28366', '112', '30243', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.70.1905667» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30244', '1079', '1', 'Huyện Mù Căng Chải', 'VN.70.1905668', 'ASCII:Huyen Mu Cang Chai;ID:1905668', '28367');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28367', '112', '30244', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.70.1905668» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30245', '1079', '1', 'Huyện Bạch Thông', 'VN.72.1905670', 'ASCII:Huyen Bach Thong;ID:1905670', '28368');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28368', '112', '30245', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.72.1905670» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30246', '1079', '1', 'Huyện Chợ Ðồn', 'VN.72.1905671', 'ASCII:Huyen Cho Don;ID:1905671', '28369');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28369', '112', '30246', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.72.1905671» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30247', '1079', '1', 'Huyện Ba Bể', 'VN.72.1905672', 'ASCII:Huyen Ba Be;ID:1905672', '28370');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28370', '112', '30247', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.72.1905672» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30248', '1079', '1', 'Huyện Ngân Sơn', 'VN.72.1905673', 'ASCII:Huyen Ngan Son;ID:1905673', '28371');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28371', '112', '30248', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.72.1905673» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30249', '1079', '1', 'Huyện Na Rì', 'VN.72.1905674', 'ASCII:Huyen Na Ri;ID:1905674', '28372');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28372', '112', '30249', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.72.1905674» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30250', '1079', '1', 'Huyện Giá Rai', 'VN.73.1905676', 'ASCII:Huyen Gia Rai;ID:1905676', '28373');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28373', '112', '30250', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.73.1905676» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30251', '1079', '1', 'Huyện Hồng Dân', 'VN.73.1905677', 'ASCII:Huyen Hong Dan;ID:1905677', '28374');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28374', '112', '30251', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.73.1905677» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30252', '1079', '1', 'Thị Xã Cà Ma', 'VN.77.1905679', 'ASCII:Thi Xa Ca Ma;ID:1905679', '28375');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28375', '112', '30252', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.77.1905679» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30253', '1079', '1', 'Huyện Thới Bình', 'VN.77.1905680', 'ASCII:Huyen Thoi Binh;ID:1905680', '28376');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28376', '112', '30253', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.77.1905680» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30254', '1079', '1', 'Huyện U Minh', 'VN.77.1905681', 'ASCII:Huyen U Minh;ID:1905681', '28377');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28377', '112', '30254', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.77.1905681» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30255', '1079', '1', 'Huyện Trần Văn Thời', 'VN.77.1905682', 'ASCII:Huyen Tran Van Thoi;ID:1905682', '28378');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28378', '112', '30255', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.77.1905682» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30256', '1079', '1', 'Huyện Cái Nước', 'VN.77.1905683', 'ASCII:Huyen Cai Nuoc;ID:1905683', '28379');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28379', '112', '30256', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.77.1905683» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30257', '1079', '1', 'Huyện Ðầm Dơi', 'VN.77.1905684', 'ASCII:Huyen Dam Doi;ID:1905684', '28380');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28380', '112', '30257', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.77.1905684» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30258', '1079', '1', 'Huyện Ngọc Hiển', 'VN.77.1905685', 'ASCII:Huyen Ngoc Hien;ID:1905685', '28381');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28381', '112', '30258', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.77.1905685» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30259', '1079', '1', 'Thị Xã Hải Dương', 'VN.79.1905687', 'ASCII:Thi Xa Hai Duong;ID:1905687', '28382');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28382', '112', '30259', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905687» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30260', '1079', '1', 'Huyện Cẩm Giàng', 'VN.79.1905688', 'ASCII:Huyen Cam Giang;ID:1905688', '28383');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28383', '112', '30260', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905688» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30261', '1079', '1', 'Huyện Bình Giang', 'VN.79.1905689', 'ASCII:Huyen Binh Giang;ID:1905689', '28384');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28384', '112', '30261', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905689» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30262', '1079', '1', 'Huyện Gia Lộc', 'VN.79.1905690', 'ASCII:Huyen Gia Loc;ID:1905690', '28385');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28385', '112', '30262', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905690» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30263', '1079', '1', 'Huyện Thanh Miện', 'VN.79.1905691', 'ASCII:Huyen Thanh Mien;ID:1905691', '28386');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28386', '112', '30263', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905691» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30264', '1079', '1', 'Huyện Minh Giang', 'VN.79.1905692', 'ASCII:Huyen Minh Giang;ID:1905692', '28387');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28387', '112', '30264', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905692» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30265', '1079', '1', 'Huyện Tứ Kỳ', 'VN.79.1905693', 'ASCII:Huyen Tu Ky;ID:1905693', '28388');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28388', '112', '30265', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905693» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30266', '1079', '1', 'Huyện Thanh Hà', 'VN.79.1905694', 'ASCII:Huyen Thanh Ha;ID:1905694', '28389');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28389', '112', '30266', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905694» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30267', '1079', '1', 'Huyện Kim Thành', 'VN.79.1905695', 'ASCII:Huyen Kim Thanh;ID:1905695', '28390');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28390', '112', '30267', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905695» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30268', '1079', '1', 'Huyện Nam Sách', 'VN.79.1905696', 'ASCII:Huyen Nam Sach;ID:1905696', '28391');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28391', '112', '30268', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905696» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30269', '1079', '1', 'Huyện Kinh Môn', 'VN.79.1905697', 'ASCII:Huyen Kinh Mon;ID:1905697', '28392');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28392', '112', '30269', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905697» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30270', '1079', '1', 'Huyện Chí Linh', 'VN.79.1905698', 'ASCII:Huyen Chi Linh;ID:1905698', '28393');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28393', '112', '30270', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.79.1905698» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30271', '1079', '1', 'Huyện TIên Lữ', 'VN.81.1905700', 'ASCII:Huyen TIen Lu;ID:1905700', '28394');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28394', '112', '30271', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.81.1905700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30272', '1079', '1', 'Huyện Kim Ðông', 'VN.81.1905701', 'ASCII:Huyen Kim Dong;ID:1905701', '28395');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28395', '112', '30272', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.81.1905701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30273', '1079', '1', 'Huyện Phù Cừ', 'VN.81.1905702', 'ASCII:Huyen Phu Cu;ID:1905702', '28396');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28396', '112', '30273', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.81.1905702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30274', '1079', '1', 'Huyện Ân Thi', 'VN.81.1905703', 'ASCII:Huyen An Thi;ID:1905703', '28397');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28397', '112', '30274', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.81.1905703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30275', '1079', '1', 'Huyện Châu Giang', 'VN.81.1905704', 'ASCII:Huyen Chau Giang;ID:1905704', '28398');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28398', '112', '30275', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.81.1905704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30276', '1079', '1', 'Huyện Mỹ Văn', 'VN.81.1905705', 'ASCII:Huyen My Van;ID:1905705', '28399');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28399', '112', '30276', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.81.1905705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30277', '1079', '1', 'Thị Xã Hưng Yên', 'VN.81.1905854', 'ASCII:Thi Xa Hung Yen;ID:1905854', '28400');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28400', '112', '30277', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.81.1905854» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30278', '1079', '1', 'Thành Phố Thái Nguyên', 'VN.85.1905855', 'ASCII:Thanh Pho Thai Nguyen;ID:1905855', '28401');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28401', '112', '30278', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.85.1905855» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30279', '1079', '1', 'Thị Xã Cao Bằng', 'VN.05.1905857', 'ASCII:Thi Xa Cao Bang;ID:1905857', '28402');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28402', '112', '30279', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.05.1905857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30280', '1079', '1', 'Quận Hồng Bàng', 'VN.13.1905858', 'ASCII:Quan Hong Bang;ID:1905858', '28403');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28403', '112', '30280', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.13.1905858» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30281', '1079', '1', 'Thị Xã Tuyên Quang', 'VN.68.1905859', 'ASCII:Thi Xa Tuyen Quang;ID:1905859', '28404');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28404', '112', '30281', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.68.1905859» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30282', '1079', '1', 'Huyện Sơn Dương', 'VN.68.1905860', 'ASCII:Huyen Son Duong;ID:1905860', '28405');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28405', '112', '30282', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.68.1905860» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30283', '1079', '1', 'Huyện Yên Sơn', 'VN.68.1905861', 'ASCII:Huyen Yen Son;ID:1905861', '28406');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28406', '112', '30283', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.68.1905861» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30284', '1079', '1', 'Huyện Hàm Yên', 'VN.68.1905862', 'ASCII:Huyen Ham Yen;ID:1905862', '28407');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28407', '112', '30284', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.68.1905862» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30285', '1079', '1', 'Huyện Chiêm Hóa', 'VN.68.1905863', 'ASCII:Huyen Chiem Hoa;ID:1905863', '28408');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28408', '112', '30285', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.68.1905863» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30286', '1079', '1', 'Huyện Na Hang', 'VN.68.1905864', 'ASCII:Huyen Na Hang;ID:1905864', '28409');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28409', '112', '30286', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.68.1905864» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30287', '1079', '1', 'Thị Xã Bắc Giang', 'VN.71.1905865', 'ASCII:Thi Xa Bac Giang;ID:1905865', '28410');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28410', '112', '30287', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.71.1905865» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30288', '1079', '1', 'Thị Xã Bắc Kạn', 'VN.72.1905866', 'ASCII:Thi Xa Bac Kan;ID:1905866', '28411');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28411', '112', '30288', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.72.1905866» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30289', '1079', '1', 'Thị Xã Bạc Liêu', 'VN.73.1905867', 'ASCII:Thi Xa Bac Lieu;ID:1905867', '28412');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28412', '112', '30289', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.73.1905867» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30290', '1079', '1', 'Quận Hải Châu', 'VN.78.1905868', 'ASCII:Quan Hai Chau;ID:1905868', '28413');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28413', '112', '30290', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.78.1905868» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30291', '1079', '1', 'Huyện Lắk', 'VN.07.2591717', 'ASCII:Huyen Lak;ID:2591717', '28414');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28414', '112', '30291', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30292', '1079', '1', 'Huyện Ðắk Mil', 'VN.07.2591718', 'ASCII:Huyen Dak Mil;ID:2591718', '28415');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28415', '112', '30292', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30293', '1079', '1', 'Huyện Krông Ana', 'VN.07.2591721', 'ASCII:Huyen Krong Ana;ID:2591721', '28416');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28416', '112', '30293', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30294', '1079', '1', 'Huyện Krông Bông', 'VN.07.2591722', 'ASCII:Huyen Krong Bong;ID:2591722', '28417');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28417', '112', '30294', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30295', '1079', '1', 'Huyện Krông Pắk', 'VN.07.2591723', 'ASCII:Huyen Krong Pak;ID:2591723', '28418');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28418', '112', '30295', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30296', '1079', '1', 'Huyện Ea Kar', 'VN.07.2591724', 'ASCII:Huyen Ea Kar;ID:2591724', '28419');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28419', '112', '30296', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30297', '1079', '1', 'Huyện M''Ðrắk', 'VN.07.2591725', 'ASCII:Huyen M''Drak;ID:2591725', '28420');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28420', '112', '30297', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30298', '1079', '1', 'Huyện Cư M''Gar', 'VN.07.2591727', 'ASCII:Huyen Cu M''Gar;ID:2591727', '28421');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28421', '112', '30298', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591727» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30299', '1079', '1', 'Huyện Krông Búk', 'VN.07.2591728', 'ASCII:Huyen Krong Buk;ID:2591728', '28422');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28422', '112', '30299', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30300', '1079', '1', 'Huyện Krông Năng', 'VN.07.2591729', 'ASCII:Huyen Krong Nang;ID:2591729', '28423');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28423', '112', '30300', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30301', '1079', '1', 'Huyện Ea H''Leo', 'VN.07.2591730', 'ASCII:Huyen Ea H''Leo;ID:2591730', '28424');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28424', '112', '30301', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30302', '1079', '1', 'Huyện Cư Jút', 'VN.07.2591731', 'ASCII:Huyen Cu Jut;ID:2591731', '28425');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28425', '112', '30302', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «VN.07.2591731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30303', '1079', '1', 'Circonscription d'' Uvéa', 'WF.00.4034759', 'ASCII:Circonscription d'' Uvea;ID:4034759', '28426');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28426', '112', '30303', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «WF.00.4034759» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30304', '1079', '1', 'Circonscription de Sigavé', 'WF.00.4034776', 'ASCII:Circonscription de Sigave;ID:4034776', '28427');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28427', '112', '30304', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «WF.00.4034776» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30305', '1079', '1', 'Az Zaydiyah', 'YE.08.1807', 'ASCII:Az Zaydiyah;ID:69440', '28428');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28428', '112', '30305', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30306', '1079', '1', 'Zabid', 'YE.08.1824', 'ASCII:Zabid;ID:69499', '28429');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28429', '112', '30306', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1824» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30307', '1079', '1', 'Yarim', 'YE.23.1102', 'ASCII:Yarim;ID:69558', '28430');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28430', '112', '30307', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30308', '1079', '1', 'Washhah', 'YE.22.1730', 'ASCII:Washhah;ID:69639', '28431');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28431', '112', '30308', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1730» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30309', '1079', '1', 'Al Udayn', 'YE.23.1111', 'ASCII:Al Udayn;ID:69921', '28432');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28432', '112', '30309', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30310', '1079', '1', 'At Tawilah', 'YE.10.2702', 'ASCII:At Tawilah;ID:70135', '28433');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28433', '112', '30310', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.10.2702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30311', '1079', '1', 'At Ta''iziyah', 'YE.25.1502', 'ASCII:At Ta''iziyah;ID:70221', '28434');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28434', '112', '30311', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30312', '1079', '1', 'Ash Sharyah', 'YE.20.1419', 'ASCII:Ash Sharyah;ID:70825', '28435');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28435', '112', '30312', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1419» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30313', '1079', '1', 'Shaharah', 'YE.19.2905', 'ASCII:Shaharah;ID:70908', '28436');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28436', '112', '30313', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30314', '1079', '1', 'Sanhan', 'YE.16.2305', 'ASCII:Sanhan;ID:71131', '28437');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28437', '112', '30314', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30315', '1079', '1', 'Sahar', 'YE.15.2211', 'ASCII:Sahar;ID:71271', '28438');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28438', '112', '30315', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30316', '1079', '1', 'Sa''adah', 'YE.15.2215', 'ASCII:Sa''adah;ID:71332', '28439');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28439', '112', '30316', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2215» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30317', '1079', '1', 'Rada''', 'YE.20.1413', 'ASCII:Rada'';ID:71489', '28440');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28440', '112', '30317', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1413» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30318', '1079', '1', 'Razih', 'YE.15.2205', 'ASCII:Razih;ID:71519', '28441');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28441', '112', '30318', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30319', '1079', '1', 'An Nadirah', 'YE.23.1104', 'ASCII:An Nadirah;ID:72370', '28442');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28442', '112', '30319', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30320', '1079', '1', 'Al  Mukha', 'YE.25.1506', 'ASCII:Al  Mukha;ID:72514', '28443');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28443', '112', '30320', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30321', '1079', '1', 'Mawiyah', 'YE.25.1501', 'ASCII:Mawiyah;ID:72780', '28444');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28444', '112', '30321', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30322', '1079', '1', 'Marib City', 'YE.14.2612', 'ASCII:Marib City;ID:72965', '28445');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28445', '112', '30322', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30323', '1079', '1', 'Al Makhadir', 'YE.23.1107', 'ASCII:Al Makhadir;ID:73172', '28446');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28446', '112', '30323', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30324', '1079', '1', 'Al Khawkhah', 'YE.08.1820', 'ASCII:Al Khawkhah;ID:73794', '28447');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28447', '112', '30324', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1820» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30325', '1079', '1', 'Khamir', 'YE.19.2919', 'ASCII:Khamir;ID:73865', '28448');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28448', '112', '30325', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30326', '1079', '1', 'Shibam Kawkaban', 'YE.10.2701', 'ASCII:Shibam Kawkaban;ID:73956', '28449');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28449', '112', '30326', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.10.2701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30327', '1079', '1', 'Ibb', 'YE.23.1120', 'ASCII:Ibb;ID:74475', '28450');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28450', '112', '30327', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1120» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30328', '1079', '1', 'Huth', 'YE.19.2902', 'ASCII:Huth;ID:74489', '28451');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28451', '112', '30328', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30329', '1079', '1', 'Huraidhah', 'YE.04.1928', 'ASCII:Huraidhah;ID:74580', '28452');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28452', '112', '30329', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1928» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30330', '1079', '1', 'Harib', 'YE.14.2609', 'ASCII:Harib;ID:75132', '28453');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28453', '112', '30330', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30331', '1079', '1', 'Harad', 'YE.22.1702', 'ASCII:Harad;ID:75142', '28454');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28454', '112', '30331', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30332', '1079', '1', 'Hamdan', 'YE.16.2301', 'ASCII:Hamdan;ID:75257', '28455');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28455', '112', '30332', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30333', '1079', '1', 'Hajjah City', 'YE.22.1728', 'ASCII:Hajjah City;ID:75334', '28456');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28456', '112', '30333', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1728» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30334', '1079', '1', 'Dhi As Sufal', 'YE.23.1116', 'ASCII:Dhi As Sufal;ID:76153', '28457');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28457', '112', '30334', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30335', '1079', '1', 'Dhamar City', 'YE.11.2008', 'ASCII:Dhamar City;ID:76182', '28458');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28458', '112', '30335', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30336', '1079', '1', 'Bayt Al Faqiah', 'YE.08.1817', 'ASCII:Bayt Al Faqiah;ID:76989', '28459');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28459', '112', '30336', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1817» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30337', '1079', '1', 'Al Bayda', 'YE.20.1410', 'ASCII:Al Bayda;ID:77026', '28460');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28460', '112', '30337', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1410» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30338', '1079', '1', 'Bart Al Anan', 'YE.21.1610', 'ASCII:Bart Al Anan;ID:77122', '28461');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28461', '112', '30338', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30339', '1079', '1', 'Bajil', 'YE.08.1810', 'ASCII:Bajil;ID:77407', '28462');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28462', '112', '30339', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1810» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30340', '1079', '1', 'Anss', 'YE.11.2010', 'ASCII:Anss;ID:78321', '28463');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28463', '112', '30340', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30341', '1079', '1', 'Amran', 'YE.19.2915', 'ASCII:Amran;ID:78427', '28464');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28464', '112', '30341', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30342', '1079', '1', 'Haydan', 'YE.15.2208', 'ASCII:Haydan;ID:6940588', '28465');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28465', '112', '30342', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30343', '1079', '1', 'Abs', 'YE.22.1704', 'ASCII:Abs;ID:6940589', '28466');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28466', '112', '30343', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30344', '1079', '1', 'Qafl Shamer', 'YE.22.1713', 'ASCII:Qafl Shamer;ID:6940590', '28467');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28467', '112', '30344', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1713» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30345', '1079', '1', 'Bani Qa''is', 'YE.22.1724', 'ASCII:Bani Qa''is;ID:6940591', '28468');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28468', '112', '30345', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1724» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30346', '1079', '1', 'Hazm Al Udayn', 'YE.23.1109', 'ASCII:Hazm Al Udayn;ID:6940592', '28469');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28469', '112', '30346', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30347', '1079', '1', 'Al Qafr', 'YE.23.1101', 'ASCII:Al Qafr;ID:6940593', '28470');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28470', '112', '30347', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30348', '1079', '1', 'Al Maghrabah', 'YE.22.1717', 'ASCII:Al Maghrabah;ID:6940594', '28471');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28471', '112', '30348', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1717» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30349', '1079', '1', 'Bani Al Harith', 'YE.26.1310', 'ASCII:Bani Al Harith;ID:6940595', '28472');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28472', '112', '30349', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.26.1310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30350', '1079', '1', 'Sama', 'YE.25.1523', 'ASCII:Sama;ID:6940596', '28473');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28473', '112', '30350', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1523» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30351', '1079', '1', 'Al Misrakh', 'YE.25.1512', 'ASCII:Al Misrakh;ID:6940597', '28474');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28474', '112', '30351', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30352', '1079', '1', 'Sabir Al Mawadim', 'YE.25.1511', 'ASCII:Sabir Al Mawadim;ID:6940598', '28475');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28475', '112', '30352', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30353', '1079', '1', 'Dimnat Khadir', 'YE.25.1513', 'ASCII:Dimnat Khadir;ID:6940599', '28476');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28476', '112', '30353', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30354', '1079', '1', 'Ash Shamayatayn', 'YE.25.1515', 'ASCII:Ash Shamayatayn;ID:6940600', '28477');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28477', '112', '30354', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30355', '1079', '1', 'Jabal Habashy', 'YE.25.1509', 'ASCII:Jabal Habashy;ID:6940601', '28478');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28478', '112', '30355', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30356', '1079', '1', 'Az Zahir', 'YE.21.1604', 'ASCII:Az Zahir;ID:6940602', '28479');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28479', '112', '30356', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30357', '1079', '1', 'Kharab Al Marashi', 'YE.21.1612', 'ASCII:Kharab Al Marashi;ID:6940603', '28480');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28480', '112', '30357', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1612» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30358', '1079', '1', 'Al Mahabishah', 'YE.22.1715', 'ASCII:Al Mahabishah;ID:6940604', '28481');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28481', '112', '30358', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1715» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30359', '1079', '1', 'Midi', 'YE.22.1703', 'ASCII:Midi;ID:6940605', '28482');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28482', '112', '30359', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30360', '1079', '1', 'Hayran', 'YE.22.1705', 'ASCII:Hayran;ID:6940606', '28483');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28483', '112', '30360', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30361', '1079', '1', 'Bani Al Awam', 'YE.22.1727', 'ASCII:Bani Al Awam;ID:6940607', '28484');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28484', '112', '30361', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1727» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30362', '1079', '1', 'Hajjah', 'YE.22.1729', 'ASCII:Hajjah;ID:6940608', '28485');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28485', '112', '30362', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1729» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30363', '1079', '1', 'Al Munirah', 'YE.08.1805', 'ASCII:Al Munirah;ID:6940609', '28486');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28486', '112', '30363', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30364', '1079', '1', 'Ad Durayhimi', 'YE.08.1814', 'ASCII:Ad Durayhimi;ID:6940610', '28487');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28487', '112', '30364', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1814» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30365', '1079', '1', 'Al Marawi''ah', 'YE.08.1813', 'ASCII:Al Marawi''ah;ID:6940611', '28488');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28488', '112', '30365', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1813» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30366', '1079', '1', 'Al Hawak', 'YE.08.1821', 'ASCII:Al Hawak;ID:6940612', '28489');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28489', '112', '30366', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30367', '1079', '1', 'As Salif', 'YE.08.1804', 'ASCII:As Salif;ID:6940613', '28490');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28490', '112', '30367', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30368', '1079', '1', 'Jabal Ra''s', 'YE.08.1818', 'ASCII:Jabal Ra''s;ID:6940614', '28491');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28491', '112', '30368', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1818» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30369', '1079', '1', 'Rakhyah', 'YE.04.1920', 'ASCII:Rakhyah;ID:6940615', '28492');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28492', '112', '30369', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30370', '1079', '1', 'Dawran Aness', 'YE.11.2011', 'ASCII:Dawran Aness;ID:6940616', '28493');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28493', '112', '30370', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2011» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30371', '1079', '1', 'Usaylan', 'YE.05.2105', 'ASCII:Usaylan;ID:6940617', '28494');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28494', '112', '30371', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30372', '1079', '1', 'Al Hashwah', 'YE.15.2213', 'ASCII:Al Hashwah;ID:6940618', '28495');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28495', '112', '30372', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2213» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30373', '1079', '1', 'Ghamr', 'YE.15.2204', 'ASCII:Ghamr;ID:6940619', '28496');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28496', '112', '30373', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30374', '1079', '1', 'Qatabir', 'YE.15.2202', 'ASCII:Qatabir;ID:6940620', '28497');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28497', '112', '30374', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30375', '1079', '1', 'Monabbih', 'YE.15.2203', 'ASCII:Monabbih;ID:6940621', '28498');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28498', '112', '30375', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30376', '1079', '1', 'Arhab', 'YE.16.2302', 'ASCII:Arhab;ID:6940622', '28499');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28499', '112', '30376', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30377', '1079', '1', 'Tuban', 'YE.24.2515', 'ASCII:Tuban;ID:6940623', '28500');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28500', '112', '30377', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30378', '1079', '1', 'Al Qabbaytah', 'YE.24.2510', 'ASCII:Al Qabbaytah;ID:6940624', '28501');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28501', '112', '30378', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30379', '1079', '1', 'Harib Al Qaramish', 'YE.14.2604', 'ASCII:Harib Al Qaramish;ID:6940625', '28502');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28502', '112', '30379', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2604» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30380', '1079', '1', 'Harf Sufyan', 'YE.19.2901', 'ASCII:Harf Sufyan;ID:6940626', '28503');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28503', '112', '30380', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30381', '1079', '1', 'Raydah', 'YE.19.2911', 'ASCII:Raydah;ID:6940627', '28504');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28504', '112', '30381', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30382', '1079', '1', 'Ash Sha''ir', 'YE.23.1105', 'ASCII:Ash Sha''ir;ID:6940628', '28505');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28505', '112', '30382', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30383', '1079', '1', 'Ar Radmah', 'YE.23.1103', 'ASCII:Ar Radmah;ID:6940629', '28506');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28506', '112', '30383', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30384', '1079', '1', 'As Saddah', 'YE.23.1106', 'ASCII:As Saddah;ID:6940630', '28507');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28507', '112', '30384', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30385', '1079', '1', 'Mudhaykhirah', 'YE.23.1117', 'ASCII:Mudhaykhirah;ID:6940631', '28508');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28508', '112', '30385', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30386', '1079', '1', 'Far Al Udayn', 'YE.23.1110', 'ASCII:Far Al Udayn;ID:6940632', '28509');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28509', '112', '30386', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30387', '1079', '1', 'Al Husha', 'YE.18.3009', 'ASCII:Al Husha;ID:6940633', '28510');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28510', '112', '30387', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.18.3009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30388', '1079', '1', 'Qa''atabah', 'YE.18.3003', 'ASCII:Qa''atabah;ID:6940634', '28511');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28511', '112', '30388', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.18.3003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30389', '1079', '1', 'Al Jabin', 'YE.27.3102', 'ASCII:Al Jabin;ID:6940635', '28512');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28512', '112', '30389', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.27.3102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30390', '1079', '1', 'Al Jafariyah', 'YE.27.3105', 'ASCII:Al Jafariyah;ID:6940636', '28513');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28513', '112', '30390', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.27.3105» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30391', '1079', '1', 'Kusmah', 'YE.27.3104', 'ASCII:Kusmah;ID:6940637', '28514');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28514', '112', '30391', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.27.3104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30392', '1079', '1', 'As Salafiyah', 'YE.27.3103', 'ASCII:As Salafiyah;ID:6940638', '28515');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28515', '112', '30392', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.27.3103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30393', '1079', '1', 'Al Dhihar', 'YE.23.1119', 'ASCII:Al Dhihar;ID:6940639', '28516');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28516', '112', '30393', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1119» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30394', '1079', '1', 'As Sayyani', 'YE.23.1115', 'ASCII:As Sayyani;ID:6940640', '28517');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28517', '112', '30394', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30395', '1079', '1', 'Al Mashannah', 'YE.23.1118', 'ASCII:Al Mashannah;ID:6940641', '28518');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28518', '112', '30395', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1118» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30396', '1079', '1', 'As Sabrah', 'YE.23.1114', 'ASCII:As Sabrah;ID:6940642', '28519');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28519', '112', '30396', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30397', '1079', '1', 'Hubaysh', 'YE.23.1108', 'ASCII:Hubaysh;ID:6940643', '28520');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28520', '112', '30397', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30398', '1079', '1', 'Jiblah', 'YE.23.1112', 'ASCII:Jiblah;ID:6940644', '28521');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28521', '112', '30398', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30399', '1079', '1', 'Ba''dan', 'YE.23.1113', 'ASCII:Ba''dan;ID:6940645', '28522');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28522', '112', '30399', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.23.1113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30400', '1079', '1', 'Ahwar', 'YE.01.1209', 'ASCII:Ahwar;ID:6940646', '28523');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28523', '112', '30400', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30401', '1079', '1', 'Mudiyah', 'YE.01.1202', 'ASCII:Mudiyah;ID:6940647', '28524');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28524', '112', '30401', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1202» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30402', '1079', '1', 'Al Mahfad', 'YE.01.1201', 'ASCII:Al Mahfad;ID:6940648', '28525');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28525', '112', '30402', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30403', '1079', '1', 'Rasad', 'YE.01.1206', 'ASCII:Rasad;ID:6940649', '28526');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28526', '112', '30403', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30404', '1079', '1', 'Jayshan', 'YE.01.1203', 'ASCII:Jayshan;ID:6940650', '28527');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28527', '112', '30404', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1203» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30405', '1079', '1', 'Sibah', 'YE.01.1205', 'ASCII:Sibah;ID:6940651', '28528');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28528', '112', '30405', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1205» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30406', '1079', '1', 'Lawdar', 'YE.01.1204', 'ASCII:Lawdar;ID:6940652', '28529');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28529', '112', '30406', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1204» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30407', '1079', '1', 'Al Wade''a', 'YE.01.1208', 'ASCII:Al Wade''a;ID:6940653', '28530');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28530', '112', '30407', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1208» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30408', '1079', '1', 'Khanfir', 'YE.01.1211', 'ASCII:Khanfir;ID:6940654', '28531');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28531', '112', '30408', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1211» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30409', '1079', '1', 'Sarar', 'YE.01.1207', 'ASCII:Sarar;ID:6940655', '28532');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28532', '112', '30409', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30410', '1079', '1', 'Zingibar', 'YE.01.1210', 'ASCII:Zingibar;ID:6940656', '28533');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28533', '112', '30410', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.01.1210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30411', '1079', '1', 'Al Wahdah', 'YE.26.1306', 'ASCII:Al Wahdah;ID:6940657', '28534');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28534', '112', '30411', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.26.1306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30412', '1079', '1', 'Old City', 'YE.26.1301', 'ASCII:Old City;ID:6940658', '28535');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28535', '112', '30412', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.26.1301» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30413', '1079', '1', 'Ath''thaorah', 'YE.26.1309', 'ASCII:Ath''thaorah;ID:6940659', '28536');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28536', '112', '30413', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.26.1309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30414', '1079', '1', 'Assafi''yah', 'YE.26.1304', 'ASCII:Assafi''yah;ID:6940660', '28537');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28537', '112', '30414', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.26.1304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30415', '1079', '1', 'Ma''ain', 'YE.26.1308', 'ASCII:Ma''ain;ID:6940661', '28538');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28538', '112', '30415', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.26.1308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30416', '1079', '1', 'As Sabain', 'YE.26.1305', 'ASCII:As Sabain;ID:6940662', '28539');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28539', '112', '30416', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.26.1305» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30417', '1079', '1', 'Shu''aub', 'YE.26.1302', 'ASCII:Shu''aub;ID:6940663', '28540');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28540', '112', '30417', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.26.1302» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30418', '1079', '1', 'Az''zal', 'YE.26.1303', 'ASCII:Az''zal;ID:6940664', '28541');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28541', '112', '30418', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.26.1303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30419', '1079', '1', 'At Tahrir', 'YE.26.1307', 'ASCII:At Tahrir;ID:6940665', '28542');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28542', '112', '30419', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.26.1307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30420', '1079', '1', 'Sabah', 'YE.20.1417', 'ASCII:Sabah;ID:6940666', '28543');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28543', '112', '30420', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1417» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30421', '1079', '1', 'Wald Rabi''', 'YE.20.1415', 'ASCII:Wald Rabi'';ID:6940667', '28544');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28544', '112', '30421', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1415» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30422', '1079', '1', 'Al Quraishyah', 'YE.20.1414', 'ASCII:Al Quraishyah;ID:6940668', '28545');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28545', '112', '30422', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1414» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30423', '1079', '1', 'Ar Ryashyyah', 'YE.20.1418', 'ASCII:Ar Ryashyyah;ID:6940669', '28546');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28546', '112', '30423', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1418» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30424', '1079', '1', 'Na''man', 'YE.20.1401', 'ASCII:Na''man;ID:6940670', '28547');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28547', '112', '30424', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30425', '1079', '1', 'Mukayras', 'YE.20.1408', 'ASCII:Mukayras;ID:6940671', '28548');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28548', '112', '30425', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30426', '1079', '1', 'Nati''', 'YE.20.1402', 'ASCII:Nati'';ID:6940672', '28549');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28549', '112', '30426', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30427', '1079', '1', 'As Sawadiyah', 'YE.20.1411', 'ASCII:As Sawadiyah;ID:6940673', '28550');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28550', '112', '30427', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1411» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30428', '1079', '1', 'At Taffah', 'YE.20.1407', 'ASCII:At Taffah;ID:6940674', '28551');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28551', '112', '30428', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30429', '1079', '1', 'Radman Al Awad', 'YE.20.1412', 'ASCII:Radman Al Awad;ID:6940675', '28552');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28552', '112', '30429', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1412» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30430', '1079', '1', 'Dhi Na''im', 'YE.20.1406', 'ASCII:Dhi Na''im;ID:6940676', '28553');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28553', '112', '30430', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30431', '1079', '1', 'Al Bayda City', 'YE.20.1409', 'ASCII:Al Bayda City;ID:6940677', '28554');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28554', '112', '30431', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1409» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30432', '1079', '1', 'Al Malagim', 'YE.20.1420', 'ASCII:Al Malagim;ID:6940678', '28555');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28555', '112', '30432', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30433', '1079', '1', 'Maswarah', 'YE.20.1403', 'ASCII:Maswarah;ID:6940679', '28556');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28556', '112', '30433', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30434', '1079', '1', 'Al A''rsh', 'YE.20.1416', 'ASCII:Al A''rsh;ID:6940680', '28557');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28557', '112', '30434', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1416» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30435', '1079', '1', 'As Sawma''ah', 'YE.20.1404', 'ASCII:As Sawma''ah;ID:6940681', '28558');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28558', '112', '30435', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30436', '1079', '1', 'Az Zahir', 'YE.20.1405', 'ASCII:Az Zahir;ID:6940682', '28559');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28559', '112', '30436', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.20.1405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30437', '1079', '1', 'Mashra''a Wa Hadnan', 'YE.25.1510', 'ASCII:Mashra''a Wa Hadnan;ID:6940683', '28560');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28560', '112', '30437', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1510» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30438', '1079', '1', 'Al Wazi''iyah', 'YE.25.1516', 'ASCII:Al Wazi''iyah;ID:6940684', '28561');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28561', '112', '30438', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1516» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30439', '1079', '1', 'As Silw', 'YE.25.1514', 'ASCII:As Silw;ID:6940685', '28562');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28562', '112', '30439', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30440', '1079', '1', 'Hayfan', 'YE.25.1517', 'ASCII:Hayfan;ID:6940686', '28563');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28563', '112', '30440', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1517» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30441', '1079', '1', 'Al Ma''afer', 'YE.25.1521', 'ASCII:Al Ma''afer;ID:6940687', '28564');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28564', '112', '30441', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1521» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30442', '1079', '1', 'Al Mawasit', 'YE.25.1522', 'ASCII:Al Mawasit;ID:6940688', '28565');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28565', '112', '30442', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1522» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30443', '1079', '1', 'Dhubab', 'YE.25.1507', 'ASCII:Dhubab;ID:6940689', '28566');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28566', '112', '30443', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30444', '1079', '1', 'Al Qahirah', 'YE.25.1519', 'ASCII:Al Qahirah;ID:6940690', '28567');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28567', '112', '30444', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30445', '1079', '1', 'Salh', 'YE.25.1520', 'ASCII:Salh;ID:6940691', '28568');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28568', '112', '30445', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1520» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30446', '1079', '1', 'Al Mudhaffar', 'YE.25.1518', 'ASCII:Al Mudhaffar;ID:6940692', '28569');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28569', '112', '30446', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1518» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30447', '1079', '1', 'Mawza', 'YE.25.1508', 'ASCII:Mawza;ID:6940693', '28570');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28570', '112', '30447', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30448', '1079', '1', 'Shara''b Ar Rawnah', 'YE.25.1504', 'ASCII:Shara''b Ar Rawnah;ID:6940694', '28571');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28571', '112', '30448', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30449', '1079', '1', 'Maqbanah', 'YE.25.1505', 'ASCII:Maqbanah;ID:6940695', '28572');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28572', '112', '30449', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30450', '1079', '1', 'Shara''b As Salam', 'YE.25.1503', 'ASCII:Shara''b As Salam;ID:6940696', '28573');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28573', '112', '30450', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.25.1503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30451', '1079', '1', 'Al Hazm', 'YE.21.1605', 'ASCII:Al Hazm;ID:6940697', '28574');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28574', '112', '30451', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30452', '1079', '1', 'Al Khalq', 'YE.21.1609', 'ASCII:Al Khalq;ID:6940698', '28575');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28575', '112', '30452', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1609» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30453', '1079', '1', 'Al Maton', 'YE.21.1606', 'ASCII:Al Maton;ID:6940699', '28576');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28576', '112', '30453', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30454', '1079', '1', 'Al Matammah', 'YE.21.1603', 'ASCII:Al Matammah;ID:6940700', '28577');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28577', '112', '30454', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30455', '1079', '1', 'Al Maslub', 'YE.21.1607', 'ASCII:Al Maslub;ID:6940701', '28578');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28578', '112', '30455', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30456', '1079', '1', 'Al Ghayl', 'YE.21.1608', 'ASCII:Al Ghayl;ID:6940702', '28579');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28579', '112', '30456', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30457', '1079', '1', 'Khabb wa ash Sha''af', 'YE.21.1601', 'ASCII:Khabb wa ash Sha''af;ID:6940703', '28580');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28580', '112', '30457', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30458', '1079', '1', 'Al Humaydat', 'YE.21.1602', 'ASCII:Al Humaydat;ID:6940704', '28581');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28581', '112', '30458', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30459', '1079', '1', 'Rajuzah', 'YE.21.1611', 'ASCII:Rajuzah;ID:6940705', '28582');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28582', '112', '30459', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.21.1611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30460', '1079', '1', 'Ku''aydinah', 'YE.22.1722', 'ASCII:Ku''aydinah;ID:6940706', '28583');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28583', '112', '30460', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1722» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30461', '1079', '1', 'Mustaba', 'YE.22.1706', 'ASCII:Mustaba;ID:6940707', '28584');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28584', '112', '30461', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30462', '1079', '1', 'Qarah', 'YE.22.1731', 'ASCII:Qarah;ID:6940708', '28585');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28585', '112', '30462', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1731» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30463', '1079', '1', 'Wadhrah', 'YE.22.1723', 'ASCII:Wadhrah;ID:6940709', '28586');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28586', '112', '30463', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30464', '1079', '1', 'Kuhlan Affar', 'YE.22.1718', 'ASCII:Kuhlan Affar;ID:6940710', '28587');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28587', '112', '30464', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30465', '1079', '1', 'Kuhlan Ash Sharaf', 'YE.22.1709', 'ASCII:Kuhlan Ash Sharaf;ID:6940711', '28588');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28588', '112', '30465', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30466', '1079', '1', 'Sharas', 'YE.22.1719', 'ASCII:Sharas;ID:6940712', '28589');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28589', '112', '30466', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1719» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30467', '1079', '1', 'Khayran Al Muharraq', 'YE.22.1711', 'ASCII:Khayran Al Muharraq;ID:6940713', '28590');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28590', '112', '30467', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30468', '1079', '1', 'Ash Shahil', 'YE.22.1721', 'ASCII:Ash Shahil;ID:6940714', '28591');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28591', '112', '30468', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1721» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30469', '1079', '1', 'Najrah', 'YE.22.1726', 'ASCII:Najrah;ID:6940715', '28592');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28592', '112', '30469', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1726» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30470', '1079', '1', 'Ash Shaghadirah', 'YE.22.1725', 'ASCII:Ash Shaghadirah;ID:6940716', '28593');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28593', '112', '30470', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1725» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30471', '1079', '1', 'Aflah Ash Shawm', 'YE.22.1710', 'ASCII:Aflah Ash Shawm;ID:6940717', '28594');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28594', '112', '30471', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1710» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30472', '1079', '1', 'Mabyan', 'YE.22.1720', 'ASCII:Mabyan;ID:6940718', '28595');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28595', '112', '30472', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1720» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30473', '1079', '1', 'Al Miftah', 'YE.22.1716', 'ASCII:Al Miftah;ID:6940719', '28596');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28596', '112', '30473', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1716» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30474', '1079', '1', 'Aflah Al Yaman', 'YE.22.1714', 'ASCII:Aflah Al Yaman;ID:6940720', '28597');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28597', '112', '30474', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1714» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30475', '1079', '1', 'Al Jamimah', 'YE.22.1708', 'ASCII:Al Jamimah;ID:6940721', '28598');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28598', '112', '30475', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30476', '1079', '1', 'Aslem', 'YE.22.1712', 'ASCII:Aslem;ID:6940722', '28599');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28599', '112', '30476', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1712» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30477', '1079', '1', 'Bakil Al Mir', 'YE.22.1701', 'ASCII:Bakil Al Mir;ID:6940723', '28600');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28600', '112', '30477', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1701» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30478', '1079', '1', 'Kushar', 'YE.22.1707', 'ASCII:Kushar;ID:6940724', '28601');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28601', '112', '30478', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.22.1707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30479', '1079', '1', 'Al Mina', 'YE.08.1822', 'ASCII:Al Mina;ID:6940725', '28602');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28602', '112', '30479', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1822» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30480', '1079', '1', 'As Sukhnah', 'YE.08.1815', 'ASCII:As Sukhnah;ID:6940726', '28603');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28603', '112', '30480', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1815» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30481', '1079', '1', 'Al Garrahi', 'YE.08.1825', 'ASCII:Al Garrahi;ID:6940727', '28604');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28604', '112', '30481', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1825» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30482', '1079', '1', 'Bura', 'YE.08.1812', 'ASCII:Bura;ID:6940728', '28605');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28605', '112', '30482', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1812» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30483', '1079', '1', 'Kamaran', 'YE.08.1803', 'ASCII:Kamaran;ID:6940729', '28606');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28606', '112', '30483', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30484', '1079', '1', 'Al Mansuriyah', 'YE.08.1816', 'ASCII:Al Mansuriyah;ID:6940730', '28607');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28607', '112', '30484', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1816» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30485', '1079', '1', 'Az Zuhrah', 'YE.08.1801', 'ASCII:Az Zuhrah;ID:6940731', '28608');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28608', '112', '30485', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1801» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30486', '1079', '1', 'Ad Dahi', 'YE.08.1809', 'ASCII:Ad Dahi;ID:6940732', '28609');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28609', '112', '30486', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30487', '1079', '1', 'Hays', 'YE.08.1819', 'ASCII:Hays;ID:6940733', '28610');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28610', '112', '30487', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1819» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30488', '1079', '1', 'At Tuhayat', 'YE.08.1826', 'ASCII:At Tuhayat;ID:6940734', '28611');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28611', '112', '30488', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1826» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30489', '1079', '1', 'Al Hali', 'YE.08.1823', 'ASCII:Al Hali;ID:6940735', '28612');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28612', '112', '30489', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1823» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30490', '1079', '1', 'Al Hajjaylah', 'YE.08.1811', 'ASCII:Al Hajjaylah;ID:6940736', '28613');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28613', '112', '30490', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30491', '1079', '1', 'Al Mighlaf', 'YE.08.1808', 'ASCII:Al Mighlaf;ID:6940737', '28614');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28614', '112', '30491', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30492', '1079', '1', 'Al Qanawis', 'YE.08.1806', 'ASCII:Al Qanawis;ID:6940738', '28615');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28615', '112', '30492', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30493', '1079', '1', 'Alluheyah', 'YE.08.1802', 'ASCII:Alluheyah;ID:6940739', '28616');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28616', '112', '30493', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.08.1802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30494', '1079', '1', 'Adh Dhlia''ah', 'YE.04.1922', 'ASCII:Adh Dhlia''ah;ID:6940740', '28617');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28617', '112', '30494', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1922» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30495', '1079', '1', 'Al Mukalla', 'YE.04.1930', 'ASCII:Al Mukalla;ID:6940741', '28618');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28618', '112', '30495', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1930» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30496', '1079', '1', 'Yabuth', 'YE.04.1923', 'ASCII:Yabuth;ID:6940742', '28619');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28619', '112', '30496', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1923» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30497', '1079', '1', 'Hajr', 'YE.04.1924', 'ASCII:Hajr;ID:6940743', '28620');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28620', '112', '30497', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1924» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30498', '1079', '1', 'Shibam', 'YE.04.1908', 'ASCII:Shibam;ID:6940744', '28621');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28621', '112', '30498', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30499', '1079', '1', 'Sah', 'YE.04.1909', 'ASCII:Sah;ID:6940745', '28622');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28622', '112', '30499', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30500', '1079', '1', 'Ghayl Bin Yamin', 'YE.04.1916', 'ASCII:Ghayl Bin Yamin;ID:6940746', '28623');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28623', '112', '30500', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30501', '1079', '1', 'Wadi Al Ayn', 'YE.04.1919', 'ASCII:Wadi Al Ayn;ID:6940747', '28624');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28624', '112', '30501', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1919» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30502', '1079', '1', 'Amd', 'YE.04.1921', 'ASCII:Amd;ID:6940748', '28625');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28625', '112', '30502', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1921» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30503', '1079', '1', 'Ar Raydah Wa Qusayar', 'YE.04.1913', 'ASCII:Ar Raydah Wa Qusayar;ID:6940749', '28626');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28626', '112', '30503', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30504', '1079', '1', 'Daw''an', 'YE.04.1918', 'ASCII:Daw''an;ID:6940750', '28627');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28627', '112', '30504', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30505', '1079', '1', 'Ad Dis', 'YE.04.1914', 'ASCII:Ad Dis;ID:6940751', '28628');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28628', '112', '30505', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30506', '1079', '1', 'Ash Shihr', 'YE.04.1915', 'ASCII:Ash Shihr;ID:6940752', '28629');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28629', '112', '30506', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1915» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30507', '1079', '1', 'Ghayl Ba Wazir', 'YE.04.1917', 'ASCII:Ghayl Ba Wazir;ID:6940753', '28630');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28630', '112', '30507', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30508', '1079', '1', 'Brom Mayfa', 'YE.04.1925', 'ASCII:Brom Mayfa;ID:6940755', '28631');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28631', '112', '30508', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1925» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30509', '1079', '1', 'Al Mukalla City', 'YE.04.1929', 'ASCII:Al Mukalla City;ID:6940756', '28632');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28632', '112', '30509', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1929» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30510', '1079', '1', 'Sayun', 'YE.04.1910', 'ASCII:Sayun;ID:6940757', '28633');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28633', '112', '30510', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30511', '1079', '1', 'Hidaybu', 'YE.04.1926', 'ASCII:Hidaybu;ID:6940758', '28634');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28634', '112', '30511', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30512', '1079', '1', 'Thamud', 'YE.04.1902', 'ASCII:Thamud;ID:6940759', '28635');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28635', '112', '30512', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30513', '1079', '1', 'Al Qaf', 'YE.04.1903', 'ASCII:Al Qaf;ID:6940760', '28636');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28636', '112', '30513', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30514', '1079', '1', 'As Sawm', 'YE.04.1912', 'ASCII:As Sawm;ID:6940762', '28637');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28637', '112', '30514', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30515', '1079', '1', 'Hagr As Sai''ar', 'YE.04.1905', 'ASCII:Hagr As Sai''ar;ID:6940763', '28638');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28638', '112', '30515', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1905» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30516', '1079', '1', 'Tarim', 'YE.04.1911', 'ASCII:Tarim;ID:6940764', '28639');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28639', '112', '30516', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30517', '1079', '1', 'Rumah', 'YE.04.1901', 'ASCII:Rumah;ID:6940765', '28640');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28640', '112', '30517', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1901» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30518', '1079', '1', 'Al Qatn', 'YE.04.1907', 'ASCII:Al Qatn;ID:6940766', '28641');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28641', '112', '30518', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30519', '1079', '1', 'Al Abr', 'YE.04.1906', 'ASCII:Al Abr;ID:6940767', '28642');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28642', '112', '30519', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.04.1906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30520', '1079', '1', 'Mayfa''at Anss', 'YE.11.2009', 'ASCII:Mayfa''at Anss;ID:6940768', '28643');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28643', '112', '30520', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2009» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30521', '1079', '1', 'Al Hada', 'YE.11.2001', 'ASCII:Al Hada;ID:6940769', '28644');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28644', '112', '30521', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30522', '1079', '1', 'Wusab Al Ali', 'YE.11.2006', 'ASCII:Wusab Al Ali;ID:6940770', '28645');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28645', '112', '30522', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30523', '1079', '1', 'Maghirib Ans', 'YE.11.2004', 'ASCII:Maghirib Ans;ID:6940771', '28646');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28646', '112', '30523', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30524', '1079', '1', 'Jahran', 'YE.11.2002', 'ASCII:Jahran;ID:6940772', '28647');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28647', '112', '30524', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30525', '1079', '1', 'Al Manar', 'YE.11.2012', 'ASCII:Al Manar;ID:6940773', '28648');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28648', '112', '30525', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2012» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30526', '1079', '1', 'Jabal Ash sharq', 'YE.11.2003', 'ASCII:Jabal Ash sharq;ID:6940774', '28649');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28649', '112', '30526', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2003» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30527', '1079', '1', 'Wusab As Safil', 'YE.11.2007', 'ASCII:Wusab As Safil;ID:6940775', '28650');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28650', '112', '30527', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30528', '1079', '1', 'Utmah', 'YE.11.2005', 'ASCII:Utmah;ID:6940776', '28651');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28651', '112', '30528', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.11.2005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30529', '1079', '1', 'Ataq', 'YE.05.2113', 'ASCII:Ataq;ID:6940777', '28652');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28652', '112', '30529', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2113» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30530', '1079', '1', 'Rudum', 'YE.05.2117', 'ASCII:Rudum;ID:6940778', '28653');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28653', '112', '30530', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2117» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30531', '1079', '1', 'Nisab', 'YE.05.2110', 'ASCII:Nisab;ID:6940779', '28654');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28654', '112', '30531', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2110» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30532', '1079', '1', 'Bayhan', 'YE.05.2107', 'ASCII:Bayhan;ID:6940780', '28655');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28655', '112', '30532', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30533', '1079', '1', 'Habban', 'YE.05.2114', 'ASCII:Habban;ID:6940781', '28656');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28656', '112', '30533', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2114» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30534', '1079', '1', 'Hatib', 'YE.05.2111', 'ASCII:Hatib;ID:6940782', '28657');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28657', '112', '30534', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2111» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30535', '1079', '1', 'Mayfa''a', 'YE.05.2116', 'ASCII:Mayfa''a;ID:6940783', '28658');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28658', '112', '30535', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2116» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30536', '1079', '1', 'Merkhah Al Ulya', 'YE.05.2108', 'ASCII:Merkhah Al Ulya;ID:6940784', '28659');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28659', '112', '30536', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30537', '1079', '1', 'Merkhah As Sufla', 'YE.05.2109', 'ASCII:Merkhah As Sufla;ID:6940785', '28660');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28660', '112', '30537', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2109» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30538', '1079', '1', 'As Said', 'YE.05.2112', 'ASCII:As Said;ID:6940786', '28661');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28661', '112', '30538', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2112» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30539', '1079', '1', 'Dhar', 'YE.05.2101', 'ASCII:Dhar;ID:6940787', '28662');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28662', '112', '30539', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30540', '1079', '1', 'Arma', 'YE.05.2104', 'ASCII:Arma;ID:6940788', '28663');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28663', '112', '30540', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2104» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30541', '1079', '1', 'Jardan', 'YE.05.2103', 'ASCII:Jardan;ID:6940789', '28664');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28664', '112', '30541', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2103» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30542', '1079', '1', 'Ain', 'YE.05.2106', 'ASCII:Ain;ID:6940790', '28665');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28665', '112', '30542', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30543', '1079', '1', 'Al Talh', 'YE.05.2102', 'ASCII:Al Talh;ID:6940791', '28666');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28666', '112', '30543', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2102» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30544', '1079', '1', 'Ar Rawdah', 'YE.05.2115', 'ASCII:Ar Rawdah;ID:6940792', '28667');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28667', '112', '30544', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.05.2115» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30545', '1079', '1', 'Al Dhaher', 'YE.15.2207', 'ASCII:Al Dhaher;ID:6940793', '28668');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28668', '112', '30545', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2207» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30546', '1079', '1', 'Shada''a', 'YE.15.2206', 'ASCII:Shada''a;ID:6940794', '28669');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28669', '112', '30546', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2206» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30547', '1079', '1', 'Saqayn', 'YE.15.2209', 'ASCII:Saqayn;ID:6940795', '28670');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28670', '112', '30547', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2209» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30548', '1079', '1', 'Baqim', 'YE.15.2201', 'ASCII:Baqim;ID:6940796', '28671');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28671', '112', '30548', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2201» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30549', '1079', '1', 'As Safra', 'YE.15.2212', 'ASCII:As Safra;ID:6940797', '28672');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28672', '112', '30549', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2212» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30550', '1079', '1', 'Majz', 'YE.15.2210', 'ASCII:Majz;ID:6940798', '28673');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28673', '112', '30550', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2210» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30551', '1079', '1', 'Kitaf wa Al Boqe''e', 'YE.15.2214', 'ASCII:Kitaf wa Al Boqe''e;ID:6940799', '28674');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28674', '112', '30551', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.15.2214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30552', '1079', '1', 'Nihm', 'YE.16.2303', 'ASCII:Nihm;ID:6940800', '28675');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28675', '112', '30552', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2303» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30553', '1079', '1', 'Bani Matar', 'YE.16.2307', 'ASCII:Bani Matar;ID:6940801', '28676');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28676', '112', '30553', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2307» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30554', '1079', '1', 'Attyal', 'YE.16.2313', 'ASCII:Attyal;ID:6940802', '28677');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28677', '112', '30554', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2313» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30555', '1079', '1', 'Al Husn', 'YE.16.2315', 'ASCII:Al Husn;ID:6940803', '28678');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28678', '112', '30555', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2315» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30556', '1079', '1', 'Bilad Ar Rus', 'YE.16.2306', 'ASCII:Bilad Ar Rus;ID:6940804', '28679');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28679', '112', '30556', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2306» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30557', '1079', '1', 'Al Haymah Al Kharijiyah', 'YE.16.2309', 'ASCII:Al Haymah Al Kharijiyah;ID:6940805', '28680');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28680', '112', '30557', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2309» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30558', '1079', '1', 'Manakhah', 'YE.16.2310', 'ASCII:Manakhah;ID:6940806', '28681');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28681', '112', '30558', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2310» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30559', '1079', '1', 'Jihanah', 'YE.16.2316', 'ASCII:Jihanah;ID:6940807', '28682');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28682', '112', '30559', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2316» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30560', '1079', '1', 'Bani Dhabyan', 'YE.16.2314', 'ASCII:Bani Dhabyan;ID:6940808', '28683');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28683', '112', '30560', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2314» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30561', '1079', '1', 'Khwlan', 'YE.16.2312', 'ASCII:Khwlan;ID:6940809', '28684');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28684', '112', '30561', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2312» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30562', '1079', '1', 'Bani Hushaysh', 'YE.16.2304', 'ASCII:Bani Hushaysh;ID:6940810', '28685');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28685', '112', '30562', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2304» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30563', '1079', '1', 'Al Haymah Ad Dakhiliyah', 'YE.16.2308', 'ASCII:Al Haymah Ad Dakhiliyah;ID:6940811', '28686');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28686', '112', '30563', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2308» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30564', '1079', '1', 'Sa''fan', 'YE.16.2311', 'ASCII:Sa''fan;ID:6940812', '28687');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28687', '112', '30564', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.16.2311» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30565', '1079', '1', 'Attawahi', 'YE.02.2405', 'ASCII:Attawahi;ID:6940813', '28688');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28688', '112', '30565', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.02.2405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30566', '1079', '1', 'Craiter', 'YE.02.2407', 'ASCII:Craiter;ID:6940814', '28689');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28689', '112', '30566', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.02.2407» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30567', '1079', '1', 'Al Buraiqeh', 'YE.02.2404', 'ASCII:Al Buraiqeh;ID:6940815', '28690');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28690', '112', '30567', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.02.2404» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30568', '1079', '1', 'Khur Maksar', 'YE.02.2408', 'ASCII:Khur Maksar;ID:6940816', '28691');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28691', '112', '30568', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.02.2408» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30569', '1079', '1', 'Dar Sad', 'YE.02.2401', 'ASCII:Dar Sad;ID:6940817', '28692');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28692', '112', '30569', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.02.2401» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30570', '1079', '1', 'Al Mansura', 'YE.02.2403', 'ASCII:Al Mansura;ID:6940818', '28693');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28693', '112', '30570', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.02.2403» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30571', '1079', '1', 'Ash Shaikh Outhman', 'YE.02.2402', 'ASCII:Ash Shaikh Outhman;ID:6940819', '28694');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28694', '112', '30571', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.02.2402» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30572', '1079', '1', 'Al Mualla', 'YE.02.2406', 'ASCII:Al Mualla;ID:6940820', '28695');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28695', '112', '30572', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.02.2406» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30573', '1079', '1', 'Tur Al Bahah', 'YE.24.2511', 'ASCII:Tur Al Bahah;ID:6940821', '28696');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28696', '112', '30573', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2511» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30574', '1079', '1', 'Al  Hawtah', 'YE.24.2514', 'ASCII:Al  Hawtah;ID:6940822', '28697');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28697', '112', '30574', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2514» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30575', '1079', '1', 'Habil Jabr', 'YE.24.2505', 'ASCII:Habil Jabr;ID:6940823', '28698');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28698', '112', '30575', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2505» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30576', '1079', '1', 'Yahr', 'YE.24.2504', 'ASCII:Yahr;ID:6940824', '28699');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28699', '112', '30576', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2504» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30577', '1079', '1', 'Halimayn', 'YE.24.2506', 'ASCII:Halimayn;ID:6940825', '28700');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28700', '112', '30577', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2506» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30578', '1079', '1', 'Al Milah', 'YE.24.2508', 'ASCII:Al Milah;ID:6940826', '28701');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28701', '112', '30578', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2508» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30579', '1079', '1', 'Radfan', 'YE.24.2507', 'ASCII:Radfan;ID:6940827', '28702');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28702', '112', '30579', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2507» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30580', '1079', '1', 'Al Maflahy', 'YE.24.2503', 'ASCII:Al Maflahy;ID:6940828', '28703');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28703', '112', '30580', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2503» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30581', '1079', '1', 'Yafa''a', 'YE.24.2502', 'ASCII:Yafa''a;ID:6940829', '28704');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28704', '112', '30581', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2502» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30582', '1079', '1', 'Al Musaymir', 'YE.24.2509', 'ASCII:Al Musaymir;ID:6940830', '28705');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28705', '112', '30582', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2509» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30583', '1079', '1', 'Al Had', 'YE.24.2501', 'ASCII:Al Had;ID:6940831', '28706');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28706', '112', '30583', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2501» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30584', '1079', '1', 'Al Maqatirah', 'YE.24.2512', 'ASCII:Al Maqatirah;ID:6940832', '28707');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28707', '112', '30584', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2512» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30585', '1079', '1', 'Al Madaribah Wa Al Arah', 'YE.24.2513', 'ASCII:Al Madaribah Wa Al Arah;ID:6940833', '28708');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28708', '112', '30585', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.24.2513» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30586', '1079', '1', 'Bidbadah', 'YE.14.2605', 'ASCII:Bidbadah;ID:6940834', '28709');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28709', '112', '30586', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2605» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30587', '1079', '1', 'Marib', 'YE.14.2613', 'ASCII:Marib;ID:6940835', '28710');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28710', '112', '30587', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2613» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30588', '1079', '1', 'Majzar', 'YE.14.2601', 'ASCII:Majzar;ID:6940836', '28711');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28711', '112', '30588', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2601» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30589', '1079', '1', 'Medghal', 'YE.14.2603', 'ASCII:Medghal;ID:6940837', '28712');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28712', '112', '30589', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2603» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30590', '1079', '1', 'Raghwan', 'YE.14.2602', 'ASCII:Raghwan;ID:6940838', '28713');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28713', '112', '30590', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2602» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30591', '1079', '1', 'Sirwah', 'YE.14.2606', 'ASCII:Sirwah;ID:6940839', '28714');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28714', '112', '30591', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2606» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30592', '1079', '1', 'Al Abdiyah', 'YE.14.2611', 'ASCII:Al Abdiyah;ID:6940840', '28715');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28715', '112', '30592', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30593', '1079', '1', 'Mahliyah', 'YE.14.2610', 'ASCII:Mahliyah;ID:6940841', '28716');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28716', '112', '30593', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2610» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30594', '1079', '1', 'Jabal Murad', 'YE.14.2614', 'ASCII:Jabal Murad;ID:6940842', '28717');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28717', '112', '30594', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2614» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30595', '1079', '1', 'Rahabah', 'YE.14.2608', 'ASCII:Rahabah;ID:6940843', '28718');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28718', '112', '30595', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2608» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30596', '1079', '1', 'Al Jubah', 'YE.14.2607', 'ASCII:Al Jubah;ID:6940844', '28719');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28719', '112', '30596', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.14.2607» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30597', '1079', '1', 'Al Mahwait', 'YE.10.2709', 'ASCII:Al Mahwait;ID:6940845', '28720');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28720', '112', '30597', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.10.2709» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30598', '1079', '1', 'Bani Sa''d', 'YE.10.2707', 'ASCII:Bani Sa''d;ID:6940846', '28721');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28721', '112', '30598', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.10.2707» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30599', '1079', '1', 'Al Khabt', 'YE.10.2704', 'ASCII:Al Khabt;ID:6940847', '28722');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28722', '112', '30599', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.10.2704» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30600', '1079', '1', 'Ar Rujum', 'YE.10.2703', 'ASCII:Ar Rujum;ID:6940848', '28723');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28723', '112', '30600', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.10.2703» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30601', '1079', '1', 'Al Mahwait City', 'YE.10.2708', 'ASCII:Al Mahwait City;ID:6940849', '28724');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28724', '112', '30601', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.10.2708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30602', '1079', '1', 'Hufash', 'YE.10.2706', 'ASCII:Hufash;ID:6940850', '28725');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28725', '112', '30602', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.10.2706» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30603', '1079', '1', 'Milhan', 'YE.10.2705', 'ASCII:Milhan;ID:6940851', '28726');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28726', '112', '30603', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.10.2705» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30604', '1079', '1', 'Sayhut', 'YE.03.2807', 'ASCII:Sayhut;ID:6940853', '28727');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28727', '112', '30604', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.03.2807» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30605', '1079', '1', 'Hat', 'YE.03.2802', 'ASCII:Hat;ID:6940854', '28728');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28728', '112', '30605', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.03.2802» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30606', '1079', '1', 'Al Ghaydah', 'YE.03.2804', 'ASCII:Al Ghaydah;ID:6940855', '28729');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28729', '112', '30606', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.03.2804» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30607', '1079', '1', 'Hawf', 'YE.03.2803', 'ASCII:Hawf;ID:6940856', '28730');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28730', '112', '30607', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.03.2803» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30608', '1079', '1', 'Huswain', 'YE.03.2809', 'ASCII:Huswain;ID:6940857', '28731');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28731', '112', '30608', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.03.2809» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30609', '1079', '1', 'Qishn', 'YE.03.2808', 'ASCII:Qishn;ID:6940858', '28732');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28732', '112', '30609', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.03.2808» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30610', '1079', '1', 'Man''ar', 'YE.03.2805', 'ASCII:Man''ar;ID:6940859', '28733');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28733', '112', '30610', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.03.2805» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30611', '1079', '1', 'Al Masilah', 'YE.03.2806', 'ASCII:Al Masilah;ID:6940860', '28734');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28734', '112', '30611', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.03.2806» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30612', '1079', '1', 'Jabal Iyal Yazid', 'YE.19.2912', 'ASCII:Jabal Iyal Yazid;ID:6940861', '28735');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28735', '112', '30612', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2912» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30613', '1079', '1', 'Al Ashah', 'YE.19.2903', 'ASCII:Al Ashah;ID:6940862', '28736');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28736', '112', '30613', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30614', '1079', '1', 'Suwayr', 'YE.19.2907', 'ASCII:Suwayr;ID:6940863', '28737');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28737', '112', '30614', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2907» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30615', '1079', '1', 'Bani Suraim', 'YE.19.2920', 'ASCII:Bani Suraim;ID:6940864', '28738');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28738', '112', '30615', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2920» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30616', '1079', '1', 'Al Madan', 'YE.19.2906', 'ASCII:Al Madan;ID:6940865', '28739');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28739', '112', '30616', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2906» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30617', '1079', '1', 'Thula', 'YE.19.2917', 'ASCII:Thula;ID:6940866', '28740');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28740', '112', '30617', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2917» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30618', '1079', '1', 'As Sudah', 'YE.19.2913', 'ASCII:As Sudah;ID:6940867', '28741');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28741', '112', '30618', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2913» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30619', '1079', '1', 'Habur Zulaymah', 'YE.19.2908', 'ASCII:Habur Zulaymah;ID:6940868', '28742');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28742', '112', '30619', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2908» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30620', '1079', '1', 'Al Qaflah', 'YE.19.2904', 'ASCII:Al Qaflah;ID:6940869', '28743');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28743', '112', '30620', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30621', '1079', '1', 'Maswar', 'YE.19.2916', 'ASCII:Maswar;ID:6940870', '28744');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28744', '112', '30621', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2916» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30622', '1079', '1', 'As Sawd', 'YE.19.2914', 'ASCII:As Sawd;ID:6940871', '28745');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28745', '112', '30622', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2914» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30623', '1079', '1', 'Kharif', 'YE.19.2910', 'ASCII:Kharif;ID:6940872', '28746');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28746', '112', '30623', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2910» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30624', '1079', '1', 'Iyal Surayh', 'YE.19.2918', 'ASCII:Iyal Surayh;ID:6940873', '28747');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28747', '112', '30624', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2918» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30625', '1079', '1', 'Dhi Bin', 'YE.19.2909', 'ASCII:Dhi Bin;ID:6940874', '28748');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28748', '112', '30625', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.19.2909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30626', '1079', '1', 'Ad Dhale''e', 'YE.18.3006', 'ASCII:Ad Dhale''e;ID:6940875', '28749');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28749', '112', '30626', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.18.3006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30627', '1079', '1', 'Al Hussein', 'YE.18.3005', 'ASCII:Al Hussein;ID:6940876', '28750');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28750', '112', '30627', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.18.3005» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30628', '1079', '1', 'Jahaf', 'YE.18.3007', 'ASCII:Jahaf;ID:6940877', '28751');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28751', '112', '30628', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.18.3007» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30629', '1079', '1', 'Damt', 'YE.18.3002', 'ASCII:Damt;ID:6940878', '28752');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28752', '112', '30629', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.18.3002» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30630', '1079', '1', 'Al Azariq', 'YE.18.3008', 'ASCII:Al Azariq;ID:6940879', '28753');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28753', '112', '30630', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.18.3008» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30631', '1079', '1', 'Juban', 'YE.18.3001', 'ASCII:Juban;ID:6940880', '28754');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28754', '112', '30631', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.18.3001» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30632', '1079', '1', 'Ash Shu''ayb', 'YE.18.3004', 'ASCII:Ash Shu''ayb;ID:6940881', '28755');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28755', '112', '30632', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.18.3004» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30633', '1079', '1', 'Bilad At Ta''am', 'YE.27.3101', 'ASCII:Bilad At Ta''am;ID:6940882', '28756');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28756', '112', '30633', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.27.3101» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30634', '1079', '1', 'Mazhar', 'YE.27.3106', 'ASCII:Mazhar;ID:6940883', '28757');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28757', '112', '30634', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «YE.27.3106» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30635', '1079', '1', 'Nchelenge District', 'ZM.08.175497', 'ASCII:Nchelenge District;ID:175497', '28758');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28758', '112', '30635', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.08.175497» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30636', '1079', '1', 'Mporokoso District', 'ZM.07.175966', 'ASCII:Mporokoso District;ID:175966', '28759');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28759', '112', '30636', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.07.175966» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30637', '1079', '1', 'Mbala District', 'ZM.07.176143', 'ASCII:Mbala District;ID:176143', '28760');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28760', '112', '30637', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.07.176143» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30638', '1079', '1', 'Kawambwa District', 'ZM.08.176553', 'ASCII:Kawambwa District;ID:176553', '28761');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28761', '112', '30638', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.08.176553» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30639', '1079', '1', 'Kaputa District', 'ZM.07.176756', 'ASCII:Kaputa District;ID:176756', '28762');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28762', '112', '30639', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.07.176756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30640', '1079', '1', 'Zambezi District', 'ZM.01.895952', 'ASCII:Zambezi District;ID:895952', '28763');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28763', '112', '30640', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.01.895952» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30641', '1079', '1', 'Solwezi District', 'ZM.01.897041', 'ASCII:Solwezi District;ID:897041', '28764');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28764', '112', '30641', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.01.897041» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30642', '1079', '1', 'Sesheke District', 'ZM.03.898902', 'ASCII:Sesheke District;ID:898902', '28765');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28765', '112', '30642', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.03.898902» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30643', '1079', '1', 'Serenje District', 'ZM.05.898909', 'ASCII:Serenje District;ID:898909', '28766');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28766', '112', '30643', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.05.898909» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30644', '1079', '1', 'Senanga District', 'ZM.03.898945', 'ASCII:Senanga District;ID:898945', '28767');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28767', '112', '30644', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.03.898945» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30645', '1079', '1', 'Samfya District', 'ZM.08.899273', 'ASCII:Samfya District;ID:899273', '28768');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28768', '112', '30645', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.08.899273» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30646', '1079', '1', 'Petauke District', 'ZM.06.899821', 'ASCII:Petauke District;ID:899821', '28769');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28769', '112', '30646', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.06.899821» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30647', '1079', '1', 'Ndola Rural District', 'ZM.02.901339', 'ASCII:Ndola Rural District;ID:901339', '28770');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28770', '112', '30647', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.02.901339» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30648', '1079', '1', 'Ndola District', 'ZM.02.901342', 'ASCII:Ndola District;ID:901342', '28771');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28771', '112', '30648', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.02.901342» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30649', '1079', '1', 'Namwala District', 'ZM.04.901764', 'ASCII:Namwala District;ID:901764', '28772');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28772', '112', '30649', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.04.901764» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30650', '1079', '1', 'Mwinilunga District', 'ZM.01.902616', 'ASCII:Mwinilunga District;ID:902616', '28773');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28773', '112', '30650', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.01.902616» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30651', '1079', '1', 'Mwense District', 'ZM.08.902718', 'ASCII:Mwense District;ID:902718', '28774');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28774', '112', '30651', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.08.902718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30652', '1079', '1', 'Mumbwa District', 'ZM.05.904420', 'ASCII:Mumbwa District;ID:904420', '28775');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28775', '112', '30652', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.05.904420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30653', '1079', '1', 'Mufulira District', 'ZM.02.905389', 'ASCII:Mufulira District;ID:905389', '28776');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28776', '112', '30653', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.02.905389» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30654', '1079', '1', 'Mpika District', 'ZM.07.905843', 'ASCII:Mpika District;ID:905843', '28777');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28777', '112', '30654', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.07.905843» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30655', '1079', '1', 'Monze District', 'ZM.04.906042', 'ASCII:Monze District;ID:906042', '28778');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28778', '112', '30655', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.04.906042» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30656', '1079', '1', 'Mongu District', 'ZM.03.906052', 'ASCII:Mongu District;ID:906052', '28779');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28779', '112', '30656', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.03.906052» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30657', '1079', '1', 'Mkushi District', 'ZM.05.906219', 'ASCII:Mkushi District;ID:906219', '28780');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28780', '112', '30657', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.05.906219» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30658', '1079', '1', 'Mazabuka District', 'ZM.04.907108', 'ASCII:Mazabuka District;ID:907108', '28781');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28781', '112', '30658', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.04.907108» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30659', '1079', '1', 'Mansa District', 'ZM.08.907767', 'ASCII:Mansa District;ID:907767', '28782');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28782', '112', '30659', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.08.907767» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30660', '1079', '1', 'Luwingu District', 'ZM.07.908911', 'ASCII:Luwingu District;ID:908911', '28783');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28783', '112', '30660', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.07.908911» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30661', '1079', '1', 'Lusaka District', 'ZM.00.909134', 'ASCII:Lusaka District;ID:909134', '28784');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28784', '112', '30661', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.00.909134» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30662', '1079', '1', 'Lundazi District', 'ZM.06.909296', 'ASCII:Lundazi District;ID:909296', '28785');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28785', '112', '30662', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.06.909296» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30663', '1079', '1', 'Lukulu District', 'ZM.03.909482', 'ASCII:Lukulu District;ID:909482', '28786');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28786', '112', '30663', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.03.909482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30664', '1079', '1', 'Luanshya District', 'ZM.02.909857', 'ASCII:Luanshya District;ID:909857', '28787');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28787', '112', '30664', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.02.909857» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30665', '1079', '1', 'Luangwa District', 'ZM.00.909886', 'ASCII:Luangwa District;ID:909886', '28788');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28788', '112', '30665', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.00.909886» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30666', '1079', '1', 'Livingstone District', 'ZM.04.910107', 'ASCII:Livingstone District;ID:910107', '28789');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28789', '112', '30666', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.04.910107» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30667', '1079', '1', 'Kitwe District', 'ZM.02.911144', 'ASCII:Kitwe District;ID:911144', '28790');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28790', '112', '30667', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.02.911144» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30668', '1079', '1', 'Katete District', 'ZM.06.912053', 'ASCII:Katete District;ID:912053', '28791');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28791', '112', '30668', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.06.912053» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30669', '1079', '1', 'Kasempa District', 'ZM.01.912623', 'ASCII:Kasempa District;ID:912623', '28792');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28792', '112', '30669', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.01.912623» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30670', '1079', '1', 'Kasama District', 'ZM.07.912763', 'ASCII:Kasama District;ID:912763', '28793');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28793', '112', '30670', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.07.912763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30671', '1079', '1', 'Kaoma District', 'ZM.03.913321', 'ASCII:Kaoma District;ID:913321', '28794');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28794', '112', '30671', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.03.913321» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30672', '1079', '1', 'Kalulushi District', 'ZM.02.914956', 'ASCII:Kalulushi District;ID:914956', '28795');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28795', '112', '30672', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.02.914956» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30673', '1079', '1', 'Kalomo District', 'ZM.04.915082', 'ASCII:Kalomo District;ID:915082', '28796');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28796', '112', '30673', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.04.915082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30674', '1079', '1', 'Kalabo District', 'ZM.03.915468', 'ASCII:Kalabo District;ID:915468', '28797');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28797', '112', '30674', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.03.915468» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30675', '1079', '1', 'Kabwe Rural District', 'ZM.05.916077', 'ASCII:Kabwe Rural District;ID:916077', '28798');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28798', '112', '30675', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.05.916077» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30676', '1079', '1', 'Kabwe District', 'ZM.05.916082', 'ASCII:Kabwe District;ID:916082', '28799');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28799', '112', '30676', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.05.916082» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30677', '1079', '1', 'Kabompo District', 'ZM.01.916244', 'ASCII:Kabompo District;ID:916244', '28800');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28800', '112', '30677', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.01.916244» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30678', '1079', '1', 'Isoka District', 'ZM.07.916666', 'ASCII:Isoka District;ID:916666', '28801');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28801', '112', '30678', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.07.916666» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30679', '1079', '1', 'Gwembe District', 'ZM.04.917010', 'ASCII:Gwembe District;ID:917010', '28802');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28802', '112', '30679', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.04.917010» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30680', '1079', '1', 'Choma District', 'ZM.04.917743', 'ASCII:Choma District;ID:917743', '28803');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28803', '112', '30680', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.04.917743» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30681', '1079', '1', 'Chipata District', 'ZM.06.918699', 'ASCII:Chipata District;ID:918699', '28804');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28804', '112', '30681', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.06.918699» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30682', '1079', '1', 'Chinsali District', 'ZM.07.918903', 'ASCII:Chinsali District;ID:918903', '28805');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28805', '112', '30682', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.07.918903» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30683', '1079', '1', 'Chingola District', 'ZM.02.919006', 'ASCII:Chingola District;ID:919006', '28806');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28806', '112', '30683', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.02.919006» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30684', '1079', '1', 'Chililabombwe District', 'ZM.02.919540', 'ASCII:Chililabombwe District;ID:919540', '28807');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28807', '112', '30684', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.02.919540» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30685', '1079', '1', 'Chama District', 'ZM.06.920896', 'ASCII:Chama District;ID:920896', '28808');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28808', '112', '30685', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.06.920896» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30686', '1079', '1', 'Chadiza District', 'ZM.06.921026', 'ASCII:Chadiza District;ID:921026', '28809');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28809', '112', '30686', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZM.06.921026» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30687', '1079', '1', 'Wedza District', 'ZW.00.879178', 'ASCII:Wedza District;ID:879178', '28810');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28810', '112', '30687', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.879178» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30688', '1079', '1', 'Umzingwane District', 'ZW.00.879611', 'ASCII:Umzingwane District;ID:879611', '28811');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28811', '112', '30688', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.879611» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30689', '1079', '1', 'Shurugwi District', 'ZW.00.881163', 'ASCII:Shurugwi District;ID:881163', '28812');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28812', '112', '30689', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.881163» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30690', '1079', '1', 'Shamva District', 'ZW.00.881344', 'ASCII:Shamva District;ID:881344', '28813');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28813', '112', '30690', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.881344» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30691', '1079', '1', 'Seki District', 'ZW.00.881519', 'ASCII:Seki District;ID:881519', '28814');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28814', '112', '30691', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.881519» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30692', '1079', '1', 'Rushinga District', 'ZW.00.882083', 'ASCII:Rushinga District;ID:882083', '28815');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28815', '112', '30692', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.882083» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30693', '1079', '1', 'Nyanga District', 'ZW.00.883480', 'ASCII:Nyanga District;ID:883480', '28816');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28816', '112', '30693', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.883480» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30694', '1079', '1', 'Nyamandhlovu District', 'ZW.06.883763', 'ASCII:Nyamandhlovu District;ID:883763', '28817');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28817', '112', '30694', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.06.883763» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30695', '1079', '1', 'Nkayi District', 'ZW.00.884216', 'ASCII:Nkayi District;ID:884216', '28818');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28818', '112', '30695', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.884216» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30696', '1079', '1', 'Ndanga District', 'ZW.00.884594', 'ASCII:Ndanga District;ID:884594', '28819');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28819', '112', '30696', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.884594» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30697', '1079', '1', 'Mwenezi District', 'ZW.00.884756', 'ASCII:Mwenezi District;ID:884756', '28820');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28820', '112', '30697', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.884756» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30698', '1079', '1', 'Mutoko District', 'ZW.00.884926', 'ASCII:Mutoko District;ID:884926', '28821');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28821', '112', '30698', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.884926» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30699', '1079', '1', 'Mutasa District', 'ZW.00.884977', 'ASCII:Mutasa District;ID:884977', '28822');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28822', '112', '30699', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.884977» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30700', '1079', '1', 'Mutare District', 'ZW.00.884978', 'ASCII:Mutare District;ID:884978', '28823');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28823', '112', '30700', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.884978» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30701', '1079', '1', 'Murehwa District', 'ZW.00.885172', 'ASCII:Murehwa District;ID:885172', '28824');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28824', '112', '30701', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.885172» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30702', '1079', '1', 'Mudzi District', 'ZW.00.885457', 'ASCII:Mudzi District;ID:885457', '28825');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28825', '112', '30702', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.885457» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30703', '1079', '1', 'Mberengwa District', 'ZW.00.886328', 'ASCII:Mberengwa District;ID:886328', '28826');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28826', '112', '30703', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.886328» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30704', '1079', '1', 'Mazowe District', 'ZW.00.886383', 'ASCII:Mazowe District;ID:886383', '28827');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28827', '112', '30704', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.886383» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30705', '1079', '1', 'Matobo District', 'ZW.00.886636', 'ASCII:Matobo District;ID:886636', '28828');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28828', '112', '30705', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.886636» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30706', '1079', '1', 'Masvingo District', 'ZW.00.886762', 'ASCII:Masvingo District;ID:886762', '28829');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28829', '112', '30706', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.886762» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30707', '1079', '1', 'Marondera District', 'ZW.00.886989', 'ASCII:Marondera District;ID:886989', '28830');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28830', '112', '30707', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.886989» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30708', '1079', '1', 'Makoni District', 'ZW.00.887718', 'ASCII:Makoni District;ID:887718', '28831');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28831', '112', '30708', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.887718» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30709', '1079', '1', 'Makonde District', 'ZW.00.887723', 'ASCII:Makonde District;ID:887723', '28832');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28832', '112', '30709', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.887723» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30710', '1079', '1', 'Lupane District', 'ZW.00.888223', 'ASCII:Lupane District;ID:888223', '28833');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28833', '112', '30710', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.888223» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30711', '1079', '1', 'Kwekwe District', 'ZW.00.888708', 'ASCII:Kwekwe District;ID:888708', '28834');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28834', '112', '30711', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.888708» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30712', '1079', '1', 'Kariba District', 'ZW.00.889214', 'ASCII:Kariba District;ID:889214', '28835');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28835', '112', '30712', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.889214» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30713', '1079', '1', 'Kadoma District', 'ZW.00.889452', 'ASCII:Kadoma District;ID:889452', '28836');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28836', '112', '30713', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.889452» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30714', '1079', '1', 'Insiza District', 'ZW.00.889793', 'ASCII:Insiza District;ID:889793', '28837');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28837', '112', '30714', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.889793» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30715', '1079', '1', 'Hwange District', 'ZW.00.889941', 'ASCII:Hwange District;ID:889941', '28838');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28838', '112', '30715', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.889941» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30716', '1079', '1', 'Hurungwe District', 'ZW.00.889953', 'ASCII:Hurungwe District;ID:889953', '28839');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28839', '112', '30716', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.889953» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30717', '1079', '1', 'Harare District', 'ZW.00.890298', 'ASCII:Harare District;ID:890298', '28840');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28840', '112', '30717', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.890298» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30718', '1079', '1', 'Gweru District', 'ZW.00.890420', 'ASCII:Gweru District;ID:890420', '28841');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28841', '112', '30718', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.890420» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30719', '1079', '1', 'Gwanda District', 'ZW.00.890515', 'ASCII:Gwanda District;ID:890515', '28842');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28842', '112', '30719', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.890515» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30720', '1079', '1', 'Gutu District', 'ZW.00.890589', 'ASCII:Gutu District;ID:890589', '28843');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28843', '112', '30720', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.890589» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30721', '1079', '1', 'Guruve District', 'ZW.00.890599', 'ASCII:Guruve District;ID:890599', '28844');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28844', '112', '30721', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.890599» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30722', '1079', '1', 'Goromonzi District', 'ZW.00.890848', 'ASCII:Goromonzi District;ID:890848', '28845');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28845', '112', '30722', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.890848» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30723', '1079', '1', 'Gokwe District', 'ZW.00.890981', 'ASCII:Gokwe District;ID:890981', '28846');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28846', '112', '30723', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.890981» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30724', '1079', '1', 'Darwin District', 'ZW.00.892597', 'ASCII:Darwin District;ID:892597', '28847');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28847', '112', '30724', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.892597» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30725', '1079', '1', 'Chivi District', 'ZW.00.893171', 'ASCII:Chivi District;ID:893171', '28848');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28848', '112', '30725', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.893171» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30726', '1079', '1', 'Chirumanzu District', 'ZW.00.893405', 'ASCII:Chirumanzu District;ID:893405', '28849');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28849', '112', '30726', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.893405» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30727', '1079', '1', 'Chiredzi District', 'ZW.00.893482', 'ASCII:Chiredzi District;ID:893482', '28850');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28850', '112', '30727', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.893482» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30728', '1079', '1', 'Chipinge District', 'ZW.00.893548', 'ASCII:Chipinge District;ID:893548', '28851');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28851', '112', '30728', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.893548» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30729', '1079', '1', 'Chimanimani District', 'ZW.00.893811', 'ASCII:Chimanimani District;ID:893811', '28852');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28852', '112', '30729', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.893811» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30730', '1079', '1', 'Chegutu District', 'ZW.00.894238', 'ASCII:Chegutu District;ID:894238', '28853');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28853', '112', '30730', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.894238» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30731', '1079', '1', 'Charter District', 'ZW.00.894293', 'ASCII:Charter District;ID:894293', '28854');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28854', '112', '30731', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.894293» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30732', '1079', '1', 'Centenary District', 'ZW.00.894459', 'ASCII:Centenary District;ID:894459', '28855');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28855', '112', '30732', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.894459» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30733', '1079', '1', 'Bulawayo District', 'ZW.06.894700', 'ASCII:Bulawayo District;ID:894700', '28856');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28856', '112', '30733', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.06.894700» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30734', '1079', '1', 'Bulilimamangwe District', 'ZW.07.894702', 'ASCII:Bulilimamangwe District;ID:894702', '28857');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28857', '112', '30734', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.07.894702» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30735', '1079', '1', 'Buhera District', 'ZW.00.894711', 'ASCII:Buhera District;ID:894711', '28858');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28858', '112', '30735', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.894711» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30736', '1079', '1', 'Bubi District', 'ZW.00.894741', 'ASCII:Bubi District;ID:894741', '28859');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28859', '112', '30736', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.894741» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30737', '1079', '1', 'Binga District', 'ZW.00.895055', 'ASCII:Binga District;ID:895055', '28860');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28860', '112', '30737', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.895055» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30738', '1079', '1', 'Bindura District', 'ZW.00.895060', 'ASCII:Bindura District;ID:895060', '28861');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28861', '112', '30738', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.895060» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30739', '1079', '1', 'Bikita District', 'ZW.00.895080', 'ASCII:Bikita District;ID:895080', '28862');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28862', '112', '30739', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.895080» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30740', '1079', '1', 'Beitbridge District', 'ZW.00.895268', 'ASCII:Beitbridge District;ID:895268', '28863');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28863', '112', '30740', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «ZW.00.895268» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30741', '1079', '1', 'Qulensya Wa Abd Al Kuri', 'null.04.1927', 'ASCII:Qulensya Wa Abd Al Kuri;ID:6940754', '28864');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28864', '112', '30741', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «null.04.1927» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30742', '1079', '1', 'Zamakh wa Manwakh', 'null.04.1904', 'ASCII:Zamakh wa Manwakh;ID:6940761', '28865');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28865', '112', '30742', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «null.04.1904» pour la liste «76».', '1', '1', '162.38.234.1');
INSERT INTO `tb_coel`.`coel_meta_liste_valeur` (`cmlv_id_valeur` ,`cmlv_ce_parent` ,`cmlv_ce_projet` ,`cmlv_nom` ,`cmlv_abreviation` ,`cmlv_description` ,`cmlv_ce_meta`) VALUES 
	('30743', '1079', '1', 'Shahan', 'null.03.2801', 'ASCII:Shahan;ID:6940852', '28866');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28866', '112', '30743', NULL , '2009-07-29 01:15:00' , 'Initialisation de la valeur «null.03.2801» pour la liste «76».', '1', '1', '162.38.234.1');

# Gestion des colonnes
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('1', '1', '0', '101', 'cc_id_collection', 'cc_id_c', 'Identifiant de la collection.', '15', '', '28867');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28867', '108', '1', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('2', '1', '0', '101', 'cc_ce_projet', 'cc_ce_p', 'Identifiant du projet dans lequel les informations de la collection sont saisies.', '15', '', '28868');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28868', '108', '2', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('3', '1', '0', '101', 'cc_ce_mere', 'cc_ce_m', 'Identifiant de la collection parente. Si la collection courrante n''a pas de parente laisser la valeur 0 par défaut.', '15', '', '28869');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28869', '108', '3', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('4', '1', '0', '101', 'cc_ce_structure', 'cc_ce_s', 'Identifiant de la structure habritant physiquement la collection. Si c''est un particulier, laisser la valeur 0 par défaut et utiliser la table liant les collections aux personnes.', '15', '', '28870');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28870', '108', '4', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('5', '1', '0', '101', 'cc_guid', 'cc_g', 'Identifiant global unique de type LSID ou URI.', '29', '255', '28871');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28871', '108', '5', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('6', '1', '0', '101', 'cc_truk_identifiant_alternatif', 'cc_tia', 'Autres identifiants de la structure.', '29', '255', '28872');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28872', '108', '6', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('7', '1', '0', '101', 'cc_truk_code', 'cc_tc', 'Code(s) de la collection.', '29', '100', '28873');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28873', '108', '7', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('8', '1', '0', '101', 'cc_nom', 'cc_n', 'Nom de la collection dans la langue d''origine. Afficher vis à vis du public.', '29', '255', '28874');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28874', '108', '8', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('9', '1', '0', '101', 'cc_truk_nom_alternatif', 'cc_tna', 'Nom alternatif de la collection.', '37', '', '28875');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28875', '108', '9', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('10', '1', '0', '101', 'cc_description', 'cc_d', 'Description principale de la collection pour un large public.', '37', '', '28876');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28876', '108', '10', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('11', '1', '0', '101', 'cc_description_specialiste', 'cc_ds', 'Description de la collection pour un public de spécialistes.', '37', '', '28877');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28877', '108', '11', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('12', '1', '0', '101', 'cc_historique', 'cc_h', 'Historique de la collection (acquisition, différentes interventions de restauration, de traitement ...).', '37', '', '28878');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28878', '108', '12', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('13', '1', '0', '101', 'cc_truk_url', 'cc_tu', 'URL(s) du site web ou de la page concernant la collection.', '29', '255', '28879');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28879', '108', '13', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('14', '1', '0', '101', 'cc_truk_url_objet', 'cc_tuo', 'URL(s) indiquant un web service ou une page permettant d''accèder à des informations sur les objets de la collection.', '29', '255', '28880');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28880', '108', '14', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('15', '1', '1034', '101', 'cc_truk_groupement_principe', 'cc_tgp', 'Principal but de groupement de la collection au niveau intélectuel plutôt que physique.', '29', '255', '28881');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28881', '108', '15', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('16', '1', '1035', '101', 'cc_truk_groupement_but', 'cc_tgb', 'Principal but de réalisation de la collection.', '15', '', '28882');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28882', '108', '16', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('17', '1', '1032', '101', 'cc_ce_type', 'cc_ce_t', 'Type de la collection vis à vis du standard NCD.', '15', '', '28883');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28883', '108', '17', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('18', '1', '1033', '101', 'cc_ce_type_depot', 'cc_ce_td', 'Type de dépôt de la collection.', '15', '', '28884');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28884', '108', '18', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('19', '1', '0', '101', 'cc_cote', 'cc_c', 'Côte de la collection.', '29', '255', '28885');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28885', '108', '19', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('20', '1', '0', '101', 'cc_dimenssion', 'cc_d', 'Dimenssion, taille de la collection sous forme de texte libre.', '29', '255', '28886');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28886', '108', '20', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('21', '1', '0', '101', 'cc_condition_acces', 'cc_ca', 'Condition d''accès à la collection. Peut être définit par défaut par la structure.', '37', '', '28887');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28887', '108', '21', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('22', '1', '0', '101', 'cc_condition_usage', 'cc_cu', 'Condition d''usages de la collection. Peut être définit par défaut par la structure.', '37', '', '28888');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28888', '108', '22', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('23', '1', '0', '101', 'cc_truk_couverture_vernaculaire', 'cc_tcv', 'Nature de la collection sous forme de nom(s) vernaculaire(s).', '29', '255', '28889');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28889', '108', '23', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('24', '1', '0', '101', 'cc_truk_couverture_taxonomique', 'cc_tct', 'Nom de famille ou de taxons supérieurs présent dans la collection.', '29', '255', '28890');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28890', '108', '24', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('25', '1', '1037', '101', 'cc_truk_couverture_regne', 'cc_tcr', 'Liste des règnes couverts par la collection.', '29', '255', '28891');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28891', '108', '25', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('26', '1', '0', '101', 'cc_truk_couverture_temporelle', 'cc_tct', 'Période de temps couverte par la collection.', '29', '255', '28892');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28892', '108', '26', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('27', '1', '0', '101', 'cc_truk_couverture_vie', 'cc_tcv', 'Période de temps durant laquelle le matériel biologique était en vie. Inclu les périodes de temps paléontologiques.', '29', '255', '28893');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28893', '108', '27', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('28', '1', '1036', '101', 'cc_truk_conservation_statut', 'cc_tcs', 'Indiquer la date d''une estimation séparée par un dièse du statut estimé utilisant l''échelle de McGinley. Plusieurs estimations seront séparés par un point virgule.', '29', '255', '28894');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28894', '108', '28', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('29', '1', '1038', '101', 'cc_truk_preservation', 'cc_tp', 'Liste indiquant les procédures ou techniques de conservation utilisées pour les collections non vivantes.', '29', '255', '28895');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28895', '108', '29', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('30', '1', '1039', '101', 'cc_ce_developpement', 'cc_ce_d', 'Indique le changement potentiel dans la portée de la collection.', '29', '255', '28896');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28896', '108', '30', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('31', '1', '1040', '101', 'cc_truk_periode_constitution', 'cc_tpc', 'Liste de périodes de temps durant laquelle la collection a été assemblée.', '29', '255', '28897');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28897', '108', '31', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('32', '1', '0', '101', 'cc_truk_couverture_lieu', 'cc_tcl', 'Liste de lieux (continent, pays, region, département, commune, autres lieux historique ou texte libre) desquels le matériel de la collection est originaire.', '29', '255', '28898');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28898', '108', '32', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('33', '1', '0', '101', 'cc_truk_coordonnee', 'cc_tc', 'Liste de coordonnées décimales des lieux d''origine du matériel de la collection.', '29', '255', '28899');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28899', '108', '33', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('34', '1', '1041', '101', 'cc_ce_specimen_type', 'cc_ce_st', 'Y-a-t''il des échantillons-types?', '15', '', '28900');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28900', '108', '34', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('35', '1', '0', '101', 'cc_specimen_type_nbre', 'cc_stn', 'Nombre de spécimen type présent dans la collection.', '15', '', '28901');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28901', '108', '35', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('36', '1', '0', '101', 'cc_mark_speciment_type_nbre_precision', 'cc_mstnp', 'Précision sur le nombre de spécimens types indiqué (1 = exact, 0 = approximatif).', '31', '', '28902');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28902', '108', '36', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('37', '1', '1042', '101', 'cc_ce_specimen_type_classement', 'cc_ce_stc', 'Type de classement des specimens types.', '15', '', '28903');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28903', '108', '37', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('38', '1', '0', '101', 'cc_expedition_nom', 'cc_en', 'Nom de l''expédition durant laquelle le matériel a été collecté.', '29', '255', '28904');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28904', '108', '38', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('39', '1', '0', '101', 'cc_truk_digital_medium', 'cc_tdm', 'Pour les collections digitales, listes des types de support d''enregistrement. Ex. : DVD-R.', '29', '255', '28905');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28905', '108', '39', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('40', '1', '0', '101', 'cc_truk_digital_format', 'cc_tdf', 'Pour les collections digitales, listes des types MIME.', '29', '255', '28906');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28906', '108', '40', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('41', '1', '0', '101', 'cc_mark_public', 'cc_mp', 'Indique si oui (=1) ou non (=0) les données de cette collection sont publiques.', '31', '', '28907');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28907', '108', '41', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('42', '1', '0', '101', 'cc_ce_meta', 'cc_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '28908');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28908', '108', '42', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('43', '1', '0', '120', 'cs_id_structure', 'cs_id_s', 'Identifiant de la structure.', '15', '', '28909');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28909', '108', '43', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('44', '1', '0', '120', 'cs_ce_projet', 'cs_ce_p', 'Identifiant du projet dans lequel les informations de la structure sont saisies.', '15', '', '28910');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28910', '108', '44', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('45', '1', '0', '120', 'cs_ce_mere', 'cs_ce_m', 'Identifiant de la structure mère.', '15', '', '28911');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28911', '108', '45', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('46', '1', '0', '120', 'cs_guid', 'cs_g', 'URI (LSID ou URL) de la structure. Dans le format RDF, cela sera utilisé comme URI des données de l''institutions.', '29', '255', '28912');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28912', '108', '46', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('47', '1', '1017', '120', 'cs_truk_identifiant_alternatif', 'cs_tia', 'Identifiant alternatif. Par exemple, l''acronyme de l''Index Herbariorum ou du MNHN. Séparer les différentes valeurs par un point virgule ";" et le type d''identifiant de sa valeur par un dièze "#". Exemple : IH#MPU;MNHN#163', '29', '255', '28913');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28913', '108', '47', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('48', '1', '0', '120', 'cs_nom', 'cs_n', 'Nom officiel de la structure dans sa langue d''origine.', '29', '255', '28914');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28914', '108', '48', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('49', '1', '0', '120', 'cs_truk_nom_alternatif', 'cs_tna', 'Autres noms de la structures. Séparer les différentes valeurs par un point virgule ";".', '29', '255', '28915');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28915', '108', '49', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('50', '1', '0', '120', 'cs_description', 'cs_d', 'Description de la structure pour le public.', '37', '', '28916');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28916', '108', '50', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('51', '1', '1014', '120', 'cs_ce_type', 'cs_ce_t', 'Identifiant du type de la structure vis à vis du standard NCD.', '15', '', '28917');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28917', '108', '51', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('52', '1', '1015', '120', 'cs_ce_truk_type_prive', 'cs_ce_ttp', 'Type privé de structure.', '29', '255', '28918');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28918', '108', '52', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('53', '1', '1016', '120', 'cs_ce_truk_type_public', 'cs_ce_ttp', 'Type public de structure.', '29', '255', '28919');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28919', '108', '53', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('54', '1', '0', '120', 'cs_adresse_01', 'cs_a0', 'Adresse principale.', '29', '255', '28920');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28920', '108', '54', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('55', '1', '0', '120', 'cs_adresse_02', 'cs_a0', 'Complément d''adresse.', '29', '255', '28921');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28921', '108', '55', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('56', '1', '0', '120', 'cs_date_fondation', 'cs_df', 'Date de fondation de la structure.', '23', '', '28922');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28922', '108', '56', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('57', '1', '0', '120', 'cs_code_postal', 'cs_cp', 'Code postal.', '29', '16', '28923');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28923', '108', '57', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('58', '1', '0', '120', 'cs_ville', 'cs_v', 'Ville.', '29', '255', '28924');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28924', '108', '58', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('59', '1', '0', '120', 'cs_region', 'cs_r', 'Nom de la région (état, province) où est situé la structure. Utiliser les noms du standard ISO-3166-2.', '29', '255', '28925');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28925', '108', '59', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('60', '1', '0', '120', 'cs_pays', 'cs_p', 'Pays de la structure. Utiliser les codes sur deux lettres si le nom est dans le standard ISO-3166-1 sinon mettre le nom du pays.', '29', '255', '28926');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28926', '108', '60', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('61', '1', '0', '120', 'cs_latitude', 'cs_l', 'Latitude du local de la structure.', '17', '', '28927');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28927', '108', '61', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('62', '1', '0', '120', 'cs_longitude', 'cs_l', 'Longitude du local de la structure.', '17', '', '28928');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28928', '108', '62', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('63', '1', '0', '120', 'cs_telephone', 'cs_t', 'Téléphone principale de la structure.', '29', '50', '28929');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28929', '108', '63', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('64', '1', '0', '120', 'cs_fax', 'cs_f', 'Fax de la structure.', '29', '50', '28930');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28930', '108', '64', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('65', '1', '0', '120', 'cs_courriel', 'cs_c', 'Courriel principal de contact de l''organisation ex : accueil@organisation.org, pas de mail individuel.', '29', '255', '28931');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28931', '108', '65', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('66', '1', '1066', '120', 'cs_truk_url', 'cs_tu', 'URL(s) du site web principal de la structure, du logo de la structure ou d''une page web particulière.', '29', '255', '28932');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28932', '108', '66', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('67', '1', '0', '120', 'cs_nbre_personne', 'cs_np', 'Nombre de personne présentent dans la structure.', '15', '', '28933');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28933', '108', '67', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('68', '1', '0', '120', 'cs_condition_acces', 'cs_ca', 'Conditions d''accès à la structure.', '37', '', '28934');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28934', '108', '68', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('69', '1', '0', '120', 'cs_condition_usage', 'cs_cu', 'Conditions d''usage générales des collections de la structure.', '37', '', '28935');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28935', '108', '69', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('70', '1', '0', '120', 'cs_mark_public', 'cs_mp', 'Indique si oui (=1) ou non (=0) les données de cette structure sont publiques.', '31', '', '28936');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28936', '108', '70', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('71', '1', '0', '120', 'cs_ce_meta', 'cs_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '28937');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28937', '108', '71', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('72', '1', '0', '113', 'cp_id_personne', 'cp_id_p', 'Identifiant d''un contact.', '15', '', '28938');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28938', '108', '72', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('73', '1', '0', '113', 'cp_ce_projet', 'cp_ce_p', 'Identifiant du projet auquel la personne appartient. Exemple : utilisateur appli coel, HUH, IPNI...', '15', '', '28939');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28939', '108', '73', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('74', '1', '0', '113', 'cp_fmt_nom_complet', 'cp_fnc', 'Nom complet du contact formaté pour l''affichage (le format peut être différent en fonction du projet).', '29', '100', '28940');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28940', '108', '74', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('75', '1', '1004', '113', 'cp_ce_truk_prefix', 'cp_ce_tp', 'Préfixe du nom principal. Exemple : Dr., Prof., Mr., Lord, von...', '29', '20', '28941');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28941', '108', '75', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('76', '1', '0', '113', 'cp_prenom', 'cp_p', 'Prénom principal (le plus connu, répandu) de la personne. Un point virgule peut séparer le prénom principal de prénoms secondaires à ne pas afficher dans le nom complet.', '29', '100', '28942');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28942', '108', '76', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('77', '1', '0', '113', 'cp_nom', 'cp_n', 'Indiquer les lieux de récolte (code ISO des pays) séparés par des points virgules. Après chaque code ISO indiqué les années de récolte séparées par des vigules ou des tirets pour les périodes continues). Si le pays de récolte est inconnu utilisé un point d''interogration. Exemple : FR#1905-1908,1910;PS#1912.', '29', '100', '28943');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28943', '108', '77', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('78', '1', '1005', '113', 'cp_ce_truk_suffix', 'cp_ce_ts', 'Suffixe du nom principal. Exemple : Jr, III.', '29', '20', '28944');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28944', '108', '78', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('79', '1', '1006', '113', 'cp_truk_nom_autre', 'cp_tna', 'Nom(s) complet alternatif et surnoms. Pour les valeurs, séparez l''identifiant de l''abreviation par un symbole pipe "|". Exemple: HUH#105714|Sharp, Aaron John;APN#9544-1|Sharp, Aaron John (''Jack'')', '29', '255', '28945');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28945', '108', '79', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('80', '1', '0', '113', 'cp_abreviation', 'cp_a', 'Abreviation retenu du nom.', '29', '50', '28946');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28946', '108', '80', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('81', '1', '0', '113', 'cp_truk_abreviation_autre', 'cp_taa', 'Autres abréviations du nom.', '29', '255', '28947');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28947', '108', '81', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('82', '1', '0', '113', 'cp_naissance_date', 'cp_nd', 'Date de naissance de la personne.', '23', '', '28948');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28948', '108', '82', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('83', '1', '0', '113', 'cp_naissance_lieu', 'cp_nl', 'Lieu de naissance de la personne.', '29', '100', '28949');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28949', '108', '83', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('84', '1', '0', '113', 'cp_deces_date', 'cp_dd', 'Date de décés de la personne. Par défaut, si la personne n''est pas décédé le champ reste null. Si la personne est décédée mais que l''on ne connait pas la date mettre : 0000-00-00', '23', '', '28950');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28950', '108', '84', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('85', '1', '0', '113', 'cp_deces_lieu', 'cp_dl', 'Lieu de décés de la personne.', '29', '100', '28951');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28951', '108', '85', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('86', '1', '1067', '113', 'cp_ce_sexe', 'cp_ce_s', 'Indique si la personne est un homme ou une femme...', '15', '', '28952');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28952', '108', '86', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('87', '1', '0', '113', 'cp_description', 'cp_d', 'Informations diverses sur la personne.', '37', '', '28953');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28953', '108', '87', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('88', '1', '0', '113', 'cp_biographie', 'cp_b', 'Vie et renommée (locale, régionale, ...) de la personne.', '37', '', '28954');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28954', '108', '88', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('89', '1', '0', '113', 'cp_adresse_01', 'cp_a0', 'Adresse de la personne.', '29', '255', '28955');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28955', '108', '89', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('90', '1', '0', '113', 'cp_adresse_02', 'cp_a0', 'Complément d''adresse personnelle.', '29', '255', '28956');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28956', '108', '90', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('91', '1', '0', '113', 'cp_region', 'cp_r', 'Nom de la région (état, province) où vit la personne. Utiliser les noms du standard ISO-3166-2.', '29', '100', '28957');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28957', '108', '91', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('92', '1', '0', '113', 'cp_bp', 'cp_b', 'Boite postale de l''adresse de la personne.', '29', '20', '28958');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28958', '108', '92', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('93', '1', '0', '113', 'cp_code_postal', 'cp_cp', 'Code postal (zip) personnel.', '29', '10', '28959');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28959', '108', '93', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('94', '1', '0', '113', 'cp_ville', 'cp_v', 'Nom de la localité (ville) où vit la personne.', '29', '100', '28960');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28960', '108', '94', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('95', '1', '0', '113', 'cp_pays', 'cp_p', 'Nom du pays où vit la personne. Utiliser les noms du standard ISO-3166-1.', '29', '100', '28961');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28961', '108', '95', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('96', '1', '1007', '113', 'cp_truk_telephone', 'cp_tt', 'Numéro(s) de téléphone, pager... personnels complémentaires.', '29', '255', '28962');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28962', '108', '96', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('97', '1', '0', '113', 'cp_truk_fax', 'cp_tf', 'Numéro(s) de fax.', '29', '255', '28963');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28963', '108', '97', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('98', '1', '0', '113', 'cp_truk_courriel', 'cp_tc', 'Adresse(s) de courriel personnel. Ajouter les adresses dans leur ordre d''importance.', '29', '255', '28964');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28964', '108', '98', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('99', '1', '0', '113', 'cp_truk_url', 'cp_tu', 'URL(s) de site web personnel. Ajouter les adresses dans leur ordre d''importance.', '29', '255', '28965');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28965', '108', '99', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('100', '1', '0', '113', 'cp_truk_logo', 'cp_tl', 'URL(s) de logo personnel. Ajouter les adresses dans leur ordre d''importance.', '29', '255', '28966');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28966', '108', '100', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('101', '1', '1008', '113', 'cp_ce_truk_specialite', 'cp_ce_ts', 'Indiquer séparer par des points virgules ";" les spécialités naturalistes de la personne.', '29', '255', '28967');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28967', '108', '101', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('102', '1', '0', '113', 'cp_truk_recolte', 'cp_tr', 'Indiquer les lieux de récolte séparés par des points virgules. Indiquer le référentiel géographique utilisé puis après un # mettre le code ou identitifiant de la zone géographique. Après chaque code ISO un peut signe pipe | peut être suivi des années de récolte séparées par des vigules ou des tirets pour les périodes continues). Si le pays de récolte est inconnu utilisé un point d''interogration. Exemple : ISO-3166-1#FR|1905-1908,1910;ISO-3166-1#PS|1912;ISO-3166-2#FR-34|1917.', '29', '255', '28968');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28968', '108', '102', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('103', '1', '1009', '113', 'cp_ce_truk_role', 'cp_ce_tr', 'Rôle générale de la personne vis à vis de l''ensemble des projets : superadmin, admin...', '29', '255', '28969');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28969', '108', '103', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('104', '1', '0', '113', 'cp_mark_licence', 'cp_ml', 'Indique quand la valeur vaut 1 que l''utilisateur a accepté la licence d''utilisation de l''application. ', '31', '', '28970');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28970', '108', '104', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('105', '1', '0', '113', 'cp_parametre', 'cp_p', 'Parametres de l''utilisateur vis à vis de l''application.', '37', '', '28971');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28971', '108', '105', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('106', '1', '0', '113', 'cp_session_id', 'cp_si', 'Identifiant de session de la personne utilisatrice de l''application.', '29', '100', '28972');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28972', '108', '106', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('107', '1', '0', '113', 'cp_login', 'cp_l', 'Login de la personne pour accéder à l''application.', '29', '50', '28973');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28973', '108', '107', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('108', '1', '0', '113', 'cp_mot_de_passe', 'cp_mdp', 'Mot de passe de la personne pour accéder à l''application. Encodé par SHA1.', '29', '100', '28974');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28974', '108', '108', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('109', '1', '0', '113', 'cp_ce_annuaire_tela', 'cp_ce_at', 'Identifiant de la personne dans l''annuaire de Tela Botanica.', '15', '', '28975');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28975', '108', '109', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('110', '1', '0', '113', 'cp_mark_public', 'cp_mp', 'Indique si oui (=1) ou non (=0) les données de cette personne sont publiques.', '31', '', '28976');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28976', '108', '110', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('111', '1', '0', '113', 'cp_ce_meta', 'cp_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '28977');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28977', '108', '111', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('112', '1', '0', '121', 'csap_id_structure', 'csap_id_s', 'Identifiant de la structure.', '15', '', '28978');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28978', '108', '112', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('113', '1', '0', '121', 'csap_id_personne', 'csap_id_p', 'Identifiant d''une personne.', '15', '', '28979');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28979', '108', '113', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('114', '1', '1011', '121', 'csap_id_role', 'csap_id_r', 'Rôle de la personne vis à vis de la structure.', '15', '', '28980');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28980', '108', '114', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('115', '1', '1012', '121', 'csap_ce_truk_fonction', 'csap_ce_tf', 'Intitulé de la fonction de la personne dans son travail.', '29', '255', '28981');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28981', '108', '115', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('116', '1', '0', '121', 'csap_service', 'csap_s', 'Nom du service ou département dans lequel la personne travaille.', '29', '100', '28982');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28982', '108', '116', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('117', '1', '1013', '121', 'csap_ce_truk_statut', 'csap_ce_ts', 'Statut(s) de la personne : salarié, bénévole...', '29', '255', '28983');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28983', '108', '117', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('118', '1', '0', '121', 'csap_mark_contact', 'csap_mc', 'Si la personne est un contact la valeur vaut 1 sinon c''est 0.', '31', '', '28984');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28984', '108', '118', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('119', '1', '0', '121', 'csap_bota_travail_hebdo_tps', 'csap_btht', 'Date de la dernière modification sur cet enregistrement.', '15', '', '28985');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28985', '108', '119', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('120', '1', '0', '121', 'csap_ce_meta', 'csap_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '28986');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28986', '108', '120', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('121', '1', '0', '109', 'cmd_id_donnee', 'cmd_id_d', 'Identifiant de la donnée.', '15', '', '28987');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28987', '108', '121', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('122', '1', '0', '109', 'cmd_ce_table', 'cmd_ce_t', 'Identifiant de la table.', '15', '', '28988');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28988', '108', '122', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('123', '1', '0', '109', 'cmd_ce_ligne', 'cmd_ce_l', 'Identifiant de la ligne à laquelle le champ dans la table d''origine appartient. Pour les tables à clé primaire multi colonnes, bien respecter l''ordre des champs de la clé et inscrire chaque valeur de clé séparée par un tiret "-".', '29', '64', '28989');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28989', '108', '123', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('124', '1', '0', '109', 'cmd_ce_champ', 'cmd_ce_c', 'Identifiant du champ.', '15', '', '28990');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28990', '108', '124', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('125', '1', '0', '109', 'cmd_valeur', 'cmd_v', 'Valeur.', '29', '255', '28991');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28991', '108', '125', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('126', '1', '0', '108', 'cmc_id_champ', 'cmc_id_c', 'Identifiant du nom du champ dans la table.', '15', '', '28992');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28992', '108', '126', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('127', '1', '0', '108', 'cmc_ce_projet', 'cmc_ce_p', 'Identifiant du projet.', '15', '', '28993');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28993', '108', '127', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('128', '1', '0', '108', 'cmc_ce_liste', 'cmc_ce_l', 'Identifiant de la liste de valeur possédée par cette colonne.', '15', '', '28994');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28994', '108', '128', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('129', '1', '1003', '108', 'cmc_ce_table', 'cmc_ce_t', 'Identifiant de la table à laquelle ce champ appartient.', '15', '', '28995');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28995', '108', '129', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('130', '1', '0', '108', 'cmc_nom', 'cmc_n', 'Intitulé du champ.', '29', '50', '28996');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28996', '108', '130', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('131', '1', '0', '108', 'cmc_abreviation', 'cmc_a', 'Abréviation du champ.', '29', '20', '28997');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28997', '108', '131', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('132', '1', '0', '108', 'cmc_description', 'cmc_d', 'Description du champ.', '29', '510', '28998');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28998', '108', '132', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('133', '1', '1002', '108', 'cmc_ce_format_sql', 'cmc_ce_fs', 'Identifiant du format SQL utilisé pour ce champ.', '15', '', '28999');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('28999', '108', '133', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('134', '1', '0', '108', 'cmc_taille', 'cmc_t', 'Taille du format SQL du champ.', '29', '20', '29000');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29000', '108', '134', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('135', '1', '0', '108', 'cmc_ce_meta', 'cmc_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29001');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29001', '108', '135', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('136', '1', '0', '112', 'cmlv_id_valeur', 'cmlv_id_v', 'Identifiant d''une valeur de liste. Notez que les listes sont des valeurs de la liste des listes.', '15', '', '29002');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29002', '108', '136', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('137', '1', '0', '112', 'cmlv_ce_parent', 'cmlv_ce_p', 'Identifiant de la catégorie ou des informations sur la liste. Les listes ont pour parent la valeur 0 qui correspond à la liste des listes.', '15', '', '29003');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29003', '108', '137', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('138', '1', '0', '112', 'cmlv_ce_projet', 'cmlv_ce_p', 'Identifiant du projet de la valeur.', '15', '', '29004');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29004', '108', '138', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('139', '1', '0', '112', 'cmlv_nom', 'cmlv_n', 'Nom de la valeur.', '29', '100', '29005');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29005', '108', '139', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('140', '1', '0', '112', 'cmlv_abreviation', 'cmlv_a', 'Abréviation, code ou identifiant de la valeur.', '29', '50', '29006');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29006', '108', '140', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('141', '1', '0', '112', 'cmlv_description', 'cmlv_d', 'Description de cette valeur.', '29', '255', '29007');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29007', '108', '141', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('142', '1', '0', '112', 'cmlv_ce_meta', 'cmlv_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29008');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29008', '108', '142', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('143', '1', '0', '110', 'cmhc_id_historique_colonne', 'cmhc_id_hc', 'Identifiant de cet enregistrement historisé.', '15', '', '29009');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29009', '108', '143', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('144', '1', '0', '110', 'cmhc_ce_historique_ligne', 'cmhc_ce_hl', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29010');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29010', '108', '144', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('145', '1', '0', '110', 'cmhc_ce_champ', 'cmhc_ce_c', 'Identifiant du champ.', '15', '', '29011');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29011', '108', '145', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('146', '1', '0', '110', 'cmhc_valeur', 'cmhc_v', 'Valeur du champ pour cette ligne.', '29', '255', '29012');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29012', '108', '146', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('147', '1', '0', '122', 'csc_id_structure', 'csc_id_s', 'Identifiant de la structure.', '15', '', '29013');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29013', '108', '147', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('148', '1', '0', '122', 'csc_mark_formation', 'csc_mf', 'Le personnel s''occupant des collections botaniques a-t-il suivi des formations en conservation ?', '31', '', '29014');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29014', '108', '148', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('149', '1', '0', '122', 'csc_formation', 'csc_f', 'Les formations en conservation suvi par le personnel.', '29', '255', '29015');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29015', '108', '149', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('150', '1', '0', '122', 'csc_mark_formation_interet', 'csc_mfi', 'Le personnel s''occupant des collections botaniques a-t-il suivi des formations en conservation ?', '31', '', '29016');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29016', '108', '150', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('151', '1', '0', '122', 'csc_truk_stockage_local', 'csc_tsl', 'Avez-vous des locaux spécifiques de stockage des collections botaniques ?', '29', '255', '29017');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29017', '108', '151', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('152', '1', '0', '122', 'csc_truk_stockage_meuble', 'csc_tsm', 'Avez-vous des meubles spécifiques au stockage des collections botaniques ? ', '29', '255', '29018');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29018', '108', '152', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('153', '1', '1020', '122', 'csc_truk_stockage_parametre', 'csc_tsp', 'Quels paramètres maîtrisez-vous ?', '29', '255', '29019');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29019', '108', '153', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('154', '1', '0', '122', 'csc_mark_collection_commune', 'csc_mcc', 'Les collections botaniques sont-elles conservées avec d''autres collections dans les mêmes locaux (problème de conservation en commun) ? ', '31', '', '29020');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29020', '108', '154', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('155', '1', '1021', '122', 'csc_truk_collection_autre', 'csc_tca', 'Actuellement, vos collections botaniques s''accroissent-elles de nouvelles acquisitions ?', '29', '255', '29021');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29021', '108', '155', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('156', '1', '0', '122', 'csc_mark_acces_controle', 'csc_mac', 'L''accès à vos collections botaniques est-il contrôlé (ex. : manipulation réservée à des personnes compétentes) ?', '31', '', '29022');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29022', '108', '156', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('157', '1', '0', '122', 'csc_mark_restauration', 'csc_mr', 'Effectuez-vous actuellement des opérations de restauration ou de remise en état de vos collections botaniques ?', '31', '', '29023');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29023', '108', '157', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('158', '1', '1022', '122', 'csc_truk_restauration_operation', 'csc_tro', 'Les différentes opérations de restauration actuellement menées.', '29', '255', '29024');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29024', '108', '158', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('159', '1', '1023', '122', 'csc_ce_materiel_conservation', 'csc_ce_mc', 'Utilisez-vous du matériel de conservation ?', '15', '', '29025');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29025', '108', '159', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('160', '1', '1024', '122', 'csc_truk_materiel_autre', 'csc_tma', 'Le matériel, dit de "non conservation" utilisé.', '29', '255', '29026');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29026', '108', '160', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('161', '1', '0', '122', 'csc_mark_traitement', 'csc_mt', 'Réalisez-vous actuellement des traitements globaux contre les insectes ?', '31', '', '29027');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29027', '108', '161', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('162', '1', '0', '122', 'csc_truk_traitement', 'csc_tt', 'Traitements globaux contre les insectes.', '29', '255', '29028');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29028', '108', '162', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('163', '1', '0', '122', 'csc_mark_acquisition_collection', 'csc_mac', 'Actuellement, vos collections botaniques s''accroissent-elles de nouvelles acquisitions ?', '31', '', '29029');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29029', '108', '163', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('164', '1', '0', '122', 'csc_mark_acquisition_echantillon', 'csc_mae', 'Actuellement mettez-vous en herbier de nouveaux échantillons ? ', '31', '', '29030');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29030', '108', '164', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('165', '1', '0', '122', 'csc_mark_acquisition_traitement', 'csc_mat', 'Si oui, faites-vous un traitement contre les insectes avant l''intégration dans vos collections ?', '31', '', '29031');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29031', '108', '165', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('166', '1', '0', '122', 'csc_truk_acquisition_traitement_poison', 'csc_tatp', 'Traitement de type empoisonnement effectué lors des des acquisitions.', '29', '255', '29032');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29032', '108', '166', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('167', '1', '1025', '122', 'csc_truk_acquisition_traitement_insecte', 'csc_tati', 'Traitement de type désinctisation effectué lors des des acquisitions.', '29', '255', '29033');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29033', '108', '167', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('168', '1', '0', '122', 'csc_ce_meta', 'csc_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29034');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29034', '108', '168', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('169', '1', '0', '123', 'csv_id_structure', 'csv_id_s', 'Identifiant de la structure.', '15', '', '29035');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29035', '108', '169', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('170', '1', '0', '123', 'csv_mark_action', 'csv_ma', 'Avez-vous réalisé des actions de valorisation de vos collections botaniques ou avez-vous été sollicités pour la valorisation de ces collections ?', '31', '', '29036');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29036', '108', '170', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('171', '1', '1027', '123', 'csv_truk_action', 'csv_ta', 'Les actions de valorisation réalisées.', '29', '255', '29037');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29037', '108', '171', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('172', '1', '0', '123', 'csv_publication', 'csv_p', 'Quelques titres des ouvrages, articles scientifiques, ... ?', '37', '', '29038');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29038', '108', '172', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('173', '1', '1021', '123', 'csv_collection_autre', 'csv_ca', 'L''organisme dispose-t-il d''autres collections (permettant une valorisation pluridisciplinaire) ?', '29', '255', '29039');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29039', '108', '173', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('174', '1', '0', '123', 'csv_mark_action_future', 'csv_maf', 'Envisagez-vous des actions de valorisation dans le cadre de votre politique culturelle ?', '31', '', '29040');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29040', '108', '174', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('175', '1', '0', '123', 'csv_action_future', 'csv_af', 'Les actions de valorisation futures envisagées.', '29', '255', '29041');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29041', '108', '175', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('176', '1', '0', '123', 'csv_mark_recherche', 'csv_mr', 'Vos collections botaniques sont-elles utilisées pour des recherches scientifiques ?', '31', '', '29042');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29042', '108', '176', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('177', '1', '1028', '123', 'csv_truk_recherche_provenance', 'csv_trp', 'Si oui, par des chercheurs (professionnels ou amateurs ) de  quelle provenance ?', '29', '255', '29043');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29043', '108', '177', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('178', '1', '1029', '123', 'csv_truk_recherche_type', 'csv_trt', 'Et pour quelles types de recherches ? ', '29', '255', '29044');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29044', '108', '178', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('179', '1', '0', '123', 'csv_mark_acces_ss_motif', 'csv_masm', 'Peut-on consulter vos collections botaniques sans motif de recherches scientifiques ?', '31', '', '29045');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29045', '108', '179', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('180', '1', '0', '123', 'csv_acces_ss_motif', 'csv_asm', 'Si oui, quelles démarches doit-on faire pour les consulter ?', '29', '255', '29046');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29046', '108', '180', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('181', '1', '0', '123', 'csv_mark_visite_avec_motif', 'csv_mvam', 'Peut-on visiter vos collections botaniques en avec des objectifs de recherches scientifiques ?', '31', '', '29047');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29047', '108', '181', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('182', '1', '0', '123', 'csv_visite_avec_motif', 'csv_vam', 'Si oui, quelles démarches doit-on faire pour les visiter ?', '29', '255', '29048');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29048', '108', '182', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('183', '1', '0', '123', 'csv_ce_meta', 'csv_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29049');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29049', '108', '183', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('184', '1', '0', '103', 'ccap_id_collection', 'ccap_id_c', 'Identifiant de la collection associée à une personne.', '15', '', '29050');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29050', '108', '184', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('185', '1', '0', '103', 'ccap_id_personne', 'ccap_id_p', 'Identifiant de la personne associée à une collection.', '15', '', '29051');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29051', '108', '185', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('186', '1', '1030', '103', 'ccap_id_role', 'ccap_id_r', 'Rôle(s) de la personne : auteur, collecteur... permet aussi de connaître qui a les droits de modification sur la collection.', '29', '255', '29052');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29052', '108', '186', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('187', '1', '0', '103', 'ccap_ce_meta', 'ccap_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29053');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29053', '108', '187', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('188', '1', '0', '106', 'ccb_id_collection', 'ccb_id_c', 'Identifiant de la collection botanique.', '15', '', '29054');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29054', '108', '188', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('189', '1', '0', '106', 'ccb_ce_truk_type', 'ccb_ce_tt', 'Type(s) de collection botanique.', '29', '255', '29055');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29055', '108', '189', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('190', '1', '1044', '106', 'ccb_truk_unite_rangement', 'ccb_tur', 'Type(s) unité de rangement de la collection botanique. \
Pour chaque type : indication du nombre d''unité, de la précision du nom (exact, approximatif), des formats.', '29', '510', '29056');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29056', '108', '190', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('191', '1', '1045', '106', 'ccb_ce_unite_rangement_etat', 'ccb_ce_ure', 'État de la majorité des unités de rangements (état des rubans, des poignées, des sangles, des cartons...).', '15', '', '29057');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29057', '108', '191', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('192', '1', '1046', '106', 'ccb_truk_unite_base', 'ccb_tub', 'Type(s) d''unité de base de la collection,  si différent de l''unité de rangement. \\  Ex. : si l''unité de rangement est un carton, l''unité de base peut être  une enveloppe. \\  Pour chaque type : indication du nombre d''unité, de la précision du nom (exact = 1, approximatif = 0), des formats (Lxl cm), du nombre de parts, de la précision sur le nombre de parts  (exact = 1, approximatif = 0), du nombre d''espèces, de la précision sur le nombre d''espèces (exact, approximatif).', '29', '510', '29058');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29058', '108', '192', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('193', '1', '1047', '106', 'ccb_truk_conservation_papier_type', 'ccb_tcpt', 'Type(s) du papier de conservation.', '29', '255', '29059');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29059', '108', '193', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('194', '1', '1048', '106', 'ccb_truk_conservation_methode', 'ccb_tcm', 'Type(s) de méthode de conservation.', '29', '255', '29060');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29060', '108', '194', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('195', '1', '0', '106', 'ccb_specimen_fixation_pourcent', 'ccb_sfp', 'Pourcentage de spécimens fixés.', '15', '', '29061');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29061', '108', '195', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('196', '1', '0', '106', 'ccb_etiquette_fixation_pourcent', 'ccb_efp', 'Pourcentage d''étiquettes fixées.', '15', '', '29062');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29062', '108', '196', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('197', '1', '1049', '106', 'ccb_truk_specimen_fixation_methode', 'ccb_tsfm', 'Type(s) de fixation des spécimens.', '29', '255', '29063');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29063', '108', '197', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('198', '1', '1049', '106', 'ccb_truk_etiquette_fixation_support', 'ccb_tefs', 'Type(s) de fixation des étiquettes fixées au support.', '29', '255', '29064');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29064', '108', '198', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('199', '1', '1050', '106', 'ccb_truk_etiquette_fixation_specimen', 'ccb_tefs', 'Type(s) de fixation des étiquettes fixées au spécimen.', '29', '255', '29065');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29065', '108', '199', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('200', '1', '1051', '106', 'ccb_truk_etiquette_ecriture', 'ccb_tee', 'Type(s) d''écriture sur les étiquettes.', '29', '255', '29066');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29066', '108', '200', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('201', '1', '1041', '106', 'ccb_ce_traitement', 'ccb_ce_t', 'La collection botanique semble-t-elle avoir été empoisonnée ou désinsectisée lors de sa réalisation ?', '15', '', '29067');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29067', '108', '201', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('202', '1', '1026', '106', 'ccb_truk_traitement_poison', 'ccb_ttp', 'Type(s) d''empoisonement de la collection.', '29', '255', '29068');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29068', '108', '202', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('203', '1', '1025', '106', 'ccb_truk_traitement_insecte', 'ccb_tti', 'Type(s) de désinctisation de la collection.', '29', '255', '29069');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29069', '108', '203', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('204', '1', '1045', '106', 'ccb_ce_etat_general', 'ccb_ce_eg', 'État général de la collection (grosses attaques d''insectes, pourriture, papier très fragile, etc... de 1 très mauvais à 5 très bon état).', '15', '', '29070');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29070', '108', '204', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('205', '1', '1052', '106', 'ccb_truk_degradation_specimen', 'ccb_tds', 'Type(s) de causes des dégradations des spécimens notées de 1 très mauvais à 5 très bon état.', '29', '255', '29071');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29071', '108', '205', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('206', '1', '1053', '106', 'ccb_truk_degradation_presentation', 'ccb_tdp', 'Type(s) de causes des dégradations de la présentation notées de 1 très mauvais à 5 très bon état.', '29', '255', '29072');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29072', '108', '206', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('207', '1', '1054', '106', 'ccb_ce_determination', 'ccb_ce_d', 'Les échantillons sont-ils déterminables ? (de 1 : quelques fragment de plantes à 5 plantes entières).', '15', '', '29073');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29073', '108', '207', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('208', '1', '1043', '106', 'ccb_truk_nature', 'ccb_tn', 'Nature de l''herbier.', '29', '255', '29074');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29074', '108', '208', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('209', '1', '0', '106', 'ccb_specialite', 'ccb_s', 'Collection botanique spécialisée (ex. herbier de céréales...)', '29', '255', '29075');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29075', '108', '209', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('210', '1', '0', '106', 'ccb_recolte_date_debut', 'ccb_rdd', 'Date extrême de début de récolte.', '23', '', '29076');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29076', '108', '210', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('211', '1', '1055', '106', 'ccb_ce_recolte_date_debut_type', 'ccb_ce_rddt', 'Type de date extrême de début de récolte.', '15', '', '29077');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29077', '108', '211', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('212', '1', '0', '106', 'ccb_recolte_date_fin', 'ccb_rdf', 'Date extrême de fin de récolte.', '23', '', '29078');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29078', '108', '212', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('213', '1', '1056', '106', 'ccb_ce_recolte_date_fin_type', 'ccb_ce_rdft', 'Type de date extrême de fin de récolte.', '15', '', '29079');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29079', '108', '213', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('214', '1', '0', '106', 'ccb_annotation_classement', 'ccb_ac', 'Indiquer le type de classement ou des informations concernant un éventuel classement.', '37', '', '29080');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29080', '108', '214', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('215', '1', '1057', '106', 'ccb_ce_classement_etat', 'ccb_ce_ce', 'État du classement (de 1 très mauvais à 5 très bon).', '15', '', '29081');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29081', '108', '215', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('216', '1', '1058', '106', 'ccb_truk_etiquette_renseignement', 'ccb_ter', 'Pourcentage pour chaque type de renseignements portés sur l''étiquette ou sur la part.', '29', '255', '29082');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29082', '108', '216', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('217', '1', '0', '106', 'ccb_ce_precision_localite', 'ccb_ce_pl', 'Les localités sont elles précises?', '15', '', '29083');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29083', '108', '217', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('218', '1', '1059', '106', 'ccb_ce_precision_date', 'ccb_ce_pd', 'Les dates sont elles précises?', '15', '', '29084');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29084', '108', '218', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('219', '1', '0', '106', 'ccb_annotation_diverse', 'ccb_ad', 'Autres annotations (dons, annotations personnelles, recettes, utilisations médicales...).', '37', '', '29085');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29085', '108', '219', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('220', '1', '1041', '106', 'ccb_ce_collection_integre', 'ccb_ce_ci', 'La collection observée intègre-t-elle des collections botaniques antérieures ?', '15', '', '29086');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29086', '108', '220', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('221', '1', '1060', '106', 'ccb_ce_collection_integre_info', 'ccb_ce_cii', 'Les noms de ces collections sont-ils notés sur les étiquettes de chaque échantillon ?', '15', '', '29087');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29087', '108', '221', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('222', '1', '1041', '106', 'ccb_ce_inventaire', 'ccb_ce_i', 'Existe-t-il un inventaire de cette collection?', '15', '', '29088');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29088', '108', '222', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('223', '1', '1042', '106', 'ccb_ce_inventaire_auteur', 'ccb_ce_ia', 'L''auteur de la collection a-t-il participé à cet inventaire?', '15', '', '29089');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29089', '108', '223', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('224', '1', '1061', '106', 'ccb_ce_inventaire_forme', 'ccb_ce_if', 'Forme de l''inventaire (mnauscrit, informatique...).', '15', '', '29090');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29090', '108', '224', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('225', '1', '0', '106', 'ccb_inventaire_info', 'ccb_ii', 'Quelles informations retrouve-t-on?', '37', '', '29091');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29091', '108', '225', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('226', '1', '1062', '106', 'ccb_ce_truk_inventaire_digital', 'ccb_ce_tid', 'Si inventaire digial, quel logiciel utilisez vous?', '29', '255', '29092');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29092', '108', '226', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('227', '1', '0', '106', 'ccb_inventaire_digital_pourcent', 'ccb_idp', 'Pourcentage de la documentation en base de données.', '15', '', '29093');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29093', '108', '227', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('228', '1', '1063', '106', 'ccb_ce_inventaire_etat', 'ccb_ce_ie', 'L''inventaire est il complet ou partiel?', '15', '', '29094');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29094', '108', '228', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('229', '1', '0', '106', 'ccb_inventaire_donnee_type', 'ccb_idt', 'Quels sont les éléments qui ont déjà été inventoriés (Ex. : familles, localités...) ?', '37', '', '29095');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29095', '108', '229', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('230', '1', '0', '106', 'ccb_ce_meta', 'ccb_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29096');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29096', '108', '230', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('231', '1', '0', '118', 'cpu_id_publication', 'cpu_id_p', 'Identifiant de la publication.', '15', '', '29097');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29097', '108', '231', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('232', '1', '0', '118', 'cpu_ce_projet', 'cpu_ce_p', 'Identifiant du projet dans lequel les données de cet enregistrement ont été saisies.', '15', '', '29098');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29098', '108', '232', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('233', '1', '0', '118', 'cpu_fmt_nom_complet', 'cpu_fnc', 'Intitulé de la publication complet : fmt_auteur, date_parution(année). titre. Editeur (nom), collection, fascicule, indication_nvt. pages.', '29', '255', '29099');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29099', '108', '233', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('234', '1', '0', '118', 'cpu_uri', 'cpu_u', 'URI de la publication qui peut être un site web...', '29', '255', '29100');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29100', '108', '234', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('235', '1', '0', '118', 'cpu_fmt_auteur', 'cpu_fa', 'Contient le nom formaté de l''intitulé auteur(s). Si plusieurs personnes sont auteurs, l''intitulé est formaté ici.', '29', '255', '29101');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29101', '108', '235', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('236', '1', '0', '118', 'cpu_titre', 'cpu_t', 'Titre de l''article ou de l''ouvrage.', '29', '255', '29102');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29102', '108', '236', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('237', '1', '0', '118', 'cpu_ce_truk_editeur', 'cpu_ce_te', 'Identifiant de la structure éditrice de la publication. S''il n''est pas renseignné dans la table Structure, contient AUTRE# suivit du nom complet de la structure éditrice.', '29', '255', '29103');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29103', '108', '237', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('238', '1', '0', '118', 'cpu_collection', 'cpu_c', 'Intitulé de la collection, c''est à dire de la revue.', '29', '255', '29104');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29104', '108', '238', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('239', '1', '0', '118', 'cpu_date_parution', 'cpu_dp', 'Date de parution de la publication.', '23', '', '29105');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29105', '108', '239', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('240', '1', '0', '118', 'cpu_indication_nvt', 'cpu_in', 'Indication du numéro, volume ou tome de la publication. Plutôt utilisé pour les ouvrages et non les articles de revue.', '29', '255', '29106');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29106', '108', '240', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('241', '1', '0', '118', 'cpu_fascicule', 'cpu_f', 'Indication du titre du fascicule. Surtout utilisé pour les revues.', '29', '255', '29107');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29107', '108', '241', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('242', '1', '0', '118', 'cpu_truk_pages', 'cpu_tp', 'Indication du nombre de pages (pour les ouvrages) ou des pages de début et de fin pour un artcile. Dans le cas des ouvrages un nombre doit être présent. Pour les articles deux nombres ou point d''intérogation séparés par un tiret.', '29', '25', '29108');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29108', '108', '242', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('243', '1', '0', '118', 'cpu_ce_meta', 'cpu_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29109');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29109', '108', '243', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('244', '1', '0', '104', 'ccapu_id_collection', 'ccapu_id_c', 'Identifiant de collection.', '15', '', '29110');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29110', '108', '244', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('245', '1', '0', '104', 'ccapu_id_publication', 'ccapu_id_p', 'Identifiant de la publication.', '15', '', '29111');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29111', '108', '245', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('246', '1', '0', '104', 'ccapu_mark_licence', 'ccapu_ml', 'Booléen indiquant si la publication indiqué correspond aux droits de propriétés intellectuelles de la collection.', '31', '', '29112');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29112', '108', '246', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('247', '1', '0', '104', 'ccapu_ce_meta', 'ccapu_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29113');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29113', '108', '247', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('248', '1', '0', '119', 'cpuap_id_publication', 'cpuap_id_p', 'Identifiant d''une publication.', '15', '', '29114');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29114', '108', '248', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('249', '1', '0', '119', 'cpuap_id_personne', 'cpuap_id_p', 'Identifiant d''une personne.', '15', '', '29115');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29115', '108', '249', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('250', '1', '1064', '119', 'cpuap_id_role', 'cpuap_id_r', 'Rôle de la personne vis à vis de la publication : contributeur, auteur...', '15', '', '29116');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29116', '108', '250', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('251', '1', '1065', '119', 'cpuap_ce_truk_type', 'cpuap_ce_tt', 'Contient le type de référence bibliographique : nécrologie, biographie, publication personnelle...', '29', '255', '29117');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29117', '108', '251', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('252', '1', '0', '119', 'cpuap_ce_meta', 'cpuap_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29118');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29118', '108', '252', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('253', '1', '0', '105', 'ccar_id_collection_01', 'ccar_id_c0', 'Identifiant de la collection n°1.', '15', '', '29119');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29119', '108', '253', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('254', '1', '0', '105', 'ccar_id_collection_02', 'ccar_id_c0', 'Identifiant de la collection n°2.', '15', '', '29120');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29120', '108', '254', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('255', '1', '1031', '105', 'ccar_id_relation', 'ccar_id_r', 'Indentifiant du type de la relation.', '15', '', '29121');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29121', '108', '255', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('256', '1', '0', '105', 'ccar_ce_meta', 'ccar_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29122');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29122', '108', '256', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('257', '1', '0', '115', 'cpr_id_projet', 'cpr_id_p', 'Identifiant d''un projet.', '15', '', '29123');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29123', '108', '257', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('258', '1', '0', '115', 'cpr_nom', 'cpr_n', 'Nom du projet.', '29', '255', '29124');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29124', '108', '258', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('259', '1', '0', '115', 'cpr_abreviation', 'cpr_a', 'Abréviation du projet.', '29', '40', '29125');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29125', '108', '259', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('260', '1', '0', '115', 'cpr_resume', 'cpr_r', 'Résumé du projet.', '29', '255', '29126');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29126', '108', '260', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('261', '1', '0', '115', 'cpr_description', 'cpr_d', 'Description détaillée du projet.', '37', '', '29127');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29127', '108', '261', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('262', '1', '0', '115', 'cpr_url', 'cpr_u', 'URL principal où trouver des compléments d''information sur le projet.', '29', '255', '29128');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29128', '108', '262', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('263', '1', '0', '115', 'cpr_mot_cles', 'cpr_mc', 'Mots clés correspondant au projet.', '29', '255', '29129');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29129', '108', '263', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('264', '1', '0', '115', 'cpr_citation', 'cpr_c', 'Indication sur la fa\195\167on de citer le projet pour réaliser une bibliographie.', '29', '255', '29130');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29130', '108', '264', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('265', '1', '0', '115', 'cpr_licence', 'cpr_l', 'Url ou texte présentant la licence des données du projet.', '29', '255', '29131');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29131', '108', '265', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('266', '1', '1071', '115', 'cpr_ce_langue', 'cpr_ce_l', 'Langue principale des données du projet (selon l''ISO-639-1).', '15', '', '29132');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29132', '108', '266', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('267', '1', '0', '115', 'cpr_indexation_heure', 'cpr_ih', 'Préférence de l''heure de départ pour les procédures d''indexation externe.', '26', '', '29133');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29133', '108', '267', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('268', '1', '1072', '115', 'cpr_ce_indexation_duree', 'cpr_ce_id', 'Durée maximum acceptable pour une procédure d''indexation externe.', '15', '', '29134');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29134', '108', '268', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('269', '1', '1073', '115', 'cpr_ce_indexation_freq', 'cpr_ce_if', 'Fréquence maximum acceptable pour une procédure d''indexation externe.', '15', '', '29135');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29135', '108', '269', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('270', '1', '0', '115', 'cpr_mark_public', 'cpr_mp', 'Indique si oui (=1) ou non (=0) ce projet est public. Si oui, il peut être publié dans eFlore.', '31', '', '29136');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29136', '108', '270', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('271', '1', '0', '115', 'cpr_ce_meta', 'cpr_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29137');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29137', '108', '271', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('272', '1', '0', '114', 'cpar_id_personne_01', 'cpar_id_p0', 'Identifiant de la personne n°1.', '15', '', '29138');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29138', '108', '272', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('273', '1', '0', '114', 'cpar_id_personne_02', 'cpar_id_p0', 'Identifiant de la personne n°2.', '15', '', '29139');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29139', '108', '273', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('274', '1', '0', '114', 'cpar_id_projet', 'cpar_id_p', 'Identifiant du projet dans lequel la relation entre les deux personnes s''établie.', '15', '', '29140');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29140', '108', '274', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('275', '1', '1010', '114', 'cpar_id_role', 'cpar_id_r', 'Identifiant du rôle ou de la valeur établie entre les deux personnes.', '15', '', '29141');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29141', '108', '275', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('276', '1', '0', '114', 'cpar_ce_meta', 'cpar_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29142');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29142', '108', '276', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('277', '1', '0', '117', 'cprv_id_version', 'cprv_id_v', 'Identifiant d''une version de projet.', '15', '', '29143');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29143', '108', '277', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('278', '1', '0', '117', 'cprv_ce_projet', 'cprv_ce_p', 'Identifiant du projet de la version.', '15', '', '29144');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29144', '108', '278', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('279', '1', '0', '117', 'cprv_nom', 'cprv_n', 'Nom éventuel de la version.', '29', '255', '29145');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29145', '108', '279', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('280', '1', '0', '117', 'cprv_code', 'cprv_c', 'Numéro ou code de la version.', '29', '25', '29146');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29146', '108', '280', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('281', '1', '0', '117', 'cprv_date_debut', 'cprv_dd', 'Date de début de la version.', '24', '', '29147');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29147', '108', '281', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('282', '1', '0', '117', 'cprv_date_fin', 'cprv_df', 'Date de fin de la version.', '24', '', '29148');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29148', '108', '282', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('283', '1', '0', '117', 'cprv_ce_meta', 'cprv_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29149');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29149', '108', '283', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('284', '1', '0', '111', 'cmhl_id_historique_ligne', 'cmhl_id_hl', 'Identifiant de l''historique des lignes.', '15', '', '29150');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29150', '108', '284', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('285', '1', '0', '111', 'cmhl_ce_table', 'cmhl_ce_t', 'Identifiant de la table.', '15', '', '29151');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29151', '108', '285', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('286', '1', '0', '111', 'cmhl_cle_ligne', 'cmhl_cl', 'Identifiant de la ligne. Pour les tables à clé primaire multi colonnes, bien respecter l''ordre des champs de la clé et inscrire chaque valeur de clé séparée par un tiret "-".', '29', '64', '29152');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29152', '108', '286', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('287', '1', '0', '111', 'cmhl_enregistrement', 'cmhl_e', 'Contient les données au format XML pour les enregistrements supprimés uniquement, sinon possède la valeur NULL. Format XML : <xml encoding="UTF-8><ligne><nom_du_champ_01>valeur_du_champ_01</nom_du_champ_01><nom_du_champ_02>valeur_du_champ_02</nom_du_champ_02>...</ligne></xml>.', '37', '', '29153');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29153', '108', '287', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('288', '1', '0', '111', 'cmhl_date_modification', 'cmhl_dm', 'Date de modification de la ligne.', '24', '', '29154');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29154', '108', '288', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('289', '1', '0', '111', 'cmhl_notes', 'cmhl_n', 'Notes sur la modification effectuée sur la ligne.', '29', '255', '29155');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29155', '108', '289', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('290', '1', '0', '111', 'cmhl_ce_modifier_par', 'cmhl_ce_mp', 'Identifiant de la personne ayant effectué cette modification sur la ligne.', '15', '', '29156');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29156', '108', '290', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('291', '1', '1001', '111', 'cmhl_ce_etat', 'cmhl_ce_e', 'Identifiant de l''état de la ligne.', '15', '', '29157');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29157', '108', '291', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('292', '1', '0', '111', 'cmhl_ip', 'cmhl_i', 'Adresse IP (et MAC éventuellement) depuis laquelle la modification a eu lieu.', '29', '50', '29158');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29158', '108', '292', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('293', '1', '0', '111', 'cmhl_session_id', 'cmhl_si', 'Identifiant de session del ''utilisateur.', '29', '40', '29159');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29159', '108', '293', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('294', '1', '0', '107', 'ccm_id_commentaire', 'ccm_id_c', 'Identifiant d''un commentaire.', '15', '', '29160');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29160', '108', '294', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('295', '1', '0', '107', 'ccm_ce_pere', 'ccm_ce_p', 'Identifiant du commentaire père.', '15', '', '29161');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29161', '108', '295', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('296', '1', '0', '107', 'ccm_ce_projet', 'ccm_ce_p', 'Identifiant du projet dans lequel le commentaire est fait.', '15', '', '29162');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29162', '108', '296', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('297', '1', '0', '107', 'ccm_titre', 'ccm_t', 'Titre du commentaire.', '29', '255', '29163');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29163', '108', '297', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('298', '1', '0', '107', 'ccm_texte', 'ccm_t', 'Texte du commentaire.', '37', '', '29164');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29164', '108', '298', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('299', '1', '0', '107', 'ccm_ponderation', 'ccm_p', 'Pondération du commentaire (importance). Valeur de 1 à 10.', '15', '', '29165');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29165', '108', '299', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('300', '1', '0', '107', 'ccm_ce_meta', 'ccm_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29166');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29166', '108', '300', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('301', '1', '0', '107', 'ccm_mark_public', 'ccm_mp', 'Indique si oui (=1) ou non (=0) ce commentaire est public .', '31', '', '29167');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29167', '108', '301', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('302', '1', '0', '102', 'ccac_id_collection', 'ccac_id_c', 'Identifiant de la collection.', '15', '', '29168');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29168', '108', '302', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('303', '1', '0', '102', 'ccac_id_commentaire', 'ccac_id_c', 'Identifiant du commentaire.', '15', '', '29169');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29169', '108', '303', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('304', '1', '1068', '102', 'ccac_truk_type', 'ccac_tt', 'Liste des types de commentaires séparés par des points virgules.', '29', '255', '29170');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29170', '108', '304', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('305', '1', '0', '102', 'ccac_ce_meta', 'ccac_ce_m', 'Identifiant des métadonnées de cet enregistrement.', '15', '', '29171');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29171', '108', '305', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
		INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('306', '1', '0', '116', 'cpras_id_projet', 'cpras_id_p', '', '15', '', '29172');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29172', '108', '306', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('307', '1', '0', '116', 'cpras_id_structure', 'cpras_id_s', '', '15', '', '29173');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29173', '108', '307', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('308', '1', '0', '116', 'cpras_truk_role', 'cpras_tr', '', '29', '255', '29174');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29174', '108', '308', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	INSERT INTO `tb_coel`.`coel_meta_colonne` (`cmc_id_champ` ,`cmc_ce_projet` ,`cmc_ce_liste` ,`cmc_ce_table` ,`cmc_nom` ,`cmc_abreviation` ,`cmc_description` ,`cmc_ce_format_sql` ,`cmc_taille` ,`cmc_ce_meta`) VALUES 
	('309', '1', '0', '116', 'cpras_ce_meta', 'cpras_ce_m', '', '15', '', '29175');
INSERT INTO `tb_coel`.`coel_meta_historique_ligne` (`cmhl_id_historique_ligne` ,`cmhl_ce_table` ,`cmhl_cle_ligne` ,`cmhl_enregistrement` ,`cmhl_date_modification` ,`cmhl_notes` ,`cmhl_ce_modifier_par` ,`cmhl_ce_etat` ,`cmhl_ip`) VALUES 
	('29175', '108', '309', NULL , NOW( ) , 'Ajout des informations sur une colonne.', '1', '1', '162.38.234.1');
	
ALTER TABLE `tb_coel`.`coel_meta_liste_valeur`  ORDER BY `cmlv_id_valeur`;
#---------------------------------------------------------------------------------------------------------------------#
# Gestion des tables de la base de données phpmyadmin
# Table PMA_TABLE_INFO
DELETE FROM `phpmyadmin`.`pma_table_info` WHERE `db_name` = 'tb_coel';
INSERT INTO `phpmyadmin`.`pma_table_info` (`db_name`, `table_name`, `display_field`)
VALUES ('tb_coel', 'coel_collection', 'cc_nom');
INSERT INTO `phpmyadmin`.`pma_table_info` (`db_name`, `table_name`, `display_field`)
VALUES ('tb_coel', 'coel_structure', 'cs_nom');
INSERT INTO `phpmyadmin`.`pma_table_info` (`db_name`, `table_name`, `display_field`)
VALUES ('tb_coel', 'coel_personne', 'cp_fmt_nom_complet');
INSERT INTO `phpmyadmin`.`pma_table_info` (`db_name`, `table_name`, `display_field`)
VALUES ('tb_coel', 'coel_meta_colonne', 'cmc_nom');
INSERT INTO `phpmyadmin`.`pma_table_info` (`db_name`, `table_name`, `display_field`)
VALUES ('tb_coel', 'coel_meta_liste_valeur', 'cmlv_nom');
INSERT INTO `phpmyadmin`.`pma_table_info` (`db_name`, `table_name`, `display_field`)
VALUES ('tb_coel', 'coel_publication', 'cpu_fmt_nom_complet');
INSERT INTO `phpmyadmin`.`pma_table_info` (`db_name`, `table_name`, `display_field`)
VALUES ('tb_coel', 'coel_projet', 'cpr_nom');
INSERT INTO `phpmyadmin`.`pma_table_info` (`db_name`, `table_name`, `display_field`)
VALUES ('tb_coel', 'coel_projet_version', 'cprv_nom');
INSERT INTO `phpmyadmin`.`pma_table_info` (`db_name`, `table_name`, `display_field`)
VALUES ('tb_coel', 'coel_meta_historique_ligne', 'cmhl_date_modification');
INSERT INTO `phpmyadmin`.`pma_table_info` (`db_name`, `table_name`, `display_field`)
VALUES ('tb_coel', 'coel_commentaire', 'ccm_titre');

# Table PMA_RELATION
DELETE FROM `phpmyadmin`.`pma_relation` WHERE `master_db` = 'tb_coel' OR `foreign_db` = 'tb_coel';
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_a_personne', 'csap_id_structure', 'tb_coel', 'coel_structure', 'cs_id_structure');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_a_personne', 'csap_id_personne', 'tb_coel', 'coel_personne', 'cp_id_personne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_donnee', 'cmd_ce_champ', 'tb_coel', 'coel_meta_colonne', 'cmc_id_champ');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_historique_colonne', 'cmhc_ce_champ', 'tb_coel', 'coel_meta_colonne', 'cmc_id_champ');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection', 'cc_ce_structure', 'tb_coel', 'coel_structure', 'cs_id_structure');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection', 'cc_ce_mere', 'tb_coel', 'coel_collection', 'cc_id_collection');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_conservation', 'csc_id_structure', 'tb_coel', 'coel_structure', 'cs_id_structure');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_valorisation', 'csv_id_structure', 'tb_coel', 'coel_structure', 'cs_id_structure');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_personne', 'ccap_id_collection', 'tb_coel', 'coel_collection', 'cc_id_collection');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_personne', 'ccap_id_personne', 'tb_coel', 'coel_personne', 'cp_id_personne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_id_collection', 'tb_coel', 'coel_collection', 'cc_id_collection');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure', 'cs_ce_mere', 'tb_coel', 'coel_structure', 'cs_id_structure');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_publication', 'ccapu_id_collection', 'tb_coel', 'coel_collection', 'cc_id_collection');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_publication', 'ccapu_id_publication', 'tb_coel', 'coel_publication', 'cpu_id_publication');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_publication_a_personne', 'cpuap_id_personne', 'tb_coel', 'coel_personne', 'cp_id_personne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_publication_a_personne', 'cpuap_id_publication', 'tb_coel', 'coel_publication', 'cpu_id_publication');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_relation', 'ccar_id_collection_01', 'tb_coel', 'coel_collection', 'cc_id_collection');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_relation', 'ccar_id_collection_02', 'tb_coel', 'coel_collection', 'cc_id_collection');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne_a_relation', 'cpar_id_projet', 'tb_coel', 'coel_projet', 'cpr_id_projet');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne_a_relation', 'cpar_id_personne_01', 'tb_coel', 'coel_personne', 'cp_id_personne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_publication', 'cpu_ce_truk_editeur', 'tb_coel', 'coel_structure', 'cs_id_structure');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne', 'cp_ce_projet', 'tb_coel', 'coel_projet', 'cpr_id_projet');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure', 'cs_ce_projet', 'tb_coel', 'coel_projet', 'cpr_id_projet');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection', 'cc_ce_projet', 'tb_coel', 'coel_projet', 'cpr_id_projet');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_publication', 'cpu_ce_projet', 'tb_coel', 'coel_projet', 'cpr_id_projet');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_projet_version', 'cprv_ce_projet', 'tb_coel', 'coel_projet', 'cpr_id_projet');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne_a_relation', 'cpar_id_personne_02', 'tb_coel', 'coel_personne', 'cp_id_personne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_historique_ligne', 'cmhl_ce_modifier_par', 'tb_coel', 'coel_personne', 'cp_id_personne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_liste_valeur', 'cmlv_ce_projet', 'tb_coel', 'coel_projet', 'cpr_id_projet');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_liste_valeur', 'cmlv_ce_parent', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_colonne', 'cmc_ce_liste', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_colonne', 'cmc_ce_projet', 'tb_coel', 'coel_projet', 'cpr_id_projet');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_historique_colonne', 'cmhc_ce_historique_ligne', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_liste_valeur', 'cmlv_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_colonne', 'cmc_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure', 'cs_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure', 'cs_ce_type', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure', 'cs_ce_truk_type_prive', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure', 'cs_ce_truk_type_public', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_commentaire', 'ccm_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_commentaire', 'ccm_ce_projet', 'tb_coel', 'coel_projet', 'cpr_id_projet');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_commentaire', 'ccm_ce_pere', 'tb_coel', 'coel_commentaire', 'ccm_id_commentaire');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_commentaire', 'ccac_id_collection', 'tb_coel', 'coel_collection', 'cc_id_collection');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_commentaire', 'ccac_id_commentaire', 'tb_coel', 'coel_commentaire', 'ccm_id_commentaire');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_commentaire', 'ccac_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne', 'cp_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne_a_relation', 'cpar_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_projet', 'cpr_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_projet_version', 'cprv_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_historique_ligne', 'cmhl_ce_etat', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_a_personne', 'csap_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_relation', 'ccar_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_personne', 'ccap_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection', 'cc_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_publication', 'ccapu_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_publication', 'cpu_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_publication_a_personne', 'cpuap_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_colonne', 'cmc_ce_table', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_colonne', 'cmc_ce_format_sql', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_donnee', 'cmd_ce_table', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_meta_historique_ligne', 'cmhl_ce_table', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne_a_relation', 'cpar_id_role', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne', 'cp_ce_truk_prefix', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne', 'cp_ce_truk_suffix', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne', 'cp_ce_sexe', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne', 'cp_ce_truk_specialite', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_personne', 'cp_ce_truk_role', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_a_personne', 'csap_ce_truk_fonction', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_a_personne', 'csap_ce_truk_statut', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_conservation', 'csc_ce_materiel_conservation', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_publication_a_personne', 'cpuap_ce_truk_type', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_publication_a_personne', 'cpuap_id_role', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_relation', 'ccar_id_relation', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_a_personne', 'ccap_id_role', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection', 'cc_ce_type', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection', 'cc_ce_developpement', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection', 'cc_ce_specimen_type', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection', 'cc_ce_specimen_type_classement', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_unite_rangement_etat', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_traitement', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_etat_general', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_determination', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_recolte_date_debut_type', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_recolte_date_fin_type', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_classement_etat', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_precision_localite', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_precision_date', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_collection_integre', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_collection_integre_info', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_inventaire', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_inventaire_auteur', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_inventaire_forme', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_truk_inventaire_digital', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_inventaire_etat', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection', 'cc_ce_type_depot', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_projet_a_structure', 'cpras_id_projet', 'tb_coel', 'coel_projet', 'cpr_id_projet');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_projet_a_structure', 'cpras_id_structure', 'tb_coel', 'coel_structure', 'cs_id_structure');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_projet_a_structure', 'cpras_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_projet', 'cpr_ce_langue', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_projet', 'cpr_ce_indexation_duree', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_projet', 'cpr_ce_indexation_freq', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_conservation', 'csc_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_valorisation', 'csv_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_collection_botanique', 'ccb_ce_meta', 'tb_coel', 'coel_meta_historique_ligne', 'cmhl_id_historique_ligne');
INSERT INTO `phpmyadmin`.`pma_relation` (`master_db`, `master_table`, `master_field`, `foreign_db`, `foreign_table`, `foreign_field`) 
VALUES ('tb_coel', 'coel_structure_a_personne', 'csap_id_role', 'tb_coel', 'coel_meta_liste_valeur', 'cmlv_id_valeur');

# Table PMA_DESIGNER_COORDS
DELETE FROM `phpmyadmin`.`pma_designer_coords` WHERE `db_name` = 'tb_coel';
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_collection', 36, 1151, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_structure', 806, 1410, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_personne', 1204, 540, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_structure_a_personne', 1203, 1523, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_meta_donnee', 272, 312, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_meta_colonne', 572, 93, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_meta_liste_valeur', 108, 57, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_meta_historique_colonne', 840, 316, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_structure_conservation', 1170, 1795, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_structure_valorisation', 827, 2027, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_collection_a_personne', 473, 1068, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_collection_botanique', 443, 1329, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_publication', 98, 2368, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_collection_a_publication', 45, 2181, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_publication_a_personne', 508, 2404, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_collection_a_relation', 76, 955, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_projet', 57, 541, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_personne_a_relation', 817, 568, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_projet_version', 500, 526, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_meta_historique_ligne', 1161, 132, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_commentaire', 826, 2390, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_collection_a_commentaire', 427, 2183, 1, 1);
INSERT INTO `phpmyadmin`.`pma_designer_coords` (`db_name`, `table_name`, `x`, `y`, `v`, `h`) 
VALUES ('tb_coel', 'coel_projet_a_structure', 451, 762, 1, 1);
